"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __knownSymbol = (name, symbol) => (symbol = Symbol[name]) ? symbol : /* @__PURE__ */ Symbol.for("Symbol." + name);
var __typeError = (msg) => {
  throw TypeError(msg);
};
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });
var __esm = (fn, res, err) => function __init() {
  if (err) throw err[0];
  try {
    return fn && (res = (0, fn[__getOwnPropNames(fn)[0]])(fn = 0)), res;
  } catch (e32) {
    throw err = [e32], e32;
  }
};
var __commonJS = (cb, mod) => function __require() {
  try {
    return mod || (0, cb[__getOwnPropNames(cb)[0]])((mod = { exports: {} }).exports, mod), mod.exports;
  } catch (e32) {
    throw mod = 0, e32;
  }
};
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __reExport = (target, mod, secondTarget) => (__copyProps(target, mod, "default"), secondTarget && __copyProps(secondTarget, mod, "default"));
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var __decorateClass = (decorators, target, key, kind) => {
  var result2 = kind > 1 ? void 0 : kind ? __getOwnPropDesc(target, key) : target;
  for (var i32 = decorators.length - 1, decorator; i32 >= 0; i32--)
    if (decorator = decorators[i32])
      result2 = (kind ? decorator(target, key, result2) : decorator(result2)) || result2;
  if (kind && result2) __defProp(target, key, result2);
  return result2;
};
var __using = (stack, value, async) => {
  if (value != null) {
    if (typeof value !== "object" && typeof value !== "function") __typeError("Object expected");
    var dispose, inner;
    if (async) dispose = value[__knownSymbol("asyncDispose")];
    if (dispose === void 0) {
      dispose = value[__knownSymbol("dispose")];
      if (async) inner = dispose;
    }
    if (typeof dispose !== "function") __typeError("Object not disposable");
    if (inner) dispose = function() {
      try {
        inner.call(this);
      } catch (e32) {
        return Promise.reject(e32);
      }
    };
    stack.push([async, dispose, value]);
  } else if (async) {
    stack.push([async]);
  }
  return value;
};
var __callDispose = (stack, error4, hasError) => {
  var E = typeof SuppressedError === "function" ? SuppressedError : function(e32, s, m20, _) {
    return _ = Error(m20), _.name = "SuppressedError", _.error = e32, _.suppressed = s, _;
  };
  var fail = (e32) => error4 = hasError ? new E(e32, error4, "An error was suppressed during disposal") : (hasError = true, e32);
  var next = (it) => {
    while (it = stack.pop()) {
      try {
        var result2 = it[1] && it[1].call(it[2]);
        if (it[0]) return Promise.resolve(result2).then(next, (e32) => (fail(e32), next()));
      } catch (e32) {
        fail(e32);
      }
    }
    if (hasError) throw error4;
  };
  return next();
};

// ../@aws-cdk/cloud-assembly-api/lib/context/vpc.ts
var vpc_exports = {};
__export(vpc_exports, {
  VpcSubnetGroupType: () => VpcSubnetGroupType
});
var VpcSubnetGroupType;
var init_vpc = __esm({
  "../@aws-cdk/cloud-assembly-api/lib/context/vpc.ts"() {
    "use strict";
    VpcSubnetGroupType = /* @__PURE__ */ ((VpcSubnetGroupType3) => {
      VpcSubnetGroupType3["PUBLIC"] = "Public";
      VpcSubnetGroupType3["PRIVATE"] = "Private";
      VpcSubnetGroupType3["ISOLATED"] = "Isolated";
      return VpcSubnetGroupType3;
    })(VpcSubnetGroupType || {});
  }
});

// ../@aws-cdk/cloud-assembly-api/lib/context/ami.ts
var ami_exports = {};
var init_ami = __esm({
  "../@aws-cdk/cloud-assembly-api/lib/context/ami.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/cloud-assembly-api/lib/context/load-balancer.ts
var load_balancer_exports = {};
__export(load_balancer_exports, {
  LoadBalancerIpAddressType: () => LoadBalancerIpAddressType
});
var LoadBalancerIpAddressType;
var init_load_balancer = __esm({
  "../@aws-cdk/cloud-assembly-api/lib/context/load-balancer.ts"() {
    "use strict";
    LoadBalancerIpAddressType = /* @__PURE__ */ ((LoadBalancerIpAddressType3) => {
      LoadBalancerIpAddressType3["IPV4"] = "ipv4";
      LoadBalancerIpAddressType3["DUAL_STACK"] = "dualstack";
      LoadBalancerIpAddressType3["DUAL_STACK_WITHOUT_PUBLIC_IPV4"] = "dualstack-without-public-ipv4";
      return LoadBalancerIpAddressType3;
    })(LoadBalancerIpAddressType || {});
  }
});

// ../@aws-cdk/cloud-assembly-api/lib/context/availability-zones.ts
var availability_zones_exports = {};
__export(availability_zones_exports, {
  AVAILABILITY_ZONE_FALLBACK_CONTEXT_KEY: () => AVAILABILITY_ZONE_FALLBACK_CONTEXT_KEY
});
var AVAILABILITY_ZONE_FALLBACK_CONTEXT_KEY;
var init_availability_zones = __esm({
  "../@aws-cdk/cloud-assembly-api/lib/context/availability-zones.ts"() {
    "use strict";
    AVAILABILITY_ZONE_FALLBACK_CONTEXT_KEY = "aws:cdk:availability-zones:fallback";
  }
});

// ../@aws-cdk/cloud-assembly-api/lib/context/endpoint-service-availability-zones.ts
var endpoint_service_availability_zones_exports = {};
__export(endpoint_service_availability_zones_exports, {
  ENDPOINT_SERVICE_AVAILABILITY_ZONE_PROVIDER: () => ENDPOINT_SERVICE_AVAILABILITY_ZONE_PROVIDER
});
var ENDPOINT_SERVICE_AVAILABILITY_ZONE_PROVIDER;
var init_endpoint_service_availability_zones = __esm({
  "../@aws-cdk/cloud-assembly-api/lib/context/endpoint-service-availability-zones.ts"() {
    "use strict";
    ENDPOINT_SERVICE_AVAILABILITY_ZONE_PROVIDER = "endpoint-service-availability-zones";
  }
});

// ../@aws-cdk/cloud-assembly-api/lib/context/security-group.ts
var security_group_exports = {};
var init_security_group = __esm({
  "../@aws-cdk/cloud-assembly-api/lib/context/security-group.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/cloud-assembly-api/lib/context/key.ts
var key_exports = {};
var init_key = __esm({
  "../@aws-cdk/cloud-assembly-api/lib/context/key.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/cloud-assembly-api/lib/context/generic.ts
var generic_exports = {};
__export(generic_exports, {
  PROVIDER_ERROR_KEY: () => PROVIDER_ERROR_KEY
});
var PROVIDER_ERROR_KEY;
var init_generic = __esm({
  "../@aws-cdk/cloud-assembly-api/lib/context/generic.ts"() {
    "use strict";
    PROVIDER_ERROR_KEY = "$providerError";
  }
});

// ../@aws-cdk/cloud-assembly-schema/lib/cloud-assembly/schema.ts
var ArtifactType;
var init_schema = __esm({
  "../@aws-cdk/cloud-assembly-schema/lib/cloud-assembly/schema.ts"() {
    "use strict";
    ArtifactType = /* @__PURE__ */ ((ArtifactType6) => {
      ArtifactType6["NONE"] = "none";
      ArtifactType6["AWS_CLOUDFORMATION_STACK"] = "aws:cloudformation:stack";
      ArtifactType6["CDK_TREE"] = "cdk:tree";
      ArtifactType6["ASSET_MANIFEST"] = "cdk:asset-manifest";
      ArtifactType6["NESTED_CLOUD_ASSEMBLY"] = "cdk:cloud-assembly";
      ArtifactType6["FEATURE_FLAG_REPORT"] = "cdk:feature-flag-report";
      return ArtifactType6;
    })(ArtifactType || {});
  }
});

// ../@aws-cdk/cloud-assembly-schema/lib/cloud-assembly/metadata-schema.ts
var ArtifactMetadataEntryType;
var init_metadata_schema = __esm({
  "../@aws-cdk/cloud-assembly-schema/lib/cloud-assembly/metadata-schema.ts"() {
    "use strict";
    ArtifactMetadataEntryType = /* @__PURE__ */ ((ArtifactMetadataEntryType7) => {
      ArtifactMetadataEntryType7["ASSET"] = "aws:cdk:asset";
      ArtifactMetadataEntryType7["INFO"] = "aws:cdk:info";
      ArtifactMetadataEntryType7["WARN"] = "aws:cdk:warning";
      ArtifactMetadataEntryType7["ERROR"] = "aws:cdk:error";
      ArtifactMetadataEntryType7["LOGICAL_ID"] = "aws:cdk:logicalId";
      ArtifactMetadataEntryType7["STACK_TAGS"] = "aws:cdk:stack-tags";
      ArtifactMetadataEntryType7["DO_NOT_REFACTOR"] = "aws:cdk:do-not-refactor";
      ArtifactMetadataEntryType7["CREATION_STACK"] = "aws:cdk:creationStack";
      ArtifactMetadataEntryType7["PROPERTY_ASSIGNMENT"] = "aws:cdk:propertyAssignment";
      return ArtifactMetadataEntryType7;
    })(ArtifactMetadataEntryType || {});
  }
});

// ../@aws-cdk/cloud-assembly-schema/lib/cloud-assembly/artifact-schema.ts
var init_artifact_schema = __esm({
  "../@aws-cdk/cloud-assembly-schema/lib/cloud-assembly/artifact-schema.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/cloud-assembly-schema/lib/cloud-assembly/context-queries.ts
var ContextProvider, LoadBalancerType, LoadBalancerListenerProtocol;
var init_context_queries = __esm({
  "../@aws-cdk/cloud-assembly-schema/lib/cloud-assembly/context-queries.ts"() {
    "use strict";
    ContextProvider = /* @__PURE__ */ ((ContextProvider3) => {
      ContextProvider3["AMI_PROVIDER"] = "ami";
      ContextProvider3["AVAILABILITY_ZONE_PROVIDER"] = "availability-zones";
      ContextProvider3["HOSTED_ZONE_PROVIDER"] = "hosted-zone";
      ContextProvider3["SSM_PARAMETER_PROVIDER"] = "ssm";
      ContextProvider3["VPC_PROVIDER"] = "vpc-provider";
      ContextProvider3["ENDPOINT_SERVICE_AVAILABILITY_ZONE_PROVIDER"] = "endpoint-service-availability-zones";
      ContextProvider3["LOAD_BALANCER_PROVIDER"] = "load-balancer";
      ContextProvider3["LOAD_BALANCER_LISTENER_PROVIDER"] = "load-balancer-listener";
      ContextProvider3["SECURITY_GROUP_PROVIDER"] = "security-group";
      ContextProvider3["KEY_PROVIDER"] = "key-provider";
      ContextProvider3["CC_API_PROVIDER"] = "cc-api-provider";
      ContextProvider3["PLUGIN"] = "plugin";
      return ContextProvider3;
    })(ContextProvider || {});
    LoadBalancerType = /* @__PURE__ */ ((LoadBalancerType2) => {
      LoadBalancerType2["NETWORK"] = "network";
      LoadBalancerType2["APPLICATION"] = "application";
      return LoadBalancerType2;
    })(LoadBalancerType || {});
    LoadBalancerListenerProtocol = /* @__PURE__ */ ((LoadBalancerListenerProtocol2) => {
      LoadBalancerListenerProtocol2["HTTP"] = "HTTP";
      LoadBalancerListenerProtocol2["HTTPS"] = "HTTPS";
      LoadBalancerListenerProtocol2["TCP"] = "TCP";
      LoadBalancerListenerProtocol2["TLS"] = "TLS";
      LoadBalancerListenerProtocol2["UDP"] = "UDP";
      LoadBalancerListenerProtocol2["TCP_UDP"] = "TCP_UDP";
      return LoadBalancerListenerProtocol2;
    })(LoadBalancerListenerProtocol || {});
  }
});

// ../@aws-cdk/cloud-assembly-schema/lib/cloud-assembly/interfaces.ts
var init_interfaces = __esm({
  "../@aws-cdk/cloud-assembly-schema/lib/cloud-assembly/interfaces.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/cloud-assembly-schema/lib/cloud-assembly/validation-report-schema.ts
var init_validation_report_schema = __esm({
  "../@aws-cdk/cloud-assembly-schema/lib/cloud-assembly/validation-report-schema.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/cloud-assembly-schema/lib/cloud-assembly/index.ts
var cloud_assembly_exports = {};
__export(cloud_assembly_exports, {
  ArtifactMetadataEntryType: () => ArtifactMetadataEntryType,
  ArtifactType: () => ArtifactType,
  ContextProvider: () => ContextProvider,
  LoadBalancerListenerProtocol: () => LoadBalancerListenerProtocol,
  LoadBalancerType: () => LoadBalancerType
});
var init_cloud_assembly = __esm({
  "../@aws-cdk/cloud-assembly-schema/lib/cloud-assembly/index.ts"() {
    "use strict";
    init_schema();
    init_metadata_schema();
    init_artifact_schema();
    init_context_queries();
    init_interfaces();
    init_validation_report_schema();
  }
});

// ../@aws-cdk/cloud-assembly-schema/lib/assets/schema.ts
var init_schema2 = __esm({
  "../@aws-cdk/cloud-assembly-schema/lib/assets/schema.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/cloud-assembly-schema/lib/assets/docker-image-asset.ts
var init_docker_image_asset = __esm({
  "../@aws-cdk/cloud-assembly-schema/lib/assets/docker-image-asset.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/cloud-assembly-schema/lib/assets/file-asset.ts
var FileAssetPackaging;
var init_file_asset = __esm({
  "../@aws-cdk/cloud-assembly-schema/lib/assets/file-asset.ts"() {
    "use strict";
    FileAssetPackaging = /* @__PURE__ */ ((FileAssetPackaging4) => {
      FileAssetPackaging4["FILE"] = "file";
      FileAssetPackaging4["ZIP_DIRECTORY"] = "zip";
      return FileAssetPackaging4;
    })(FileAssetPackaging || {});
  }
});

// ../@aws-cdk/cloud-assembly-schema/lib/assets/aws-destination.ts
var init_aws_destination = __esm({
  "../@aws-cdk/cloud-assembly-schema/lib/assets/aws-destination.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/cloud-assembly-schema/lib/assets/index.ts
var assets_exports = {};
__export(assets_exports, {
  FileAssetPackaging: () => FileAssetPackaging
});
var init_assets = __esm({
  "../@aws-cdk/cloud-assembly-schema/lib/assets/index.ts"() {
    "use strict";
    init_schema2();
    init_docker_image_asset();
    init_file_asset();
    init_aws_destination();
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/jsonschema/lib/helpers.js
var require_helpers = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/jsonschema/lib/helpers.js"(exports2, module2) {
    "use strict";
    var ValidationError = exports2.ValidationError = /* @__PURE__ */ __name(function ValidationError2(message2, instance, schema, path47, name, argument) {
      if (Array.isArray(path47)) {
        this.path = path47;
        this.property = path47.reduce(function(sum4, item) {
          return sum4 + makeSuffix(item);
        }, "instance");
      } else if (path47 !== void 0) {
        this.property = path47;
      }
      if (message2) {
        this.message = message2;
      }
      if (schema) {
        var id = schema.$id || schema.id;
        this.schema = id || schema;
      }
      if (instance !== void 0) {
        this.instance = instance;
      }
      this.name = name;
      this.argument = argument;
      this.stack = this.toString();
    }, "ValidationError");
    ValidationError.prototype.toString = /* @__PURE__ */ __name(function toString() {
      return this.property + " " + this.message;
    }, "toString");
    var ValidatorResult = exports2.ValidatorResult = /* @__PURE__ */ __name(function ValidatorResult2(instance, schema, options, ctx) {
      this.instance = instance;
      this.schema = schema;
      this.options = options;
      this.path = ctx.path;
      this.propertyPath = ctx.propertyPath;
      this.errors = [];
      this.throwError = options && options.throwError;
      this.throwFirst = options && options.throwFirst;
      this.throwAll = options && options.throwAll;
      this.disableFormat = options && options.disableFormat === true;
    }, "ValidatorResult");
    ValidatorResult.prototype.addError = /* @__PURE__ */ __name(function addError(detail) {
      var err;
      if (typeof detail == "string") {
        err = new ValidationError(detail, this.instance, this.schema, this.path);
      } else {
        if (!detail) throw new Error("Missing error detail");
        if (!detail.message) throw new Error("Missing error message");
        if (!detail.name) throw new Error("Missing validator type");
        err = new ValidationError(detail.message, this.instance, this.schema, this.path, detail.name, detail.argument);
      }
      this.errors.push(err);
      if (this.throwFirst) {
        throw new ValidatorResultError(this);
      } else if (this.throwError) {
        throw err;
      }
      return err;
    }, "addError");
    ValidatorResult.prototype.importErrors = /* @__PURE__ */ __name(function importErrors(res) {
      if (typeof res == "string" || res && res.validatorType) {
        this.addError(res);
      } else if (res && res.errors) {
        this.errors = this.errors.concat(res.errors);
      }
    }, "importErrors");
    function stringizer(v, i32) {
      return i32 + ": " + v.toString() + "\n";
    }
    __name(stringizer, "stringizer");
    ValidatorResult.prototype.toString = /* @__PURE__ */ __name(function toString(res) {
      return this.errors.map(stringizer).join("");
    }, "toString");
    Object.defineProperty(ValidatorResult.prototype, "valid", { get: /* @__PURE__ */ __name(function() {
      return !this.errors.length;
    }, "get") });
    module2.exports.ValidatorResultError = ValidatorResultError;
    function ValidatorResultError(result2) {
      if (typeof Error.captureStackTrace === "function") {
        Error.captureStackTrace(this, ValidatorResultError);
      }
      this.instance = result2.instance;
      this.schema = result2.schema;
      this.options = result2.options;
      this.errors = result2.errors;
    }
    __name(ValidatorResultError, "ValidatorResultError");
    ValidatorResultError.prototype = new Error();
    ValidatorResultError.prototype.constructor = ValidatorResultError;
    ValidatorResultError.prototype.name = "Validation Error";
    var SchemaError = exports2.SchemaError = /* @__PURE__ */ __name(function SchemaError2(msg, schema) {
      this.message = msg;
      this.schema = schema;
      Error.call(this, msg);
      if (typeof Error.captureStackTrace === "function") {
        Error.captureStackTrace(this, SchemaError2);
      }
    }, "SchemaError");
    SchemaError.prototype = Object.create(
      Error.prototype,
      {
        constructor: { value: SchemaError, enumerable: false },
        name: { value: "SchemaError", enumerable: false }
      }
    );
    var SchemaContext = exports2.SchemaContext = /* @__PURE__ */ __name(function SchemaContext2(schema, options, path47, base, schemas) {
      this.schema = schema;
      this.options = options;
      if (Array.isArray(path47)) {
        this.path = path47;
        this.propertyPath = path47.reduce(function(sum4, item) {
          return sum4 + makeSuffix(item);
        }, "instance");
      } else {
        this.propertyPath = path47;
      }
      this.base = base;
      this.schemas = schemas;
    }, "SchemaContext");
    SchemaContext.prototype.resolve = /* @__PURE__ */ __name(function resolve13(target) {
      return (() => resolveUrl(this.base, target))();
    }, "resolve");
    SchemaContext.prototype.makeChild = /* @__PURE__ */ __name(function makeChild(schema, propertyName) {
      var path47 = propertyName === void 0 ? this.path : this.path.concat([propertyName]);
      var id = schema.$id || schema.id;
      let base = (() => resolveUrl(this.base, id || ""))();
      var ctx = new SchemaContext(schema, this.options, path47, base, Object.create(this.schemas));
      if (id && !ctx.schemas[base]) {
        ctx.schemas[base] = schema;
      }
      return ctx;
    }, "makeChild");
    var FORMAT_REGEXPS = exports2.FORMAT_REGEXPS = {
      // 7.3.1. Dates, Times, and Duration
      "date-time": /^\d{4}-(?:0[0-9]{1}|1[0-2]{1})-(3[01]|0[1-9]|[12][0-9])[tT ](2[0-4]|[01][0-9]):([0-5][0-9]):(60|[0-5][0-9])(\.\d+)?([zZ]|[+-]([0-5][0-9]):(60|[0-5][0-9]))$/,
      "date": /^\d{4}-(?:0[0-9]{1}|1[0-2]{1})-(3[01]|0[1-9]|[12][0-9])$/,
      "time": /^(2[0-4]|[01][0-9]):([0-5][0-9]):(60|[0-5][0-9])$/,
      "duration": /P(T\d+(H(\d+M(\d+S)?)?|M(\d+S)?|S)|\d+(D|M(\d+D)?|Y(\d+M(\d+D)?)?)(T\d+(H(\d+M(\d+S)?)?|M(\d+S)?|S))?|\d+W)/i,
      // 7.3.2. Email Addresses
      // TODO: fix the email production
      "email": /^(?:[\w\!\#\$\%\&\'\*\+\-\/\=\?\^\`\{\|\}\~]+\.)*[\w\!\#\$\%\&\'\*\+\-\/\=\?\^\`\{\|\}\~]+@(?:(?:(?:[a-zA-Z0-9](?:[a-zA-Z0-9\-](?!\.)){0,61}[a-zA-Z0-9]?\.)+[a-zA-Z0-9](?:[a-zA-Z0-9\-](?!$)){0,61}[a-zA-Z0-9]?)|(?:\[(?:(?:[01]?\d{1,2}|2[0-4]\d|25[0-5])\.){3}(?:[01]?\d{1,2}|2[0-4]\d|25[0-5])\]))$/,
      "idn-email": /^("(?:[!#-\[\]-\u{10FFFF}]|\\[\t -\u{10FFFF}])*"|[!#-'*+\-/-9=?A-Z\^-\u{10FFFF}](?:\.?[!#-'*+\-/-9=?A-Z\^-\u{10FFFF}])*)@([!#-'*+\-/-9=?A-Z\^-\u{10FFFF}](?:\.?[!#-'*+\-/-9=?A-Z\^-\u{10FFFF}])*|\[[!-Z\^-\u{10FFFF}]*\])$/u,
      // 7.3.3. Hostnames
      // 7.3.4. IP Addresses
      "ip-address": /^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$/,
      // FIXME whitespace is invalid
      "ipv6": /^\s*((([0-9A-Fa-f]{1,4}:){7}([0-9A-Fa-f]{1,4}|:))|(([0-9A-Fa-f]{1,4}:){6}(:[0-9A-Fa-f]{1,4}|((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3})|:))|(([0-9A-Fa-f]{1,4}:){5}(((:[0-9A-Fa-f]{1,4}){1,2})|:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3})|:))|(([0-9A-Fa-f]{1,4}:){4}(((:[0-9A-Fa-f]{1,4}){1,3})|((:[0-9A-Fa-f]{1,4})?:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(([0-9A-Fa-f]{1,4}:){3}(((:[0-9A-Fa-f]{1,4}){1,4})|((:[0-9A-Fa-f]{1,4}){0,2}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(([0-9A-Fa-f]{1,4}:){2}(((:[0-9A-Fa-f]{1,4}){1,5})|((:[0-9A-Fa-f]{1,4}){0,3}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(([0-9A-Fa-f]{1,4}:){1}(((:[0-9A-Fa-f]{1,4}){1,6})|((:[0-9A-Fa-f]{1,4}){0,4}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(:(((:[0-9A-Fa-f]{1,4}){1,7})|((:[0-9A-Fa-f]{1,4}){0,5}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:)))(%.+)?\s*$/,
      // 7.3.5. Resource Identifiers
      // TODO: A more accurate regular expression for "uri" goes:
      // [A-Za-z][+\-.0-9A-Za-z]*:((/(/((%[0-9A-Fa-f]{2}|[!$&-.0-9;=A-Z_a-z~])+|(\[(([Vv][0-9A-Fa-f]+\.[!$&-.0-;=A-Z_a-z~]+)?|[.0-:A-Fa-f]+)\])?)(:\d*)?)?)?#(%[0-9A-Fa-f]{2}|[!$&-;=?-Z_a-z~])*|(/(/((%[0-9A-Fa-f]{2}|[!$&-.0-9;=A-Z_a-z~])+|(\[(([Vv][0-9A-Fa-f]+\.[!$&-.0-;=A-Z_a-z~]+)?|[.0-:A-Fa-f]+)\])?)(:\d*)?[/?]|[!$&-.0-;=?-Z_a-z~])|/?%[0-9A-Fa-f]{2}|[!$&-.0-;=?-Z_a-z~])(%[0-9A-Fa-f]{2}|[!$&-;=?-Z_a-z~])*(#(%[0-9A-Fa-f]{2}|[!$&-;=?-Z_a-z~])*)?|/(/((%[0-9A-Fa-f]{2}|[!$&-.0-9;=A-Z_a-z~])+(:\d*)?|(\[(([Vv][0-9A-Fa-f]+\.[!$&-.0-;=A-Z_a-z~]+)?|[.0-:A-Fa-f]+)\])?:\d*|\[(([Vv][0-9A-Fa-f]+\.[!$&-.0-;=A-Z_a-z~]+)?|[.0-:A-Fa-f]+)\])?)?)?
      "uri": /^[a-zA-Z][a-zA-Z0-9+.-]*:[^\s]*$/,
      "uri-reference": /^(((([A-Za-z][+\-.0-9A-Za-z]*(:%[0-9A-Fa-f]{2}|:[!$&-.0-;=?-Z_a-z~]|[/?])|\?)(%[0-9A-Fa-f]{2}|[!$&-;=?-Z_a-z~])*|([A-Za-z][+\-.0-9A-Za-z]*:?)?)|([A-Za-z][+\-.0-9A-Za-z]*:)?\/((%[0-9A-Fa-f]{2}|\/((%[0-9A-Fa-f]{2}|[!$&-.0-9;=A-Z_a-z~])+|(\[(([Vv][0-9A-Fa-f]+\.[!$&-.0-;=A-Z_a-z~]+)?|[.0-:A-Fa-f]+)\])?)(:\d*)?[/?]|[!$&-.0-;=?-Z_a-z~])(%[0-9A-Fa-f]{2}|[!$&-;=?-Z_a-z~])*|(\/((%[0-9A-Fa-f]{2}|[!$&-.0-9;=A-Z_a-z~])+|(\[(([Vv][0-9A-Fa-f]+\.[!$&-.0-;=A-Z_a-z~]+)?|[.0-:A-Fa-f]+)\])?)(:\d*)?)?))#(%[0-9A-Fa-f]{2}|[!$&-;=?-Z_a-z~])*|(([A-Za-z][+\-.0-9A-Za-z]*)?%[0-9A-Fa-f]{2}|[!$&-.0-9;=@_~]|[A-Za-z][+\-.0-9A-Za-z]*[!$&-*,;=@_~])(%[0-9A-Fa-f]{2}|[!$&-.0-9;=@-Z_a-z~])*((([/?](%[0-9A-Fa-f]{2}|[!$&-;=?-Z_a-z~])*)?#|[/?])(%[0-9A-Fa-f]{2}|[!$&-;=?-Z_a-z~])*)?|([A-Za-z][+\-.0-9A-Za-z]*(:%[0-9A-Fa-f]{2}|:[!$&-.0-;=?-Z_a-z~]|[/?])|\?)(%[0-9A-Fa-f]{2}|[!$&-;=?-Z_a-z~])*|([A-Za-z][+\-.0-9A-Za-z]*:)?\/((%[0-9A-Fa-f]{2}|\/((%[0-9A-Fa-f]{2}|[!$&-.0-9;=A-Z_a-z~])+|(\[(([Vv][0-9A-Fa-f]+\.[!$&-.0-;=A-Z_a-z~]+)?|[.0-:A-Fa-f]+)\])?)(:\d*)?[/?]|[!$&-.0-;=?-Z_a-z~])(%[0-9A-Fa-f]{2}|[!$&-;=?-Z_a-z~])*|\/((%[0-9A-Fa-f]{2}|[!$&-.0-9;=A-Z_a-z~])+(:\d*)?|(\[(([Vv][0-9A-Fa-f]+\.[!$&-.0-;=A-Z_a-z~]+)?|[.0-:A-Fa-f]+)\])?:\d*|\[(([Vv][0-9A-Fa-f]+\.[!$&-.0-;=A-Z_a-z~]+)?|[.0-:A-Fa-f]+)\])?)?|[A-Za-z][+\-.0-9A-Za-z]*:?)?$/,
      "iri": /^[a-zA-Z][a-zA-Z0-9+.-]*:[^\s]*$/,
      "iri-reference": /^(((([A-Za-z][+\-.0-9A-Za-z]*(:%[0-9A-Fa-f]{2}|:[!$&-.0-;=?-Z_a-z~-\u{10FFFF}]|[/?])|\?)(%[0-9A-Fa-f]{2}|[!$&-;=?-Z_a-z~-\u{10FFFF}])*|([A-Za-z][+\-.0-9A-Za-z]*:?)?)|([A-Za-z][+\-.0-9A-Za-z]*:)?\/((%[0-9A-Fa-f]{2}|\/((%[0-9A-Fa-f]{2}|[!$&-.0-9;=A-Z_a-z~-\u{10FFFF}])+|(\[(([Vv][0-9A-Fa-f]+\.[!$&-.0-;=A-Z_a-z~-\u{10FFFF}]+)?|[.0-:A-Fa-f]+)\])?)(:\d*)?[/?]|[!$&-.0-;=?-Z_a-z~-\u{10FFFF}])(%[0-9A-Fa-f]{2}|[!$&-;=?-Z_a-z~-\u{10FFFF}])*|(\/((%[0-9A-Fa-f]{2}|[!$&-.0-9;=A-Z_a-z~-\u{10FFFF}])+|(\[(([Vv][0-9A-Fa-f]+\.[!$&-.0-;=A-Z_a-z~-\u{10FFFF}]+)?|[.0-:A-Fa-f]+)\])?)(:\d*)?)?))#(%[0-9A-Fa-f]{2}|[!$&-;=?-Z_a-z~-\u{10FFFF}])*|(([A-Za-z][+\-.0-9A-Za-z]*)?%[0-9A-Fa-f]{2}|[!$&-.0-9;=@_~-\u{10FFFF}]|[A-Za-z][+\-.0-9A-Za-z]*[!$&-*,;=@_~-\u{10FFFF}])(%[0-9A-Fa-f]{2}|[!$&-.0-9;=@-Z_a-z~-\u{10FFFF}])*((([/?](%[0-9A-Fa-f]{2}|[!$&-;=?-Z_a-z~-\u{10FFFF}])*)?#|[/?])(%[0-9A-Fa-f]{2}|[!$&-;=?-Z_a-z~-\u{10FFFF}])*)?|([A-Za-z][+\-.0-9A-Za-z]*(:%[0-9A-Fa-f]{2}|:[!$&-.0-;=?-Z_a-z~-\u{10FFFF}]|[/?])|\?)(%[0-9A-Fa-f]{2}|[!$&-;=?-Z_a-z~-\u{10FFFF}])*|([A-Za-z][+\-.0-9A-Za-z]*:)?\/((%[0-9A-Fa-f]{2}|\/((%[0-9A-Fa-f]{2}|[!$&-.0-9;=A-Z_a-z~-\u{10FFFF}])+|(\[(([Vv][0-9A-Fa-f]+\.[!$&-.0-;=A-Z_a-z~-\u{10FFFF}]+)?|[.0-:A-Fa-f]+)\])?)(:\d*)?[/?]|[!$&-.0-;=?-Z_a-z~-\u{10FFFF}])(%[0-9A-Fa-f]{2}|[!$&-;=?-Z_a-z~-\u{10FFFF}])*|\/((%[0-9A-Fa-f]{2}|[!$&-.0-9;=A-Z_a-z~-\u{10FFFF}])+(:\d*)?|(\[(([Vv][0-9A-Fa-f]+\.[!$&-.0-;=A-Z_a-z~-\u{10FFFF}]+)?|[.0-:A-Fa-f]+)\])?:\d*|\[(([Vv][0-9A-Fa-f]+\.[!$&-.0-;=A-Z_a-z~-\u{10FFFF}]+)?|[.0-:A-Fa-f]+)\])?)?|[A-Za-z][+\-.0-9A-Za-z]*:?)?$/u,
      "uuid": /^[0-9A-F]{8}-[0-9A-F]{4}-[0-9A-F]{4}-[0-9A-F]{4}-[0-9A-F]{12}$/i,
      // 7.3.6. uri-template
      "uri-template": /(%[0-9a-f]{2}|[!#$&(-;=?@\[\]_a-z~]|\{[!#&+,./;=?@|]?(%[0-9a-f]{2}|[0-9_a-z])(\.?(%[0-9a-f]{2}|[0-9_a-z]))*(:[1-9]\d{0,3}|\*)?(,(%[0-9a-f]{2}|[0-9_a-z])(\.?(%[0-9a-f]{2}|[0-9_a-z]))*(:[1-9]\d{0,3}|\*)?)*\})*/iu,
      // 7.3.7. JSON Pointers
      "json-pointer": /^(\/([\x00-\x2e0-@\[-}\x7f]|~[01])*)*$/iu,
      "relative-json-pointer": /^\d+(#|(\/([\x00-\x2e0-@\[-}\x7f]|~[01])*)*)$/iu,
      // hostname regex from: http://stackoverflow.com/a/1420225/5628
      "hostname": /^(?=.{1,255}$)[0-9A-Za-z](?:(?:[0-9A-Za-z]|-){0,61}[0-9A-Za-z])?(?:\.[0-9A-Za-z](?:(?:[0-9A-Za-z]|-){0,61}[0-9A-Za-z])?)*\.?$/,
      "host-name": /^(?=.{1,255}$)[0-9A-Za-z](?:(?:[0-9A-Za-z]|-){0,61}[0-9A-Za-z])?(?:\.[0-9A-Za-z](?:(?:[0-9A-Za-z]|-){0,61}[0-9A-Za-z])?)*\.?$/,
      "utc-millisec": /* @__PURE__ */ __name(function(input) {
        return typeof input === "string" && parseFloat(input) === parseInt(input, 10) && !isNaN(input);
      }, "utc-millisec"),
      // 7.3.8. regex
      "regex": /* @__PURE__ */ __name(function(input) {
        var result2 = true;
        try {
          new RegExp(input);
        } catch (e32) {
          result2 = false;
        }
        return result2;
      }, "regex"),
      // Other definitions
      // "style" was removed from JSON Schema in draft-4 and is deprecated
      "style": /[\r\n\t ]*[^\r\n\t ][^:]*:[\r\n\t ]*[^\r\n\t ;]*[\r\n\t ]*;?/,
      // "color" was removed from JSON Schema in draft-4 and is deprecated
      "color": /^(#?([0-9A-Fa-f]{3}){1,2}\b|aqua|black|blue|fuchsia|gray|green|lime|maroon|navy|olive|orange|purple|red|silver|teal|white|yellow|(rgb\(\s*\b([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\b\s*,\s*\b([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\b\s*,\s*\b([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\b\s*\))|(rgb\(\s*(\d?\d%|100%)+\s*,\s*(\d?\d%|100%)+\s*,\s*(\d?\d%|100%)+\s*\)))$/,
      "phone": /^\+(?:[0-9] ?){6,14}[0-9]$/,
      "alpha": /^[a-zA-Z]+$/,
      "alphanumeric": /^[a-zA-Z0-9]+$/
    };
    FORMAT_REGEXPS.regexp = FORMAT_REGEXPS.regex;
    FORMAT_REGEXPS.pattern = FORMAT_REGEXPS.regex;
    FORMAT_REGEXPS.ipv4 = FORMAT_REGEXPS["ip-address"];
    exports2.isFormat = /* @__PURE__ */ __name(function isFormat(input, format32, validator) {
      if (typeof input === "string" && FORMAT_REGEXPS[format32] !== void 0) {
        if (FORMAT_REGEXPS[format32] instanceof RegExp) {
          return FORMAT_REGEXPS[format32].test(input);
        }
        if (typeof FORMAT_REGEXPS[format32] === "function") {
          return FORMAT_REGEXPS[format32](input);
        }
      } else if (validator && validator.customFormats && typeof validator.customFormats[format32] === "function") {
        return validator.customFormats[format32](input);
      }
      return true;
    }, "isFormat");
    var makeSuffix = exports2.makeSuffix = /* @__PURE__ */ __name(function makeSuffix2(key) {
      key = key.toString();
      if (!key.match(/[.\s\[\]]/) && !key.match(/^[\d]/)) {
        return "." + key;
      }
      if (key.match(/^\d+$/)) {
        return "[" + key + "]";
      }
      return "[" + JSON.stringify(key) + "]";
    }, "makeSuffix");
    exports2.deepCompareStrict = /* @__PURE__ */ __name(function deepCompareStrict(a32, b32) {
      if (typeof a32 !== typeof b32) {
        return false;
      }
      if (Array.isArray(a32)) {
        if (!Array.isArray(b32)) {
          return false;
        }
        if (a32.length !== b32.length) {
          return false;
        }
        return a32.every(function(v, i32) {
          return deepCompareStrict(a32[i32], b32[i32]);
        });
      }
      if (typeof a32 === "object") {
        if (!a32 || !b32) {
          return a32 === b32;
        }
        var aKeys = Object.keys(a32);
        var bKeys = Object.keys(b32);
        if (aKeys.length !== bKeys.length) {
          return false;
        }
        return aKeys.every(function(v) {
          return deepCompareStrict(a32[v], b32[v]);
        });
      }
      return a32 === b32;
    }, "deepCompareStrict");
    function deepMerger(target, dst, e32, i32) {
      if (typeof e32 === "object") {
        dst[i32] = deepMerge2(target[i32], e32);
      } else {
        if (target.indexOf(e32) === -1) {
          dst.push(e32);
        }
      }
    }
    __name(deepMerger, "deepMerger");
    function copyist(src, dst, key) {
      dst[key] = src[key];
    }
    __name(copyist, "copyist");
    function copyistWithDeepMerge(target, src, dst, key) {
      if (typeof src[key] !== "object" || !src[key]) {
        dst[key] = src[key];
      } else {
        if (!target[key]) {
          dst[key] = src[key];
        } else {
          dst[key] = deepMerge2(target[key], src[key]);
        }
      }
    }
    __name(copyistWithDeepMerge, "copyistWithDeepMerge");
    function deepMerge2(target, src) {
      var array = Array.isArray(src);
      var dst = array && [] || {};
      if (array) {
        target = target || [];
        dst = dst.concat(target);
        src.forEach(deepMerger.bind(null, target, dst));
      } else {
        if (target && typeof target === "object") {
          Object.keys(target).forEach(copyist.bind(null, target, dst));
        }
        Object.keys(src).forEach(copyistWithDeepMerge.bind(null, target, src, dst));
      }
      return dst;
    }
    __name(deepMerge2, "deepMerge");
    module2.exports.deepMerge = deepMerge2;
    exports2.objectGetPath = /* @__PURE__ */ __name(function objectGetPath(o10, s) {
      var parts = s.split("/").slice(1);
      var k32;
      while (typeof (k32 = parts.shift()) == "string") {
        var n10 = decodeURIComponent(k32.replace(/~0/, "~").replace(/~1/g, "/"));
        if (!(n10 in o10)) return;
        o10 = o10[n10];
      }
      return o10;
    }, "objectGetPath");
    function pathEncoder(v) {
      return "/" + encodeURIComponent(v).replace(/~/g, "%7E");
    }
    __name(pathEncoder, "pathEncoder");
    exports2.encodePath = /* @__PURE__ */ __name(function encodePointer(a32) {
      return a32.map(pathEncoder).join("");
    }, "encodePointer");
    exports2.getDecimalPlaces = /* @__PURE__ */ __name(function getDecimalPlaces(number) {
      var decimalPlaces = 0;
      if (isNaN(number)) return decimalPlaces;
      if (typeof number !== "number") {
        number = Number(number);
      }
      var parts = number.toString().split("e");
      if (parts.length === 2) {
        if (parts[1][0] !== "-") {
          return decimalPlaces;
        } else {
          decimalPlaces = Number(parts[1].slice(1));
        }
      }
      var decimalParts = parts[0].split(".");
      if (decimalParts.length === 2) {
        decimalPlaces += decimalParts[1].length;
      }
      return decimalPlaces;
    }, "getDecimalPlaces");
    exports2.isSchema = /* @__PURE__ */ __name(function isSchema(val) {
      return typeof val === "object" && val || typeof val === "boolean";
    }, "isSchema");
    var resolveUrl = exports2.resolveUrl = /* @__PURE__ */ __name(function resolveUrl2(from, to) {
      const resolvedUrl = new URL(to, new URL(from, "resolve://"));
      if (resolvedUrl.protocol === "resolve:") {
        const { pathname, search, hash } = resolvedUrl;
        return pathname + search + hash;
      }
      return resolvedUrl.toString();
    }, "resolveUrl");
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/jsonschema/lib/attribute.js
var require_attribute = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/jsonschema/lib/attribute.js"(exports2, module2) {
    "use strict";
    var helpers = require_helpers();
    var ValidatorResult = helpers.ValidatorResult;
    var SchemaError = helpers.SchemaError;
    var attribute = {};
    attribute.ignoreProperties = {
      // informative properties
      "id": true,
      "default": true,
      "description": true,
      "title": true,
      // arguments to other properties
      "additionalItems": true,
      "then": true,
      "else": true,
      // special-handled properties
      "$schema": true,
      "$ref": true,
      "extends": true
    };
    var validators = attribute.validators = {};
    validators.type = /* @__PURE__ */ __name(function validateType(instance, schema, options, ctx) {
      if (instance === void 0) {
        return null;
      }
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      var types2 = Array.isArray(schema.type) ? schema.type : [schema.type];
      if (!types2.some(this.testType.bind(this, instance, schema, options, ctx))) {
        var list3 = types2.map(function(v) {
          if (!v) return;
          var id = v.$id || v.id;
          return id ? "<" + id + ">" : v + "";
        });
        result2.addError({
          name: "type",
          argument: list3,
          message: "is not of a type(s) " + list3
        });
      }
      return result2;
    }, "validateType");
    function testSchemaNoThrow(instance, options, ctx, callback, schema) {
      var throwError = options.throwError;
      var throwAll = options.throwAll;
      options.throwError = false;
      options.throwAll = false;
      var res = this.validateSchema(instance, schema, options, ctx);
      options.throwError = throwError;
      options.throwAll = throwAll;
      if (!res.valid && callback instanceof Function) {
        callback(res);
      }
      return res.valid;
    }
    __name(testSchemaNoThrow, "testSchemaNoThrow");
    validators.anyOf = /* @__PURE__ */ __name(function validateAnyOf(instance, schema, options, ctx) {
      if (instance === void 0) {
        return null;
      }
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      var inner = new ValidatorResult(instance, schema, options, ctx);
      if (!Array.isArray(schema.anyOf)) {
        throw new SchemaError("anyOf must be an array");
      }
      if (!schema.anyOf.some(
        testSchemaNoThrow.bind(
          this,
          instance,
          options,
          ctx,
          function(res) {
            inner.importErrors(res);
          }
        )
      )) {
        var list3 = schema.anyOf.map(function(v, i32) {
          var id = v.$id || v.id;
          if (id) return "<" + id + ">";
          return v.title && JSON.stringify(v.title) || v["$ref"] && "<" + v["$ref"] + ">" || "[subschema " + i32 + "]";
        });
        if (options.nestedErrors) {
          result2.importErrors(inner);
        }
        result2.addError({
          name: "anyOf",
          argument: list3,
          message: "is not any of " + list3.join(",")
        });
      }
      return result2;
    }, "validateAnyOf");
    validators.allOf = /* @__PURE__ */ __name(function validateAllOf(instance, schema, options, ctx) {
      if (instance === void 0) {
        return null;
      }
      if (!Array.isArray(schema.allOf)) {
        throw new SchemaError("allOf must be an array");
      }
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      var self2 = this;
      schema.allOf.forEach(function(v, i32) {
        var valid3 = self2.validateSchema(instance, v, options, ctx);
        if (!valid3.valid) {
          var id = v.$id || v.id;
          var msg = id || v.title && JSON.stringify(v.title) || v["$ref"] && "<" + v["$ref"] + ">" || "[subschema " + i32 + "]";
          result2.addError({
            name: "allOf",
            argument: { id: msg, length: valid3.errors.length, valid: valid3 },
            message: "does not match allOf schema " + msg + " with " + valid3.errors.length + " error[s]:"
          });
          result2.importErrors(valid3);
        }
      });
      return result2;
    }, "validateAllOf");
    validators.oneOf = /* @__PURE__ */ __name(function validateOneOf(instance, schema, options, ctx) {
      if (instance === void 0) {
        return null;
      }
      if (!Array.isArray(schema.oneOf)) {
        throw new SchemaError("oneOf must be an array");
      }
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      var inner = new ValidatorResult(instance, schema, options, ctx);
      var count = schema.oneOf.filter(
        testSchemaNoThrow.bind(
          this,
          instance,
          options,
          ctx,
          function(res) {
            inner.importErrors(res);
          }
        )
      ).length;
      var list3 = schema.oneOf.map(function(v, i32) {
        var id = v.$id || v.id;
        return id || v.title && JSON.stringify(v.title) || v["$ref"] && "<" + v["$ref"] + ">" || "[subschema " + i32 + "]";
      });
      if (count !== 1) {
        if (options.nestedErrors) {
          result2.importErrors(inner);
        }
        result2.addError({
          name: "oneOf",
          argument: list3,
          message: "is not exactly one from " + list3.join(",")
        });
      }
      return result2;
    }, "validateOneOf");
    validators.if = /* @__PURE__ */ __name(function validateIf(instance, schema, options, ctx) {
      if (instance === void 0) return null;
      if (!helpers.isSchema(schema.if)) throw new Error('Expected "if" keyword to be a schema');
      var ifValid = testSchemaNoThrow.call(this, instance, options, ctx, null, schema.if);
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      var res;
      if (ifValid) {
        if (schema.then === void 0) return;
        if (!helpers.isSchema(schema.then)) throw new Error('Expected "then" keyword to be a schema');
        res = this.validateSchema(instance, schema.then, options, ctx.makeChild(schema.then));
        result2.importErrors(res);
      } else {
        if (schema.else === void 0) return;
        if (!helpers.isSchema(schema.else)) throw new Error('Expected "else" keyword to be a schema');
        res = this.validateSchema(instance, schema.else, options, ctx.makeChild(schema.else));
        result2.importErrors(res);
      }
      return result2;
    }, "validateIf");
    function getEnumerableProperty(object, key) {
      if (Object.hasOwnProperty.call(object, key)) return object[key];
      if (!(key in object)) return;
      while (object = Object.getPrototypeOf(object)) {
        if (Object.propertyIsEnumerable.call(object, key)) return object[key];
      }
    }
    __name(getEnumerableProperty, "getEnumerableProperty");
    validators.propertyNames = /* @__PURE__ */ __name(function validatePropertyNames(instance, schema, options, ctx) {
      if (!this.types.object(instance)) return;
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      var subschema = schema.propertyNames !== void 0 ? schema.propertyNames : {};
      if (!helpers.isSchema(subschema)) throw new SchemaError('Expected "propertyNames" to be a schema (object or boolean)');
      for (var property in instance) {
        if (getEnumerableProperty(instance, property) !== void 0) {
          var res = this.validateSchema(property, subschema, options, ctx.makeChild(subschema));
          result2.importErrors(res);
        }
      }
      return result2;
    }, "validatePropertyNames");
    validators.properties = /* @__PURE__ */ __name(function validateProperties(instance, schema, options, ctx) {
      if (!this.types.object(instance)) return;
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      var properties = schema.properties || {};
      for (var property in properties) {
        var subschema = properties[property];
        if (subschema === void 0) {
          continue;
        } else if (subschema === null) {
          throw new SchemaError('Unexpected null, expected schema in "properties"');
        }
        if (typeof options.preValidateProperty == "function") {
          options.preValidateProperty(instance, property, subschema, options, ctx);
        }
        var prop = getEnumerableProperty(instance, property);
        var res = this.validateSchema(prop, subschema, options, ctx.makeChild(subschema, property));
        if (res.instance !== result2.instance[property]) result2.instance[property] = res.instance;
        result2.importErrors(res);
      }
      return result2;
    }, "validateProperties");
    function testAdditionalProperty(instance, schema, options, ctx, property, result2) {
      if (!this.types.object(instance)) return;
      if (schema.properties && schema.properties[property] !== void 0) {
        return;
      }
      if (schema.additionalProperties === false) {
        result2.addError({
          name: "additionalProperties",
          argument: property,
          message: "is not allowed to have the additional property " + JSON.stringify(property)
        });
      } else {
        var additionalProperties = schema.additionalProperties || {};
        if (typeof options.preValidateProperty == "function") {
          options.preValidateProperty(instance, property, additionalProperties, options, ctx);
        }
        var res = this.validateSchema(instance[property], additionalProperties, options, ctx.makeChild(additionalProperties, property));
        if (res.instance !== result2.instance[property]) result2.instance[property] = res.instance;
        result2.importErrors(res);
      }
    }
    __name(testAdditionalProperty, "testAdditionalProperty");
    validators.patternProperties = /* @__PURE__ */ __name(function validatePatternProperties(instance, schema, options, ctx) {
      if (!this.types.object(instance)) return;
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      var patternProperties = schema.patternProperties || {};
      for (var property in instance) {
        var test = true;
        for (var pattern in patternProperties) {
          var subschema = patternProperties[pattern];
          if (subschema === void 0) {
            continue;
          } else if (subschema === null) {
            throw new SchemaError('Unexpected null, expected schema in "patternProperties"');
          }
          try {
            var regexp = new RegExp(pattern, "u");
          } catch (_e32) {
            regexp = new RegExp(pattern);
          }
          if (!regexp.test(property)) {
            continue;
          }
          test = false;
          if (typeof options.preValidateProperty == "function") {
            options.preValidateProperty(instance, property, subschema, options, ctx);
          }
          var res = this.validateSchema(instance[property], subschema, options, ctx.makeChild(subschema, property));
          if (res.instance !== result2.instance[property]) result2.instance[property] = res.instance;
          result2.importErrors(res);
        }
        if (test) {
          testAdditionalProperty.call(this, instance, schema, options, ctx, property, result2);
        }
      }
      return result2;
    }, "validatePatternProperties");
    validators.additionalProperties = /* @__PURE__ */ __name(function validateAdditionalProperties(instance, schema, options, ctx) {
      if (!this.types.object(instance)) return;
      if (schema.patternProperties) {
        return null;
      }
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      for (var property in instance) {
        testAdditionalProperty.call(this, instance, schema, options, ctx, property, result2);
      }
      return result2;
    }, "validateAdditionalProperties");
    validators.minProperties = /* @__PURE__ */ __name(function validateMinProperties(instance, schema, options, ctx) {
      if (!this.types.object(instance)) return;
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      var keys = Object.keys(instance);
      if (!(keys.length >= schema.minProperties)) {
        result2.addError({
          name: "minProperties",
          argument: schema.minProperties,
          message: "does not meet minimum property length of " + schema.minProperties
        });
      }
      return result2;
    }, "validateMinProperties");
    validators.maxProperties = /* @__PURE__ */ __name(function validateMaxProperties(instance, schema, options, ctx) {
      if (!this.types.object(instance)) return;
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      var keys = Object.keys(instance);
      if (!(keys.length <= schema.maxProperties)) {
        result2.addError({
          name: "maxProperties",
          argument: schema.maxProperties,
          message: "does not meet maximum property length of " + schema.maxProperties
        });
      }
      return result2;
    }, "validateMaxProperties");
    validators.items = /* @__PURE__ */ __name(function validateItems(instance, schema, options, ctx) {
      var self2 = this;
      if (!this.types.array(instance)) return;
      if (schema.items === void 0) return;
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      instance.every(function(value, i32) {
        if (Array.isArray(schema.items)) {
          var items = schema.items[i32] === void 0 ? schema.additionalItems : schema.items[i32];
        } else {
          var items = schema.items;
        }
        if (items === void 0) {
          return true;
        }
        if (items === false) {
          result2.addError({
            name: "items",
            message: "additionalItems not permitted"
          });
          return false;
        }
        var res = self2.validateSchema(value, items, options, ctx.makeChild(items, i32));
        if (res.instance !== result2.instance[i32]) result2.instance[i32] = res.instance;
        result2.importErrors(res);
        return true;
      });
      return result2;
    }, "validateItems");
    validators.contains = /* @__PURE__ */ __name(function validateContains(instance, schema, options, ctx) {
      var self2 = this;
      if (!this.types.array(instance)) return;
      if (schema.contains === void 0) return;
      if (!helpers.isSchema(schema.contains)) throw new Error('Expected "contains" keyword to be a schema');
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      var count = instance.some(function(value, i32) {
        var res = self2.validateSchema(value, schema.contains, options, ctx.makeChild(schema.contains, i32));
        return res.errors.length === 0;
      });
      if (count === false) {
        result2.addError({
          name: "contains",
          argument: schema.contains,
          message: "must contain an item matching given schema"
        });
      }
      return result2;
    }, "validateContains");
    validators.minimum = /* @__PURE__ */ __name(function validateMinimum(instance, schema, options, ctx) {
      if (!this.types.number(instance)) return;
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      if (schema.exclusiveMinimum && schema.exclusiveMinimum === true) {
        if (!(instance > schema.minimum)) {
          result2.addError({
            name: "minimum",
            argument: schema.minimum,
            message: "must be greater than " + schema.minimum
          });
        }
      } else {
        if (!(instance >= schema.minimum)) {
          result2.addError({
            name: "minimum",
            argument: schema.minimum,
            message: "must be greater than or equal to " + schema.minimum
          });
        }
      }
      return result2;
    }, "validateMinimum");
    validators.maximum = /* @__PURE__ */ __name(function validateMaximum(instance, schema, options, ctx) {
      if (!this.types.number(instance)) return;
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      if (schema.exclusiveMaximum && schema.exclusiveMaximum === true) {
        if (!(instance < schema.maximum)) {
          result2.addError({
            name: "maximum",
            argument: schema.maximum,
            message: "must be less than " + schema.maximum
          });
        }
      } else {
        if (!(instance <= schema.maximum)) {
          result2.addError({
            name: "maximum",
            argument: schema.maximum,
            message: "must be less than or equal to " + schema.maximum
          });
        }
      }
      return result2;
    }, "validateMaximum");
    validators.exclusiveMinimum = /* @__PURE__ */ __name(function validateExclusiveMinimum(instance, schema, options, ctx) {
      if (typeof schema.exclusiveMinimum === "boolean") return;
      if (!this.types.number(instance)) return;
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      var valid3 = instance > schema.exclusiveMinimum;
      if (!valid3) {
        result2.addError({
          name: "exclusiveMinimum",
          argument: schema.exclusiveMinimum,
          message: "must be strictly greater than " + schema.exclusiveMinimum
        });
      }
      return result2;
    }, "validateExclusiveMinimum");
    validators.exclusiveMaximum = /* @__PURE__ */ __name(function validateExclusiveMaximum(instance, schema, options, ctx) {
      if (typeof schema.exclusiveMaximum === "boolean") return;
      if (!this.types.number(instance)) return;
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      var valid3 = instance < schema.exclusiveMaximum;
      if (!valid3) {
        result2.addError({
          name: "exclusiveMaximum",
          argument: schema.exclusiveMaximum,
          message: "must be strictly less than " + schema.exclusiveMaximum
        });
      }
      return result2;
    }, "validateExclusiveMaximum");
    var validateMultipleOfOrDivisbleBy = /* @__PURE__ */ __name(function validateMultipleOfOrDivisbleBy2(instance, schema, options, ctx, validationType, errorMessage) {
      if (!this.types.number(instance)) return;
      var validationArgument = schema[validationType];
      if (validationArgument == 0) {
        throw new SchemaError(validationType + " cannot be zero");
      }
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      var instanceDecimals = helpers.getDecimalPlaces(instance);
      var divisorDecimals = helpers.getDecimalPlaces(validationArgument);
      var maxDecimals = Math.max(instanceDecimals, divisorDecimals);
      var multiplier = Math.pow(10, maxDecimals);
      if (Math.round(instance * multiplier) % Math.round(validationArgument * multiplier) !== 0) {
        result2.addError({
          name: validationType,
          argument: validationArgument,
          message: errorMessage + JSON.stringify(validationArgument)
        });
      }
      return result2;
    }, "validateMultipleOfOrDivisbleBy");
    validators.multipleOf = /* @__PURE__ */ __name(function validateMultipleOf(instance, schema, options, ctx) {
      return validateMultipleOfOrDivisbleBy.call(this, instance, schema, options, ctx, "multipleOf", "is not a multiple of (divisible by) ");
    }, "validateMultipleOf");
    validators.divisibleBy = /* @__PURE__ */ __name(function validateDivisibleBy(instance, schema, options, ctx) {
      return validateMultipleOfOrDivisbleBy.call(this, instance, schema, options, ctx, "divisibleBy", "is not divisible by (multiple of) ");
    }, "validateDivisibleBy");
    validators.required = /* @__PURE__ */ __name(function validateRequired(instance, schema, options, ctx) {
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      if (instance === void 0 && schema.required === true) {
        result2.addError({
          name: "required",
          message: "is required"
        });
      } else if (this.types.object(instance) && Array.isArray(schema.required)) {
        schema.required.forEach(function(n10) {
          if (getEnumerableProperty(instance, n10) === void 0) {
            result2.addError({
              name: "required",
              argument: n10,
              message: "requires property " + JSON.stringify(n10)
            });
          }
        });
      }
      return result2;
    }, "validateRequired");
    validators.pattern = /* @__PURE__ */ __name(function validatePattern(instance, schema, options, ctx) {
      if (!this.types.string(instance)) return;
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      var pattern = schema.pattern;
      try {
        var regexp = new RegExp(pattern, "u");
      } catch (_e32) {
        regexp = new RegExp(pattern);
      }
      if (!instance.match(regexp)) {
        result2.addError({
          name: "pattern",
          argument: schema.pattern,
          message: "does not match pattern " + JSON.stringify(schema.pattern.toString())
        });
      }
      return result2;
    }, "validatePattern");
    validators.format = /* @__PURE__ */ __name(function validateFormat(instance, schema, options, ctx) {
      if (instance === void 0) return;
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      if (!result2.disableFormat && !helpers.isFormat(instance, schema.format, this)) {
        result2.addError({
          name: "format",
          argument: schema.format,
          message: "does not conform to the " + JSON.stringify(schema.format) + " format"
        });
      }
      return result2;
    }, "validateFormat");
    validators.minLength = /* @__PURE__ */ __name(function validateMinLength(instance, schema, options, ctx) {
      if (!this.types.string(instance)) return;
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      var hsp = instance.match(/[\uDC00-\uDFFF]/g);
      var length = instance.length - (hsp ? hsp.length : 0);
      if (!(length >= schema.minLength)) {
        result2.addError({
          name: "minLength",
          argument: schema.minLength,
          message: "does not meet minimum length of " + schema.minLength
        });
      }
      return result2;
    }, "validateMinLength");
    validators.maxLength = /* @__PURE__ */ __name(function validateMaxLength(instance, schema, options, ctx) {
      if (!this.types.string(instance)) return;
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      var hsp = instance.match(/[\uDC00-\uDFFF]/g);
      var length = instance.length - (hsp ? hsp.length : 0);
      if (!(length <= schema.maxLength)) {
        result2.addError({
          name: "maxLength",
          argument: schema.maxLength,
          message: "does not meet maximum length of " + schema.maxLength
        });
      }
      return result2;
    }, "validateMaxLength");
    validators.minItems = /* @__PURE__ */ __name(function validateMinItems(instance, schema, options, ctx) {
      if (!this.types.array(instance)) return;
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      if (!(instance.length >= schema.minItems)) {
        result2.addError({
          name: "minItems",
          argument: schema.minItems,
          message: "does not meet minimum length of " + schema.minItems
        });
      }
      return result2;
    }, "validateMinItems");
    validators.maxItems = /* @__PURE__ */ __name(function validateMaxItems(instance, schema, options, ctx) {
      if (!this.types.array(instance)) return;
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      if (!(instance.length <= schema.maxItems)) {
        result2.addError({
          name: "maxItems",
          argument: schema.maxItems,
          message: "does not meet maximum length of " + schema.maxItems
        });
      }
      return result2;
    }, "validateMaxItems");
    function testArrays(v, i32, a32) {
      var j32, len = a32.length;
      for (j32 = i32 + 1, len; j32 < len; j32++) {
        if (helpers.deepCompareStrict(v, a32[j32])) {
          return false;
        }
      }
      return true;
    }
    __name(testArrays, "testArrays");
    validators.uniqueItems = /* @__PURE__ */ __name(function validateUniqueItems(instance, schema, options, ctx) {
      if (schema.uniqueItems !== true) return;
      if (!this.types.array(instance)) return;
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      if (!instance.every(testArrays)) {
        result2.addError({
          name: "uniqueItems",
          message: "contains duplicate item"
        });
      }
      return result2;
    }, "validateUniqueItems");
    validators.dependencies = /* @__PURE__ */ __name(function validateDependencies(instance, schema, options, ctx) {
      if (!this.types.object(instance)) return;
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      for (var property in schema.dependencies) {
        if (instance[property] === void 0) {
          continue;
        }
        var dep = schema.dependencies[property];
        var childContext = ctx.makeChild(dep, property);
        if (typeof dep == "string") {
          dep = [dep];
        }
        if (Array.isArray(dep)) {
          dep.forEach(function(prop) {
            if (instance[prop] === void 0) {
              result2.addError({
                // FIXME there's two different "dependencies" errors here with slightly different outputs
                // Can we make these the same? Or should we create different error types?
                name: "dependencies",
                argument: childContext.propertyPath,
                message: "property " + prop + " not found, required by " + childContext.propertyPath
              });
            }
          });
        } else {
          var res = this.validateSchema(instance, dep, options, childContext);
          if (result2.instance !== res.instance) result2.instance = res.instance;
          if (res && res.errors.length) {
            result2.addError({
              name: "dependencies",
              argument: childContext.propertyPath,
              message: "does not meet dependency required by " + childContext.propertyPath
            });
            result2.importErrors(res);
          }
        }
      }
      return result2;
    }, "validateDependencies");
    validators["enum"] = /* @__PURE__ */ __name(function validateEnum(instance, schema, options, ctx) {
      if (instance === void 0) {
        return null;
      }
      if (!Array.isArray(schema["enum"])) {
        throw new SchemaError("enum expects an array", schema);
      }
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      if (!schema["enum"].some(helpers.deepCompareStrict.bind(null, instance))) {
        result2.addError({
          name: "enum",
          argument: schema["enum"],
          message: "is not one of enum values: " + schema["enum"].map(String).join(",")
        });
      }
      return result2;
    }, "validateEnum");
    validators["const"] = /* @__PURE__ */ __name(function validateEnum(instance, schema, options, ctx) {
      if (instance === void 0) {
        return null;
      }
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      if (!helpers.deepCompareStrict(schema["const"], instance)) {
        result2.addError({
          name: "const",
          argument: schema["const"],
          message: "does not exactly match expected constant: " + schema["const"]
        });
      }
      return result2;
    }, "validateEnum");
    validators.not = validators.disallow = /* @__PURE__ */ __name(function validateNot(instance, schema, options, ctx) {
      var self2 = this;
      if (instance === void 0) return null;
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      var notTypes = schema.not || schema.disallow;
      if (!notTypes) return null;
      if (!Array.isArray(notTypes)) notTypes = [notTypes];
      notTypes.forEach(function(type) {
        if (self2.testType(instance, schema, options, ctx, type)) {
          var id = type && (type.$id || type.id);
          var schemaId = id || type;
          result2.addError({
            name: "not",
            argument: schemaId,
            message: "is of prohibited type " + schemaId
          });
        }
      });
      return result2;
    }, "validateNot");
    module2.exports = attribute;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/jsonschema/lib/scan.js
var require_scan = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/jsonschema/lib/scan.js"(exports2, module2) {
    "use strict";
    var helpers = require_helpers();
    module2.exports.SchemaScanResult = SchemaScanResult;
    function SchemaScanResult(found, ref) {
      this.id = found;
      this.ref = ref;
    }
    __name(SchemaScanResult, "SchemaScanResult");
    module2.exports.scan = /* @__PURE__ */ __name(function scan(base, schema) {
      function scanSchema(baseuri, schema2) {
        if (!schema2 || typeof schema2 != "object") return;
        if (schema2.$ref) {
          let resolvedUri = helpers.resolveUrl(baseuri, schema2.$ref);
          ref[resolvedUri] = ref[resolvedUri] ? ref[resolvedUri] + 1 : 0;
          return;
        }
        var id = schema2.$id || schema2.id;
        let resolvedBase = helpers.resolveUrl(baseuri, id);
        var ourBase = id ? resolvedBase : baseuri;
        if (ourBase) {
          if (ourBase.indexOf("#") < 0) ourBase += "#";
          if (found[ourBase]) {
            if (!helpers.deepCompareStrict(found[ourBase], schema2)) {
              throw new Error("Schema <" + ourBase + "> already exists with different definition");
            }
            return found[ourBase];
          }
          found[ourBase] = schema2;
          if (ourBase[ourBase.length - 1] == "#") {
            found[ourBase.substring(0, ourBase.length - 1)] = schema2;
          }
        }
        scanArray(ourBase + "/items", Array.isArray(schema2.items) ? schema2.items : [schema2.items]);
        scanArray(ourBase + "/extends", Array.isArray(schema2.extends) ? schema2.extends : [schema2.extends]);
        scanSchema(ourBase + "/additionalItems", schema2.additionalItems);
        scanObject(ourBase + "/properties", schema2.properties);
        scanSchema(ourBase + "/additionalProperties", schema2.additionalProperties);
        scanObject(ourBase + "/definitions", schema2.definitions);
        scanObject(ourBase + "/patternProperties", schema2.patternProperties);
        scanObject(ourBase + "/dependencies", schema2.dependencies);
        scanArray(ourBase + "/disallow", schema2.disallow);
        scanArray(ourBase + "/allOf", schema2.allOf);
        scanArray(ourBase + "/anyOf", schema2.anyOf);
        scanArray(ourBase + "/oneOf", schema2.oneOf);
        scanSchema(ourBase + "/not", schema2.not);
      }
      __name(scanSchema, "scanSchema");
      function scanArray(baseuri, schemas) {
        if (!Array.isArray(schemas)) return;
        for (var i32 = 0; i32 < schemas.length; i32++) {
          scanSchema(baseuri + "/" + i32, schemas[i32]);
        }
      }
      __name(scanArray, "scanArray");
      function scanObject(baseuri, schemas) {
        if (!schemas || typeof schemas != "object") return;
        for (var p10 in schemas) {
          scanSchema(baseuri + "/" + p10, schemas[p10]);
        }
      }
      __name(scanObject, "scanObject");
      var found = {};
      var ref = {};
      scanSchema(base, schema);
      return new SchemaScanResult(found, ref);
    }, "scan");
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/jsonschema/lib/validator.js
var require_validator = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/jsonschema/lib/validator.js"(exports2, module2) {
    "use strict";
    var attribute = require_attribute();
    var helpers = require_helpers();
    var scanSchema = require_scan().scan;
    var ValidatorResult = helpers.ValidatorResult;
    var ValidatorResultError = helpers.ValidatorResultError;
    var SchemaError = helpers.SchemaError;
    var SchemaContext = helpers.SchemaContext;
    var anonymousBase = "/";
    var Validator2 = /* @__PURE__ */ __name(function Validator3() {
      this.customFormats = Object.create(Validator3.prototype.customFormats);
      this.schemas = {};
      this.unresolvedRefs = [];
      this.types = Object.create(types2);
      this.attributes = Object.create(attribute.validators);
    }, "Validator");
    Validator2.prototype.customFormats = {};
    Validator2.prototype.schemas = null;
    Validator2.prototype.types = null;
    Validator2.prototype.attributes = null;
    Validator2.prototype.unresolvedRefs = null;
    Validator2.prototype.addSchema = /* @__PURE__ */ __name(function addSchema(schema, base) {
      var self2 = this;
      if (!schema) {
        return null;
      }
      var scan = scanSchema(base || anonymousBase, schema);
      var ourUri = base || schema.$id || schema.id;
      for (var uri in scan.id) {
        this.schemas[uri] = scan.id[uri];
      }
      for (var uri in scan.ref) {
        this.unresolvedRefs.push(uri);
      }
      this.unresolvedRefs = this.unresolvedRefs.filter(function(uri2) {
        return typeof self2.schemas[uri2] === "undefined";
      });
      return this.schemas[ourUri];
    }, "addSchema");
    Validator2.prototype.addSubSchemaArray = /* @__PURE__ */ __name(function addSubSchemaArray(baseuri, schemas) {
      if (!Array.isArray(schemas)) return;
      for (var i32 = 0; i32 < schemas.length; i32++) {
        this.addSubSchema(baseuri, schemas[i32]);
      }
    }, "addSubSchemaArray");
    Validator2.prototype.addSubSchemaObject = /* @__PURE__ */ __name(function addSubSchemaArray(baseuri, schemas) {
      if (!schemas || typeof schemas != "object") return;
      for (var p10 in schemas) {
        this.addSubSchema(baseuri, schemas[p10]);
      }
    }, "addSubSchemaArray");
    Validator2.prototype.setSchemas = /* @__PURE__ */ __name(function setSchemas(schemas) {
      this.schemas = schemas;
    }, "setSchemas");
    Validator2.prototype.getSchema = /* @__PURE__ */ __name(function getSchema(urn) {
      return this.schemas[urn];
    }, "getSchema");
    Validator2.prototype.validate = /* @__PURE__ */ __name(function validate(instance, schema, options, ctx) {
      if (typeof schema !== "boolean" && typeof schema !== "object" || schema === null) {
        throw new SchemaError("Expected `schema` to be an object or boolean");
      }
      if (!options) {
        options = {};
      }
      var id = schema.$id || schema.id;
      let base = helpers.resolveUrl(options.base, id || "");
      if (!ctx) {
        ctx = new SchemaContext(schema, options, [], base, Object.create(this.schemas));
        if (!ctx.schemas[base]) {
          ctx.schemas[base] = schema;
        }
        var found = scanSchema(base, schema);
        for (var n10 in found.id) {
          var sch = found.id[n10];
          ctx.schemas[n10] = sch;
        }
      }
      if (options.required && instance === void 0) {
        var result2 = new ValidatorResult(instance, schema, options, ctx);
        result2.addError("is required, but is undefined");
        return result2;
      }
      var result2 = this.validateSchema(instance, schema, options, ctx);
      if (!result2) {
        throw new Error("Result undefined");
      } else if (options.throwAll && result2.errors.length) {
        throw new ValidatorResultError(result2);
      }
      return result2;
    }, "validate");
    function shouldResolve(schema) {
      var ref = typeof schema === "string" ? schema : schema.$ref;
      if (typeof ref == "string") return ref;
      return false;
    }
    __name(shouldResolve, "shouldResolve");
    Validator2.prototype.validateSchema = /* @__PURE__ */ __name(function validateSchema(instance, schema, options, ctx) {
      var result2 = new ValidatorResult(instance, schema, options, ctx);
      if (typeof schema === "boolean") {
        if (schema === true) {
          schema = {};
        } else if (schema === false) {
          schema = { type: [] };
        }
      } else if (!schema) {
        throw new Error("schema is undefined");
      }
      if (schema["extends"]) {
        if (Array.isArray(schema["extends"])) {
          var schemaobj = { schema, ctx };
          schema["extends"].forEach(this.schemaTraverser.bind(this, schemaobj));
          schema = schemaobj.schema;
          schemaobj.schema = null;
          schemaobj.ctx = null;
          schemaobj = null;
        } else {
          schema = helpers.deepMerge(schema, this.superResolve(schema["extends"], ctx));
        }
      }
      var switchSchema = shouldResolve(schema);
      if (switchSchema) {
        var resolved = this.resolve(schema, switchSchema, ctx);
        var subctx = new SchemaContext(resolved.subschema, options, ctx.path, resolved.switchSchema, ctx.schemas);
        return this.validateSchema(instance, resolved.subschema, options, subctx);
      }
      var skipAttributes = options && options.skipAttributes || [];
      for (var key in schema) {
        if (!attribute.ignoreProperties[key] && skipAttributes.indexOf(key) < 0) {
          var validatorErr = null;
          var validator = this.attributes[key];
          if (validator) {
            validatorErr = validator.call(this, instance, schema, options, ctx);
          } else if (options.allowUnknownAttributes === false) {
            throw new SchemaError("Unsupported attribute: " + key, schema);
          }
          if (validatorErr) {
            result2.importErrors(validatorErr);
          }
        }
      }
      if (typeof options.rewrite == "function") {
        var value = options.rewrite.call(this, instance, schema, options, ctx);
        result2.instance = value;
      }
      return result2;
    }, "validateSchema");
    Validator2.prototype.schemaTraverser = /* @__PURE__ */ __name(function schemaTraverser(schemaobj, s) {
      schemaobj.schema = helpers.deepMerge(schemaobj.schema, this.superResolve(s, schemaobj.ctx));
    }, "schemaTraverser");
    Validator2.prototype.superResolve = /* @__PURE__ */ __name(function superResolve(schema, ctx) {
      var ref = shouldResolve(schema);
      if (ref) {
        return this.resolve(schema, ref, ctx).subschema;
      }
      return schema;
    }, "superResolve");
    Validator2.prototype.resolve = /* @__PURE__ */ __name(function resolve13(schema, switchSchema, ctx) {
      switchSchema = ctx.resolve(switchSchema);
      if (ctx.schemas[switchSchema]) {
        return { subschema: ctx.schemas[switchSchema], switchSchema };
      }
      let parsed = new URL(switchSchema, "thismessage::/");
      let fragment = parsed.hash;
      var document2 = fragment && fragment.length && switchSchema.substr(0, switchSchema.length - fragment.length);
      if (!document2 || !ctx.schemas[document2]) {
        throw new SchemaError("no such schema <" + switchSchema + ">", schema);
      }
      var subschema = helpers.objectGetPath(ctx.schemas[document2], fragment.substr(1));
      if (subschema === void 0) {
        throw new SchemaError("no such schema " + fragment + " located in <" + document2 + ">", schema);
      }
      return { subschema, switchSchema };
    }, "resolve");
    Validator2.prototype.testType = /* @__PURE__ */ __name(function validateType(instance, schema, options, ctx, type) {
      if (type === void 0) {
        return;
      } else if (type === null) {
        throw new SchemaError('Unexpected null in "type" keyword');
      }
      if (typeof this.types[type] == "function") {
        return this.types[type].call(this, instance);
      }
      if (type && typeof type == "object") {
        var res = this.validateSchema(instance, type, options, ctx);
        return res === void 0 || !(res && res.errors.length);
      }
      return true;
    }, "validateType");
    var types2 = Validator2.prototype.types = {};
    types2.string = /* @__PURE__ */ __name(function testString(instance) {
      return typeof instance == "string";
    }, "testString");
    types2.number = /* @__PURE__ */ __name(function testNumber(instance) {
      return typeof instance == "number" && isFinite(instance);
    }, "testNumber");
    types2.integer = /* @__PURE__ */ __name(function testInteger(instance) {
      return typeof instance == "number" && instance % 1 === 0;
    }, "testInteger");
    types2.boolean = /* @__PURE__ */ __name(function testBoolean(instance) {
      return typeof instance == "boolean";
    }, "testBoolean");
    types2.array = /* @__PURE__ */ __name(function testArray(instance) {
      return Array.isArray(instance);
    }, "testArray");
    types2["null"] = /* @__PURE__ */ __name(function testNull(instance) {
      return instance === null;
    }, "testNull");
    types2.date = /* @__PURE__ */ __name(function testDate(instance) {
      return instance instanceof Date;
    }, "testDate");
    types2.any = /* @__PURE__ */ __name(function testAny(instance) {
      return true;
    }, "testAny");
    types2.object = /* @__PURE__ */ __name(function testObject(instance) {
      return instance && typeof instance === "object" && !Array.isArray(instance) && !(instance instanceof Date);
    }, "testObject");
    module2.exports = Validator2;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/jsonschema/lib/index.js
var require_lib = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/jsonschema/lib/index.js"(exports2, module2) {
    "use strict";
    var Validator2 = module2.exports.Validator = require_validator();
    module2.exports.ValidatorResult = require_helpers().ValidatorResult;
    module2.exports.ValidatorResultError = require_helpers().ValidatorResultError;
    module2.exports.ValidationError = require_helpers().ValidationError;
    module2.exports.SchemaError = require_helpers().SchemaError;
    module2.exports.SchemaScanResult = require_scan().SchemaScanResult;
    module2.exports.scan = require_scan().scan;
    module2.exports.validate = function(instance, schema, options) {
      var v = new Validator2();
      return v.validate(instance, schema, options);
    };
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/internal/constants.js
var require_constants = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/internal/constants.js"(exports2, module2) {
    "use strict";
    var SEMVER_SPEC_VERSION = "2.0.0";
    var MAX_LENGTH = 256;
    var MAX_SAFE_INTEGER = Number.MAX_SAFE_INTEGER || /* istanbul ignore next */
    9007199254740991;
    var MAX_SAFE_COMPONENT_LENGTH = 16;
    var MAX_SAFE_BUILD_LENGTH = MAX_LENGTH - 6;
    var RELEASE_TYPES = [
      "major",
      "premajor",
      "minor",
      "preminor",
      "patch",
      "prepatch",
      "prerelease"
    ];
    module2.exports = {
      MAX_LENGTH,
      MAX_SAFE_COMPONENT_LENGTH,
      MAX_SAFE_BUILD_LENGTH,
      MAX_SAFE_INTEGER,
      RELEASE_TYPES,
      SEMVER_SPEC_VERSION,
      FLAG_INCLUDE_PRERELEASE: 1,
      FLAG_LOOSE: 2
    };
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/internal/debug.js
var require_debug = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/internal/debug.js"(exports2, module2) {
    "use strict";
    var debug2 = typeof process === "object" && process.env && process.env.NODE_DEBUG && /\bsemver\b/i.test(process.env.NODE_DEBUG) ? (...args) => console.error("SEMVER", ...args) : () => {
    };
    module2.exports = debug2;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/internal/re.js
var require_re = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/internal/re.js"(exports2, module2) {
    "use strict";
    var {
      MAX_SAFE_COMPONENT_LENGTH,
      MAX_SAFE_BUILD_LENGTH,
      MAX_LENGTH
    } = require_constants();
    var debug2 = require_debug();
    exports2 = module2.exports = {};
    var re = exports2.re = [];
    var safeRe = exports2.safeRe = [];
    var src = exports2.src = [];
    var safeSrc = exports2.safeSrc = [];
    var t = exports2.t = {};
    var R = 0;
    var LETTERDASHNUMBER = "[a-zA-Z0-9-]";
    var safeRegexReplacements = [
      ["\\s", 1],
      ["\\d", MAX_LENGTH],
      [LETTERDASHNUMBER, MAX_SAFE_BUILD_LENGTH]
    ];
    var makeSafeRegex = /* @__PURE__ */ __name((value) => {
      for (const [token, max] of safeRegexReplacements) {
        value = value.split(`${token}*`).join(`${token}{0,${max}}`).split(`${token}+`).join(`${token}{1,${max}}`);
      }
      return value;
    }, "makeSafeRegex");
    var createToken = /* @__PURE__ */ __name((name, value, isGlobal) => {
      const safe = makeSafeRegex(value);
      const index = R++;
      debug2(name, index, value);
      t[name] = index;
      src[index] = value;
      safeSrc[index] = safe;
      re[index] = new RegExp(value, isGlobal ? "g" : void 0);
      safeRe[index] = new RegExp(safe, isGlobal ? "g" : void 0);
    }, "createToken");
    createToken("NUMERICIDENTIFIER", "0|[1-9]\\d*");
    createToken("NUMERICIDENTIFIERLOOSE", "\\d+");
    createToken("NONNUMERICIDENTIFIER", `\\d*[a-zA-Z-]${LETTERDASHNUMBER}*`);
    createToken("MAINVERSION", `(${src[t.NUMERICIDENTIFIER]})\\.(${src[t.NUMERICIDENTIFIER]})\\.(${src[t.NUMERICIDENTIFIER]})`);
    createToken("MAINVERSIONLOOSE", `(${src[t.NUMERICIDENTIFIERLOOSE]})\\.(${src[t.NUMERICIDENTIFIERLOOSE]})\\.(${src[t.NUMERICIDENTIFIERLOOSE]})`);
    createToken("PRERELEASEIDENTIFIER", `(?:${src[t.NONNUMERICIDENTIFIER]}|${src[t.NUMERICIDENTIFIER]})`);
    createToken("PRERELEASEIDENTIFIERLOOSE", `(?:${src[t.NONNUMERICIDENTIFIER]}|${src[t.NUMERICIDENTIFIERLOOSE]})`);
    createToken("PRERELEASE", `(?:-(${src[t.PRERELEASEIDENTIFIER]}(?:\\.${src[t.PRERELEASEIDENTIFIER]})*))`);
    createToken("PRERELEASELOOSE", `(?:-?(${src[t.PRERELEASEIDENTIFIERLOOSE]}(?:\\.${src[t.PRERELEASEIDENTIFIERLOOSE]})*))`);
    createToken("BUILDIDENTIFIER", `${LETTERDASHNUMBER}+`);
    createToken("BUILD", `(?:\\+(${src[t.BUILDIDENTIFIER]}(?:\\.${src[t.BUILDIDENTIFIER]})*))`);
    createToken("FULLPLAIN", `v?${src[t.MAINVERSION]}${src[t.PRERELEASE]}?${src[t.BUILD]}?`);
    createToken("FULL", `^${src[t.FULLPLAIN]}$`);
    createToken("LOOSEPLAIN", `[v=\\s]*${src[t.MAINVERSIONLOOSE]}${src[t.PRERELEASELOOSE]}?${src[t.BUILD]}?`);
    createToken("LOOSE", `^${src[t.LOOSEPLAIN]}$`);
    createToken("GTLT", "((?:<|>)?=?)");
    createToken("XRANGEIDENTIFIERLOOSE", `${src[t.NUMERICIDENTIFIERLOOSE]}|x|X|\\*`);
    createToken("XRANGEIDENTIFIER", `${src[t.NUMERICIDENTIFIER]}|x|X|\\*`);
    createToken("XRANGEPLAIN", `[v=\\s]*(${src[t.XRANGEIDENTIFIER]})(?:\\.(${src[t.XRANGEIDENTIFIER]})(?:\\.(${src[t.XRANGEIDENTIFIER]})(?:${src[t.PRERELEASE]})?${src[t.BUILD]}?)?)?`);
    createToken("XRANGEPLAINLOOSE", `[v=\\s]*(${src[t.XRANGEIDENTIFIERLOOSE]})(?:\\.(${src[t.XRANGEIDENTIFIERLOOSE]})(?:\\.(${src[t.XRANGEIDENTIFIERLOOSE]})(?:${src[t.PRERELEASELOOSE]})?${src[t.BUILD]}?)?)?`);
    createToken("XRANGE", `^${src[t.GTLT]}\\s*${src[t.XRANGEPLAIN]}$`);
    createToken("XRANGELOOSE", `^${src[t.GTLT]}\\s*${src[t.XRANGEPLAINLOOSE]}$`);
    createToken("COERCEPLAIN", `${"(^|[^\\d])(\\d{1,"}${MAX_SAFE_COMPONENT_LENGTH}})(?:\\.(\\d{1,${MAX_SAFE_COMPONENT_LENGTH}}))?(?:\\.(\\d{1,${MAX_SAFE_COMPONENT_LENGTH}}))?`);
    createToken("COERCE", `${src[t.COERCEPLAIN]}(?:$|[^\\d])`);
    createToken("COERCEFULL", src[t.COERCEPLAIN] + `(?:${src[t.PRERELEASE]})?(?:${src[t.BUILD]})?(?:$|[^\\d])`);
    createToken("COERCERTL", src[t.COERCE], true);
    createToken("COERCERTLFULL", src[t.COERCEFULL], true);
    createToken("LONETILDE", "(?:~>?)");
    createToken("TILDETRIM", `(\\s*)${src[t.LONETILDE]}\\s+`, true);
    exports2.tildeTrimReplace = "$1~";
    createToken("TILDE", `^${src[t.LONETILDE]}${src[t.XRANGEPLAIN]}$`);
    createToken("TILDELOOSE", `^${src[t.LONETILDE]}${src[t.XRANGEPLAINLOOSE]}$`);
    createToken("LONECARET", "(?:\\^)");
    createToken("CARETTRIM", `(\\s*)${src[t.LONECARET]}\\s+`, true);
    exports2.caretTrimReplace = "$1^";
    createToken("CARET", `^${src[t.LONECARET]}${src[t.XRANGEPLAIN]}$`);
    createToken("CARETLOOSE", `^${src[t.LONECARET]}${src[t.XRANGEPLAINLOOSE]}$`);
    createToken("COMPARATORLOOSE", `^${src[t.GTLT]}\\s*(${src[t.LOOSEPLAIN]})$|^$`);
    createToken("COMPARATOR", `^${src[t.GTLT]}\\s*(${src[t.FULLPLAIN]})$|^$`);
    createToken("COMPARATORTRIM", `(\\s*)${src[t.GTLT]}\\s*(${src[t.LOOSEPLAIN]}|${src[t.XRANGEPLAIN]})`, true);
    exports2.comparatorTrimReplace = "$1$2$3";
    createToken("HYPHENRANGE", `^\\s*(${src[t.XRANGEPLAIN]})\\s+-\\s+(${src[t.XRANGEPLAIN]})\\s*$`);
    createToken("HYPHENRANGELOOSE", `^\\s*(${src[t.XRANGEPLAINLOOSE]})\\s+-\\s+(${src[t.XRANGEPLAINLOOSE]})\\s*$`);
    createToken("STAR", "(<|>)?=?\\s*\\*");
    createToken("GTE0", "^\\s*>=\\s*0\\.0\\.0\\s*$");
    createToken("GTE0PRE", "^\\s*>=\\s*0\\.0\\.0-0\\s*$");
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/internal/parse-options.js
var require_parse_options = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/internal/parse-options.js"(exports2, module2) {
    "use strict";
    var looseOption = Object.freeze({ loose: true });
    var emptyOpts = Object.freeze({});
    var parseOptions = /* @__PURE__ */ __name((options) => {
      if (!options) {
        return emptyOpts;
      }
      if (typeof options !== "object") {
        return looseOption;
      }
      return options;
    }, "parseOptions");
    module2.exports = parseOptions;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/internal/identifiers.js
var require_identifiers = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/internal/identifiers.js"(exports2, module2) {
    "use strict";
    var numeric = /^[0-9]+$/;
    var compareIdentifiers = /* @__PURE__ */ __name((a32, b32) => {
      if (typeof a32 === "number" && typeof b32 === "number") {
        return a32 === b32 ? 0 : a32 < b32 ? -1 : 1;
      }
      const anum = numeric.test(a32);
      const bnum = numeric.test(b32);
      if (anum && bnum) {
        a32 = +a32;
        b32 = +b32;
      }
      return a32 === b32 ? 0 : anum && !bnum ? -1 : bnum && !anum ? 1 : a32 < b32 ? -1 : 1;
    }, "compareIdentifiers");
    var rcompareIdentifiers = /* @__PURE__ */ __name((a32, b32) => compareIdentifiers(b32, a32), "rcompareIdentifiers");
    module2.exports = {
      compareIdentifiers,
      rcompareIdentifiers
    };
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/classes/semver.js
var require_semver = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/classes/semver.js"(exports2, module2) {
    "use strict";
    var debug2 = require_debug();
    var { MAX_LENGTH, MAX_SAFE_INTEGER } = require_constants();
    var { safeRe: re, t } = require_re();
    var parseOptions = require_parse_options();
    var { compareIdentifiers } = require_identifiers();
    var isPrereleaseIdentifier = /* @__PURE__ */ __name((prerelease, identifier) => {
      const identifiers = identifier.split(".");
      if (identifiers.length > prerelease.length) {
        return false;
      }
      for (let i32 = 0; i32 < identifiers.length; i32++) {
        if (compareIdentifiers(prerelease[i32], identifiers[i32]) !== 0) {
          return false;
        }
      }
      return true;
    }, "isPrereleaseIdentifier");
    var SemVer = class _SemVer {
      static {
        __name(this, "SemVer");
      }
      constructor(version, options) {
        options = parseOptions(options);
        if (version instanceof _SemVer) {
          if (version.loose === !!options.loose && version.includePrerelease === !!options.includePrerelease) {
            return version;
          } else {
            version = version.version;
          }
        } else if (typeof version !== "string") {
          throw new TypeError(`Invalid version. Must be a string. Got type "${typeof version}".`);
        }
        if (version.length > MAX_LENGTH) {
          throw new TypeError(
            `version is longer than ${MAX_LENGTH} characters`
          );
        }
        debug2("SemVer", version, options);
        this.options = options;
        this.loose = !!options.loose;
        this.includePrerelease = !!options.includePrerelease;
        const m20 = version.trim().match(options.loose ? re[t.LOOSE] : re[t.FULL]);
        if (!m20) {
          throw new TypeError(`Invalid Version: ${version}`);
        }
        this.raw = version;
        this.major = +m20[1];
        this.minor = +m20[2];
        this.patch = +m20[3];
        if (this.major > MAX_SAFE_INTEGER || this.major < 0) {
          throw new TypeError("Invalid major version");
        }
        if (this.minor > MAX_SAFE_INTEGER || this.minor < 0) {
          throw new TypeError("Invalid minor version");
        }
        if (this.patch > MAX_SAFE_INTEGER || this.patch < 0) {
          throw new TypeError("Invalid patch version");
        }
        if (!m20[4]) {
          this.prerelease = [];
        } else {
          this.prerelease = m20[4].split(".").map((id) => {
            if (/^[0-9]+$/.test(id)) {
              const num = +id;
              if (num >= 0 && num < MAX_SAFE_INTEGER) {
                return num;
              }
            }
            return id;
          });
        }
        this.build = m20[5] ? m20[5].split(".") : [];
        this.format();
      }
      format() {
        this.version = `${this.major}.${this.minor}.${this.patch}`;
        if (this.prerelease.length) {
          this.version += `-${this.prerelease.join(".")}`;
        }
        return this.version;
      }
      toString() {
        return this.version;
      }
      compare(other) {
        debug2("SemVer.compare", this.version, this.options, other);
        if (!(other instanceof _SemVer)) {
          if (typeof other === "string" && other === this.version) {
            return 0;
          }
          other = new _SemVer(other, this.options);
        }
        if (other.version === this.version) {
          return 0;
        }
        return this.compareMain(other) || this.comparePre(other);
      }
      compareMain(other) {
        if (!(other instanceof _SemVer)) {
          other = new _SemVer(other, this.options);
        }
        if (this.major < other.major) {
          return -1;
        }
        if (this.major > other.major) {
          return 1;
        }
        if (this.minor < other.minor) {
          return -1;
        }
        if (this.minor > other.minor) {
          return 1;
        }
        if (this.patch < other.patch) {
          return -1;
        }
        if (this.patch > other.patch) {
          return 1;
        }
        return 0;
      }
      comparePre(other) {
        if (!(other instanceof _SemVer)) {
          other = new _SemVer(other, this.options);
        }
        if (this.prerelease.length && !other.prerelease.length) {
          return -1;
        } else if (!this.prerelease.length && other.prerelease.length) {
          return 1;
        } else if (!this.prerelease.length && !other.prerelease.length) {
          return 0;
        }
        let i32 = 0;
        do {
          const a32 = this.prerelease[i32];
          const b32 = other.prerelease[i32];
          debug2("prerelease compare", i32, a32, b32);
          if (a32 === void 0 && b32 === void 0) {
            return 0;
          } else if (b32 === void 0) {
            return 1;
          } else if (a32 === void 0) {
            return -1;
          } else if (a32 === b32) {
            continue;
          } else {
            return compareIdentifiers(a32, b32);
          }
        } while (++i32);
      }
      compareBuild(other) {
        if (!(other instanceof _SemVer)) {
          other = new _SemVer(other, this.options);
        }
        let i32 = 0;
        do {
          const a32 = this.build[i32];
          const b32 = other.build[i32];
          debug2("build compare", i32, a32, b32);
          if (a32 === void 0 && b32 === void 0) {
            return 0;
          } else if (b32 === void 0) {
            return 1;
          } else if (a32 === void 0) {
            return -1;
          } else if (a32 === b32) {
            continue;
          } else {
            return compareIdentifiers(a32, b32);
          }
        } while (++i32);
      }
      // preminor will bump the version up to the next minor release, and immediately
      // down to pre-release. premajor and prepatch work the same way.
      inc(release3, identifier, identifierBase) {
        if (release3.startsWith("pre")) {
          if (!identifier && identifierBase === false) {
            throw new Error("invalid increment argument: identifier is empty");
          }
          if (identifier) {
            const match = `-${identifier}`.match(this.options.loose ? re[t.PRERELEASELOOSE] : re[t.PRERELEASE]);
            if (!match || match[1] !== identifier) {
              throw new Error(`invalid identifier: ${identifier}`);
            }
          }
        }
        switch (release3) {
          case "premajor":
            this.prerelease.length = 0;
            this.patch = 0;
            this.minor = 0;
            this.major++;
            this.inc("pre", identifier, identifierBase);
            break;
          case "preminor":
            this.prerelease.length = 0;
            this.patch = 0;
            this.minor++;
            this.inc("pre", identifier, identifierBase);
            break;
          case "prepatch":
            this.prerelease.length = 0;
            this.inc("patch", identifier, identifierBase);
            this.inc("pre", identifier, identifierBase);
            break;
          // If the input is a non-prerelease version, this acts the same as
          // prepatch.
          case "prerelease":
            if (this.prerelease.length === 0) {
              this.inc("patch", identifier, identifierBase);
            }
            this.inc("pre", identifier, identifierBase);
            break;
          case "release":
            if (this.prerelease.length === 0) {
              throw new Error(`version ${this.raw} is not a prerelease`);
            }
            this.prerelease.length = 0;
            break;
          case "major":
            if (this.minor !== 0 || this.patch !== 0 || this.prerelease.length === 0) {
              this.major++;
            }
            this.minor = 0;
            this.patch = 0;
            this.prerelease = [];
            break;
          case "minor":
            if (this.patch !== 0 || this.prerelease.length === 0) {
              this.minor++;
            }
            this.patch = 0;
            this.prerelease = [];
            break;
          case "patch":
            if (this.prerelease.length === 0) {
              this.patch++;
            }
            this.prerelease = [];
            break;
          // This probably shouldn't be used publicly.
          // 1.0.0 'pre' would become 1.0.0-0 which is the wrong direction.
          case "pre": {
            const base = Number(identifierBase) ? 1 : 0;
            if (this.prerelease.length === 0) {
              this.prerelease = [base];
            } else {
              let i32 = this.prerelease.length;
              while (--i32 >= 0) {
                if (typeof this.prerelease[i32] === "number") {
                  this.prerelease[i32]++;
                  i32 = -2;
                }
              }
              if (i32 === -1) {
                if (identifier === this.prerelease.join(".") && identifierBase === false) {
                  throw new Error("invalid increment argument: identifier already exists");
                }
                this.prerelease.push(base);
              }
            }
            if (identifier) {
              let prerelease = [identifier, base];
              if (identifierBase === false) {
                prerelease = [identifier];
              }
              if (isPrereleaseIdentifier(this.prerelease, identifier)) {
                const prereleaseBase = this.prerelease[identifier.split(".").length];
                if (isNaN(prereleaseBase)) {
                  this.prerelease = prerelease;
                }
              } else {
                this.prerelease = prerelease;
              }
            }
            break;
          }
          default:
            throw new Error(`invalid increment argument: ${release3}`);
        }
        this.raw = this.format();
        if (this.build.length) {
          this.raw += `+${this.build.join(".")}`;
        }
        return this;
      }
    };
    module2.exports = SemVer;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/parse.js
var require_parse = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/parse.js"(exports2, module2) {
    "use strict";
    var SemVer = require_semver();
    var parse2 = /* @__PURE__ */ __name((version, options, throwErrors = false) => {
      if (version instanceof SemVer) {
        return version;
      }
      try {
        return new SemVer(version, options);
      } catch (er) {
        if (!throwErrors) {
          return null;
        }
        throw er;
      }
    }, "parse");
    module2.exports = parse2;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/valid.js
var require_valid = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/valid.js"(exports2, module2) {
    "use strict";
    var parse2 = require_parse();
    var valid3 = /* @__PURE__ */ __name((version, options) => {
      const v = parse2(version, options);
      return v ? v.version : null;
    }, "valid");
    module2.exports = valid3;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/clean.js
var require_clean = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/clean.js"(exports2, module2) {
    "use strict";
    var parse2 = require_parse();
    var clean = /* @__PURE__ */ __name((version, options) => {
      const s = parse2(version.trim().replace(/^[=v]+/, ""), options);
      return s ? s.version : null;
    }, "clean");
    module2.exports = clean;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/inc.js
var require_inc = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/inc.js"(exports2, module2) {
    "use strict";
    var SemVer = require_semver();
    var inc = /* @__PURE__ */ __name((version, release3, options, identifier, identifierBase) => {
      if (typeof options === "string") {
        identifierBase = identifier;
        identifier = options;
        options = void 0;
      }
      try {
        return new SemVer(
          version instanceof SemVer ? version.version : version,
          options
        ).inc(release3, identifier, identifierBase).version;
      } catch (er) {
        return null;
      }
    }, "inc");
    module2.exports = inc;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/diff.js
var require_diff = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/diff.js"(exports2, module2) {
    "use strict";
    var parse2 = require_parse();
    var diff = /* @__PURE__ */ __name((version1, version2) => {
      const v1 = parse2(version1, null, true);
      const v2 = parse2(version2, null, true);
      const comparison = v1.compare(v2);
      if (comparison === 0) {
        return null;
      }
      const v1Higher = comparison > 0;
      const highVersion = v1Higher ? v1 : v2;
      const lowVersion = v1Higher ? v2 : v1;
      const highHasPre = !!highVersion.prerelease.length;
      const lowHasPre = !!lowVersion.prerelease.length;
      if (lowHasPre && !highHasPre) {
        if (!lowVersion.patch && !lowVersion.minor) {
          return "major";
        }
        if (lowVersion.compareMain(highVersion) === 0) {
          if (lowVersion.minor && !lowVersion.patch) {
            return "minor";
          }
          return "patch";
        }
      }
      const prefix = highHasPre ? "pre" : "";
      if (v1.major !== v2.major) {
        return prefix + "major";
      }
      if (v1.minor !== v2.minor) {
        return prefix + "minor";
      }
      if (v1.patch !== v2.patch) {
        return prefix + "patch";
      }
      return "prerelease";
    }, "diff");
    module2.exports = diff;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/major.js
var require_major = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/major.js"(exports2, module2) {
    "use strict";
    var SemVer = require_semver();
    var major6 = /* @__PURE__ */ __name((a32, loose) => new SemVer(a32, loose).major, "major");
    module2.exports = major6;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/minor.js
var require_minor = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/minor.js"(exports2, module2) {
    "use strict";
    var SemVer = require_semver();
    var minor = /* @__PURE__ */ __name((a32, loose) => new SemVer(a32, loose).minor, "minor");
    module2.exports = minor;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/patch.js
var require_patch = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/patch.js"(exports2, module2) {
    "use strict";
    var SemVer = require_semver();
    var patch = /* @__PURE__ */ __name((a32, loose) => new SemVer(a32, loose).patch, "patch");
    module2.exports = patch;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/prerelease.js
var require_prerelease = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/prerelease.js"(exports2, module2) {
    "use strict";
    var parse2 = require_parse();
    var prerelease = /* @__PURE__ */ __name((version, options) => {
      const parsed = parse2(version, options);
      return parsed && parsed.prerelease.length ? parsed.prerelease : null;
    }, "prerelease");
    module2.exports = prerelease;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/compare.js
var require_compare = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/compare.js"(exports2, module2) {
    "use strict";
    var SemVer = require_semver();
    var compare2 = /* @__PURE__ */ __name((a32, b32, loose) => new SemVer(a32, loose).compare(new SemVer(b32, loose)), "compare");
    module2.exports = compare2;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/rcompare.js
var require_rcompare = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/rcompare.js"(exports2, module2) {
    "use strict";
    var compare2 = require_compare();
    var rcompare = /* @__PURE__ */ __name((a32, b32, loose) => compare2(b32, a32, loose), "rcompare");
    module2.exports = rcompare;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/compare-loose.js
var require_compare_loose = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/compare-loose.js"(exports2, module2) {
    "use strict";
    var compare2 = require_compare();
    var compareLoose = /* @__PURE__ */ __name((a32, b32) => compare2(a32, b32, true), "compareLoose");
    module2.exports = compareLoose;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/compare-build.js
var require_compare_build = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/compare-build.js"(exports2, module2) {
    "use strict";
    var SemVer = require_semver();
    var compareBuild = /* @__PURE__ */ __name((a32, b32, loose) => {
      const versionA = new SemVer(a32, loose);
      const versionB = new SemVer(b32, loose);
      return versionA.compare(versionB) || versionA.compareBuild(versionB);
    }, "compareBuild");
    module2.exports = compareBuild;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/sort.js
var require_sort = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/sort.js"(exports2, module2) {
    "use strict";
    var compareBuild = require_compare_build();
    var sort = /* @__PURE__ */ __name((list3, loose) => list3.sort((a32, b32) => compareBuild(a32, b32, loose)), "sort");
    module2.exports = sort;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/rsort.js
var require_rsort = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/rsort.js"(exports2, module2) {
    "use strict";
    var compareBuild = require_compare_build();
    var rsort = /* @__PURE__ */ __name((list3, loose) => list3.sort((a32, b32) => compareBuild(b32, a32, loose)), "rsort");
    module2.exports = rsort;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/gt.js
var require_gt = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/gt.js"(exports2, module2) {
    "use strict";
    var compare2 = require_compare();
    var gt = /* @__PURE__ */ __name((a32, b32, loose) => compare2(a32, b32, loose) > 0, "gt");
    module2.exports = gt;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/lt.js
var require_lt = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/lt.js"(exports2, module2) {
    "use strict";
    var compare2 = require_compare();
    var lt = /* @__PURE__ */ __name((a32, b32, loose) => compare2(a32, b32, loose) < 0, "lt");
    module2.exports = lt;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/eq.js
var require_eq = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/eq.js"(exports2, module2) {
    "use strict";
    var compare2 = require_compare();
    var eq2 = /* @__PURE__ */ __name((a32, b32, loose) => compare2(a32, b32, loose) === 0, "eq");
    module2.exports = eq2;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/neq.js
var require_neq = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/neq.js"(exports2, module2) {
    "use strict";
    var compare2 = require_compare();
    var neq = /* @__PURE__ */ __name((a32, b32, loose) => compare2(a32, b32, loose) !== 0, "neq");
    module2.exports = neq;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/gte.js
var require_gte = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/gte.js"(exports2, module2) {
    "use strict";
    var compare2 = require_compare();
    var gte = /* @__PURE__ */ __name((a32, b32, loose) => compare2(a32, b32, loose) >= 0, "gte");
    module2.exports = gte;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/lte.js
var require_lte = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/lte.js"(exports2, module2) {
    "use strict";
    var compare2 = require_compare();
    var lte2 = /* @__PURE__ */ __name((a32, b32, loose) => compare2(a32, b32, loose) <= 0, "lte");
    module2.exports = lte2;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/cmp.js
var require_cmp = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/cmp.js"(exports2, module2) {
    "use strict";
    var eq2 = require_eq();
    var neq = require_neq();
    var gt = require_gt();
    var gte = require_gte();
    var lt = require_lt();
    var lte2 = require_lte();
    var cmp = /* @__PURE__ */ __name((a32, op3, b32, loose) => {
      switch (op3) {
        case "===":
          if (typeof a32 === "object") {
            a32 = a32.version;
          }
          if (typeof b32 === "object") {
            b32 = b32.version;
          }
          return a32 === b32;
        case "!==":
          if (typeof a32 === "object") {
            a32 = a32.version;
          }
          if (typeof b32 === "object") {
            b32 = b32.version;
          }
          return a32 !== b32;
        case "":
        case "=":
        case "==":
          return eq2(a32, b32, loose);
        case "!=":
          return neq(a32, b32, loose);
        case ">":
          return gt(a32, b32, loose);
        case ">=":
          return gte(a32, b32, loose);
        case "<":
          return lt(a32, b32, loose);
        case "<=":
          return lte2(a32, b32, loose);
        default:
          throw new TypeError(`Invalid operator: ${op3}`);
      }
    }, "cmp");
    module2.exports = cmp;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/coerce.js
var require_coerce = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/coerce.js"(exports2, module2) {
    "use strict";
    var SemVer = require_semver();
    var parse2 = require_parse();
    var { safeRe: re, t } = require_re();
    var coerce2 = /* @__PURE__ */ __name((version, options) => {
      if (version instanceof SemVer) {
        return version;
      }
      if (typeof version === "number") {
        version = String(version);
      }
      if (typeof version !== "string") {
        return null;
      }
      options = options || {};
      let match = null;
      if (!options.rtl) {
        match = version.match(options.includePrerelease ? re[t.COERCEFULL] : re[t.COERCE]);
      } else {
        const coerceRtlRegex = options.includePrerelease ? re[t.COERCERTLFULL] : re[t.COERCERTL];
        let next;
        while ((next = coerceRtlRegex.exec(version)) && (!match || match.index + match[0].length !== version.length)) {
          if (!match || next.index + next[0].length !== match.index + match[0].length) {
            match = next;
          }
          coerceRtlRegex.lastIndex = next.index + next[1].length + next[2].length;
        }
        coerceRtlRegex.lastIndex = -1;
      }
      if (match === null) {
        return null;
      }
      const major6 = match[2];
      const minor = match[3] || "0";
      const patch = match[4] || "0";
      const prerelease = options.includePrerelease && match[5] ? `-${match[5]}` : "";
      const build = options.includePrerelease && match[6] ? `+${match[6]}` : "";
      return parse2(`${major6}.${minor}.${patch}${prerelease}${build}`, options);
    }, "coerce");
    module2.exports = coerce2;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/truncate.js
var require_truncate = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/truncate.js"(exports2, module2) {
    "use strict";
    var parse2 = require_parse();
    var constants3 = require_constants();
    var SemVer = require_semver();
    var truncate = /* @__PURE__ */ __name((version, truncation, options) => {
      if (!constants3.RELEASE_TYPES.includes(truncation)) {
        return null;
      }
      const clonedVersion = cloneInputVersion(version, options);
      return clonedVersion && doTruncation(clonedVersion, truncation);
    }, "truncate");
    var cloneInputVersion = /* @__PURE__ */ __name((version, options) => {
      const versionStringToParse = version instanceof SemVer ? version.version : version;
      return parse2(versionStringToParse, options);
    }, "cloneInputVersion");
    var doTruncation = /* @__PURE__ */ __name((version, truncation) => {
      if (isPrerelease(truncation)) {
        return version.version;
      }
      version.prerelease = [];
      switch (truncation) {
        case "major":
          version.minor = 0;
          version.patch = 0;
          break;
        case "minor":
          version.patch = 0;
          break;
      }
      return version.format();
    }, "doTruncation");
    var isPrerelease = /* @__PURE__ */ __name((type) => {
      return type.startsWith("pre");
    }, "isPrerelease");
    module2.exports = truncate;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/internal/lrucache.js
var require_lrucache = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/internal/lrucache.js"(exports2, module2) {
    "use strict";
    var LRUCache = class {
      static {
        __name(this, "LRUCache");
      }
      constructor() {
        this.max = 1e3;
        this.map = /* @__PURE__ */ new Map();
      }
      get(key) {
        const value = this.map.get(key);
        if (value === void 0) {
          return void 0;
        } else {
          this.map.delete(key);
          this.map.set(key, value);
          return value;
        }
      }
      delete(key) {
        return this.map.delete(key);
      }
      set(key, value) {
        const deleted = this.delete(key);
        if (!deleted && value !== void 0) {
          if (this.map.size >= this.max) {
            const firstKey = this.map.keys().next().value;
            this.delete(firstKey);
          }
          this.map.set(key, value);
        }
        return this;
      }
    };
    module2.exports = LRUCache;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/classes/range.js
var require_range = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/classes/range.js"(exports2, module2) {
    "use strict";
    var SPACE_CHARACTERS = /\s+/g;
    var Range = class _Range {
      static {
        __name(this, "Range");
      }
      constructor(range7, options) {
        options = parseOptions(options);
        if (range7 instanceof _Range) {
          if (range7.loose === !!options.loose && range7.includePrerelease === !!options.includePrerelease) {
            return range7;
          } else {
            return new _Range(range7.raw, options);
          }
        }
        if (range7 instanceof Comparator) {
          this.raw = range7.value;
          this.set = [[range7]];
          this.formatted = void 0;
          return this;
        }
        this.options = options;
        this.loose = !!options.loose;
        this.includePrerelease = !!options.includePrerelease;
        this.raw = range7.trim().replace(SPACE_CHARACTERS, " ");
        this.set = this.raw.split("||").map((r32) => this.parseRange(r32.trim())).filter((c32) => c32.length);
        if (!this.set.length) {
          throw new TypeError(`Invalid SemVer Range: ${this.raw}`);
        }
        if (this.set.length > 1) {
          const first = this.set[0];
          this.set = this.set.filter((c32) => !isNullSet(c32[0]));
          if (this.set.length === 0) {
            this.set = [first];
          } else if (this.set.length > 1) {
            for (const c32 of this.set) {
              if (c32.length === 1 && isAny(c32[0])) {
                this.set = [c32];
                break;
              }
            }
          }
        }
        this.formatted = void 0;
      }
      get range() {
        if (this.formatted === void 0) {
          this.formatted = "";
          for (let i32 = 0; i32 < this.set.length; i32++) {
            if (i32 > 0) {
              this.formatted += "||";
            }
            const comps = this.set[i32];
            for (let k32 = 0; k32 < comps.length; k32++) {
              if (k32 > 0) {
                this.formatted += " ";
              }
              this.formatted += comps[k32].toString().trim();
            }
          }
        }
        return this.formatted;
      }
      format() {
        return this.range;
      }
      toString() {
        return this.range;
      }
      parseRange(range7) {
        range7 = range7.replace(BUILDSTRIPRE, "");
        const memoOpts = (this.options.includePrerelease && FLAG_INCLUDE_PRERELEASE) | (this.options.loose && FLAG_LOOSE);
        const memoKey = memoOpts + ":" + range7;
        const cached3 = cache32.get(memoKey);
        if (cached3) {
          return cached3;
        }
        const loose = this.options.loose;
        const hr = loose ? re[t.HYPHENRANGELOOSE] : re[t.HYPHENRANGE];
        range7 = range7.replace(hr, hyphenReplace(this.options.includePrerelease));
        debug2("hyphen replace", range7);
        range7 = range7.replace(re[t.COMPARATORTRIM], comparatorTrimReplace);
        debug2("comparator trim", range7);
        range7 = range7.replace(re[t.TILDETRIM], tildeTrimReplace);
        debug2("tilde trim", range7);
        range7 = range7.replace(re[t.CARETTRIM], caretTrimReplace);
        debug2("caret trim", range7);
        let rangeList = range7.split(" ").map((comp) => parseComparator(comp, this.options)).join(" ").split(/\s+/).map((comp) => replaceGTE0(comp, this.options));
        if (loose) {
          rangeList = rangeList.filter((comp) => {
            debug2("loose invalid filter", comp, this.options);
            return !!comp.match(re[t.COMPARATORLOOSE]);
          });
        }
        debug2("range list", rangeList);
        const rangeMap = /* @__PURE__ */ new Map();
        const comparators = rangeList.map((comp) => new Comparator(comp, this.options));
        for (const comp of comparators) {
          if (isNullSet(comp)) {
            return [comp];
          }
          rangeMap.set(comp.value, comp);
        }
        if (rangeMap.size > 1 && rangeMap.has("")) {
          rangeMap.delete("");
        }
        const result2 = [...rangeMap.values()];
        cache32.set(memoKey, result2);
        return result2;
      }
      intersects(range7, options) {
        if (!(range7 instanceof _Range)) {
          throw new TypeError("a Range is required");
        }
        return this.set.some((thisComparators) => {
          return isSatisfiable(thisComparators, options) && range7.set.some((rangeComparators) => {
            return isSatisfiable(rangeComparators, options) && thisComparators.every((thisComparator) => {
              return rangeComparators.every((rangeComparator) => {
                return thisComparator.intersects(rangeComparator, options);
              });
            });
          });
        });
      }
      // if ANY of the sets match ALL of its comparators, then pass
      test(version) {
        if (!version) {
          return false;
        }
        if (typeof version === "string") {
          try {
            version = new SemVer(version, this.options);
          } catch (er) {
            return false;
          }
        }
        for (let i32 = 0; i32 < this.set.length; i32++) {
          if (testSet(this.set[i32], version, this.options)) {
            return true;
          }
        }
        return false;
      }
    };
    module2.exports = Range;
    var LRU = require_lrucache();
    var cache32 = new LRU();
    var parseOptions = require_parse_options();
    var Comparator = require_comparator();
    var debug2 = require_debug();
    var SemVer = require_semver();
    var {
      safeRe: re,
      src,
      t,
      comparatorTrimReplace,
      tildeTrimReplace,
      caretTrimReplace
    } = require_re();
    var { FLAG_INCLUDE_PRERELEASE, FLAG_LOOSE } = require_constants();
    var BUILDSTRIPRE = new RegExp(src[t.BUILD], "g");
    var isNullSet = /* @__PURE__ */ __name((c32) => c32.value === "<0.0.0-0", "isNullSet");
    var isAny = /* @__PURE__ */ __name((c32) => c32.value === "", "isAny");
    var isSatisfiable = /* @__PURE__ */ __name((comparators, options) => {
      let result2 = true;
      const remainingComparators = comparators.slice();
      let testComparator = remainingComparators.pop();
      while (result2 && remainingComparators.length) {
        result2 = remainingComparators.every((otherComparator) => {
          return testComparator.intersects(otherComparator, options);
        });
        testComparator = remainingComparators.pop();
      }
      return result2;
    }, "isSatisfiable");
    var parseComparator = /* @__PURE__ */ __name((comp, options) => {
      comp = comp.replace(re[t.BUILD], "");
      debug2("comp", comp, options);
      comp = replaceCarets(comp, options);
      debug2("caret", comp);
      comp = replaceTildes(comp, options);
      debug2("tildes", comp);
      comp = replaceXRanges(comp, options);
      debug2("xrange", comp);
      comp = replaceStars(comp, options);
      debug2("stars", comp);
      return comp;
    }, "parseComparator");
    var isX = /* @__PURE__ */ __name((id) => !id || id.toLowerCase() === "x" || id === "*", "isX");
    var invalidXRangeOrder = /* @__PURE__ */ __name((M, m20, p10) => isX(M) && !isX(m20) || isX(m20) && p10 && !isX(p10), "invalidXRangeOrder");
    var replaceTildes = /* @__PURE__ */ __name((comp, options) => {
      return comp.trim().split(/\s+/).map((c32) => replaceTilde(c32, options)).join(" ");
    }, "replaceTildes");
    var replaceTilde = /* @__PURE__ */ __name((comp, options) => {
      const r32 = options.loose ? re[t.TILDELOOSE] : re[t.TILDE];
      return comp.replace(r32, (_, M, m20, p10, pr) => {
        debug2("tilde", comp, _, M, m20, p10, pr);
        let ret;
        if (isX(M)) {
          ret = "";
        } else if (isX(m20)) {
          ret = `>=${M}.0.0 <${+M + 1}.0.0-0`;
        } else if (isX(p10)) {
          ret = `>=${M}.${m20}.0 <${M}.${+m20 + 1}.0-0`;
        } else if (pr) {
          debug2("replaceTilde pr", pr);
          ret = `>=${M}.${m20}.${p10}-${pr} <${M}.${+m20 + 1}.0-0`;
        } else {
          ret = `>=${M}.${m20}.${p10} <${M}.${+m20 + 1}.0-0`;
        }
        debug2("tilde return", ret);
        return ret;
      });
    }, "replaceTilde");
    var replaceCarets = /* @__PURE__ */ __name((comp, options) => {
      return comp.trim().split(/\s+/).map((c32) => replaceCaret(c32, options)).join(" ");
    }, "replaceCarets");
    var replaceCaret = /* @__PURE__ */ __name((comp, options) => {
      debug2("caret", comp, options);
      const r32 = options.loose ? re[t.CARETLOOSE] : re[t.CARET];
      const z = options.includePrerelease ? "-0" : "";
      return comp.replace(r32, (_, M, m20, p10, pr) => {
        debug2("caret", comp, _, M, m20, p10, pr);
        let ret;
        if (isX(M)) {
          ret = "";
        } else if (isX(m20)) {
          ret = `>=${M}.0.0${z} <${+M + 1}.0.0-0`;
        } else if (isX(p10)) {
          if (M === "0") {
            ret = `>=${M}.${m20}.0${z} <${M}.${+m20 + 1}.0-0`;
          } else {
            ret = `>=${M}.${m20}.0${z} <${+M + 1}.0.0-0`;
          }
        } else if (pr) {
          debug2("replaceCaret pr", pr);
          if (M === "0") {
            if (m20 === "0") {
              ret = `>=${M}.${m20}.${p10}-${pr} <${M}.${m20}.${+p10 + 1}-0`;
            } else {
              ret = `>=${M}.${m20}.${p10}-${pr} <${M}.${+m20 + 1}.0-0`;
            }
          } else {
            ret = `>=${M}.${m20}.${p10}-${pr} <${+M + 1}.0.0-0`;
          }
        } else {
          debug2("no pr");
          if (M === "0") {
            if (m20 === "0") {
              ret = `>=${M}.${m20}.${p10} <${M}.${m20}.${+p10 + 1}-0`;
            } else {
              ret = `>=${M}.${m20}.${p10} <${M}.${+m20 + 1}.0-0`;
            }
          } else {
            ret = `>=${M}.${m20}.${p10} <${+M + 1}.0.0-0`;
          }
        }
        debug2("caret return", ret);
        return ret;
      });
    }, "replaceCaret");
    var replaceXRanges = /* @__PURE__ */ __name((comp, options) => {
      debug2("replaceXRanges", comp, options);
      return comp.split(/\s+/).map((c32) => replaceXRange(c32, options)).join(" ");
    }, "replaceXRanges");
    var replaceXRange = /* @__PURE__ */ __name((comp, options) => {
      comp = comp.trim();
      const r32 = options.loose ? re[t.XRANGELOOSE] : re[t.XRANGE];
      return comp.replace(r32, (ret, gtlt, M, m20, p10, pr) => {
        debug2("xRange", comp, ret, gtlt, M, m20, p10, pr);
        if (invalidXRangeOrder(M, m20, p10)) {
          return comp;
        }
        const xM = isX(M);
        const xm = xM || isX(m20);
        const xp = xm || isX(p10);
        const anyX = xp;
        if (gtlt === "=" && anyX) {
          gtlt = "";
        }
        pr = options.includePrerelease ? "-0" : "";
        if (xM) {
          if (gtlt === ">" || gtlt === "<") {
            ret = "<0.0.0-0";
          } else {
            ret = "*";
          }
        } else if (gtlt && anyX) {
          if (xm) {
            m20 = 0;
          }
          p10 = 0;
          if (gtlt === ">") {
            gtlt = ">=";
            if (xm) {
              M = +M + 1;
              m20 = 0;
              p10 = 0;
            } else {
              m20 = +m20 + 1;
              p10 = 0;
            }
          } else if (gtlt === "<=") {
            gtlt = "<";
            if (xm) {
              M = +M + 1;
            } else {
              m20 = +m20 + 1;
            }
          }
          if (gtlt === "<") {
            pr = "-0";
          }
          ret = `${gtlt + M}.${m20}.${p10}${pr}`;
        } else if (xm) {
          ret = `>=${M}.0.0${pr} <${+M + 1}.0.0-0`;
        } else if (xp) {
          ret = `>=${M}.${m20}.0${pr} <${M}.${+m20 + 1}.0-0`;
        }
        debug2("xRange return", ret);
        return ret;
      });
    }, "replaceXRange");
    var replaceStars = /* @__PURE__ */ __name((comp, options) => {
      debug2("replaceStars", comp, options);
      return comp.trim().replace(re[t.STAR], "");
    }, "replaceStars");
    var replaceGTE0 = /* @__PURE__ */ __name((comp, options) => {
      debug2("replaceGTE0", comp, options);
      return comp.trim().replace(re[options.includePrerelease ? t.GTE0PRE : t.GTE0], "");
    }, "replaceGTE0");
    var hyphenReplace = /* @__PURE__ */ __name((incPr) => ($0, from, fM, fm, fp, fpr, fb, to, tM, tm, tp, tpr) => {
      if (isX(fM)) {
        from = "";
      } else if (isX(fm)) {
        from = `>=${fM}.0.0${incPr ? "-0" : ""}`;
      } else if (isX(fp)) {
        from = `>=${fM}.${fm}.0${incPr ? "-0" : ""}`;
      } else if (fpr) {
        from = `>=${from}`;
      } else {
        from = `>=${from}${incPr ? "-0" : ""}`;
      }
      if (isX(tM)) {
        to = "";
      } else if (isX(tm)) {
        to = `<${+tM + 1}.0.0-0`;
      } else if (isX(tp)) {
        to = `<${tM}.${+tm + 1}.0-0`;
      } else if (tpr) {
        to = `<=${tM}.${tm}.${tp}-${tpr}`;
      } else if (incPr) {
        to = `<${tM}.${tm}.${+tp + 1}-0`;
      } else {
        to = `<=${to}`;
      }
      return `${from} ${to}`.trim();
    }, "hyphenReplace");
    var testSet = /* @__PURE__ */ __name((set, version, options) => {
      for (let i32 = 0; i32 < set.length; i32++) {
        if (!set[i32].test(version)) {
          return false;
        }
      }
      if (version.prerelease.length && !options.includePrerelease) {
        for (let i32 = 0; i32 < set.length; i32++) {
          debug2(set[i32].semver);
          if (set[i32].semver === Comparator.ANY) {
            continue;
          }
          if (set[i32].semver.prerelease.length > 0) {
            const allowed = set[i32].semver;
            if (allowed.major === version.major && allowed.minor === version.minor && allowed.patch === version.patch) {
              return true;
            }
          }
        }
        return false;
      }
      return true;
    }, "testSet");
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/classes/comparator.js
var require_comparator = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/classes/comparator.js"(exports2, module2) {
    "use strict";
    var ANY = /* @__PURE__ */ Symbol("SemVer ANY");
    var Comparator = class _Comparator {
      static {
        __name(this, "Comparator");
      }
      static get ANY() {
        return ANY;
      }
      constructor(comp, options) {
        options = parseOptions(options);
        if (comp instanceof _Comparator) {
          if (comp.loose === !!options.loose) {
            return comp;
          } else {
            comp = comp.value;
          }
        }
        comp = comp.trim().split(/\s+/).join(" ");
        debug2("comparator", comp, options);
        this.options = options;
        this.loose = !!options.loose;
        this.parse(comp);
        if (this.semver === ANY) {
          this.value = "";
        } else {
          this.value = this.operator + this.semver.version;
        }
        debug2("comp", this);
      }
      parse(comp) {
        const r32 = this.options.loose ? re[t.COMPARATORLOOSE] : re[t.COMPARATOR];
        const m20 = comp.match(r32);
        if (!m20) {
          throw new TypeError(`Invalid comparator: ${comp}`);
        }
        this.operator = m20[1] !== void 0 ? m20[1] : "";
        if (this.operator === "=") {
          this.operator = "";
        }
        if (!m20[2]) {
          this.semver = ANY;
        } else {
          this.semver = new SemVer(m20[2], this.options.loose);
        }
      }
      toString() {
        return this.value;
      }
      test(version) {
        debug2("Comparator.test", version, this.options.loose);
        if (this.semver === ANY || version === ANY) {
          return true;
        }
        if (typeof version === "string") {
          try {
            version = new SemVer(version, this.options);
          } catch (er) {
            return false;
          }
        }
        return cmp(version, this.operator, this.semver, this.options);
      }
      intersects(comp, options) {
        if (!(comp instanceof _Comparator)) {
          throw new TypeError("a Comparator is required");
        }
        if (this.operator === "") {
          if (this.value === "") {
            return true;
          }
          return new Range(comp.value, options).test(this.value);
        } else if (comp.operator === "") {
          if (comp.value === "") {
            return true;
          }
          return new Range(this.value, options).test(comp.semver);
        }
        options = parseOptions(options);
        if (options.includePrerelease && (this.value === "<0.0.0-0" || comp.value === "<0.0.0-0")) {
          return false;
        }
        if (!options.includePrerelease && (this.value.startsWith("<0.0.0") || comp.value.startsWith("<0.0.0"))) {
          return false;
        }
        if (this.operator.startsWith(">") && comp.operator.startsWith(">")) {
          return true;
        }
        if (this.operator.startsWith("<") && comp.operator.startsWith("<")) {
          return true;
        }
        if (this.semver.version === comp.semver.version && this.operator.includes("=") && comp.operator.includes("=")) {
          return true;
        }
        if (cmp(this.semver, "<", comp.semver, options) && this.operator.startsWith(">") && comp.operator.startsWith("<")) {
          return true;
        }
        if (cmp(this.semver, ">", comp.semver, options) && this.operator.startsWith("<") && comp.operator.startsWith(">")) {
          return true;
        }
        return false;
      }
    };
    module2.exports = Comparator;
    var parseOptions = require_parse_options();
    var { safeRe: re, t } = require_re();
    var cmp = require_cmp();
    var debug2 = require_debug();
    var SemVer = require_semver();
    var Range = require_range();
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/satisfies.js
var require_satisfies = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/functions/satisfies.js"(exports2, module2) {
    "use strict";
    var Range = require_range();
    var satisfies2 = /* @__PURE__ */ __name((version, range7, options) => {
      try {
        range7 = new Range(range7, options);
      } catch (er) {
        return false;
      }
      return range7.test(version);
    }, "satisfies");
    module2.exports = satisfies2;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/ranges/to-comparators.js
var require_to_comparators = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/ranges/to-comparators.js"(exports2, module2) {
    "use strict";
    var Range = require_range();
    var toComparators = /* @__PURE__ */ __name((range7, options) => new Range(range7, options).set.map((comp) => comp.map((c32) => c32.value).join(" ").trim().split(" ")), "toComparators");
    module2.exports = toComparators;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/ranges/max-satisfying.js
var require_max_satisfying = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/ranges/max-satisfying.js"(exports2, module2) {
    "use strict";
    var SemVer = require_semver();
    var Range = require_range();
    var maxSatisfying = /* @__PURE__ */ __name((versions2, range7, options) => {
      let max = null;
      let maxSV = null;
      let rangeObj = null;
      try {
        rangeObj = new Range(range7, options);
      } catch (er) {
        return null;
      }
      versions2.forEach((v) => {
        if (rangeObj.test(v)) {
          if (!max || maxSV.compare(v) === -1) {
            max = v;
            maxSV = new SemVer(max, options);
          }
        }
      });
      return max;
    }, "maxSatisfying");
    module2.exports = maxSatisfying;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/ranges/min-satisfying.js
var require_min_satisfying = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/ranges/min-satisfying.js"(exports2, module2) {
    "use strict";
    var SemVer = require_semver();
    var Range = require_range();
    var minSatisfying = /* @__PURE__ */ __name((versions2, range7, options) => {
      let min = null;
      let minSV = null;
      let rangeObj = null;
      try {
        rangeObj = new Range(range7, options);
      } catch (er) {
        return null;
      }
      versions2.forEach((v) => {
        if (rangeObj.test(v)) {
          if (!min || minSV.compare(v) === 1) {
            min = v;
            minSV = new SemVer(min, options);
          }
        }
      });
      return min;
    }, "minSatisfying");
    module2.exports = minSatisfying;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/ranges/min-version.js
var require_min_version = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/ranges/min-version.js"(exports2, module2) {
    "use strict";
    var SemVer = require_semver();
    var Range = require_range();
    var gt = require_gt();
    var minVersion = /* @__PURE__ */ __name((range7, loose) => {
      range7 = new Range(range7, loose);
      let minver = new SemVer("0.0.0");
      if (range7.test(minver)) {
        return minver;
      }
      minver = new SemVer("0.0.0-0");
      if (range7.test(minver)) {
        return minver;
      }
      minver = null;
      for (let i32 = 0; i32 < range7.set.length; ++i32) {
        const comparators = range7.set[i32];
        let setMin = null;
        comparators.forEach((comparator) => {
          const compver = new SemVer(comparator.semver.version);
          switch (comparator.operator) {
            case ">":
              if (compver.prerelease.length === 0) {
                compver.patch++;
              } else {
                compver.prerelease.push(0);
              }
              compver.raw = compver.format();
            /* fallthrough */
            case "":
            case ">=":
              if (!setMin || gt(compver, setMin)) {
                setMin = compver;
              }
              break;
            case "<":
            case "<=":
              break;
            /* istanbul ignore next */
            default:
              throw new Error(`Unexpected operation: ${comparator.operator}`);
          }
        });
        if (setMin && (!minver || gt(minver, setMin))) {
          minver = setMin;
        }
      }
      if (minver && range7.test(minver)) {
        return minver;
      }
      return null;
    }, "minVersion");
    module2.exports = minVersion;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/ranges/valid.js
var require_valid2 = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/ranges/valid.js"(exports2, module2) {
    "use strict";
    var Range = require_range();
    var validRange = /* @__PURE__ */ __name((range7, options) => {
      try {
        return new Range(range7, options).range || "*";
      } catch (er) {
        return null;
      }
    }, "validRange");
    module2.exports = validRange;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/ranges/outside.js
var require_outside = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/ranges/outside.js"(exports2, module2) {
    "use strict";
    var SemVer = require_semver();
    var Comparator = require_comparator();
    var { ANY } = Comparator;
    var Range = require_range();
    var satisfies2 = require_satisfies();
    var gt = require_gt();
    var lt = require_lt();
    var lte2 = require_lte();
    var gte = require_gte();
    var outside = /* @__PURE__ */ __name((version, range7, hilo, options) => {
      version = new SemVer(version, options);
      range7 = new Range(range7, options);
      let gtfn, ltefn, ltfn, comp, ecomp;
      switch (hilo) {
        case ">":
          gtfn = gt;
          ltefn = lte2;
          ltfn = lt;
          comp = ">";
          ecomp = ">=";
          break;
        case "<":
          gtfn = lt;
          ltefn = gte;
          ltfn = gt;
          comp = "<";
          ecomp = "<=";
          break;
        default:
          throw new TypeError('Must provide a hilo val of "<" or ">"');
      }
      if (satisfies2(version, range7, options)) {
        return false;
      }
      for (let i32 = 0; i32 < range7.set.length; ++i32) {
        const comparators = range7.set[i32];
        let high = null;
        let low = null;
        comparators.forEach((comparator) => {
          if (comparator.semver === ANY) {
            comparator = new Comparator(">=0.0.0");
          }
          high = high || comparator;
          low = low || comparator;
          if (gtfn(comparator.semver, high.semver, options)) {
            high = comparator;
          } else if (ltfn(comparator.semver, low.semver, options)) {
            low = comparator;
          }
        });
        if (high.operator === comp || high.operator === ecomp) {
          return false;
        }
        if ((!low.operator || low.operator === comp) && ltefn(version, low.semver)) {
          return false;
        } else if (low.operator === ecomp && ltfn(version, low.semver)) {
          return false;
        }
      }
      return true;
    }, "outside");
    module2.exports = outside;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/ranges/gtr.js
var require_gtr = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/ranges/gtr.js"(exports2, module2) {
    "use strict";
    var outside = require_outside();
    var gtr = /* @__PURE__ */ __name((version, range7, options) => outside(version, range7, ">", options), "gtr");
    module2.exports = gtr;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/ranges/ltr.js
var require_ltr = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/ranges/ltr.js"(exports2, module2) {
    "use strict";
    var outside = require_outside();
    var ltr = /* @__PURE__ */ __name((version, range7, options) => outside(version, range7, "<", options), "ltr");
    module2.exports = ltr;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/ranges/intersects.js
var require_intersects = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/ranges/intersects.js"(exports2, module2) {
    "use strict";
    var Range = require_range();
    var intersects = /* @__PURE__ */ __name((r1, r210, options) => {
      r1 = new Range(r1, options);
      r210 = new Range(r210, options);
      return r1.intersects(r210, options);
    }, "intersects");
    module2.exports = intersects;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/ranges/simplify.js
var require_simplify = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/ranges/simplify.js"(exports2, module2) {
    "use strict";
    var satisfies2 = require_satisfies();
    var compare2 = require_compare();
    module2.exports = (versions2, range7, options) => {
      const set = [];
      let first = null;
      let prev = null;
      const v = versions2.sort((a32, b32) => compare2(a32, b32, options));
      for (const version of v) {
        const included = satisfies2(version, range7, options);
        if (included) {
          prev = version;
          if (!first) {
            first = version;
          }
        } else {
          if (prev) {
            set.push([first, prev]);
          }
          prev = null;
          first = null;
        }
      }
      if (first) {
        set.push([first, null]);
      }
      const ranges = [];
      for (const [min, max] of set) {
        if (min === max) {
          ranges.push(min);
        } else if (!max && min === v[0]) {
          ranges.push("*");
        } else if (!max) {
          ranges.push(`>=${min}`);
        } else if (min === v[0]) {
          ranges.push(`<=${max}`);
        } else {
          ranges.push(`${min} - ${max}`);
        }
      }
      const simplified = ranges.join(" || ");
      const original = typeof range7.raw === "string" ? range7.raw : String(range7);
      return simplified.length < original.length ? simplified : range7;
    };
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/ranges/subset.js
var require_subset = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/ranges/subset.js"(exports2, module2) {
    "use strict";
    var Range = require_range();
    var Comparator = require_comparator();
    var { ANY } = Comparator;
    var satisfies2 = require_satisfies();
    var compare2 = require_compare();
    var subset = /* @__PURE__ */ __name((sub, dom, options = {}) => {
      if (sub === dom) {
        return true;
      }
      sub = new Range(sub, options);
      dom = new Range(dom, options);
      let sawNonNull = false;
      OUTER: for (const simpleSub of sub.set) {
        for (const simpleDom of dom.set) {
          const isSub = simpleSubset(simpleSub, simpleDom, options);
          sawNonNull = sawNonNull || isSub !== null;
          if (isSub) {
            continue OUTER;
          }
        }
        if (sawNonNull) {
          return false;
        }
      }
      return true;
    }, "subset");
    var minimumVersionWithPreRelease = [new Comparator(">=0.0.0-0")];
    var minimumVersion = [new Comparator(">=0.0.0")];
    var simpleSubset = /* @__PURE__ */ __name((sub, dom, options) => {
      if (sub === dom) {
        return true;
      }
      if (sub.length === 1 && sub[0].semver === ANY) {
        if (dom.length === 1 && dom[0].semver === ANY) {
          return true;
        } else if (options.includePrerelease) {
          sub = minimumVersionWithPreRelease;
        } else {
          sub = minimumVersion;
        }
      }
      if (dom.length === 1 && dom[0].semver === ANY) {
        if (options.includePrerelease) {
          return true;
        } else {
          dom = minimumVersion;
        }
      }
      const eqSet = /* @__PURE__ */ new Set();
      let gt, lt;
      for (const c32 of sub) {
        if (c32.operator === ">" || c32.operator === ">=") {
          gt = higherGT(gt, c32, options);
        } else if (c32.operator === "<" || c32.operator === "<=") {
          lt = lowerLT(lt, c32, options);
        } else {
          eqSet.add(c32.semver);
        }
      }
      if (eqSet.size > 1) {
        return null;
      }
      let gtltComp;
      if (gt && lt) {
        gtltComp = compare2(gt.semver, lt.semver, options);
        if (gtltComp > 0) {
          return null;
        } else if (gtltComp === 0 && (gt.operator !== ">=" || lt.operator !== "<=")) {
          return null;
        }
      }
      for (const eq2 of eqSet) {
        if (gt && !satisfies2(eq2, String(gt), options)) {
          return null;
        }
        if (lt && !satisfies2(eq2, String(lt), options)) {
          return null;
        }
        for (const c32 of dom) {
          if (!satisfies2(eq2, String(c32), options)) {
            return false;
          }
        }
        return true;
      }
      let higher, lower;
      let hasDomLT, hasDomGT;
      let needDomLTPre = lt && !options.includePrerelease && lt.semver.prerelease.length ? lt.semver : false;
      let needDomGTPre = gt && !options.includePrerelease && gt.semver.prerelease.length ? gt.semver : false;
      if (needDomLTPre && needDomLTPre.prerelease.length === 1 && lt.operator === "<" && needDomLTPre.prerelease[0] === 0) {
        needDomLTPre = false;
      }
      for (const c32 of dom) {
        hasDomGT = hasDomGT || c32.operator === ">" || c32.operator === ">=";
        hasDomLT = hasDomLT || c32.operator === "<" || c32.operator === "<=";
        if (gt) {
          if (needDomGTPre) {
            if (c32.semver.prerelease && c32.semver.prerelease.length && c32.semver.major === needDomGTPre.major && c32.semver.minor === needDomGTPre.minor && c32.semver.patch === needDomGTPre.patch) {
              needDomGTPre = false;
            }
          }
          if (c32.operator === ">" || c32.operator === ">=") {
            higher = higherGT(gt, c32, options);
            if (higher === c32 && higher !== gt) {
              return false;
            }
          } else if (gt.operator === ">=" && !c32.test(gt.semver)) {
            return false;
          }
        }
        if (lt) {
          if (needDomLTPre) {
            if (c32.semver.prerelease && c32.semver.prerelease.length && c32.semver.major === needDomLTPre.major && c32.semver.minor === needDomLTPre.minor && c32.semver.patch === needDomLTPre.patch) {
              needDomLTPre = false;
            }
          }
          if (c32.operator === "<" || c32.operator === "<=") {
            lower = lowerLT(lt, c32, options);
            if (lower === c32 && lower !== lt) {
              return false;
            }
          } else if (lt.operator === "<=" && !c32.test(lt.semver)) {
            return false;
          }
        }
        if (!c32.operator && (lt || gt) && gtltComp !== 0) {
          return false;
        }
      }
      if (gt && hasDomLT && !lt && gtltComp !== 0) {
        return false;
      }
      if (lt && hasDomGT && !gt && gtltComp !== 0) {
        return false;
      }
      if (needDomGTPre || needDomLTPre) {
        return false;
      }
      return true;
    }, "simpleSubset");
    var higherGT = /* @__PURE__ */ __name((a32, b32, options) => {
      if (!a32) {
        return b32;
      }
      const comp = compare2(a32.semver, b32.semver, options);
      return comp > 0 ? a32 : comp < 0 ? b32 : b32.operator === ">" && a32.operator === ">=" ? b32 : a32;
    }, "higherGT");
    var lowerLT = /* @__PURE__ */ __name((a32, b32, options) => {
      if (!a32) {
        return b32;
      }
      const comp = compare2(a32.semver, b32.semver, options);
      return comp < 0 ? a32 : comp > 0 ? b32 : b32.operator === "<" && a32.operator === "<=" ? b32 : a32;
    }, "lowerLT");
    module2.exports = subset;
  }
});

// ../@aws-cdk/cloud-assembly-schema/node_modules/semver/index.js
var require_semver2 = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/node_modules/semver/index.js"(exports2, module2) {
    "use strict";
    var internalRe = require_re();
    var constants3 = require_constants();
    var SemVer = require_semver();
    var identifiers = require_identifiers();
    var parse2 = require_parse();
    var valid3 = require_valid();
    var clean = require_clean();
    var inc = require_inc();
    var diff = require_diff();
    var major6 = require_major();
    var minor = require_minor();
    var patch = require_patch();
    var prerelease = require_prerelease();
    var compare2 = require_compare();
    var rcompare = require_rcompare();
    var compareLoose = require_compare_loose();
    var compareBuild = require_compare_build();
    var sort = require_sort();
    var rsort = require_rsort();
    var gt = require_gt();
    var lt = require_lt();
    var eq2 = require_eq();
    var neq = require_neq();
    var gte = require_gte();
    var lte2 = require_lte();
    var cmp = require_cmp();
    var coerce2 = require_coerce();
    var truncate = require_truncate();
    var Comparator = require_comparator();
    var Range = require_range();
    var satisfies2 = require_satisfies();
    var toComparators = require_to_comparators();
    var maxSatisfying = require_max_satisfying();
    var minSatisfying = require_min_satisfying();
    var minVersion = require_min_version();
    var validRange = require_valid2();
    var outside = require_outside();
    var gtr = require_gtr();
    var ltr = require_ltr();
    var intersects = require_intersects();
    var simplifyRange = require_simplify();
    var subset = require_subset();
    module2.exports = {
      parse: parse2,
      valid: valid3,
      clean,
      inc,
      diff,
      major: major6,
      minor,
      patch,
      prerelease,
      compare: compare2,
      rcompare,
      compareLoose,
      compareBuild,
      sort,
      rsort,
      gt,
      lt,
      eq: eq2,
      neq,
      gte,
      lte: lte2,
      cmp,
      coerce: coerce2,
      truncate,
      Comparator,
      Range,
      satisfies: satisfies2,
      toComparators,
      maxSatisfying,
      minSatisfying,
      minVersion,
      validRange,
      outside,
      gtr,
      ltr,
      intersects,
      simplifyRange,
      subset,
      SemVer,
      re: internalRe.re,
      src: internalRe.src,
      tokens: internalRe.t,
      SEMVER_SPEC_VERSION: constants3.SEMVER_SPEC_VERSION,
      RELEASE_TYPES: constants3.RELEASE_TYPES,
      compareIdentifiers: identifiers.compareIdentifiers,
      rcompareIdentifiers: identifiers.rcompareIdentifiers
    };
  }
});

// ../@aws-cdk/cloud-assembly-schema/cli-version.json
var require_cli_version = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/cli-version.json"(exports2, module2) {
    module2.exports = { version: "2.1128.1" };
  }
});

// ../@aws-cdk/cloud-assembly-schema/schema/assets.schema.json
var require_assets_schema = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/schema/assets.schema.json"(exports2, module2) {
    module2.exports = {
      $ref: "#/definitions/AssetManifest",
      definitions: {
        AssetManifest: {
          description: "Definitions for the asset manifest",
          type: "object",
          properties: {
            version: {
              description: "Version of the manifest",
              type: "string"
            },
            files: {
              description: "The file assets in this manifest (Default - No files)",
              type: "object",
              additionalProperties: {
                $ref: "#/definitions/FileAsset"
              }
            },
            dockerImages: {
              description: "The Docker image assets in this manifest (Default - No Docker images)",
              type: "object",
              additionalProperties: {
                $ref: "#/definitions/DockerImageAsset"
              }
            }
          },
          required: [
            "version"
          ]
        },
        FileAsset: {
          description: "A file asset",
          type: "object",
          properties: {
            displayName: {
              description: "A display name for this asset (Default - The identifier will be used as the display name)",
              type: "string"
            },
            source: {
              $ref: "#/definitions/FileSource",
              description: "Source description for file assets"
            },
            destinations: {
              description: "Destinations for this file asset",
              type: "object",
              additionalProperties: {
                $ref: "#/definitions/FileDestination"
              }
            }
          },
          required: [
            "destinations",
            "source"
          ]
        },
        FileSource: {
          description: "Describe the source of a file asset",
          type: "object",
          properties: {
            executable: {
              description: "External command which will produce the file asset to upload. (Default - Exactly one of `executable` and `path` is required.)",
              type: "array",
              items: {
                type: "string"
              }
            },
            path: {
              description: "The filesystem object to upload\n\nThis path is relative to the asset manifest location. (Default - Exactly one of `executable` and `path` is required.)",
              type: "string"
            },
            packaging: {
              description: "Packaging method\n\nOnly allowed when `path` is specified. (Default FILE)",
              enum: [
                "file",
                "zip"
              ],
              type: "string"
            }
          }
        },
        FileDestination: {
          description: "Where in S3 a file asset needs to be published",
          type: "object",
          properties: {
            bucketName: {
              description: "The name of the bucket",
              type: "string"
            },
            objectKey: {
              description: "The destination object key",
              type: "string"
            },
            region: {
              description: "The region where this asset will need to be published (Default - Current region)",
              type: "string"
            },
            assumeRoleArn: {
              description: "The role that needs to be assumed while publishing this asset (Default - No role will be assumed)",
              type: "string"
            },
            assumeRoleExternalId: {
              description: "The ExternalId that needs to be supplied while assuming this role (Default - No ExternalId will be supplied)",
              type: "string"
            },
            assumeRoleAdditionalOptions: {
              description: "Additional options to pass to STS when assuming the role.\n\n- `RoleArn` should not be used. Use the dedicated `assumeRoleArn` property instead.\n- `ExternalId` should not be used. Use the dedicated `assumeRoleExternalId` instead. (Default - No additional options.)",
              type: "object",
              additionalProperties: {}
            }
          },
          required: [
            "bucketName",
            "objectKey"
          ]
        },
        DockerImageAsset: {
          description: "A file asset",
          type: "object",
          properties: {
            displayName: {
              description: "A display name for this asset (Default - The identifier will be used as the display name)",
              type: "string"
            },
            source: {
              $ref: "#/definitions/DockerImageSource",
              description: "Source description for container assets"
            },
            destinations: {
              description: "Destinations for this container asset",
              type: "object",
              additionalProperties: {
                $ref: "#/definitions/DockerImageDestination"
              }
            }
          },
          required: [
            "destinations",
            "source"
          ]
        },
        DockerImageSource: {
          description: "Properties for how to produce a Docker image from a source",
          type: "object",
          properties: {
            directory: {
              description: "The directory containing the Docker image build instructions.\n\nThis path is relative to the asset manifest location. (Default - Exactly one of `directory` and `executable` is required)",
              type: "string"
            },
            executable: {
              description: "A command-line executable that returns the name of a local\nDocker image on stdout after being run. (Default - Exactly one of `directory` and `executable` is required)",
              type: "array",
              items: {
                type: "string"
              }
            },
            dockerFile: {
              description: "The name of the file with build instructions\n\nOnly allowed when `directory` is set. (Default Dockerfile)",
              type: "string"
            },
            dockerBuildTarget: {
              description: "Target build stage in a Dockerfile with multiple build stages\n\nOnly allowed when `directory` is set. (Default - The last stage in the Dockerfile)",
              type: "string"
            },
            dockerBuildArgs: {
              description: "Additional build arguments\n\nOnly allowed when `directory` is set. (Default - No additional build arguments)",
              type: "object",
              additionalProperties: {
                type: "string"
              }
            },
            dockerBuildContexts: {
              description: "Additional build contexts\n\nOnly allowed when `directory` is set. (Default - No additional build contexts)",
              type: "object",
              additionalProperties: {
                type: "string"
              }
            },
            dockerBuildSsh: {
              description: "SSH agent socket or keys\n\nRequires building with docker buildkit. (Default - No ssh flag is set)",
              type: "string"
            },
            dockerBuildSecrets: {
              description: "Additional build secrets\n\nOnly allowed when `directory` is set. (Default - No additional build secrets)",
              type: "object",
              additionalProperties: {
                type: "string"
              }
            },
            networkMode: {
              description: "Networking mode for the RUN commands during build. _Requires Docker Engine API v1.25+_.\n\nSpecify this property to build images on a specific networking mode. (Default - no networking mode specified)",
              type: "string"
            },
            platform: {
              description: "Platform to build for. _Requires Docker Buildx_.\n\nSpecify this property to build images on a specific platform/architecture. (Default - current machine platform)",
              type: "string"
            },
            dockerOutputs: {
              description: "Outputs (Default - no outputs are passed to the build command (default outputs are used))",
              type: "array",
              items: {
                type: "string"
              }
            },
            cacheFrom: {
              description: "Cache from options to pass to the `docker build` command. (Default - no cache from options are passed to the build command)",
              type: "array",
              items: {
                $ref: "#/definitions/DockerCacheOption"
              }
            },
            cacheTo: {
              description: "Cache to options to pass to the `docker build` command. (Default - no cache to options are passed to the build command)",
              $ref: "#/definitions/DockerCacheOption"
            },
            cacheDisabled: {
              description: "Disable the cache and pass `--no-cache` to the `docker build` command. (Default - cache is used)",
              type: "boolean"
            }
          }
        },
        DockerCacheOption: {
          description: "Options for configuring the Docker cache backend",
          type: "object",
          properties: {
            type: {
              description: "The type of cache to use.\nRefer to https://docs.docker.com/build/cache/backends/ for full list of backends. (Default - unspecified)",
              type: "string"
            },
            params: {
              description: "Any parameters to pass into the docker cache backend configuration.\nRefer to https://docs.docker.com/build/cache/backends/ for cache backend configuration. (Default {} No options provided)",
              type: "object",
              additionalProperties: {
                type: "string"
              }
            }
          },
          required: [
            "type"
          ]
        },
        DockerImageDestination: {
          description: "Where to publish docker images",
          type: "object",
          properties: {
            repositoryName: {
              description: "Name of the ECR repository to publish to",
              type: "string"
            },
            imageTag: {
              description: "Tag of the image to publish",
              type: "string"
            },
            region: {
              description: "The region where this asset will need to be published (Default - Current region)",
              type: "string"
            },
            assumeRoleArn: {
              description: "The role that needs to be assumed while publishing this asset (Default - No role will be assumed)",
              type: "string"
            },
            assumeRoleExternalId: {
              description: "The ExternalId that needs to be supplied while assuming this role (Default - No ExternalId will be supplied)",
              type: "string"
            },
            assumeRoleAdditionalOptions: {
              description: "Additional options to pass to STS when assuming the role.\n\n- `RoleArn` should not be used. Use the dedicated `assumeRoleArn` property instead.\n- `ExternalId` should not be used. Use the dedicated `assumeRoleExternalId` instead. (Default - No additional options.)",
              type: "object",
              additionalProperties: {}
            }
          },
          required: [
            "imageTag",
            "repositoryName"
          ]
        }
      },
      $schema: "http://json-schema.org/draft-07/schema#"
    };
  }
});

// ../@aws-cdk/cloud-assembly-schema/schema/cloud-assembly.schema.json
var require_cloud_assembly_schema = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/schema/cloud-assembly.schema.json"(exports2, module2) {
    module2.exports = {
      $ref: "#/definitions/AssemblyManifest",
      definitions: {
        AssemblyManifest: {
          description: "A manifest which describes the cloud assembly.",
          type: "object",
          properties: {
            version: {
              description: "Protocol version",
              type: "string"
            },
            minimumCliVersion: {
              description: "Required CLI version, if available\n\nIf the manifest producer knows, it can put the minimum version of the CLI\nhere that supports reading this assembly.\n\nIf set, it can be used to show a more informative error message to users. (Default - Minimum CLI version unknown)",
              type: "string"
            },
            artifacts: {
              description: "The set of artifacts in this assembly. (Default - no artifacts.)",
              type: "object",
              additionalProperties: {
                $ref: "#/definitions/ArtifactManifest"
              }
            },
            missing: {
              description: "Missing context information. If this field has values, it means that the\ncloud assembly is not complete and should not be deployed. (Default - no missing context.)",
              type: "array",
              items: {
                $ref: "#/definitions/MissingContext"
              }
            },
            runtime: {
              description: "Runtime information. (Default - no info.)",
              $ref: "#/definitions/RuntimeInfo"
            }
          },
          required: [
            "version"
          ]
        },
        ArtifactManifest: {
          description: "A manifest for a single artifact within the cloud assembly.",
          type: "object",
          properties: {
            type: {
              $ref: "#/definitions/ArtifactType",
              description: "The type of artifact."
            },
            environment: {
              description: "The environment into which this artifact is deployed. (Default - no envrionment.)",
              type: "string"
            },
            metadata: {
              description: "Associated metadata.\n\nMetadata can be stored directly in the assembly manifest, as well as in a\nseparate file (see `additionalMetadataFile`). It should prefer to be stored\nin the additional file, as that will reduce the size of the assembly\nmanifest in cases of a lot of metdata (which CDK does emit by default). (Default - no metadata.)",
              type: "object",
              additionalProperties: {
                type: "array",
                items: {
                  $ref: "#/definitions/MetadataEntry"
                }
              }
            },
            additionalMetadataFile: {
              description: "A file with additional metadata entries.\n\nThe schema of this file is exactly the same as the type of the `metadata` field.\nIn other words, that file contains an object mapping construct paths to arrays\nof metadata entries. (Default - no additional metadata)",
              type: "string"
            },
            dependencies: {
              description: "IDs of artifacts that must be deployed before this artifact. (Default - no dependencies.)",
              type: "array",
              items: {
                type: "string"
              }
            },
            properties: {
              description: "The set of properties for this artifact (depends on type) (Default - no properties.)",
              anyOf: [
                {
                  $ref: "#/definitions/AwsCloudFormationStackProperties"
                },
                {
                  $ref: "#/definitions/AssetManifestProperties"
                },
                {
                  $ref: "#/definitions/TreeArtifactProperties"
                },
                {
                  $ref: "#/definitions/NestedCloudAssemblyProperties"
                },
                {
                  $ref: "#/definitions/FeatureFlagReportProperties"
                }
              ]
            },
            displayName: {
              description: `A string that can be shown to a user to uniquely identify this artifact inside a cloud assembly tree

Is used by the CLI to present a list of stacks to the user in a way that
makes sense to them. Even though the property name "display name" doesn't
imply it, this field is used to select stacks as well, so all stacks should
have a unique display name. (Default - no display name)`,
              type: "string"
            }
          },
          required: [
            "type"
          ]
        },
        ArtifactType: {
          description: "Type of cloud artifact.",
          type: "string",
          enum: [
            "none",
            "aws:cloudformation:stack",
            "cdk:tree",
            "cdk:asset-manifest",
            "cdk:cloud-assembly",
            "cdk:feature-flag-report"
          ]
        },
        MetadataEntry: {
          description: "A metadata entry in a cloud assembly artifact.",
          type: "object",
          properties: {
            type: {
              description: "The type of the metadata entry.",
              type: "string"
            },
            data: {
              description: "The data. (Default - no data.)",
              anyOf: [
                {
                  $ref: "#/definitions/FileAssetMetadataEntry"
                },
                {
                  $ref: "#/definitions/ContainerImageAssetMetadataEntry"
                },
                {
                  $ref: "#/definitions/PropertyMutationMetadataEntry"
                },
                {
                  type: "array",
                  items: {
                    anyOf: [
                      {
                        $ref: "#/definitions/Tag"
                      },
                      {
                        type: "string"
                      }
                    ]
                  }
                },
                {
                  type: [
                    "string",
                    "number",
                    "boolean"
                  ]
                },
                {
                  description: "Free form data."
                }
              ]
            },
            trace: {
              description: "A stack trace for when the entry was created. (Default - no trace.)",
              type: "array",
              items: {
                type: "string"
              }
            }
          },
          required: [
            "type"
          ]
        },
        FileAssetMetadataEntry: {
          description: "Metadata Entry spec for files.",
          type: "object",
          properties: {
            packaging: {
              description: "Requested packaging style",
              enum: [
                "file",
                "zip"
              ],
              type: "string"
            },
            s3BucketParameter: {
              description: "Name of parameter where S3 bucket should be passed in",
              type: "string"
            },
            s3KeyParameter: {
              description: "Name of parameter where S3 key should be passed in",
              type: "string"
            },
            artifactHashParameter: {
              description: "The name of the parameter where the hash of the bundled asset should be passed in.",
              type: "string"
            },
            id: {
              description: "Logical identifier for the asset",
              type: "string"
            },
            sourceHash: {
              description: "The hash of the asset source.",
              type: "string"
            },
            path: {
              description: "Path on disk to the asset",
              type: "string"
            }
          },
          required: [
            "artifactHashParameter",
            "id",
            "packaging",
            "path",
            "s3BucketParameter",
            "s3KeyParameter",
            "sourceHash"
          ]
        },
        ContainerImageAssetMetadataEntry: {
          description: "Metadata Entry spec for container images.",
          type: "object",
          properties: {
            packaging: {
              description: "Type of asset",
              type: "string",
              const: "container-image"
            },
            imageNameParameter: {
              description: 'ECR Repository name and repo digest (separated by "@sha256:") where this\nimage is stored. (Default undefined If not specified, `repositoryName` and `imageTag` are\nrequired because otherwise how will the stack know where to find the asset,\nha?)',
              type: "string"
            },
            repositoryName: {
              description: "ECR repository name, if omitted a default name based on the asset's ID is\nused instead. Specify this property if you need to statically address the\nimage, e.g. from a Kubernetes Pod. Note, this is only the repository name,\nwithout the registry and the tag parts. (Default - this parameter is REQUIRED after 1.21.0)",
              type: "string"
            },
            imageTag: {
              description: "The docker image tag to use for tagging pushed images. This field is\nrequired if `imageParameterName` is ommited (otherwise, the app won't be\nable to find the image). (Default - this parameter is REQUIRED after 1.21.0)",
              type: "string"
            },
            buildArgs: {
              description: "Build args to pass to the `docker build` command (Default no build args are passed)",
              type: "object",
              additionalProperties: {
                type: "string"
              }
            },
            buildContexts: {
              description: "Build contexts to pass to the `docker build` command (Default no build contexts are passed)",
              type: "object",
              additionalProperties: {
                type: "string"
              }
            },
            buildSsh: {
              description: "SSH agent socket or keys to pass to the `docker build` command (Default no ssh arg is passed)",
              type: "string"
            },
            buildSecrets: {
              description: "Build secrets to pass to the `docker build` command (Default no build secrets are passed)",
              type: "object",
              additionalProperties: {
                type: "string"
              }
            },
            target: {
              description: "Docker target to build to (Default no build target)",
              type: "string"
            },
            file: {
              description: "Path to the Dockerfile (relative to the directory). (Default - no file is passed)",
              type: "string"
            },
            networkMode: {
              description: "Networking mode for the RUN commands during build. (Default - no networking mode specified)",
              type: "string"
            },
            platform: {
              description: "Platform to build for. _Requires Docker Buildx_. (Default - current machine platform)",
              type: "string"
            },
            outputs: {
              description: "Outputs to pass to the `docker build` command. (Default - no outputs are passed to the build command (default outputs are used))",
              type: "array",
              items: {
                type: "string"
              }
            },
            cacheFrom: {
              description: "Cache from options to pass to the `docker build` command. (Default - no cache from options are passed to the build command)",
              type: "array",
              items: {
                $ref: "#/definitions/ContainerImageAssetCacheOption"
              }
            },
            cacheTo: {
              description: "Cache to options to pass to the `docker build` command. (Default - no cache to options are passed to the build command)",
              $ref: "#/definitions/ContainerImageAssetCacheOption"
            },
            cacheDisabled: {
              description: "Disable the cache and pass `--no-cache` to the `docker build` command. (Default - cache is used)",
              type: "boolean"
            },
            id: {
              description: "Logical identifier for the asset",
              type: "string"
            },
            sourceHash: {
              description: "The hash of the asset source.",
              type: "string"
            },
            path: {
              description: "Path on disk to the asset",
              type: "string"
            }
          },
          required: [
            "id",
            "packaging",
            "path",
            "sourceHash"
          ]
        },
        ContainerImageAssetCacheOption: {
          description: "Options for configuring the Docker cache backend",
          type: "object",
          properties: {
            type: {
              description: "The type of cache to use.\nRefer to https://docs.docker.com/build/cache/backends/ for full list of backends. (Default - unspecified)",
              type: "string"
            },
            params: {
              description: "Any parameters to pass into the docker cache backend configuration.\nRefer to https://docs.docker.com/build/cache/backends/ for cache backend configuration. (Default {} No options provided)",
              type: "object",
              additionalProperties: {
                type: "string"
              }
            }
          },
          required: [
            "type"
          ]
        },
        PropertyMutationMetadataEntry: {
          description: "Metadata type of a PropertyMutation",
          type: "object",
          properties: {
            propertyName: {
              description: "Name of the property",
              type: "string"
            },
            stackTrace: {
              description: "Stack trace of the mutation",
              type: "array",
              items: {
                type: "string"
              }
            }
          },
          required: [
            "propertyName",
            "stackTrace"
          ]
        },
        Tag: {
          description: "Metadata Entry spec for stack tag.",
          type: "object",
          properties: {
            key: {
              description: 'Tag key.\n\n(In the actual file on disk this will be cased as "Key", and the structure is\npatched to match this structure upon loading:\nhttps://github.com/aws/aws-cdk/blob/4aadaa779b48f35838cccd4e25107b2338f05547/packages/%40aws-cdk/cloud-assembly-schema/lib/manifest.ts#L137)',
              type: "string"
            },
            value: {
              description: 'Tag value.\n\n(In the actual file on disk this will be cased as "Value", and the structure is\npatched to match this structure upon loading:\nhttps://github.com/aws/aws-cdk/blob/4aadaa779b48f35838cccd4e25107b2338f05547/packages/%40aws-cdk/cloud-assembly-schema/lib/manifest.ts#L137)',
              type: "string"
            }
          },
          required: [
            "key",
            "value"
          ]
        },
        AwsCloudFormationStackProperties: {
          description: "Artifact properties for CloudFormation stacks.",
          type: "object",
          properties: {
            templateFile: {
              description: "A file relative to the assembly root which contains the CloudFormation template for this stack.",
              type: "string"
            },
            parameters: {
              description: "Values for CloudFormation stack parameters that should be passed when the stack is deployed. (Default - No parameters)",
              type: "object",
              additionalProperties: {
                type: "string"
              }
            },
            tags: {
              description: "Values for CloudFormation stack tags that should be passed when the stack is deployed.\n\nN.B.: Tags are also written to stack metadata, under the path of the Stack\nconstruct. Only in CDK CLI v1 are those tags found in metadata used for\nactual deployments; in all stable versions of CDK only the stack tags\ndirectly found in the `tags` property of `AwsCloudFormationStack` artifact\n(i.e., this property) are used. (Default - No tags)",
              type: "object",
              additionalProperties: {
                type: "string"
              }
            },
            notificationArns: {
              description: "SNS Notification ARNs that should receive CloudFormation Stack Events. (Default - No notification arns)",
              type: "array",
              items: {
                type: "string"
              }
            },
            stackName: {
              description: "The name to use for the CloudFormation stack. (Default - name derived from artifact ID)",
              type: "string"
            },
            terminationProtection: {
              description: "Whether to enable termination protection for this stack.",
              default: false,
              type: "boolean"
            },
            assumeRoleArn: {
              description: "The role that needs to be assumed to deploy the stack (Default - No role is assumed (current credentials are used))",
              type: "string"
            },
            assumeRoleExternalId: {
              description: "External ID to use when assuming role for cloudformation deployments (Default - No external ID)",
              type: "string"
            },
            assumeRoleAdditionalOptions: {
              description: "Additional options to pass to STS when assuming the role.\n\n- `RoleArn` should not be used. Use the dedicated `assumeRoleArn` property instead.\n- `ExternalId` should not be used. Use the dedicated `assumeRoleExternalId` instead. (Default - No additional options.)",
              type: "object",
              additionalProperties: {}
            },
            cloudFormationExecutionRoleArn: {
              description: "The role that is passed to CloudFormation to execute the change set (Default - No role is passed (currently assumed role/credentials are used))",
              type: "string"
            },
            lookupRole: {
              description: "The role to use to look up values from the target AWS account (Default - No role is assumed (current credentials are used))",
              $ref: "#/definitions/BootstrapRole"
            },
            stackTemplateAssetObjectUrl: {
              description: "If the stack template has already been included in the asset manifest, its asset URL (Default - Not uploaded yet, upload just before deploying)",
              type: "string"
            },
            requiresBootstrapStackVersion: {
              description: "Version of bootstrap stack required to deploy this stack (Default - No bootstrap stack required)",
              type: "number"
            },
            bootstrapStackVersionSsmParameter: {
              description: "SSM parameter where the bootstrap stack version number can be found\n\nOnly used if `requiresBootstrapStackVersion` is set.\n\n- If this value is not set, the bootstrap stack name must be known at\n  deployment time so the stack version can be looked up from the stack\n  outputs.\n- If this value is set, the bootstrap stack can have any name because\n  we won't need to look it up. (Default - Bootstrap stack version number looked up)",
              type: "string"
            },
            validateOnSynth: {
              description: "Whether this stack should be validated by the CLI after synthesis (Default - false)",
              type: "boolean"
            }
          },
          required: [
            "templateFile"
          ]
        },
        BootstrapRole: {
          description: "Information needed to access an IAM role created\nas part of the bootstrap process",
          type: "object",
          properties: {
            arn: {
              description: "The ARN of the IAM role created as part of bootrapping\ne.g. lookupRoleArn",
              type: "string"
            },
            assumeRoleExternalId: {
              description: "External ID to use when assuming the bootstrap role (Default - No external ID)",
              type: "string"
            },
            assumeRoleAdditionalOptions: {
              description: "Additional options to pass to STS when assuming the role.\n\n- `RoleArn` should not be used. Use the dedicated `arn` property instead.\n- `ExternalId` should not be used. Use the dedicated `assumeRoleExternalId` instead. (Default - No additional options.)",
              type: "object",
              additionalProperties: {}
            },
            requiresBootstrapStackVersion: {
              description: "Version of bootstrap stack required to use this role (Default - No bootstrap stack required)",
              type: "number"
            },
            bootstrapStackVersionSsmParameter: {
              description: "Name of SSM parameter with bootstrap stack version (Default - Discover SSM parameter by reading stack)",
              type: "string"
            }
          },
          required: [
            "arn"
          ]
        },
        AssetManifestProperties: {
          description: "Artifact properties for the Asset Manifest",
          type: "object",
          properties: {
            file: {
              description: "Filename of the asset manifest",
              type: "string"
            },
            requiresBootstrapStackVersion: {
              description: "Version of bootstrap stack required to deploy this stack (Default - Version 1 (basic modern bootstrap stack))",
              type: "number"
            },
            bootstrapStackVersionSsmParameter: {
              description: "SSM parameter where the bootstrap stack version number can be found\n\n- If this value is not set, the bootstrap stack name must be known at\n  deployment time so the stack version can be looked up from the stack\n  outputs.\n- If this value is set, the bootstrap stack can have any name because\n  we won't need to look it up. (Default - Bootstrap stack version number looked up)",
              type: "string"
            }
          },
          required: [
            "file"
          ]
        },
        TreeArtifactProperties: {
          description: "Artifact properties for the Construct Tree Artifact",
          type: "object",
          properties: {
            file: {
              description: "Filename of the tree artifact",
              type: "string"
            }
          },
          required: [
            "file"
          ]
        },
        NestedCloudAssemblyProperties: {
          description: "Artifact properties for nested cloud assemblies",
          type: "object",
          properties: {
            directoryName: {
              description: "Relative path to the nested cloud assembly",
              type: "string"
            },
            displayName: {
              description: "Display name for the cloud assembly (Default - The artifact ID)",
              type: "string"
            }
          },
          required: [
            "directoryName"
          ]
        },
        FeatureFlagReportProperties: {
          description: "Artifact properties for a feature flag report\n\nA feature flag report is small enough that all the properties can be inlined\nhere, and doesn't need an additional file.",
          type: "object",
          properties: {
            module: {
              description: "The library that this feature flag report applies to.",
              type: "string"
            },
            flags: {
              description: "Information about every feature flag supported by this library.",
              type: "object",
              additionalProperties: {
                $ref: "#/definitions/FeatureFlag"
              }
            }
          },
          required: [
            "flags",
            "module"
          ]
        },
        FeatureFlag: {
          description: "A single feature flag",
          type: "object",
          properties: {
            recommendedValue: {
              description: "The library-recommended value for this flag, if any\n\nIt is possible that there is no recommended value. (Default - No recommended value.)"
            },
            userValue: {
              description: "The value configured by the user\n\nThis is the value configured at the root of the tree. Users may also have\nconfigured values at specific locations in the tree; we don't report on\nthose. (Default - Not configured by the user)"
            },
            explanation: {
              description: "Explanation about the purpose of this flag that can be shown to the user. (Default - No description)",
              type: "string"
            },
            unconfiguredBehavesLike: {
              description: "The value of the flag that produces the same behavior as when the flag is not configured at all\n\nThe structure of this field is a historical accident. The type of this field\nshould have been boolean, which should have contained the default value for\nthe flag appropriate for the *current* version of the CDK library. We are\nnot rectifying this accident because doing so\n\nInstead, the canonical way to access this value is by evaluating\n`unconfiguredBehavesLike?.v2 ?? false`.",
              default: false,
              $ref: "#/definitions/UnconfiguredBehavesLike"
            }
          }
        },
        UnconfiguredBehavesLike: {
          type: "object",
          properties: {
            v1: {
              description: "Historical accident, don't use.\n\nThis value may be present, but it should never be used. The actual value is\nin the `v2` field, regardless of the version of the CDK library. (Default - ignore)"
            },
            v2: {
              description: "The value of the flag that produces the same behavior as when the flag is not configured at all\n\nEven though it is called 'v2', this is the official name of this field. In\nany future versions of CDK (v3, v4, ...), this field will still be called 'v2'.\n\nThe structure of this field is a historical accident. See the comment on\n`unconfiguredBehavesLike` for more information.",
              default: false
            }
          }
        },
        MissingContext: {
          description: "Represents a missing piece of context.",
          type: "object",
          properties: {
            key: {
              description: "The missing context key.",
              type: "string"
            },
            provider: {
              $ref: "#/definitions/ContextProvider",
              description: "The provider from which we expect this context key to be obtained."
            },
            props: {
              $ref: "#/definitions/ContextQueryProperties",
              description: "A set of provider-specific options."
            }
          },
          required: [
            "key",
            "props",
            "provider"
          ]
        },
        ContextProvider: {
          description: "Identifier for the context provider",
          type: "string",
          enum: [
            "ami",
            "availability-zones",
            "hosted-zone",
            "ssm",
            "vpc-provider",
            "endpoint-service-availability-zones",
            "load-balancer",
            "load-balancer-listener",
            "security-group",
            "key-provider",
            "cc-api-provider",
            "plugin"
          ]
        },
        ContextQueryProperties: {
          anyOf: [
            {
              $ref: "#/definitions/AmiContextQuery"
            },
            {
              $ref: "#/definitions/AvailabilityZonesContextQuery"
            },
            {
              $ref: "#/definitions/HostedZoneContextQuery"
            },
            {
              $ref: "#/definitions/SSMParameterContextQuery"
            },
            {
              $ref: "#/definitions/VpcContextQuery"
            },
            {
              $ref: "#/definitions/EndpointServiceAvailabilityZonesContextQuery"
            },
            {
              $ref: "#/definitions/LoadBalancerContextQuery"
            },
            {
              $ref: "#/definitions/LoadBalancerListenerContextQuery"
            },
            {
              $ref: "#/definitions/SecurityGroupContextQuery"
            },
            {
              $ref: "#/definitions/KeyContextQuery"
            },
            {
              $ref: "#/definitions/CcApiContextQuery"
            },
            {
              $ref: "#/definitions/PluginContextQuery"
            }
          ]
        },
        AmiContextQuery: {
          description: "Query to AMI context provider",
          type: "object",
          properties: {
            owners: {
              description: "Owners to DescribeImages call (Default - All owners)",
              type: "array",
              items: {
                type: "string"
              }
            },
            filters: {
              description: "Filters to DescribeImages call",
              type: "object",
              additionalProperties: {
                type: "array",
                items: {
                  type: "string"
                }
              }
            },
            account: {
              description: "Query account",
              type: "string"
            },
            region: {
              description: "Query region",
              type: "string"
            },
            lookupRoleArn: {
              description: "The ARN of the role that should be used to look up the missing values (Default - None)",
              type: "string"
            },
            lookupRoleExternalId: {
              description: "The ExternalId that needs to be supplied while assuming this role (Default - No ExternalId will be supplied)",
              type: "string"
            },
            assumeRoleAdditionalOptions: {
              description: "Additional options to pass to STS when assuming the lookup role.\n\n- `RoleArn` should not be used. Use the dedicated `lookupRoleArn` property instead.\n- `ExternalId` should not be used. Use the dedicated `lookupRoleExternalId` instead. (Default - No additional options.)",
              type: "object",
              additionalProperties: {}
            }
          },
          required: [
            "account",
            "filters",
            "region"
          ]
        },
        AvailabilityZonesContextQuery: {
          description: "Query to availability zone context provider",
          type: "object",
          properties: {
            account: {
              description: "Query account",
              type: "string"
            },
            region: {
              description: "Query region",
              type: "string"
            },
            lookupRoleArn: {
              description: "The ARN of the role that should be used to look up the missing values (Default - None)",
              type: "string"
            },
            lookupRoleExternalId: {
              description: "The ExternalId that needs to be supplied while assuming this role (Default - No ExternalId will be supplied)",
              type: "string"
            },
            assumeRoleAdditionalOptions: {
              description: "Additional options to pass to STS when assuming the lookup role.\n\n- `RoleArn` should not be used. Use the dedicated `lookupRoleArn` property instead.\n- `ExternalId` should not be used. Use the dedicated `lookupRoleExternalId` instead. (Default - No additional options.)",
              type: "object",
              additionalProperties: {}
            }
          },
          required: [
            "account",
            "region"
          ]
        },
        HostedZoneContextQuery: {
          description: "Query to hosted zone context provider",
          type: "object",
          properties: {
            domainName: {
              description: "The domain name e.g. example.com to lookup",
              type: "string"
            },
            privateZone: {
              description: "True if the zone you want to find is a private hosted zone",
              default: false,
              type: "boolean"
            },
            vpcId: {
              description: "The VPC ID to that the private zone must be associated with\n\nIf you provide VPC ID and privateZone is false, this will return no results\nand raise an error. (Default - Required if privateZone=true)",
              type: "string"
            },
            account: {
              description: "Query account",
              type: "string"
            },
            region: {
              description: "Query region",
              type: "string"
            },
            lookupRoleArn: {
              description: "The ARN of the role that should be used to look up the missing values (Default - None)",
              type: "string"
            },
            lookupRoleExternalId: {
              description: "The ExternalId that needs to be supplied while assuming this role (Default - No ExternalId will be supplied)",
              type: "string"
            },
            assumeRoleAdditionalOptions: {
              description: "Additional options to pass to STS when assuming the lookup role.\n\n- `RoleArn` should not be used. Use the dedicated `lookupRoleArn` property instead.\n- `ExternalId` should not be used. Use the dedicated `lookupRoleExternalId` instead. (Default - No additional options.)",
              type: "object",
              additionalProperties: {}
            }
          },
          required: [
            "account",
            "domainName",
            "region"
          ]
        },
        SSMParameterContextQuery: {
          description: "Query to SSM Parameter Context Provider",
          type: "object",
          properties: {
            parameterName: {
              description: "Parameter name to query",
              type: "string"
            },
            account: {
              description: "Query account",
              type: "string"
            },
            region: {
              description: "Query region",
              type: "string"
            },
            lookupRoleArn: {
              description: "The ARN of the role that should be used to look up the missing values (Default - None)",
              type: "string"
            },
            lookupRoleExternalId: {
              description: "The ExternalId that needs to be supplied while assuming this role (Default - No ExternalId will be supplied)",
              type: "string"
            },
            assumeRoleAdditionalOptions: {
              description: "Additional options to pass to STS when assuming the lookup role.\n\n- `RoleArn` should not be used. Use the dedicated `lookupRoleArn` property instead.\n- `ExternalId` should not be used. Use the dedicated `lookupRoleExternalId` instead. (Default - No additional options.)",
              type: "object",
              additionalProperties: {}
            }
          },
          required: [
            "account",
            "parameterName",
            "region"
          ]
        },
        VpcContextQuery: {
          description: "Query input for looking up a VPC",
          type: "object",
          properties: {
            filter: {
              description: "Filters to apply to the VPC\n\nFilter parameters are the same as passed to DescribeVpcs.",
              type: "object",
              additionalProperties: {
                type: "string"
              }
            },
            returnAsymmetricSubnets: {
              description: "Whether to populate the subnetGroups field of the `VpcContextResponse`,\nwhich contains potentially asymmetric subnet groups.",
              default: false,
              type: "boolean"
            },
            subnetGroupNameTag: {
              description: "Optional tag for subnet group name.\nIf not provided, we'll look at the aws-cdk:subnet-name tag.\nIf the subnet does not have the specified tag,\nwe'll use its type as the name. (Default 'aws-cdk:subnet-name')",
              type: "string"
            },
            returnVpnGateways: {
              description: "Whether to populate the `vpnGatewayId` field of the `VpcContextResponse`,\nwhich contains the VPN Gateway ID, if one exists. You can explicitly\ndisable this in order to avoid the lookup if you know the VPC does not have\na VPN Gatway attached. (Default true)",
              type: "boolean"
            },
            account: {
              description: "Query account",
              type: "string"
            },
            region: {
              description: "Query region",
              type: "string"
            },
            lookupRoleArn: {
              description: "The ARN of the role that should be used to look up the missing values (Default - None)",
              type: "string"
            },
            lookupRoleExternalId: {
              description: "The ExternalId that needs to be supplied while assuming this role (Default - No ExternalId will be supplied)",
              type: "string"
            },
            assumeRoleAdditionalOptions: {
              description: "Additional options to pass to STS when assuming the lookup role.\n\n- `RoleArn` should not be used. Use the dedicated `lookupRoleArn` property instead.\n- `ExternalId` should not be used. Use the dedicated `lookupRoleExternalId` instead. (Default - No additional options.)",
              type: "object",
              additionalProperties: {}
            }
          },
          required: [
            "account",
            "filter",
            "region"
          ]
        },
        EndpointServiceAvailabilityZonesContextQuery: {
          description: "Query to endpoint service context provider",
          type: "object",
          properties: {
            serviceName: {
              description: "Query service name",
              type: "string"
            },
            account: {
              description: "Query account",
              type: "string"
            },
            region: {
              description: "Query region",
              type: "string"
            },
            lookupRoleArn: {
              description: "The ARN of the role that should be used to look up the missing values (Default - None)",
              type: "string"
            },
            lookupRoleExternalId: {
              description: "The ExternalId that needs to be supplied while assuming this role (Default - No ExternalId will be supplied)",
              type: "string"
            },
            assumeRoleAdditionalOptions: {
              description: "Additional options to pass to STS when assuming the lookup role.\n\n- `RoleArn` should not be used. Use the dedicated `lookupRoleArn` property instead.\n- `ExternalId` should not be used. Use the dedicated `lookupRoleExternalId` instead. (Default - No additional options.)",
              type: "object",
              additionalProperties: {}
            }
          },
          required: [
            "account",
            "region",
            "serviceName"
          ]
        },
        LoadBalancerContextQuery: {
          description: "Query input for looking up a load balancer",
          type: "object",
          properties: {
            loadBalancerType: {
              $ref: "#/definitions/LoadBalancerType",
              description: "Filter load balancers by their type"
            },
            loadBalancerArn: {
              description: "Find by load balancer's ARN (Default - does not search by load balancer arn)",
              type: "string"
            },
            loadBalancerTags: {
              description: "Match load balancer tags (Default - does not match load balancers by tags)",
              type: "array",
              items: {
                $ref: "#/definitions/Tag"
              }
            },
            account: {
              description: "Query account",
              type: "string"
            },
            region: {
              description: "Query region",
              type: "string"
            },
            lookupRoleArn: {
              description: "The ARN of the role that should be used to look up the missing values (Default - None)",
              type: "string"
            },
            lookupRoleExternalId: {
              description: "The ExternalId that needs to be supplied while assuming this role (Default - No ExternalId will be supplied)",
              type: "string"
            },
            assumeRoleAdditionalOptions: {
              description: "Additional options to pass to STS when assuming the lookup role.\n\n- `RoleArn` should not be used. Use the dedicated `lookupRoleArn` property instead.\n- `ExternalId` should not be used. Use the dedicated `lookupRoleExternalId` instead. (Default - No additional options.)",
              type: "object",
              additionalProperties: {}
            }
          },
          required: [
            "account",
            "loadBalancerType",
            "region"
          ]
        },
        LoadBalancerType: {
          description: "Type of load balancer",
          type: "string",
          enum: [
            "network",
            "application"
          ]
        },
        LoadBalancerListenerContextQuery: {
          description: "Query input for looking up a load balancer listener",
          type: "object",
          properties: {
            listenerArn: {
              description: "Find by listener's arn (Default - does not find by listener arn)",
              type: "string"
            },
            listenerProtocol: {
              description: "Filter by listener protocol (Default - does not filter by listener protocol)",
              enum: [
                "HTTP",
                "HTTPS",
                "TCP",
                "TCP_UDP",
                "TLS",
                "UDP"
              ],
              type: "string"
            },
            listenerPort: {
              description: "Filter listeners by listener port (Default - does not filter by a listener port)",
              type: "number"
            },
            loadBalancerType: {
              $ref: "#/definitions/LoadBalancerType",
              description: "Filter load balancers by their type"
            },
            loadBalancerArn: {
              description: "Find by load balancer's ARN (Default - does not search by load balancer arn)",
              type: "string"
            },
            loadBalancerTags: {
              description: "Match load balancer tags (Default - does not match load balancers by tags)",
              type: "array",
              items: {
                $ref: "#/definitions/Tag"
              }
            },
            account: {
              description: "Query account",
              type: "string"
            },
            region: {
              description: "Query region",
              type: "string"
            },
            lookupRoleArn: {
              description: "The ARN of the role that should be used to look up the missing values (Default - None)",
              type: "string"
            },
            lookupRoleExternalId: {
              description: "The ExternalId that needs to be supplied while assuming this role (Default - No ExternalId will be supplied)",
              type: "string"
            },
            assumeRoleAdditionalOptions: {
              description: "Additional options to pass to STS when assuming the lookup role.\n\n- `RoleArn` should not be used. Use the dedicated `lookupRoleArn` property instead.\n- `ExternalId` should not be used. Use the dedicated `lookupRoleExternalId` instead. (Default - No additional options.)",
              type: "object",
              additionalProperties: {}
            }
          },
          required: [
            "account",
            "loadBalancerType",
            "region"
          ]
        },
        SecurityGroupContextQuery: {
          description: "Query input for looking up a security group",
          type: "object",
          properties: {
            securityGroupId: {
              description: "Security group id (Default - None)",
              type: "string"
            },
            securityGroupName: {
              description: "Security group name (Default - None)",
              type: "string"
            },
            vpcId: {
              description: "VPC ID (Default - None)",
              type: "string"
            },
            account: {
              description: "Query account",
              type: "string"
            },
            region: {
              description: "Query region",
              type: "string"
            },
            lookupRoleArn: {
              description: "The ARN of the role that should be used to look up the missing values (Default - None)",
              type: "string"
            },
            lookupRoleExternalId: {
              description: "The ExternalId that needs to be supplied while assuming this role (Default - No ExternalId will be supplied)",
              type: "string"
            },
            assumeRoleAdditionalOptions: {
              description: "Additional options to pass to STS when assuming the lookup role.\n\n- `RoleArn` should not be used. Use the dedicated `lookupRoleArn` property instead.\n- `ExternalId` should not be used. Use the dedicated `lookupRoleExternalId` instead. (Default - No additional options.)",
              type: "object",
              additionalProperties: {}
            }
          },
          required: [
            "account",
            "region"
          ]
        },
        KeyContextQuery: {
          description: "Query input for looking up a KMS Key",
          type: "object",
          properties: {
            aliasName: {
              description: "Alias name used to search the Key",
              type: "string"
            },
            account: {
              description: "Query account",
              type: "string"
            },
            region: {
              description: "Query region",
              type: "string"
            },
            lookupRoleArn: {
              description: "The ARN of the role that should be used to look up the missing values (Default - None)",
              type: "string"
            },
            lookupRoleExternalId: {
              description: "The ExternalId that needs to be supplied while assuming this role (Default - No ExternalId will be supplied)",
              type: "string"
            },
            assumeRoleAdditionalOptions: {
              description: "Additional options to pass to STS when assuming the lookup role.\n\n- `RoleArn` should not be used. Use the dedicated `lookupRoleArn` property instead.\n- `ExternalId` should not be used. Use the dedicated `lookupRoleExternalId` instead. (Default - No additional options.)",
              type: "object",
              additionalProperties: {}
            }
          },
          required: [
            "account",
            "aliasName",
            "region"
          ]
        },
        CcApiContextQuery: {
          description: "Query input for lookup up CloudFormation resources using CC API\n\nThe example below is required to successfully compile CDK (otherwise,\nthe CDK build will generate a synthetic example for the below, but it\ndoesn't have enough type information about the literal string union\nto generate a validly compiling example).",
          type: "object",
          properties: {
            typeName: {
              description: "The CloudFormation resource type.\nSee https://docs.aws.amazon.com/cloudcontrolapi/latest/userguide/supported-resources.html",
              type: "string"
            },
            exactIdentifier: {
              description: "Identifier of the resource to look up using `GetResource`.\n\nSpecifying exactIdentifier will return exactly one result, or throw an error\nunless `ignoreErrorOnMissingContext` is set. (Default - Either exactIdentifier or propertyMatch should be specified.)",
              type: "string"
            },
            resourceModel: {
              description: "The resource model to use to select the resources, using `ListResources`..\n\nThis is needed for sub-resources where the parent Arn is required.\n\nSee https://docs.aws.amazon.com/cloudcontrolapi/latest/userguide/resource-operations-list.html#resource-operations-list-containers (Default - no resource Model is provided)",
              $ref: "#/definitions/Record%3Cstring%2Cunknown%3E"
            },
            propertyMatch: {
              description: "Returns any resources matching these properties, using `ListResources`.\n\nBy default, specifying propertyMatch will successfully return 0 or more\nresults. To throw an error if the number of results is unexpected (and\nprevent the query results from being committed to context), specify\n`expectedMatchCount`.\n\n## Notes on property completeness\n\nCloudControl API's `ListResources` may return fewer properties than\n`GetResource` would, depending on the resource implementation.\n\nThe resources that `propertyMatch` matches against will *only ever* be the\nproperties returned by the `ListResources` call. (Default - Either exactIdentifier or propertyMatch should be specified.)",
              $ref: "#/definitions/Record%3Cstring%2Cunknown%3E"
            },
            propertiesToReturn: {
              description: "This is a set of properties returned from CC API that we want to return from ContextQuery.\n\nIf any properties listed here are absent from the target resource, an error will be thrown.\n\nThe returned object will always include the key `Identifier` with the CC-API returned\nfield `Identifier`.\n\n## Notes on property completeness\n\nCloudControl API's `ListResources` may return fewer properties than\n`GetResource` would, depending on the resource implementation.\n\nThe returned properties here are *currently* selected from the response\nobject that CloudControl API returns to the CDK CLI.\n\nHowever, if we find there is need to do so, we may decide to change this\nbehavior in the future: we might change it to perform an additional\n`GetResource` call for resources matched by `propertyMatch`.",
              type: "array",
              items: {
                type: "string"
              }
            },
            expectedMatchCount: {
              description: "Expected count of results if `propertyMatch` is specified.\n\nIf the expected result count does not match the actual count,\nby default an error is produced and the result is not committed to cached\ncontext, and the user can correct the situation and try again without\nhaving to manually clear out the context key using `cdk context --remove`\n\nIf the value of * `ignoreErrorOnMissingContext` is `true`, the value of\n`expectedMatchCount` is `at-least-one | exactly-one` and the number\nof found resources is 0, `dummyValue` is returned and committed to context\ninstead. (Default 'any')",
              enum: [
                "any",
                "at-least-one",
                "at-most-one",
                "exactly-one"
              ],
              type: "string"
            },
            dummyValue: {
              description: "The value to return if the resource was not found and `ignoreErrorOnMissingContext` is true.\n\nIf supplied, `dummyValue` should be an array of objects.\n\n`dummyValue` does not have to have elements, and it may have objects with\ndifferent properties than the properties in `propertiesToReturn`, but it\nwill be easiest for downstream code if the `dummyValue` conforms to\nthe expected response shape. (Default - No dummy value available)"
            },
            ignoreErrorOnMissingContext: {
              description: "Ignore an error and return the `dummyValue` instead if the resource was not found.\n\n- In case of an `exactIdentifier` lookup, return the `dummyValue` if the resource with\n  that identifier was not found.\n- In case of a `propertyMatch` lookup, return the `dummyValue` if `expectedMatchCount`\n  is `at-least-one | exactly-one` and the number of resources found was 0.\n\nif `ignoreErrorOnMissingContext` is set, `dummyValue` should be set and be an array.",
              default: false,
              type: "boolean"
            },
            account: {
              description: "Query account",
              type: "string"
            },
            region: {
              description: "Query region",
              type: "string"
            },
            lookupRoleArn: {
              description: "The ARN of the role that should be used to look up the missing values (Default - None)",
              type: "string"
            },
            lookupRoleExternalId: {
              description: "The ExternalId that needs to be supplied while assuming this role (Default - No ExternalId will be supplied)",
              type: "string"
            },
            assumeRoleAdditionalOptions: {
              description: "Additional options to pass to STS when assuming the lookup role.\n\n- `RoleArn` should not be used. Use the dedicated `lookupRoleArn` property instead.\n- `ExternalId` should not be used. Use the dedicated `lookupRoleExternalId` instead. (Default - No additional options.)",
              type: "object",
              additionalProperties: {}
            }
          },
          required: [
            "account",
            "propertiesToReturn",
            "region",
            "typeName"
          ]
        },
        "Record<string,unknown>": {
          type: "object"
        },
        PluginContextQuery: {
          description: "Query input for plugins\n\nThis alternate branch is necessary because it needs to be able to escape all type checking\nwe do on on the cloud assembly -- we cannot know the properties that will be used a priori.",
          type: "object",
          additionalProperties: {},
          properties: {
            pluginName: {
              description: "The name of the plugin",
              type: "string"
            }
          },
          required: [
            "pluginName"
          ]
        },
        RuntimeInfo: {
          description: "Information about the application's runtime components.",
          type: "object",
          properties: {
            libraries: {
              description: "The list of libraries loaded in the application, associated with their versions.",
              type: "object",
              additionalProperties: {
                type: "string"
              }
            }
          },
          required: [
            "libraries"
          ]
        }
      },
      $schema: "http://json-schema.org/draft-07/schema#"
    };
  }
});

// ../@aws-cdk/cloud-assembly-schema/schema/integ.schema.json
var require_integ_schema = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/schema/integ.schema.json"(exports2, module2) {
    module2.exports = {
      $ref: "#/definitions/IntegManifest",
      definitions: {
        IntegManifest: {
          description: "Definitions for the integration testing manifest",
          type: "object",
          properties: {
            version: {
              description: "Version of the manifest",
              type: "string"
            },
            enableLookups: {
              description: "Enable lookups for this test. If lookups are enabled\nthen `stackUpdateWorkflow` must be set to false.\nLookups should only be enabled when you are explicitly testing\nlookups.",
              default: false,
              type: "boolean"
            },
            synthContext: {
              description: "Additional context to use when performing\na synth. Any context provided here will override\nany default context (Default - no additional context)",
              type: "object",
              additionalProperties: {
                type: "string"
              }
            },
            testCases: {
              description: "test cases",
              type: "object",
              additionalProperties: {
                $ref: "#/definitions/TestCase"
              }
            }
          },
          required: [
            "testCases",
            "version"
          ]
        },
        TestCase: {
          description: "Represents an integration test case",
          type: "object",
          properties: {
            stacks: {
              description: "Stacks that should be tested as part of this test case\nThe stackNames will be passed as args to the cdk commands\nso dependent stacks will be automatically deployed unless\n`exclusively` is passed",
              type: "array",
              items: {
                type: "string"
              }
            },
            assertionStack: {
              description: "The node id of the stack that contains assertions.\nThis is the value that can be used to deploy the stack with the CDK CLI (Default - no assertion stack)",
              type: "string"
            },
            assertionStackName: {
              description: "The name of the stack that contains assertions (Default - no assertion stack)",
              type: "string"
            },
            stackUpdateWorkflow: {
              description: "Run update workflow on this test case\nThis should only be set to false to test scenarios\nthat are not possible to test as part of the update workflow (Default true)",
              type: "boolean"
            },
            cdkCommandOptions: {
              description: "Additional options to use for each CDK command (Default - runner default options)",
              $ref: "#/definitions/CdkCommands"
            },
            hooks: {
              description: "Additional commands to run at predefined points in the test workflow\n\ne.g. { postDeploy: ['yarn', 'test'] } (Default - no hooks)",
              $ref: "#/definitions/Hooks"
            },
            allowDeleteFailures: {
              description: "Whether to allow resources that fail to delete during a stack update.\n\nWhen false, the test will fail if CloudFormation skips deleting a resource\nduring a stack update. When true, only a warning is printed.",
              default: false,
              type: "boolean"
            },
            diffAssets: {
              description: "Whether or not to include asset hashes in the diff\nAsset hashes can introduces a lot of unneccessary noise into tests,\nbut there are some cases where asset hashes _should_ be included. For example\nany tests involving custom resources or bundling",
              default: false,
              type: "boolean"
            },
            allowDestroy: {
              description: "List of CloudFormation resource types in this stack that can\nbe destroyed as part of an update without failing the test.\n\nThis list should only include resources that for this specific\nintegration test we are sure will not cause errors or an outage if\ndestroyed. For example, maybe we know that a new resource will be created\nfirst before the old resource is destroyed which prevents any outage.\n\ne.g. ['AWS::IAM::Role'] (Default - do not allow destruction of any resources on update)",
              type: "array",
              items: {
                type: "string"
              }
            },
            regions: {
              description: "Limit deployment to these regions (Default - can run in any region)",
              type: "array",
              items: {
                type: "string"
              }
            }
          },
          required: [
            "stacks"
          ]
        },
        CdkCommands: {
          description: "Options for specific cdk commands that are run\nas part of the integration test workflow",
          type: "object",
          properties: {
            deploy: {
              description: "Options to for the cdk deploy command (Default - default deploy options)",
              $ref: "#/definitions/DeployCommand"
            },
            destroy: {
              description: "Options to for the cdk destroy command (Default - default destroy options)",
              $ref: "#/definitions/DestroyCommand"
            }
          }
        },
        DeployCommand: {
          description: "Represents a cdk deploy command",
          type: "object",
          properties: {
            args: {
              description: "Additional arguments to pass to the command\nThis can be used to test specific CLI functionality (Default - only default args are used)",
              $ref: "#/definitions/DeployOptions"
            },
            enabled: {
              description: "Whether or not to run this command as part of the workflow\nThis can be used if you only want to test some of the workflow\nfor example enable `synth` and disable `deploy` & `destroy` in order\nto limit the test to synthesis (Default true)",
              type: "boolean"
            },
            expectError: {
              description: "If the runner should expect this command to fail",
              default: false,
              type: "boolean"
            },
            expectedMessage: {
              description: "This can be used in combination with `expectedError`\nto validate that a specific message is returned. (Default - do not validate message)",
              type: "string"
            }
          }
        },
        DeployOptions: {
          description: "Options to use with cdk deploy",
          type: "object",
          properties: {
            exclusively: {
              description: "Only perform action on the given stack",
              default: false,
              type: "boolean"
            },
            toolkitStackName: {
              description: "Name of the toolkit stack to use/deploy (Default CDKToolkit)",
              type: "string"
            },
            reuseAssets: {
              description: "Reuse the assets with the given asset IDs (Default - do not reuse assets)",
              type: "array",
              items: {
                type: "string"
              }
            },
            changeSetName: {
              description: "Optional name to use for the CloudFormation change set.\nIf not provided, a name will be generated automatically. (Default - auto generate a name)",
              type: "string"
            },
            force: {
              description: "Always deploy, even if templates are identical.",
              default: false,
              type: "boolean"
            },
            rollback: {
              description: "Rollback failed deployments (Default true)",
              type: "boolean"
            },
            notificationArns: {
              description: "ARNs of SNS topics that CloudFormation will notify with stack related events (Default - no notifications)",
              type: "array",
              items: {
                type: "string"
              }
            },
            requireApproval: {
              description: "What kind of security changes require approval (Default RequireApproval.NEVER)",
              enum: [
                "any-change",
                "broadening",
                "never"
              ],
              type: "string"
            },
            execute: {
              description: "Whether to execute the ChangeSet\nNot providing `execute` parameter will result in execution of ChangeSet (Default true)",
              type: "boolean"
            },
            parameters: {
              description: "Additional parameters for CloudFormation at deploy time (Default [object Object])",
              type: "object",
              additionalProperties: {
                type: "string"
              }
            },
            usePreviousParameters: {
              description: "Use previous values for unspecified parameters\n\nIf not set, all parameters must be specified for every deployment. (Default true)",
              type: "boolean"
            },
            outputsFile: {
              description: "Path to file where stack outputs will be written after a successful deploy as JSON (Default - Outputs are not written to any file)",
              type: "string"
            },
            ci: {
              description: "Whether we are on a CI system",
              default: false,
              type: "boolean"
            },
            concurrency: {
              description: "Deploy multiple stacks in parallel (Default 1)",
              type: "number"
            },
            stacks: {
              description: "List of stacks to deploy\n\nRequried if `all` is not set (Default - [])",
              type: "array",
              items: {
                type: "string"
              }
            },
            all: {
              description: "Deploy all stacks\n\nRequried if `stacks` is not set (Default - false)",
              type: "boolean"
            },
            app: {
              description: 'command-line for executing your app or a cloud assembly directory\ne.g. "node bin/my-app.js"\nor\n"cdk.out" (Default - read from cdk.json)',
              type: "string"
            },
            roleArn: {
              description: "Role to pass to CloudFormation for deployment (Default - use the bootstrap cfn-exec role)",
              type: "string"
            },
            context: {
              description: "Additional context (Default - no additional context)",
              type: "object",
              additionalProperties: {
                type: "string"
              }
            },
            trace: {
              description: "Print trace for stack warnings",
              default: false,
              type: "boolean"
            },
            strict: {
              description: "Do not construct stacks with warnings",
              default: false,
              type: "boolean"
            },
            lookups: {
              description: "Perform context lookups.\n\nSynthesis fails if this is disabled and context lookups need\nto be performed (Default true)",
              type: "boolean"
            },
            ignoreErrors: {
              description: "Ignores synthesis errors, which will likely produce an invalid output",
              default: false,
              type: "boolean"
            },
            json: {
              description: "Use JSON output instead of YAML when templates are printed\nto STDOUT",
              default: false,
              type: "boolean"
            },
            verbose: {
              description: "show debug logs",
              default: false,
              type: "boolean"
            },
            debug: {
              description: "enable emission of additional debugging information, such as creation stack\ntraces of tokens",
              default: false,
              type: "boolean"
            },
            profile: {
              description: "Use the indicated AWS profile as the default environment (Default - no profile is used)",
              type: "string"
            },
            proxy: {
              description: "Use the indicated proxy. Will read from\nHTTPS_PROXY environment if specified (Default - no proxy)",
              type: "string"
            },
            caBundlePath: {
              description: "Path to CA certificate to use when validating HTTPS\nrequests. (Default - read from AWS_CA_BUNDLE environment variable)",
              type: "string"
            },
            ec2Creds: {
              description: "Force trying to fetch EC2 instance credentials (Default - guess EC2 instance status)",
              type: "boolean"
            },
            versionReporting: {
              description: 'Include "AWS::CDK::Metadata" resource in synthesized templates (Default true)',
              type: "boolean"
            },
            pathMetadata: {
              description: 'Include "aws:cdk:path" CloudFormation metadata for each resource (Default true)',
              type: "boolean"
            },
            assetMetadata: {
              description: 'Include "aws:asset:*" CloudFormation metadata for resources that use assets (Default true)',
              type: "boolean"
            },
            staging: {
              description: "Copy assets to the output directory\n\nNeeded for local debugging the source files with SAM CLI",
              default: false,
              type: "boolean"
            },
            output: {
              description: "Emits the synthesized cloud assembly into a directory (Default cdk.out)",
              type: "string"
            },
            notices: {
              description: "Show relevant notices (Default true)",
              type: "boolean"
            },
            color: {
              description: "Show colors and other style from console output (Default true)",
              type: "boolean"
            }
          }
        },
        DestroyCommand: {
          description: "Represents a cdk destroy command",
          type: "object",
          properties: {
            args: {
              description: "Additional arguments to pass to the command\nThis can be used to test specific CLI functionality (Default - only default args are used)",
              $ref: "#/definitions/DestroyOptions"
            },
            enabled: {
              description: "Whether or not to run this command as part of the workflow\nThis can be used if you only want to test some of the workflow\nfor example enable `synth` and disable `deploy` & `destroy` in order\nto limit the test to synthesis (Default true)",
              type: "boolean"
            },
            expectError: {
              description: "If the runner should expect this command to fail",
              default: false,
              type: "boolean"
            },
            expectedMessage: {
              description: "This can be used in combination with `expectedError`\nto validate that a specific message is returned. (Default - do not validate message)",
              type: "string"
            }
          }
        },
        DestroyOptions: {
          description: "Options to use with cdk destroy",
          type: "object",
          properties: {
            force: {
              description: "Do not ask for permission before destroying stacks",
              default: false,
              type: "boolean"
            },
            exclusively: {
              description: "Only destroy the given stack",
              default: false,
              type: "boolean"
            },
            stacks: {
              description: "List of stacks to deploy\n\nRequried if `all` is not set (Default - [])",
              type: "array",
              items: {
                type: "string"
              }
            },
            all: {
              description: "Deploy all stacks\n\nRequried if `stacks` is not set (Default - false)",
              type: "boolean"
            },
            app: {
              description: 'command-line for executing your app or a cloud assembly directory\ne.g. "node bin/my-app.js"\nor\n"cdk.out" (Default - read from cdk.json)',
              type: "string"
            },
            roleArn: {
              description: "Role to pass to CloudFormation for deployment (Default - use the bootstrap cfn-exec role)",
              type: "string"
            },
            context: {
              description: "Additional context (Default - no additional context)",
              type: "object",
              additionalProperties: {
                type: "string"
              }
            },
            trace: {
              description: "Print trace for stack warnings",
              default: false,
              type: "boolean"
            },
            strict: {
              description: "Do not construct stacks with warnings",
              default: false,
              type: "boolean"
            },
            lookups: {
              description: "Perform context lookups.\n\nSynthesis fails if this is disabled and context lookups need\nto be performed (Default true)",
              type: "boolean"
            },
            ignoreErrors: {
              description: "Ignores synthesis errors, which will likely produce an invalid output",
              default: false,
              type: "boolean"
            },
            json: {
              description: "Use JSON output instead of YAML when templates are printed\nto STDOUT",
              default: false,
              type: "boolean"
            },
            verbose: {
              description: "show debug logs",
              default: false,
              type: "boolean"
            },
            debug: {
              description: "enable emission of additional debugging information, such as creation stack\ntraces of tokens",
              default: false,
              type: "boolean"
            },
            profile: {
              description: "Use the indicated AWS profile as the default environment (Default - no profile is used)",
              type: "string"
            },
            proxy: {
              description: "Use the indicated proxy. Will read from\nHTTPS_PROXY environment if specified (Default - no proxy)",
              type: "string"
            },
            caBundlePath: {
              description: "Path to CA certificate to use when validating HTTPS\nrequests. (Default - read from AWS_CA_BUNDLE environment variable)",
              type: "string"
            },
            ec2Creds: {
              description: "Force trying to fetch EC2 instance credentials (Default - guess EC2 instance status)",
              type: "boolean"
            },
            versionReporting: {
              description: 'Include "AWS::CDK::Metadata" resource in synthesized templates (Default true)',
              type: "boolean"
            },
            pathMetadata: {
              description: 'Include "aws:cdk:path" CloudFormation metadata for each resource (Default true)',
              type: "boolean"
            },
            assetMetadata: {
              description: 'Include "aws:asset:*" CloudFormation metadata for resources that use assets (Default true)',
              type: "boolean"
            },
            staging: {
              description: "Copy assets to the output directory\n\nNeeded for local debugging the source files with SAM CLI",
              default: false,
              type: "boolean"
            },
            output: {
              description: "Emits the synthesized cloud assembly into a directory (Default cdk.out)",
              type: "string"
            },
            notices: {
              description: "Show relevant notices (Default true)",
              type: "boolean"
            },
            color: {
              description: "Show colors and other style from console output (Default true)",
              type: "boolean"
            }
          }
        },
        Hooks: {
          description: "Commands to run at predefined points during the\nintegration test workflow",
          type: "object",
          properties: {
            preDeploy: {
              description: "Commands to run prior to deploying the cdk stacks\nin the integration test (Default - no commands)",
              type: "array",
              items: {
                type: "string"
              }
            },
            postDeploy: {
              description: "Commands to run prior after deploying the cdk stacks\nin the integration test (Default - no commands)",
              type: "array",
              items: {
                type: "string"
              }
            },
            preDestroy: {
              description: "Commands to run prior to destroying the cdk stacks\nin the integration test (Default - no commands)",
              type: "array",
              items: {
                type: "string"
              }
            },
            postDestroy: {
              description: "Commands to run after destroying the cdk stacks\nin the integration test (Default - no commands)",
              type: "array",
              items: {
                type: "string"
              }
            }
          }
        }
      },
      $schema: "http://json-schema.org/draft-07/schema#"
    };
  }
});

// ../@aws-cdk/cloud-assembly-schema/schema/validation-report.schema.json
var require_validation_report_schema = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/schema/validation-report.schema.json"(exports2, module2) {
    module2.exports = {
      $ref: "#/definitions/PolicyValidationReportJson",
      definitions: {
        PolicyValidationReportJson: {
          description: "The top-level structure of the policy validation report file.",
          type: "object",
          properties: {
            version: {
              description: "Protocol version",
              type: "string"
            },
            title: {
              description: "Report title, if present.",
              type: "string"
            },
            pluginReports: {
              description: "Reports from all validation plugins that ran during synthesis.",
              type: "array",
              items: {
                $ref: "#/definitions/PluginReportJson"
              }
            }
          },
          required: ["version", "pluginReports"]
        },
        PluginReportJson: {
          description: "A report from a single validation plugin.",
          type: "object",
          properties: {
            pluginName: {
              description: "The name of the plugin that produced this report.",
              type: "string"
            },
            pluginVersion: {
              description: "Version of the plugin that produced this report.",
              type: "string"
            },
            conclusion: {
              description: "Whether the plugin's validation passed or failed.",
              $ref: "#/definitions/PolicyValidationReportConclusion"
            },
            metadata: {
              description: "Additional plugin-specific metadata.",
              type: "object",
              additionalProperties: {
                type: "string"
              }
            },
            violations: {
              description: "Violations found by this plugin.",
              type: "array",
              items: {
                $ref: "#/definitions/PolicyViolationJson"
              }
            },
            suppressedViolations: {
              description: "Violations that were suppressed via acknowledgement.",
              type: "array",
              items: {
                $ref: "#/definitions/SuppressedViolationJson"
              }
            }
          },
          required: ["pluginName", "conclusion", "violations"]
        },
        PolicyValidationReportConclusion: {
          description: "The final conclusion of a validation report.",
          type: "string",
          enum: ["success", "failure"]
        },
        PolicyViolationJson: {
          description: "A single policy violation found by a validation plugin.",
          type: "object",
          properties: {
            ruleName: {
              description: "The name of the rule that was violated.",
              type: "string"
            },
            description: {
              description: "A description of the violation.",
              type: "string"
            },
            suggestedFix: {
              description: "How to fix the violation.",
              type: "string"
            },
            severity: {
              description: "The severity of the violation.",
              $ref: "#/definitions/PolicyViolationSeverity"
            },
            customSeverity: {
              description: "If the plugin wants to report using a non-standard severity, put it here.",
              type: "string"
            },
            ruleMetadata: {
              description: "Additional rule-specific metadata.",
              type: "object",
              additionalProperties: {
                type: "string"
              }
            },
            violatingConstructs: {
              description: "Constructs that violated the rule.",
              type: "array",
              items: {
                $ref: "#/definitions/ViolatingConstructJson"
              }
            }
          },
          required: ["ruleName", "description", "severity", "violatingConstructs"]
        },
        PolicyViolationSeverity: {
          description: "The severity of a policy violation.",
          type: "string",
          enum: ["fatal", "error", "warning", "info", "custom"]
        },
        SuppressedViolationJson: {
          description: "A violation that was acknowledged/suppressed and excluded from the active violation set.",
          type: "object",
          properties: {
            ruleName: {
              description: "The name of the rule that was violated.",
              type: "string"
            },
            description: {
              description: "A description of the violation.",
              type: "string"
            },
            suggestedFix: {
              description: "How to fix the violation.",
              type: "string"
            },
            severity: {
              description: "The severity of the violation.",
              $ref: "#/definitions/PolicyViolationSeverity"
            },
            customSeverity: {
              description: "If the plugin wants to report using a non-standard severity, put it here.",
              type: "string"
            },
            ruleMetadata: {
              description: "Additional rule-specific metadata.",
              type: "object",
              additionalProperties: {
                type: "string"
              }
            },
            violatingConstructs: {
              description: "Constructs that violated the rule.",
              type: "array",
              items: {
                $ref: "#/definitions/ViolatingConstructJson"
              }
            },
            acknowledgedId: {
              description: "The acknowledgement ID that caused this violation to be suppressed.",
              type: "string"
            },
            reason: {
              description: "The reason given for the acknowledgement, if provided.",
              type: "string"
            },
            acknowledgedAt: {
              description: "The construct path where the acknowledgement was declared.",
              type: "string"
            },
            acknowledgedStackTrace: {
              description: "Stack trace showing where the acknowledgement was declared.",
              type: "string"
            }
          },
          required: ["ruleName", "description", "severity", "violatingConstructs", "acknowledgedId"]
        },
        ViolatingConstructJson: {
          description: "A construct that violated a policy rule.",
          type: "object",
          properties: {
            constructPath: {
              description: "The construct path as defined in the application.",
              type: "string"
            },
            constructFqn: {
              description: "The fully qualified name of the construct class (includes the library name).",
              type: "string"
            },
            libraryVersion: {
              description: "The version of the library that contains this construct.",
              type: "string"
            },
            cloudFormationResource: {
              description: "If this construct violation regards a CloudFormation resource, a reference to the resource details.",
              $ref: "#/definitions/CloudFormationResourceJson"
            },
            stackTraces: {
              description: "Stack traces associated with this violation.",
              type: "array",
              items: {
                type: "string"
              }
            }
          },
          required: ["constructPath"]
        },
        CloudFormationResourceJson: {
          description: "CloudFormation resource details for a violating construct.",
          type: "object",
          properties: {
            templatePath: {
              description: "The path to the CloudFormation template containing this resource.",
              type: "string"
            },
            logicalId: {
              description: "The logical ID of the resource in the CloudFormation template.",
              type: "string"
            },
            propertyPaths: {
              description: "Properties within the construct where the violation was detected.",
              type: "array",
              items: {
                type: "string"
              }
            }
          },
          required: ["templatePath", "logicalId"]
        }
      }
    };
  }
});

// ../@aws-cdk/cloud-assembly-schema/schema/version.json
var require_version = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/schema/version.json"(exports2, module2) {
    module2.exports = {
      schemaHash: "095859ad1d3d89d3bc4f9cbe9393d219798972dbd2389287bcc66b49f323cef1",
      $comment: "Do not hold back the version on additions: jsonschema validation of the manifest by the consumer will trigger errors on unexpected fields.",
      revision: 54
    };
  }
});

// ../@aws-cdk/cloud-assembly-schema/lib/manifest.ts
var manifest_exports = {};
__export(manifest_exports, {
  Manifest: () => Manifest,
  VERSION_MISMATCH: () => VERSION_MISMATCH
});
function stripEnumErrors(errors) {
  return errors.filter((e32) => typeof e32.schema === "string" || !("enum" in e32.schema));
}
var fs, jsonschema, semver, VERSION_MISMATCH, CLI_VERSION, ASSETS_SCHEMA, ASSEMBLY_SCHEMA, INTEG_SCHEMA, VALIDATION_REPORT_SCHEMA, SCHEMA_VERSION, Manifest;
var init_manifest = __esm({
  "../@aws-cdk/cloud-assembly-schema/lib/manifest.ts"() {
    "use strict";
    fs = __toESM(require("fs"));
    jsonschema = __toESM(require_lib());
    semver = __toESM(require_semver2());
    init_cloud_assembly();
    VERSION_MISMATCH = "Cloud assembly schema version mismatch";
    CLI_VERSION = require_cli_version();
    ASSETS_SCHEMA = require_assets_schema();
    ASSEMBLY_SCHEMA = require_cloud_assembly_schema();
    INTEG_SCHEMA = require_integ_schema();
    VALIDATION_REPORT_SCHEMA = require_validation_report_schema();
    SCHEMA_VERSION = require_version();
    Manifest = class _Manifest {
      static {
        __name(this, "Manifest");
      }
      /**
       * Validates and saves the cloud assembly manifest to file.
       *
       * @param manifest - manifest.
       * @param filePath - output file path.
       */
      static saveAssemblyManifest(manifest, filePath) {
        _Manifest.saveManifest(manifest, filePath, ASSEMBLY_SCHEMA);
      }
      /**
       * Load and validates the cloud assembly manifest from file.
       *
       * @param filePath - path to the manifest file.
       */
      static loadAssemblyManifest(filePath, options) {
        return _Manifest.loadManifest(filePath, ASSEMBLY_SCHEMA, _Manifest.patchStackTagsOnRead, options);
      }
      /**
       * Validates and saves the asset manifest to file.
       *
       * @param manifest - manifest.
       * @param filePath - output file path.
       */
      static saveAssetManifest(manifest, filePath) {
        _Manifest.saveManifest(manifest, filePath, ASSETS_SCHEMA);
      }
      /**
       * Load and validates the asset manifest from file.
       *
       * @param filePath - path to the manifest file.
       */
      static loadAssetManifest(filePath) {
        return _Manifest.loadManifest(filePath, ASSETS_SCHEMA);
      }
      /**
       * Validates and saves the integ manifest to file.
       *
       * @param manifest - manifest.
       * @param filePath - output file path.
       */
      static saveIntegManifest(manifest, filePath) {
        _Manifest.saveManifest(manifest, filePath, INTEG_SCHEMA);
      }
      /**
       * Load and validates the integ manifest from file.
       *
       * @param filePath - path to the manifest file.
       */
      static loadIntegManifest(filePath) {
        const manifest = this.loadManifest(filePath, INTEG_SCHEMA);
        return {
          ...manifest,
          testCases: manifest.testCases ?? []
        };
      }
      /**
       * Load and validate the policy validation report from file.
       *
       * @param filePath - path to the validation report file.
       */
      static loadValidationReport(filePath) {
        return _Manifest.loadManifest(filePath, VALIDATION_REPORT_SCHEMA);
      }
      /**
       * Fetch the current schema version number.
       */
      static version() {
        return `${SCHEMA_VERSION.revision}.0.0`;
      }
      /**
       * Return the CLI version that supports this Cloud Assembly Schema version
       */
      static cliVersion() {
        const version = CLI_VERSION.version;
        return version ? version : void 0;
      }
      /**
       * Deprecated
       * @deprecated use `saveAssemblyManifest()`
       */
      static save(manifest, filePath) {
        return this.saveAssemblyManifest(manifest, filePath);
      }
      /**
       * Deprecated
       * @deprecated use `loadAssemblyManifest()`
       */
      static load(filePath) {
        return this.loadAssemblyManifest(filePath);
      }
      static validate(manifest, schema, options) {
        function parseVersion(version) {
          const ver = semver.valid(version);
          if (!ver) {
            throw new Error(`Invalid semver string: "${version}"`);
          }
          return ver;
        }
        __name(parseVersion, "parseVersion");
        const maxSupported = semver.major(parseVersion(_Manifest.version()));
        const actual = parseVersion(manifest.version);
        if (maxSupported < semver.major(actual) && !options?.skipVersionCheck) {
          const cliVersion2 = manifest.minimumCliVersion;
          let cliWarning = "";
          if (cliVersion2) {
            cliWarning = `. You need at least CLI version ${cliVersion2} to read this manifest.`;
          }
          throw new Error(
            `${VERSION_MISMATCH}: Maximum schema version supported is ${maxSupported}.x.x, but found ${actual}${cliWarning}`
          );
        }
        if (options?.validateSchema ?? process.env.TESTING_CDK === "1") {
          const validator = new jsonschema.Validator();
          const result2 = validator.validate(manifest, schema, {
            nestedErrors: true,
            allowUnknownAttributes: false,
            preValidateProperty: _Manifest.validateAssumeRoleAdditionalOptions
          });
          let errors = result2.errors;
          if (options?.skipEnumCheck) {
            errors = stripEnumErrors(errors);
          }
          if (errors.length > 0) {
            throw new Error(`Invalid assembly manifest:
${errors.map((e32) => e32.stack).join("\n")}`);
          }
        }
      }
      static saveManifest(manifest, filePath, schema, preprocess) {
        let withVersion = {
          ...manifest,
          version: _Manifest.version(),
          minimumCliVersion: _Manifest.cliVersion()
        };
        _Manifest.validate(withVersion, schema);
        if (preprocess) {
          withVersion = preprocess(withVersion);
        }
        fs.writeFileSync(filePath, JSON.stringify(withVersion, void 0, 2));
      }
      static loadManifest(filePath, schema, preprocess, options) {
        const contents = fs.readFileSync(filePath, { encoding: "utf-8" });
        let obj;
        try {
          obj = JSON.parse(contents);
        } catch (e32) {
          throw new Error(`${e32.message}, while parsing ${JSON.stringify(contents)}`);
        }
        if (preprocess) {
          obj = preprocess(obj);
        }
        _Manifest.validate(obj, schema, options);
        return obj;
      }
      /**
       * Fix the casing of stack tags entries
       *
       * At the very beginning of the CDK we used to emit stack tags as an object with
       * `{ Key, Value }` keys; this had the "advantage" that we could stick those
       * tags directly into the `CreateChangeSet` call.
       *
       * Then we later on used jsii on the assembly schema and we were forced to type
       * the in-memory objects as `{ key, value }` with lowercase letters. Now the
       * objects have a different on-disk and in-memory format, and we need to convert
       * between them.
       *
       * For backwards compatibility reasons, we used to convert lowercase in-memory
       * to uppercase on-disk variant until very recently. This is now unnecessary,
       * since no officially supported CDK tools read the stack tags from the
       * metadata; the CLI and toolkit library read stack tags from the artifact
       * properties.
       *
       * So although we don't emit uppercase stack tag objects anymore, we might still read
       * manifests that have them. Because the manifest we read must pass JSON Schema
       * validation (which expects lowercase tag objects), we have to fix the casing
       * of these objects after reading from disk and before validating.
       *
       * That's what this function does.
       */
      static patchStackTagsOnRead(manifest) {
        const artifacts = Object.values(manifest.artifacts ?? {}).filter((artifact) => artifact.type === "aws:cloudformation:stack" /* AWS_CLOUDFORMATION_STACK */);
        for (const artifact of artifacts) {
          const tagMetadata = Object.values(artifact.metadata ?? {}).flatMap((x) => x).filter((entry) => entry.type === "aws:cdk:stack-tags" /* STACK_TAGS */);
          for (const entry of tagMetadata) {
            const tags = entry.data;
            for (const tag3 of tags ?? []) {
              const t = tag3;
              if ("Key" in t) {
                t.key = t.Key;
                delete t.Key;
              }
              if ("Value" in t) {
                t.value = t.Value;
                delete t.Value;
              }
            }
          }
        }
        return manifest;
      }
      /**
       * Validates that `assumeRoleAdditionalOptions` doesn't contain nor `ExternalId` neither `RoleArn`, as they
       * should have dedicated properties preceding this (e.g `assumeRoleArn` and `assumeRoleExternalId`).
       */
      static validateAssumeRoleAdditionalOptions(instance, key, _schema, _options, _ctx) {
        if (key !== "assumeRoleAdditionalOptions") {
          return;
        }
        const assumeRoleOptions = instance[key];
        if (assumeRoleOptions?.RoleArn) {
          throw new Error(`RoleArn is not allowed inside '${key}'`);
        }
        if (assumeRoleOptions?.ExternalId) {
          throw new Error(`ExternalId is not allowed inside '${key}'`);
        }
      }
    };
    __name(stripEnumErrors, "stripEnumErrors");
  }
});

// ../@aws-cdk/cloud-assembly-schema/lib/integ-tests/schema.ts
var init_schema3 = __esm({
  "../@aws-cdk/cloud-assembly-schema/lib/integ-tests/schema.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/cloud-assembly-schema/lib/integ-tests/commands/common.ts
var RequireApproval;
var init_common = __esm({
  "../@aws-cdk/cloud-assembly-schema/lib/integ-tests/commands/common.ts"() {
    "use strict";
    RequireApproval = /* @__PURE__ */ ((RequireApproval4) => {
      RequireApproval4["NEVER"] = "never";
      RequireApproval4["ANYCHANGE"] = "any-change";
      RequireApproval4["BROADENING"] = "broadening";
      return RequireApproval4;
    })(RequireApproval || {});
  }
});

// ../@aws-cdk/cloud-assembly-schema/lib/integ-tests/commands/deploy.ts
var init_deploy = __esm({
  "../@aws-cdk/cloud-assembly-schema/lib/integ-tests/commands/deploy.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/cloud-assembly-schema/lib/integ-tests/commands/destroy.ts
var init_destroy = __esm({
  "../@aws-cdk/cloud-assembly-schema/lib/integ-tests/commands/destroy.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/cloud-assembly-schema/lib/integ-tests/commands/index.ts
var init_commands = __esm({
  "../@aws-cdk/cloud-assembly-schema/lib/integ-tests/commands/index.ts"() {
    "use strict";
    init_common();
    init_deploy();
    init_destroy();
  }
});

// ../@aws-cdk/cloud-assembly-schema/lib/integ-tests/test-case.ts
var init_test_case = __esm({
  "../@aws-cdk/cloud-assembly-schema/lib/integ-tests/test-case.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/cloud-assembly-schema/lib/integ-tests/index.ts
var integ_tests_exports = {};
__export(integ_tests_exports, {
  RequireApproval: () => RequireApproval
});
var init_integ_tests = __esm({
  "../@aws-cdk/cloud-assembly-schema/lib/integ-tests/index.ts"() {
    "use strict";
    init_schema3();
    init_commands();
    init_test_case();
  }
});

// ../@aws-cdk/cloud-assembly-schema/lib/index.js
var require_lib2 = __commonJS({
  "../@aws-cdk/cloud-assembly-schema/lib/index.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __exportStar3 = exports2 && exports2.__exportStar || function(m20, exports3) {
      for (var p10 in m20) if (p10 !== "default" && !Object.prototype.hasOwnProperty.call(exports3, p10)) __createBinding3(exports3, m20, p10);
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    __exportStar3((init_cloud_assembly(), __toCommonJS(cloud_assembly_exports)), exports2);
    __exportStar3((init_assets(), __toCommonJS(assets_exports)), exports2);
    __exportStar3((init_manifest(), __toCommonJS(manifest_exports)), exports2);
    __exportStar3((init_integ_tests(), __toCommonJS(integ_tests_exports)), exports2);
  }
});

// ../@aws-cdk/cloud-assembly-api/lib/metadata.ts
var metadata_exports = {};
__export(metadata_exports, {
  PATH_METADATA_KEY: () => PATH_METADATA_KEY,
  SynthesisMessageLevel: () => SynthesisMessageLevel
});
var PATH_METADATA_KEY, SynthesisMessageLevel;
var init_metadata = __esm({
  "../@aws-cdk/cloud-assembly-api/lib/metadata.ts"() {
    "use strict";
    PATH_METADATA_KEY = "aws:cdk:path";
    SynthesisMessageLevel = /* @__PURE__ */ ((SynthesisMessageLevel5) => {
      SynthesisMessageLevel5["INFO"] = "info";
      SynthesisMessageLevel5["WARNING"] = "warning";
      SynthesisMessageLevel5["ERROR"] = "error";
      return SynthesisMessageLevel5;
    })(SynthesisMessageLevel || {});
  }
});

// ../@aws-cdk/cloud-assembly-api/lib/private/error.ts
var ASSEMBLY_ERROR_SYMBOL, CloudAssemblyError;
var init_error = __esm({
  "../@aws-cdk/cloud-assembly-api/lib/private/error.ts"() {
    "use strict";
    ASSEMBLY_ERROR_SYMBOL = /* @__PURE__ */ Symbol.for("@aws-cdk/cx-api.CloudAssemblyError");
    CloudAssemblyError = class _CloudAssemblyError extends Error {
      static {
        __name(this, "CloudAssemblyError");
      }
      #time;
      /**
       * The time the error was thrown.
       */
      get time() {
        return this.#time;
      }
      get type() {
        return "assembly";
      }
      constructor(msg) {
        super(msg);
        Object.setPrototypeOf(this, _CloudAssemblyError.prototype);
        Object.defineProperty(this, ASSEMBLY_ERROR_SYMBOL, { value: true });
        this.name = new.target.name;
        this.#time = (/* @__PURE__ */ new Date()).toISOString();
      }
    };
  }
});

// ../@aws-cdk/cloud-assembly-api/lib/cloud-artifact.ts
var cloud_artifact_exports = {};
__export(cloud_artifact_exports, {
  CloudArtifact: () => CloudArtifact
});
var fs2, path, cxschema, CloudArtifact;
var init_cloud_artifact = __esm({
  "../@aws-cdk/cloud-assembly-api/lib/cloud-artifact.ts"() {
    "use strict";
    fs2 = __toESM(require("fs"));
    path = __toESM(require("path"));
    cxschema = __toESM(require_lib2());
    init_metadata();
    init_error();
    CloudArtifact = class _CloudArtifact {
      constructor(assembly, id, manifest) {
        this.assembly = assembly;
        this.id = id;
        this.manifest = manifest;
        this.messages = this.renderMessages();
        this._dependencyIDs = manifest.dependencies || [];
      }
      static {
        __name(this, "CloudArtifact");
      }
      /**
       * Read the metadata for the given artifact
       *
       * HISTORICAL OR PRIVATE USE ONLY
       *
       * This is publicly exposed as a static function for downstream libraries that
       * don't use the `CloudAssembly`/`CloudArtifact` API, yet still need to read
       * an artifact's metadata.
       *
       * 99% of consumers should just access `artifact.metadata`.
       */
      static readMetadata(assemblyDirectory, x) {
        const ret = {};
        if (x.additionalMetadataFile) {
          Object.assign(ret, JSON.parse(fs2.readFileSync(path.join(assemblyDirectory, x.additionalMetadataFile), "utf-8")));
        }
        for (const [p10, entries] of Object.entries(x.metadata ?? {})) {
          if (ret[p10]) {
            ret[p10].push(...entries);
          } else {
            ret[p10] = entries;
          }
        }
        return ret;
      }
      /**
       * Returns a subclass of `CloudArtifact` based on the artifact type defined in the artifact manifest.
       *
       * @param assembly - The cloud assembly from which to load the artifact
       * @param id - The artifact ID
       * @param artifact - The artifact manifest
       * @returns the `CloudArtifact` that matches the artifact type or `undefined` if it's an artifact type that is unrecognized by this module.
       */
      static fromManifest(assembly, id, artifact) {
        void assembly, void id, void artifact;
        throw new CloudAssemblyError("Implementation not overridden yet");
      }
      /**
       * Returns the metadata associated with this Cloud Artifact
       */
      get metadata() {
        return _CloudArtifact.readMetadata(this.assembly.directory, this.manifest);
      }
      /**
       * Returns all the artifacts that this artifact depends on.
       */
      get dependencies() {
        if (this._deps) {
          return this._deps;
        }
        this._deps = this._dependencyIDs.map((id) => {
          const dep = this.assembly.tryGetArtifact(id);
          if (!dep) {
            throw new CloudAssemblyError(`Artifact ${this.id} depends on non-existing artifact ${id}`);
          }
          return dep;
        });
        return this._deps;
      }
      /**
       * @returns all the metadata entries of a specific type in this artifact.
       */
      findMetadataByType(type) {
        const metadata = this.metadata;
        const result2 = new Array();
        for (const p10 of Object.keys(metadata || {})) {
          for (const entry of (metadata || {})[p10]) {
            if (entry.type === type) {
              result2.push({ path: p10, ...entry });
            }
          }
        }
        return result2;
      }
      renderMessages() {
        const messages = new Array();
        for (const [id, metadata] of Object.entries(this.metadata || {})) {
          for (const entry of metadata) {
            let level;
            switch (entry.type) {
              case cxschema.ArtifactMetadataEntryType.WARN:
                level = "warning" /* WARNING */;
                break;
              case cxschema.ArtifactMetadataEntryType.ERROR:
                level = "error" /* ERROR */;
                break;
              case cxschema.ArtifactMetadataEntryType.INFO:
                level = "info" /* INFO */;
                break;
              default:
                continue;
            }
            messages.push({ level, entry, id });
          }
        }
        return messages;
      }
      /**
       * An identifier that shows where this artifact is located in the tree
       * of nested assemblies, based on their manifests. Defaults to the normal
       * id. Should only be used in user interfaces.
       */
      get hierarchicalId() {
        return this.manifest.displayName ?? this.id;
      }
    };
  }
});

// ../@aws-cdk/cloud-assembly-api/lib/artifacts/asset-manifest-artifact.ts
var asset_manifest_artifact_exports = {};
__export(asset_manifest_artifact_exports, {
  AssetManifestArtifact: () => AssetManifestArtifact
});
var fs3, path2, ASSET_MANIFEST_ARTIFACT_SYM, AssetManifestArtifact;
var init_asset_manifest_artifact = __esm({
  "../@aws-cdk/cloud-assembly-api/lib/artifacts/asset-manifest-artifact.ts"() {
    "use strict";
    fs3 = __toESM(require("fs"));
    path2 = __toESM(require("path"));
    init_cloud_artifact();
    init_error();
    ASSET_MANIFEST_ARTIFACT_SYM = /* @__PURE__ */ Symbol.for("@aws-cdk/cx-api.AssetManifestArtifact");
    AssetManifestArtifact = class extends CloudArtifact {
      static {
        __name(this, "AssetManifestArtifact");
      }
      /**
       * Checks if `art` is an instance of this class.
       *
       * Use this method instead of `instanceof` to properly detect `AssetManifestArtifact`
       * instances, even when the construct library is symlinked.
       *
       * Explanation: in JavaScript, multiple copies of the `cx-api` library on
       * disk are seen as independent, completely different libraries. As a
       * consequence, the class `AssetManifestArtifact` in each copy of the `cx-api` library
       * is seen as a different class, and an instance of one class will not test as
       * `instanceof` the other class. `npm install` will not create installations
       * like this, but users may manually symlink construct libraries together or
       * use a monorepo tool: in those cases, multiple copies of the `cx-api`
       * library can be accidentally installed, and `instanceof` will behave
       * unpredictably. It is safest to avoid using `instanceof`, and using
       * this type-testing method instead.
       */
      static isAssetManifestArtifact(art) {
        return art && typeof art === "object" && art[ASSET_MANIFEST_ARTIFACT_SYM];
      }
      constructor(assembly, name, artifact) {
        super(assembly, name, artifact);
        const properties = this.manifest.properties || {};
        if (!properties.file) {
          throw new CloudAssemblyError('Invalid AssetManifestArtifact. Missing "file" property');
        }
        this.file = path2.resolve(this.assembly.directory, properties.file);
        this.requiresBootstrapStackVersion = properties.requiresBootstrapStackVersion;
        this.bootstrapStackVersionSsmParameter = properties.bootstrapStackVersionSsmParameter;
      }
      /**
       * The Asset Manifest contents
       */
      get contents() {
        if (this._contents !== void 0) {
          return this._contents;
        }
        const contents = this._contents = JSON.parse(fs3.readFileSync(this.file, "utf-8"));
        return contents;
      }
    };
    Object.defineProperty(AssetManifestArtifact.prototype, ASSET_MANIFEST_ARTIFACT_SYM, {
      value: true,
      enumerable: false,
      writable: false
    });
  }
});

// ../@aws-cdk/cloud-assembly-api/lib/environment.ts
var environment_exports = {};
__export(environment_exports, {
  EnvironmentUtils: () => EnvironmentUtils,
  UNKNOWN_ACCOUNT: () => UNKNOWN_ACCOUNT,
  UNKNOWN_REGION: () => UNKNOWN_REGION
});
var AWS_ENV_REGEX, UNKNOWN_ACCOUNT, UNKNOWN_REGION, EnvironmentUtils;
var init_environment = __esm({
  "../@aws-cdk/cloud-assembly-api/lib/environment.ts"() {
    "use strict";
    init_error();
    AWS_ENV_REGEX = /aws\:\/\/([a-z0-9A-Z\-\@\.\_]+)\/([a-z\-0-9]+)/;
    UNKNOWN_ACCOUNT = "unknown-account";
    UNKNOWN_REGION = "unknown-region";
    EnvironmentUtils = class {
      static {
        __name(this, "EnvironmentUtils");
      }
      static parse(environment) {
        const env3 = AWS_ENV_REGEX.exec(environment);
        if (!env3) {
          throw new CloudAssemblyError(
            `Unable to parse environment specification "${environment}". Expected format: aws://account/region`
          );
        }
        const [, account, region] = env3;
        if (!account || !region) {
          throw new CloudAssemblyError(`Invalid environment specification: ${environment}`);
        }
        return { account, region, name: environment };
      }
      /**
       * Build an environment object from an account and region
       */
      static make(account, region) {
        return { account, region, name: this.format(account, region) };
      }
      /**
       * Format an environment string from an account and region
       */
      static format(account, region) {
        return `aws://${account}/${region}`;
      }
    };
  }
});

// ../@aws-cdk/cloud-assembly-api/lib/artifacts/cloudformation-artifact.ts
var cloudformation_artifact_exports = {};
__export(cloudformation_artifact_exports, {
  CloudFormationStackArtifact: () => CloudFormationStackArtifact
});
var fs4, path3, cxschema2, CLOUDFORMATION_STACK_ARTIFACT_SYM, CloudFormationStackArtifact;
var init_cloudformation_artifact = __esm({
  "../@aws-cdk/cloud-assembly-api/lib/artifacts/cloudformation-artifact.ts"() {
    "use strict";
    fs4 = __toESM(require("fs"));
    path3 = __toESM(require("path"));
    cxschema2 = __toESM(require_lib2());
    init_cloud_artifact();
    init_environment();
    init_error();
    CLOUDFORMATION_STACK_ARTIFACT_SYM = /* @__PURE__ */ Symbol.for("@aws-cdk/cx-api.CloudFormationStackArtifact");
    CloudFormationStackArtifact = class extends CloudArtifact {
      static {
        __name(this, "CloudFormationStackArtifact");
      }
      /**
       * Checks if `art` is an instance of this class.
       *
       * Use this method instead of `instanceof` to properly detect `CloudFormationStackArtifact`
       * instances, even when the construct library is symlinked.
       *
       * Explanation: in JavaScript, multiple copies of the `cx-api` library on
       * disk are seen as independent, completely different libraries. As a
       * consequence, the class `CloudFormationStackArtifact` in each copy of the `cx-api` library
       * is seen as a different class, and an instance of one class will not test as
       * `instanceof` the other class. `npm install` will not create installations
       * like this, but users may manually symlink construct libraries together or
       * use a monorepo tool: in those cases, multiple copies of the `cx-api`
       * library can be accidentally installed, and `instanceof` will behave
       * unpredictably. It is safest to avoid using `instanceof`, and using
       * this type-testing method instead.
       */
      static isCloudFormationStackArtifact(art) {
        return art && typeof art === "object" && CLOUDFORMATION_STACK_ARTIFACT_SYM in art;
      }
      constructor(assembly, artifactId, artifact) {
        super(assembly, artifactId, artifact);
        const properties = this.manifest.properties || {};
        if (!properties.templateFile) {
          throw new CloudAssemblyError('Invalid CloudFormation stack artifact. Missing "templateFile" property in cloud assembly manifest');
        }
        if (!artifact.environment) {
          throw new CloudAssemblyError("Invalid CloudFormation stack artifact. Missing environment");
        }
        this.environment = EnvironmentUtils.parse(artifact.environment);
        this.templateFile = properties.templateFile;
        this.parameters = properties.parameters ?? {};
        this.tags = properties.tags ?? {};
        this.notificationArns = properties.notificationArns;
        this.assumeRoleArn = properties.assumeRoleArn;
        this.assumeRoleExternalId = properties.assumeRoleExternalId;
        this.assumeRoleAdditionalOptions = properties.assumeRoleAdditionalOptions;
        this.cloudFormationExecutionRoleArn = properties.cloudFormationExecutionRoleArn;
        this.stackTemplateAssetObjectUrl = properties.stackTemplateAssetObjectUrl;
        this.requiresBootstrapStackVersion = properties.requiresBootstrapStackVersion;
        this.bootstrapStackVersionSsmParameter = properties.bootstrapStackVersionSsmParameter;
        this.terminationProtection = properties.terminationProtection;
        this.validateOnSynth = properties.validateOnSynth;
        this.lookupRole = properties.lookupRole;
        this.stackName = properties.stackName || artifactId;
        this.assets = this.findMetadataByType(cxschema2.ArtifactMetadataEntryType.ASSET).map((e32) => e32.data);
        this.displayName = this.stackName === artifactId ? this.hierarchicalId : `${this.hierarchicalId} (${this.stackName})`;
        this.name = this.stackName;
        this.originalName = this.stackName;
      }
      /**
       * Full path to the template file
       */
      get templateFullPath() {
        return path3.join(this.assembly.directory, this.templateFile);
      }
      /**
       * The CloudFormation template for this stack.
       */
      get template() {
        if (this._template === void 0) {
          this._template = JSON.parse(fs4.readFileSync(this.templateFullPath, "utf-8"));
        }
        return this._template;
      }
    };
    Object.defineProperty(CloudFormationStackArtifact.prototype, CLOUDFORMATION_STACK_ARTIFACT_SYM, {
      value: true,
      enumerable: false,
      writable: false
    });
  }
});

// ../@aws-cdk/cloud-assembly-api/lib/artifacts/nested-cloud-assembly-artifact.ts
var nested_cloud_assembly_artifact_exports = {};
__export(nested_cloud_assembly_artifact_exports, {
  NestedCloudAssemblyArtifact: () => NestedCloudAssemblyArtifact
});
var path4, NESTED_CLOUD_ASSEMBLY_SYM, NestedCloudAssemblyArtifact;
var init_nested_cloud_assembly_artifact = __esm({
  "../@aws-cdk/cloud-assembly-api/lib/artifacts/nested-cloud-assembly-artifact.ts"() {
    "use strict";
    path4 = __toESM(require("path"));
    init_cloud_artifact();
    NESTED_CLOUD_ASSEMBLY_SYM = /* @__PURE__ */ Symbol.for("@aws-cdk/cx-api.NestedCloudAssemblyArtifact");
    NestedCloudAssemblyArtifact = class extends CloudArtifact {
      static {
        __name(this, "NestedCloudAssemblyArtifact");
      }
      /**
       * Checks if `art` is an instance of this class.
       *
       * Use this method instead of `instanceof` to properly detect `NestedCloudAssemblyArtifact`
       * instances, even when the construct library is symlinked.
       *
       * Explanation: in JavaScript, multiple copies of the `cx-api` library on
       * disk are seen as independent, completely different libraries. As a
       * consequence, the class `NestedCloudAssemblyArtifact` in each copy of the `cx-api` library
       * is seen as a different class, and an instance of one class will not test as
       * `instanceof` the other class. `npm install` will not create installations
       * like this, but users may manually symlink construct libraries together or
       * use a monorepo tool: in those cases, multiple copies of the `cx-api`
       * library can be accidentally installed, and `instanceof` will behave
       * unpredictably. It is safest to avoid using `instanceof`, and using
       * this type-testing method instead.
       */
      static isNestedCloudAssemblyArtifact(art) {
        return art && typeof art === "object" && NESTED_CLOUD_ASSEMBLY_SYM in art;
      }
      constructor(assembly, name, artifact) {
        super(assembly, name, artifact);
        const properties = this.manifest.properties || {};
        this.directoryName = properties.directoryName;
        this.displayName = properties.displayName ?? name;
      }
      /**
       * Full path to the nested assembly directory
       */
      get fullPath() {
        return path4.join(this.assembly.directory, this.directoryName);
      }
    };
    Object.defineProperty(NestedCloudAssemblyArtifact.prototype, NESTED_CLOUD_ASSEMBLY_SYM, {
      value: true,
      enumerable: false,
      writable: false
    });
  }
});

// ../@aws-cdk/cloud-assembly-api/lib/artifacts/tree-cloud-artifact.ts
var tree_cloud_artifact_exports = {};
__export(tree_cloud_artifact_exports, {
  TreeCloudArtifact: () => TreeCloudArtifact
});
var TREE_CLOUD_ARTIFACT_SYM, TreeCloudArtifact;
var init_tree_cloud_artifact = __esm({
  "../@aws-cdk/cloud-assembly-api/lib/artifacts/tree-cloud-artifact.ts"() {
    "use strict";
    init_cloud_artifact();
    init_error();
    TREE_CLOUD_ARTIFACT_SYM = /* @__PURE__ */ Symbol.for("@aws-cdk/cx-api.TreeCloudArtifact");
    TreeCloudArtifact = class extends CloudArtifact {
      static {
        __name(this, "TreeCloudArtifact");
      }
      /**
       * Checks if `art` is an instance of this class.
       *
       * Use this method instead of `instanceof` to properly detect `TreeCloudArtifact`
       * instances, even when the construct library is symlinked.
       *
       * Explanation: in JavaScript, multiple copies of the `cx-api` library on
       * disk are seen as independent, completely different libraries. As a
       * consequence, the class `TreeCloudArtifact` in each copy of the `cx-api` library
       * is seen as a different class, and an instance of one class will not test as
       * `instanceof` the other class. `npm install` will not create installations
       * like this, but users may manually symlink construct libraries together or
       * use a monorepo tool: in those cases, multiple copies of the `cx-api`
       * library can be accidentally installed, and `instanceof` will behave
       * unpredictably. It is safest to avoid using `instanceof`, and using
       * this type-testing method instead.
       */
      static isTreeCloudArtifact(art) {
        return art && typeof art === "object" && TREE_CLOUD_ARTIFACT_SYM in art;
      }
      constructor(assembly, name, artifact) {
        super(assembly, name, artifact);
        const properties = this.manifest.properties || {};
        if (!properties.file) {
          throw new CloudAssemblyError('Invalid TreeCloudArtifact. Missing "file" property');
        }
        this.file = properties.file;
      }
    };
    Object.defineProperty(TreeCloudArtifact.prototype, TREE_CLOUD_ARTIFACT_SYM, {
      value: true,
      enumerable: false,
      writable: false
    });
  }
});

// ../@aws-cdk/cloud-assembly-api/lib/cloud-artifact-aug.ts
var cloud_artifact_aug_exports = {};
var cxschema3;
var init_cloud_artifact_aug = __esm({
  "../@aws-cdk/cloud-assembly-api/lib/cloud-artifact-aug.ts"() {
    "use strict";
    cxschema3 = __toESM(require_lib2());
    init_asset_manifest_artifact();
    init_cloudformation_artifact();
    init_nested_cloud_assembly_artifact();
    init_tree_cloud_artifact();
    init_cloud_artifact();
    CloudArtifact.fromManifest = /* @__PURE__ */ __name(function fromManifest(assembly, id, artifact) {
      switch (artifact.type) {
        case cxschema3.ArtifactType.AWS_CLOUDFORMATION_STACK:
          return new CloudFormationStackArtifact(assembly, id, artifact);
        case cxschema3.ArtifactType.CDK_TREE:
          return new TreeCloudArtifact(assembly, id, artifact);
        case cxschema3.ArtifactType.ASSET_MANIFEST:
          return new AssetManifestArtifact(assembly, id, artifact);
        case cxschema3.ArtifactType.NESTED_CLOUD_ASSEMBLY:
          return new NestedCloudAssemblyArtifact(assembly, id, artifact);
        default:
          return void 0;
      }
    }, "fromManifest");
  }
});

// ../@aws-cdk/cloud-assembly-api/lib/private/toposort.ts
function topologicalSort(xs, keyFn, depFn) {
  const remaining = /* @__PURE__ */ new Map();
  for (const element of xs) {
    const key = keyFn(element);
    remaining.set(key, { key, element, dependencies: depFn(element) });
  }
  const ret = new Array();
  while (remaining.size > 0) {
    const selectable = Array.from(remaining.values()).filter((e32) => e32.dependencies.every((d32) => !remaining.has(d32)));
    selectable.sort((a32, b32) => a32.key < b32.key ? -1 : b32.key < a32.key ? 1 : 0);
    for (const selected of selectable) {
      ret.push(selected.element);
      remaining.delete(selected.key);
    }
    if (selectable.length === 0) {
      throw new CloudAssemblyError(`Could not determine ordering between: ${Array.from(remaining.keys()).join(", ")}`);
    }
  }
  return ret;
}
var init_toposort = __esm({
  "../@aws-cdk/cloud-assembly-api/lib/private/toposort.ts"() {
    "use strict";
    init_error();
    __name(topologicalSort, "topologicalSort");
  }
});

// ../@aws-cdk/cloud-assembly-api/lib/cloud-assembly.ts
var cloud_assembly_exports2 = {};
__export(cloud_assembly_exports2, {
  CloudAssembly: () => CloudAssembly,
  CloudAssemblyBuilder: () => CloudAssemblyBuilder
});
function filterUndefined(obj) {
  if (Array.isArray(obj)) {
    return obj.filter((x) => x !== void 0).map((x) => filterUndefined(x));
  }
  if (typeof obj === "object") {
    const ret = {};
    for (const [key, value] of Object.entries(obj)) {
      if (value === void 0) {
        continue;
      }
      ret[key] = filterUndefined(value);
    }
    return ret;
  }
  return obj;
}
function ignore(_x) {
  return;
}
function determineOutputDirectory(outdir) {
  if (outdir) {
    return outdir;
  }
  const tmpDir = fs5.mkdtempSync(path5.join(fs5.realpathSync(os.tmpdir()), "cdk.out"));
  TEMPORARY_ASSEMBLY_DIRS.push(tmpDir);
  return outdir ?? tmpDir;
}
function ensureDirSync(dir) {
  if (fs5.existsSync(dir)) {
    if (!fs5.statSync(dir).isDirectory()) {
      throw new CloudAssemblyError(`${dir} must be a directory`);
    }
  } else {
    fs5.mkdirSync(dir, { recursive: true });
  }
}
var fs5, os, path5, cxschema4, CLOUD_ASSEMBLY_SYMBOL, MANIFEST_FILE, CloudAssembly, CloudAssemblyBuilder, TEMPORARY_ASSEMBLY_DIRS;
var init_cloud_assembly2 = __esm({
  "../@aws-cdk/cloud-assembly-api/lib/cloud-assembly.ts"() {
    "use strict";
    fs5 = __toESM(require("fs"));
    os = __toESM(require("os"));
    path5 = __toESM(require("path"));
    cxschema4 = __toESM(require_lib2());
    init_cloudformation_artifact();
    init_nested_cloud_assembly_artifact();
    init_tree_cloud_artifact();
    init_cloud_artifact();
    init_error();
    init_toposort();
    CLOUD_ASSEMBLY_SYMBOL = /* @__PURE__ */ Symbol.for("@aws-cdk/cx-api.CloudAssembly");
    MANIFEST_FILE = "manifest.json";
    CloudAssembly = class {
      static {
        __name(this, "CloudAssembly");
      }
      /**
       * Return whether the given object is a CloudAssembly.
       *
       * We do attribute detection since we can't reliably use 'instanceof'.
       */
      static isCloudAssembly(x) {
        return x !== null && typeof x === "object" && CLOUD_ASSEMBLY_SYMBOL in x;
      }
      /**
       * Cleans up any temporary assembly directories that got created in this process
       *
       * If a Cloud Assembly is emitted to a temporary directory, its directory gets
       * added to a list. This function iterates over that list and deletes each
       * directory in it, to free up disk space.
       *
       * This function will normally be called automatically during Node process
       * exit and so you don't need to call this. However, some test environments do
       * not properly trigger Node's `exit` event. Notably: Jest does not trigger
       * the `exit` event (<https://github.com/jestjs/jest/issues/10927>).
       *
       * ## Cleaning up temporary directories in jest
       *
       * For Jest, you have to make sure this function is called at the end of the
       * test suite instead:
       *
       * ```js
       * import { CloudAssembly } from 'aws-cdk-lib/cx-api';
       *
       * afterAll(CloudAssembly.cleanupTemporaryDirectories);
       * ```
       *
       * Alternatively, you can use the `setupFilesAfterEnv` feature and use a
       * provided helper script to automatically inject the above into every
       * test file, so you don't have to do it by hand.
       *
       * ```
       * $ npx jest --setupFilesAfterEnv aws-cdk-lib/testhelpers/jest-autoclean
       * ```
       *
       * Or put the following into `jest.config.js`:
       *
       * ```js
       * module.exports = {
       *   // ...
       *   setupFilesAfterEnv: ['aws-cdk-lib/testhelpers/jest-cleanup'],
       * };
       * ```
       */
      static cleanupTemporaryDirectories() {
        for (const dir of TEMPORARY_ASSEMBLY_DIRS) {
          fs5.rmSync(dir, { recursive: true, force: true });
        }
        TEMPORARY_ASSEMBLY_DIRS.splice(0, TEMPORARY_ASSEMBLY_DIRS.length);
      }
      /**
       * Reads a cloud assembly from the specified directory.
       * @param directory - The root directory of the assembly.
       */
      constructor(directory, loadOptions) {
        this.directory = directory;
        this.loadOptions = loadOptions;
        this.manifest = cxschema4.Manifest.loadAssemblyManifest(path5.join(directory, MANIFEST_FILE), this.loadOptions);
        this.version = this.manifest.version;
        this.artifacts = this.renderArtifacts(this.loadOptions?.topoSort ?? true);
        this.runtime = this.manifest.runtime || { libraries: {} };
        Object.defineProperty(this, CLOUD_ASSEMBLY_SYMBOL, { value: true });
        this.validateDeps();
      }
      /**
       * Attempts to find an artifact with a specific identity.
       * @returns A `CloudArtifact` object or `undefined` if the artifact does not exist in this assembly.
       * @param id - The artifact ID
       */
      tryGetArtifact(id) {
        return this.artifacts.find((a32) => a32.id === id);
      }
      /**
       * Returns a CloudFormation stack artifact from this assembly.
       *
       * Will only search the current assembly.
       *
       * @param stackName - the name of the CloudFormation stack.
       * @throws if there is no stack artifact by that name
       * @throws if there is more than one stack with the same stack name. You can
       * use `getStackArtifact(stack.artifactId)` instead.
       * @returns a `CloudFormationStackArtifact` object.
       */
      getStackByName(stackName) {
        const artifacts = this.artifacts.filter((a32) => a32 instanceof CloudFormationStackArtifact && a32.stackName === stackName);
        if (!artifacts || artifacts.length === 0) {
          throw new CloudAssemblyError(`Unable to find stack with stack name "${stackName}"`);
        }
        if (artifacts.length > 1) {
          throw new CloudAssemblyError(`There are multiple stacks with the stack name "${stackName}" (${artifacts.map((a32) => a32.id).join(",")}). Use "getStackArtifact(id)" instead`);
        }
        return artifacts[0];
      }
      /**
       * Returns a CloudFormation stack artifact by name from this assembly.
       * @deprecated renamed to `getStackByName` (or `getStackArtifact(id)`)
       */
      getStack(stackName) {
        return this.getStackByName(stackName);
      }
      /**
       * Returns a CloudFormation stack artifact from this assembly.
       *
       * @param artifactId - the artifact id of the stack (can be obtained through `stack.artifactId`).
       * @throws if there is no stack artifact with that id
       * @returns a `CloudFormationStackArtifact` object.
       */
      getStackArtifact(artifactId) {
        const artifact = this.tryGetArtifactRecursively(artifactId);
        if (!artifact) {
          throw new CloudAssemblyError(`Unable to find artifact with id "${artifactId}"`);
        }
        if (!(artifact instanceof CloudFormationStackArtifact)) {
          throw new CloudAssemblyError(`Artifact ${artifactId} is not a CloudFormation stack`);
        }
        return artifact;
      }
      tryGetArtifactRecursively(artifactId) {
        return this.stacksRecursively.find((a32) => a32.id === artifactId);
      }
      /**
       * Returns all the stacks, including the ones in nested assemblies
       */
      get stacksRecursively() {
        function search(stackArtifacts, assemblies) {
          if (assemblies.length === 0) {
            return stackArtifacts;
          }
          const [head, ...tail] = assemblies;
          const nestedAssemblies = head.nestedAssemblies.map((asm) => asm.nestedAssembly);
          return search(stackArtifacts.concat(head.stacks), tail.concat(nestedAssemblies));
        }
        __name(search, "search");
        return search([], [this]);
      }
      /**
       * Returns a nested assembly artifact.
       *
       * @param artifactId - The artifact ID of the nested assembly
       */
      getNestedAssemblyArtifact(artifactId) {
        const artifact = this.tryGetArtifact(artifactId);
        if (!artifact) {
          throw new CloudAssemblyError(`Unable to find artifact with id "${artifactId}"`);
        }
        if (!(artifact instanceof NestedCloudAssemblyArtifact)) {
          throw new CloudAssemblyError(`Found artifact '${artifactId}' but it's not a nested cloud assembly`);
        }
        return artifact;
      }
      /**
       * Returns a nested assembly.
       *
       * @param artifactId - The artifact ID of the nested assembly
       */
      getNestedAssembly(artifactId) {
        return this.getNestedAssemblyArtifact(artifactId).nestedAssembly;
      }
      /**
       * Returns the tree metadata artifact from this assembly.
       * @throws if there is no metadata artifact by that name
       * @returns a `TreeCloudArtifact` object if there is one defined in the manifest, `undefined` otherwise.
       */
      tree() {
        const trees = this.artifacts.filter((a32) => a32.manifest.type === cxschema4.ArtifactType.CDK_TREE);
        if (trees.length === 0) {
          return void 0;
        } else if (trees.length > 1) {
          throw new CloudAssemblyError(`Multiple artifacts of type ${cxschema4.ArtifactType.CDK_TREE} found in manifest`);
        }
        const tree = trees[0];
        if (!(tree instanceof TreeCloudArtifact)) {
          throw new CloudAssemblyError('"Tree" artifact is not of expected type');
        }
        return tree;
      }
      /**
       * @returns all the CloudFormation stack artifacts that are included in this assembly.
       */
      get stacks() {
        return this.artifacts.filter(isCloudFormationStackArtifact);
        function isCloudFormationStackArtifact(x) {
          return x instanceof CloudFormationStackArtifact;
        }
        __name(isCloudFormationStackArtifact, "isCloudFormationStackArtifact");
      }
      /**
       * The nested assembly artifacts in this assembly
       */
      get nestedAssemblies() {
        return this.artifacts.filter(isNestedCloudAssemblyArtifact);
        function isNestedCloudAssemblyArtifact(x) {
          return x instanceof NestedCloudAssemblyArtifact;
        }
        __name(isNestedCloudAssemblyArtifact, "isNestedCloudAssemblyArtifact");
      }
      validateDeps() {
        for (const artifact of this.artifacts) {
          ignore(artifact.dependencies);
        }
      }
      renderArtifacts(topoSort) {
        const result2 = new Array();
        for (const [name, artifact] of Object.entries(this.manifest.artifacts || {})) {
          const cloudartifact = CloudArtifact.fromManifest(this, name, artifact);
          if (cloudartifact) {
            result2.push(cloudartifact);
          }
        }
        return topoSort ? topologicalSort(result2, (x) => x.id, (x) => x._dependencyIDs) : result2;
      }
    };
    CloudAssemblyBuilder = class _CloudAssemblyBuilder {
      /**
       * Initializes a cloud assembly builder.
       * @param outdir - The output directory, uses temporary directory if undefined
       */
      constructor(outdir, props = {}) {
        this.artifacts = {};
        this.missing = new Array();
        this.outdir = determineOutputDirectory(outdir);
        this.assetOutdir = props.assetOutdir ?? this.outdir;
        this.parentBuilder = props.parentBuilder;
        ensureDirSync(this.outdir);
      }
      static {
        __name(this, "CloudAssemblyBuilder");
      }
      /**
       * Adds an artifact into the cloud assembly.
       * @param id - The ID of the artifact.
       * @param manifest - The artifact manifest
       */
      addArtifact(id, manifest) {
        this.artifacts[id] = filterUndefined(manifest);
      }
      /**
       * Reports that some context is missing in order for this cloud assembly to be fully synthesized.
       * @param missing - Missing context information.
       */
      addMissing(missing) {
        if (this.missing.every((m20) => m20.key !== missing.key)) {
          this.missing.push(missing);
        }
        this.parentBuilder?.addMissing(missing);
      }
      /**
       * Finalizes the cloud assembly into the output directory returns a
       * `CloudAssembly` object that can be used to inspect the assembly.
       */
      buildAssembly(options = {}) {
        let manifest = {
          version: cxschema4.Manifest.version(),
          artifacts: this.artifacts,
          runtime: options.runtimeInfo,
          missing: this.missing.length > 0 ? this.missing : void 0
        };
        manifest = filterUndefined(manifest);
        const manifestFilePath = path5.join(this.outdir, MANIFEST_FILE);
        cxschema4.Manifest.saveAssemblyManifest(manifest, manifestFilePath);
        fs5.writeFileSync(path5.join(this.outdir, "cdk.out"), JSON.stringify({ version: manifest.version }));
        return new CloudAssembly(this.outdir);
      }
      /**
       * Creates a nested cloud assembly
       */
      createNestedAssembly(artifactId, displayName) {
        const directoryName = artifactId;
        const innerAsmDir = path5.join(this.outdir, directoryName);
        this.addArtifact(artifactId, {
          type: cxschema4.ArtifactType.NESTED_CLOUD_ASSEMBLY,
          properties: {
            directoryName,
            displayName
          }
        });
        return new _CloudAssemblyBuilder(innerAsmDir, {
          // Reuse the same asset output directory as the current Casm builder
          assetOutdir: this.assetOutdir,
          parentBuilder: this
        });
      }
      /**
       * Delete the cloud assembly directory
       */
      delete() {
        fs5.rmSync(this.outdir, { recursive: true, force: true });
      }
    };
    __name(filterUndefined, "filterUndefined");
    __name(ignore, "ignore");
    __name(determineOutputDirectory, "determineOutputDirectory");
    __name(ensureDirSync, "ensureDirSync");
    TEMPORARY_ASSEMBLY_DIRS = [];
    process.on("exit", () => CloudAssembly.cleanupTemporaryDirectories());
  }
});

// ../@aws-cdk/cloud-assembly-api/lib/artifacts/nested-cloud-assembly-artifact-aug.ts
var nested_cloud_assembly_artifact_aug_exports = {};
var cacheSym;
var init_nested_cloud_assembly_artifact_aug = __esm({
  "../@aws-cdk/cloud-assembly-api/lib/artifacts/nested-cloud-assembly-artifact-aug.ts"() {
    "use strict";
    init_nested_cloud_assembly_artifact();
    init_cloud_assembly2();
    cacheSym = /* @__PURE__ */ Symbol();
    Object.defineProperty(NestedCloudAssemblyArtifact.prototype, "nestedAssembly", {
      get() {
        if (!this[cacheSym]) {
          this[cacheSym] = new CloudAssembly(this.fullPath, this.assembly.loadOptions);
        }
        return this[cacheSym];
      }
    });
  }
});

// ../@aws-cdk/cloud-assembly-api/lib/assets.ts
var assets_exports2 = {};
__export(assets_exports2, {
  ASSET_PREFIX_SEPARATOR: () => ASSET_PREFIX_SEPARATOR,
  ASSET_RESOURCE_METADATA_DOCKERFILE_PATH_KEY: () => ASSET_RESOURCE_METADATA_DOCKERFILE_PATH_KEY,
  ASSET_RESOURCE_METADATA_DOCKER_BUILD_ARGS_KEY: () => ASSET_RESOURCE_METADATA_DOCKER_BUILD_ARGS_KEY,
  ASSET_RESOURCE_METADATA_DOCKER_BUILD_CONTEXTS_KEY: () => ASSET_RESOURCE_METADATA_DOCKER_BUILD_CONTEXTS_KEY,
  ASSET_RESOURCE_METADATA_DOCKER_BUILD_SECRETS_KEY: () => ASSET_RESOURCE_METADATA_DOCKER_BUILD_SECRETS_KEY,
  ASSET_RESOURCE_METADATA_DOCKER_BUILD_SSH_KEY: () => ASSET_RESOURCE_METADATA_DOCKER_BUILD_SSH_KEY,
  ASSET_RESOURCE_METADATA_DOCKER_BUILD_TARGET_KEY: () => ASSET_RESOURCE_METADATA_DOCKER_BUILD_TARGET_KEY,
  ASSET_RESOURCE_METADATA_DOCKER_CACHE_DISABLED_KEY: () => ASSET_RESOURCE_METADATA_DOCKER_CACHE_DISABLED_KEY,
  ASSET_RESOURCE_METADATA_DOCKER_CACHE_FROM_KEY: () => ASSET_RESOURCE_METADATA_DOCKER_CACHE_FROM_KEY,
  ASSET_RESOURCE_METADATA_DOCKER_CACHE_TO_KEY: () => ASSET_RESOURCE_METADATA_DOCKER_CACHE_TO_KEY,
  ASSET_RESOURCE_METADATA_DOCKER_OUTPUTS_KEY: () => ASSET_RESOURCE_METADATA_DOCKER_OUTPUTS_KEY,
  ASSET_RESOURCE_METADATA_ENABLED_CONTEXT: () => ASSET_RESOURCE_METADATA_ENABLED_CONTEXT,
  ASSET_RESOURCE_METADATA_IS_BUNDLED_KEY: () => ASSET_RESOURCE_METADATA_IS_BUNDLED_KEY,
  ASSET_RESOURCE_METADATA_PATH_KEY: () => ASSET_RESOURCE_METADATA_PATH_KEY,
  ASSET_RESOURCE_METADATA_PROPERTY_KEY: () => ASSET_RESOURCE_METADATA_PROPERTY_KEY
});
var ASSET_RESOURCE_METADATA_ENABLED_CONTEXT, ASSET_RESOURCE_METADATA_PATH_KEY, ASSET_RESOURCE_METADATA_DOCKERFILE_PATH_KEY, ASSET_RESOURCE_METADATA_DOCKER_BUILD_ARGS_KEY, ASSET_RESOURCE_METADATA_DOCKER_BUILD_CONTEXTS_KEY, ASSET_RESOURCE_METADATA_DOCKER_BUILD_SECRETS_KEY, ASSET_RESOURCE_METADATA_DOCKER_BUILD_SSH_KEY, ASSET_RESOURCE_METADATA_DOCKER_BUILD_TARGET_KEY, ASSET_RESOURCE_METADATA_PROPERTY_KEY, ASSET_RESOURCE_METADATA_IS_BUNDLED_KEY, ASSET_RESOURCE_METADATA_DOCKER_OUTPUTS_KEY, ASSET_RESOURCE_METADATA_DOCKER_CACHE_FROM_KEY, ASSET_RESOURCE_METADATA_DOCKER_CACHE_TO_KEY, ASSET_RESOURCE_METADATA_DOCKER_CACHE_DISABLED_KEY, ASSET_PREFIX_SEPARATOR;
var init_assets2 = __esm({
  "../@aws-cdk/cloud-assembly-api/lib/assets.ts"() {
    "use strict";
    ASSET_RESOURCE_METADATA_ENABLED_CONTEXT = "aws:cdk:enable-asset-metadata";
    ASSET_RESOURCE_METADATA_PATH_KEY = "aws:asset:path";
    ASSET_RESOURCE_METADATA_DOCKERFILE_PATH_KEY = "aws:asset:dockerfile-path";
    ASSET_RESOURCE_METADATA_DOCKER_BUILD_ARGS_KEY = "aws:asset:docker-build-args";
    ASSET_RESOURCE_METADATA_DOCKER_BUILD_CONTEXTS_KEY = "aws:asset:docker-build-contexts";
    ASSET_RESOURCE_METADATA_DOCKER_BUILD_SECRETS_KEY = "aws:asset:docker-build-secrets";
    ASSET_RESOURCE_METADATA_DOCKER_BUILD_SSH_KEY = "aws:asset:docker-build-ssh";
    ASSET_RESOURCE_METADATA_DOCKER_BUILD_TARGET_KEY = "aws:asset:docker-build-target";
    ASSET_RESOURCE_METADATA_PROPERTY_KEY = "aws:asset:property";
    ASSET_RESOURCE_METADATA_IS_BUNDLED_KEY = "aws:asset:is-bundled";
    ASSET_RESOURCE_METADATA_DOCKER_OUTPUTS_KEY = "aws:asset:docker-outputs";
    ASSET_RESOURCE_METADATA_DOCKER_CACHE_FROM_KEY = "aws:asset:docker-cache-from";
    ASSET_RESOURCE_METADATA_DOCKER_CACHE_TO_KEY = "aws:asset:docker-cache-to";
    ASSET_RESOURCE_METADATA_DOCKER_CACHE_DISABLED_KEY = "aws:asset:docker-cache-disabled";
    ASSET_PREFIX_SEPARATOR = "||";
  }
});

// ../@aws-cdk/cloud-assembly-api/lib/placeholders.ts
var placeholders_exports = {};
__export(placeholders_exports, {
  EnvironmentPlaceholders: () => EnvironmentPlaceholders
});
function replaceAll(s, search, replace) {
  return s.split(search).join(replace);
}
var EnvironmentPlaceholders;
var init_placeholders = __esm({
  "../@aws-cdk/cloud-assembly-api/lib/placeholders.ts"() {
    "use strict";
    EnvironmentPlaceholders = class _EnvironmentPlaceholders {
      static {
        __name(this, "EnvironmentPlaceholders");
      }
      static {
        /**
         * Insert this into the destination fields to be replaced with the current region
         */
        this.CURRENT_REGION = "${AWS::Region}";
      }
      static {
        /**
         * Insert this into the destination fields to be replaced with the current account
         */
        this.CURRENT_ACCOUNT = "${AWS::AccountId}";
      }
      static {
        /**
         * Insert this into the destination fields to be replaced with the current partition
         */
        this.CURRENT_PARTITION = "${AWS::Partition}";
      }
      /**
       * Replace the environment placeholders in all strings found in a complex object.
       *
       * Duplicated between cdk-assets and aws-cdk CLI because we don't have a good single place to put it
       * (they're nominally independent tools).
       */
      static replace(object, values) {
        return this.recurse(object, (value) => {
          value = replaceAll(value, _EnvironmentPlaceholders.CURRENT_REGION, values.region);
          value = replaceAll(value, _EnvironmentPlaceholders.CURRENT_ACCOUNT, values.accountId);
          value = replaceAll(value, _EnvironmentPlaceholders.CURRENT_PARTITION, values.partition);
          return value;
        });
      }
      /**
       * Like 'replace', but asynchronous
       */
      static async replaceAsync(object, provider) {
        let needRegion = false;
        let needAccountId = false;
        let needPartition = false;
        this.recurse(object, (value) => {
          if (value.indexOf(_EnvironmentPlaceholders.CURRENT_REGION) > 1) {
            needRegion = true;
          }
          if (value.indexOf(_EnvironmentPlaceholders.CURRENT_ACCOUNT) > 1) {
            needAccountId = true;
          }
          if (value.indexOf(_EnvironmentPlaceholders.CURRENT_PARTITION) > 1) {
            needPartition = true;
          }
          return value;
        });
        const region = needRegion ? await provider.region() : void 0;
        const accountId = needAccountId ? await provider.accountId() : void 0;
        const partition4 = needPartition ? await provider.partition() : void 0;
        return this.recurse(object, (value) => {
          value = replaceAll(value, _EnvironmentPlaceholders.CURRENT_REGION, region ?? "WONTHAPPEN");
          value = replaceAll(value, _EnvironmentPlaceholders.CURRENT_ACCOUNT, accountId ?? "WONTHAPPEN");
          value = replaceAll(value, _EnvironmentPlaceholders.CURRENT_PARTITION, partition4 ?? "WONTHAPPEN");
          return value;
        });
      }
      static recurse(value, cb) {
        if (typeof value === "string") {
          return cb(value);
        }
        if (typeof value !== "object" || value === null) {
          return value;
        }
        if (Array.isArray(value)) {
          return value.map((x) => this.recurse(x, cb));
        }
        const ret = {};
        for (const [key, inner] of Object.entries(value)) {
          ret[key] = this.recurse(inner, cb);
        }
        return ret;
      }
    };
    __name(replaceAll, "replaceAll");
  }
});

// ../@aws-cdk/cloud-assembly-api/lib/bootstrap.ts
var bootstrap_exports = {};
__export(bootstrap_exports, {
  SSMPARAM_NO_INVALIDATE: () => SSMPARAM_NO_INVALIDATE
});
var SSMPARAM_NO_INVALIDATE;
var init_bootstrap = __esm({
  "../@aws-cdk/cloud-assembly-api/lib/bootstrap.ts"() {
    "use strict";
    SSMPARAM_NO_INVALIDATE = "[cdk:skip]";
  }
});

// ../@aws-cdk/cloud-assembly-api/lib/index.js
var require_lib3 = __commonJS({
  "../@aws-cdk/cloud-assembly-api/lib/index.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __exportStar3 = exports2 && exports2.__exportStar || function(m20, exports3) {
      for (var p10 in m20) if (p10 !== "default" && !Object.prototype.hasOwnProperty.call(exports3, p10)) __createBinding3(exports3, m20, p10);
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    __exportStar3((init_vpc(), __toCommonJS(vpc_exports)), exports2);
    __exportStar3((init_ami(), __toCommonJS(ami_exports)), exports2);
    __exportStar3((init_load_balancer(), __toCommonJS(load_balancer_exports)), exports2);
    __exportStar3((init_availability_zones(), __toCommonJS(availability_zones_exports)), exports2);
    __exportStar3((init_endpoint_service_availability_zones(), __toCommonJS(endpoint_service_availability_zones_exports)), exports2);
    __exportStar3((init_security_group(), __toCommonJS(security_group_exports)), exports2);
    __exportStar3((init_key(), __toCommonJS(key_exports)), exports2);
    __exportStar3((init_generic(), __toCommonJS(generic_exports)), exports2);
    __exportStar3((init_cloud_artifact(), __toCommonJS(cloud_artifact_exports)), exports2);
    init_cloud_artifact_aug();
    __exportStar3((init_asset_manifest_artifact(), __toCommonJS(asset_manifest_artifact_exports)), exports2);
    __exportStar3((init_cloudformation_artifact(), __toCommonJS(cloudformation_artifact_exports)), exports2);
    __exportStar3((init_tree_cloud_artifact(), __toCommonJS(tree_cloud_artifact_exports)), exports2);
    __exportStar3((init_nested_cloud_assembly_artifact(), __toCommonJS(nested_cloud_assembly_artifact_exports)), exports2);
    init_nested_cloud_assembly_artifact_aug();
    __exportStar3((init_cloud_assembly2(), __toCommonJS(cloud_assembly_exports2)), exports2);
    __exportStar3((init_assets2(), __toCommonJS(assets_exports2)), exports2);
    __exportStar3((init_metadata(), __toCommonJS(metadata_exports)), exports2);
    __exportStar3((init_placeholders(), __toCommonJS(placeholders_exports)), exports2);
    __exportStar3((init_environment(), __toCommonJS(environment_exports)), exports2);
    __exportStar3((init_bootstrap(), __toCommonJS(bootstrap_exports)), exports2);
  }
});

// ../../node_modules/universalify/index.js
var require_universalify = __commonJS({
  "../../node_modules/universalify/index.js"(exports2) {
    "use strict";
    exports2.fromCallback = function(fn) {
      return Object.defineProperty(function(...args) {
        if (typeof args[args.length - 1] === "function") fn.apply(this, args);
        else {
          return new Promise((resolve13, reject) => {
            args.push((err, res) => err != null ? reject(err) : resolve13(res));
            fn.apply(this, args);
          });
        }
      }, "name", { value: fn.name });
    };
    exports2.fromPromise = function(fn) {
      return Object.defineProperty(function(...args) {
        const cb = args[args.length - 1];
        if (typeof cb !== "function") return fn.apply(this, args);
        else {
          args.pop();
          fn.apply(this, args).then((r32) => cb(null, r32), cb);
        }
      }, "name", { value: fn.name });
    };
  }
});

// ../../node_modules/graceful-fs/polyfills.js
var require_polyfills = __commonJS({
  "../../node_modules/graceful-fs/polyfills.js"(exports2, module2) {
    var constants3 = require("constants");
    var origCwd = process.cwd;
    var cwd = null;
    var platform5 = process.env.GRACEFUL_FS_PLATFORM || process.platform;
    process.cwd = function() {
      if (!cwd)
        cwd = origCwd.call(process);
      return cwd;
    };
    try {
      process.cwd();
    } catch (er) {
    }
    if (typeof process.chdir === "function") {
      chdir = process.chdir;
      process.chdir = function(d32) {
        cwd = null;
        chdir.call(process, d32);
      };
      if (Object.setPrototypeOf) Object.setPrototypeOf(process.chdir, chdir);
    }
    var chdir;
    module2.exports = patch;
    function patch(fs51) {
      if (constants3.hasOwnProperty("O_SYMLINK") && process.version.match(/^v0\.6\.[0-2]|^v0\.5\./)) {
        patchLchmod(fs51);
      }
      if (!fs51.lutimes) {
        patchLutimes(fs51);
      }
      fs51.chown = chownFix(fs51.chown);
      fs51.fchown = chownFix(fs51.fchown);
      fs51.lchown = chownFix(fs51.lchown);
      fs51.chmod = chmodFix(fs51.chmod);
      fs51.fchmod = chmodFix(fs51.fchmod);
      fs51.lchmod = chmodFix(fs51.lchmod);
      fs51.chownSync = chownFixSync(fs51.chownSync);
      fs51.fchownSync = chownFixSync(fs51.fchownSync);
      fs51.lchownSync = chownFixSync(fs51.lchownSync);
      fs51.chmodSync = chmodFixSync(fs51.chmodSync);
      fs51.fchmodSync = chmodFixSync(fs51.fchmodSync);
      fs51.lchmodSync = chmodFixSync(fs51.lchmodSync);
      fs51.stat = statFix(fs51.stat);
      fs51.fstat = statFix(fs51.fstat);
      fs51.lstat = statFix(fs51.lstat);
      fs51.statSync = statFixSync(fs51.statSync);
      fs51.fstatSync = statFixSync(fs51.fstatSync);
      fs51.lstatSync = statFixSync(fs51.lstatSync);
      if (fs51.chmod && !fs51.lchmod) {
        fs51.lchmod = function(path47, mode, cb) {
          if (cb) process.nextTick(cb);
        };
        fs51.lchmodSync = function() {
        };
      }
      if (fs51.chown && !fs51.lchown) {
        fs51.lchown = function(path47, uid, gid, cb) {
          if (cb) process.nextTick(cb);
        };
        fs51.lchownSync = function() {
        };
      }
      if (platform5 === "win32") {
        fs51.rename = typeof fs51.rename !== "function" ? fs51.rename : (function(fs$rename) {
          function rename(from, to, cb) {
            var start = Date.now();
            var backoff = 0;
            fs$rename(from, to, /* @__PURE__ */ __name(function CB(er) {
              if (er && (er.code === "EACCES" || er.code === "EPERM" || er.code === "EBUSY") && Date.now() - start < 6e4) {
                setTimeout(function() {
                  fs51.stat(to, function(stater, st) {
                    if (stater && stater.code === "ENOENT")
                      fs$rename(from, to, CB);
                    else
                      cb(er);
                  });
                }, backoff);
                if (backoff < 100)
                  backoff += 10;
                return;
              }
              if (cb) cb(er);
            }, "CB"));
          }
          __name(rename, "rename");
          if (Object.setPrototypeOf) Object.setPrototypeOf(rename, fs$rename);
          return rename;
        })(fs51.rename);
      }
      fs51.read = typeof fs51.read !== "function" ? fs51.read : (function(fs$read) {
        function read(fd, buffer, offset, length, position, callback_) {
          var callback;
          if (callback_ && typeof callback_ === "function") {
            var eagCounter = 0;
            callback = /* @__PURE__ */ __name(function(er, _, __) {
              if (er && er.code === "EAGAIN" && eagCounter < 10) {
                eagCounter++;
                return fs$read.call(fs51, fd, buffer, offset, length, position, callback);
              }
              callback_.apply(this, arguments);
            }, "callback");
          }
          return fs$read.call(fs51, fd, buffer, offset, length, position, callback);
        }
        __name(read, "read");
        if (Object.setPrototypeOf) Object.setPrototypeOf(read, fs$read);
        return read;
      })(fs51.read);
      fs51.readSync = typeof fs51.readSync !== "function" ? fs51.readSync : /* @__PURE__ */ (function(fs$readSync) {
        return function(fd, buffer, offset, length, position) {
          var eagCounter = 0;
          while (true) {
            try {
              return fs$readSync.call(fs51, fd, buffer, offset, length, position);
            } catch (er) {
              if (er.code === "EAGAIN" && eagCounter < 10) {
                eagCounter++;
                continue;
              }
              throw er;
            }
          }
        };
      })(fs51.readSync);
      function patchLchmod(fs52) {
        fs52.lchmod = function(path47, mode, callback) {
          fs52.open(
            path47,
            constants3.O_WRONLY | constants3.O_SYMLINK,
            mode,
            function(err, fd) {
              if (err) {
                if (callback) callback(err);
                return;
              }
              fs52.fchmod(fd, mode, function(err2) {
                fs52.close(fd, function(err22) {
                  if (callback) callback(err2 || err22);
                });
              });
            }
          );
        };
        fs52.lchmodSync = function(path47, mode) {
          var fd = fs52.openSync(path47, constants3.O_WRONLY | constants3.O_SYMLINK, mode);
          var threw = true;
          var ret;
          try {
            ret = fs52.fchmodSync(fd, mode);
            threw = false;
          } finally {
            if (threw) {
              try {
                fs52.closeSync(fd);
              } catch (er) {
              }
            } else {
              fs52.closeSync(fd);
            }
          }
          return ret;
        };
      }
      __name(patchLchmod, "patchLchmod");
      function patchLutimes(fs52) {
        if (constants3.hasOwnProperty("O_SYMLINK") && fs52.futimes) {
          fs52.lutimes = function(path47, at, mt, cb) {
            fs52.open(path47, constants3.O_SYMLINK, function(er, fd) {
              if (er) {
                if (cb) cb(er);
                return;
              }
              fs52.futimes(fd, at, mt, function(er2) {
                fs52.close(fd, function(er22) {
                  if (cb) cb(er2 || er22);
                });
              });
            });
          };
          fs52.lutimesSync = function(path47, at, mt) {
            var fd = fs52.openSync(path47, constants3.O_SYMLINK);
            var ret;
            var threw = true;
            try {
              ret = fs52.futimesSync(fd, at, mt);
              threw = false;
            } finally {
              if (threw) {
                try {
                  fs52.closeSync(fd);
                } catch (er) {
                }
              } else {
                fs52.closeSync(fd);
              }
            }
            return ret;
          };
        } else if (fs52.futimes) {
          fs52.lutimes = function(_a10, _b, _c32, cb) {
            if (cb) process.nextTick(cb);
          };
          fs52.lutimesSync = function() {
          };
        }
      }
      __name(patchLutimes, "patchLutimes");
      function chmodFix(orig) {
        if (!orig) return orig;
        return function(target, mode, cb) {
          return orig.call(fs51, target, mode, function(er) {
            if (chownErOk(er)) er = null;
            if (cb) cb.apply(this, arguments);
          });
        };
      }
      __name(chmodFix, "chmodFix");
      function chmodFixSync(orig) {
        if (!orig) return orig;
        return function(target, mode) {
          try {
            return orig.call(fs51, target, mode);
          } catch (er) {
            if (!chownErOk(er)) throw er;
          }
        };
      }
      __name(chmodFixSync, "chmodFixSync");
      function chownFix(orig) {
        if (!orig) return orig;
        return function(target, uid, gid, cb) {
          return orig.call(fs51, target, uid, gid, function(er) {
            if (chownErOk(er)) er = null;
            if (cb) cb.apply(this, arguments);
          });
        };
      }
      __name(chownFix, "chownFix");
      function chownFixSync(orig) {
        if (!orig) return orig;
        return function(target, uid, gid) {
          try {
            return orig.call(fs51, target, uid, gid);
          } catch (er) {
            if (!chownErOk(er)) throw er;
          }
        };
      }
      __name(chownFixSync, "chownFixSync");
      function statFix(orig) {
        if (!orig) return orig;
        return function(target, options, cb) {
          if (typeof options === "function") {
            cb = options;
            options = null;
          }
          function callback(er, stats) {
            if (stats) {
              if (stats.uid < 0) stats.uid += 4294967296;
              if (stats.gid < 0) stats.gid += 4294967296;
            }
            if (cb) cb.apply(this, arguments);
          }
          __name(callback, "callback");
          return options ? orig.call(fs51, target, options, callback) : orig.call(fs51, target, callback);
        };
      }
      __name(statFix, "statFix");
      function statFixSync(orig) {
        if (!orig) return orig;
        return function(target, options) {
          var stats = options ? orig.call(fs51, target, options) : orig.call(fs51, target);
          if (stats) {
            if (stats.uid < 0) stats.uid += 4294967296;
            if (stats.gid < 0) stats.gid += 4294967296;
          }
          return stats;
        };
      }
      __name(statFixSync, "statFixSync");
      function chownErOk(er) {
        if (!er)
          return true;
        if (er.code === "ENOSYS")
          return true;
        var nonroot = !process.getuid || process.getuid() !== 0;
        if (nonroot) {
          if (er.code === "EINVAL" || er.code === "EPERM")
            return true;
        }
        return false;
      }
      __name(chownErOk, "chownErOk");
    }
    __name(patch, "patch");
  }
});

// ../../node_modules/graceful-fs/legacy-streams.js
var require_legacy_streams = __commonJS({
  "../../node_modules/graceful-fs/legacy-streams.js"(exports2, module2) {
    var Stream = require("stream").Stream;
    module2.exports = legacy;
    function legacy(fs51) {
      return {
        ReadStream: ReadStream3,
        WriteStream
      };
      function ReadStream3(path47, options) {
        if (!(this instanceof ReadStream3)) return new ReadStream3(path47, options);
        Stream.call(this);
        var self2 = this;
        this.path = path47;
        this.fd = null;
        this.readable = true;
        this.paused = false;
        this.flags = "r";
        this.mode = 438;
        this.bufferSize = 64 * 1024;
        options = options || {};
        var keys = Object.keys(options);
        for (var index = 0, length = keys.length; index < length; index++) {
          var key = keys[index];
          this[key] = options[key];
        }
        if (this.encoding) this.setEncoding(this.encoding);
        if (this.start !== void 0) {
          if ("number" !== typeof this.start) {
            throw TypeError("start must be a Number");
          }
          if (this.end === void 0) {
            this.end = Infinity;
          } else if ("number" !== typeof this.end) {
            throw TypeError("end must be a Number");
          }
          if (this.start > this.end) {
            throw new Error("start must be <= end");
          }
          this.pos = this.start;
        }
        if (this.fd !== null) {
          process.nextTick(function() {
            self2._read();
          });
          return;
        }
        fs51.open(this.path, this.flags, this.mode, function(err, fd) {
          if (err) {
            self2.emit("error", err);
            self2.readable = false;
            return;
          }
          self2.fd = fd;
          self2.emit("open", fd);
          self2._read();
        });
      }
      __name(ReadStream3, "ReadStream");
      function WriteStream(path47, options) {
        if (!(this instanceof WriteStream)) return new WriteStream(path47, options);
        Stream.call(this);
        this.path = path47;
        this.fd = null;
        this.writable = true;
        this.flags = "w";
        this.encoding = "binary";
        this.mode = 438;
        this.bytesWritten = 0;
        options = options || {};
        var keys = Object.keys(options);
        for (var index = 0, length = keys.length; index < length; index++) {
          var key = keys[index];
          this[key] = options[key];
        }
        if (this.start !== void 0) {
          if ("number" !== typeof this.start) {
            throw TypeError("start must be a Number");
          }
          if (this.start < 0) {
            throw new Error("start must be >= zero");
          }
          this.pos = this.start;
        }
        this.busy = false;
        this._queue = [];
        if (this.fd === null) {
          this._open = fs51.open;
          this._queue.push([this._open, this.path, this.flags, this.mode, void 0]);
          this.flush();
        }
      }
      __name(WriteStream, "WriteStream");
    }
    __name(legacy, "legacy");
  }
});

// ../../node_modules/graceful-fs/clone.js
var require_clone = __commonJS({
  "../../node_modules/graceful-fs/clone.js"(exports2, module2) {
    "use strict";
    module2.exports = clone;
    var getPrototypeOf = Object.getPrototypeOf || function(obj) {
      return obj.__proto__;
    };
    function clone(obj) {
      if (obj === null || typeof obj !== "object")
        return obj;
      if (obj instanceof Object)
        var copy2 = { __proto__: getPrototypeOf(obj) };
      else
        var copy2 = /* @__PURE__ */ Object.create(null);
      Object.getOwnPropertyNames(obj).forEach(function(key) {
        Object.defineProperty(copy2, key, Object.getOwnPropertyDescriptor(obj, key));
      });
      return copy2;
    }
    __name(clone, "clone");
  }
});

// ../../node_modules/graceful-fs/graceful-fs.js
var require_graceful_fs = __commonJS({
  "../../node_modules/graceful-fs/graceful-fs.js"(exports2, module2) {
    var fs51 = require("fs");
    var polyfills = require_polyfills();
    var legacy = require_legacy_streams();
    var clone = require_clone();
    var util11 = require("util");
    var gracefulQueue;
    var previousSymbol;
    if (typeof Symbol === "function" && typeof Symbol.for === "function") {
      gracefulQueue = /* @__PURE__ */ Symbol.for("graceful-fs.queue");
      previousSymbol = /* @__PURE__ */ Symbol.for("graceful-fs.previous");
    } else {
      gracefulQueue = "___graceful-fs.queue";
      previousSymbol = "___graceful-fs.previous";
    }
    function noop() {
    }
    __name(noop, "noop");
    function publishQueue(context, queue2) {
      Object.defineProperty(context, gracefulQueue, {
        get: /* @__PURE__ */ __name(function() {
          return queue2;
        }, "get")
      });
    }
    __name(publishQueue, "publishQueue");
    var debug2 = noop;
    if (util11.debuglog)
      debug2 = util11.debuglog("gfs4");
    else if (/\bgfs4\b/i.test(process.env.NODE_DEBUG || ""))
      debug2 = /* @__PURE__ */ __name(function() {
        var m20 = util11.format.apply(util11, arguments);
        m20 = "GFS4: " + m20.split(/\n/).join("\nGFS4: ");
        console.error(m20);
      }, "debug");
    if (!fs51[gracefulQueue]) {
      queue = global[gracefulQueue] || [];
      publishQueue(fs51, queue);
      fs51.close = (function(fs$close) {
        function close(fd, cb) {
          return fs$close.call(fs51, fd, function(err) {
            if (!err) {
              resetQueue();
            }
            if (typeof cb === "function")
              cb.apply(this, arguments);
          });
        }
        __name(close, "close");
        Object.defineProperty(close, previousSymbol, {
          value: fs$close
        });
        return close;
      })(fs51.close);
      fs51.closeSync = (function(fs$closeSync) {
        function closeSync(fd) {
          fs$closeSync.apply(fs51, arguments);
          resetQueue();
        }
        __name(closeSync, "closeSync");
        Object.defineProperty(closeSync, previousSymbol, {
          value: fs$closeSync
        });
        return closeSync;
      })(fs51.closeSync);
      if (/\bgfs4\b/i.test(process.env.NODE_DEBUG || "")) {
        process.on("exit", function() {
          debug2(fs51[gracefulQueue]);
          require("assert").equal(fs51[gracefulQueue].length, 0);
        });
      }
    }
    var queue;
    if (!global[gracefulQueue]) {
      publishQueue(global, fs51[gracefulQueue]);
    }
    module2.exports = patch(clone(fs51));
    if (process.env.TEST_GRACEFUL_FS_GLOBAL_PATCH && !fs51.__patched) {
      module2.exports = patch(fs51);
      fs51.__patched = true;
    }
    function patch(fs52) {
      polyfills(fs52);
      fs52.gracefulify = patch;
      fs52.createReadStream = createReadStream2;
      fs52.createWriteStream = createWriteStream;
      var fs$readFile = fs52.readFile;
      fs52.readFile = readFile15;
      function readFile15(path47, options, cb) {
        if (typeof options === "function")
          cb = options, options = null;
        return go$readFile(path47, options, cb);
        function go$readFile(path48, options2, cb2, startTime) {
          return fs$readFile(path48, options2, function(err) {
            if (err && (err.code === "EMFILE" || err.code === "ENFILE"))
              enqueue([go$readFile, [path48, options2, cb2], err, startTime || Date.now(), Date.now()]);
            else {
              if (typeof cb2 === "function")
                cb2.apply(this, arguments);
            }
          });
        }
        __name(go$readFile, "go$readFile");
      }
      __name(readFile15, "readFile");
      var fs$writeFile = fs52.writeFile;
      fs52.writeFile = writeFile6;
      function writeFile6(path47, data3, options, cb) {
        if (typeof options === "function")
          cb = options, options = null;
        return go$writeFile(path47, data3, options, cb);
        function go$writeFile(path48, data4, options2, cb2, startTime) {
          return fs$writeFile(path48, data4, options2, function(err) {
            if (err && (err.code === "EMFILE" || err.code === "ENFILE"))
              enqueue([go$writeFile, [path48, data4, options2, cb2], err, startTime || Date.now(), Date.now()]);
            else {
              if (typeof cb2 === "function")
                cb2.apply(this, arguments);
            }
          });
        }
        __name(go$writeFile, "go$writeFile");
      }
      __name(writeFile6, "writeFile");
      var fs$appendFile = fs52.appendFile;
      if (fs$appendFile)
        fs52.appendFile = appendFile;
      function appendFile(path47, data3, options, cb) {
        if (typeof options === "function")
          cb = options, options = null;
        return go$appendFile(path47, data3, options, cb);
        function go$appendFile(path48, data4, options2, cb2, startTime) {
          return fs$appendFile(path48, data4, options2, function(err) {
            if (err && (err.code === "EMFILE" || err.code === "ENFILE"))
              enqueue([go$appendFile, [path48, data4, options2, cb2], err, startTime || Date.now(), Date.now()]);
            else {
              if (typeof cb2 === "function")
                cb2.apply(this, arguments);
            }
          });
        }
        __name(go$appendFile, "go$appendFile");
      }
      __name(appendFile, "appendFile");
      var fs$copyFile = fs52.copyFile;
      if (fs$copyFile)
        fs52.copyFile = copyFile;
      function copyFile(src, dest, flags, cb) {
        if (typeof flags === "function") {
          cb = flags;
          flags = 0;
        }
        return go$copyFile(src, dest, flags, cb);
        function go$copyFile(src2, dest2, flags2, cb2, startTime) {
          return fs$copyFile(src2, dest2, flags2, function(err) {
            if (err && (err.code === "EMFILE" || err.code === "ENFILE"))
              enqueue([go$copyFile, [src2, dest2, flags2, cb2], err, startTime || Date.now(), Date.now()]);
            else {
              if (typeof cb2 === "function")
                cb2.apply(this, arguments);
            }
          });
        }
        __name(go$copyFile, "go$copyFile");
      }
      __name(copyFile, "copyFile");
      var fs$readdir = fs52.readdir;
      fs52.readdir = readdir5;
      var noReaddirOptionVersions = /^v[0-5]\./;
      function readdir5(path47, options, cb) {
        if (typeof options === "function")
          cb = options, options = null;
        var go$readdir = noReaddirOptionVersions.test(process.version) ? /* @__PURE__ */ __name(function go$readdir2(path48, options2, cb2, startTime) {
          return fs$readdir(path48, fs$readdirCallback(
            path48,
            options2,
            cb2,
            startTime
          ));
        }, "go$readdir") : /* @__PURE__ */ __name(function go$readdir2(path48, options2, cb2, startTime) {
          return fs$readdir(path48, options2, fs$readdirCallback(
            path48,
            options2,
            cb2,
            startTime
          ));
        }, "go$readdir");
        return go$readdir(path47, options, cb);
        function fs$readdirCallback(path48, options2, cb2, startTime) {
          return function(err, files) {
            if (err && (err.code === "EMFILE" || err.code === "ENFILE"))
              enqueue([
                go$readdir,
                [path48, options2, cb2],
                err,
                startTime || Date.now(),
                Date.now()
              ]);
            else {
              if (files && files.sort)
                files.sort();
              if (typeof cb2 === "function")
                cb2.call(this, err, files);
            }
          };
        }
        __name(fs$readdirCallback, "fs$readdirCallback");
      }
      __name(readdir5, "readdir");
      if (process.version.substr(0, 4) === "v0.8") {
        var legStreams = legacy(fs52);
        ReadStream3 = legStreams.ReadStream;
        WriteStream = legStreams.WriteStream;
      }
      var fs$ReadStream = fs52.ReadStream;
      if (fs$ReadStream) {
        ReadStream3.prototype = Object.create(fs$ReadStream.prototype);
        ReadStream3.prototype.open = ReadStream$open;
      }
      var fs$WriteStream = fs52.WriteStream;
      if (fs$WriteStream) {
        WriteStream.prototype = Object.create(fs$WriteStream.prototype);
        WriteStream.prototype.open = WriteStream$open;
      }
      Object.defineProperty(fs52, "ReadStream", {
        get: /* @__PURE__ */ __name(function() {
          return ReadStream3;
        }, "get"),
        set: /* @__PURE__ */ __name(function(val) {
          ReadStream3 = val;
        }, "set"),
        enumerable: true,
        configurable: true
      });
      Object.defineProperty(fs52, "WriteStream", {
        get: /* @__PURE__ */ __name(function() {
          return WriteStream;
        }, "get"),
        set: /* @__PURE__ */ __name(function(val) {
          WriteStream = val;
        }, "set"),
        enumerable: true,
        configurable: true
      });
      var FileReadStream = ReadStream3;
      Object.defineProperty(fs52, "FileReadStream", {
        get: /* @__PURE__ */ __name(function() {
          return FileReadStream;
        }, "get"),
        set: /* @__PURE__ */ __name(function(val) {
          FileReadStream = val;
        }, "set"),
        enumerable: true,
        configurable: true
      });
      var FileWriteStream = WriteStream;
      Object.defineProperty(fs52, "FileWriteStream", {
        get: /* @__PURE__ */ __name(function() {
          return FileWriteStream;
        }, "get"),
        set: /* @__PURE__ */ __name(function(val) {
          FileWriteStream = val;
        }, "set"),
        enumerable: true,
        configurable: true
      });
      function ReadStream3(path47, options) {
        if (this instanceof ReadStream3)
          return fs$ReadStream.apply(this, arguments), this;
        else
          return ReadStream3.apply(Object.create(ReadStream3.prototype), arguments);
      }
      __name(ReadStream3, "ReadStream");
      function ReadStream$open() {
        var that = this;
        open2(that.path, that.flags, that.mode, function(err, fd) {
          if (err) {
            if (that.autoClose)
              that.destroy();
            that.emit("error", err);
          } else {
            that.fd = fd;
            that.emit("open", fd);
            that.read();
          }
        });
      }
      __name(ReadStream$open, "ReadStream$open");
      function WriteStream(path47, options) {
        if (this instanceof WriteStream)
          return fs$WriteStream.apply(this, arguments), this;
        else
          return WriteStream.apply(Object.create(WriteStream.prototype), arguments);
      }
      __name(WriteStream, "WriteStream");
      function WriteStream$open() {
        var that = this;
        open2(that.path, that.flags, that.mode, function(err, fd) {
          if (err) {
            that.destroy();
            that.emit("error", err);
          } else {
            that.fd = fd;
            that.emit("open", fd);
          }
        });
      }
      __name(WriteStream$open, "WriteStream$open");
      function createReadStream2(path47, options) {
        return new fs52.ReadStream(path47, options);
      }
      __name(createReadStream2, "createReadStream");
      function createWriteStream(path47, options) {
        return new fs52.WriteStream(path47, options);
      }
      __name(createWriteStream, "createWriteStream");
      var fs$open = fs52.open;
      fs52.open = open2;
      function open2(path47, flags, mode, cb) {
        if (typeof mode === "function")
          cb = mode, mode = null;
        return go$open(path47, flags, mode, cb);
        function go$open(path48, flags2, mode2, cb2, startTime) {
          return fs$open(path48, flags2, mode2, function(err, fd) {
            if (err && (err.code === "EMFILE" || err.code === "ENFILE"))
              enqueue([go$open, [path48, flags2, mode2, cb2], err, startTime || Date.now(), Date.now()]);
            else {
              if (typeof cb2 === "function")
                cb2.apply(this, arguments);
            }
          });
        }
        __name(go$open, "go$open");
      }
      __name(open2, "open");
      return fs52;
    }
    __name(patch, "patch");
    function enqueue(elem) {
      debug2("ENQUEUE", elem[0].name, elem[1]);
      fs51[gracefulQueue].push(elem);
      retry();
    }
    __name(enqueue, "enqueue");
    var retryTimer;
    function resetQueue() {
      var now = Date.now();
      for (var i32 = 0; i32 < fs51[gracefulQueue].length; ++i32) {
        if (fs51[gracefulQueue][i32].length > 2) {
          fs51[gracefulQueue][i32][3] = now;
          fs51[gracefulQueue][i32][4] = now;
        }
      }
      retry();
    }
    __name(resetQueue, "resetQueue");
    function retry() {
      clearTimeout(retryTimer);
      retryTimer = void 0;
      if (fs51[gracefulQueue].length === 0)
        return;
      var elem = fs51[gracefulQueue].shift();
      var fn = elem[0];
      var args = elem[1];
      var err = elem[2];
      var startTime = elem[3];
      var lastTime = elem[4];
      if (startTime === void 0) {
        debug2("RETRY", fn.name, args);
        fn.apply(null, args);
      } else if (Date.now() - startTime >= 6e4) {
        debug2("TIMEOUT", fn.name, args);
        var cb = args.pop();
        if (typeof cb === "function")
          cb.call(null, err);
      } else {
        var sinceAttempt = Date.now() - lastTime;
        var sinceStart = Math.max(lastTime - startTime, 1);
        var desiredDelay = Math.min(sinceStart * 1.2, 100);
        if (sinceAttempt >= desiredDelay) {
          debug2("RETRY", fn.name, args);
          fn.apply(null, args.concat([startTime]));
        } else {
          fs51[gracefulQueue].push(elem);
        }
      }
      if (retryTimer === void 0) {
        retryTimer = setTimeout(retry, 0);
      }
    }
    __name(retry, "retry");
  }
});

// ../../node_modules/fs-extra/lib/fs/index.js
var require_fs = __commonJS({
  "../../node_modules/fs-extra/lib/fs/index.js"(exports2) {
    "use strict";
    var u = require_universalify().fromCallback;
    var fs51 = require_graceful_fs();
    var api = [
      "access",
      "appendFile",
      "chmod",
      "chown",
      "close",
      "copyFile",
      "cp",
      "fchmod",
      "fchown",
      "fdatasync",
      "fstat",
      "fsync",
      "ftruncate",
      "futimes",
      "glob",
      "lchmod",
      "lchown",
      "lutimes",
      "link",
      "lstat",
      "mkdir",
      "mkdtemp",
      "open",
      "opendir",
      "readdir",
      "readFile",
      "readlink",
      "realpath",
      "rename",
      "rm",
      "rmdir",
      "stat",
      "statfs",
      "symlink",
      "truncate",
      "unlink",
      "utimes",
      "writeFile"
    ].filter((key) => {
      return typeof fs51[key] === "function";
    });
    Object.assign(exports2, fs51);
    api.forEach((method) => {
      exports2[method] = u(fs51[method]);
    });
    exports2.exists = function(filename, callback) {
      if (typeof callback === "function") {
        return fs51.exists(filename, callback);
      }
      return new Promise((resolve13) => {
        return fs51.exists(filename, resolve13);
      });
    };
    exports2.read = function(fd, buffer, offset, length, position, callback) {
      if (typeof callback === "function") {
        return fs51.read(fd, buffer, offset, length, position, callback);
      }
      return new Promise((resolve13, reject) => {
        fs51.read(fd, buffer, offset, length, position, (err, bytesRead, buffer2) => {
          if (err) return reject(err);
          resolve13({ bytesRead, buffer: buffer2 });
        });
      });
    };
    exports2.write = function(fd, buffer, ...args) {
      if (typeof args[args.length - 1] === "function") {
        return fs51.write(fd, buffer, ...args);
      }
      return new Promise((resolve13, reject) => {
        fs51.write(fd, buffer, ...args, (err, bytesWritten, buffer2) => {
          if (err) return reject(err);
          resolve13({ bytesWritten, buffer: buffer2 });
        });
      });
    };
    exports2.readv = function(fd, buffers, ...args) {
      if (typeof args[args.length - 1] === "function") {
        return fs51.readv(fd, buffers, ...args);
      }
      return new Promise((resolve13, reject) => {
        fs51.readv(fd, buffers, ...args, (err, bytesRead, buffers2) => {
          if (err) return reject(err);
          resolve13({ bytesRead, buffers: buffers2 });
        });
      });
    };
    exports2.writev = function(fd, buffers, ...args) {
      if (typeof args[args.length - 1] === "function") {
        return fs51.writev(fd, buffers, ...args);
      }
      return new Promise((resolve13, reject) => {
        fs51.writev(fd, buffers, ...args, (err, bytesWritten, buffers2) => {
          if (err) return reject(err);
          resolve13({ bytesWritten, buffers: buffers2 });
        });
      });
    };
    if (typeof fs51.realpath.native === "function") {
      exports2.realpath.native = u(fs51.realpath.native);
    } else {
      process.emitWarning(
        "fs.realpath.native is not a function. Is fs being monkey-patched?",
        "Warning",
        "fs-extra-WARN0003"
      );
    }
  }
});

// ../../node_modules/fs-extra/lib/mkdirs/utils.js
var require_utils = __commonJS({
  "../../node_modules/fs-extra/lib/mkdirs/utils.js"(exports2, module2) {
    "use strict";
    var path47 = require("path");
    module2.exports.checkPath = /* @__PURE__ */ __name(function checkPath(pth) {
      if (process.platform === "win32") {
        const pathHasInvalidWinCharacters = /[<>:"|?*]/.test(pth.replace(path47.parse(pth).root, ""));
        if (pathHasInvalidWinCharacters) {
          const error4 = new Error(`Path contains invalid characters: ${pth}`);
          error4.code = "EINVAL";
          throw error4;
        }
      }
    }, "checkPath");
  }
});

// ../../node_modules/fs-extra/lib/mkdirs/make-dir.js
var require_make_dir = __commonJS({
  "../../node_modules/fs-extra/lib/mkdirs/make-dir.js"(exports2, module2) {
    "use strict";
    var fs51 = require_fs();
    var { checkPath } = require_utils();
    var getMode = /* @__PURE__ */ __name((options) => {
      const defaults = { mode: 511 };
      if (typeof options === "number") return options;
      return { ...defaults, ...options }.mode;
    }, "getMode");
    module2.exports.makeDir = async (dir, options) => {
      checkPath(dir);
      return fs51.mkdir(dir, {
        mode: getMode(options),
        recursive: true
      });
    };
    module2.exports.makeDirSync = (dir, options) => {
      checkPath(dir);
      return fs51.mkdirSync(dir, {
        mode: getMode(options),
        recursive: true
      });
    };
  }
});

// ../../node_modules/fs-extra/lib/mkdirs/index.js
var require_mkdirs = __commonJS({
  "../../node_modules/fs-extra/lib/mkdirs/index.js"(exports2, module2) {
    "use strict";
    var u = require_universalify().fromPromise;
    var { makeDir: _makeDir, makeDirSync } = require_make_dir();
    var makeDir = u(_makeDir);
    module2.exports = {
      mkdirs: makeDir,
      mkdirsSync: makeDirSync,
      // alias
      mkdirp: makeDir,
      mkdirpSync: makeDirSync,
      ensureDir: makeDir,
      ensureDirSync: makeDirSync
    };
  }
});

// ../../node_modules/fs-extra/lib/path-exists/index.js
var require_path_exists = __commonJS({
  "../../node_modules/fs-extra/lib/path-exists/index.js"(exports2, module2) {
    "use strict";
    var u = require_universalify().fromPromise;
    var fs51 = require_fs();
    function pathExists9(path47) {
      return fs51.access(path47).then(() => true).catch(() => false);
    }
    __name(pathExists9, "pathExists");
    module2.exports = {
      pathExists: u(pathExists9),
      pathExistsSync: fs51.existsSync
    };
  }
});

// ../../node_modules/fs-extra/lib/util/utimes.js
var require_utimes = __commonJS({
  "../../node_modules/fs-extra/lib/util/utimes.js"(exports2, module2) {
    "use strict";
    var fs51 = require_fs();
    var u = require_universalify().fromPromise;
    async function utimesMillis(path47, atime, mtime) {
      const fd = await fs51.open(path47, "r+");
      let closeErr = null;
      try {
        await fs51.futimes(fd, atime, mtime);
      } finally {
        try {
          await fs51.close(fd);
        } catch (e32) {
          closeErr = e32;
        }
      }
      if (closeErr) {
        throw closeErr;
      }
    }
    __name(utimesMillis, "utimesMillis");
    function utimesMillisSync(path47, atime, mtime) {
      const fd = fs51.openSync(path47, "r+");
      fs51.futimesSync(fd, atime, mtime);
      return fs51.closeSync(fd);
    }
    __name(utimesMillisSync, "utimesMillisSync");
    module2.exports = {
      utimesMillis: u(utimesMillis),
      utimesMillisSync
    };
  }
});

// ../../node_modules/fs-extra/lib/util/stat.js
var require_stat = __commonJS({
  "../../node_modules/fs-extra/lib/util/stat.js"(exports2, module2) {
    "use strict";
    var fs51 = require_fs();
    var path47 = require("path");
    var u = require_universalify().fromPromise;
    function getStats(src, dest, opts) {
      const statFunc = opts.dereference ? (file) => fs51.stat(file, { bigint: true }) : (file) => fs51.lstat(file, { bigint: true });
      return Promise.all([
        statFunc(src),
        statFunc(dest).catch((err) => {
          if (err.code === "ENOENT") return null;
          throw err;
        })
      ]).then(([srcStat, destStat]) => ({ srcStat, destStat }));
    }
    __name(getStats, "getStats");
    function getStatsSync(src, dest, opts) {
      let destStat;
      const statFunc = opts.dereference ? (file) => fs51.statSync(file, { bigint: true }) : (file) => fs51.lstatSync(file, { bigint: true });
      const srcStat = statFunc(src);
      try {
        destStat = statFunc(dest);
      } catch (err) {
        if (err.code === "ENOENT") return { srcStat, destStat: null };
        throw err;
      }
      return { srcStat, destStat };
    }
    __name(getStatsSync, "getStatsSync");
    async function checkPaths(src, dest, funcName, opts) {
      const { srcStat, destStat } = await getStats(src, dest, opts);
      if (destStat) {
        if (areIdentical(srcStat, destStat)) {
          const srcBaseName = path47.basename(src);
          const destBaseName = path47.basename(dest);
          if (funcName === "move" && srcBaseName !== destBaseName && srcBaseName.toLowerCase() === destBaseName.toLowerCase()) {
            return { srcStat, destStat, isChangingCase: true };
          }
          throw new Error("Source and destination must not be the same.");
        }
        if (srcStat.isDirectory() && !destStat.isDirectory()) {
          throw new Error(`Cannot overwrite non-directory '${dest}' with directory '${src}'.`);
        }
        if (!srcStat.isDirectory() && destStat.isDirectory()) {
          throw new Error(`Cannot overwrite directory '${dest}' with non-directory '${src}'.`);
        }
      }
      if (srcStat.isDirectory() && isSrcSubdir(src, dest)) {
        throw new Error(errMsg(src, dest, funcName));
      }
      return { srcStat, destStat };
    }
    __name(checkPaths, "checkPaths");
    function checkPathsSync(src, dest, funcName, opts) {
      const { srcStat, destStat } = getStatsSync(src, dest, opts);
      if (destStat) {
        if (areIdentical(srcStat, destStat)) {
          const srcBaseName = path47.basename(src);
          const destBaseName = path47.basename(dest);
          if (funcName === "move" && srcBaseName !== destBaseName && srcBaseName.toLowerCase() === destBaseName.toLowerCase()) {
            return { srcStat, destStat, isChangingCase: true };
          }
          throw new Error("Source and destination must not be the same.");
        }
        if (srcStat.isDirectory() && !destStat.isDirectory()) {
          throw new Error(`Cannot overwrite non-directory '${dest}' with directory '${src}'.`);
        }
        if (!srcStat.isDirectory() && destStat.isDirectory()) {
          throw new Error(`Cannot overwrite directory '${dest}' with non-directory '${src}'.`);
        }
      }
      if (srcStat.isDirectory() && isSrcSubdir(src, dest)) {
        throw new Error(errMsg(src, dest, funcName));
      }
      return { srcStat, destStat };
    }
    __name(checkPathsSync, "checkPathsSync");
    async function checkParentPaths(src, srcStat, dest, funcName) {
      const srcParent = path47.resolve(path47.dirname(src));
      const destParent = path47.resolve(path47.dirname(dest));
      if (destParent === srcParent || destParent === path47.parse(destParent).root) return;
      let destStat;
      try {
        destStat = await fs51.stat(destParent, { bigint: true });
      } catch (err) {
        if (err.code === "ENOENT") return;
        throw err;
      }
      if (areIdentical(srcStat, destStat)) {
        throw new Error(errMsg(src, dest, funcName));
      }
      return checkParentPaths(src, srcStat, destParent, funcName);
    }
    __name(checkParentPaths, "checkParentPaths");
    function checkParentPathsSync(src, srcStat, dest, funcName) {
      const srcParent = path47.resolve(path47.dirname(src));
      const destParent = path47.resolve(path47.dirname(dest));
      if (destParent === srcParent || destParent === path47.parse(destParent).root) return;
      let destStat;
      try {
        destStat = fs51.statSync(destParent, { bigint: true });
      } catch (err) {
        if (err.code === "ENOENT") return;
        throw err;
      }
      if (areIdentical(srcStat, destStat)) {
        throw new Error(errMsg(src, dest, funcName));
      }
      return checkParentPathsSync(src, srcStat, destParent, funcName);
    }
    __name(checkParentPathsSync, "checkParentPathsSync");
    function areIdentical(srcStat, destStat) {
      return destStat.ino !== void 0 && destStat.dev !== void 0 && destStat.ino === srcStat.ino && destStat.dev === srcStat.dev;
    }
    __name(areIdentical, "areIdentical");
    function isSrcSubdir(src, dest) {
      const srcArr = path47.resolve(src).split(path47.sep).filter((i32) => i32);
      const destArr = path47.resolve(dest).split(path47.sep).filter((i32) => i32);
      return srcArr.every((cur, i32) => destArr[i32] === cur);
    }
    __name(isSrcSubdir, "isSrcSubdir");
    function errMsg(src, dest, funcName) {
      return `Cannot ${funcName} '${src}' to a subdirectory of itself, '${dest}'.`;
    }
    __name(errMsg, "errMsg");
    module2.exports = {
      // checkPaths
      checkPaths: u(checkPaths),
      checkPathsSync,
      // checkParent
      checkParentPaths: u(checkParentPaths),
      checkParentPathsSync,
      // Misc
      isSrcSubdir,
      areIdentical
    };
  }
});

// ../../node_modules/fs-extra/lib/util/async.js
var require_async = __commonJS({
  "../../node_modules/fs-extra/lib/util/async.js"(exports2, module2) {
    "use strict";
    async function asyncIteratorConcurrentProcess(iterator, fn) {
      const promises5 = [];
      for await (const item of iterator) {
        promises5.push(
          fn(item).then(
            () => null,
            (err) => err ?? new Error("unknown error")
          )
        );
      }
      await Promise.all(
        promises5.map(
          (promise) => promise.then((possibleErr) => {
            if (possibleErr !== null) throw possibleErr;
          })
        )
      );
    }
    __name(asyncIteratorConcurrentProcess, "asyncIteratorConcurrentProcess");
    module2.exports = {
      asyncIteratorConcurrentProcess
    };
  }
});

// ../../node_modules/fs-extra/lib/copy/copy.js
var require_copy = __commonJS({
  "../../node_modules/fs-extra/lib/copy/copy.js"(exports2, module2) {
    "use strict";
    var fs51 = require_fs();
    var path47 = require("path");
    var { mkdirs } = require_mkdirs();
    var { pathExists: pathExists9 } = require_path_exists();
    var { utimesMillis } = require_utimes();
    var stat8 = require_stat();
    var { asyncIteratorConcurrentProcess } = require_async();
    async function copy2(src, dest, opts = {}) {
      if (typeof opts === "function") {
        opts = { filter: opts };
      }
      opts.clobber = "clobber" in opts ? !!opts.clobber : true;
      opts.overwrite = "overwrite" in opts ? !!opts.overwrite : opts.clobber;
      if (opts.preserveTimestamps && process.arch === "ia32") {
        process.emitWarning(
          "Using the preserveTimestamps option in 32-bit node is not recommended;\n\n	see https://github.com/jprichardson/node-fs-extra/issues/269",
          "Warning",
          "fs-extra-WARN0001"
        );
      }
      const { srcStat, destStat } = await stat8.checkPaths(src, dest, "copy", opts);
      await stat8.checkParentPaths(src, srcStat, dest, "copy");
      const include = await runFilter(src, dest, opts);
      if (!include) return;
      const destParent = path47.dirname(dest);
      const dirExists = await pathExists9(destParent);
      if (!dirExists) {
        await mkdirs(destParent);
      }
      await getStatsAndPerformCopy(destStat, src, dest, opts);
    }
    __name(copy2, "copy");
    async function runFilter(src, dest, opts) {
      if (!opts.filter) return true;
      return opts.filter(src, dest);
    }
    __name(runFilter, "runFilter");
    async function getStatsAndPerformCopy(destStat, src, dest, opts) {
      const statFn = opts.dereference ? fs51.stat : fs51.lstat;
      const srcStat = await statFn(src);
      if (srcStat.isDirectory()) return onDir(srcStat, destStat, src, dest, opts);
      if (srcStat.isFile() || srcStat.isCharacterDevice() || srcStat.isBlockDevice()) return onFile(srcStat, destStat, src, dest, opts);
      if (srcStat.isSymbolicLink()) return onLink(destStat, src, dest, opts);
      if (srcStat.isSocket()) throw new Error(`Cannot copy a socket file: ${src}`);
      if (srcStat.isFIFO()) throw new Error(`Cannot copy a FIFO pipe: ${src}`);
      throw new Error(`Unknown file: ${src}`);
    }
    __name(getStatsAndPerformCopy, "getStatsAndPerformCopy");
    async function onFile(srcStat, destStat, src, dest, opts) {
      if (!destStat) return copyFile(srcStat, src, dest, opts);
      if (opts.overwrite) {
        await fs51.unlink(dest);
        return copyFile(srcStat, src, dest, opts);
      }
      if (opts.errorOnExist) {
        throw new Error(`'${dest}' already exists`);
      }
    }
    __name(onFile, "onFile");
    async function copyFile(srcStat, src, dest, opts) {
      await fs51.copyFile(src, dest);
      if (opts.preserveTimestamps) {
        if (fileIsNotWritable(srcStat.mode)) {
          await makeFileWritable(dest, srcStat.mode);
        }
        const updatedSrcStat = await fs51.stat(src);
        await utimesMillis(dest, updatedSrcStat.atime, updatedSrcStat.mtime);
      }
      return fs51.chmod(dest, srcStat.mode);
    }
    __name(copyFile, "copyFile");
    function fileIsNotWritable(srcMode) {
      return (srcMode & 128) === 0;
    }
    __name(fileIsNotWritable, "fileIsNotWritable");
    function makeFileWritable(dest, srcMode) {
      return fs51.chmod(dest, srcMode | 128);
    }
    __name(makeFileWritable, "makeFileWritable");
    async function onDir(srcStat, destStat, src, dest, opts) {
      if (!destStat) {
        await fs51.mkdir(dest);
      }
      await asyncIteratorConcurrentProcess(await fs51.opendir(src), async (item) => {
        const srcItem = path47.join(src, item.name);
        const destItem = path47.join(dest, item.name);
        const include = await runFilter(srcItem, destItem, opts);
        if (include) {
          const { destStat: destStat2 } = await stat8.checkPaths(srcItem, destItem, "copy", opts);
          await getStatsAndPerformCopy(destStat2, srcItem, destItem, opts);
        }
      });
      if (!destStat) {
        await fs51.chmod(dest, srcStat.mode);
      }
    }
    __name(onDir, "onDir");
    async function onLink(destStat, src, dest, opts) {
      let resolvedSrc = await fs51.readlink(src);
      if (opts.dereference) {
        resolvedSrc = path47.resolve(process.cwd(), resolvedSrc);
      }
      if (!destStat) {
        return fs51.symlink(resolvedSrc, dest);
      }
      let resolvedDest = null;
      try {
        resolvedDest = await fs51.readlink(dest);
      } catch (e32) {
        if (e32.code === "EINVAL" || e32.code === "UNKNOWN") return fs51.symlink(resolvedSrc, dest);
        throw e32;
      }
      if (opts.dereference) {
        resolvedDest = path47.resolve(process.cwd(), resolvedDest);
      }
      if (resolvedSrc !== resolvedDest) {
        if (stat8.isSrcSubdir(resolvedSrc, resolvedDest)) {
          throw new Error(`Cannot copy '${resolvedSrc}' to a subdirectory of itself, '${resolvedDest}'.`);
        }
        if (stat8.isSrcSubdir(resolvedDest, resolvedSrc)) {
          throw new Error(`Cannot overwrite '${resolvedDest}' with '${resolvedSrc}'.`);
        }
      }
      await fs51.unlink(dest);
      return fs51.symlink(resolvedSrc, dest);
    }
    __name(onLink, "onLink");
    module2.exports = copy2;
  }
});

// ../../node_modules/fs-extra/lib/copy/copy-sync.js
var require_copy_sync = __commonJS({
  "../../node_modules/fs-extra/lib/copy/copy-sync.js"(exports2, module2) {
    "use strict";
    var fs51 = require_graceful_fs();
    var path47 = require("path");
    var mkdirsSync2 = require_mkdirs().mkdirsSync;
    var utimesMillisSync = require_utimes().utimesMillisSync;
    var stat8 = require_stat();
    function copySync(src, dest, opts) {
      if (typeof opts === "function") {
        opts = { filter: opts };
      }
      opts = opts || {};
      opts.clobber = "clobber" in opts ? !!opts.clobber : true;
      opts.overwrite = "overwrite" in opts ? !!opts.overwrite : opts.clobber;
      if (opts.preserveTimestamps && process.arch === "ia32") {
        process.emitWarning(
          "Using the preserveTimestamps option in 32-bit node is not recommended;\n\n	see https://github.com/jprichardson/node-fs-extra/issues/269",
          "Warning",
          "fs-extra-WARN0002"
        );
      }
      const { srcStat, destStat } = stat8.checkPathsSync(src, dest, "copy", opts);
      stat8.checkParentPathsSync(src, srcStat, dest, "copy");
      if (opts.filter && !opts.filter(src, dest)) return;
      const destParent = path47.dirname(dest);
      if (!fs51.existsSync(destParent)) mkdirsSync2(destParent);
      return getStats(destStat, src, dest, opts);
    }
    __name(copySync, "copySync");
    function getStats(destStat, src, dest, opts) {
      const statSync3 = opts.dereference ? fs51.statSync : fs51.lstatSync;
      const srcStat = statSync3(src);
      if (srcStat.isDirectory()) return onDir(srcStat, destStat, src, dest, opts);
      else if (srcStat.isFile() || srcStat.isCharacterDevice() || srcStat.isBlockDevice()) return onFile(srcStat, destStat, src, dest, opts);
      else if (srcStat.isSymbolicLink()) return onLink(destStat, src, dest, opts);
      else if (srcStat.isSocket()) throw new Error(`Cannot copy a socket file: ${src}`);
      else if (srcStat.isFIFO()) throw new Error(`Cannot copy a FIFO pipe: ${src}`);
      throw new Error(`Unknown file: ${src}`);
    }
    __name(getStats, "getStats");
    function onFile(srcStat, destStat, src, dest, opts) {
      if (!destStat) return copyFile(srcStat, src, dest, opts);
      return mayCopyFile(srcStat, src, dest, opts);
    }
    __name(onFile, "onFile");
    function mayCopyFile(srcStat, src, dest, opts) {
      if (opts.overwrite) {
        fs51.unlinkSync(dest);
        return copyFile(srcStat, src, dest, opts);
      } else if (opts.errorOnExist) {
        throw new Error(`'${dest}' already exists`);
      }
    }
    __name(mayCopyFile, "mayCopyFile");
    function copyFile(srcStat, src, dest, opts) {
      fs51.copyFileSync(src, dest);
      if (opts.preserveTimestamps) handleTimestamps(srcStat.mode, src, dest);
      return setDestMode(dest, srcStat.mode);
    }
    __name(copyFile, "copyFile");
    function handleTimestamps(srcMode, src, dest) {
      if (fileIsNotWritable(srcMode)) makeFileWritable(dest, srcMode);
      return setDestTimestamps(src, dest);
    }
    __name(handleTimestamps, "handleTimestamps");
    function fileIsNotWritable(srcMode) {
      return (srcMode & 128) === 0;
    }
    __name(fileIsNotWritable, "fileIsNotWritable");
    function makeFileWritable(dest, srcMode) {
      return setDestMode(dest, srcMode | 128);
    }
    __name(makeFileWritable, "makeFileWritable");
    function setDestMode(dest, srcMode) {
      return fs51.chmodSync(dest, srcMode);
    }
    __name(setDestMode, "setDestMode");
    function setDestTimestamps(src, dest) {
      const updatedSrcStat = fs51.statSync(src);
      return utimesMillisSync(dest, updatedSrcStat.atime, updatedSrcStat.mtime);
    }
    __name(setDestTimestamps, "setDestTimestamps");
    function onDir(srcStat, destStat, src, dest, opts) {
      if (!destStat) return mkDirAndCopy(srcStat.mode, src, dest, opts);
      return copyDir(src, dest, opts);
    }
    __name(onDir, "onDir");
    function mkDirAndCopy(srcMode, src, dest, opts) {
      fs51.mkdirSync(dest);
      copyDir(src, dest, opts);
      return setDestMode(dest, srcMode);
    }
    __name(mkDirAndCopy, "mkDirAndCopy");
    function copyDir(src, dest, opts) {
      const dir = fs51.opendirSync(src);
      try {
        let dirent;
        while ((dirent = dir.readSync()) !== null) {
          copyDirItem(dirent.name, src, dest, opts);
        }
      } finally {
        dir.closeSync();
      }
    }
    __name(copyDir, "copyDir");
    function copyDirItem(item, src, dest, opts) {
      const srcItem = path47.join(src, item);
      const destItem = path47.join(dest, item);
      if (opts.filter && !opts.filter(srcItem, destItem)) return;
      const { destStat } = stat8.checkPathsSync(srcItem, destItem, "copy", opts);
      return getStats(destStat, srcItem, destItem, opts);
    }
    __name(copyDirItem, "copyDirItem");
    function onLink(destStat, src, dest, opts) {
      let resolvedSrc = fs51.readlinkSync(src);
      if (opts.dereference) {
        resolvedSrc = path47.resolve(process.cwd(), resolvedSrc);
      }
      if (!destStat) {
        return fs51.symlinkSync(resolvedSrc, dest);
      } else {
        let resolvedDest;
        try {
          resolvedDest = fs51.readlinkSync(dest);
        } catch (err) {
          if (err.code === "EINVAL" || err.code === "UNKNOWN") return fs51.symlinkSync(resolvedSrc, dest);
          throw err;
        }
        if (opts.dereference) {
          resolvedDest = path47.resolve(process.cwd(), resolvedDest);
        }
        if (resolvedSrc !== resolvedDest) {
          if (stat8.isSrcSubdir(resolvedSrc, resolvedDest)) {
            throw new Error(`Cannot copy '${resolvedSrc}' to a subdirectory of itself, '${resolvedDest}'.`);
          }
          if (stat8.isSrcSubdir(resolvedDest, resolvedSrc)) {
            throw new Error(`Cannot overwrite '${resolvedDest}' with '${resolvedSrc}'.`);
          }
        }
        return copyLink(resolvedSrc, dest);
      }
    }
    __name(onLink, "onLink");
    function copyLink(resolvedSrc, dest) {
      fs51.unlinkSync(dest);
      return fs51.symlinkSync(resolvedSrc, dest);
    }
    __name(copyLink, "copyLink");
    module2.exports = copySync;
  }
});

// ../../node_modules/fs-extra/lib/copy/index.js
var require_copy2 = __commonJS({
  "../../node_modules/fs-extra/lib/copy/index.js"(exports2, module2) {
    "use strict";
    var u = require_universalify().fromPromise;
    module2.exports = {
      copy: u(require_copy()),
      copySync: require_copy_sync()
    };
  }
});

// ../../node_modules/fs-extra/lib/remove/index.js
var require_remove = __commonJS({
  "../../node_modules/fs-extra/lib/remove/index.js"(exports2, module2) {
    "use strict";
    var fs51 = require_graceful_fs();
    var u = require_universalify().fromCallback;
    function remove2(path47, callback) {
      fs51.rm(path47, { recursive: true, force: true }, callback);
    }
    __name(remove2, "remove");
    function removeSync(path47) {
      fs51.rmSync(path47, { recursive: true, force: true });
    }
    __name(removeSync, "removeSync");
    module2.exports = {
      remove: u(remove2),
      removeSync
    };
  }
});

// ../../node_modules/fs-extra/lib/empty/index.js
var require_empty = __commonJS({
  "../../node_modules/fs-extra/lib/empty/index.js"(exports2, module2) {
    "use strict";
    var u = require_universalify().fromPromise;
    var fs51 = require_fs();
    var path47 = require("path");
    var mkdir2 = require_mkdirs();
    var remove2 = require_remove();
    var emptyDir = u(/* @__PURE__ */ __name(async function emptyDir2(dir) {
      let items;
      try {
        items = await fs51.readdir(dir);
      } catch {
        return mkdir2.mkdirs(dir);
      }
      return Promise.all(items.map((item) => remove2.remove(path47.join(dir, item))));
    }, "emptyDir"));
    function emptyDirSync(dir) {
      let items;
      try {
        items = fs51.readdirSync(dir);
      } catch {
        return mkdir2.mkdirsSync(dir);
      }
      items.forEach((item) => {
        item = path47.join(dir, item);
        remove2.removeSync(item);
      });
    }
    __name(emptyDirSync, "emptyDirSync");
    module2.exports = {
      emptyDirSync,
      emptydirSync: emptyDirSync,
      emptyDir,
      emptydir: emptyDir
    };
  }
});

// ../../node_modules/fs-extra/lib/ensure/file.js
var require_file = __commonJS({
  "../../node_modules/fs-extra/lib/ensure/file.js"(exports2, module2) {
    "use strict";
    var u = require_universalify().fromPromise;
    var path47 = require("path");
    var fs51 = require_fs();
    var mkdir2 = require_mkdirs();
    async function createFile(file) {
      let stats;
      try {
        stats = await fs51.stat(file);
      } catch {
      }
      if (stats && stats.isFile()) return;
      const dir = path47.dirname(file);
      let dirStats = null;
      try {
        dirStats = await fs51.stat(dir);
      } catch (err) {
        if (err.code === "ENOENT") {
          await mkdir2.mkdirs(dir);
          await fs51.writeFile(file, "");
          return;
        } else {
          throw err;
        }
      }
      if (dirStats.isDirectory()) {
        await fs51.writeFile(file, "");
      } else {
        await fs51.readdir(dir);
      }
    }
    __name(createFile, "createFile");
    function createFileSync(file) {
      let stats;
      try {
        stats = fs51.statSync(file);
      } catch {
      }
      if (stats && stats.isFile()) return;
      const dir = path47.dirname(file);
      try {
        if (!fs51.statSync(dir).isDirectory()) {
          fs51.readdirSync(dir);
        }
      } catch (err) {
        if (err && err.code === "ENOENT") mkdir2.mkdirsSync(dir);
        else throw err;
      }
      fs51.writeFileSync(file, "");
    }
    __name(createFileSync, "createFileSync");
    module2.exports = {
      createFile: u(createFile),
      createFileSync
    };
  }
});

// ../../node_modules/fs-extra/lib/ensure/link.js
var require_link = __commonJS({
  "../../node_modules/fs-extra/lib/ensure/link.js"(exports2, module2) {
    "use strict";
    var u = require_universalify().fromPromise;
    var path47 = require("path");
    var fs51 = require_fs();
    var mkdir2 = require_mkdirs();
    var { pathExists: pathExists9 } = require_path_exists();
    var { areIdentical } = require_stat();
    async function createLink(srcpath, dstpath) {
      let dstStat;
      try {
        dstStat = await fs51.lstat(dstpath);
      } catch {
      }
      let srcStat;
      try {
        srcStat = await fs51.lstat(srcpath);
      } catch (err) {
        err.message = err.message.replace("lstat", "ensureLink");
        throw err;
      }
      if (dstStat && areIdentical(srcStat, dstStat)) return;
      const dir = path47.dirname(dstpath);
      const dirExists = await pathExists9(dir);
      if (!dirExists) {
        await mkdir2.mkdirs(dir);
      }
      await fs51.link(srcpath, dstpath);
    }
    __name(createLink, "createLink");
    function createLinkSync(srcpath, dstpath) {
      let dstStat;
      try {
        dstStat = fs51.lstatSync(dstpath);
      } catch {
      }
      try {
        const srcStat = fs51.lstatSync(srcpath);
        if (dstStat && areIdentical(srcStat, dstStat)) return;
      } catch (err) {
        err.message = err.message.replace("lstat", "ensureLink");
        throw err;
      }
      const dir = path47.dirname(dstpath);
      const dirExists = fs51.existsSync(dir);
      if (dirExists) return fs51.linkSync(srcpath, dstpath);
      mkdir2.mkdirsSync(dir);
      return fs51.linkSync(srcpath, dstpath);
    }
    __name(createLinkSync, "createLinkSync");
    module2.exports = {
      createLink: u(createLink),
      createLinkSync
    };
  }
});

// ../../node_modules/fs-extra/lib/ensure/symlink-paths.js
var require_symlink_paths = __commonJS({
  "../../node_modules/fs-extra/lib/ensure/symlink-paths.js"(exports2, module2) {
    "use strict";
    var path47 = require("path");
    var fs51 = require_fs();
    var { pathExists: pathExists9 } = require_path_exists();
    var u = require_universalify().fromPromise;
    async function symlinkPaths(srcpath, dstpath) {
      if (path47.isAbsolute(srcpath)) {
        try {
          await fs51.lstat(srcpath);
        } catch (err) {
          err.message = err.message.replace("lstat", "ensureSymlink");
          throw err;
        }
        return {
          toCwd: srcpath,
          toDst: srcpath
        };
      }
      const dstdir = path47.dirname(dstpath);
      const relativeToDst = path47.join(dstdir, srcpath);
      const exists = await pathExists9(relativeToDst);
      if (exists) {
        return {
          toCwd: relativeToDst,
          toDst: srcpath
        };
      }
      try {
        await fs51.lstat(srcpath);
      } catch (err) {
        err.message = err.message.replace("lstat", "ensureSymlink");
        throw err;
      }
      return {
        toCwd: srcpath,
        toDst: path47.relative(dstdir, srcpath)
      };
    }
    __name(symlinkPaths, "symlinkPaths");
    function symlinkPathsSync(srcpath, dstpath) {
      if (path47.isAbsolute(srcpath)) {
        const exists2 = fs51.existsSync(srcpath);
        if (!exists2) throw new Error("absolute srcpath does not exist");
        return {
          toCwd: srcpath,
          toDst: srcpath
        };
      }
      const dstdir = path47.dirname(dstpath);
      const relativeToDst = path47.join(dstdir, srcpath);
      const exists = fs51.existsSync(relativeToDst);
      if (exists) {
        return {
          toCwd: relativeToDst,
          toDst: srcpath
        };
      }
      const srcExists = fs51.existsSync(srcpath);
      if (!srcExists) throw new Error("relative srcpath does not exist");
      return {
        toCwd: srcpath,
        toDst: path47.relative(dstdir, srcpath)
      };
    }
    __name(symlinkPathsSync, "symlinkPathsSync");
    module2.exports = {
      symlinkPaths: u(symlinkPaths),
      symlinkPathsSync
    };
  }
});

// ../../node_modules/fs-extra/lib/ensure/symlink-type.js
var require_symlink_type = __commonJS({
  "../../node_modules/fs-extra/lib/ensure/symlink-type.js"(exports2, module2) {
    "use strict";
    var fs51 = require_fs();
    var u = require_universalify().fromPromise;
    async function symlinkType(srcpath, type) {
      if (type) return type;
      let stats;
      try {
        stats = await fs51.lstat(srcpath);
      } catch {
        return "file";
      }
      return stats && stats.isDirectory() ? "dir" : "file";
    }
    __name(symlinkType, "symlinkType");
    function symlinkTypeSync(srcpath, type) {
      if (type) return type;
      let stats;
      try {
        stats = fs51.lstatSync(srcpath);
      } catch {
        return "file";
      }
      return stats && stats.isDirectory() ? "dir" : "file";
    }
    __name(symlinkTypeSync, "symlinkTypeSync");
    module2.exports = {
      symlinkType: u(symlinkType),
      symlinkTypeSync
    };
  }
});

// ../../node_modules/fs-extra/lib/ensure/symlink.js
var require_symlink = __commonJS({
  "../../node_modules/fs-extra/lib/ensure/symlink.js"(exports2, module2) {
    "use strict";
    var u = require_universalify().fromPromise;
    var path47 = require("path");
    var fs51 = require_fs();
    var { mkdirs, mkdirsSync: mkdirsSync2 } = require_mkdirs();
    var { symlinkPaths, symlinkPathsSync } = require_symlink_paths();
    var { symlinkType, symlinkTypeSync } = require_symlink_type();
    var { pathExists: pathExists9 } = require_path_exists();
    var { areIdentical } = require_stat();
    async function createSymlink(srcpath, dstpath, type) {
      let stats;
      try {
        stats = await fs51.lstat(dstpath);
      } catch {
      }
      if (stats && stats.isSymbolicLink()) {
        let srcStat;
        if (path47.isAbsolute(srcpath)) {
          srcStat = await fs51.stat(srcpath);
        } else {
          const dstdir = path47.dirname(dstpath);
          const relativeToDst = path47.join(dstdir, srcpath);
          try {
            srcStat = await fs51.stat(relativeToDst);
          } catch {
            srcStat = await fs51.stat(srcpath);
          }
        }
        const dstStat = await fs51.stat(dstpath);
        if (areIdentical(srcStat, dstStat)) return;
      }
      const relative5 = await symlinkPaths(srcpath, dstpath);
      srcpath = relative5.toDst;
      const toType = await symlinkType(relative5.toCwd, type);
      const dir = path47.dirname(dstpath);
      if (!await pathExists9(dir)) {
        await mkdirs(dir);
      }
      return fs51.symlink(srcpath, dstpath, toType);
    }
    __name(createSymlink, "createSymlink");
    function createSymlinkSync(srcpath, dstpath, type) {
      let stats;
      try {
        stats = fs51.lstatSync(dstpath);
      } catch {
      }
      if (stats && stats.isSymbolicLink()) {
        let srcStat;
        if (path47.isAbsolute(srcpath)) {
          srcStat = fs51.statSync(srcpath);
        } else {
          const dstdir = path47.dirname(dstpath);
          const relativeToDst = path47.join(dstdir, srcpath);
          try {
            srcStat = fs51.statSync(relativeToDst);
          } catch {
            srcStat = fs51.statSync(srcpath);
          }
        }
        const dstStat = fs51.statSync(dstpath);
        if (areIdentical(srcStat, dstStat)) return;
      }
      const relative5 = symlinkPathsSync(srcpath, dstpath);
      srcpath = relative5.toDst;
      type = symlinkTypeSync(relative5.toCwd, type);
      const dir = path47.dirname(dstpath);
      const exists = fs51.existsSync(dir);
      if (exists) return fs51.symlinkSync(srcpath, dstpath, type);
      mkdirsSync2(dir);
      return fs51.symlinkSync(srcpath, dstpath, type);
    }
    __name(createSymlinkSync, "createSymlinkSync");
    module2.exports = {
      createSymlink: u(createSymlink),
      createSymlinkSync
    };
  }
});

// ../../node_modules/fs-extra/lib/ensure/index.js
var require_ensure = __commonJS({
  "../../node_modules/fs-extra/lib/ensure/index.js"(exports2, module2) {
    "use strict";
    var { createFile, createFileSync } = require_file();
    var { createLink, createLinkSync } = require_link();
    var { createSymlink, createSymlinkSync } = require_symlink();
    module2.exports = {
      // file
      createFile,
      createFileSync,
      ensureFile: createFile,
      ensureFileSync: createFileSync,
      // link
      createLink,
      createLinkSync,
      ensureLink: createLink,
      ensureLinkSync: createLinkSync,
      // symlink
      createSymlink,
      createSymlinkSync,
      ensureSymlink: createSymlink,
      ensureSymlinkSync: createSymlinkSync
    };
  }
});

// ../../node_modules/jsonfile/utils.js
var require_utils2 = __commonJS({
  "../../node_modules/jsonfile/utils.js"(exports2, module2) {
    function stringify2(obj, { EOL = "\n", finalEOL = true, replacer = null, spaces } = {}) {
      const EOF = finalEOL ? EOL : "";
      const str = JSON.stringify(obj, replacer, spaces);
      return str.replace(/\n/g, EOL) + EOF;
    }
    __name(stringify2, "stringify");
    function stripBom(content) {
      if (Buffer.isBuffer(content)) content = content.toString("utf8");
      return content.replace(/^\uFEFF/, "");
    }
    __name(stripBom, "stripBom");
    module2.exports = { stringify: stringify2, stripBom };
  }
});

// ../../node_modules/jsonfile/index.js
var require_jsonfile = __commonJS({
  "../../node_modules/jsonfile/index.js"(exports2, module2) {
    var _fs;
    try {
      _fs = require_graceful_fs();
    } catch (_) {
      _fs = require("fs");
    }
    var universalify = require_universalify();
    var { stringify: stringify2, stripBom } = require_utils2();
    async function _readFile(file, options = {}) {
      if (typeof options === "string") {
        options = { encoding: options };
      }
      const fs51 = options.fs || _fs;
      const shouldThrow = "throws" in options ? options.throws : true;
      let data3 = await universalify.fromCallback(fs51.readFile)(file, options);
      data3 = stripBom(data3);
      let obj;
      try {
        obj = JSON.parse(data3, options ? options.reviver : null);
      } catch (err) {
        if (shouldThrow) {
          err.message = `${file}: ${err.message}`;
          throw err;
        } else {
          return null;
        }
      }
      return obj;
    }
    __name(_readFile, "_readFile");
    var readFile15 = universalify.fromPromise(_readFile);
    function readFileSync17(file, options = {}) {
      if (typeof options === "string") {
        options = { encoding: options };
      }
      const fs51 = options.fs || _fs;
      const shouldThrow = "throws" in options ? options.throws : true;
      try {
        let content = fs51.readFileSync(file, options);
        content = stripBom(content);
        return JSON.parse(content, options.reviver);
      } catch (err) {
        if (shouldThrow) {
          err.message = `${file}: ${err.message}`;
          throw err;
        } else {
          return null;
        }
      }
    }
    __name(readFileSync17, "readFileSync");
    async function _writeFile(file, obj, options = {}) {
      const fs51 = options.fs || _fs;
      const str = stringify2(obj, options);
      await universalify.fromCallback(fs51.writeFile)(file, str, options);
    }
    __name(_writeFile, "_writeFile");
    var writeFile6 = universalify.fromPromise(_writeFile);
    function writeFileSync6(file, obj, options = {}) {
      const fs51 = options.fs || _fs;
      const str = stringify2(obj, options);
      return fs51.writeFileSync(file, str, options);
    }
    __name(writeFileSync6, "writeFileSync");
    module2.exports = {
      readFile: readFile15,
      readFileSync: readFileSync17,
      writeFile: writeFile6,
      writeFileSync: writeFileSync6
    };
  }
});

// ../../node_modules/fs-extra/lib/json/jsonfile.js
var require_jsonfile2 = __commonJS({
  "../../node_modules/fs-extra/lib/json/jsonfile.js"(exports2, module2) {
    "use strict";
    var jsonFile = require_jsonfile();
    module2.exports = {
      // jsonfile exports
      readJson: jsonFile.readFile,
      readJsonSync: jsonFile.readFileSync,
      writeJson: jsonFile.writeFile,
      writeJsonSync: jsonFile.writeFileSync
    };
  }
});

// ../../node_modules/fs-extra/lib/output-file/index.js
var require_output_file = __commonJS({
  "../../node_modules/fs-extra/lib/output-file/index.js"(exports2, module2) {
    "use strict";
    var u = require_universalify().fromPromise;
    var fs51 = require_fs();
    var path47 = require("path");
    var mkdir2 = require_mkdirs();
    var pathExists9 = require_path_exists().pathExists;
    async function outputFile(file, data3, encoding = "utf-8") {
      const dir = path47.dirname(file);
      if (!await pathExists9(dir)) {
        await mkdir2.mkdirs(dir);
      }
      return fs51.writeFile(file, data3, encoding);
    }
    __name(outputFile, "outputFile");
    function outputFileSync(file, ...args) {
      const dir = path47.dirname(file);
      if (!fs51.existsSync(dir)) {
        mkdir2.mkdirsSync(dir);
      }
      fs51.writeFileSync(file, ...args);
    }
    __name(outputFileSync, "outputFileSync");
    module2.exports = {
      outputFile: u(outputFile),
      outputFileSync
    };
  }
});

// ../../node_modules/fs-extra/lib/json/output-json.js
var require_output_json = __commonJS({
  "../../node_modules/fs-extra/lib/json/output-json.js"(exports2, module2) {
    "use strict";
    var { stringify: stringify2 } = require_utils2();
    var { outputFile } = require_output_file();
    async function outputJson(file, data3, options = {}) {
      const str = stringify2(data3, options);
      await outputFile(file, str, options);
    }
    __name(outputJson, "outputJson");
    module2.exports = outputJson;
  }
});

// ../../node_modules/fs-extra/lib/json/output-json-sync.js
var require_output_json_sync = __commonJS({
  "../../node_modules/fs-extra/lib/json/output-json-sync.js"(exports2, module2) {
    "use strict";
    var { stringify: stringify2 } = require_utils2();
    var { outputFileSync } = require_output_file();
    function outputJsonSync(file, data3, options) {
      const str = stringify2(data3, options);
      outputFileSync(file, str, options);
    }
    __name(outputJsonSync, "outputJsonSync");
    module2.exports = outputJsonSync;
  }
});

// ../../node_modules/fs-extra/lib/json/index.js
var require_json = __commonJS({
  "../../node_modules/fs-extra/lib/json/index.js"(exports2, module2) {
    "use strict";
    var u = require_universalify().fromPromise;
    var jsonFile = require_jsonfile2();
    jsonFile.outputJson = u(require_output_json());
    jsonFile.outputJsonSync = require_output_json_sync();
    jsonFile.outputJSON = jsonFile.outputJson;
    jsonFile.outputJSONSync = jsonFile.outputJsonSync;
    jsonFile.writeJSON = jsonFile.writeJson;
    jsonFile.writeJSONSync = jsonFile.writeJsonSync;
    jsonFile.readJSON = jsonFile.readJson;
    jsonFile.readJSONSync = jsonFile.readJsonSync;
    module2.exports = jsonFile;
  }
});

// ../../node_modules/fs-extra/lib/move/move.js
var require_move = __commonJS({
  "../../node_modules/fs-extra/lib/move/move.js"(exports2, module2) {
    "use strict";
    var fs51 = require_fs();
    var path47 = require("path");
    var { copy: copy2 } = require_copy2();
    var { remove: remove2 } = require_remove();
    var { mkdirp: mkdirp2 } = require_mkdirs();
    var { pathExists: pathExists9 } = require_path_exists();
    var stat8 = require_stat();
    async function move(src, dest, opts = {}) {
      const overwrite = opts.overwrite || opts.clobber || false;
      const { srcStat, isChangingCase = false } = await stat8.checkPaths(src, dest, "move", opts);
      await stat8.checkParentPaths(src, srcStat, dest, "move");
      const destParent = path47.dirname(dest);
      const parsedParentPath = path47.parse(destParent);
      if (parsedParentPath.root !== destParent) {
        await mkdirp2(destParent);
      }
      return doRename(src, dest, overwrite, isChangingCase);
    }
    __name(move, "move");
    async function doRename(src, dest, overwrite, isChangingCase) {
      if (!isChangingCase) {
        if (overwrite) {
          await remove2(dest);
        } else if (await pathExists9(dest)) {
          throw new Error("dest already exists.");
        }
      }
      try {
        await fs51.rename(src, dest);
      } catch (err) {
        if (err.code !== "EXDEV") {
          throw err;
        }
        await moveAcrossDevice(src, dest, overwrite);
      }
    }
    __name(doRename, "doRename");
    async function moveAcrossDevice(src, dest, overwrite) {
      const opts = {
        overwrite,
        errorOnExist: true,
        preserveTimestamps: true
      };
      await copy2(src, dest, opts);
      return remove2(src);
    }
    __name(moveAcrossDevice, "moveAcrossDevice");
    module2.exports = move;
  }
});

// ../../node_modules/fs-extra/lib/move/move-sync.js
var require_move_sync = __commonJS({
  "../../node_modules/fs-extra/lib/move/move-sync.js"(exports2, module2) {
    "use strict";
    var fs51 = require_graceful_fs();
    var path47 = require("path");
    var copySync = require_copy2().copySync;
    var removeSync = require_remove().removeSync;
    var mkdirpSync2 = require_mkdirs().mkdirpSync;
    var stat8 = require_stat();
    function moveSync(src, dest, opts) {
      opts = opts || {};
      const overwrite = opts.overwrite || opts.clobber || false;
      const { srcStat, isChangingCase = false } = stat8.checkPathsSync(src, dest, "move", opts);
      stat8.checkParentPathsSync(src, srcStat, dest, "move");
      if (!isParentRoot(dest)) mkdirpSync2(path47.dirname(dest));
      return doRename(src, dest, overwrite, isChangingCase);
    }
    __name(moveSync, "moveSync");
    function isParentRoot(dest) {
      const parent = path47.dirname(dest);
      const parsedPath = path47.parse(parent);
      return parsedPath.root === parent;
    }
    __name(isParentRoot, "isParentRoot");
    function doRename(src, dest, overwrite, isChangingCase) {
      if (isChangingCase) return rename(src, dest, overwrite);
      if (overwrite) {
        removeSync(dest);
        return rename(src, dest, overwrite);
      }
      if (fs51.existsSync(dest)) throw new Error("dest already exists.");
      return rename(src, dest, overwrite);
    }
    __name(doRename, "doRename");
    function rename(src, dest, overwrite) {
      try {
        fs51.renameSync(src, dest);
      } catch (err) {
        if (err.code !== "EXDEV") throw err;
        return moveAcrossDevice(src, dest, overwrite);
      }
    }
    __name(rename, "rename");
    function moveAcrossDevice(src, dest, overwrite) {
      const opts = {
        overwrite,
        errorOnExist: true,
        preserveTimestamps: true
      };
      copySync(src, dest, opts);
      return removeSync(src);
    }
    __name(moveAcrossDevice, "moveAcrossDevice");
    module2.exports = moveSync;
  }
});

// ../../node_modules/fs-extra/lib/move/index.js
var require_move2 = __commonJS({
  "../../node_modules/fs-extra/lib/move/index.js"(exports2, module2) {
    "use strict";
    var u = require_universalify().fromPromise;
    module2.exports = {
      move: u(require_move()),
      moveSync: require_move_sync()
    };
  }
});

// ../../node_modules/fs-extra/lib/index.js
var require_lib4 = __commonJS({
  "../../node_modules/fs-extra/lib/index.js"(exports2, module2) {
    "use strict";
    module2.exports = {
      // Export promiseified graceful-fs:
      ...require_fs(),
      // Export extra methods:
      ...require_copy2(),
      ...require_empty(),
      ...require_ensure(),
      ...require_json(),
      ...require_mkdirs(),
      ...require_move2(),
      ...require_output_file(),
      ...require_path_exists(),
      ...require_remove()
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/bootstrap/bootstrap-props.ts
var BUCKET_NAME_OUTPUT, REPOSITORY_NAME_OUTPUT, BUCKET_DOMAIN_NAME_OUTPUT, BOOTSTRAP_VERSION_OUTPUT, BOOTSTRAP_VERSION_RESOURCE, BOOTSTRAP_VARIANT_PARAMETER, DEFAULT_BOOTSTRAP_VARIANT;
var init_bootstrap_props = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/bootstrap/bootstrap-props.ts"() {
    "use strict";
    BUCKET_NAME_OUTPUT = "BucketName";
    REPOSITORY_NAME_OUTPUT = "ImageRepositoryName";
    BUCKET_DOMAIN_NAME_OUTPUT = "BucketDomainName";
    BOOTSTRAP_VERSION_OUTPUT = "BootstrapVersion";
    BOOTSTRAP_VERSION_RESOURCE = "CdkBootstrapVersion";
    BOOTSTRAP_VARIANT_PARAMETER = "BootstrapVariant";
    DEFAULT_BOOTSTRAP_VARIANT = "AWS CDK: Default Resources";
  }
});

// ../@aws-cdk/cdk-assets-lib/lib/progress.ts
var progress_exports = {};
__export(progress_exports, {
  EventType: () => EventType,
  shellEventPublisherFromEventEmitter: () => shellEventPublisherFromEventEmitter,
  shellEventToEventType: () => shellEventToEventType
});
function shellEventToEventType(event) {
  switch (event) {
    case "open":
      return "shell_open" /* SHELL_OPEN */;
    case "close":
      return "shell_close" /* SHELL_CLOSE */;
    case "data_stdout":
      return "shell_stdout" /* SHELL_STDOUT */;
    case "data_stderr":
      return "shell_stderr" /* SHELL_STDERR */;
  }
}
function shellEventPublisherFromEventEmitter(eventEmitter) {
  return (event, message2) => {
    const eventType = shellEventToEventType(event);
    eventEmitter(eventType, message2);
  };
}
var EventType;
var init_progress = __esm({
  "../@aws-cdk/cdk-assets-lib/lib/progress.ts"() {
    "use strict";
    EventType = /* @__PURE__ */ ((EventType2) => {
      EventType2["START"] = "start";
      EventType2["SUCCESS"] = "success";
      EventType2["FAIL"] = "fail";
      EventType2["CHECK"] = "check";
      EventType2["FOUND"] = "found";
      EventType2["CACHED"] = "cached";
      EventType2["BUILD"] = "build";
      EventType2["UPLOAD"] = "upload";
      EventType2["DEBUG"] = "debug";
      EventType2["SHELL_OPEN"] = "shell_open";
      EventType2["SHELL_STDOUT"] = "shell_stdout";
      EventType2["SHELL_STDERR"] = "shell_stderr";
      EventType2["SHELL_CLOSE"] = "shell_close";
      return EventType2;
    })(EventType || {});
    __name(shellEventToEventType, "shellEventToEventType");
    __name(shellEventPublisherFromEventEmitter, "shellEventPublisherFromEventEmitter");
  }
});

// ../@aws-cdk/cdk-assets-lib/lib/private/docker-credentials.ts
function cdkCredentialsConfigFile() {
  return process.env.CDK_DOCKER_CREDS_FILE ?? path6.join(
    (os2.userInfo().homedir ?? os2.homedir()).trim() || "/",
    ".cdk",
    "cdk-docker-creds.json"
  );
}
function cdkCredentialsConfig() {
  if (!_cdkCredentials) {
    try {
      _cdkCredentials = JSON.parse(
        fs6.readFileSync(cdkCredentialsConfigFile(), { encoding: "utf-8" })
      );
    } catch {
    }
  }
  return _cdkCredentials;
}
async function obtainEcrCredentials(ecr, eventEmitter) {
  if (eventEmitter) {
    eventEmitter("debug" /* DEBUG */, "Fetching ECR authorization token");
  }
  const authData = (await ecr.getAuthorizationToken()).authorizationData || [];
  if (authData.length === 0) {
    throw new Error("No authorization data received from ECR");
  }
  const token = Buffer.from(authData[0].authorizationToken, "base64").toString("ascii");
  const [username, password] = token.split(":");
  if (!username || !password) {
    throw new Error("unexpected ECR authData format");
  }
  return {
    username,
    password,
    endpoint: authData[0].proxyEndpoint
  };
}
var fs6, os2, path6, _cdkCredentials;
var init_docker_credentials = __esm({
  "../@aws-cdk/cdk-assets-lib/lib/private/docker-credentials.ts"() {
    "use strict";
    fs6 = __toESM(require("fs"));
    os2 = __toESM(require("os"));
    path6 = __toESM(require("path"));
    init_progress();
    __name(cdkCredentialsConfigFile, "cdkCredentialsConfigFile");
    __name(cdkCredentialsConfig, "cdkCredentialsConfig");
    __name(obtainEcrCredentials, "obtainEcrCredentials");
  }
});

// ../@aws-cdk/cdk-assets-lib/lib/private/shell.ts
async function shell(command, options) {
  handleShellOutput(renderCommandLine(command), options, "open");
  const child = child_process.spawn(command[0], command.slice(1), {
    ...options,
    stdio: [options.input ? "pipe" : "ignore", "pipe", "pipe"]
  });
  return new Promise((resolve13, reject) => {
    if (options.input) {
      child.stdin.write(options.input);
      child.stdin.end();
    }
    const stdout = new Array();
    const stderr = new Array();
    child.stdout.on("data", (chunk) => {
      handleShellOutput(chunk, options, "data_stdout");
      stdout.push(chunk);
    });
    child.stderr.on("data", (chunk) => {
      handleShellOutput(chunk, options, "data_stderr");
      stderr.push(chunk);
    });
    child.once("error", reject);
    child.once("close", (code, signal) => {
      handleShellOutput(renderCommandLine(command), options, "close");
      if (code === 0) {
        resolve13(Buffer.concat(stdout).toString("utf-8"));
      } else {
        const out = Buffer.concat(stderr).toString("utf-8").trim();
        reject(
          new ProcessFailed(
            code,
            signal,
            `${renderCommandLine(command)} exited with ${code != null ? "error code" : "signal"} ${code ?? signal}: ${out}`
          )
        );
      }
    });
  });
}
function handleShellOutput(chunk, options, shellEventType) {
  switch (options.subprocessOutputDestination) {
    case "ignore":
      return;
    case "publish":
      options.shellEventPublisher(shellEventType, chunk.toString("utf-8"));
      break;
    case "stdio":
    default:
      switch (shellEventType) {
        case "data_stdout":
          process.stdout.write(chunk);
          break;
        case "data_stderr":
          process.stderr.write(chunk);
          break;
        case "open":
          options.shellEventPublisher(shellEventType, chunk.toString("utf-8"));
          break;
      }
      break;
  }
}
function renderCommandLine(cmd) {
  if (process.platform !== "win32") {
    return doRender(cmd, hasAnyChars(" ", "\\", "!", '"', "'", "&", "$"), posixEscape);
  } else {
    return doRender(cmd, hasAnyChars(" ", '"', "&", "^", "%"), windowsEscape);
  }
}
function doRender(cmd, needsEscaping, doEscape) {
  return cmd.map((x) => needsEscaping(x) ? doEscape(x) : x).join(" ");
}
function hasAnyChars(...chars6) {
  return (str) => {
    return chars6.some((c32) => str.indexOf(c32) !== -1);
  };
}
function posixEscape(x) {
  x = x.replace(/'/g, `'"'"'`);
  return `'${x}'`;
}
function windowsEscape(x) {
  x = `"${x}"`;
  const shellMeta = /* @__PURE__ */ new Set(['"', "&", "^", "%"]);
  return x.split("").map((c32) => shellMeta.has(x) ? "^" + c32 : c32).join("");
}
var child_process, ProcessFailed;
var init_shell = __esm({
  "../@aws-cdk/cdk-assets-lib/lib/private/shell.ts"() {
    "use strict";
    child_process = __toESM(require("child_process"));
    __name(shell, "shell");
    __name(handleShellOutput, "handleShellOutput");
    ProcessFailed = class extends Error {
      constructor(exitCode, signal, message2) {
        super(message2);
        this.exitCode = exitCode;
        this.signal = signal;
        this.code = "PROCESS_FAILED";
      }
      static {
        __name(this, "ProcessFailed");
      }
    };
    __name(renderCommandLine, "renderCommandLine");
    __name(doRender, "doRender");
    __name(hasAnyChars, "hasAnyChars");
    __name(posixEscape, "posixEscape");
    __name(windowsEscape, "windowsEscape");
  }
});

// ../@aws-cdk/cdk-assets-lib/lib/private/util.ts
function createCriticalSection() {
  let lock = Promise.resolve();
  return async (criticalFunction) => {
    const res = lock.then(() => criticalFunction());
    lock = res.catch((e32) => e32);
    return res;
  };
}
var init_util = __esm({
  "../@aws-cdk/cdk-assets-lib/lib/private/util.ts"() {
    "use strict";
    __name(createCriticalSection, "createCriticalSection");
  }
});

// ../@aws-cdk/cdk-assets-lib/lib/private/docker.ts
function getDockerCmd() {
  return process.env.CDK_DOCKER ?? "docker";
}
function flatten(x) {
  return Array.prototype.concat([], ...x);
}
var fs7, os3, path7, Docker, DockerFactory;
var init_docker = __esm({
  "../@aws-cdk/cdk-assets-lib/lib/private/docker.ts"() {
    "use strict";
    fs7 = __toESM(require("fs"));
    os3 = __toESM(require("os"));
    path7 = __toESM(require("path"));
    init_docker_credentials();
    init_shell();
    init_util();
    init_progress();
    Docker = class {
      constructor(eventEmitter, subprocessOutputDestination) {
        this.eventEmitter = eventEmitter;
        this.subprocessOutputDestination = subprocessOutputDestination;
        this.configDir = void 0;
      }
      static {
        __name(this, "Docker");
      }
      /**
       * Whether an image with the given tag exists
       */
      async exists(tag3) {
        try {
          await this.execute(["inspect", tag3], {
            subprocessOutputDestination: "ignore"
          });
          return true;
        } catch (e32) {
          const error4 = e32;
          if (error4.code !== "PROCESS_FAILED") {
            throw error4;
          }
          switch (error4.exitCode) {
            case 1 /* Docker */:
            case 125 /* Podman */:
              return false;
            default:
              throw error4;
          }
        }
      }
      async build(options) {
        const buildCommand = [
          "build",
          ...flatten(
            Object.entries(options.buildArgs || {}).map(([k32, v]) => ["--build-arg", `${k32}=${v}`])
          ),
          ...flatten(
            Object.entries(options.buildContexts || {}).map(([k32, v]) => ["--build-context", `${k32}=${v}`])
          ),
          ...flatten(
            Object.entries(options.buildSecrets || {}).map(([k32, v]) => ["--secret", `id=${k32},${v}`])
          ),
          ...options.buildSsh ? ["--ssh", options.buildSsh] : [],
          "--tag",
          options.tag,
          ...options.target ? ["--target", options.target] : [],
          ...options.file ? ["--file", options.file] : [],
          ...options.networkMode ? ["--network", options.networkMode] : [],
          ...options.platform ? ["--platform", options.platform] : [],
          ...options.outputs ? options.outputs.map((output) => [`--output=${output}`]) : [],
          ...options.cacheFrom ? [
            ...options.cacheFrom.map((cacheFrom) => ["--cache-from", this.cacheOptionToFlag(cacheFrom)]).flat()
          ] : [],
          ...options.cacheTo ? ["--cache-to", this.cacheOptionToFlag(options.cacheTo)] : [],
          ...options.cacheDisabled ? ["--no-cache"] : [],
          "."
        ];
        await this.execute(buildCommand, {
          cwd: options.directory,
          subprocessOutputDestination: this.subprocessOutputDestination,
          env: {
            BUILDX_NO_DEFAULT_ATTESTATIONS: "1"
            // Docker Build adds provenance attestations by default that confuse cdk-assets
          }
        });
      }
      /**
       * Get credentials from ECR and run docker login
       */
      async login(ecr) {
        const credentials = await obtainEcrCredentials(ecr, this.eventEmitter);
        await this.execute(
          ["login", "--username", credentials.username, "--password-stdin", credentials.endpoint.replace(/^https?:\/\/|\/$/g, "")],
          {
            input: credentials.password,
            // Need to ignore otherwise Docker will complain
            // 'WARNING! Your password will be stored unencrypted'
            // doesn't really matter since it's a token.
            subprocessOutputDestination: "ignore"
          }
        );
      }
      async tag(sourceTag, targetTag) {
        await this.execute(["tag", sourceTag, targetTag]);
      }
      /**
       * Find a local image tagged with the given imageTag (the tag portion after the colon).
       * Returns the full `repository:tag` string, or undefined if not found.
       */
      async findImageByTag(imageTag) {
        try {
          const configArgs = this.configDir ? ["--config", this.configDir] : [];
          const shellEventPublisher = shellEventPublisherFromEventEmitter(this.eventEmitter);
          const output = await shell(
            [getDockerCmd(), ...configArgs, "images", "--format", "{{.Repository}}:{{.Tag}}", "--filter", `reference=*/*:${imageTag}`],
            { shellEventPublisher, subprocessOutputDestination: "ignore" }
          );
          const firstLine = output.trim().split("\n")[0]?.trim();
          return firstLine || void 0;
        } catch {
          return void 0;
        }
      }
      async push(options) {
        await this.execute(["push", options.tag], {
          subprocessOutputDestination: this.subprocessOutputDestination
        });
      }
      /**
       * If a CDK Docker Credentials file exists, creates a new Docker config directory.
       * Sets up `docker-credential-cdk-assets` to be the credential helper for each domain in the CDK config.
       * All future commands (e.g., `build`, `push`) will use this config.
       *
       * See https://docs.docker.com/engine/reference/commandline/login/#credential-helpers for more details on cred helpers.
       *
       * @returns true if CDK config was found and configured, false otherwise
       */
      configureCdkCredentials() {
        const config2 = cdkCredentialsConfig();
        if (!config2) {
          return false;
        }
        this.configDir = fs7.mkdtempSync(path7.join(os3.tmpdir(), "cdkDockerConfig"));
        const domains = Object.keys(config2.domainCredentials);
        const credHelpers = domains.reduce((map5, domain) => {
          map5[domain] = "cdk-assets";
          return map5;
        }, {});
        fs7.writeFileSync(path7.join(this.configDir, "config.json"), JSON.stringify({ credHelpers }), {
          encoding: "utf-8"
        });
        return true;
      }
      /**
       * Removes any configured Docker config directory.
       * All future commands (e.g., `build`, `push`) will use the default config.
       *
       * This is useful after calling `configureCdkCredentials` to reset to default credentials.
       */
      resetAuthPlugins() {
        this.configDir = void 0;
      }
      async execute(args, options = {}) {
        const configArgs = this.configDir ? ["--config", this.configDir] : [];
        const pathToCdkAssets = path7.resolve(__dirname, "..", "..", "bin");
        const shellEventPublisher = shellEventPublisherFromEventEmitter(this.eventEmitter);
        try {
          await shell([getDockerCmd(), ...configArgs, ...args], {
            ...options,
            shellEventPublisher,
            env: {
              ...process.env,
              ...options.env,
              PATH: `${pathToCdkAssets}${path7.delimiter}${options.env?.PATH ?? process.env.PATH}`
            }
          });
        } catch (e32) {
          if (e32.code === "ENOENT") {
            throw new Error(
              `Failed to find and execute '${getDockerCmd()}' while attempting to build a container asset. Please install '${getDockerCmd()}' and try again. (Or set the 'CDK_DOCKER ' environment variable to choose a different compatible container client.)`
            );
          }
          throw e32;
        }
      }
      cacheOptionToFlag(option) {
        let flag = `type=${option.type}`;
        if (option.params) {
          flag += "," + Object.entries(option.params).map(([k32, v]) => `${k32}=${v}`).join(",");
        }
        return flag;
      }
    };
    DockerFactory = class {
      constructor() {
        this.enterLoggedInDestinationsCriticalSection = createCriticalSection();
        this.loggedInDestinations = /* @__PURE__ */ new Set();
      }
      static {
        __name(this, "DockerFactory");
      }
      /**
       * Gets a Docker instance for building images.
       */
      async forBuild(options) {
        const docker = new Docker(options.eventEmitter, options.subprocessOutputDestination);
        let cdkDockerCredentialsConfigured = docker.configureCdkCredentials();
        if (!cdkDockerCredentialsConfigured) {
          await this.loginOncePerDestination(docker, options);
        }
        return docker;
      }
      /**
       * Gets a Docker instance for pushing images to ECR.
       */
      async forEcrPush(options) {
        const docker = new Docker(options.eventEmitter, options.subprocessOutputDestination);
        await this.loginOncePerDestination(docker, options);
        return docker;
      }
      async loginOncePerDestination(docker, options) {
        const repositoryDomain = options.repoUri.split("/")[0];
        await this.enterLoggedInDestinationsCriticalSection(async () => {
          if (this.loggedInDestinations.has(repositoryDomain)) {
            return;
          }
          await docker.login(options.ecr);
          this.loggedInDestinations.add(repositoryDomain);
        });
      }
    };
    __name(getDockerCmd, "getDockerCmd");
    __name(flatten, "flatten");
  }
});

// ../@aws-cdk/cdk-assets-lib/lib/private/handlers/client-options.ts
function destinationToClientOptions(destination) {
  return {
    assumeRoleArn: destination.assumeRoleArn,
    assumeRoleExternalId: destination.assumeRoleExternalId,
    assumeRoleAdditionalOptions: destination.assumeRoleAdditionalOptions,
    region: destination.region
  };
}
var init_client_options = __esm({
  "../@aws-cdk/cdk-assets-lib/lib/private/handlers/client-options.ts"() {
    "use strict";
    __name(destinationToClientOptions, "destinationToClientOptions");
  }
});

// ../@aws-cdk/cdk-assets-lib/lib/private/placeholders.ts
async function replaceAwsPlaceholders(object, aws) {
  let partition4 = /* @__PURE__ */ __name(async () => {
    const p10 = await aws.discoverPartition();
    partition4 = /* @__PURE__ */ __name(() => Promise.resolve(p10), "partition");
    return p10;
  }, "partition");
  let account = /* @__PURE__ */ __name(async () => {
    const a32 = await aws.discoverCurrentAccount();
    account = /* @__PURE__ */ __name(() => Promise.resolve(a32), "account");
    return a32;
  }, "account");
  return import_cloud_assembly_api.EnvironmentPlaceholders.replaceAsync(object, {
    async region() {
      return object.region ?? aws.discoverDefaultRegion();
    },
    async accountId() {
      return (await account()).accountId;
    },
    async partition() {
      return partition4();
    }
  });
}
var import_cloud_assembly_api;
var init_placeholders2 = __esm({
  "../@aws-cdk/cdk-assets-lib/lib/private/placeholders.ts"() {
    "use strict";
    import_cloud_assembly_api = __toESM(require_lib3());
    __name(replaceAwsPlaceholders, "replaceAwsPlaceholders");
  }
});

// ../@aws-cdk/cdk-assets-lib/lib/private/handlers/container-images.ts
async function imageExists(ecr, repositoryName, imageTag) {
  try {
    await ecr.describeImages({
      repositoryName,
      imageIds: [{ imageTag }]
    });
    return true;
  } catch (e32) {
    if (e32.name !== "ImageNotFoundException") {
      throw e32;
    }
    return false;
  }
}
async function repositoryUri(ecr, repositoryName) {
  try {
    const response = await ecr.describeRepositories({
      repositoryNames: [repositoryName]
    });
    return (response.repositories || [])[0]?.repositoryUri;
  } catch (e32) {
    if (e32.name !== "RepositoryNotFoundException") {
      throw e32;
    }
    return void 0;
  }
}
var path8, ContainerImageAssetHandler, ContainerImageBuilder;
var init_container_images = __esm({
  "../@aws-cdk/cdk-assets-lib/lib/private/handlers/container-images.ts"() {
    "use strict";
    path8 = __toESM(require("path"));
    init_client_options();
    init_progress();
    init_placeholders2();
    init_shell();
    ContainerImageAssetHandler = class {
      constructor(workDir, asset, host, options) {
        this.workDir = workDir;
        this.asset = asset;
        this.host = host;
        this.options = options;
        this.buildCompleted = false;
      }
      static {
        __name(this, "ContainerImageAssetHandler");
      }
      async build() {
        const initOnce = await this.initOnce();
        if (initOnce.destinationAlreadyExists) {
          return;
        }
        if (this.host.aborted) {
          return;
        }
        const dockerForBuilding = await this.host.dockerFactory.forBuild({
          repoUri: initOnce.repoUri,
          eventEmitter: /* @__PURE__ */ __name((m20) => this.host.emitMessage("debug" /* DEBUG */, m20), "eventEmitter"),
          ecr: initOnce.ecr,
          subprocessOutputDestination: this.options.subprocessOutputDestination
        });
        const builder = new ContainerImageBuilder(
          dockerForBuilding,
          this.workDir,
          this.asset,
          this.host
        );
        const localTagName = await builder.build();
        if (localTagName === void 0 || this.host.aborted) {
          return;
        }
        if (this.host.aborted) {
          return;
        }
        await dockerForBuilding.tag(localTagName, initOnce.imageUri);
        this.buildCompleted = true;
      }
      async isPublished() {
        try {
          const initOnce = await this.initOnce();
          return initOnce.destinationAlreadyExists;
        } catch (e32) {
          this.host.emitMessage("debug" /* DEBUG */, `${e32.message}`);
        }
        return false;
      }
      async publish() {
        const initOnce = await this.initOnce();
        if (initOnce.destinationAlreadyExists) {
          return;
        }
        if (this.host.aborted) {
          return;
        }
        const dockerForPushing = await this.host.dockerFactory.forEcrPush({
          repoUri: initOnce.repoUri,
          eventEmitter: this.host.emitMessage,
          ecr: initOnce.ecr,
          subprocessOutputDestination: this.options.subprocessOutputDestination
        });
        if (this.host.aborted) {
          return;
        }
        if (!this.buildCompleted && !await dockerForPushing.exists(initOnce.imageUri)) {
          const imageTag = this.asset.destination.imageTag;
          const existing = await dockerForPushing.findImageByTag(imageTag);
          if (existing) {
            await dockerForPushing.tag(existing, initOnce.imageUri);
          }
        }
        this.host.emitMessage("upload" /* UPLOAD */, `Push ${initOnce.imageUri}`);
        await dockerForPushing.push({
          tag: initOnce.imageUri
        });
      }
      async initOnce() {
        if (this.init) {
          return this.init;
        }
        const destination = await replaceAwsPlaceholders(this.asset.destination, this.host.aws);
        const ecr = await this.host.aws.ecrClient(destinationToClientOptions(destination));
        const account = /* @__PURE__ */ __name(async () => (await this.host.aws.discoverCurrentAccount())?.accountId, "account");
        const repoUri = await repositoryUri(ecr, destination.repositoryName);
        if (!repoUri) {
          throw new Error(
            `No ECR repository named '${destination.repositoryName}' in account ${await account()}. Is this account bootstrapped?`
          );
        }
        const imageUri = `${repoUri}:${destination.imageTag}`;
        this.init = {
          imageUri,
          ecr,
          repoUri,
          destinationAlreadyExists: await this.destinationAlreadyExists(ecr, destination, imageUri)
        };
        return this.init;
      }
      /**
       * Check whether the image already exists in the ECR repo
       *
       * Use the fields from the destination to do the actual check. The imageUri
       * should correspond to that, but is only used to print Docker image location
       * for user benefit (the format is slightly different).
       */
      async destinationAlreadyExists(ecr, destination, imageUri) {
        this.host.emitMessage("check" /* CHECK */, `Check ${imageUri}`);
        if (await imageExists(ecr, destination.repositoryName, destination.imageTag)) {
          this.host.emitMessage("found" /* FOUND */, `Found ${imageUri}`);
          return true;
        }
        return false;
      }
    };
    ContainerImageBuilder = class {
      constructor(docker, workDir, asset, host) {
        this.docker = docker;
        this.workDir = workDir;
        this.asset = asset;
        this.host = host;
      }
      static {
        __name(this, "ContainerImageBuilder");
      }
      async build() {
        return this.asset.source.executable ? this.buildExternalAsset(this.asset.source.executable) : this.buildDirectoryAsset();
      }
      /**
       * Build a (local) Docker asset from a directory with a Dockerfile
       *
       * Tags under a deterministic, unique, local identifier wich will skip
       * the build if it already exists.
       */
      async buildDirectoryAsset() {
        const localTagName = `cdkasset-${this.asset.id.assetId.toLowerCase()}`;
        if (!await this.isImageCached(localTagName)) {
          if (this.host.aborted) {
            return void 0;
          }
          await this.buildImage(localTagName);
        }
        return localTagName;
      }
      /**
       * Build a (local) Docker asset by running an external command
       *
       * External command is responsible for deduplicating the build if possible,
       * and is expected to return the generated image identifier on stdout.
       */
      async buildExternalAsset(executable, cwd) {
        const assetPath = cwd ?? this.workDir;
        this.host.emitMessage("build" /* BUILD */, `Building Docker image using command '${executable}'`);
        if (this.host.aborted) {
          return void 0;
        }
        const shellEventPublisher = shellEventPublisherFromEventEmitter(this.host.emitMessage);
        return (await shell(executable, {
          cwd: assetPath,
          shellEventPublisher,
          subprocessOutputDestination: "ignore"
        })).trim();
      }
      async buildImage(localTagName) {
        const source = this.asset.source;
        if (!source.directory) {
          throw new Error(
            `'directory' is expected in the DockerImage asset source, got: ${JSON.stringify(source)}`
          );
        }
        const fullPath = path8.resolve(this.workDir, source.directory);
        this.host.emitMessage("build" /* BUILD */, `Building Docker image at ${fullPath}`);
        await this.docker.build({
          directory: fullPath,
          tag: localTagName,
          buildArgs: source.dockerBuildArgs,
          buildContexts: source.dockerBuildContexts,
          buildSecrets: source.dockerBuildSecrets,
          buildSsh: source.dockerBuildSsh,
          target: source.dockerBuildTarget,
          file: source.dockerFile,
          networkMode: source.networkMode,
          platform: source.platform,
          outputs: source.dockerOutputs,
          cacheFrom: source.cacheFrom,
          cacheTo: source.cacheTo,
          cacheDisabled: source.cacheDisabled
        });
      }
      async isImageCached(localTagName) {
        if (await this.docker.exists(localTagName)) {
          this.host.emitMessage("cached" /* CACHED */, `Cached ${localTagName}`);
          return true;
        }
        return false;
      }
    };
    __name(imageExists, "imageExists");
    __name(repositoryUri, "repositoryUri");
  }
});

// ../../node_modules/mime/Mime.js
var require_Mime = __commonJS({
  "../../node_modules/mime/Mime.js"(exports2, module2) {
    "use strict";
    function Mime() {
      this._types = /* @__PURE__ */ Object.create(null);
      this._extensions = /* @__PURE__ */ Object.create(null);
      for (let i32 = 0; i32 < arguments.length; i32++) {
        this.define(arguments[i32]);
      }
      this.define = this.define.bind(this);
      this.getType = this.getType.bind(this);
      this.getExtension = this.getExtension.bind(this);
    }
    __name(Mime, "Mime");
    Mime.prototype.define = function(typeMap, force) {
      for (let type in typeMap) {
        let extensions = typeMap[type].map(function(t) {
          return t.toLowerCase();
        });
        type = type.toLowerCase();
        for (let i32 = 0; i32 < extensions.length; i32++) {
          const ext = extensions[i32];
          if (ext[0] === "*") {
            continue;
          }
          if (!force && ext in this._types) {
            throw new Error(
              'Attempt to change mapping for "' + ext + '" extension from "' + this._types[ext] + '" to "' + type + '". Pass `force=true` to allow this, otherwise remove "' + ext + '" from the list of extensions for "' + type + '".'
            );
          }
          this._types[ext] = type;
        }
        if (force || !this._extensions[type]) {
          const ext = extensions[0];
          this._extensions[type] = ext[0] !== "*" ? ext : ext.substr(1);
        }
      }
    };
    Mime.prototype.getType = function(path47) {
      path47 = String(path47);
      let last = path47.replace(/^.*[/\\]/, "").toLowerCase();
      let ext = last.replace(/^.*\./, "").toLowerCase();
      let hasPath = last.length < path47.length;
      let hasDot = ext.length < last.length - 1;
      return (hasDot || !hasPath) && this._types[ext] || null;
    };
    Mime.prototype.getExtension = function(type) {
      type = /^\s*([^;\s]*)/.test(type) && RegExp.$1;
      return type && this._extensions[type.toLowerCase()] || null;
    };
    module2.exports = Mime;
  }
});

// ../../node_modules/mime/types/standard.js
var require_standard = __commonJS({
  "../../node_modules/mime/types/standard.js"(exports2, module2) {
    module2.exports = { "application/andrew-inset": ["ez"], "application/applixware": ["aw"], "application/atom+xml": ["atom"], "application/atomcat+xml": ["atomcat"], "application/atomdeleted+xml": ["atomdeleted"], "application/atomsvc+xml": ["atomsvc"], "application/atsc-dwd+xml": ["dwd"], "application/atsc-held+xml": ["held"], "application/atsc-rsat+xml": ["rsat"], "application/bdoc": ["bdoc"], "application/calendar+xml": ["xcs"], "application/ccxml+xml": ["ccxml"], "application/cdfx+xml": ["cdfx"], "application/cdmi-capability": ["cdmia"], "application/cdmi-container": ["cdmic"], "application/cdmi-domain": ["cdmid"], "application/cdmi-object": ["cdmio"], "application/cdmi-queue": ["cdmiq"], "application/cu-seeme": ["cu"], "application/dash+xml": ["mpd"], "application/davmount+xml": ["davmount"], "application/docbook+xml": ["dbk"], "application/dssc+der": ["dssc"], "application/dssc+xml": ["xdssc"], "application/ecmascript": ["es", "ecma"], "application/emma+xml": ["emma"], "application/emotionml+xml": ["emotionml"], "application/epub+zip": ["epub"], "application/exi": ["exi"], "application/express": ["exp"], "application/fdt+xml": ["fdt"], "application/font-tdpfr": ["pfr"], "application/geo+json": ["geojson"], "application/gml+xml": ["gml"], "application/gpx+xml": ["gpx"], "application/gxf": ["gxf"], "application/gzip": ["gz"], "application/hjson": ["hjson"], "application/hyperstudio": ["stk"], "application/inkml+xml": ["ink", "inkml"], "application/ipfix": ["ipfix"], "application/its+xml": ["its"], "application/java-archive": ["jar", "war", "ear"], "application/java-serialized-object": ["ser"], "application/java-vm": ["class"], "application/javascript": ["js", "mjs"], "application/json": ["json", "map"], "application/json5": ["json5"], "application/jsonml+json": ["jsonml"], "application/ld+json": ["jsonld"], "application/lgr+xml": ["lgr"], "application/lost+xml": ["lostxml"], "application/mac-binhex40": ["hqx"], "application/mac-compactpro": ["cpt"], "application/mads+xml": ["mads"], "application/manifest+json": ["webmanifest"], "application/marc": ["mrc"], "application/marcxml+xml": ["mrcx"], "application/mathematica": ["ma", "nb", "mb"], "application/mathml+xml": ["mathml"], "application/mbox": ["mbox"], "application/mediaservercontrol+xml": ["mscml"], "application/metalink+xml": ["metalink"], "application/metalink4+xml": ["meta4"], "application/mets+xml": ["mets"], "application/mmt-aei+xml": ["maei"], "application/mmt-usd+xml": ["musd"], "application/mods+xml": ["mods"], "application/mp21": ["m21", "mp21"], "application/mp4": ["mp4s", "m4p"], "application/msword": ["doc", "dot"], "application/mxf": ["mxf"], "application/n-quads": ["nq"], "application/n-triples": ["nt"], "application/node": ["cjs"], "application/octet-stream": ["bin", "dms", "lrf", "mar", "so", "dist", "distz", "pkg", "bpk", "dump", "elc", "deploy", "exe", "dll", "deb", "dmg", "iso", "img", "msi", "msp", "msm", "buffer"], "application/oda": ["oda"], "application/oebps-package+xml": ["opf"], "application/ogg": ["ogx"], "application/omdoc+xml": ["omdoc"], "application/onenote": ["onetoc", "onetoc2", "onetmp", "onepkg"], "application/oxps": ["oxps"], "application/p2p-overlay+xml": ["relo"], "application/patch-ops-error+xml": ["xer"], "application/pdf": ["pdf"], "application/pgp-encrypted": ["pgp"], "application/pgp-signature": ["asc", "sig"], "application/pics-rules": ["prf"], "application/pkcs10": ["p10"], "application/pkcs7-mime": ["p7m", "p7c"], "application/pkcs7-signature": ["p7s"], "application/pkcs8": ["p8"], "application/pkix-attr-cert": ["ac"], "application/pkix-cert": ["cer"], "application/pkix-crl": ["crl"], "application/pkix-pkipath": ["pkipath"], "application/pkixcmp": ["pki"], "application/pls+xml": ["pls"], "application/postscript": ["ai", "eps", "ps"], "application/provenance+xml": ["provx"], "application/pskc+xml": ["pskcxml"], "application/raml+yaml": ["raml"], "application/rdf+xml": ["rdf", "owl"], "application/reginfo+xml": ["rif"], "application/relax-ng-compact-syntax": ["rnc"], "application/resource-lists+xml": ["rl"], "application/resource-lists-diff+xml": ["rld"], "application/rls-services+xml": ["rs"], "application/route-apd+xml": ["rapd"], "application/route-s-tsid+xml": ["sls"], "application/route-usd+xml": ["rusd"], "application/rpki-ghostbusters": ["gbr"], "application/rpki-manifest": ["mft"], "application/rpki-roa": ["roa"], "application/rsd+xml": ["rsd"], "application/rss+xml": ["rss"], "application/rtf": ["rtf"], "application/sbml+xml": ["sbml"], "application/scvp-cv-request": ["scq"], "application/scvp-cv-response": ["scs"], "application/scvp-vp-request": ["spq"], "application/scvp-vp-response": ["spp"], "application/sdp": ["sdp"], "application/senml+xml": ["senmlx"], "application/sensml+xml": ["sensmlx"], "application/set-payment-initiation": ["setpay"], "application/set-registration-initiation": ["setreg"], "application/shf+xml": ["shf"], "application/sieve": ["siv", "sieve"], "application/smil+xml": ["smi", "smil"], "application/sparql-query": ["rq"], "application/sparql-results+xml": ["srx"], "application/srgs": ["gram"], "application/srgs+xml": ["grxml"], "application/sru+xml": ["sru"], "application/ssdl+xml": ["ssdl"], "application/ssml+xml": ["ssml"], "application/swid+xml": ["swidtag"], "application/tei+xml": ["tei", "teicorpus"], "application/thraud+xml": ["tfi"], "application/timestamped-data": ["tsd"], "application/toml": ["toml"], "application/trig": ["trig"], "application/ttml+xml": ["ttml"], "application/ubjson": ["ubj"], "application/urc-ressheet+xml": ["rsheet"], "application/urc-targetdesc+xml": ["td"], "application/voicexml+xml": ["vxml"], "application/wasm": ["wasm"], "application/widget": ["wgt"], "application/winhlp": ["hlp"], "application/wsdl+xml": ["wsdl"], "application/wspolicy+xml": ["wspolicy"], "application/xaml+xml": ["xaml"], "application/xcap-att+xml": ["xav"], "application/xcap-caps+xml": ["xca"], "application/xcap-diff+xml": ["xdf"], "application/xcap-el+xml": ["xel"], "application/xcap-ns+xml": ["xns"], "application/xenc+xml": ["xenc"], "application/xhtml+xml": ["xhtml", "xht"], "application/xliff+xml": ["xlf"], "application/xml": ["xml", "xsl", "xsd", "rng"], "application/xml-dtd": ["dtd"], "application/xop+xml": ["xop"], "application/xproc+xml": ["xpl"], "application/xslt+xml": ["*xsl", "xslt"], "application/xspf+xml": ["xspf"], "application/xv+xml": ["mxml", "xhvml", "xvml", "xvm"], "application/yang": ["yang"], "application/yin+xml": ["yin"], "application/zip": ["zip"], "audio/3gpp": ["*3gpp"], "audio/adpcm": ["adp"], "audio/amr": ["amr"], "audio/basic": ["au", "snd"], "audio/midi": ["mid", "midi", "kar", "rmi"], "audio/mobile-xmf": ["mxmf"], "audio/mp3": ["*mp3"], "audio/mp4": ["m4a", "mp4a"], "audio/mpeg": ["mpga", "mp2", "mp2a", "mp3", "m2a", "m3a"], "audio/ogg": ["oga", "ogg", "spx", "opus"], "audio/s3m": ["s3m"], "audio/silk": ["sil"], "audio/wav": ["wav"], "audio/wave": ["*wav"], "audio/webm": ["weba"], "audio/xm": ["xm"], "font/collection": ["ttc"], "font/otf": ["otf"], "font/ttf": ["ttf"], "font/woff": ["woff"], "font/woff2": ["woff2"], "image/aces": ["exr"], "image/apng": ["apng"], "image/avif": ["avif"], "image/bmp": ["bmp"], "image/cgm": ["cgm"], "image/dicom-rle": ["drle"], "image/emf": ["emf"], "image/fits": ["fits"], "image/g3fax": ["g3"], "image/gif": ["gif"], "image/heic": ["heic"], "image/heic-sequence": ["heics"], "image/heif": ["heif"], "image/heif-sequence": ["heifs"], "image/hej2k": ["hej2"], "image/hsj2": ["hsj2"], "image/ief": ["ief"], "image/jls": ["jls"], "image/jp2": ["jp2", "jpg2"], "image/jpeg": ["jpeg", "jpg", "jpe"], "image/jph": ["jph"], "image/jphc": ["jhc"], "image/jpm": ["jpm"], "image/jpx": ["jpx", "jpf"], "image/jxr": ["jxr"], "image/jxra": ["jxra"], "image/jxrs": ["jxrs"], "image/jxs": ["jxs"], "image/jxsc": ["jxsc"], "image/jxsi": ["jxsi"], "image/jxss": ["jxss"], "image/ktx": ["ktx"], "image/ktx2": ["ktx2"], "image/png": ["png"], "image/sgi": ["sgi"], "image/svg+xml": ["svg", "svgz"], "image/t38": ["t38"], "image/tiff": ["tif", "tiff"], "image/tiff-fx": ["tfx"], "image/webp": ["webp"], "image/wmf": ["wmf"], "message/disposition-notification": ["disposition-notification"], "message/global": ["u8msg"], "message/global-delivery-status": ["u8dsn"], "message/global-disposition-notification": ["u8mdn"], "message/global-headers": ["u8hdr"], "message/rfc822": ["eml", "mime"], "model/3mf": ["3mf"], "model/gltf+json": ["gltf"], "model/gltf-binary": ["glb"], "model/iges": ["igs", "iges"], "model/mesh": ["msh", "mesh", "silo"], "model/mtl": ["mtl"], "model/obj": ["obj"], "model/step+xml": ["stpx"], "model/step+zip": ["stpz"], "model/step-xml+zip": ["stpxz"], "model/stl": ["stl"], "model/vrml": ["wrl", "vrml"], "model/x3d+binary": ["*x3db", "x3dbz"], "model/x3d+fastinfoset": ["x3db"], "model/x3d+vrml": ["*x3dv", "x3dvz"], "model/x3d+xml": ["x3d", "x3dz"], "model/x3d-vrml": ["x3dv"], "text/cache-manifest": ["appcache", "manifest"], "text/calendar": ["ics", "ifb"], "text/coffeescript": ["coffee", "litcoffee"], "text/css": ["css"], "text/csv": ["csv"], "text/html": ["html", "htm", "shtml"], "text/jade": ["jade"], "text/jsx": ["jsx"], "text/less": ["less"], "text/markdown": ["markdown", "md"], "text/mathml": ["mml"], "text/mdx": ["mdx"], "text/n3": ["n3"], "text/plain": ["txt", "text", "conf", "def", "list", "log", "in", "ini"], "text/richtext": ["rtx"], "text/rtf": ["*rtf"], "text/sgml": ["sgml", "sgm"], "text/shex": ["shex"], "text/slim": ["slim", "slm"], "text/spdx": ["spdx"], "text/stylus": ["stylus", "styl"], "text/tab-separated-values": ["tsv"], "text/troff": ["t", "tr", "roff", "man", "me", "ms"], "text/turtle": ["ttl"], "text/uri-list": ["uri", "uris", "urls"], "text/vcard": ["vcard"], "text/vtt": ["vtt"], "text/xml": ["*xml"], "text/yaml": ["yaml", "yml"], "video/3gpp": ["3gp", "3gpp"], "video/3gpp2": ["3g2"], "video/h261": ["h261"], "video/h263": ["h263"], "video/h264": ["h264"], "video/iso.segment": ["m4s"], "video/jpeg": ["jpgv"], "video/jpm": ["*jpm", "jpgm"], "video/mj2": ["mj2", "mjp2"], "video/mp2t": ["ts"], "video/mp4": ["mp4", "mp4v", "mpg4"], "video/mpeg": ["mpeg", "mpg", "mpe", "m1v", "m2v"], "video/ogg": ["ogv"], "video/quicktime": ["qt", "mov"], "video/webm": ["webm"] };
  }
});

// ../../node_modules/mime/types/other.js
var require_other = __commonJS({
  "../../node_modules/mime/types/other.js"(exports2, module2) {
    module2.exports = { "application/prs.cww": ["cww"], "application/vnd.1000minds.decision-model+xml": ["1km"], "application/vnd.3gpp.pic-bw-large": ["plb"], "application/vnd.3gpp.pic-bw-small": ["psb"], "application/vnd.3gpp.pic-bw-var": ["pvb"], "application/vnd.3gpp2.tcap": ["tcap"], "application/vnd.3m.post-it-notes": ["pwn"], "application/vnd.accpac.simply.aso": ["aso"], "application/vnd.accpac.simply.imp": ["imp"], "application/vnd.acucobol": ["acu"], "application/vnd.acucorp": ["atc", "acutc"], "application/vnd.adobe.air-application-installer-package+zip": ["air"], "application/vnd.adobe.formscentral.fcdt": ["fcdt"], "application/vnd.adobe.fxp": ["fxp", "fxpl"], "application/vnd.adobe.xdp+xml": ["xdp"], "application/vnd.adobe.xfdf": ["xfdf"], "application/vnd.ahead.space": ["ahead"], "application/vnd.airzip.filesecure.azf": ["azf"], "application/vnd.airzip.filesecure.azs": ["azs"], "application/vnd.amazon.ebook": ["azw"], "application/vnd.americandynamics.acc": ["acc"], "application/vnd.amiga.ami": ["ami"], "application/vnd.android.package-archive": ["apk"], "application/vnd.anser-web-certificate-issue-initiation": ["cii"], "application/vnd.anser-web-funds-transfer-initiation": ["fti"], "application/vnd.antix.game-component": ["atx"], "application/vnd.apple.installer+xml": ["mpkg"], "application/vnd.apple.keynote": ["key"], "application/vnd.apple.mpegurl": ["m3u8"], "application/vnd.apple.numbers": ["numbers"], "application/vnd.apple.pages": ["pages"], "application/vnd.apple.pkpass": ["pkpass"], "application/vnd.aristanetworks.swi": ["swi"], "application/vnd.astraea-software.iota": ["iota"], "application/vnd.audiograph": ["aep"], "application/vnd.balsamiq.bmml+xml": ["bmml"], "application/vnd.blueice.multipass": ["mpm"], "application/vnd.bmi": ["bmi"], "application/vnd.businessobjects": ["rep"], "application/vnd.chemdraw+xml": ["cdxml"], "application/vnd.chipnuts.karaoke-mmd": ["mmd"], "application/vnd.cinderella": ["cdy"], "application/vnd.citationstyles.style+xml": ["csl"], "application/vnd.claymore": ["cla"], "application/vnd.cloanto.rp9": ["rp9"], "application/vnd.clonk.c4group": ["c4g", "c4d", "c4f", "c4p", "c4u"], "application/vnd.cluetrust.cartomobile-config": ["c11amc"], "application/vnd.cluetrust.cartomobile-config-pkg": ["c11amz"], "application/vnd.commonspace": ["csp"], "application/vnd.contact.cmsg": ["cdbcmsg"], "application/vnd.cosmocaller": ["cmc"], "application/vnd.crick.clicker": ["clkx"], "application/vnd.crick.clicker.keyboard": ["clkk"], "application/vnd.crick.clicker.palette": ["clkp"], "application/vnd.crick.clicker.template": ["clkt"], "application/vnd.crick.clicker.wordbank": ["clkw"], "application/vnd.criticaltools.wbs+xml": ["wbs"], "application/vnd.ctc-posml": ["pml"], "application/vnd.cups-ppd": ["ppd"], "application/vnd.curl.car": ["car"], "application/vnd.curl.pcurl": ["pcurl"], "application/vnd.dart": ["dart"], "application/vnd.data-vision.rdz": ["rdz"], "application/vnd.dbf": ["dbf"], "application/vnd.dece.data": ["uvf", "uvvf", "uvd", "uvvd"], "application/vnd.dece.ttml+xml": ["uvt", "uvvt"], "application/vnd.dece.unspecified": ["uvx", "uvvx"], "application/vnd.dece.zip": ["uvz", "uvvz"], "application/vnd.denovo.fcselayout-link": ["fe_launch"], "application/vnd.dna": ["dna"], "application/vnd.dolby.mlp": ["mlp"], "application/vnd.dpgraph": ["dpg"], "application/vnd.dreamfactory": ["dfac"], "application/vnd.ds-keypoint": ["kpxx"], "application/vnd.dvb.ait": ["ait"], "application/vnd.dvb.service": ["svc"], "application/vnd.dynageo": ["geo"], "application/vnd.ecowin.chart": ["mag"], "application/vnd.enliven": ["nml"], "application/vnd.epson.esf": ["esf"], "application/vnd.epson.msf": ["msf"], "application/vnd.epson.quickanime": ["qam"], "application/vnd.epson.salt": ["slt"], "application/vnd.epson.ssf": ["ssf"], "application/vnd.eszigno3+xml": ["es3", "et3"], "application/vnd.ezpix-album": ["ez2"], "application/vnd.ezpix-package": ["ez3"], "application/vnd.fdf": ["fdf"], "application/vnd.fdsn.mseed": ["mseed"], "application/vnd.fdsn.seed": ["seed", "dataless"], "application/vnd.flographit": ["gph"], "application/vnd.fluxtime.clip": ["ftc"], "application/vnd.framemaker": ["fm", "frame", "maker", "book"], "application/vnd.frogans.fnc": ["fnc"], "application/vnd.frogans.ltf": ["ltf"], "application/vnd.fsc.weblaunch": ["fsc"], "application/vnd.fujitsu.oasys": ["oas"], "application/vnd.fujitsu.oasys2": ["oa2"], "application/vnd.fujitsu.oasys3": ["oa3"], "application/vnd.fujitsu.oasysgp": ["fg5"], "application/vnd.fujitsu.oasysprs": ["bh2"], "application/vnd.fujixerox.ddd": ["ddd"], "application/vnd.fujixerox.docuworks": ["xdw"], "application/vnd.fujixerox.docuworks.binder": ["xbd"], "application/vnd.fuzzysheet": ["fzs"], "application/vnd.genomatix.tuxedo": ["txd"], "application/vnd.geogebra.file": ["ggb"], "application/vnd.geogebra.tool": ["ggt"], "application/vnd.geometry-explorer": ["gex", "gre"], "application/vnd.geonext": ["gxt"], "application/vnd.geoplan": ["g2w"], "application/vnd.geospace": ["g3w"], "application/vnd.gmx": ["gmx"], "application/vnd.google-apps.document": ["gdoc"], "application/vnd.google-apps.presentation": ["gslides"], "application/vnd.google-apps.spreadsheet": ["gsheet"], "application/vnd.google-earth.kml+xml": ["kml"], "application/vnd.google-earth.kmz": ["kmz"], "application/vnd.grafeq": ["gqf", "gqs"], "application/vnd.groove-account": ["gac"], "application/vnd.groove-help": ["ghf"], "application/vnd.groove-identity-message": ["gim"], "application/vnd.groove-injector": ["grv"], "application/vnd.groove-tool-message": ["gtm"], "application/vnd.groove-tool-template": ["tpl"], "application/vnd.groove-vcard": ["vcg"], "application/vnd.hal+xml": ["hal"], "application/vnd.handheld-entertainment+xml": ["zmm"], "application/vnd.hbci": ["hbci"], "application/vnd.hhe.lesson-player": ["les"], "application/vnd.hp-hpgl": ["hpgl"], "application/vnd.hp-hpid": ["hpid"], "application/vnd.hp-hps": ["hps"], "application/vnd.hp-jlyt": ["jlt"], "application/vnd.hp-pcl": ["pcl"], "application/vnd.hp-pclxl": ["pclxl"], "application/vnd.hydrostatix.sof-data": ["sfd-hdstx"], "application/vnd.ibm.minipay": ["mpy"], "application/vnd.ibm.modcap": ["afp", "listafp", "list3820"], "application/vnd.ibm.rights-management": ["irm"], "application/vnd.ibm.secure-container": ["sc"], "application/vnd.iccprofile": ["icc", "icm"], "application/vnd.igloader": ["igl"], "application/vnd.immervision-ivp": ["ivp"], "application/vnd.immervision-ivu": ["ivu"], "application/vnd.insors.igm": ["igm"], "application/vnd.intercon.formnet": ["xpw", "xpx"], "application/vnd.intergeo": ["i2g"], "application/vnd.intu.qbo": ["qbo"], "application/vnd.intu.qfx": ["qfx"], "application/vnd.ipunplugged.rcprofile": ["rcprofile"], "application/vnd.irepository.package+xml": ["irp"], "application/vnd.is-xpr": ["xpr"], "application/vnd.isac.fcs": ["fcs"], "application/vnd.jam": ["jam"], "application/vnd.jcp.javame.midlet-rms": ["rms"], "application/vnd.jisp": ["jisp"], "application/vnd.joost.joda-archive": ["joda"], "application/vnd.kahootz": ["ktz", "ktr"], "application/vnd.kde.karbon": ["karbon"], "application/vnd.kde.kchart": ["chrt"], "application/vnd.kde.kformula": ["kfo"], "application/vnd.kde.kivio": ["flw"], "application/vnd.kde.kontour": ["kon"], "application/vnd.kde.kpresenter": ["kpr", "kpt"], "application/vnd.kde.kspread": ["ksp"], "application/vnd.kde.kword": ["kwd", "kwt"], "application/vnd.kenameaapp": ["htke"], "application/vnd.kidspiration": ["kia"], "application/vnd.kinar": ["kne", "knp"], "application/vnd.koan": ["skp", "skd", "skt", "skm"], "application/vnd.kodak-descriptor": ["sse"], "application/vnd.las.las+xml": ["lasxml"], "application/vnd.llamagraphics.life-balance.desktop": ["lbd"], "application/vnd.llamagraphics.life-balance.exchange+xml": ["lbe"], "application/vnd.lotus-1-2-3": ["123"], "application/vnd.lotus-approach": ["apr"], "application/vnd.lotus-freelance": ["pre"], "application/vnd.lotus-notes": ["nsf"], "application/vnd.lotus-organizer": ["org"], "application/vnd.lotus-screencam": ["scm"], "application/vnd.lotus-wordpro": ["lwp"], "application/vnd.macports.portpkg": ["portpkg"], "application/vnd.mapbox-vector-tile": ["mvt"], "application/vnd.mcd": ["mcd"], "application/vnd.medcalcdata": ["mc1"], "application/vnd.mediastation.cdkey": ["cdkey"], "application/vnd.mfer": ["mwf"], "application/vnd.mfmp": ["mfm"], "application/vnd.micrografx.flo": ["flo"], "application/vnd.micrografx.igx": ["igx"], "application/vnd.mif": ["mif"], "application/vnd.mobius.daf": ["daf"], "application/vnd.mobius.dis": ["dis"], "application/vnd.mobius.mbk": ["mbk"], "application/vnd.mobius.mqy": ["mqy"], "application/vnd.mobius.msl": ["msl"], "application/vnd.mobius.plc": ["plc"], "application/vnd.mobius.txf": ["txf"], "application/vnd.mophun.application": ["mpn"], "application/vnd.mophun.certificate": ["mpc"], "application/vnd.mozilla.xul+xml": ["xul"], "application/vnd.ms-artgalry": ["cil"], "application/vnd.ms-cab-compressed": ["cab"], "application/vnd.ms-excel": ["xls", "xlm", "xla", "xlc", "xlt", "xlw"], "application/vnd.ms-excel.addin.macroenabled.12": ["xlam"], "application/vnd.ms-excel.sheet.binary.macroenabled.12": ["xlsb"], "application/vnd.ms-excel.sheet.macroenabled.12": ["xlsm"], "application/vnd.ms-excel.template.macroenabled.12": ["xltm"], "application/vnd.ms-fontobject": ["eot"], "application/vnd.ms-htmlhelp": ["chm"], "application/vnd.ms-ims": ["ims"], "application/vnd.ms-lrm": ["lrm"], "application/vnd.ms-officetheme": ["thmx"], "application/vnd.ms-outlook": ["msg"], "application/vnd.ms-pki.seccat": ["cat"], "application/vnd.ms-pki.stl": ["*stl"], "application/vnd.ms-powerpoint": ["ppt", "pps", "pot"], "application/vnd.ms-powerpoint.addin.macroenabled.12": ["ppam"], "application/vnd.ms-powerpoint.presentation.macroenabled.12": ["pptm"], "application/vnd.ms-powerpoint.slide.macroenabled.12": ["sldm"], "application/vnd.ms-powerpoint.slideshow.macroenabled.12": ["ppsm"], "application/vnd.ms-powerpoint.template.macroenabled.12": ["potm"], "application/vnd.ms-project": ["mpp", "mpt"], "application/vnd.ms-word.document.macroenabled.12": ["docm"], "application/vnd.ms-word.template.macroenabled.12": ["dotm"], "application/vnd.ms-works": ["wps", "wks", "wcm", "wdb"], "application/vnd.ms-wpl": ["wpl"], "application/vnd.ms-xpsdocument": ["xps"], "application/vnd.mseq": ["mseq"], "application/vnd.musician": ["mus"], "application/vnd.muvee.style": ["msty"], "application/vnd.mynfc": ["taglet"], "application/vnd.neurolanguage.nlu": ["nlu"], "application/vnd.nitf": ["ntf", "nitf"], "application/vnd.noblenet-directory": ["nnd"], "application/vnd.noblenet-sealer": ["nns"], "application/vnd.noblenet-web": ["nnw"], "application/vnd.nokia.n-gage.ac+xml": ["*ac"], "application/vnd.nokia.n-gage.data": ["ngdat"], "application/vnd.nokia.n-gage.symbian.install": ["n-gage"], "application/vnd.nokia.radio-preset": ["rpst"], "application/vnd.nokia.radio-presets": ["rpss"], "application/vnd.novadigm.edm": ["edm"], "application/vnd.novadigm.edx": ["edx"], "application/vnd.novadigm.ext": ["ext"], "application/vnd.oasis.opendocument.chart": ["odc"], "application/vnd.oasis.opendocument.chart-template": ["otc"], "application/vnd.oasis.opendocument.database": ["odb"], "application/vnd.oasis.opendocument.formula": ["odf"], "application/vnd.oasis.opendocument.formula-template": ["odft"], "application/vnd.oasis.opendocument.graphics": ["odg"], "application/vnd.oasis.opendocument.graphics-template": ["otg"], "application/vnd.oasis.opendocument.image": ["odi"], "application/vnd.oasis.opendocument.image-template": ["oti"], "application/vnd.oasis.opendocument.presentation": ["odp"], "application/vnd.oasis.opendocument.presentation-template": ["otp"], "application/vnd.oasis.opendocument.spreadsheet": ["ods"], "application/vnd.oasis.opendocument.spreadsheet-template": ["ots"], "application/vnd.oasis.opendocument.text": ["odt"], "application/vnd.oasis.opendocument.text-master": ["odm"], "application/vnd.oasis.opendocument.text-template": ["ott"], "application/vnd.oasis.opendocument.text-web": ["oth"], "application/vnd.olpc-sugar": ["xo"], "application/vnd.oma.dd2+xml": ["dd2"], "application/vnd.openblox.game+xml": ["obgx"], "application/vnd.openofficeorg.extension": ["oxt"], "application/vnd.openstreetmap.data+xml": ["osm"], "application/vnd.openxmlformats-officedocument.presentationml.presentation": ["pptx"], "application/vnd.openxmlformats-officedocument.presentationml.slide": ["sldx"], "application/vnd.openxmlformats-officedocument.presentationml.slideshow": ["ppsx"], "application/vnd.openxmlformats-officedocument.presentationml.template": ["potx"], "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet": ["xlsx"], "application/vnd.openxmlformats-officedocument.spreadsheetml.template": ["xltx"], "application/vnd.openxmlformats-officedocument.wordprocessingml.document": ["docx"], "application/vnd.openxmlformats-officedocument.wordprocessingml.template": ["dotx"], "application/vnd.osgeo.mapguide.package": ["mgp"], "application/vnd.osgi.dp": ["dp"], "application/vnd.osgi.subsystem": ["esa"], "application/vnd.palm": ["pdb", "pqa", "oprc"], "application/vnd.pawaafile": ["paw"], "application/vnd.pg.format": ["str"], "application/vnd.pg.osasli": ["ei6"], "application/vnd.picsel": ["efif"], "application/vnd.pmi.widget": ["wg"], "application/vnd.pocketlearn": ["plf"], "application/vnd.powerbuilder6": ["pbd"], "application/vnd.previewsystems.box": ["box"], "application/vnd.proteus.magazine": ["mgz"], "application/vnd.publishare-delta-tree": ["qps"], "application/vnd.pvi.ptid1": ["ptid"], "application/vnd.quark.quarkxpress": ["qxd", "qxt", "qwd", "qwt", "qxl", "qxb"], "application/vnd.rar": ["rar"], "application/vnd.realvnc.bed": ["bed"], "application/vnd.recordare.musicxml": ["mxl"], "application/vnd.recordare.musicxml+xml": ["musicxml"], "application/vnd.rig.cryptonote": ["cryptonote"], "application/vnd.rim.cod": ["cod"], "application/vnd.rn-realmedia": ["rm"], "application/vnd.rn-realmedia-vbr": ["rmvb"], "application/vnd.route66.link66+xml": ["link66"], "application/vnd.sailingtracker.track": ["st"], "application/vnd.seemail": ["see"], "application/vnd.sema": ["sema"], "application/vnd.semd": ["semd"], "application/vnd.semf": ["semf"], "application/vnd.shana.informed.formdata": ["ifm"], "application/vnd.shana.informed.formtemplate": ["itp"], "application/vnd.shana.informed.interchange": ["iif"], "application/vnd.shana.informed.package": ["ipk"], "application/vnd.simtech-mindmapper": ["twd", "twds"], "application/vnd.smaf": ["mmf"], "application/vnd.smart.teacher": ["teacher"], "application/vnd.software602.filler.form+xml": ["fo"], "application/vnd.solent.sdkm+xml": ["sdkm", "sdkd"], "application/vnd.spotfire.dxp": ["dxp"], "application/vnd.spotfire.sfs": ["sfs"], "application/vnd.stardivision.calc": ["sdc"], "application/vnd.stardivision.draw": ["sda"], "application/vnd.stardivision.impress": ["sdd"], "application/vnd.stardivision.math": ["smf"], "application/vnd.stardivision.writer": ["sdw", "vor"], "application/vnd.stardivision.writer-global": ["sgl"], "application/vnd.stepmania.package": ["smzip"], "application/vnd.stepmania.stepchart": ["sm"], "application/vnd.sun.wadl+xml": ["wadl"], "application/vnd.sun.xml.calc": ["sxc"], "application/vnd.sun.xml.calc.template": ["stc"], "application/vnd.sun.xml.draw": ["sxd"], "application/vnd.sun.xml.draw.template": ["std"], "application/vnd.sun.xml.impress": ["sxi"], "application/vnd.sun.xml.impress.template": ["sti"], "application/vnd.sun.xml.math": ["sxm"], "application/vnd.sun.xml.writer": ["sxw"], "application/vnd.sun.xml.writer.global": ["sxg"], "application/vnd.sun.xml.writer.template": ["stw"], "application/vnd.sus-calendar": ["sus", "susp"], "application/vnd.svd": ["svd"], "application/vnd.symbian.install": ["sis", "sisx"], "application/vnd.syncml+xml": ["xsm"], "application/vnd.syncml.dm+wbxml": ["bdm"], "application/vnd.syncml.dm+xml": ["xdm"], "application/vnd.syncml.dmddf+xml": ["ddf"], "application/vnd.tao.intent-module-archive": ["tao"], "application/vnd.tcpdump.pcap": ["pcap", "cap", "dmp"], "application/vnd.tmobile-livetv": ["tmo"], "application/vnd.trid.tpt": ["tpt"], "application/vnd.triscape.mxs": ["mxs"], "application/vnd.trueapp": ["tra"], "application/vnd.ufdl": ["ufd", "ufdl"], "application/vnd.uiq.theme": ["utz"], "application/vnd.umajin": ["umj"], "application/vnd.unity": ["unityweb"], "application/vnd.uoml+xml": ["uoml"], "application/vnd.vcx": ["vcx"], "application/vnd.visio": ["vsd", "vst", "vss", "vsw"], "application/vnd.visionary": ["vis"], "application/vnd.vsf": ["vsf"], "application/vnd.wap.wbxml": ["wbxml"], "application/vnd.wap.wmlc": ["wmlc"], "application/vnd.wap.wmlscriptc": ["wmlsc"], "application/vnd.webturbo": ["wtb"], "application/vnd.wolfram.player": ["nbp"], "application/vnd.wordperfect": ["wpd"], "application/vnd.wqd": ["wqd"], "application/vnd.wt.stf": ["stf"], "application/vnd.xara": ["xar"], "application/vnd.xfdl": ["xfdl"], "application/vnd.yamaha.hv-dic": ["hvd"], "application/vnd.yamaha.hv-script": ["hvs"], "application/vnd.yamaha.hv-voice": ["hvp"], "application/vnd.yamaha.openscoreformat": ["osf"], "application/vnd.yamaha.openscoreformat.osfpvg+xml": ["osfpvg"], "application/vnd.yamaha.smaf-audio": ["saf"], "application/vnd.yamaha.smaf-phrase": ["spf"], "application/vnd.yellowriver-custom-menu": ["cmp"], "application/vnd.zul": ["zir", "zirz"], "application/vnd.zzazz.deck+xml": ["zaz"], "application/x-7z-compressed": ["7z"], "application/x-abiword": ["abw"], "application/x-ace-compressed": ["ace"], "application/x-apple-diskimage": ["*dmg"], "application/x-arj": ["arj"], "application/x-authorware-bin": ["aab", "x32", "u32", "vox"], "application/x-authorware-map": ["aam"], "application/x-authorware-seg": ["aas"], "application/x-bcpio": ["bcpio"], "application/x-bdoc": ["*bdoc"], "application/x-bittorrent": ["torrent"], "application/x-blorb": ["blb", "blorb"], "application/x-bzip": ["bz"], "application/x-bzip2": ["bz2", "boz"], "application/x-cbr": ["cbr", "cba", "cbt", "cbz", "cb7"], "application/x-cdlink": ["vcd"], "application/x-cfs-compressed": ["cfs"], "application/x-chat": ["chat"], "application/x-chess-pgn": ["pgn"], "application/x-chrome-extension": ["crx"], "application/x-cocoa": ["cco"], "application/x-conference": ["nsc"], "application/x-cpio": ["cpio"], "application/x-csh": ["csh"], "application/x-debian-package": ["*deb", "udeb"], "application/x-dgc-compressed": ["dgc"], "application/x-director": ["dir", "dcr", "dxr", "cst", "cct", "cxt", "w3d", "fgd", "swa"], "application/x-doom": ["wad"], "application/x-dtbncx+xml": ["ncx"], "application/x-dtbook+xml": ["dtb"], "application/x-dtbresource+xml": ["res"], "application/x-dvi": ["dvi"], "application/x-envoy": ["evy"], "application/x-eva": ["eva"], "application/x-font-bdf": ["bdf"], "application/x-font-ghostscript": ["gsf"], "application/x-font-linux-psf": ["psf"], "application/x-font-pcf": ["pcf"], "application/x-font-snf": ["snf"], "application/x-font-type1": ["pfa", "pfb", "pfm", "afm"], "application/x-freearc": ["arc"], "application/x-futuresplash": ["spl"], "application/x-gca-compressed": ["gca"], "application/x-glulx": ["ulx"], "application/x-gnumeric": ["gnumeric"], "application/x-gramps-xml": ["gramps"], "application/x-gtar": ["gtar"], "application/x-hdf": ["hdf"], "application/x-httpd-php": ["php"], "application/x-install-instructions": ["install"], "application/x-iso9660-image": ["*iso"], "application/x-iwork-keynote-sffkey": ["*key"], "application/x-iwork-numbers-sffnumbers": ["*numbers"], "application/x-iwork-pages-sffpages": ["*pages"], "application/x-java-archive-diff": ["jardiff"], "application/x-java-jnlp-file": ["jnlp"], "application/x-keepass2": ["kdbx"], "application/x-latex": ["latex"], "application/x-lua-bytecode": ["luac"], "application/x-lzh-compressed": ["lzh", "lha"], "application/x-makeself": ["run"], "application/x-mie": ["mie"], "application/x-mobipocket-ebook": ["prc", "mobi"], "application/x-ms-application": ["application"], "application/x-ms-shortcut": ["lnk"], "application/x-ms-wmd": ["wmd"], "application/x-ms-wmz": ["wmz"], "application/x-ms-xbap": ["xbap"], "application/x-msaccess": ["mdb"], "application/x-msbinder": ["obd"], "application/x-mscardfile": ["crd"], "application/x-msclip": ["clp"], "application/x-msdos-program": ["*exe"], "application/x-msdownload": ["*exe", "*dll", "com", "bat", "*msi"], "application/x-msmediaview": ["mvb", "m13", "m14"], "application/x-msmetafile": ["*wmf", "*wmz", "*emf", "emz"], "application/x-msmoney": ["mny"], "application/x-mspublisher": ["pub"], "application/x-msschedule": ["scd"], "application/x-msterminal": ["trm"], "application/x-mswrite": ["wri"], "application/x-netcdf": ["nc", "cdf"], "application/x-ns-proxy-autoconfig": ["pac"], "application/x-nzb": ["nzb"], "application/x-perl": ["pl", "pm"], "application/x-pilot": ["*prc", "*pdb"], "application/x-pkcs12": ["p12", "pfx"], "application/x-pkcs7-certificates": ["p7b", "spc"], "application/x-pkcs7-certreqresp": ["p7r"], "application/x-rar-compressed": ["*rar"], "application/x-redhat-package-manager": ["rpm"], "application/x-research-info-systems": ["ris"], "application/x-sea": ["sea"], "application/x-sh": ["sh"], "application/x-shar": ["shar"], "application/x-shockwave-flash": ["swf"], "application/x-silverlight-app": ["xap"], "application/x-sql": ["sql"], "application/x-stuffit": ["sit"], "application/x-stuffitx": ["sitx"], "application/x-subrip": ["srt"], "application/x-sv4cpio": ["sv4cpio"], "application/x-sv4crc": ["sv4crc"], "application/x-t3vm-image": ["t3"], "application/x-tads": ["gam"], "application/x-tar": ["tar"], "application/x-tcl": ["tcl", "tk"], "application/x-tex": ["tex"], "application/x-tex-tfm": ["tfm"], "application/x-texinfo": ["texinfo", "texi"], "application/x-tgif": ["*obj"], "application/x-ustar": ["ustar"], "application/x-virtualbox-hdd": ["hdd"], "application/x-virtualbox-ova": ["ova"], "application/x-virtualbox-ovf": ["ovf"], "application/x-virtualbox-vbox": ["vbox"], "application/x-virtualbox-vbox-extpack": ["vbox-extpack"], "application/x-virtualbox-vdi": ["vdi"], "application/x-virtualbox-vhd": ["vhd"], "application/x-virtualbox-vmdk": ["vmdk"], "application/x-wais-source": ["src"], "application/x-web-app-manifest+json": ["webapp"], "application/x-x509-ca-cert": ["der", "crt", "pem"], "application/x-xfig": ["fig"], "application/x-xliff+xml": ["*xlf"], "application/x-xpinstall": ["xpi"], "application/x-xz": ["xz"], "application/x-zmachine": ["z1", "z2", "z3", "z4", "z5", "z6", "z7", "z8"], "audio/vnd.dece.audio": ["uva", "uvva"], "audio/vnd.digital-winds": ["eol"], "audio/vnd.dra": ["dra"], "audio/vnd.dts": ["dts"], "audio/vnd.dts.hd": ["dtshd"], "audio/vnd.lucent.voice": ["lvp"], "audio/vnd.ms-playready.media.pya": ["pya"], "audio/vnd.nuera.ecelp4800": ["ecelp4800"], "audio/vnd.nuera.ecelp7470": ["ecelp7470"], "audio/vnd.nuera.ecelp9600": ["ecelp9600"], "audio/vnd.rip": ["rip"], "audio/x-aac": ["aac"], "audio/x-aiff": ["aif", "aiff", "aifc"], "audio/x-caf": ["caf"], "audio/x-flac": ["flac"], "audio/x-m4a": ["*m4a"], "audio/x-matroska": ["mka"], "audio/x-mpegurl": ["m3u"], "audio/x-ms-wax": ["wax"], "audio/x-ms-wma": ["wma"], "audio/x-pn-realaudio": ["ram", "ra"], "audio/x-pn-realaudio-plugin": ["rmp"], "audio/x-realaudio": ["*ra"], "audio/x-wav": ["*wav"], "chemical/x-cdx": ["cdx"], "chemical/x-cif": ["cif"], "chemical/x-cmdf": ["cmdf"], "chemical/x-cml": ["cml"], "chemical/x-csml": ["csml"], "chemical/x-xyz": ["xyz"], "image/prs.btif": ["btif"], "image/prs.pti": ["pti"], "image/vnd.adobe.photoshop": ["psd"], "image/vnd.airzip.accelerator.azv": ["azv"], "image/vnd.dece.graphic": ["uvi", "uvvi", "uvg", "uvvg"], "image/vnd.djvu": ["djvu", "djv"], "image/vnd.dvb.subtitle": ["*sub"], "image/vnd.dwg": ["dwg"], "image/vnd.dxf": ["dxf"], "image/vnd.fastbidsheet": ["fbs"], "image/vnd.fpx": ["fpx"], "image/vnd.fst": ["fst"], "image/vnd.fujixerox.edmics-mmr": ["mmr"], "image/vnd.fujixerox.edmics-rlc": ["rlc"], "image/vnd.microsoft.icon": ["ico"], "image/vnd.ms-dds": ["dds"], "image/vnd.ms-modi": ["mdi"], "image/vnd.ms-photo": ["wdp"], "image/vnd.net-fpx": ["npx"], "image/vnd.pco.b16": ["b16"], "image/vnd.tencent.tap": ["tap"], "image/vnd.valve.source.texture": ["vtf"], "image/vnd.wap.wbmp": ["wbmp"], "image/vnd.xiff": ["xif"], "image/vnd.zbrush.pcx": ["pcx"], "image/x-3ds": ["3ds"], "image/x-cmu-raster": ["ras"], "image/x-cmx": ["cmx"], "image/x-freehand": ["fh", "fhc", "fh4", "fh5", "fh7"], "image/x-icon": ["*ico"], "image/x-jng": ["jng"], "image/x-mrsid-image": ["sid"], "image/x-ms-bmp": ["*bmp"], "image/x-pcx": ["*pcx"], "image/x-pict": ["pic", "pct"], "image/x-portable-anymap": ["pnm"], "image/x-portable-bitmap": ["pbm"], "image/x-portable-graymap": ["pgm"], "image/x-portable-pixmap": ["ppm"], "image/x-rgb": ["rgb"], "image/x-tga": ["tga"], "image/x-xbitmap": ["xbm"], "image/x-xpixmap": ["xpm"], "image/x-xwindowdump": ["xwd"], "message/vnd.wfa.wsc": ["wsc"], "model/vnd.collada+xml": ["dae"], "model/vnd.dwf": ["dwf"], "model/vnd.gdl": ["gdl"], "model/vnd.gtw": ["gtw"], "model/vnd.mts": ["mts"], "model/vnd.opengex": ["ogex"], "model/vnd.parasolid.transmit.binary": ["x_b"], "model/vnd.parasolid.transmit.text": ["x_t"], "model/vnd.sap.vds": ["vds"], "model/vnd.usdz+zip": ["usdz"], "model/vnd.valve.source.compiled-map": ["bsp"], "model/vnd.vtu": ["vtu"], "text/prs.lines.tag": ["dsc"], "text/vnd.curl": ["curl"], "text/vnd.curl.dcurl": ["dcurl"], "text/vnd.curl.mcurl": ["mcurl"], "text/vnd.curl.scurl": ["scurl"], "text/vnd.dvb.subtitle": ["sub"], "text/vnd.fly": ["fly"], "text/vnd.fmi.flexstor": ["flx"], "text/vnd.graphviz": ["gv"], "text/vnd.in3d.3dml": ["3dml"], "text/vnd.in3d.spot": ["spot"], "text/vnd.sun.j2me.app-descriptor": ["jad"], "text/vnd.wap.wml": ["wml"], "text/vnd.wap.wmlscript": ["wmls"], "text/x-asm": ["s", "asm"], "text/x-c": ["c", "cc", "cxx", "cpp", "h", "hh", "dic"], "text/x-component": ["htc"], "text/x-fortran": ["f", "for", "f77", "f90"], "text/x-handlebars-template": ["hbs"], "text/x-java-source": ["java"], "text/x-lua": ["lua"], "text/x-markdown": ["mkd"], "text/x-nfo": ["nfo"], "text/x-opml": ["opml"], "text/x-org": ["*org"], "text/x-pascal": ["p", "pas"], "text/x-processing": ["pde"], "text/x-sass": ["sass"], "text/x-scss": ["scss"], "text/x-setext": ["etx"], "text/x-sfv": ["sfv"], "text/x-suse-ymp": ["ymp"], "text/x-uuencode": ["uu"], "text/x-vcalendar": ["vcs"], "text/x-vcard": ["vcf"], "video/vnd.dece.hd": ["uvh", "uvvh"], "video/vnd.dece.mobile": ["uvm", "uvvm"], "video/vnd.dece.pd": ["uvp", "uvvp"], "video/vnd.dece.sd": ["uvs", "uvvs"], "video/vnd.dece.video": ["uvv", "uvvv"], "video/vnd.dvb.file": ["dvb"], "video/vnd.fvt": ["fvt"], "video/vnd.mpegurl": ["mxu", "m4u"], "video/vnd.ms-playready.media.pyv": ["pyv"], "video/vnd.uvvu.mp4": ["uvu", "uvvu"], "video/vnd.vivo": ["viv"], "video/x-f4v": ["f4v"], "video/x-fli": ["fli"], "video/x-flv": ["flv"], "video/x-m4v": ["m4v"], "video/x-matroska": ["mkv", "mk3d", "mks"], "video/x-mng": ["mng"], "video/x-ms-asf": ["asf", "asx"], "video/x-ms-vob": ["vob"], "video/x-ms-wm": ["wm"], "video/x-ms-wmv": ["wmv"], "video/x-ms-wmx": ["wmx"], "video/x-ms-wvx": ["wvx"], "video/x-msvideo": ["avi"], "video/x-sgi-movie": ["movie"], "video/x-smv": ["smv"], "x-conference/x-cooltalk": ["ice"] };
  }
});

// ../../node_modules/mime/index.js
var require_mime = __commonJS({
  "../../node_modules/mime/index.js"(exports2, module2) {
    "use strict";
    var Mime = require_Mime();
    module2.exports = new Mime(require_standard(), require_other());
  }
});

// ../@aws-cdk/cdk-assets-lib/lib/private/fs-extra.ts
async function pathExists(pathName) {
  try {
    await pfs.stat(pathName);
    return true;
  } catch (e32) {
    if (e32.code !== "ENOENT") {
      throw e32;
    }
    return false;
  }
}
var fs8, pfs;
var init_fs_extra = __esm({
  "../@aws-cdk/cdk-assets-lib/lib/private/fs-extra.ts"() {
    "use strict";
    fs8 = __toESM(require("fs"));
    pfs = fs8.promises;
    __name(pathExists, "pathExists");
  }
});

// ../../node_modules/fast-glob/out/utils/array.js
var require_array = __commonJS({
  "../../node_modules/fast-glob/out/utils/array.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.splitWhen = exports2.flatten = void 0;
    function flatten3(items) {
      return items.reduce((collection, item) => [].concat(collection, item), []);
    }
    __name(flatten3, "flatten");
    exports2.flatten = flatten3;
    function splitWhen(items, predicate) {
      const result2 = [[]];
      let groupIndex = 0;
      for (const item of items) {
        if (predicate(item)) {
          groupIndex++;
          result2[groupIndex] = [];
        } else {
          result2[groupIndex].push(item);
        }
      }
      return result2;
    }
    __name(splitWhen, "splitWhen");
    exports2.splitWhen = splitWhen;
  }
});

// ../../node_modules/fast-glob/out/utils/errno.js
var require_errno = __commonJS({
  "../../node_modules/fast-glob/out/utils/errno.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isEnoentCodeError = void 0;
    function isEnoentCodeError(error4) {
      return error4.code === "ENOENT";
    }
    __name(isEnoentCodeError, "isEnoentCodeError");
    exports2.isEnoentCodeError = isEnoentCodeError;
  }
});

// ../../node_modules/fast-glob/out/utils/fs.js
var require_fs2 = __commonJS({
  "../../node_modules/fast-glob/out/utils/fs.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createDirentFromStats = void 0;
    var DirentFromStats = class {
      static {
        __name(this, "DirentFromStats");
      }
      constructor(name, stats) {
        this.name = name;
        this.isBlockDevice = stats.isBlockDevice.bind(stats);
        this.isCharacterDevice = stats.isCharacterDevice.bind(stats);
        this.isDirectory = stats.isDirectory.bind(stats);
        this.isFIFO = stats.isFIFO.bind(stats);
        this.isFile = stats.isFile.bind(stats);
        this.isSocket = stats.isSocket.bind(stats);
        this.isSymbolicLink = stats.isSymbolicLink.bind(stats);
      }
    };
    function createDirentFromStats(name, stats) {
      return new DirentFromStats(name, stats);
    }
    __name(createDirentFromStats, "createDirentFromStats");
    exports2.createDirentFromStats = createDirentFromStats;
  }
});

// ../../node_modules/fast-glob/out/utils/path.js
var require_path = __commonJS({
  "../../node_modules/fast-glob/out/utils/path.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.convertPosixPathToPattern = exports2.convertWindowsPathToPattern = exports2.convertPathToPattern = exports2.escapePosixPath = exports2.escapeWindowsPath = exports2.escape = exports2.removeLeadingDotSegment = exports2.makeAbsolute = exports2.unixify = void 0;
    var os14 = require("os");
    var path47 = require("path");
    var IS_WINDOWS_PLATFORM = os14.platform() === "win32";
    var LEADING_DOT_SEGMENT_CHARACTERS_COUNT = 2;
    var POSIX_UNESCAPED_GLOB_SYMBOLS_RE = /(\\?)([()*?[\]{|}]|^!|[!+@](?=\()|\\(?![!()*+?@[\]{|}]))/g;
    var WINDOWS_UNESCAPED_GLOB_SYMBOLS_RE = /(\\?)([()[\]{}]|^!|[!+@](?=\())/g;
    var DOS_DEVICE_PATH_RE = /^\\\\([.?])/;
    var WINDOWS_BACKSLASHES_RE = /\\(?![!()+@[\]{}])/g;
    function unixify(filepath) {
      return filepath.replace(/\\/g, "/");
    }
    __name(unixify, "unixify");
    exports2.unixify = unixify;
    function makeAbsolute(cwd, filepath) {
      return path47.resolve(cwd, filepath);
    }
    __name(makeAbsolute, "makeAbsolute");
    exports2.makeAbsolute = makeAbsolute;
    function removeLeadingDotSegment(entry) {
      if (entry.charAt(0) === ".") {
        const secondCharactery = entry.charAt(1);
        if (secondCharactery === "/" || secondCharactery === "\\") {
          return entry.slice(LEADING_DOT_SEGMENT_CHARACTERS_COUNT);
        }
      }
      return entry;
    }
    __name(removeLeadingDotSegment, "removeLeadingDotSegment");
    exports2.removeLeadingDotSegment = removeLeadingDotSegment;
    exports2.escape = IS_WINDOWS_PLATFORM ? escapeWindowsPath : escapePosixPath;
    function escapeWindowsPath(pattern) {
      return pattern.replace(WINDOWS_UNESCAPED_GLOB_SYMBOLS_RE, "\\$2");
    }
    __name(escapeWindowsPath, "escapeWindowsPath");
    exports2.escapeWindowsPath = escapeWindowsPath;
    function escapePosixPath(pattern) {
      return pattern.replace(POSIX_UNESCAPED_GLOB_SYMBOLS_RE, "\\$2");
    }
    __name(escapePosixPath, "escapePosixPath");
    exports2.escapePosixPath = escapePosixPath;
    exports2.convertPathToPattern = IS_WINDOWS_PLATFORM ? convertWindowsPathToPattern : convertPosixPathToPattern;
    function convertWindowsPathToPattern(filepath) {
      return escapeWindowsPath(filepath).replace(DOS_DEVICE_PATH_RE, "//$1").replace(WINDOWS_BACKSLASHES_RE, "/");
    }
    __name(convertWindowsPathToPattern, "convertWindowsPathToPattern");
    exports2.convertWindowsPathToPattern = convertWindowsPathToPattern;
    function convertPosixPathToPattern(filepath) {
      return escapePosixPath(filepath);
    }
    __name(convertPosixPathToPattern, "convertPosixPathToPattern");
    exports2.convertPosixPathToPattern = convertPosixPathToPattern;
  }
});

// ../../node_modules/is-extglob/index.js
var require_is_extglob = __commonJS({
  "../../node_modules/is-extglob/index.js"(exports2, module2) {
    module2.exports = /* @__PURE__ */ __name(function isExtglob(str) {
      if (typeof str !== "string" || str === "") {
        return false;
      }
      var match;
      while (match = /(\\).|([@?!+*]\(.*\))/g.exec(str)) {
        if (match[2]) return true;
        str = str.slice(match.index + match[0].length);
      }
      return false;
    }, "isExtglob");
  }
});

// ../../node_modules/is-glob/index.js
var require_is_glob = __commonJS({
  "../../node_modules/is-glob/index.js"(exports2, module2) {
    var isExtglob = require_is_extglob();
    var chars6 = { "{": "}", "(": ")", "[": "]" };
    var strictCheck = /* @__PURE__ */ __name(function(str) {
      if (str[0] === "!") {
        return true;
      }
      var index = 0;
      var pipeIndex = -2;
      var closeSquareIndex = -2;
      var closeCurlyIndex = -2;
      var closeParenIndex = -2;
      var backSlashIndex = -2;
      while (index < str.length) {
        if (str[index] === "*") {
          return true;
        }
        if (str[index + 1] === "?" && /[\].+)]/.test(str[index])) {
          return true;
        }
        if (closeSquareIndex !== -1 && str[index] === "[" && str[index + 1] !== "]") {
          if (closeSquareIndex < index) {
            closeSquareIndex = str.indexOf("]", index);
          }
          if (closeSquareIndex > index) {
            if (backSlashIndex === -1 || backSlashIndex > closeSquareIndex) {
              return true;
            }
            backSlashIndex = str.indexOf("\\", index);
            if (backSlashIndex === -1 || backSlashIndex > closeSquareIndex) {
              return true;
            }
          }
        }
        if (closeCurlyIndex !== -1 && str[index] === "{" && str[index + 1] !== "}") {
          closeCurlyIndex = str.indexOf("}", index);
          if (closeCurlyIndex > index) {
            backSlashIndex = str.indexOf("\\", index);
            if (backSlashIndex === -1 || backSlashIndex > closeCurlyIndex) {
              return true;
            }
          }
        }
        if (closeParenIndex !== -1 && str[index] === "(" && str[index + 1] === "?" && /[:!=]/.test(str[index + 2]) && str[index + 3] !== ")") {
          closeParenIndex = str.indexOf(")", index);
          if (closeParenIndex > index) {
            backSlashIndex = str.indexOf("\\", index);
            if (backSlashIndex === -1 || backSlashIndex > closeParenIndex) {
              return true;
            }
          }
        }
        if (pipeIndex !== -1 && str[index] === "(" && str[index + 1] !== "|") {
          if (pipeIndex < index) {
            pipeIndex = str.indexOf("|", index);
          }
          if (pipeIndex !== -1 && str[pipeIndex + 1] !== ")") {
            closeParenIndex = str.indexOf(")", pipeIndex);
            if (closeParenIndex > pipeIndex) {
              backSlashIndex = str.indexOf("\\", pipeIndex);
              if (backSlashIndex === -1 || backSlashIndex > closeParenIndex) {
                return true;
              }
            }
          }
        }
        if (str[index] === "\\") {
          var open2 = str[index + 1];
          index += 2;
          var close = chars6[open2];
          if (close) {
            var n10 = str.indexOf(close, index);
            if (n10 !== -1) {
              index = n10 + 1;
            }
          }
          if (str[index] === "!") {
            return true;
          }
        } else {
          index++;
        }
      }
      return false;
    }, "strictCheck");
    var relaxedCheck = /* @__PURE__ */ __name(function(str) {
      if (str[0] === "!") {
        return true;
      }
      var index = 0;
      while (index < str.length) {
        if (/[*?{}()[\]]/.test(str[index])) {
          return true;
        }
        if (str[index] === "\\") {
          var open2 = str[index + 1];
          index += 2;
          var close = chars6[open2];
          if (close) {
            var n10 = str.indexOf(close, index);
            if (n10 !== -1) {
              index = n10 + 1;
            }
          }
          if (str[index] === "!") {
            return true;
          }
        } else {
          index++;
        }
      }
      return false;
    }, "relaxedCheck");
    module2.exports = /* @__PURE__ */ __name(function isGlob(str, options) {
      if (typeof str !== "string" || str === "") {
        return false;
      }
      if (isExtglob(str)) {
        return true;
      }
      var check = strictCheck;
      if (options && options.strict === false) {
        check = relaxedCheck;
      }
      return check(str);
    }, "isGlob");
  }
});

// ../../node_modules/fast-glob/node_modules/glob-parent/index.js
var require_glob_parent = __commonJS({
  "../../node_modules/fast-glob/node_modules/glob-parent/index.js"(exports2, module2) {
    "use strict";
    var isGlob = require_is_glob();
    var pathPosixDirname = require("path").posix.dirname;
    var isWin32 = require("os").platform() === "win32";
    var slash = "/";
    var backslash = /\\/g;
    var enclosure = /[\{\[].*[\}\]]$/;
    var globby = /(^|[^\\])([\{\[]|\([^\)]+$)/;
    var escaped = /\\([\!\*\?\|\[\]\(\)\{\}])/g;
    module2.exports = /* @__PURE__ */ __name(function globParent(str, opts) {
      var options = Object.assign({ flipBackslashes: true }, opts);
      if (options.flipBackslashes && isWin32 && str.indexOf(slash) < 0) {
        str = str.replace(backslash, slash);
      }
      if (enclosure.test(str)) {
        str += slash;
      }
      str += "a";
      do {
        str = pathPosixDirname(str);
      } while (isGlob(str) || globby.test(str));
      return str.replace(escaped, "$1");
    }, "globParent");
  }
});

// ../../node_modules/braces/lib/utils.js
var require_utils3 = __commonJS({
  "../../node_modules/braces/lib/utils.js"(exports2) {
    "use strict";
    exports2.isInteger = (num) => {
      if (typeof num === "number") {
        return Number.isInteger(num);
      }
      if (typeof num === "string" && num.trim() !== "") {
        return Number.isInteger(Number(num));
      }
      return false;
    };
    exports2.find = (node, type) => node.nodes.find((node2) => node2.type === type);
    exports2.exceedsLimit = (min, max, step = 1, limit) => {
      if (limit === false) return false;
      if (!exports2.isInteger(min) || !exports2.isInteger(max)) return false;
      return (Number(max) - Number(min)) / Number(step) >= limit;
    };
    exports2.escapeNode = (block, n10 = 0, type) => {
      const node = block.nodes[n10];
      if (!node) return;
      if (type && node.type === type || node.type === "open" || node.type === "close") {
        if (node.escaped !== true) {
          node.value = "\\" + node.value;
          node.escaped = true;
        }
      }
    };
    exports2.encloseBrace = (node) => {
      if (node.type !== "brace") return false;
      if (node.commas >> 0 + node.ranges >> 0 === 0) {
        node.invalid = true;
        return true;
      }
      return false;
    };
    exports2.isInvalidBrace = (block) => {
      if (block.type !== "brace") return false;
      if (block.invalid === true || block.dollar) return true;
      if (block.commas >> 0 + block.ranges >> 0 === 0) {
        block.invalid = true;
        return true;
      }
      if (block.open !== true || block.close !== true) {
        block.invalid = true;
        return true;
      }
      return false;
    };
    exports2.isOpenOrClose = (node) => {
      if (node.type === "open" || node.type === "close") {
        return true;
      }
      return node.open === true || node.close === true;
    };
    exports2.reduce = (nodes32) => nodes32.reduce((acc, node) => {
      if (node.type === "text") acc.push(node.value);
      if (node.type === "range") node.type = "text";
      return acc;
    }, []);
    exports2.flatten = (...args) => {
      const result2 = [];
      const flat = /* @__PURE__ */ __name((arr) => {
        for (let i32 = 0; i32 < arr.length; i32++) {
          const ele = arr[i32];
          if (Array.isArray(ele)) {
            flat(ele);
            continue;
          }
          if (ele !== void 0) {
            result2.push(ele);
          }
        }
        return result2;
      }, "flat");
      flat(args);
      return result2;
    };
  }
});

// ../../node_modules/braces/lib/stringify.js
var require_stringify = __commonJS({
  "../../node_modules/braces/lib/stringify.js"(exports2, module2) {
    "use strict";
    var utils = require_utils3();
    module2.exports = (ast, options = {}) => {
      const stringify2 = /* @__PURE__ */ __name((node, parent = {}) => {
        const invalidBlock = options.escapeInvalid && utils.isInvalidBrace(parent);
        const invalidNode = node.invalid === true && options.escapeInvalid === true;
        let output = "";
        if (node.value) {
          if ((invalidBlock || invalidNode) && utils.isOpenOrClose(node)) {
            return "\\" + node.value;
          }
          return node.value;
        }
        if (node.value) {
          return node.value;
        }
        if (node.nodes) {
          for (const child of node.nodes) {
            output += stringify2(child);
          }
        }
        return output;
      }, "stringify");
      return stringify2(ast);
    };
  }
});

// ../../node_modules/is-number/index.js
var require_is_number = __commonJS({
  "../../node_modules/is-number/index.js"(exports2, module2) {
    "use strict";
    module2.exports = function(num) {
      if (typeof num === "number") {
        return num - num === 0;
      }
      if (typeof num === "string" && num.trim() !== "") {
        return Number.isFinite ? Number.isFinite(+num) : isFinite(+num);
      }
      return false;
    };
  }
});

// ../../node_modules/to-regex-range/index.js
var require_to_regex_range = __commonJS({
  "../../node_modules/to-regex-range/index.js"(exports2, module2) {
    "use strict";
    var isNumber = require_is_number();
    var toRegexRange = /* @__PURE__ */ __name((min, max, options) => {
      if (isNumber(min) === false) {
        throw new TypeError("toRegexRange: expected the first argument to be a number");
      }
      if (max === void 0 || min === max) {
        return String(min);
      }
      if (isNumber(max) === false) {
        throw new TypeError("toRegexRange: expected the second argument to be a number.");
      }
      let opts = { relaxZeros: true, ...options };
      if (typeof opts.strictZeros === "boolean") {
        opts.relaxZeros = opts.strictZeros === false;
      }
      let relax = String(opts.relaxZeros);
      let shorthand = String(opts.shorthand);
      let capture = String(opts.capture);
      let wrap = String(opts.wrap);
      let cacheKey = min + ":" + max + "=" + relax + shorthand + capture + wrap;
      if (toRegexRange.cache.hasOwnProperty(cacheKey)) {
        return toRegexRange.cache[cacheKey].result;
      }
      let a32 = Math.min(min, max);
      let b32 = Math.max(min, max);
      if (Math.abs(a32 - b32) === 1) {
        let result2 = min + "|" + max;
        if (opts.capture) {
          return `(${result2})`;
        }
        if (opts.wrap === false) {
          return result2;
        }
        return `(?:${result2})`;
      }
      let isPadded = hasPadding(min) || hasPadding(max);
      let state13 = { min, max, a: a32, b: b32 };
      let positives = [];
      let negatives = [];
      if (isPadded) {
        state13.isPadded = isPadded;
        state13.maxLen = String(state13.max).length;
      }
      if (a32 < 0) {
        let newMin = b32 < 0 ? Math.abs(b32) : 1;
        negatives = splitToPatterns(newMin, Math.abs(a32), state13, opts);
        a32 = state13.a = 0;
      }
      if (b32 >= 0) {
        positives = splitToPatterns(a32, b32, state13, opts);
      }
      state13.negatives = negatives;
      state13.positives = positives;
      state13.result = collatePatterns(negatives, positives, opts);
      if (opts.capture === true) {
        state13.result = `(${state13.result})`;
      } else if (opts.wrap !== false && positives.length + negatives.length > 1) {
        state13.result = `(?:${state13.result})`;
      }
      toRegexRange.cache[cacheKey] = state13;
      return state13.result;
    }, "toRegexRange");
    function collatePatterns(neg, pos, options) {
      let onlyNegative = filterPatterns(neg, pos, "-", false, options) || [];
      let onlyPositive = filterPatterns(pos, neg, "", false, options) || [];
      let intersected = filterPatterns(neg, pos, "-?", true, options) || [];
      let subpatterns = onlyNegative.concat(intersected).concat(onlyPositive);
      return subpatterns.join("|");
    }
    __name(collatePatterns, "collatePatterns");
    function splitToRanges(min, max) {
      let nines = 1;
      let zeros = 1;
      let stop = countNines(min, nines);
      let stops = /* @__PURE__ */ new Set([max]);
      while (min <= stop && stop <= max) {
        stops.add(stop);
        nines += 1;
        stop = countNines(min, nines);
      }
      stop = countZeros(max + 1, zeros) - 1;
      while (min < stop && stop <= max) {
        stops.add(stop);
        zeros += 1;
        stop = countZeros(max + 1, zeros) - 1;
      }
      stops = [...stops];
      stops.sort(compare2);
      return stops;
    }
    __name(splitToRanges, "splitToRanges");
    function rangeToPattern(start, stop, options) {
      if (start === stop) {
        return { pattern: start, count: [], digits: 0 };
      }
      let zipped = zip2(start, stop);
      let digits = zipped.length;
      let pattern = "";
      let count = 0;
      for (let i32 = 0; i32 < digits; i32++) {
        let [startDigit, stopDigit] = zipped[i32];
        if (startDigit === stopDigit) {
          pattern += startDigit;
        } else if (startDigit !== "0" || stopDigit !== "9") {
          pattern += toCharacterClass(startDigit, stopDigit, options);
        } else {
          count++;
        }
      }
      if (count) {
        pattern += options.shorthand === true ? "\\d" : "[0-9]";
      }
      return { pattern, count: [count], digits };
    }
    __name(rangeToPattern, "rangeToPattern");
    function splitToPatterns(min, max, tok, options) {
      let ranges = splitToRanges(min, max);
      let tokens = [];
      let start = min;
      let prev;
      for (let i32 = 0; i32 < ranges.length; i32++) {
        let max2 = ranges[i32];
        let obj = rangeToPattern(String(start), String(max2), options);
        let zeros = "";
        if (!tok.isPadded && prev && prev.pattern === obj.pattern) {
          if (prev.count.length > 1) {
            prev.count.pop();
          }
          prev.count.push(obj.count[0]);
          prev.string = prev.pattern + toQuantifier(prev.count);
          start = max2 + 1;
          continue;
        }
        if (tok.isPadded) {
          zeros = padZeros(max2, tok, options);
        }
        obj.string = zeros + obj.pattern + toQuantifier(obj.count);
        tokens.push(obj);
        start = max2 + 1;
        prev = obj;
      }
      return tokens;
    }
    __name(splitToPatterns, "splitToPatterns");
    function filterPatterns(arr, comparison, prefix, intersection2, options) {
      let result2 = [];
      for (let ele of arr) {
        let { string } = ele;
        if (!intersection2 && !contains2(comparison, "string", string)) {
          result2.push(prefix + string);
        }
        if (intersection2 && contains2(comparison, "string", string)) {
          result2.push(prefix + string);
        }
      }
      return result2;
    }
    __name(filterPatterns, "filterPatterns");
    function zip2(a32, b32) {
      let arr = [];
      for (let i32 = 0; i32 < a32.length; i32++) arr.push([a32[i32], b32[i32]]);
      return arr;
    }
    __name(zip2, "zip");
    function compare2(a32, b32) {
      return a32 > b32 ? 1 : b32 > a32 ? -1 : 0;
    }
    __name(compare2, "compare");
    function contains2(arr, key, val) {
      return arr.some((ele) => ele[key] === val);
    }
    __name(contains2, "contains");
    function countNines(min, len) {
      return Number(String(min).slice(0, -len) + "9".repeat(len));
    }
    __name(countNines, "countNines");
    function countZeros(integer, zeros) {
      return integer - integer % Math.pow(10, zeros);
    }
    __name(countZeros, "countZeros");
    function toQuantifier(digits) {
      let [start = 0, stop = ""] = digits;
      if (stop || start > 1) {
        return `{${start + (stop ? "," + stop : "")}}`;
      }
      return "";
    }
    __name(toQuantifier, "toQuantifier");
    function toCharacterClass(a32, b32, options) {
      return `[${a32}${b32 - a32 === 1 ? "" : "-"}${b32}]`;
    }
    __name(toCharacterClass, "toCharacterClass");
    function hasPadding(str) {
      return /^-?(0+)\d/.test(str);
    }
    __name(hasPadding, "hasPadding");
    function padZeros(value, tok, options) {
      if (!tok.isPadded) {
        return value;
      }
      let diff = Math.abs(tok.maxLen - String(value).length);
      let relax = options.relaxZeros !== false;
      switch (diff) {
        case 0:
          return "";
        case 1:
          return relax ? "0?" : "0";
        case 2:
          return relax ? "0{0,2}" : "00";
        default: {
          return relax ? `0{0,${diff}}` : `0{${diff}}`;
        }
      }
    }
    __name(padZeros, "padZeros");
    toRegexRange.cache = {};
    toRegexRange.clearCache = () => toRegexRange.cache = {};
    module2.exports = toRegexRange;
  }
});

// ../../node_modules/fill-range/index.js
var require_fill_range = __commonJS({
  "../../node_modules/fill-range/index.js"(exports2, module2) {
    "use strict";
    var util11 = require("util");
    var toRegexRange = require_to_regex_range();
    var isObject3 = /* @__PURE__ */ __name((val) => val !== null && typeof val === "object" && !Array.isArray(val), "isObject");
    var transform = /* @__PURE__ */ __name((toNumber) => {
      return (value) => toNumber === true ? Number(value) : String(value);
    }, "transform");
    var isValidValue = /* @__PURE__ */ __name((value) => {
      return typeof value === "number" || typeof value === "string" && value !== "";
    }, "isValidValue");
    var isNumber = /* @__PURE__ */ __name((num) => Number.isInteger(+num), "isNumber");
    var zeros = /* @__PURE__ */ __name((input) => {
      let value = `${input}`;
      let index = -1;
      if (value[0] === "-") value = value.slice(1);
      if (value === "0") return false;
      while (value[++index] === "0") ;
      return index > 0;
    }, "zeros");
    var stringify2 = /* @__PURE__ */ __name((start, end, options) => {
      if (typeof start === "string" || typeof end === "string") {
        return true;
      }
      return options.stringify === true;
    }, "stringify");
    var pad = /* @__PURE__ */ __name((input, maxLength, toNumber) => {
      if (maxLength > 0) {
        let dash = input[0] === "-" ? "-" : "";
        if (dash) input = input.slice(1);
        input = dash + input.padStart(dash ? maxLength - 1 : maxLength, "0");
      }
      if (toNumber === false) {
        return String(input);
      }
      return input;
    }, "pad");
    var toMaxLen = /* @__PURE__ */ __name((input, maxLength) => {
      let negative = input[0] === "-" ? "-" : "";
      if (negative) {
        input = input.slice(1);
        maxLength--;
      }
      while (input.length < maxLength) input = "0" + input;
      return negative ? "-" + input : input;
    }, "toMaxLen");
    var toSequence = /* @__PURE__ */ __name((parts, options, maxLen) => {
      parts.negatives.sort((a32, b32) => a32 < b32 ? -1 : a32 > b32 ? 1 : 0);
      parts.positives.sort((a32, b32) => a32 < b32 ? -1 : a32 > b32 ? 1 : 0);
      let prefix = options.capture ? "" : "?:";
      let positives = "";
      let negatives = "";
      let result2;
      if (parts.positives.length) {
        positives = parts.positives.map((v) => toMaxLen(String(v), maxLen)).join("|");
      }
      if (parts.negatives.length) {
        negatives = `-(${prefix}${parts.negatives.map((v) => toMaxLen(String(v), maxLen)).join("|")})`;
      }
      if (positives && negatives) {
        result2 = `${positives}|${negatives}`;
      } else {
        result2 = positives || negatives;
      }
      if (options.wrap) {
        return `(${prefix}${result2})`;
      }
      return result2;
    }, "toSequence");
    var toRange = /* @__PURE__ */ __name((a32, b32, isNumbers, options) => {
      if (isNumbers) {
        return toRegexRange(a32, b32, { wrap: false, ...options });
      }
      let start = String.fromCharCode(a32);
      if (a32 === b32) return start;
      let stop = String.fromCharCode(b32);
      return `[${start}-${stop}]`;
    }, "toRange");
    var toRegex = /* @__PURE__ */ __name((start, end, options) => {
      if (Array.isArray(start)) {
        let wrap = options.wrap === true;
        let prefix = options.capture ? "" : "?:";
        return wrap ? `(${prefix}${start.join("|")})` : start.join("|");
      }
      return toRegexRange(start, end, options);
    }, "toRegex");
    var rangeError = /* @__PURE__ */ __name((...args) => {
      return new RangeError("Invalid range arguments: " + util11.inspect(...args));
    }, "rangeError");
    var invalidRange = /* @__PURE__ */ __name((start, end, options) => {
      if (options.strictRanges === true) throw rangeError([start, end]);
      return [];
    }, "invalidRange");
    var invalidStep = /* @__PURE__ */ __name((step, options) => {
      if (options.strictRanges === true) {
        throw new TypeError(`Expected step "${step}" to be a number`);
      }
      return [];
    }, "invalidStep");
    var fillNumbers = /* @__PURE__ */ __name((start, end, step = 1, options = {}) => {
      let a32 = Number(start);
      let b32 = Number(end);
      if (!Number.isInteger(a32) || !Number.isInteger(b32)) {
        if (options.strictRanges === true) throw rangeError([start, end]);
        return [];
      }
      if (a32 === 0) a32 = 0;
      if (b32 === 0) b32 = 0;
      let descending2 = a32 > b32;
      let startString = String(start);
      let endString = String(end);
      let stepString = String(step);
      step = Math.max(Math.abs(step), 1);
      let padded = zeros(startString) || zeros(endString) || zeros(stepString);
      let maxLen = padded ? Math.max(startString.length, endString.length, stepString.length) : 0;
      let toNumber = padded === false && stringify2(start, end, options) === false;
      let format32 = options.transform || transform(toNumber);
      if (options.toRegex && step === 1) {
        return toRange(toMaxLen(start, maxLen), toMaxLen(end, maxLen), true, options);
      }
      let parts = { negatives: [], positives: [] };
      let push = /* @__PURE__ */ __name((num) => parts[num < 0 ? "negatives" : "positives"].push(Math.abs(num)), "push");
      let range7 = [];
      let index = 0;
      while (descending2 ? a32 >= b32 : a32 <= b32) {
        if (options.toRegex === true && step > 1) {
          push(a32);
        } else {
          range7.push(pad(format32(a32, index), maxLen, toNumber));
        }
        a32 = descending2 ? a32 - step : a32 + step;
        index++;
      }
      if (options.toRegex === true) {
        return step > 1 ? toSequence(parts, options, maxLen) : toRegex(range7, null, { wrap: false, ...options });
      }
      return range7;
    }, "fillNumbers");
    var fillLetters = /* @__PURE__ */ __name((start, end, step = 1, options = {}) => {
      if (!isNumber(start) && start.length > 1 || !isNumber(end) && end.length > 1) {
        return invalidRange(start, end, options);
      }
      let format32 = options.transform || ((val) => String.fromCharCode(val));
      let a32 = `${start}`.charCodeAt(0);
      let b32 = `${end}`.charCodeAt(0);
      let descending2 = a32 > b32;
      let min = Math.min(a32, b32);
      let max = Math.max(a32, b32);
      if (options.toRegex && step === 1) {
        return toRange(min, max, false, options);
      }
      let range7 = [];
      let index = 0;
      while (descending2 ? a32 >= b32 : a32 <= b32) {
        range7.push(format32(a32, index));
        a32 = descending2 ? a32 - step : a32 + step;
        index++;
      }
      if (options.toRegex === true) {
        return toRegex(range7, null, { wrap: false, options });
      }
      return range7;
    }, "fillLetters");
    var fill = /* @__PURE__ */ __name((start, end, step, options = {}) => {
      if (end == null && isValidValue(start)) {
        return [start];
      }
      if (!isValidValue(start) || !isValidValue(end)) {
        return invalidRange(start, end, options);
      }
      if (typeof step === "function") {
        return fill(start, end, 1, { transform: step });
      }
      if (isObject3(step)) {
        return fill(start, end, 0, step);
      }
      let opts = { ...options };
      if (opts.capture === true) opts.wrap = true;
      step = step || opts.step || 1;
      if (!isNumber(step)) {
        if (step != null && !isObject3(step)) return invalidStep(step, opts);
        return fill(start, end, 1, step);
      }
      if (isNumber(start) && isNumber(end)) {
        return fillNumbers(start, end, step, opts);
      }
      return fillLetters(start, end, Math.max(Math.abs(step), 1), opts);
    }, "fill");
    module2.exports = fill;
  }
});

// ../../node_modules/braces/lib/compile.js
var require_compile = __commonJS({
  "../../node_modules/braces/lib/compile.js"(exports2, module2) {
    "use strict";
    var fill = require_fill_range();
    var utils = require_utils3();
    var compile = /* @__PURE__ */ __name((ast, options = {}) => {
      const walk = /* @__PURE__ */ __name((node, parent = {}) => {
        const invalidBlock = utils.isInvalidBrace(parent);
        const invalidNode = node.invalid === true && options.escapeInvalid === true;
        const invalid = invalidBlock === true || invalidNode === true;
        const prefix = options.escapeInvalid === true ? "\\" : "";
        let output = "";
        if (node.isOpen === true) {
          return prefix + node.value;
        }
        if (node.isClose === true) {
          console.log("node.isClose", prefix, node.value);
          return prefix + node.value;
        }
        if (node.type === "open") {
          return invalid ? prefix + node.value : "(";
        }
        if (node.type === "close") {
          return invalid ? prefix + node.value : ")";
        }
        if (node.type === "comma") {
          return node.prev.type === "comma" ? "" : invalid ? node.value : "|";
        }
        if (node.value) {
          return node.value;
        }
        if (node.nodes && node.ranges > 0) {
          const args = utils.reduce(node.nodes);
          const range7 = fill(...args, { ...options, wrap: false, toRegex: true, strictZeros: true });
          if (range7.length !== 0) {
            return args.length > 1 && range7.length > 1 ? `(${range7})` : range7;
          }
        }
        if (node.nodes) {
          for (const child of node.nodes) {
            output += walk(child, node);
          }
        }
        return output;
      }, "walk");
      return walk(ast);
    }, "compile");
    module2.exports = compile;
  }
});

// ../../node_modules/braces/lib/expand.js
var require_expand = __commonJS({
  "../../node_modules/braces/lib/expand.js"(exports2, module2) {
    "use strict";
    var fill = require_fill_range();
    var stringify2 = require_stringify();
    var utils = require_utils3();
    var append = /* @__PURE__ */ __name((queue = "", stash = "", enclose = false) => {
      const result2 = [];
      queue = [].concat(queue);
      stash = [].concat(stash);
      if (!stash.length) return queue;
      if (!queue.length) {
        return enclose ? utils.flatten(stash).map((ele) => `{${ele}}`) : stash;
      }
      for (const item of queue) {
        if (Array.isArray(item)) {
          for (const value of item) {
            result2.push(append(value, stash, enclose));
          }
        } else {
          for (let ele of stash) {
            if (enclose === true && typeof ele === "string") ele = `{${ele}}`;
            result2.push(Array.isArray(ele) ? append(item, ele, enclose) : item + ele);
          }
        }
      }
      return utils.flatten(result2);
    }, "append");
    var expand = /* @__PURE__ */ __name((ast, options = {}) => {
      const rangeLimit = options.rangeLimit === void 0 ? 1e3 : options.rangeLimit;
      const walk = /* @__PURE__ */ __name((node, parent = {}) => {
        node.queue = [];
        let p10 = parent;
        let q10 = parent.queue;
        while (p10.type !== "brace" && p10.type !== "root" && p10.parent) {
          p10 = p10.parent;
          q10 = p10.queue;
        }
        if (node.invalid || node.dollar) {
          q10.push(append(q10.pop(), stringify2(node, options)));
          return;
        }
        if (node.type === "brace" && node.invalid !== true && node.nodes.length === 2) {
          q10.push(append(q10.pop(), ["{}"]));
          return;
        }
        if (node.nodes && node.ranges > 0) {
          const args = utils.reduce(node.nodes);
          if (utils.exceedsLimit(...args, options.step, rangeLimit)) {
            throw new RangeError("expanded array length exceeds range limit. Use options.rangeLimit to increase or disable the limit.");
          }
          let range7 = fill(...args, options);
          if (range7.length === 0) {
            range7 = stringify2(node, options);
          }
          q10.push(append(q10.pop(), range7));
          node.nodes = [];
          return;
        }
        const enclose = utils.encloseBrace(node);
        let queue = node.queue;
        let block = node;
        while (block.type !== "brace" && block.type !== "root" && block.parent) {
          block = block.parent;
          queue = block.queue;
        }
        for (let i32 = 0; i32 < node.nodes.length; i32++) {
          const child = node.nodes[i32];
          if (child.type === "comma" && node.type === "brace") {
            if (i32 === 1) queue.push("");
            queue.push("");
            continue;
          }
          if (child.type === "close") {
            q10.push(append(q10.pop(), queue, enclose));
            continue;
          }
          if (child.value && child.type !== "open") {
            queue.push(append(queue.pop(), child.value));
            continue;
          }
          if (child.nodes) {
            walk(child, node);
          }
        }
        return queue;
      }, "walk");
      return utils.flatten(walk(ast));
    }, "expand");
    module2.exports = expand;
  }
});

// ../../node_modules/braces/lib/constants.js
var require_constants2 = __commonJS({
  "../../node_modules/braces/lib/constants.js"(exports2, module2) {
    "use strict";
    module2.exports = {
      MAX_LENGTH: 1e4,
      // Digits
      CHAR_0: "0",
      /* 0 */
      CHAR_9: "9",
      /* 9 */
      // Alphabet chars.
      CHAR_UPPERCASE_A: "A",
      /* A */
      CHAR_LOWERCASE_A: "a",
      /* a */
      CHAR_UPPERCASE_Z: "Z",
      /* Z */
      CHAR_LOWERCASE_Z: "z",
      /* z */
      CHAR_LEFT_PARENTHESES: "(",
      /* ( */
      CHAR_RIGHT_PARENTHESES: ")",
      /* ) */
      CHAR_ASTERISK: "*",
      /* * */
      // Non-alphabetic chars.
      CHAR_AMPERSAND: "&",
      /* & */
      CHAR_AT: "@",
      /* @ */
      CHAR_BACKSLASH: "\\",
      /* \ */
      CHAR_BACKTICK: "`",
      /* ` */
      CHAR_CARRIAGE_RETURN: "\r",
      /* \r */
      CHAR_CIRCUMFLEX_ACCENT: "^",
      /* ^ */
      CHAR_COLON: ":",
      /* : */
      CHAR_COMMA: ",",
      /* , */
      CHAR_DOLLAR: "$",
      /* . */
      CHAR_DOT: ".",
      /* . */
      CHAR_DOUBLE_QUOTE: '"',
      /* " */
      CHAR_EQUAL: "=",
      /* = */
      CHAR_EXCLAMATION_MARK: "!",
      /* ! */
      CHAR_FORM_FEED: "\f",
      /* \f */
      CHAR_FORWARD_SLASH: "/",
      /* / */
      CHAR_HASH: "#",
      /* # */
      CHAR_HYPHEN_MINUS: "-",
      /* - */
      CHAR_LEFT_ANGLE_BRACKET: "<",
      /* < */
      CHAR_LEFT_CURLY_BRACE: "{",
      /* { */
      CHAR_LEFT_SQUARE_BRACKET: "[",
      /* [ */
      CHAR_LINE_FEED: "\n",
      /* \n */
      CHAR_NO_BREAK_SPACE: "\xA0",
      /* \u00A0 */
      CHAR_PERCENT: "%",
      /* % */
      CHAR_PLUS: "+",
      /* + */
      CHAR_QUESTION_MARK: "?",
      /* ? */
      CHAR_RIGHT_ANGLE_BRACKET: ">",
      /* > */
      CHAR_RIGHT_CURLY_BRACE: "}",
      /* } */
      CHAR_RIGHT_SQUARE_BRACKET: "]",
      /* ] */
      CHAR_SEMICOLON: ";",
      /* ; */
      CHAR_SINGLE_QUOTE: "'",
      /* ' */
      CHAR_SPACE: " ",
      /*   */
      CHAR_TAB: "	",
      /* \t */
      CHAR_UNDERSCORE: "_",
      /* _ */
      CHAR_VERTICAL_LINE: "|",
      /* | */
      CHAR_ZERO_WIDTH_NOBREAK_SPACE: "\uFEFF"
      /* \uFEFF */
    };
  }
});

// ../../node_modules/braces/lib/parse.js
var require_parse2 = __commonJS({
  "../../node_modules/braces/lib/parse.js"(exports2, module2) {
    "use strict";
    var stringify2 = require_stringify();
    var {
      MAX_LENGTH,
      CHAR_BACKSLASH,
      /* \ */
      CHAR_BACKTICK,
      /* ` */
      CHAR_COMMA,
      /* , */
      CHAR_DOT,
      /* . */
      CHAR_LEFT_PARENTHESES,
      /* ( */
      CHAR_RIGHT_PARENTHESES,
      /* ) */
      CHAR_LEFT_CURLY_BRACE,
      /* { */
      CHAR_RIGHT_CURLY_BRACE,
      /* } */
      CHAR_LEFT_SQUARE_BRACKET,
      /* [ */
      CHAR_RIGHT_SQUARE_BRACKET,
      /* ] */
      CHAR_DOUBLE_QUOTE,
      /* " */
      CHAR_SINGLE_QUOTE,
      /* ' */
      CHAR_NO_BREAK_SPACE,
      CHAR_ZERO_WIDTH_NOBREAK_SPACE
    } = require_constants2();
    var parse2 = /* @__PURE__ */ __name((input, options = {}) => {
      if (typeof input !== "string") {
        throw new TypeError("Expected a string");
      }
      const opts = options || {};
      const max = typeof opts.maxLength === "number" ? Math.min(MAX_LENGTH, opts.maxLength) : MAX_LENGTH;
      if (input.length > max) {
        throw new SyntaxError(`Input length (${input.length}), exceeds max characters (${max})`);
      }
      const ast = { type: "root", input, nodes: [] };
      const stack = [ast];
      let block = ast;
      let prev = ast;
      let brackets = 0;
      const length = input.length;
      let index = 0;
      let depth = 0;
      let value;
      const advance = /* @__PURE__ */ __name(() => input[index++], "advance");
      const push = /* @__PURE__ */ __name((node) => {
        if (node.type === "text" && prev.type === "dot") {
          prev.type = "text";
        }
        if (prev && prev.type === "text" && node.type === "text") {
          prev.value += node.value;
          return;
        }
        block.nodes.push(node);
        node.parent = block;
        node.prev = prev;
        prev = node;
        return node;
      }, "push");
      push({ type: "bos" });
      while (index < length) {
        block = stack[stack.length - 1];
        value = advance();
        if (value === CHAR_ZERO_WIDTH_NOBREAK_SPACE || value === CHAR_NO_BREAK_SPACE) {
          continue;
        }
        if (value === CHAR_BACKSLASH) {
          push({ type: "text", value: (options.keepEscaping ? value : "") + advance() });
          continue;
        }
        if (value === CHAR_RIGHT_SQUARE_BRACKET) {
          push({ type: "text", value: "\\" + value });
          continue;
        }
        if (value === CHAR_LEFT_SQUARE_BRACKET) {
          brackets++;
          let next;
          while (index < length && (next = advance())) {
            value += next;
            if (next === CHAR_LEFT_SQUARE_BRACKET) {
              brackets++;
              continue;
            }
            if (next === CHAR_BACKSLASH) {
              value += advance();
              continue;
            }
            if (next === CHAR_RIGHT_SQUARE_BRACKET) {
              brackets--;
              if (brackets === 0) {
                break;
              }
            }
          }
          push({ type: "text", value });
          continue;
        }
        if (value === CHAR_LEFT_PARENTHESES) {
          block = push({ type: "paren", nodes: [] });
          stack.push(block);
          push({ type: "text", value });
          continue;
        }
        if (value === CHAR_RIGHT_PARENTHESES) {
          if (block.type !== "paren") {
            push({ type: "text", value });
            continue;
          }
          block = stack.pop();
          push({ type: "text", value });
          block = stack[stack.length - 1];
          continue;
        }
        if (value === CHAR_DOUBLE_QUOTE || value === CHAR_SINGLE_QUOTE || value === CHAR_BACKTICK) {
          const open2 = value;
          let next;
          if (options.keepQuotes !== true) {
            value = "";
          }
          while (index < length && (next = advance())) {
            if (next === CHAR_BACKSLASH) {
              value += next + advance();
              continue;
            }
            if (next === open2) {
              if (options.keepQuotes === true) value += next;
              break;
            }
            value += next;
          }
          push({ type: "text", value });
          continue;
        }
        if (value === CHAR_LEFT_CURLY_BRACE) {
          depth++;
          const dollar = prev.value && prev.value.slice(-1) === "$" || block.dollar === true;
          const brace = {
            type: "brace",
            open: true,
            close: false,
            dollar,
            depth,
            commas: 0,
            ranges: 0,
            nodes: []
          };
          block = push(brace);
          stack.push(block);
          push({ type: "open", value });
          continue;
        }
        if (value === CHAR_RIGHT_CURLY_BRACE) {
          if (block.type !== "brace") {
            push({ type: "text", value });
            continue;
          }
          const type = "close";
          block = stack.pop();
          block.close = true;
          push({ type, value });
          depth--;
          block = stack[stack.length - 1];
          continue;
        }
        if (value === CHAR_COMMA && depth > 0) {
          if (block.ranges > 0) {
            block.ranges = 0;
            const open2 = block.nodes.shift();
            block.nodes = [open2, { type: "text", value: stringify2(block) }];
          }
          push({ type: "comma", value });
          block.commas++;
          continue;
        }
        if (value === CHAR_DOT && depth > 0 && block.commas === 0) {
          const siblings = block.nodes;
          if (depth === 0 || siblings.length === 0) {
            push({ type: "text", value });
            continue;
          }
          if (prev.type === "dot") {
            block.range = [];
            prev.value += value;
            prev.type = "range";
            if (block.nodes.length !== 3 && block.nodes.length !== 5) {
              block.invalid = true;
              block.ranges = 0;
              prev.type = "text";
              continue;
            }
            block.ranges++;
            block.args = [];
            continue;
          }
          if (prev.type === "range") {
            siblings.pop();
            const before = siblings[siblings.length - 1];
            before.value += prev.value + value;
            prev = before;
            block.ranges--;
            continue;
          }
          push({ type: "dot", value });
          continue;
        }
        push({ type: "text", value });
      }
      do {
        block = stack.pop();
        if (block.type !== "root") {
          block.nodes.forEach((node) => {
            if (!node.nodes) {
              if (node.type === "open") node.isOpen = true;
              if (node.type === "close") node.isClose = true;
              if (!node.nodes) node.type = "text";
              node.invalid = true;
            }
          });
          const parent = stack[stack.length - 1];
          const index2 = parent.nodes.indexOf(block);
          parent.nodes.splice(index2, 1, ...block.nodes);
        }
      } while (stack.length > 0);
      push({ type: "eos" });
      return ast;
    }, "parse");
    module2.exports = parse2;
  }
});

// ../../node_modules/braces/index.js
var require_braces = __commonJS({
  "../../node_modules/braces/index.js"(exports2, module2) {
    "use strict";
    var stringify2 = require_stringify();
    var compile = require_compile();
    var expand = require_expand();
    var parse2 = require_parse2();
    var braces = /* @__PURE__ */ __name((input, options = {}) => {
      let output = [];
      if (Array.isArray(input)) {
        for (const pattern of input) {
          const result2 = braces.create(pattern, options);
          if (Array.isArray(result2)) {
            output.push(...result2);
          } else {
            output.push(result2);
          }
        }
      } else {
        output = [].concat(braces.create(input, options));
      }
      if (options && options.expand === true && options.nodupes === true) {
        output = [...new Set(output)];
      }
      return output;
    }, "braces");
    braces.parse = (input, options = {}) => parse2(input, options);
    braces.stringify = (input, options = {}) => {
      if (typeof input === "string") {
        return stringify2(braces.parse(input, options), options);
      }
      return stringify2(input, options);
    };
    braces.compile = (input, options = {}) => {
      if (typeof input === "string") {
        input = braces.parse(input, options);
      }
      return compile(input, options);
    };
    braces.expand = (input, options = {}) => {
      if (typeof input === "string") {
        input = braces.parse(input, options);
      }
      let result2 = expand(input, options);
      if (options.noempty === true) {
        result2 = result2.filter(Boolean);
      }
      if (options.nodupes === true) {
        result2 = [...new Set(result2)];
      }
      return result2;
    };
    braces.create = (input, options = {}) => {
      if (input === "" || input.length < 3) {
        return [input];
      }
      return options.expand !== true ? braces.compile(input, options) : braces.expand(input, options);
    };
    module2.exports = braces;
  }
});

// ../../node_modules/micromatch/node_modules/picomatch/lib/constants.js
var require_constants3 = __commonJS({
  "../../node_modules/micromatch/node_modules/picomatch/lib/constants.js"(exports2, module2) {
    "use strict";
    var path47 = require("path");
    var WIN_SLASH = "\\\\/";
    var WIN_NO_SLASH = `[^${WIN_SLASH}]`;
    var DEFAULT_MAX_EXTGLOB_RECURSION = 0;
    var DOT_LITERAL = "\\.";
    var PLUS_LITERAL = "\\+";
    var QMARK_LITERAL = "\\?";
    var SLASH_LITERAL = "\\/";
    var ONE_CHAR = "(?=.)";
    var QMARK = "[^/]";
    var END_ANCHOR = `(?:${SLASH_LITERAL}|$)`;
    var START_ANCHOR = `(?:^|${SLASH_LITERAL})`;
    var DOTS_SLASH = `${DOT_LITERAL}{1,2}${END_ANCHOR}`;
    var NO_DOT = `(?!${DOT_LITERAL})`;
    var NO_DOTS = `(?!${START_ANCHOR}${DOTS_SLASH})`;
    var NO_DOT_SLASH = `(?!${DOT_LITERAL}{0,1}${END_ANCHOR})`;
    var NO_DOTS_SLASH = `(?!${DOTS_SLASH})`;
    var QMARK_NO_DOT = `[^.${SLASH_LITERAL}]`;
    var STAR = `${QMARK}*?`;
    var POSIX_CHARS = {
      DOT_LITERAL,
      PLUS_LITERAL,
      QMARK_LITERAL,
      SLASH_LITERAL,
      ONE_CHAR,
      QMARK,
      END_ANCHOR,
      DOTS_SLASH,
      NO_DOT,
      NO_DOTS,
      NO_DOT_SLASH,
      NO_DOTS_SLASH,
      QMARK_NO_DOT,
      STAR,
      START_ANCHOR
    };
    var WINDOWS_CHARS = {
      ...POSIX_CHARS,
      SLASH_LITERAL: `[${WIN_SLASH}]`,
      QMARK: WIN_NO_SLASH,
      STAR: `${WIN_NO_SLASH}*?`,
      DOTS_SLASH: `${DOT_LITERAL}{1,2}(?:[${WIN_SLASH}]|$)`,
      NO_DOT: `(?!${DOT_LITERAL})`,
      NO_DOTS: `(?!(?:^|[${WIN_SLASH}])${DOT_LITERAL}{1,2}(?:[${WIN_SLASH}]|$))`,
      NO_DOT_SLASH: `(?!${DOT_LITERAL}{0,1}(?:[${WIN_SLASH}]|$))`,
      NO_DOTS_SLASH: `(?!${DOT_LITERAL}{1,2}(?:[${WIN_SLASH}]|$))`,
      QMARK_NO_DOT: `[^.${WIN_SLASH}]`,
      START_ANCHOR: `(?:^|[${WIN_SLASH}])`,
      END_ANCHOR: `(?:[${WIN_SLASH}]|$)`
    };
    var POSIX_REGEX_SOURCE = {
      __proto__: null,
      alnum: "a-zA-Z0-9",
      alpha: "a-zA-Z",
      ascii: "\\x00-\\x7F",
      blank: " \\t",
      cntrl: "\\x00-\\x1F\\x7F",
      digit: "0-9",
      graph: "\\x21-\\x7E",
      lower: "a-z",
      print: "\\x20-\\x7E ",
      punct: "\\-!\"#$%&'()\\*+,./:;<=>?@[\\]^_`{|}~",
      space: " \\t\\r\\n\\v\\f",
      upper: "A-Z",
      word: "A-Za-z0-9_",
      xdigit: "A-Fa-f0-9"
    };
    module2.exports = {
      DEFAULT_MAX_EXTGLOB_RECURSION,
      MAX_LENGTH: 1024 * 64,
      POSIX_REGEX_SOURCE,
      // regular expressions
      REGEX_BACKSLASH: /\\(?![*+?^${}(|)[\]])/g,
      REGEX_NON_SPECIAL_CHARS: /^[^@![\].,$*+?^{}()|\\/]+/,
      REGEX_SPECIAL_CHARS: /[-*+?.^${}(|)[\]]/,
      REGEX_SPECIAL_CHARS_BACKREF: /(\\?)((\W)(\3*))/g,
      REGEX_SPECIAL_CHARS_GLOBAL: /([-*+?.^${}(|)[\]])/g,
      REGEX_REMOVE_BACKSLASH: /(?:\[.*?[^\\]\]|\\(?=.))/g,
      // Replace globs with equivalent patterns to reduce parsing time.
      REPLACEMENTS: {
        __proto__: null,
        "***": "*",
        "**/**": "**",
        "**/**/**": "**"
      },
      // Digits
      CHAR_0: 48,
      /* 0 */
      CHAR_9: 57,
      /* 9 */
      // Alphabet chars.
      CHAR_UPPERCASE_A: 65,
      /* A */
      CHAR_LOWERCASE_A: 97,
      /* a */
      CHAR_UPPERCASE_Z: 90,
      /* Z */
      CHAR_LOWERCASE_Z: 122,
      /* z */
      CHAR_LEFT_PARENTHESES: 40,
      /* ( */
      CHAR_RIGHT_PARENTHESES: 41,
      /* ) */
      CHAR_ASTERISK: 42,
      /* * */
      // Non-alphabetic chars.
      CHAR_AMPERSAND: 38,
      /* & */
      CHAR_AT: 64,
      /* @ */
      CHAR_BACKWARD_SLASH: 92,
      /* \ */
      CHAR_CARRIAGE_RETURN: 13,
      /* \r */
      CHAR_CIRCUMFLEX_ACCENT: 94,
      /* ^ */
      CHAR_COLON: 58,
      /* : */
      CHAR_COMMA: 44,
      /* , */
      CHAR_DOT: 46,
      /* . */
      CHAR_DOUBLE_QUOTE: 34,
      /* " */
      CHAR_EQUAL: 61,
      /* = */
      CHAR_EXCLAMATION_MARK: 33,
      /* ! */
      CHAR_FORM_FEED: 12,
      /* \f */
      CHAR_FORWARD_SLASH: 47,
      /* / */
      CHAR_GRAVE_ACCENT: 96,
      /* ` */
      CHAR_HASH: 35,
      /* # */
      CHAR_HYPHEN_MINUS: 45,
      /* - */
      CHAR_LEFT_ANGLE_BRACKET: 60,
      /* < */
      CHAR_LEFT_CURLY_BRACE: 123,
      /* { */
      CHAR_LEFT_SQUARE_BRACKET: 91,
      /* [ */
      CHAR_LINE_FEED: 10,
      /* \n */
      CHAR_NO_BREAK_SPACE: 160,
      /* \u00A0 */
      CHAR_PERCENT: 37,
      /* % */
      CHAR_PLUS: 43,
      /* + */
      CHAR_QUESTION_MARK: 63,
      /* ? */
      CHAR_RIGHT_ANGLE_BRACKET: 62,
      /* > */
      CHAR_RIGHT_CURLY_BRACE: 125,
      /* } */
      CHAR_RIGHT_SQUARE_BRACKET: 93,
      /* ] */
      CHAR_SEMICOLON: 59,
      /* ; */
      CHAR_SINGLE_QUOTE: 39,
      /* ' */
      CHAR_SPACE: 32,
      /*   */
      CHAR_TAB: 9,
      /* \t */
      CHAR_UNDERSCORE: 95,
      /* _ */
      CHAR_VERTICAL_LINE: 124,
      /* | */
      CHAR_ZERO_WIDTH_NOBREAK_SPACE: 65279,
      /* \uFEFF */
      SEP: path47.sep,
      /**
       * Create EXTGLOB_CHARS
       */
      extglobChars(chars6) {
        return {
          "!": { type: "negate", open: "(?:(?!(?:", close: `))${chars6.STAR})` },
          "?": { type: "qmark", open: "(?:", close: ")?" },
          "+": { type: "plus", open: "(?:", close: ")+" },
          "*": { type: "star", open: "(?:", close: ")*" },
          "@": { type: "at", open: "(?:", close: ")" }
        };
      },
      /**
       * Create GLOB_CHARS
       */
      globChars(win32) {
        return win32 === true ? WINDOWS_CHARS : POSIX_CHARS;
      }
    };
  }
});

// ../../node_modules/micromatch/node_modules/picomatch/lib/utils.js
var require_utils4 = __commonJS({
  "../../node_modules/micromatch/node_modules/picomatch/lib/utils.js"(exports2) {
    "use strict";
    var path47 = require("path");
    var win32 = process.platform === "win32";
    var {
      REGEX_BACKSLASH,
      REGEX_REMOVE_BACKSLASH,
      REGEX_SPECIAL_CHARS,
      REGEX_SPECIAL_CHARS_GLOBAL
    } = require_constants3();
    exports2.isObject = (val) => val !== null && typeof val === "object" && !Array.isArray(val);
    exports2.hasRegexChars = (str) => REGEX_SPECIAL_CHARS.test(str);
    exports2.isRegexChar = (str) => str.length === 1 && exports2.hasRegexChars(str);
    exports2.escapeRegex = (str) => str.replace(REGEX_SPECIAL_CHARS_GLOBAL, "\\$1");
    exports2.toPosixSlashes = (str) => str.replace(REGEX_BACKSLASH, "/");
    exports2.removeBackslashes = (str) => {
      return str.replace(REGEX_REMOVE_BACKSLASH, (match) => {
        return match === "\\" ? "" : match;
      });
    };
    exports2.supportsLookbehinds = () => {
      const segs = process.version.slice(1).split(".").map(Number);
      if (segs.length === 3 && segs[0] >= 9 || segs[0] === 8 && segs[1] >= 10) {
        return true;
      }
      return false;
    };
    exports2.isWindows = (options) => {
      if (options && typeof options.windows === "boolean") {
        return options.windows;
      }
      return win32 === true || path47.sep === "\\";
    };
    exports2.escapeLast = (input, char, lastIdx) => {
      const idx = input.lastIndexOf(char, lastIdx);
      if (idx === -1) return input;
      if (input[idx - 1] === "\\") return exports2.escapeLast(input, char, idx - 1);
      return `${input.slice(0, idx)}\\${input.slice(idx)}`;
    };
    exports2.removePrefix = (input, state13 = {}) => {
      let output = input;
      if (output.startsWith("./")) {
        output = output.slice(2);
        state13.prefix = "./";
      }
      return output;
    };
    exports2.wrapOutput = (input, state13 = {}, options = {}) => {
      const prepend = options.contains ? "" : "^";
      const append = options.contains ? "" : "$";
      let output = `${prepend}(?:${input})${append}`;
      if (state13.negated === true) {
        output = `(?:^(?!${output}).*$)`;
      }
      return output;
    };
  }
});

// ../../node_modules/micromatch/node_modules/picomatch/lib/scan.js
var require_scan2 = __commonJS({
  "../../node_modules/micromatch/node_modules/picomatch/lib/scan.js"(exports2, module2) {
    "use strict";
    var utils = require_utils4();
    var {
      CHAR_ASTERISK,
      /* * */
      CHAR_AT,
      /* @ */
      CHAR_BACKWARD_SLASH,
      /* \ */
      CHAR_COMMA,
      /* , */
      CHAR_DOT,
      /* . */
      CHAR_EXCLAMATION_MARK,
      /* ! */
      CHAR_FORWARD_SLASH,
      /* / */
      CHAR_LEFT_CURLY_BRACE,
      /* { */
      CHAR_LEFT_PARENTHESES,
      /* ( */
      CHAR_LEFT_SQUARE_BRACKET,
      /* [ */
      CHAR_PLUS,
      /* + */
      CHAR_QUESTION_MARK,
      /* ? */
      CHAR_RIGHT_CURLY_BRACE,
      /* } */
      CHAR_RIGHT_PARENTHESES,
      /* ) */
      CHAR_RIGHT_SQUARE_BRACKET
      /* ] */
    } = require_constants3();
    var isPathSeparator = /* @__PURE__ */ __name((code) => {
      return code === CHAR_FORWARD_SLASH || code === CHAR_BACKWARD_SLASH;
    }, "isPathSeparator");
    var depth = /* @__PURE__ */ __name((token) => {
      if (token.isPrefix !== true) {
        token.depth = token.isGlobstar ? Infinity : 1;
      }
    }, "depth");
    var scan = /* @__PURE__ */ __name((input, options) => {
      const opts = options || {};
      const length = input.length - 1;
      const scanToEnd = opts.parts === true || opts.scanToEnd === true;
      const slashes = [];
      const tokens = [];
      const parts = [];
      let str = input;
      let index = -1;
      let start = 0;
      let lastIndex = 0;
      let isBrace = false;
      let isBracket = false;
      let isGlob = false;
      let isExtglob = false;
      let isGlobstar = false;
      let braceEscaped = false;
      let backslashes = false;
      let negated = false;
      let negatedExtglob = false;
      let finished = false;
      let braces = 0;
      let prev;
      let code;
      let token = { value: "", depth: 0, isGlob: false };
      const eos = /* @__PURE__ */ __name(() => index >= length, "eos");
      const peek = /* @__PURE__ */ __name(() => str.charCodeAt(index + 1), "peek");
      const advance = /* @__PURE__ */ __name(() => {
        prev = code;
        return str.charCodeAt(++index);
      }, "advance");
      while (index < length) {
        code = advance();
        let next;
        if (code === CHAR_BACKWARD_SLASH) {
          backslashes = token.backslashes = true;
          code = advance();
          if (code === CHAR_LEFT_CURLY_BRACE) {
            braceEscaped = true;
          }
          continue;
        }
        if (braceEscaped === true || code === CHAR_LEFT_CURLY_BRACE) {
          braces++;
          while (eos() !== true && (code = advance())) {
            if (code === CHAR_BACKWARD_SLASH) {
              backslashes = token.backslashes = true;
              advance();
              continue;
            }
            if (code === CHAR_LEFT_CURLY_BRACE) {
              braces++;
              continue;
            }
            if (braceEscaped !== true && code === CHAR_DOT && (code = advance()) === CHAR_DOT) {
              isBrace = token.isBrace = true;
              isGlob = token.isGlob = true;
              finished = true;
              if (scanToEnd === true) {
                continue;
              }
              break;
            }
            if (braceEscaped !== true && code === CHAR_COMMA) {
              isBrace = token.isBrace = true;
              isGlob = token.isGlob = true;
              finished = true;
              if (scanToEnd === true) {
                continue;
              }
              break;
            }
            if (code === CHAR_RIGHT_CURLY_BRACE) {
              braces--;
              if (braces === 0) {
                braceEscaped = false;
                isBrace = token.isBrace = true;
                finished = true;
                break;
              }
            }
          }
          if (scanToEnd === true) {
            continue;
          }
          break;
        }
        if (code === CHAR_FORWARD_SLASH) {
          slashes.push(index);
          tokens.push(token);
          token = { value: "", depth: 0, isGlob: false };
          if (finished === true) continue;
          if (prev === CHAR_DOT && index === start + 1) {
            start += 2;
            continue;
          }
          lastIndex = index + 1;
          continue;
        }
        if (opts.noext !== true) {
          const isExtglobChar = code === CHAR_PLUS || code === CHAR_AT || code === CHAR_ASTERISK || code === CHAR_QUESTION_MARK || code === CHAR_EXCLAMATION_MARK;
          if (isExtglobChar === true && peek() === CHAR_LEFT_PARENTHESES) {
            isGlob = token.isGlob = true;
            isExtglob = token.isExtglob = true;
            finished = true;
            if (code === CHAR_EXCLAMATION_MARK && index === start) {
              negatedExtglob = true;
            }
            if (scanToEnd === true) {
              while (eos() !== true && (code = advance())) {
                if (code === CHAR_BACKWARD_SLASH) {
                  backslashes = token.backslashes = true;
                  code = advance();
                  continue;
                }
                if (code === CHAR_RIGHT_PARENTHESES) {
                  isGlob = token.isGlob = true;
                  finished = true;
                  break;
                }
              }
              continue;
            }
            break;
          }
        }
        if (code === CHAR_ASTERISK) {
          if (prev === CHAR_ASTERISK) isGlobstar = token.isGlobstar = true;
          isGlob = token.isGlob = true;
          finished = true;
          if (scanToEnd === true) {
            continue;
          }
          break;
        }
        if (code === CHAR_QUESTION_MARK) {
          isGlob = token.isGlob = true;
          finished = true;
          if (scanToEnd === true) {
            continue;
          }
          break;
        }
        if (code === CHAR_LEFT_SQUARE_BRACKET) {
          while (eos() !== true && (next = advance())) {
            if (next === CHAR_BACKWARD_SLASH) {
              backslashes = token.backslashes = true;
              advance();
              continue;
            }
            if (next === CHAR_RIGHT_SQUARE_BRACKET) {
              isBracket = token.isBracket = true;
              isGlob = token.isGlob = true;
              finished = true;
              break;
            }
          }
          if (scanToEnd === true) {
            continue;
          }
          break;
        }
        if (opts.nonegate !== true && code === CHAR_EXCLAMATION_MARK && index === start) {
          negated = token.negated = true;
          start++;
          continue;
        }
        if (opts.noparen !== true && code === CHAR_LEFT_PARENTHESES) {
          isGlob = token.isGlob = true;
          if (scanToEnd === true) {
            while (eos() !== true && (code = advance())) {
              if (code === CHAR_LEFT_PARENTHESES) {
                backslashes = token.backslashes = true;
                code = advance();
                continue;
              }
              if (code === CHAR_RIGHT_PARENTHESES) {
                finished = true;
                break;
              }
            }
            continue;
          }
          break;
        }
        if (isGlob === true) {
          finished = true;
          if (scanToEnd === true) {
            continue;
          }
          break;
        }
      }
      if (opts.noext === true) {
        isExtglob = false;
        isGlob = false;
      }
      let base = str;
      let prefix = "";
      let glob = "";
      if (start > 0) {
        prefix = str.slice(0, start);
        str = str.slice(start);
        lastIndex -= start;
      }
      if (base && isGlob === true && lastIndex > 0) {
        base = str.slice(0, lastIndex);
        glob = str.slice(lastIndex);
      } else if (isGlob === true) {
        base = "";
        glob = str;
      } else {
        base = str;
      }
      if (base && base !== "" && base !== "/" && base !== str) {
        if (isPathSeparator(base.charCodeAt(base.length - 1))) {
          base = base.slice(0, -1);
        }
      }
      if (opts.unescape === true) {
        if (glob) glob = utils.removeBackslashes(glob);
        if (base && backslashes === true) {
          base = utils.removeBackslashes(base);
        }
      }
      const state13 = {
        prefix,
        input,
        start,
        base,
        glob,
        isBrace,
        isBracket,
        isGlob,
        isExtglob,
        isGlobstar,
        negated,
        negatedExtglob
      };
      if (opts.tokens === true) {
        state13.maxDepth = 0;
        if (!isPathSeparator(code)) {
          tokens.push(token);
        }
        state13.tokens = tokens;
      }
      if (opts.parts === true || opts.tokens === true) {
        let prevIndex;
        for (let idx = 0; idx < slashes.length; idx++) {
          const n10 = prevIndex ? prevIndex + 1 : start;
          const i32 = slashes[idx];
          const value = input.slice(n10, i32);
          if (opts.tokens) {
            if (idx === 0 && start !== 0) {
              tokens[idx].isPrefix = true;
              tokens[idx].value = prefix;
            } else {
              tokens[idx].value = value;
            }
            depth(tokens[idx]);
            state13.maxDepth += tokens[idx].depth;
          }
          if (idx !== 0 || value !== "") {
            parts.push(value);
          }
          prevIndex = i32;
        }
        if (prevIndex && prevIndex + 1 < input.length) {
          const value = input.slice(prevIndex + 1);
          parts.push(value);
          if (opts.tokens) {
            tokens[tokens.length - 1].value = value;
            depth(tokens[tokens.length - 1]);
            state13.maxDepth += tokens[tokens.length - 1].depth;
          }
        }
        state13.slashes = slashes;
        state13.parts = parts;
      }
      return state13;
    }, "scan");
    module2.exports = scan;
  }
});

// ../../node_modules/micromatch/node_modules/picomatch/lib/parse.js
var require_parse3 = __commonJS({
  "../../node_modules/micromatch/node_modules/picomatch/lib/parse.js"(exports2, module2) {
    "use strict";
    var constants3 = require_constants3();
    var utils = require_utils4();
    var {
      MAX_LENGTH,
      POSIX_REGEX_SOURCE,
      REGEX_NON_SPECIAL_CHARS,
      REGEX_SPECIAL_CHARS_BACKREF,
      REPLACEMENTS
    } = constants3;
    var expandRange = /* @__PURE__ */ __name((args, options) => {
      if (typeof options.expandRange === "function") {
        return options.expandRange(...args, options);
      }
      args.sort();
      const value = `[${args.join("-")}]`;
      try {
        new RegExp(value);
      } catch (ex) {
        return args.map((v) => utils.escapeRegex(v)).join("..");
      }
      return value;
    }, "expandRange");
    var syntaxError = /* @__PURE__ */ __name((type, char) => {
      return `Missing ${type}: "${char}" - use "\\\\${char}" to match literal characters`;
    }, "syntaxError");
    var splitTopLevel = /* @__PURE__ */ __name((input) => {
      const parts = [];
      let bracket = 0;
      let paren = 0;
      let quote = 0;
      let value = "";
      let escaped = false;
      for (const ch of input) {
        if (escaped === true) {
          value += ch;
          escaped = false;
          continue;
        }
        if (ch === "\\") {
          value += ch;
          escaped = true;
          continue;
        }
        if (ch === '"') {
          quote = quote === 1 ? 0 : 1;
          value += ch;
          continue;
        }
        if (quote === 0) {
          if (ch === "[") {
            bracket++;
          } else if (ch === "]" && bracket > 0) {
            bracket--;
          } else if (bracket === 0) {
            if (ch === "(") {
              paren++;
            } else if (ch === ")" && paren > 0) {
              paren--;
            } else if (ch === "|" && paren === 0) {
              parts.push(value);
              value = "";
              continue;
            }
          }
        }
        value += ch;
      }
      parts.push(value);
      return parts;
    }, "splitTopLevel");
    var isPlainBranch = /* @__PURE__ */ __name((branch) => {
      let escaped = false;
      for (const ch of branch) {
        if (escaped === true) {
          escaped = false;
          continue;
        }
        if (ch === "\\") {
          escaped = true;
          continue;
        }
        if (/[?*+@!()[\]{}]/.test(ch)) {
          return false;
        }
      }
      return true;
    }, "isPlainBranch");
    var normalizeSimpleBranch = /* @__PURE__ */ __name((branch) => {
      let value = branch.trim();
      let changed = true;
      while (changed === true) {
        changed = false;
        if (/^@\([^\\()[\]{}|]+\)$/.test(value)) {
          value = value.slice(2, -1);
          changed = true;
        }
      }
      if (!isPlainBranch(value)) {
        return;
      }
      return value.replace(/\\(.)/g, "$1");
    }, "normalizeSimpleBranch");
    var hasRepeatedCharPrefixOverlap = /* @__PURE__ */ __name((branches) => {
      const values = branches.map(normalizeSimpleBranch).filter(Boolean);
      for (let i32 = 0; i32 < values.length; i32++) {
        for (let j32 = i32 + 1; j32 < values.length; j32++) {
          const a32 = values[i32];
          const b32 = values[j32];
          const char = a32[0];
          if (!char || a32 !== char.repeat(a32.length) || b32 !== char.repeat(b32.length)) {
            continue;
          }
          if (a32 === b32 || a32.startsWith(b32) || b32.startsWith(a32)) {
            return true;
          }
        }
      }
      return false;
    }, "hasRepeatedCharPrefixOverlap");
    var parseRepeatedExtglob = /* @__PURE__ */ __name((pattern, requireEnd = true) => {
      if (pattern[0] !== "+" && pattern[0] !== "*" || pattern[1] !== "(") {
        return;
      }
      let bracket = 0;
      let paren = 0;
      let quote = 0;
      let escaped = false;
      for (let i32 = 1; i32 < pattern.length; i32++) {
        const ch = pattern[i32];
        if (escaped === true) {
          escaped = false;
          continue;
        }
        if (ch === "\\") {
          escaped = true;
          continue;
        }
        if (ch === '"') {
          quote = quote === 1 ? 0 : 1;
          continue;
        }
        if (quote === 1) {
          continue;
        }
        if (ch === "[") {
          bracket++;
          continue;
        }
        if (ch === "]" && bracket > 0) {
          bracket--;
          continue;
        }
        if (bracket > 0) {
          continue;
        }
        if (ch === "(") {
          paren++;
          continue;
        }
        if (ch === ")") {
          paren--;
          if (paren === 0) {
            if (requireEnd === true && i32 !== pattern.length - 1) {
              return;
            }
            return {
              type: pattern[0],
              body: pattern.slice(2, i32),
              end: i32
            };
          }
        }
      }
    }, "parseRepeatedExtglob");
    var getStarExtglobSequenceOutput = /* @__PURE__ */ __name((pattern) => {
      let index = 0;
      const chars6 = [];
      while (index < pattern.length) {
        const match = parseRepeatedExtglob(pattern.slice(index), false);
        if (!match || match.type !== "*") {
          return;
        }
        const branches = splitTopLevel(match.body).map((branch2) => branch2.trim());
        if (branches.length !== 1) {
          return;
        }
        const branch = normalizeSimpleBranch(branches[0]);
        if (!branch || branch.length !== 1) {
          return;
        }
        chars6.push(branch);
        index += match.end + 1;
      }
      if (chars6.length < 1) {
        return;
      }
      const source = chars6.length === 1 ? utils.escapeRegex(chars6[0]) : `[${chars6.map((ch) => utils.escapeRegex(ch)).join("")}]`;
      return `${source}*`;
    }, "getStarExtglobSequenceOutput");
    var repeatedExtglobRecursion = /* @__PURE__ */ __name((pattern) => {
      let depth = 0;
      let value = pattern.trim();
      let match = parseRepeatedExtglob(value);
      while (match) {
        depth++;
        value = match.body.trim();
        match = parseRepeatedExtglob(value);
      }
      return depth;
    }, "repeatedExtglobRecursion");
    var analyzeRepeatedExtglob = /* @__PURE__ */ __name((body, options) => {
      if (options.maxExtglobRecursion === false) {
        return { risky: false };
      }
      const max = typeof options.maxExtglobRecursion === "number" ? options.maxExtglobRecursion : constants3.DEFAULT_MAX_EXTGLOB_RECURSION;
      const branches = splitTopLevel(body).map((branch) => branch.trim());
      if (branches.length > 1) {
        if (branches.some((branch) => branch === "") || branches.some((branch) => /^[*?]+$/.test(branch)) || hasRepeatedCharPrefixOverlap(branches)) {
          return { risky: true };
        }
      }
      for (const branch of branches) {
        const safeOutput = getStarExtglobSequenceOutput(branch);
        if (safeOutput) {
          return { risky: true, safeOutput };
        }
        if (repeatedExtglobRecursion(branch) > max) {
          return { risky: true };
        }
      }
      return { risky: false };
    }, "analyzeRepeatedExtglob");
    var parse2 = /* @__PURE__ */ __name((input, options) => {
      if (typeof input !== "string") {
        throw new TypeError("Expected a string");
      }
      input = REPLACEMENTS[input] || input;
      const opts = { ...options };
      const max = typeof opts.maxLength === "number" ? Math.min(MAX_LENGTH, opts.maxLength) : MAX_LENGTH;
      let len = input.length;
      if (len > max) {
        throw new SyntaxError(`Input length: ${len}, exceeds maximum allowed length: ${max}`);
      }
      const bos = { type: "bos", value: "", output: opts.prepend || "" };
      const tokens = [bos];
      const capture = opts.capture ? "" : "?:";
      const win32 = utils.isWindows(options);
      const PLATFORM_CHARS = constants3.globChars(win32);
      const EXTGLOB_CHARS = constants3.extglobChars(PLATFORM_CHARS);
      const {
        DOT_LITERAL,
        PLUS_LITERAL,
        SLASH_LITERAL,
        ONE_CHAR,
        DOTS_SLASH,
        NO_DOT,
        NO_DOT_SLASH,
        NO_DOTS_SLASH,
        QMARK,
        QMARK_NO_DOT,
        STAR,
        START_ANCHOR
      } = PLATFORM_CHARS;
      const globstar = /* @__PURE__ */ __name((opts2) => {
        return `(${capture}(?:(?!${START_ANCHOR}${opts2.dot ? DOTS_SLASH : DOT_LITERAL}).)*?)`;
      }, "globstar");
      const nodot = opts.dot ? "" : NO_DOT;
      const qmarkNoDot = opts.dot ? QMARK : QMARK_NO_DOT;
      let star = opts.bash === true ? globstar(opts) : STAR;
      if (opts.capture) {
        star = `(${star})`;
      }
      if (typeof opts.noext === "boolean") {
        opts.noextglob = opts.noext;
      }
      const state13 = {
        input,
        index: -1,
        start: 0,
        dot: opts.dot === true,
        consumed: "",
        output: "",
        prefix: "",
        backtrack: false,
        negated: false,
        brackets: 0,
        braces: 0,
        parens: 0,
        quotes: 0,
        globstar: false,
        tokens
      };
      input = utils.removePrefix(input, state13);
      len = input.length;
      const extglobs = [];
      const braces = [];
      const stack = [];
      let prev = bos;
      let value;
      const eos = /* @__PURE__ */ __name(() => state13.index === len - 1, "eos");
      const peek = state13.peek = (n10 = 1) => input[state13.index + n10];
      const advance = state13.advance = () => input[++state13.index] || "";
      const remaining = /* @__PURE__ */ __name(() => input.slice(state13.index + 1), "remaining");
      const consume = /* @__PURE__ */ __name((value2 = "", num = 0) => {
        state13.consumed += value2;
        state13.index += num;
      }, "consume");
      const append = /* @__PURE__ */ __name((token) => {
        state13.output += token.output != null ? token.output : token.value;
        consume(token.value);
      }, "append");
      const negate6 = /* @__PURE__ */ __name(() => {
        let count = 1;
        while (peek() === "!" && (peek(2) !== "(" || peek(3) === "?")) {
          advance();
          state13.start++;
          count++;
        }
        if (count % 2 === 0) {
          return false;
        }
        state13.negated = true;
        state13.start++;
        return true;
      }, "negate");
      const increment = /* @__PURE__ */ __name((type) => {
        state13[type]++;
        stack.push(type);
      }, "increment");
      const decrement = /* @__PURE__ */ __name((type) => {
        state13[type]--;
        stack.pop();
      }, "decrement");
      const push = /* @__PURE__ */ __name((tok) => {
        if (prev.type === "globstar") {
          const isBrace = state13.braces > 0 && (tok.type === "comma" || tok.type === "brace");
          const isExtglob = tok.extglob === true || extglobs.length && (tok.type === "pipe" || tok.type === "paren");
          if (tok.type !== "slash" && tok.type !== "paren" && !isBrace && !isExtglob) {
            state13.output = state13.output.slice(0, -prev.output.length);
            prev.type = "star";
            prev.value = "*";
            prev.output = star;
            state13.output += prev.output;
          }
        }
        if (extglobs.length && tok.type !== "paren") {
          extglobs[extglobs.length - 1].inner += tok.value;
        }
        if (tok.value || tok.output) append(tok);
        if (prev && prev.type === "text" && tok.type === "text") {
          prev.value += tok.value;
          prev.output = (prev.output || "") + tok.value;
          return;
        }
        tok.prev = prev;
        tokens.push(tok);
        prev = tok;
      }, "push");
      const extglobOpen = /* @__PURE__ */ __name((type, value2) => {
        const token = { ...EXTGLOB_CHARS[value2], conditions: 1, inner: "" };
        token.prev = prev;
        token.parens = state13.parens;
        token.output = state13.output;
        token.startIndex = state13.index;
        token.tokensIndex = tokens.length;
        const output = (opts.capture ? "(" : "") + token.open;
        increment("parens");
        push({ type, value: value2, output: state13.output ? "" : ONE_CHAR });
        push({ type: "paren", extglob: true, value: advance(), output });
        extglobs.push(token);
      }, "extglobOpen");
      const extglobClose = /* @__PURE__ */ __name((token) => {
        const literal = input.slice(token.startIndex, state13.index + 1);
        const body = input.slice(token.startIndex + 2, state13.index);
        const analysis = analyzeRepeatedExtglob(body, opts);
        if ((token.type === "plus" || token.type === "star") && analysis.risky) {
          const safeOutput = analysis.safeOutput ? (token.output ? "" : ONE_CHAR) + (opts.capture ? `(${analysis.safeOutput})` : analysis.safeOutput) : void 0;
          const open2 = tokens[token.tokensIndex];
          open2.type = "text";
          open2.value = literal;
          open2.output = safeOutput || utils.escapeRegex(literal);
          for (let i32 = token.tokensIndex + 1; i32 < tokens.length; i32++) {
            tokens[i32].value = "";
            tokens[i32].output = "";
            delete tokens[i32].suffix;
          }
          state13.output = token.output + open2.output;
          state13.backtrack = true;
          push({ type: "paren", extglob: true, value, output: "" });
          decrement("parens");
          return;
        }
        let output = token.close + (opts.capture ? ")" : "");
        let rest;
        if (token.type === "negate") {
          let extglobStar = star;
          if (token.inner && token.inner.length > 1 && token.inner.includes("/")) {
            extglobStar = globstar(opts);
          }
          if (extglobStar !== star || eos() || /^\)+$/.test(remaining())) {
            output = token.close = `)$))${extglobStar}`;
          }
          if (token.inner.includes("*") && (rest = remaining()) && /^\.[^\\/.]+$/.test(rest)) {
            const expression = parse2(rest, { ...options, fastpaths: false }).output;
            output = token.close = `)${expression})${extglobStar})`;
          }
          if (token.prev.type === "bos") {
            state13.negatedExtglob = true;
          }
        }
        push({ type: "paren", extglob: true, value, output });
        decrement("parens");
      }, "extglobClose");
      if (opts.fastpaths !== false && !/(^[*!]|[/()[\]{}"])/.test(input)) {
        let backslashes = false;
        let output = input.replace(REGEX_SPECIAL_CHARS_BACKREF, (m20, esc, chars6, first, rest, index) => {
          if (first === "\\") {
            backslashes = true;
            return m20;
          }
          if (first === "?") {
            if (esc) {
              return esc + first + (rest ? QMARK.repeat(rest.length) : "");
            }
            if (index === 0) {
              return qmarkNoDot + (rest ? QMARK.repeat(rest.length) : "");
            }
            return QMARK.repeat(chars6.length);
          }
          if (first === ".") {
            return DOT_LITERAL.repeat(chars6.length);
          }
          if (first === "*") {
            if (esc) {
              return esc + first + (rest ? star : "");
            }
            return star;
          }
          return esc ? m20 : `\\${m20}`;
        });
        if (backslashes === true) {
          if (opts.unescape === true) {
            output = output.replace(/\\/g, "");
          } else {
            output = output.replace(/\\+/g, (m20) => {
              return m20.length % 2 === 0 ? "\\\\" : m20 ? "\\" : "";
            });
          }
        }
        if (output === input && opts.contains === true) {
          state13.output = input;
          return state13;
        }
        state13.output = utils.wrapOutput(output, state13, options);
        return state13;
      }
      while (!eos()) {
        value = advance();
        if (value === "\0") {
          continue;
        }
        if (value === "\\") {
          const next = peek();
          if (next === "/" && opts.bash !== true) {
            continue;
          }
          if (next === "." || next === ";") {
            continue;
          }
          if (!next) {
            value += "\\";
            push({ type: "text", value });
            continue;
          }
          const match = /^\\+/.exec(remaining());
          let slashes = 0;
          if (match && match[0].length > 2) {
            slashes = match[0].length;
            state13.index += slashes;
            if (slashes % 2 !== 0) {
              value += "\\";
            }
          }
          if (opts.unescape === true) {
            value = advance();
          } else {
            value += advance();
          }
          if (state13.brackets === 0) {
            push({ type: "text", value });
            continue;
          }
        }
        if (state13.brackets > 0 && (value !== "]" || prev.value === "[" || prev.value === "[^")) {
          if (opts.posix !== false && value === ":") {
            const inner = prev.value.slice(1);
            if (inner.includes("[")) {
              prev.posix = true;
              if (inner.includes(":")) {
                const idx = prev.value.lastIndexOf("[");
                const pre = prev.value.slice(0, idx);
                const rest2 = prev.value.slice(idx + 2);
                const posix = POSIX_REGEX_SOURCE[rest2];
                if (posix) {
                  prev.value = pre + posix;
                  state13.backtrack = true;
                  advance();
                  if (!bos.output && tokens.indexOf(prev) === 1) {
                    bos.output = ONE_CHAR;
                  }
                  continue;
                }
              }
            }
          }
          if (value === "[" && peek() !== ":" || value === "-" && peek() === "]") {
            value = `\\${value}`;
          }
          if (value === "]" && (prev.value === "[" || prev.value === "[^")) {
            value = `\\${value}`;
          }
          if (opts.posix === true && value === "!" && prev.value === "[") {
            value = "^";
          }
          prev.value += value;
          append({ value });
          continue;
        }
        if (state13.quotes === 1 && value !== '"') {
          value = utils.escapeRegex(value);
          prev.value += value;
          append({ value });
          continue;
        }
        if (value === '"') {
          state13.quotes = state13.quotes === 1 ? 0 : 1;
          if (opts.keepQuotes === true) {
            push({ type: "text", value });
          }
          continue;
        }
        if (value === "(") {
          increment("parens");
          push({ type: "paren", value });
          continue;
        }
        if (value === ")") {
          if (state13.parens === 0 && opts.strictBrackets === true) {
            throw new SyntaxError(syntaxError("opening", "("));
          }
          const extglob = extglobs[extglobs.length - 1];
          if (extglob && state13.parens === extglob.parens + 1) {
            extglobClose(extglobs.pop());
            continue;
          }
          push({ type: "paren", value, output: state13.parens ? ")" : "\\)" });
          decrement("parens");
          continue;
        }
        if (value === "[") {
          if (opts.nobracket === true || !remaining().includes("]")) {
            if (opts.nobracket !== true && opts.strictBrackets === true) {
              throw new SyntaxError(syntaxError("closing", "]"));
            }
            value = `\\${value}`;
          } else {
            increment("brackets");
          }
          push({ type: "bracket", value });
          continue;
        }
        if (value === "]") {
          if (opts.nobracket === true || prev && prev.type === "bracket" && prev.value.length === 1) {
            push({ type: "text", value, output: `\\${value}` });
            continue;
          }
          if (state13.brackets === 0) {
            if (opts.strictBrackets === true) {
              throw new SyntaxError(syntaxError("opening", "["));
            }
            push({ type: "text", value, output: `\\${value}` });
            continue;
          }
          decrement("brackets");
          const prevValue = prev.value.slice(1);
          if (prev.posix !== true && prevValue[0] === "^" && !prevValue.includes("/")) {
            value = `/${value}`;
          }
          prev.value += value;
          append({ value });
          if (opts.literalBrackets === false || utils.hasRegexChars(prevValue)) {
            continue;
          }
          const escaped = utils.escapeRegex(prev.value);
          state13.output = state13.output.slice(0, -prev.value.length);
          if (opts.literalBrackets === true) {
            state13.output += escaped;
            prev.value = escaped;
            continue;
          }
          prev.value = `(${capture}${escaped}|${prev.value})`;
          state13.output += prev.value;
          continue;
        }
        if (value === "{" && opts.nobrace !== true) {
          increment("braces");
          const open2 = {
            type: "brace",
            value,
            output: "(",
            outputIndex: state13.output.length,
            tokensIndex: state13.tokens.length
          };
          braces.push(open2);
          push(open2);
          continue;
        }
        if (value === "}") {
          const brace = braces[braces.length - 1];
          if (opts.nobrace === true || !brace) {
            push({ type: "text", value, output: value });
            continue;
          }
          let output = ")";
          if (brace.dots === true) {
            const arr = tokens.slice();
            const range7 = [];
            for (let i32 = arr.length - 1; i32 >= 0; i32--) {
              tokens.pop();
              if (arr[i32].type === "brace") {
                break;
              }
              if (arr[i32].type !== "dots") {
                range7.unshift(arr[i32].value);
              }
            }
            output = expandRange(range7, opts);
            state13.backtrack = true;
          }
          if (brace.comma !== true && brace.dots !== true) {
            const out = state13.output.slice(0, brace.outputIndex);
            const toks = state13.tokens.slice(brace.tokensIndex);
            brace.value = brace.output = "\\{";
            value = output = "\\}";
            state13.output = out;
            for (const t of toks) {
              state13.output += t.output || t.value;
            }
          }
          push({ type: "brace", value, output });
          decrement("braces");
          braces.pop();
          continue;
        }
        if (value === "|") {
          if (extglobs.length > 0) {
            extglobs[extglobs.length - 1].conditions++;
          }
          push({ type: "text", value });
          continue;
        }
        if (value === ",") {
          let output = value;
          const brace = braces[braces.length - 1];
          if (brace && stack[stack.length - 1] === "braces") {
            brace.comma = true;
            output = "|";
          }
          push({ type: "comma", value, output });
          continue;
        }
        if (value === "/") {
          if (prev.type === "dot" && state13.index === state13.start + 1) {
            state13.start = state13.index + 1;
            state13.consumed = "";
            state13.output = "";
            tokens.pop();
            prev = bos;
            continue;
          }
          push({ type: "slash", value, output: SLASH_LITERAL });
          continue;
        }
        if (value === ".") {
          if (state13.braces > 0 && prev.type === "dot") {
            if (prev.value === ".") prev.output = DOT_LITERAL;
            const brace = braces[braces.length - 1];
            prev.type = "dots";
            prev.output += value;
            prev.value += value;
            brace.dots = true;
            continue;
          }
          if (state13.braces + state13.parens === 0 && prev.type !== "bos" && prev.type !== "slash") {
            push({ type: "text", value, output: DOT_LITERAL });
            continue;
          }
          push({ type: "dot", value, output: DOT_LITERAL });
          continue;
        }
        if (value === "?") {
          const isGroup = prev && prev.value === "(";
          if (!isGroup && opts.noextglob !== true && peek() === "(" && peek(2) !== "?") {
            extglobOpen("qmark", value);
            continue;
          }
          if (prev && prev.type === "paren") {
            const next = peek();
            let output = value;
            if (next === "<" && !utils.supportsLookbehinds()) {
              throw new Error("Node.js v10 or higher is required for regex lookbehinds");
            }
            if (prev.value === "(" && !/[!=<:]/.test(next) || next === "<" && !/<([!=]|\w+>)/.test(remaining())) {
              output = `\\${value}`;
            }
            push({ type: "text", value, output });
            continue;
          }
          if (opts.dot !== true && (prev.type === "slash" || prev.type === "bos")) {
            push({ type: "qmark", value, output: QMARK_NO_DOT });
            continue;
          }
          push({ type: "qmark", value, output: QMARK });
          continue;
        }
        if (value === "!") {
          if (opts.noextglob !== true && peek() === "(") {
            if (peek(2) !== "?" || !/[!=<:]/.test(peek(3))) {
              extglobOpen("negate", value);
              continue;
            }
          }
          if (opts.nonegate !== true && state13.index === 0) {
            negate6();
            continue;
          }
        }
        if (value === "+") {
          if (opts.noextglob !== true && peek() === "(" && peek(2) !== "?") {
            extglobOpen("plus", value);
            continue;
          }
          if (prev && prev.value === "(" || opts.regex === false) {
            push({ type: "plus", value, output: PLUS_LITERAL });
            continue;
          }
          if (prev && (prev.type === "bracket" || prev.type === "paren" || prev.type === "brace") || state13.parens > 0) {
            push({ type: "plus", value });
            continue;
          }
          push({ type: "plus", value: PLUS_LITERAL });
          continue;
        }
        if (value === "@") {
          if (opts.noextglob !== true && peek() === "(" && peek(2) !== "?") {
            push({ type: "at", extglob: true, value, output: "" });
            continue;
          }
          push({ type: "text", value });
          continue;
        }
        if (value !== "*") {
          if (value === "$" || value === "^") {
            value = `\\${value}`;
          }
          const match = REGEX_NON_SPECIAL_CHARS.exec(remaining());
          if (match) {
            value += match[0];
            state13.index += match[0].length;
          }
          push({ type: "text", value });
          continue;
        }
        if (prev && (prev.type === "globstar" || prev.star === true)) {
          prev.type = "star";
          prev.star = true;
          prev.value += value;
          prev.output = star;
          state13.backtrack = true;
          state13.globstar = true;
          consume(value);
          continue;
        }
        let rest = remaining();
        if (opts.noextglob !== true && /^\([^?]/.test(rest)) {
          extglobOpen("star", value);
          continue;
        }
        if (prev.type === "star") {
          if (opts.noglobstar === true) {
            consume(value);
            continue;
          }
          const prior = prev.prev;
          const before = prior.prev;
          const isStart = prior.type === "slash" || prior.type === "bos";
          const afterStar = before && (before.type === "star" || before.type === "globstar");
          if (opts.bash === true && (!isStart || rest[0] && rest[0] !== "/")) {
            push({ type: "star", value, output: "" });
            continue;
          }
          const isBrace = state13.braces > 0 && (prior.type === "comma" || prior.type === "brace");
          const isExtglob = extglobs.length && (prior.type === "pipe" || prior.type === "paren");
          if (!isStart && prior.type !== "paren" && !isBrace && !isExtglob) {
            push({ type: "star", value, output: "" });
            continue;
          }
          while (rest.slice(0, 3) === "/**") {
            const after = input[state13.index + 4];
            if (after && after !== "/") {
              break;
            }
            rest = rest.slice(3);
            consume("/**", 3);
          }
          if (prior.type === "bos" && eos()) {
            prev.type = "globstar";
            prev.value += value;
            prev.output = globstar(opts);
            state13.output = prev.output;
            state13.globstar = true;
            consume(value);
            continue;
          }
          if (prior.type === "slash" && prior.prev.type !== "bos" && !afterStar && eos()) {
            state13.output = state13.output.slice(0, -(prior.output + prev.output).length);
            prior.output = `(?:${prior.output}`;
            prev.type = "globstar";
            prev.output = globstar(opts) + (opts.strictSlashes ? ")" : "|$)");
            prev.value += value;
            state13.globstar = true;
            state13.output += prior.output + prev.output;
            consume(value);
            continue;
          }
          if (prior.type === "slash" && prior.prev.type !== "bos" && rest[0] === "/") {
            const end = rest[1] !== void 0 ? "|$" : "";
            state13.output = state13.output.slice(0, -(prior.output + prev.output).length);
            prior.output = `(?:${prior.output}`;
            prev.type = "globstar";
            prev.output = `${globstar(opts)}${SLASH_LITERAL}|${SLASH_LITERAL}${end})`;
            prev.value += value;
            state13.output += prior.output + prev.output;
            state13.globstar = true;
            consume(value + advance());
            push({ type: "slash", value: "/", output: "" });
            continue;
          }
          if (prior.type === "bos" && rest[0] === "/") {
            prev.type = "globstar";
            prev.value += value;
            prev.output = `(?:^|${SLASH_LITERAL}|${globstar(opts)}${SLASH_LITERAL})`;
            state13.output = prev.output;
            state13.globstar = true;
            consume(value + advance());
            push({ type: "slash", value: "/", output: "" });
            continue;
          }
          state13.output = state13.output.slice(0, -prev.output.length);
          prev.type = "globstar";
          prev.output = globstar(opts);
          prev.value += value;
          state13.output += prev.output;
          state13.globstar = true;
          consume(value);
          continue;
        }
        const token = { type: "star", value, output: star };
        if (opts.bash === true) {
          token.output = ".*?";
          if (prev.type === "bos" || prev.type === "slash") {
            token.output = nodot + token.output;
          }
          push(token);
          continue;
        }
        if (prev && (prev.type === "bracket" || prev.type === "paren") && opts.regex === true) {
          token.output = value;
          push(token);
          continue;
        }
        if (state13.index === state13.start || prev.type === "slash" || prev.type === "dot") {
          if (prev.type === "dot") {
            state13.output += NO_DOT_SLASH;
            prev.output += NO_DOT_SLASH;
          } else if (opts.dot === true) {
            state13.output += NO_DOTS_SLASH;
            prev.output += NO_DOTS_SLASH;
          } else {
            state13.output += nodot;
            prev.output += nodot;
          }
          if (peek() !== "*") {
            state13.output += ONE_CHAR;
            prev.output += ONE_CHAR;
          }
        }
        push(token);
      }
      while (state13.brackets > 0) {
        if (opts.strictBrackets === true) throw new SyntaxError(syntaxError("closing", "]"));
        state13.output = utils.escapeLast(state13.output, "[");
        decrement("brackets");
      }
      while (state13.parens > 0) {
        if (opts.strictBrackets === true) throw new SyntaxError(syntaxError("closing", ")"));
        state13.output = utils.escapeLast(state13.output, "(");
        decrement("parens");
      }
      while (state13.braces > 0) {
        if (opts.strictBrackets === true) throw new SyntaxError(syntaxError("closing", "}"));
        state13.output = utils.escapeLast(state13.output, "{");
        decrement("braces");
      }
      if (opts.strictSlashes !== true && (prev.type === "star" || prev.type === "bracket")) {
        push({ type: "maybe_slash", value: "", output: `${SLASH_LITERAL}?` });
      }
      if (state13.backtrack === true) {
        state13.output = "";
        for (const token of state13.tokens) {
          state13.output += token.output != null ? token.output : token.value;
          if (token.suffix) {
            state13.output += token.suffix;
          }
        }
      }
      return state13;
    }, "parse");
    parse2.fastpaths = (input, options) => {
      const opts = { ...options };
      const max = typeof opts.maxLength === "number" ? Math.min(MAX_LENGTH, opts.maxLength) : MAX_LENGTH;
      const len = input.length;
      if (len > max) {
        throw new SyntaxError(`Input length: ${len}, exceeds maximum allowed length: ${max}`);
      }
      input = REPLACEMENTS[input] || input;
      const win32 = utils.isWindows(options);
      const {
        DOT_LITERAL,
        SLASH_LITERAL,
        ONE_CHAR,
        DOTS_SLASH,
        NO_DOT,
        NO_DOTS,
        NO_DOTS_SLASH,
        STAR,
        START_ANCHOR
      } = constants3.globChars(win32);
      const nodot = opts.dot ? NO_DOTS : NO_DOT;
      const slashDot = opts.dot ? NO_DOTS_SLASH : NO_DOT;
      const capture = opts.capture ? "" : "?:";
      const state13 = { negated: false, prefix: "" };
      let star = opts.bash === true ? ".*?" : STAR;
      if (opts.capture) {
        star = `(${star})`;
      }
      const globstar = /* @__PURE__ */ __name((opts2) => {
        if (opts2.noglobstar === true) return star;
        return `(${capture}(?:(?!${START_ANCHOR}${opts2.dot ? DOTS_SLASH : DOT_LITERAL}).)*?)`;
      }, "globstar");
      const create = /* @__PURE__ */ __name((str) => {
        switch (str) {
          case "*":
            return `${nodot}${ONE_CHAR}${star}`;
          case ".*":
            return `${DOT_LITERAL}${ONE_CHAR}${star}`;
          case "*.*":
            return `${nodot}${star}${DOT_LITERAL}${ONE_CHAR}${star}`;
          case "*/*":
            return `${nodot}${star}${SLASH_LITERAL}${ONE_CHAR}${slashDot}${star}`;
          case "**":
            return nodot + globstar(opts);
          case "**/*":
            return `(?:${nodot}${globstar(opts)}${SLASH_LITERAL})?${slashDot}${ONE_CHAR}${star}`;
          case "**/*.*":
            return `(?:${nodot}${globstar(opts)}${SLASH_LITERAL})?${slashDot}${star}${DOT_LITERAL}${ONE_CHAR}${star}`;
          case "**/.*":
            return `(?:${nodot}${globstar(opts)}${SLASH_LITERAL})?${DOT_LITERAL}${ONE_CHAR}${star}`;
          default: {
            const match = /^(.*?)\.(\w+)$/.exec(str);
            if (!match) return;
            const source2 = create(match[1]);
            if (!source2) return;
            return source2 + DOT_LITERAL + match[2];
          }
        }
      }, "create");
      const output = utils.removePrefix(input, state13);
      let source = create(output);
      if (source && opts.strictSlashes !== true) {
        source += `${SLASH_LITERAL}?`;
      }
      return source;
    };
    module2.exports = parse2;
  }
});

// ../../node_modules/micromatch/node_modules/picomatch/lib/picomatch.js
var require_picomatch = __commonJS({
  "../../node_modules/micromatch/node_modules/picomatch/lib/picomatch.js"(exports2, module2) {
    "use strict";
    var path47 = require("path");
    var scan = require_scan2();
    var parse2 = require_parse3();
    var utils = require_utils4();
    var constants3 = require_constants3();
    var isObject3 = /* @__PURE__ */ __name((val) => val && typeof val === "object" && !Array.isArray(val), "isObject");
    var picomatch6 = /* @__PURE__ */ __name((glob, options, returnState = false) => {
      if (Array.isArray(glob)) {
        const fns = glob.map((input) => picomatch6(input, options, returnState));
        const arrayMatcher = /* @__PURE__ */ __name((str) => {
          for (const isMatch of fns) {
            const state14 = isMatch(str);
            if (state14) return state14;
          }
          return false;
        }, "arrayMatcher");
        return arrayMatcher;
      }
      const isState = isObject3(glob) && glob.tokens && glob.input;
      if (glob === "" || typeof glob !== "string" && !isState) {
        throw new TypeError("Expected pattern to be a non-empty string");
      }
      const opts = options || {};
      const posix = utils.isWindows(options);
      const regex = isState ? picomatch6.compileRe(glob, options) : picomatch6.makeRe(glob, options, false, true);
      const state13 = regex.state;
      delete regex.state;
      let isIgnored = /* @__PURE__ */ __name(() => false, "isIgnored");
      if (opts.ignore) {
        const ignoreOpts = { ...options, ignore: null, onMatch: null, onResult: null };
        isIgnored = picomatch6(opts.ignore, ignoreOpts, returnState);
      }
      const matcher = /* @__PURE__ */ __name((input, returnObject = false) => {
        const { isMatch, match, output } = picomatch6.test(input, regex, options, { glob, posix });
        const result2 = { glob, state: state13, regex, posix, input, output, match, isMatch };
        if (typeof opts.onResult === "function") {
          opts.onResult(result2);
        }
        if (isMatch === false) {
          result2.isMatch = false;
          return returnObject ? result2 : false;
        }
        if (isIgnored(input)) {
          if (typeof opts.onIgnore === "function") {
            opts.onIgnore(result2);
          }
          result2.isMatch = false;
          return returnObject ? result2 : false;
        }
        if (typeof opts.onMatch === "function") {
          opts.onMatch(result2);
        }
        return returnObject ? result2 : true;
      }, "matcher");
      if (returnState) {
        matcher.state = state13;
      }
      return matcher;
    }, "picomatch");
    picomatch6.test = (input, regex, options, { glob, posix } = {}) => {
      if (typeof input !== "string") {
        throw new TypeError("Expected input to be a string");
      }
      if (input === "") {
        return { isMatch: false, output: "" };
      }
      const opts = options || {};
      const format32 = opts.format || (posix ? utils.toPosixSlashes : null);
      let match = input === glob;
      let output = match && format32 ? format32(input) : input;
      if (match === false) {
        output = format32 ? format32(input) : input;
        match = output === glob;
      }
      if (match === false || opts.capture === true) {
        if (opts.matchBase === true || opts.basename === true) {
          match = picomatch6.matchBase(input, regex, options, posix);
        } else {
          match = regex.exec(output);
        }
      }
      return { isMatch: Boolean(match), match, output };
    };
    picomatch6.matchBase = (input, glob, options, posix = utils.isWindows(options)) => {
      const regex = glob instanceof RegExp ? glob : picomatch6.makeRe(glob, options);
      return regex.test(path47.basename(input));
    };
    picomatch6.isMatch = (str, patterns, options) => picomatch6(patterns, options)(str);
    picomatch6.parse = (pattern, options) => {
      if (Array.isArray(pattern)) return pattern.map((p10) => picomatch6.parse(p10, options));
      return parse2(pattern, { ...options, fastpaths: false });
    };
    picomatch6.scan = (input, options) => scan(input, options);
    picomatch6.compileRe = (state13, options, returnOutput = false, returnState = false) => {
      if (returnOutput === true) {
        return state13.output;
      }
      const opts = options || {};
      const prepend = opts.contains ? "" : "^";
      const append = opts.contains ? "" : "$";
      let source = `${prepend}(?:${state13.output})${append}`;
      if (state13 && state13.negated === true) {
        source = `^(?!${source}).*$`;
      }
      const regex = picomatch6.toRegex(source, options);
      if (returnState === true) {
        regex.state = state13;
      }
      return regex;
    };
    picomatch6.makeRe = (input, options = {}, returnOutput = false, returnState = false) => {
      if (!input || typeof input !== "string") {
        throw new TypeError("Expected a non-empty string");
      }
      let parsed = { negated: false, fastpaths: true };
      if (options.fastpaths !== false && (input[0] === "." || input[0] === "*")) {
        parsed.output = parse2.fastpaths(input, options);
      }
      if (!parsed.output) {
        parsed = parse2(input, options);
      }
      return picomatch6.compileRe(parsed, options, returnOutput, returnState);
    };
    picomatch6.toRegex = (source, options) => {
      try {
        const opts = options || {};
        return new RegExp(source, opts.flags || (opts.nocase ? "i" : ""));
      } catch (err) {
        if (options && options.debug === true) throw err;
        return /$^/;
      }
    };
    picomatch6.constants = constants3;
    module2.exports = picomatch6;
  }
});

// ../../node_modules/micromatch/node_modules/picomatch/index.js
var require_picomatch2 = __commonJS({
  "../../node_modules/micromatch/node_modules/picomatch/index.js"(exports2, module2) {
    "use strict";
    module2.exports = require_picomatch();
  }
});

// ../../node_modules/micromatch/index.js
var require_micromatch = __commonJS({
  "../../node_modules/micromatch/index.js"(exports2, module2) {
    "use strict";
    var util11 = require("util");
    var braces = require_braces();
    var picomatch6 = require_picomatch2();
    var utils = require_utils4();
    var isEmptyString = /* @__PURE__ */ __name((v) => v === "" || v === "./", "isEmptyString");
    var hasBraces = /* @__PURE__ */ __name((v) => {
      const index = v.indexOf("{");
      return index > -1 && v.indexOf("}", index) > -1;
    }, "hasBraces");
    var micromatch = /* @__PURE__ */ __name((list3, patterns, options) => {
      patterns = [].concat(patterns);
      list3 = [].concat(list3);
      let omit = /* @__PURE__ */ new Set();
      let keep = /* @__PURE__ */ new Set();
      let items = /* @__PURE__ */ new Set();
      let negatives = 0;
      let onResult = /* @__PURE__ */ __name((state13) => {
        items.add(state13.output);
        if (options && options.onResult) {
          options.onResult(state13);
        }
      }, "onResult");
      for (let i32 = 0; i32 < patterns.length; i32++) {
        let isMatch = picomatch6(String(patterns[i32]), { ...options, onResult }, true);
        let negated = isMatch.state.negated || isMatch.state.negatedExtglob;
        if (negated) negatives++;
        for (let item of list3) {
          let matched = isMatch(item, true);
          let match = negated ? !matched.isMatch : matched.isMatch;
          if (!match) continue;
          if (negated) {
            omit.add(matched.output);
          } else {
            omit.delete(matched.output);
            keep.add(matched.output);
          }
        }
      }
      let result2 = negatives === patterns.length ? [...items] : [...keep];
      let matches = result2.filter((item) => !omit.has(item));
      if (options && matches.length === 0) {
        if (options.failglob === true) {
          throw new Error(`No matches found for "${patterns.join(", ")}"`);
        }
        if (options.nonull === true || options.nullglob === true) {
          return options.unescape ? patterns.map((p10) => p10.replace(/\\/g, "")) : patterns;
        }
      }
      return matches;
    }, "micromatch");
    micromatch.match = micromatch;
    micromatch.matcher = (pattern, options) => picomatch6(pattern, options);
    micromatch.isMatch = (str, patterns, options) => picomatch6(patterns, options)(str);
    micromatch.any = micromatch.isMatch;
    micromatch.not = (list3, patterns, options = {}) => {
      patterns = [].concat(patterns).map(String);
      let result2 = /* @__PURE__ */ new Set();
      let items = [];
      let onResult = /* @__PURE__ */ __name((state13) => {
        if (options.onResult) options.onResult(state13);
        items.push(state13.output);
      }, "onResult");
      let matches = new Set(micromatch(list3, patterns, { ...options, onResult }));
      for (let item of items) {
        if (!matches.has(item)) {
          result2.add(item);
        }
      }
      return [...result2];
    };
    micromatch.contains = (str, pattern, options) => {
      if (typeof str !== "string") {
        throw new TypeError(`Expected a string: "${util11.inspect(str)}"`);
      }
      if (Array.isArray(pattern)) {
        return pattern.some((p10) => micromatch.contains(str, p10, options));
      }
      if (typeof pattern === "string") {
        if (isEmptyString(str) || isEmptyString(pattern)) {
          return false;
        }
        if (str.includes(pattern) || str.startsWith("./") && str.slice(2).includes(pattern)) {
          return true;
        }
      }
      return micromatch.isMatch(str, pattern, { ...options, contains: true });
    };
    micromatch.matchKeys = (obj, patterns, options) => {
      if (!utils.isObject(obj)) {
        throw new TypeError("Expected the first argument to be an object");
      }
      let keys = micromatch(Object.keys(obj), patterns, options);
      let res = {};
      for (let key of keys) res[key] = obj[key];
      return res;
    };
    micromatch.some = (list3, patterns, options) => {
      let items = [].concat(list3);
      for (let pattern of [].concat(patterns)) {
        let isMatch = picomatch6(String(pattern), options);
        if (items.some((item) => isMatch(item))) {
          return true;
        }
      }
      return false;
    };
    micromatch.every = (list3, patterns, options) => {
      let items = [].concat(list3);
      for (let pattern of [].concat(patterns)) {
        let isMatch = picomatch6(String(pattern), options);
        if (!items.every((item) => isMatch(item))) {
          return false;
        }
      }
      return true;
    };
    micromatch.all = (str, patterns, options) => {
      if (typeof str !== "string") {
        throw new TypeError(`Expected a string: "${util11.inspect(str)}"`);
      }
      return [].concat(patterns).every((p10) => picomatch6(p10, options)(str));
    };
    micromatch.capture = (glob, input, options) => {
      let posix = utils.isWindows(options);
      let regex = picomatch6.makeRe(String(glob), { ...options, capture: true });
      let match = regex.exec(posix ? utils.toPosixSlashes(input) : input);
      if (match) {
        return match.slice(1).map((v) => v === void 0 ? "" : v);
      }
    };
    micromatch.makeRe = (...args) => picomatch6.makeRe(...args);
    micromatch.scan = (...args) => picomatch6.scan(...args);
    micromatch.parse = (patterns, options) => {
      let res = [];
      for (let pattern of [].concat(patterns || [])) {
        for (let str of braces(String(pattern), options)) {
          res.push(picomatch6.parse(str, options));
        }
      }
      return res;
    };
    micromatch.braces = (pattern, options) => {
      if (typeof pattern !== "string") throw new TypeError("Expected a string");
      if (options && options.nobrace === true || !hasBraces(pattern)) {
        return [pattern];
      }
      return braces(pattern, options);
    };
    micromatch.braceExpand = (pattern, options) => {
      if (typeof pattern !== "string") throw new TypeError("Expected a string");
      return micromatch.braces(pattern, { ...options, expand: true });
    };
    micromatch.hasBraces = hasBraces;
    module2.exports = micromatch;
  }
});

// ../../node_modules/fast-glob/out/utils/pattern.js
var require_pattern = __commonJS({
  "../../node_modules/fast-glob/out/utils/pattern.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isAbsolute = exports2.partitionAbsoluteAndRelative = exports2.removeDuplicateSlashes = exports2.matchAny = exports2.convertPatternsToRe = exports2.makeRe = exports2.getPatternParts = exports2.expandBraceExpansion = exports2.expandPatternsWithBraceExpansion = exports2.isAffectDepthOfReadingPattern = exports2.endsWithSlashGlobStar = exports2.hasGlobStar = exports2.getBaseDirectory = exports2.isPatternRelatedToParentDirectory = exports2.getPatternsOutsideCurrentDirectory = exports2.getPatternsInsideCurrentDirectory = exports2.getPositivePatterns = exports2.getNegativePatterns = exports2.isPositivePattern = exports2.isNegativePattern = exports2.convertToNegativePattern = exports2.convertToPositivePattern = exports2.isDynamicPattern = exports2.isStaticPattern = void 0;
    var path47 = require("path");
    var globParent = require_glob_parent();
    var micromatch = require_micromatch();
    var GLOBSTAR = "**";
    var ESCAPE_SYMBOL = "\\";
    var COMMON_GLOB_SYMBOLS_RE = /[*?]|^!/;
    var REGEX_CHARACTER_CLASS_SYMBOLS_RE = /\[[^[]*]/;
    var REGEX_GROUP_SYMBOLS_RE = /(?:^|[^!*+?@])\([^(]*\|[^|]*\)/;
    var GLOB_EXTENSION_SYMBOLS_RE = /[!*+?@]\([^(]*\)/;
    var BRACE_EXPANSION_SEPARATORS_RE = /,|\.\./;
    var DOUBLE_SLASH_RE2 = /(?!^)\/{2,}/g;
    function isStaticPattern(pattern, options = {}) {
      return !isDynamicPattern(pattern, options);
    }
    __name(isStaticPattern, "isStaticPattern");
    exports2.isStaticPattern = isStaticPattern;
    function isDynamicPattern(pattern, options = {}) {
      if (pattern === "") {
        return false;
      }
      if (options.caseSensitiveMatch === false || pattern.includes(ESCAPE_SYMBOL)) {
        return true;
      }
      if (COMMON_GLOB_SYMBOLS_RE.test(pattern) || REGEX_CHARACTER_CLASS_SYMBOLS_RE.test(pattern) || REGEX_GROUP_SYMBOLS_RE.test(pattern)) {
        return true;
      }
      if (options.extglob !== false && GLOB_EXTENSION_SYMBOLS_RE.test(pattern)) {
        return true;
      }
      if (options.braceExpansion !== false && hasBraceExpansion(pattern)) {
        return true;
      }
      return false;
    }
    __name(isDynamicPattern, "isDynamicPattern");
    exports2.isDynamicPattern = isDynamicPattern;
    function hasBraceExpansion(pattern) {
      const openingBraceIndex = pattern.indexOf("{");
      if (openingBraceIndex === -1) {
        return false;
      }
      const closingBraceIndex = pattern.indexOf("}", openingBraceIndex + 1);
      if (closingBraceIndex === -1) {
        return false;
      }
      const braceContent = pattern.slice(openingBraceIndex, closingBraceIndex);
      return BRACE_EXPANSION_SEPARATORS_RE.test(braceContent);
    }
    __name(hasBraceExpansion, "hasBraceExpansion");
    function convertToPositivePattern(pattern) {
      return isNegativePattern(pattern) ? pattern.slice(1) : pattern;
    }
    __name(convertToPositivePattern, "convertToPositivePattern");
    exports2.convertToPositivePattern = convertToPositivePattern;
    function convertToNegativePattern(pattern) {
      return "!" + pattern;
    }
    __name(convertToNegativePattern, "convertToNegativePattern");
    exports2.convertToNegativePattern = convertToNegativePattern;
    function isNegativePattern(pattern) {
      return pattern.startsWith("!") && pattern[1] !== "(";
    }
    __name(isNegativePattern, "isNegativePattern");
    exports2.isNegativePattern = isNegativePattern;
    function isPositivePattern(pattern) {
      return !isNegativePattern(pattern);
    }
    __name(isPositivePattern, "isPositivePattern");
    exports2.isPositivePattern = isPositivePattern;
    function getNegativePatterns(patterns) {
      return patterns.filter(isNegativePattern);
    }
    __name(getNegativePatterns, "getNegativePatterns");
    exports2.getNegativePatterns = getNegativePatterns;
    function getPositivePatterns(patterns) {
      return patterns.filter(isPositivePattern);
    }
    __name(getPositivePatterns, "getPositivePatterns");
    exports2.getPositivePatterns = getPositivePatterns;
    function getPatternsInsideCurrentDirectory(patterns) {
      return patterns.filter((pattern) => !isPatternRelatedToParentDirectory(pattern));
    }
    __name(getPatternsInsideCurrentDirectory, "getPatternsInsideCurrentDirectory");
    exports2.getPatternsInsideCurrentDirectory = getPatternsInsideCurrentDirectory;
    function getPatternsOutsideCurrentDirectory(patterns) {
      return patterns.filter(isPatternRelatedToParentDirectory);
    }
    __name(getPatternsOutsideCurrentDirectory, "getPatternsOutsideCurrentDirectory");
    exports2.getPatternsOutsideCurrentDirectory = getPatternsOutsideCurrentDirectory;
    function isPatternRelatedToParentDirectory(pattern) {
      return pattern.startsWith("..") || pattern.startsWith("./..");
    }
    __name(isPatternRelatedToParentDirectory, "isPatternRelatedToParentDirectory");
    exports2.isPatternRelatedToParentDirectory = isPatternRelatedToParentDirectory;
    function getBaseDirectory(pattern) {
      return globParent(pattern, { flipBackslashes: false });
    }
    __name(getBaseDirectory, "getBaseDirectory");
    exports2.getBaseDirectory = getBaseDirectory;
    function hasGlobStar(pattern) {
      return pattern.includes(GLOBSTAR);
    }
    __name(hasGlobStar, "hasGlobStar");
    exports2.hasGlobStar = hasGlobStar;
    function endsWithSlashGlobStar(pattern) {
      return pattern.endsWith("/" + GLOBSTAR);
    }
    __name(endsWithSlashGlobStar, "endsWithSlashGlobStar");
    exports2.endsWithSlashGlobStar = endsWithSlashGlobStar;
    function isAffectDepthOfReadingPattern(pattern) {
      const basename5 = path47.basename(pattern);
      return endsWithSlashGlobStar(pattern) || isStaticPattern(basename5);
    }
    __name(isAffectDepthOfReadingPattern, "isAffectDepthOfReadingPattern");
    exports2.isAffectDepthOfReadingPattern = isAffectDepthOfReadingPattern;
    function expandPatternsWithBraceExpansion(patterns) {
      return patterns.reduce((collection, pattern) => {
        return collection.concat(expandBraceExpansion(pattern));
      }, []);
    }
    __name(expandPatternsWithBraceExpansion, "expandPatternsWithBraceExpansion");
    exports2.expandPatternsWithBraceExpansion = expandPatternsWithBraceExpansion;
    function expandBraceExpansion(pattern) {
      const patterns = micromatch.braces(pattern, { expand: true, nodupes: true, keepEscaping: true });
      patterns.sort((a32, b32) => a32.length - b32.length);
      return patterns.filter((pattern2) => pattern2 !== "");
    }
    __name(expandBraceExpansion, "expandBraceExpansion");
    exports2.expandBraceExpansion = expandBraceExpansion;
    function getPatternParts(pattern, options) {
      let { parts } = micromatch.scan(pattern, Object.assign(Object.assign({}, options), { parts: true }));
      if (parts.length === 0) {
        parts = [pattern];
      }
      if (parts[0].startsWith("/")) {
        parts[0] = parts[0].slice(1);
        parts.unshift("");
      }
      return parts;
    }
    __name(getPatternParts, "getPatternParts");
    exports2.getPatternParts = getPatternParts;
    function makeRe(pattern, options) {
      return micromatch.makeRe(pattern, options);
    }
    __name(makeRe, "makeRe");
    exports2.makeRe = makeRe;
    function convertPatternsToRe(patterns, options) {
      return patterns.map((pattern) => makeRe(pattern, options));
    }
    __name(convertPatternsToRe, "convertPatternsToRe");
    exports2.convertPatternsToRe = convertPatternsToRe;
    function matchAny(entry, patternsRe) {
      return patternsRe.some((patternRe) => patternRe.test(entry));
    }
    __name(matchAny, "matchAny");
    exports2.matchAny = matchAny;
    function removeDuplicateSlashes(pattern) {
      return pattern.replace(DOUBLE_SLASH_RE2, "/");
    }
    __name(removeDuplicateSlashes, "removeDuplicateSlashes");
    exports2.removeDuplicateSlashes = removeDuplicateSlashes;
    function partitionAbsoluteAndRelative(patterns) {
      const absolute = [];
      const relative5 = [];
      for (const pattern of patterns) {
        if (isAbsolute3(pattern)) {
          absolute.push(pattern);
        } else {
          relative5.push(pattern);
        }
      }
      return [absolute, relative5];
    }
    __name(partitionAbsoluteAndRelative, "partitionAbsoluteAndRelative");
    exports2.partitionAbsoluteAndRelative = partitionAbsoluteAndRelative;
    function isAbsolute3(pattern) {
      return path47.isAbsolute(pattern);
    }
    __name(isAbsolute3, "isAbsolute");
    exports2.isAbsolute = isAbsolute3;
  }
});

// ../../node_modules/merge2/index.js
var require_merge2 = __commonJS({
  "../../node_modules/merge2/index.js"(exports2, module2) {
    "use strict";
    var Stream = require("stream");
    var PassThrough3 = Stream.PassThrough;
    var slice = Array.prototype.slice;
    module2.exports = merge22;
    function merge22() {
      const streamsQueue = [];
      const args = slice.call(arguments);
      let merging = false;
      let options = args[args.length - 1];
      if (options && !Array.isArray(options) && options.pipe == null) {
        args.pop();
      } else {
        options = {};
      }
      const doEnd = options.end !== false;
      const doPipeError = options.pipeError === true;
      if (options.objectMode == null) {
        options.objectMode = true;
      }
      if (options.highWaterMark == null) {
        options.highWaterMark = 64 * 1024;
      }
      const mergedStream = PassThrough3(options);
      function addStream() {
        for (let i32 = 0, len = arguments.length; i32 < len; i32++) {
          streamsQueue.push(pauseStreams(arguments[i32], options));
        }
        mergeStream();
        return this;
      }
      __name(addStream, "addStream");
      function mergeStream() {
        if (merging) {
          return;
        }
        merging = true;
        let streams = streamsQueue.shift();
        if (!streams) {
          process.nextTick(endStream);
          return;
        }
        if (!Array.isArray(streams)) {
          streams = [streams];
        }
        let pipesCount = streams.length + 1;
        function next() {
          if (--pipesCount > 0) {
            return;
          }
          merging = false;
          mergeStream();
        }
        __name(next, "next");
        function pipe(stream) {
          function onend() {
            stream.removeListener("merge2UnpipeEnd", onend);
            stream.removeListener("end", onend);
            if (doPipeError) {
              stream.removeListener("error", onerror);
            }
            next();
          }
          __name(onend, "onend");
          function onerror(err) {
            mergedStream.emit("error", err);
          }
          __name(onerror, "onerror");
          if (stream._readableState.endEmitted) {
            return next();
          }
          stream.on("merge2UnpipeEnd", onend);
          stream.on("end", onend);
          if (doPipeError) {
            stream.on("error", onerror);
          }
          stream.pipe(mergedStream, { end: false });
          stream.resume();
        }
        __name(pipe, "pipe");
        for (let i32 = 0; i32 < streams.length; i32++) {
          pipe(streams[i32]);
        }
        next();
      }
      __name(mergeStream, "mergeStream");
      function endStream() {
        merging = false;
        mergedStream.emit("queueDrain");
        if (doEnd) {
          mergedStream.end();
        }
      }
      __name(endStream, "endStream");
      mergedStream.setMaxListeners(0);
      mergedStream.add = addStream;
      mergedStream.on("unpipe", function(stream) {
        stream.emit("merge2UnpipeEnd");
      });
      if (args.length) {
        addStream.apply(null, args);
      }
      return mergedStream;
    }
    __name(merge22, "merge2");
    function pauseStreams(streams, options) {
      if (!Array.isArray(streams)) {
        if (!streams._readableState && streams.pipe) {
          streams = streams.pipe(PassThrough3(options));
        }
        if (!streams._readableState || !streams.pause || !streams.pipe) {
          throw new Error("Only readable stream can be merged.");
        }
        streams.pause();
      } else {
        for (let i32 = 0, len = streams.length; i32 < len; i32++) {
          streams[i32] = pauseStreams(streams[i32], options);
        }
      }
      return streams;
    }
    __name(pauseStreams, "pauseStreams");
  }
});

// ../../node_modules/fast-glob/out/utils/stream.js
var require_stream = __commonJS({
  "../../node_modules/fast-glob/out/utils/stream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.merge = void 0;
    var merge22 = require_merge2();
    function merge3(streams) {
      const mergedStream = merge22(streams);
      streams.forEach((stream) => {
        stream.once("error", (error4) => mergedStream.emit("error", error4));
      });
      mergedStream.once("close", () => propagateCloseEventToSources(streams));
      mergedStream.once("end", () => propagateCloseEventToSources(streams));
      return mergedStream;
    }
    __name(merge3, "merge");
    exports2.merge = merge3;
    function propagateCloseEventToSources(streams) {
      streams.forEach((stream) => stream.emit("close"));
    }
    __name(propagateCloseEventToSources, "propagateCloseEventToSources");
  }
});

// ../../node_modules/fast-glob/out/utils/string.js
var require_string = __commonJS({
  "../../node_modules/fast-glob/out/utils/string.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isEmpty = exports2.isString = void 0;
    function isString(input) {
      return typeof input === "string";
    }
    __name(isString, "isString");
    exports2.isString = isString;
    function isEmpty(input) {
      return input === "";
    }
    __name(isEmpty, "isEmpty");
    exports2.isEmpty = isEmpty;
  }
});

// ../../node_modules/fast-glob/out/utils/index.js
var require_utils5 = __commonJS({
  "../../node_modules/fast-glob/out/utils/index.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.string = exports2.stream = exports2.pattern = exports2.path = exports2.fs = exports2.errno = exports2.array = void 0;
    var array = require_array();
    exports2.array = array;
    var errno = require_errno();
    exports2.errno = errno;
    var fs51 = require_fs2();
    exports2.fs = fs51;
    var path47 = require_path();
    exports2.path = path47;
    var pattern = require_pattern();
    exports2.pattern = pattern;
    var stream = require_stream();
    exports2.stream = stream;
    var string = require_string();
    exports2.string = string;
  }
});

// ../../node_modules/fast-glob/out/managers/tasks.js
var require_tasks = __commonJS({
  "../../node_modules/fast-glob/out/managers/tasks.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.convertPatternGroupToTask = exports2.convertPatternGroupsToTasks = exports2.groupPatternsByBaseDirectory = exports2.getNegativePatternsAsPositive = exports2.getPositivePatterns = exports2.convertPatternsToTasks = exports2.generate = void 0;
    var utils = require_utils5();
    function generate(input, settings) {
      const patterns = processPatterns(input, settings);
      const ignore2 = processPatterns(settings.ignore, settings);
      const positivePatterns = getPositivePatterns(patterns);
      const negativePatterns = getNegativePatternsAsPositive(patterns, ignore2);
      const staticPatterns = positivePatterns.filter((pattern) => utils.pattern.isStaticPattern(pattern, settings));
      const dynamicPatterns = positivePatterns.filter((pattern) => utils.pattern.isDynamicPattern(pattern, settings));
      const staticTasks = convertPatternsToTasks(
        staticPatterns,
        negativePatterns,
        /* dynamic */
        false
      );
      const dynamicTasks = convertPatternsToTasks(
        dynamicPatterns,
        negativePatterns,
        /* dynamic */
        true
      );
      return staticTasks.concat(dynamicTasks);
    }
    __name(generate, "generate");
    exports2.generate = generate;
    function processPatterns(input, settings) {
      let patterns = input;
      if (settings.braceExpansion) {
        patterns = utils.pattern.expandPatternsWithBraceExpansion(patterns);
      }
      if (settings.baseNameMatch) {
        patterns = patterns.map((pattern) => pattern.includes("/") ? pattern : `**/${pattern}`);
      }
      return patterns.map((pattern) => utils.pattern.removeDuplicateSlashes(pattern));
    }
    __name(processPatterns, "processPatterns");
    function convertPatternsToTasks(positive, negative, dynamic) {
      const tasks = [];
      const patternsOutsideCurrentDirectory = utils.pattern.getPatternsOutsideCurrentDirectory(positive);
      const patternsInsideCurrentDirectory = utils.pattern.getPatternsInsideCurrentDirectory(positive);
      const outsideCurrentDirectoryGroup = groupPatternsByBaseDirectory(patternsOutsideCurrentDirectory);
      const insideCurrentDirectoryGroup = groupPatternsByBaseDirectory(patternsInsideCurrentDirectory);
      tasks.push(...convertPatternGroupsToTasks(outsideCurrentDirectoryGroup, negative, dynamic));
      if ("." in insideCurrentDirectoryGroup) {
        tasks.push(convertPatternGroupToTask(".", patternsInsideCurrentDirectory, negative, dynamic));
      } else {
        tasks.push(...convertPatternGroupsToTasks(insideCurrentDirectoryGroup, negative, dynamic));
      }
      return tasks;
    }
    __name(convertPatternsToTasks, "convertPatternsToTasks");
    exports2.convertPatternsToTasks = convertPatternsToTasks;
    function getPositivePatterns(patterns) {
      return utils.pattern.getPositivePatterns(patterns);
    }
    __name(getPositivePatterns, "getPositivePatterns");
    exports2.getPositivePatterns = getPositivePatterns;
    function getNegativePatternsAsPositive(patterns, ignore2) {
      const negative = utils.pattern.getNegativePatterns(patterns).concat(ignore2);
      const positive = negative.map(utils.pattern.convertToPositivePattern);
      return positive;
    }
    __name(getNegativePatternsAsPositive, "getNegativePatternsAsPositive");
    exports2.getNegativePatternsAsPositive = getNegativePatternsAsPositive;
    function groupPatternsByBaseDirectory(patterns) {
      const group7 = {};
      return patterns.reduce((collection, pattern) => {
        const base = utils.pattern.getBaseDirectory(pattern);
        if (base in collection) {
          collection[base].push(pattern);
        } else {
          collection[base] = [pattern];
        }
        return collection;
      }, group7);
    }
    __name(groupPatternsByBaseDirectory, "groupPatternsByBaseDirectory");
    exports2.groupPatternsByBaseDirectory = groupPatternsByBaseDirectory;
    function convertPatternGroupsToTasks(positive, negative, dynamic) {
      return Object.keys(positive).map((base) => {
        return convertPatternGroupToTask(base, positive[base], negative, dynamic);
      });
    }
    __name(convertPatternGroupsToTasks, "convertPatternGroupsToTasks");
    exports2.convertPatternGroupsToTasks = convertPatternGroupsToTasks;
    function convertPatternGroupToTask(base, positive, negative, dynamic) {
      return {
        dynamic,
        positive,
        negative,
        base,
        patterns: [].concat(positive, negative.map(utils.pattern.convertToNegativePattern))
      };
    }
    __name(convertPatternGroupToTask, "convertPatternGroupToTask");
    exports2.convertPatternGroupToTask = convertPatternGroupToTask;
  }
});

// ../../node_modules/@nodelib/fs.stat/out/providers/async.js
var require_async2 = __commonJS({
  "../../node_modules/@nodelib/fs.stat/out/providers/async.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.read = void 0;
    function read(path47, settings, callback) {
      settings.fs.lstat(path47, (lstatError, lstat3) => {
        if (lstatError !== null) {
          callFailureCallback(callback, lstatError);
          return;
        }
        if (!lstat3.isSymbolicLink() || !settings.followSymbolicLink) {
          callSuccessCallback(callback, lstat3);
          return;
        }
        settings.fs.stat(path47, (statError, stat8) => {
          if (statError !== null) {
            if (settings.throwErrorOnBrokenSymbolicLink) {
              callFailureCallback(callback, statError);
              return;
            }
            callSuccessCallback(callback, lstat3);
            return;
          }
          if (settings.markSymbolicLink) {
            stat8.isSymbolicLink = () => true;
          }
          callSuccessCallback(callback, stat8);
        });
      });
    }
    __name(read, "read");
    exports2.read = read;
    function callFailureCallback(callback, error4) {
      callback(error4);
    }
    __name(callFailureCallback, "callFailureCallback");
    function callSuccessCallback(callback, result2) {
      callback(null, result2);
    }
    __name(callSuccessCallback, "callSuccessCallback");
  }
});

// ../../node_modules/@nodelib/fs.stat/out/providers/sync.js
var require_sync = __commonJS({
  "../../node_modules/@nodelib/fs.stat/out/providers/sync.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.read = void 0;
    function read(path47, settings) {
      const lstat3 = settings.fs.lstatSync(path47);
      if (!lstat3.isSymbolicLink() || !settings.followSymbolicLink) {
        return lstat3;
      }
      try {
        const stat8 = settings.fs.statSync(path47);
        if (settings.markSymbolicLink) {
          stat8.isSymbolicLink = () => true;
        }
        return stat8;
      } catch (error4) {
        if (!settings.throwErrorOnBrokenSymbolicLink) {
          return lstat3;
        }
        throw error4;
      }
    }
    __name(read, "read");
    exports2.read = read;
  }
});

// ../../node_modules/@nodelib/fs.stat/out/adapters/fs.js
var require_fs3 = __commonJS({
  "../../node_modules/@nodelib/fs.stat/out/adapters/fs.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createFileSystemAdapter = exports2.FILE_SYSTEM_ADAPTER = void 0;
    var fs51 = require("fs");
    exports2.FILE_SYSTEM_ADAPTER = {
      lstat: fs51.lstat,
      stat: fs51.stat,
      lstatSync: fs51.lstatSync,
      statSync: fs51.statSync
    };
    function createFileSystemAdapter(fsMethods) {
      if (fsMethods === void 0) {
        return exports2.FILE_SYSTEM_ADAPTER;
      }
      return Object.assign(Object.assign({}, exports2.FILE_SYSTEM_ADAPTER), fsMethods);
    }
    __name(createFileSystemAdapter, "createFileSystemAdapter");
    exports2.createFileSystemAdapter = createFileSystemAdapter;
  }
});

// ../../node_modules/@nodelib/fs.stat/out/settings.js
var require_settings = __commonJS({
  "../../node_modules/@nodelib/fs.stat/out/settings.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var fs51 = require_fs3();
    var Settings2 = class {
      static {
        __name(this, "Settings");
      }
      constructor(_options = {}) {
        this._options = _options;
        this.followSymbolicLink = this._getValue(this._options.followSymbolicLink, true);
        this.fs = fs51.createFileSystemAdapter(this._options.fs);
        this.markSymbolicLink = this._getValue(this._options.markSymbolicLink, false);
        this.throwErrorOnBrokenSymbolicLink = this._getValue(this._options.throwErrorOnBrokenSymbolicLink, true);
      }
      _getValue(option, value) {
        return option !== null && option !== void 0 ? option : value;
      }
    };
    exports2.default = Settings2;
  }
});

// ../../node_modules/@nodelib/fs.stat/out/index.js
var require_out = __commonJS({
  "../../node_modules/@nodelib/fs.stat/out/index.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.statSync = exports2.stat = exports2.Settings = void 0;
    var async = require_async2();
    var sync = require_sync();
    var settings_1 = require_settings();
    exports2.Settings = settings_1.default;
    function stat8(path47, optionsOrSettingsOrCallback, callback) {
      if (typeof optionsOrSettingsOrCallback === "function") {
        async.read(path47, getSettings(), optionsOrSettingsOrCallback);
        return;
      }
      async.read(path47, getSettings(optionsOrSettingsOrCallback), callback);
    }
    __name(stat8, "stat");
    exports2.stat = stat8;
    function statSync3(path47, optionsOrSettings) {
      const settings = getSettings(optionsOrSettings);
      return sync.read(path47, settings);
    }
    __name(statSync3, "statSync");
    exports2.statSync = statSync3;
    function getSettings(settingsOrOptions = {}) {
      if (settingsOrOptions instanceof settings_1.default) {
        return settingsOrOptions;
      }
      return new settings_1.default(settingsOrOptions);
    }
    __name(getSettings, "getSettings");
  }
});

// ../../node_modules/queue-microtask/index.js
var require_queue_microtask = __commonJS({
  "../../node_modules/queue-microtask/index.js"(exports2, module2) {
    var promise;
    module2.exports = typeof queueMicrotask === "function" ? queueMicrotask.bind(typeof window !== "undefined" ? window : global) : (cb) => (promise || (promise = Promise.resolve())).then(cb).catch((err) => setTimeout(() => {
      throw err;
    }, 0));
  }
});

// ../../node_modules/run-parallel/index.js
var require_run_parallel = __commonJS({
  "../../node_modules/run-parallel/index.js"(exports2, module2) {
    module2.exports = runParallel;
    var queueMicrotask2 = require_queue_microtask();
    function runParallel(tasks, cb) {
      let results, pending, keys;
      let isSync = true;
      if (Array.isArray(tasks)) {
        results = [];
        pending = tasks.length;
      } else {
        keys = Object.keys(tasks);
        results = {};
        pending = keys.length;
      }
      function done(err) {
        function end() {
          if (cb) cb(err, results);
          cb = null;
        }
        __name(end, "end");
        if (isSync) queueMicrotask2(end);
        else end();
      }
      __name(done, "done");
      function each(i32, err, result2) {
        results[i32] = result2;
        if (--pending === 0 || err) {
          done(err);
        }
      }
      __name(each, "each");
      if (!pending) {
        done(null);
      } else if (keys) {
        keys.forEach(function(key) {
          tasks[key](function(err, result2) {
            each(key, err, result2);
          });
        });
      } else {
        tasks.forEach(function(task, i32) {
          task(function(err, result2) {
            each(i32, err, result2);
          });
        });
      }
      isSync = false;
    }
    __name(runParallel, "runParallel");
  }
});

// ../../node_modules/@nodelib/fs.scandir/out/constants.js
var require_constants4 = __commonJS({
  "../../node_modules/@nodelib/fs.scandir/out/constants.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.IS_SUPPORT_READDIR_WITH_FILE_TYPES = void 0;
    var NODE_PROCESS_VERSION_PARTS = process.versions.node.split(".");
    if (NODE_PROCESS_VERSION_PARTS[0] === void 0 || NODE_PROCESS_VERSION_PARTS[1] === void 0) {
      throw new Error(`Unexpected behavior. The 'process.versions.node' variable has invalid value: ${process.versions.node}`);
    }
    var MAJOR_VERSION = Number.parseInt(NODE_PROCESS_VERSION_PARTS[0], 10);
    var MINOR_VERSION = Number.parseInt(NODE_PROCESS_VERSION_PARTS[1], 10);
    var SUPPORTED_MAJOR_VERSION = 10;
    var SUPPORTED_MINOR_VERSION = 10;
    var IS_MATCHED_BY_MAJOR = MAJOR_VERSION > SUPPORTED_MAJOR_VERSION;
    var IS_MATCHED_BY_MAJOR_AND_MINOR = MAJOR_VERSION === SUPPORTED_MAJOR_VERSION && MINOR_VERSION >= SUPPORTED_MINOR_VERSION;
    exports2.IS_SUPPORT_READDIR_WITH_FILE_TYPES = IS_MATCHED_BY_MAJOR || IS_MATCHED_BY_MAJOR_AND_MINOR;
  }
});

// ../../node_modules/@nodelib/fs.scandir/out/utils/fs.js
var require_fs4 = __commonJS({
  "../../node_modules/@nodelib/fs.scandir/out/utils/fs.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createDirentFromStats = void 0;
    var DirentFromStats = class {
      static {
        __name(this, "DirentFromStats");
      }
      constructor(name, stats) {
        this.name = name;
        this.isBlockDevice = stats.isBlockDevice.bind(stats);
        this.isCharacterDevice = stats.isCharacterDevice.bind(stats);
        this.isDirectory = stats.isDirectory.bind(stats);
        this.isFIFO = stats.isFIFO.bind(stats);
        this.isFile = stats.isFile.bind(stats);
        this.isSocket = stats.isSocket.bind(stats);
        this.isSymbolicLink = stats.isSymbolicLink.bind(stats);
      }
    };
    function createDirentFromStats(name, stats) {
      return new DirentFromStats(name, stats);
    }
    __name(createDirentFromStats, "createDirentFromStats");
    exports2.createDirentFromStats = createDirentFromStats;
  }
});

// ../../node_modules/@nodelib/fs.scandir/out/utils/index.js
var require_utils6 = __commonJS({
  "../../node_modules/@nodelib/fs.scandir/out/utils/index.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fs = void 0;
    var fs51 = require_fs4();
    exports2.fs = fs51;
  }
});

// ../../node_modules/@nodelib/fs.scandir/out/providers/common.js
var require_common = __commonJS({
  "../../node_modules/@nodelib/fs.scandir/out/providers/common.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.joinPathSegments = void 0;
    function joinPathSegments(a32, b32, separator) {
      if (a32.endsWith(separator)) {
        return a32 + b32;
      }
      return a32 + separator + b32;
    }
    __name(joinPathSegments, "joinPathSegments");
    exports2.joinPathSegments = joinPathSegments;
  }
});

// ../../node_modules/@nodelib/fs.scandir/out/providers/async.js
var require_async3 = __commonJS({
  "../../node_modules/@nodelib/fs.scandir/out/providers/async.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.readdir = exports2.readdirWithFileTypes = exports2.read = void 0;
    var fsStat = require_out();
    var rpl = require_run_parallel();
    var constants_1 = require_constants4();
    var utils = require_utils6();
    var common = require_common();
    function read(directory, settings, callback) {
      if (!settings.stats && constants_1.IS_SUPPORT_READDIR_WITH_FILE_TYPES) {
        readdirWithFileTypes(directory, settings, callback);
        return;
      }
      readdir5(directory, settings, callback);
    }
    __name(read, "read");
    exports2.read = read;
    function readdirWithFileTypes(directory, settings, callback) {
      settings.fs.readdir(directory, { withFileTypes: true }, (readdirError, dirents) => {
        if (readdirError !== null) {
          callFailureCallback(callback, readdirError);
          return;
        }
        const entries = dirents.map((dirent) => ({
          dirent,
          name: dirent.name,
          path: common.joinPathSegments(directory, dirent.name, settings.pathSegmentSeparator)
        }));
        if (!settings.followSymbolicLinks) {
          callSuccessCallback(callback, entries);
          return;
        }
        const tasks = entries.map((entry) => makeRplTaskEntry(entry, settings));
        rpl(tasks, (rplError, rplEntries) => {
          if (rplError !== null) {
            callFailureCallback(callback, rplError);
            return;
          }
          callSuccessCallback(callback, rplEntries);
        });
      });
    }
    __name(readdirWithFileTypes, "readdirWithFileTypes");
    exports2.readdirWithFileTypes = readdirWithFileTypes;
    function makeRplTaskEntry(entry, settings) {
      return (done) => {
        if (!entry.dirent.isSymbolicLink()) {
          done(null, entry);
          return;
        }
        settings.fs.stat(entry.path, (statError, stats) => {
          if (statError !== null) {
            if (settings.throwErrorOnBrokenSymbolicLink) {
              done(statError);
              return;
            }
            done(null, entry);
            return;
          }
          entry.dirent = utils.fs.createDirentFromStats(entry.name, stats);
          done(null, entry);
        });
      };
    }
    __name(makeRplTaskEntry, "makeRplTaskEntry");
    function readdir5(directory, settings, callback) {
      settings.fs.readdir(directory, (readdirError, names) => {
        if (readdirError !== null) {
          callFailureCallback(callback, readdirError);
          return;
        }
        const tasks = names.map((name) => {
          const path47 = common.joinPathSegments(directory, name, settings.pathSegmentSeparator);
          return (done) => {
            fsStat.stat(path47, settings.fsStatSettings, (error4, stats) => {
              if (error4 !== null) {
                done(error4);
                return;
              }
              const entry = {
                name,
                path: path47,
                dirent: utils.fs.createDirentFromStats(name, stats)
              };
              if (settings.stats) {
                entry.stats = stats;
              }
              done(null, entry);
            });
          };
        });
        rpl(tasks, (rplError, entries) => {
          if (rplError !== null) {
            callFailureCallback(callback, rplError);
            return;
          }
          callSuccessCallback(callback, entries);
        });
      });
    }
    __name(readdir5, "readdir");
    exports2.readdir = readdir5;
    function callFailureCallback(callback, error4) {
      callback(error4);
    }
    __name(callFailureCallback, "callFailureCallback");
    function callSuccessCallback(callback, result2) {
      callback(null, result2);
    }
    __name(callSuccessCallback, "callSuccessCallback");
  }
});

// ../../node_modules/@nodelib/fs.scandir/out/providers/sync.js
var require_sync2 = __commonJS({
  "../../node_modules/@nodelib/fs.scandir/out/providers/sync.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.readdir = exports2.readdirWithFileTypes = exports2.read = void 0;
    var fsStat = require_out();
    var constants_1 = require_constants4();
    var utils = require_utils6();
    var common = require_common();
    function read(directory, settings) {
      if (!settings.stats && constants_1.IS_SUPPORT_READDIR_WITH_FILE_TYPES) {
        return readdirWithFileTypes(directory, settings);
      }
      return readdir5(directory, settings);
    }
    __name(read, "read");
    exports2.read = read;
    function readdirWithFileTypes(directory, settings) {
      const dirents = settings.fs.readdirSync(directory, { withFileTypes: true });
      return dirents.map((dirent) => {
        const entry = {
          dirent,
          name: dirent.name,
          path: common.joinPathSegments(directory, dirent.name, settings.pathSegmentSeparator)
        };
        if (entry.dirent.isSymbolicLink() && settings.followSymbolicLinks) {
          try {
            const stats = settings.fs.statSync(entry.path);
            entry.dirent = utils.fs.createDirentFromStats(entry.name, stats);
          } catch (error4) {
            if (settings.throwErrorOnBrokenSymbolicLink) {
              throw error4;
            }
          }
        }
        return entry;
      });
    }
    __name(readdirWithFileTypes, "readdirWithFileTypes");
    exports2.readdirWithFileTypes = readdirWithFileTypes;
    function readdir5(directory, settings) {
      const names = settings.fs.readdirSync(directory);
      return names.map((name) => {
        const entryPath = common.joinPathSegments(directory, name, settings.pathSegmentSeparator);
        const stats = fsStat.statSync(entryPath, settings.fsStatSettings);
        const entry = {
          name,
          path: entryPath,
          dirent: utils.fs.createDirentFromStats(name, stats)
        };
        if (settings.stats) {
          entry.stats = stats;
        }
        return entry;
      });
    }
    __name(readdir5, "readdir");
    exports2.readdir = readdir5;
  }
});

// ../../node_modules/@nodelib/fs.scandir/out/adapters/fs.js
var require_fs5 = __commonJS({
  "../../node_modules/@nodelib/fs.scandir/out/adapters/fs.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createFileSystemAdapter = exports2.FILE_SYSTEM_ADAPTER = void 0;
    var fs51 = require("fs");
    exports2.FILE_SYSTEM_ADAPTER = {
      lstat: fs51.lstat,
      stat: fs51.stat,
      lstatSync: fs51.lstatSync,
      statSync: fs51.statSync,
      readdir: fs51.readdir,
      readdirSync: fs51.readdirSync
    };
    function createFileSystemAdapter(fsMethods) {
      if (fsMethods === void 0) {
        return exports2.FILE_SYSTEM_ADAPTER;
      }
      return Object.assign(Object.assign({}, exports2.FILE_SYSTEM_ADAPTER), fsMethods);
    }
    __name(createFileSystemAdapter, "createFileSystemAdapter");
    exports2.createFileSystemAdapter = createFileSystemAdapter;
  }
});

// ../../node_modules/@nodelib/fs.scandir/out/settings.js
var require_settings2 = __commonJS({
  "../../node_modules/@nodelib/fs.scandir/out/settings.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var path47 = require("path");
    var fsStat = require_out();
    var fs51 = require_fs5();
    var Settings2 = class {
      static {
        __name(this, "Settings");
      }
      constructor(_options = {}) {
        this._options = _options;
        this.followSymbolicLinks = this._getValue(this._options.followSymbolicLinks, false);
        this.fs = fs51.createFileSystemAdapter(this._options.fs);
        this.pathSegmentSeparator = this._getValue(this._options.pathSegmentSeparator, path47.sep);
        this.stats = this._getValue(this._options.stats, false);
        this.throwErrorOnBrokenSymbolicLink = this._getValue(this._options.throwErrorOnBrokenSymbolicLink, true);
        this.fsStatSettings = new fsStat.Settings({
          followSymbolicLink: this.followSymbolicLinks,
          fs: this.fs,
          throwErrorOnBrokenSymbolicLink: this.throwErrorOnBrokenSymbolicLink
        });
      }
      _getValue(option, value) {
        return option !== null && option !== void 0 ? option : value;
      }
    };
    exports2.default = Settings2;
  }
});

// ../../node_modules/@nodelib/fs.scandir/out/index.js
var require_out2 = __commonJS({
  "../../node_modules/@nodelib/fs.scandir/out/index.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.Settings = exports2.scandirSync = exports2.scandir = void 0;
    var async = require_async3();
    var sync = require_sync2();
    var settings_1 = require_settings2();
    exports2.Settings = settings_1.default;
    function scandir(path47, optionsOrSettingsOrCallback, callback) {
      if (typeof optionsOrSettingsOrCallback === "function") {
        async.read(path47, getSettings(), optionsOrSettingsOrCallback);
        return;
      }
      async.read(path47, getSettings(optionsOrSettingsOrCallback), callback);
    }
    __name(scandir, "scandir");
    exports2.scandir = scandir;
    function scandirSync(path47, optionsOrSettings) {
      const settings = getSettings(optionsOrSettings);
      return sync.read(path47, settings);
    }
    __name(scandirSync, "scandirSync");
    exports2.scandirSync = scandirSync;
    function getSettings(settingsOrOptions = {}) {
      if (settingsOrOptions instanceof settings_1.default) {
        return settingsOrOptions;
      }
      return new settings_1.default(settingsOrOptions);
    }
    __name(getSettings, "getSettings");
  }
});

// ../../node_modules/reusify/reusify.js
var require_reusify = __commonJS({
  "../../node_modules/reusify/reusify.js"(exports2, module2) {
    "use strict";
    function reusify(Constructor) {
      var head = new Constructor();
      var tail = head;
      function get4() {
        var current = head;
        if (current.next) {
          head = current.next;
        } else {
          head = new Constructor();
          tail = head;
        }
        current.next = null;
        return current;
      }
      __name(get4, "get");
      function release3(obj) {
        tail.next = obj;
        tail = obj;
      }
      __name(release3, "release");
      return {
        get: get4,
        release: release3
      };
    }
    __name(reusify, "reusify");
    module2.exports = reusify;
  }
});

// ../../node_modules/fastq/queue.js
var require_queue = __commonJS({
  "../../node_modules/fastq/queue.js"(exports2, module2) {
    "use strict";
    var reusify = require_reusify();
    function fastqueue(context, worker, _concurrency) {
      if (typeof context === "function") {
        _concurrency = worker;
        worker = context;
        context = null;
      }
      if (!(_concurrency >= 1)) {
        throw new Error("fastqueue concurrency must be equal to or greater than 1");
      }
      var cache32 = reusify(Task);
      var queueHead = null;
      var queueTail = null;
      var _running = 0;
      var errorHandler = null;
      var self2 = {
        push,
        drain: noop,
        saturated: noop,
        pause,
        paused: false,
        get concurrency() {
          return _concurrency;
        },
        set concurrency(value) {
          if (!(value >= 1)) {
            throw new Error("fastqueue concurrency must be equal to or greater than 1");
          }
          _concurrency = value;
          if (self2.paused) return;
          for (; queueHead && _running < _concurrency; ) {
            _running++;
            release3();
          }
        },
        running,
        resume,
        idle,
        length,
        getQueue,
        unshift,
        empty: noop,
        kill,
        killAndDrain,
        error: error4,
        abort
      };
      return self2;
      function running() {
        return _running;
      }
      __name(running, "running");
      function pause() {
        self2.paused = true;
      }
      __name(pause, "pause");
      function length() {
        var current = queueHead;
        var counter = 0;
        while (current) {
          current = current.next;
          counter++;
        }
        return counter;
      }
      __name(length, "length");
      function getQueue() {
        var current = queueHead;
        var tasks = [];
        while (current) {
          tasks.push(current.value);
          current = current.next;
        }
        return tasks;
      }
      __name(getQueue, "getQueue");
      function resume() {
        if (!self2.paused) return;
        self2.paused = false;
        if (queueHead === null) {
          _running++;
          release3();
          return;
        }
        for (; queueHead && _running < _concurrency; ) {
          _running++;
          release3();
        }
      }
      __name(resume, "resume");
      function idle() {
        return _running === 0 && self2.length() === 0;
      }
      __name(idle, "idle");
      function push(value, done) {
        var current = cache32.get();
        current.context = context;
        current.release = release3;
        current.value = value;
        current.callback = done || noop;
        current.errorHandler = errorHandler;
        if (_running >= _concurrency || self2.paused) {
          if (queueTail) {
            queueTail.next = current;
            queueTail = current;
          } else {
            queueHead = current;
            queueTail = current;
            self2.saturated();
          }
        } else {
          _running++;
          worker.call(context, current.value, current.worked);
        }
      }
      __name(push, "push");
      function unshift(value, done) {
        var current = cache32.get();
        current.context = context;
        current.release = release3;
        current.value = value;
        current.callback = done || noop;
        current.errorHandler = errorHandler;
        if (_running >= _concurrency || self2.paused) {
          if (queueHead) {
            current.next = queueHead;
            queueHead = current;
          } else {
            queueHead = current;
            queueTail = current;
            self2.saturated();
          }
        } else {
          _running++;
          worker.call(context, current.value, current.worked);
        }
      }
      __name(unshift, "unshift");
      function release3(holder) {
        if (holder) {
          cache32.release(holder);
        }
        var next = queueHead;
        if (next && _running <= _concurrency) {
          if (!self2.paused) {
            if (queueTail === queueHead) {
              queueTail = null;
            }
            queueHead = next.next;
            next.next = null;
            worker.call(context, next.value, next.worked);
            if (queueTail === null) {
              self2.empty();
            }
          } else {
            _running--;
          }
        } else if (--_running === 0) {
          self2.drain();
        }
      }
      __name(release3, "release");
      function kill() {
        queueHead = null;
        queueTail = null;
        self2.drain = noop;
      }
      __name(kill, "kill");
      function killAndDrain() {
        queueHead = null;
        queueTail = null;
        self2.drain();
        self2.drain = noop;
      }
      __name(killAndDrain, "killAndDrain");
      function abort() {
        var current = queueHead;
        queueHead = null;
        queueTail = null;
        while (current) {
          var next = current.next;
          var callback = current.callback;
          var errorHandler2 = current.errorHandler;
          var val = current.value;
          var context2 = current.context;
          current.value = null;
          current.callback = noop;
          current.errorHandler = null;
          if (errorHandler2) {
            errorHandler2(new Error("abort"), val);
          }
          callback.call(context2, new Error("abort"));
          current.release(current);
          current = next;
        }
        self2.drain = noop;
      }
      __name(abort, "abort");
      function error4(handler) {
        errorHandler = handler;
      }
      __name(error4, "error");
    }
    __name(fastqueue, "fastqueue");
    function noop() {
    }
    __name(noop, "noop");
    function Task() {
      this.value = null;
      this.callback = noop;
      this.next = null;
      this.release = noop;
      this.context = null;
      this.errorHandler = null;
      var self2 = this;
      this.worked = /* @__PURE__ */ __name(function worked(err, result2) {
        var callback = self2.callback;
        var errorHandler = self2.errorHandler;
        var val = self2.value;
        self2.value = null;
        self2.callback = noop;
        if (self2.errorHandler) {
          errorHandler(err, val);
        }
        callback.call(self2.context, err, result2);
        self2.release(self2);
      }, "worked");
    }
    __name(Task, "Task");
    function queueAsPromised(context, worker, _concurrency) {
      if (typeof context === "function") {
        _concurrency = worker;
        worker = context;
        context = null;
      }
      function asyncWrapper(arg, cb) {
        worker.call(this, arg).then(function(res) {
          cb(null, res);
        }, cb);
      }
      __name(asyncWrapper, "asyncWrapper");
      var queue = fastqueue(context, asyncWrapper, _concurrency);
      var pushCb = queue.push;
      var unshiftCb = queue.unshift;
      queue.push = push;
      queue.unshift = unshift;
      queue.drained = drained;
      return queue;
      function push(value) {
        var p10 = new Promise(function(resolve13, reject) {
          pushCb(value, function(err, result2) {
            if (err) {
              reject(err);
              return;
            }
            resolve13(result2);
          });
        });
        p10.catch(noop);
        return p10;
      }
      __name(push, "push");
      function unshift(value) {
        var p10 = new Promise(function(resolve13, reject) {
          unshiftCb(value, function(err, result2) {
            if (err) {
              reject(err);
              return;
            }
            resolve13(result2);
          });
        });
        p10.catch(noop);
        return p10;
      }
      __name(unshift, "unshift");
      function drained() {
        var p10 = new Promise(function(resolve13) {
          process.nextTick(function() {
            if (queue.idle()) {
              resolve13();
            } else {
              var previousDrain = queue.drain;
              queue.drain = function() {
                if (typeof previousDrain === "function") previousDrain();
                resolve13();
                queue.drain = previousDrain;
              };
            }
          });
        });
        return p10;
      }
      __name(drained, "drained");
    }
    __name(queueAsPromised, "queueAsPromised");
    module2.exports = fastqueue;
    module2.exports.promise = queueAsPromised;
  }
});

// ../../node_modules/@nodelib/fs.walk/out/readers/common.js
var require_common2 = __commonJS({
  "../../node_modules/@nodelib/fs.walk/out/readers/common.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.joinPathSegments = exports2.replacePathSegmentSeparator = exports2.isAppliedFilter = exports2.isFatalError = void 0;
    function isFatalError(settings, error4) {
      if (settings.errorFilter === null) {
        return true;
      }
      return !settings.errorFilter(error4);
    }
    __name(isFatalError, "isFatalError");
    exports2.isFatalError = isFatalError;
    function isAppliedFilter(filter, value) {
      return filter === null || filter(value);
    }
    __name(isAppliedFilter, "isAppliedFilter");
    exports2.isAppliedFilter = isAppliedFilter;
    function replacePathSegmentSeparator(filepath, separator) {
      return filepath.split(/[/\\]/).join(separator);
    }
    __name(replacePathSegmentSeparator, "replacePathSegmentSeparator");
    exports2.replacePathSegmentSeparator = replacePathSegmentSeparator;
    function joinPathSegments(a32, b32, separator) {
      if (a32 === "") {
        return b32;
      }
      if (a32.endsWith(separator)) {
        return a32 + b32;
      }
      return a32 + separator + b32;
    }
    __name(joinPathSegments, "joinPathSegments");
    exports2.joinPathSegments = joinPathSegments;
  }
});

// ../../node_modules/@nodelib/fs.walk/out/readers/reader.js
var require_reader = __commonJS({
  "../../node_modules/@nodelib/fs.walk/out/readers/reader.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var common = require_common2();
    var Reader = class {
      static {
        __name(this, "Reader");
      }
      constructor(_root, _settings) {
        this._root = _root;
        this._settings = _settings;
        this._root = common.replacePathSegmentSeparator(_root, _settings.pathSegmentSeparator);
      }
    };
    exports2.default = Reader;
  }
});

// ../../node_modules/@nodelib/fs.walk/out/readers/async.js
var require_async4 = __commonJS({
  "../../node_modules/@nodelib/fs.walk/out/readers/async.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var events_1 = require("events");
    var fsScandir = require_out2();
    var fastq = require_queue();
    var common = require_common2();
    var reader_1 = require_reader();
    var AsyncReader = class extends reader_1.default {
      static {
        __name(this, "AsyncReader");
      }
      constructor(_root, _settings) {
        super(_root, _settings);
        this._settings = _settings;
        this._scandir = fsScandir.scandir;
        this._emitter = new events_1.EventEmitter();
        this._queue = fastq(this._worker.bind(this), this._settings.concurrency);
        this._isFatalError = false;
        this._isDestroyed = false;
        this._queue.drain = () => {
          if (!this._isFatalError) {
            this._emitter.emit("end");
          }
        };
      }
      read() {
        this._isFatalError = false;
        this._isDestroyed = false;
        setImmediate(() => {
          this._pushToQueue(this._root, this._settings.basePath);
        });
        return this._emitter;
      }
      get isDestroyed() {
        return this._isDestroyed;
      }
      destroy() {
        if (this._isDestroyed) {
          throw new Error("The reader is already destroyed");
        }
        this._isDestroyed = true;
        this._queue.killAndDrain();
      }
      onEntry(callback) {
        this._emitter.on("entry", callback);
      }
      onError(callback) {
        this._emitter.once("error", callback);
      }
      onEnd(callback) {
        this._emitter.once("end", callback);
      }
      _pushToQueue(directory, base) {
        const queueItem = { directory, base };
        this._queue.push(queueItem, (error4) => {
          if (error4 !== null) {
            this._handleError(error4);
          }
        });
      }
      _worker(item, done) {
        this._scandir(item.directory, this._settings.fsScandirSettings, (error4, entries) => {
          if (error4 !== null) {
            done(error4, void 0);
            return;
          }
          for (const entry of entries) {
            this._handleEntry(entry, item.base);
          }
          done(null, void 0);
        });
      }
      _handleError(error4) {
        if (this._isDestroyed || !common.isFatalError(this._settings, error4)) {
          return;
        }
        this._isFatalError = true;
        this._isDestroyed = true;
        this._emitter.emit("error", error4);
      }
      _handleEntry(entry, base) {
        if (this._isDestroyed || this._isFatalError) {
          return;
        }
        const fullpath = entry.path;
        if (base !== void 0) {
          entry.path = common.joinPathSegments(base, entry.name, this._settings.pathSegmentSeparator);
        }
        if (common.isAppliedFilter(this._settings.entryFilter, entry)) {
          this._emitEntry(entry);
        }
        if (entry.dirent.isDirectory() && common.isAppliedFilter(this._settings.deepFilter, entry)) {
          this._pushToQueue(fullpath, base === void 0 ? void 0 : entry.path);
        }
      }
      _emitEntry(entry) {
        this._emitter.emit("entry", entry);
      }
    };
    exports2.default = AsyncReader;
  }
});

// ../../node_modules/@nodelib/fs.walk/out/providers/async.js
var require_async5 = __commonJS({
  "../../node_modules/@nodelib/fs.walk/out/providers/async.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var async_1 = require_async4();
    var AsyncProvider = class {
      static {
        __name(this, "AsyncProvider");
      }
      constructor(_root, _settings) {
        this._root = _root;
        this._settings = _settings;
        this._reader = new async_1.default(this._root, this._settings);
        this._storage = [];
      }
      read(callback) {
        this._reader.onError((error4) => {
          callFailureCallback(callback, error4);
        });
        this._reader.onEntry((entry) => {
          this._storage.push(entry);
        });
        this._reader.onEnd(() => {
          callSuccessCallback(callback, this._storage);
        });
        this._reader.read();
      }
    };
    exports2.default = AsyncProvider;
    function callFailureCallback(callback, error4) {
      callback(error4);
    }
    __name(callFailureCallback, "callFailureCallback");
    function callSuccessCallback(callback, entries) {
      callback(null, entries);
    }
    __name(callSuccessCallback, "callSuccessCallback");
  }
});

// ../../node_modules/@nodelib/fs.walk/out/providers/stream.js
var require_stream2 = __commonJS({
  "../../node_modules/@nodelib/fs.walk/out/providers/stream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var stream_1 = require("stream");
    var async_1 = require_async4();
    var StreamProvider = class {
      static {
        __name(this, "StreamProvider");
      }
      constructor(_root, _settings) {
        this._root = _root;
        this._settings = _settings;
        this._reader = new async_1.default(this._root, this._settings);
        this._stream = new stream_1.Readable({
          objectMode: true,
          read: /* @__PURE__ */ __name(() => {
          }, "read"),
          destroy: /* @__PURE__ */ __name(() => {
            if (!this._reader.isDestroyed) {
              this._reader.destroy();
            }
          }, "destroy")
        });
      }
      read() {
        this._reader.onError((error4) => {
          this._stream.emit("error", error4);
        });
        this._reader.onEntry((entry) => {
          this._stream.push(entry);
        });
        this._reader.onEnd(() => {
          this._stream.push(null);
        });
        this._reader.read();
        return this._stream;
      }
    };
    exports2.default = StreamProvider;
  }
});

// ../../node_modules/@nodelib/fs.walk/out/readers/sync.js
var require_sync3 = __commonJS({
  "../../node_modules/@nodelib/fs.walk/out/readers/sync.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var fsScandir = require_out2();
    var common = require_common2();
    var reader_1 = require_reader();
    var SyncReader = class extends reader_1.default {
      static {
        __name(this, "SyncReader");
      }
      constructor() {
        super(...arguments);
        this._scandir = fsScandir.scandirSync;
        this._storage = [];
        this._queue = /* @__PURE__ */ new Set();
      }
      read() {
        this._pushToQueue(this._root, this._settings.basePath);
        this._handleQueue();
        return this._storage;
      }
      _pushToQueue(directory, base) {
        this._queue.add({ directory, base });
      }
      _handleQueue() {
        for (const item of this._queue.values()) {
          this._handleDirectory(item.directory, item.base);
        }
      }
      _handleDirectory(directory, base) {
        try {
          const entries = this._scandir(directory, this._settings.fsScandirSettings);
          for (const entry of entries) {
            this._handleEntry(entry, base);
          }
        } catch (error4) {
          this._handleError(error4);
        }
      }
      _handleError(error4) {
        if (!common.isFatalError(this._settings, error4)) {
          return;
        }
        throw error4;
      }
      _handleEntry(entry, base) {
        const fullpath = entry.path;
        if (base !== void 0) {
          entry.path = common.joinPathSegments(base, entry.name, this._settings.pathSegmentSeparator);
        }
        if (common.isAppliedFilter(this._settings.entryFilter, entry)) {
          this._pushToStorage(entry);
        }
        if (entry.dirent.isDirectory() && common.isAppliedFilter(this._settings.deepFilter, entry)) {
          this._pushToQueue(fullpath, base === void 0 ? void 0 : entry.path);
        }
      }
      _pushToStorage(entry) {
        this._storage.push(entry);
      }
    };
    exports2.default = SyncReader;
  }
});

// ../../node_modules/@nodelib/fs.walk/out/providers/sync.js
var require_sync4 = __commonJS({
  "../../node_modules/@nodelib/fs.walk/out/providers/sync.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var sync_1 = require_sync3();
    var SyncProvider = class {
      static {
        __name(this, "SyncProvider");
      }
      constructor(_root, _settings) {
        this._root = _root;
        this._settings = _settings;
        this._reader = new sync_1.default(this._root, this._settings);
      }
      read() {
        return this._reader.read();
      }
    };
    exports2.default = SyncProvider;
  }
});

// ../../node_modules/@nodelib/fs.walk/out/settings.js
var require_settings3 = __commonJS({
  "../../node_modules/@nodelib/fs.walk/out/settings.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var path47 = require("path");
    var fsScandir = require_out2();
    var Settings2 = class {
      static {
        __name(this, "Settings");
      }
      constructor(_options = {}) {
        this._options = _options;
        this.basePath = this._getValue(this._options.basePath, void 0);
        this.concurrency = this._getValue(this._options.concurrency, Number.POSITIVE_INFINITY);
        this.deepFilter = this._getValue(this._options.deepFilter, null);
        this.entryFilter = this._getValue(this._options.entryFilter, null);
        this.errorFilter = this._getValue(this._options.errorFilter, null);
        this.pathSegmentSeparator = this._getValue(this._options.pathSegmentSeparator, path47.sep);
        this.fsScandirSettings = new fsScandir.Settings({
          followSymbolicLinks: this._options.followSymbolicLinks,
          fs: this._options.fs,
          pathSegmentSeparator: this._options.pathSegmentSeparator,
          stats: this._options.stats,
          throwErrorOnBrokenSymbolicLink: this._options.throwErrorOnBrokenSymbolicLink
        });
      }
      _getValue(option, value) {
        return option !== null && option !== void 0 ? option : value;
      }
    };
    exports2.default = Settings2;
  }
});

// ../../node_modules/@nodelib/fs.walk/out/index.js
var require_out3 = __commonJS({
  "../../node_modules/@nodelib/fs.walk/out/index.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.Settings = exports2.walkStream = exports2.walkSync = exports2.walk = void 0;
    var async_1 = require_async5();
    var stream_1 = require_stream2();
    var sync_1 = require_sync4();
    var settings_1 = require_settings3();
    exports2.Settings = settings_1.default;
    function walk(directory, optionsOrSettingsOrCallback, callback) {
      if (typeof optionsOrSettingsOrCallback === "function") {
        new async_1.default(directory, getSettings()).read(optionsOrSettingsOrCallback);
        return;
      }
      new async_1.default(directory, getSettings(optionsOrSettingsOrCallback)).read(callback);
    }
    __name(walk, "walk");
    exports2.walk = walk;
    function walkSync(directory, optionsOrSettings) {
      const settings = getSettings(optionsOrSettings);
      const provider = new sync_1.default(directory, settings);
      return provider.read();
    }
    __name(walkSync, "walkSync");
    exports2.walkSync = walkSync;
    function walkStream(directory, optionsOrSettings) {
      const settings = getSettings(optionsOrSettings);
      const provider = new stream_1.default(directory, settings);
      return provider.read();
    }
    __name(walkStream, "walkStream");
    exports2.walkStream = walkStream;
    function getSettings(settingsOrOptions = {}) {
      if (settingsOrOptions instanceof settings_1.default) {
        return settingsOrOptions;
      }
      return new settings_1.default(settingsOrOptions);
    }
    __name(getSettings, "getSettings");
  }
});

// ../../node_modules/fast-glob/out/readers/reader.js
var require_reader2 = __commonJS({
  "../../node_modules/fast-glob/out/readers/reader.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var path47 = require("path");
    var fsStat = require_out();
    var utils = require_utils5();
    var Reader = class {
      static {
        __name(this, "Reader");
      }
      constructor(_settings) {
        this._settings = _settings;
        this._fsStatSettings = new fsStat.Settings({
          followSymbolicLink: this._settings.followSymbolicLinks,
          fs: this._settings.fs,
          throwErrorOnBrokenSymbolicLink: this._settings.followSymbolicLinks
        });
      }
      _getFullEntryPath(filepath) {
        return path47.resolve(this._settings.cwd, filepath);
      }
      _makeEntry(stats, pattern) {
        const entry = {
          name: pattern,
          path: pattern,
          dirent: utils.fs.createDirentFromStats(pattern, stats)
        };
        if (this._settings.stats) {
          entry.stats = stats;
        }
        return entry;
      }
      _isFatalError(error4) {
        return !utils.errno.isEnoentCodeError(error4) && !this._settings.suppressErrors;
      }
    };
    exports2.default = Reader;
  }
});

// ../../node_modules/fast-glob/out/readers/stream.js
var require_stream3 = __commonJS({
  "../../node_modules/fast-glob/out/readers/stream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var stream_1 = require("stream");
    var fsStat = require_out();
    var fsWalk = require_out3();
    var reader_1 = require_reader2();
    var ReaderStream = class extends reader_1.default {
      static {
        __name(this, "ReaderStream");
      }
      constructor() {
        super(...arguments);
        this._walkStream = fsWalk.walkStream;
        this._stat = fsStat.stat;
      }
      dynamic(root32, options) {
        return this._walkStream(root32, options);
      }
      static(patterns, options) {
        const filepaths = patterns.map(this._getFullEntryPath, this);
        const stream = new stream_1.PassThrough({ objectMode: true });
        stream._write = (index, _enc, done) => {
          return this._getEntry(filepaths[index], patterns[index], options).then((entry) => {
            if (entry !== null && options.entryFilter(entry)) {
              stream.push(entry);
            }
            if (index === filepaths.length - 1) {
              stream.end();
            }
            done();
          }).catch(done);
        };
        for (let i32 = 0; i32 < filepaths.length; i32++) {
          stream.write(i32);
        }
        return stream;
      }
      _getEntry(filepath, pattern, options) {
        return this._getStat(filepath).then((stats) => this._makeEntry(stats, pattern)).catch((error4) => {
          if (options.errorFilter(error4)) {
            return null;
          }
          throw error4;
        });
      }
      _getStat(filepath) {
        return new Promise((resolve13, reject) => {
          this._stat(filepath, this._fsStatSettings, (error4, stats) => {
            return error4 === null ? resolve13(stats) : reject(error4);
          });
        });
      }
    };
    exports2.default = ReaderStream;
  }
});

// ../../node_modules/fast-glob/out/readers/async.js
var require_async6 = __commonJS({
  "../../node_modules/fast-glob/out/readers/async.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var fsWalk = require_out3();
    var reader_1 = require_reader2();
    var stream_1 = require_stream3();
    var ReaderAsync = class extends reader_1.default {
      static {
        __name(this, "ReaderAsync");
      }
      constructor() {
        super(...arguments);
        this._walkAsync = fsWalk.walk;
        this._readerStream = new stream_1.default(this._settings);
      }
      dynamic(root32, options) {
        return new Promise((resolve13, reject) => {
          this._walkAsync(root32, options, (error4, entries) => {
            if (error4 === null) {
              resolve13(entries);
            } else {
              reject(error4);
            }
          });
        });
      }
      async static(patterns, options) {
        const entries = [];
        const stream = this._readerStream.static(patterns, options);
        return new Promise((resolve13, reject) => {
          stream.once("error", reject);
          stream.on("data", (entry) => entries.push(entry));
          stream.once("end", () => resolve13(entries));
        });
      }
    };
    exports2.default = ReaderAsync;
  }
});

// ../../node_modules/fast-glob/out/providers/matchers/matcher.js
var require_matcher = __commonJS({
  "../../node_modules/fast-glob/out/providers/matchers/matcher.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var utils = require_utils5();
    var Matcher = class {
      static {
        __name(this, "Matcher");
      }
      constructor(_patterns, _settings, _micromatchOptions) {
        this._patterns = _patterns;
        this._settings = _settings;
        this._micromatchOptions = _micromatchOptions;
        this._storage = [];
        this._fillStorage();
      }
      _fillStorage() {
        for (const pattern of this._patterns) {
          const segments = this._getPatternSegments(pattern);
          const sections = this._splitSegmentsIntoSections(segments);
          this._storage.push({
            complete: sections.length <= 1,
            pattern,
            segments,
            sections
          });
        }
      }
      _getPatternSegments(pattern) {
        const parts = utils.pattern.getPatternParts(pattern, this._micromatchOptions);
        return parts.map((part) => {
          const dynamic = utils.pattern.isDynamicPattern(part, this._settings);
          if (!dynamic) {
            return {
              dynamic: false,
              pattern: part
            };
          }
          return {
            dynamic: true,
            pattern: part,
            patternRe: utils.pattern.makeRe(part, this._micromatchOptions)
          };
        });
      }
      _splitSegmentsIntoSections(segments) {
        return utils.array.splitWhen(segments, (segment) => segment.dynamic && utils.pattern.hasGlobStar(segment.pattern));
      }
    };
    exports2.default = Matcher;
  }
});

// ../../node_modules/fast-glob/out/providers/matchers/partial.js
var require_partial = __commonJS({
  "../../node_modules/fast-glob/out/providers/matchers/partial.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var matcher_1 = require_matcher();
    var PartialMatcher = class extends matcher_1.default {
      static {
        __name(this, "PartialMatcher");
      }
      match(filepath) {
        const parts = filepath.split("/");
        const levels2 = parts.length;
        const patterns = this._storage.filter((info2) => !info2.complete || info2.segments.length > levels2);
        for (const pattern of patterns) {
          const section = pattern.sections[0];
          if (!pattern.complete && levels2 > section.length) {
            return true;
          }
          const match = parts.every((part, index) => {
            const segment = pattern.segments[index];
            if (segment.dynamic && segment.patternRe.test(part)) {
              return true;
            }
            if (!segment.dynamic && segment.pattern === part) {
              return true;
            }
            return false;
          });
          if (match) {
            return true;
          }
        }
        return false;
      }
    };
    exports2.default = PartialMatcher;
  }
});

// ../../node_modules/fast-glob/out/providers/filters/deep.js
var require_deep = __commonJS({
  "../../node_modules/fast-glob/out/providers/filters/deep.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var utils = require_utils5();
    var partial_1 = require_partial();
    var DeepFilter = class {
      static {
        __name(this, "DeepFilter");
      }
      constructor(_settings, _micromatchOptions) {
        this._settings = _settings;
        this._micromatchOptions = _micromatchOptions;
      }
      getFilter(basePath, positive, negative) {
        const matcher = this._getMatcher(positive);
        const negativeRe = this._getNegativePatternsRe(negative);
        return (entry) => this._filter(basePath, entry, matcher, negativeRe);
      }
      _getMatcher(patterns) {
        return new partial_1.default(patterns, this._settings, this._micromatchOptions);
      }
      _getNegativePatternsRe(patterns) {
        const affectDepthOfReadingPatterns = patterns.filter(utils.pattern.isAffectDepthOfReadingPattern);
        return utils.pattern.convertPatternsToRe(affectDepthOfReadingPatterns, this._micromatchOptions);
      }
      _filter(basePath, entry, matcher, negativeRe) {
        if (this._isSkippedByDeep(basePath, entry.path)) {
          return false;
        }
        if (this._isSkippedSymbolicLink(entry)) {
          return false;
        }
        const filepath = utils.path.removeLeadingDotSegment(entry.path);
        if (this._isSkippedByPositivePatterns(filepath, matcher)) {
          return false;
        }
        return this._isSkippedByNegativePatterns(filepath, negativeRe);
      }
      _isSkippedByDeep(basePath, entryPath) {
        if (this._settings.deep === Infinity) {
          return false;
        }
        return this._getEntryLevel(basePath, entryPath) >= this._settings.deep;
      }
      _getEntryLevel(basePath, entryPath) {
        const entryPathDepth = entryPath.split("/").length;
        if (basePath === "") {
          return entryPathDepth;
        }
        const basePathDepth = basePath.split("/").length;
        return entryPathDepth - basePathDepth;
      }
      _isSkippedSymbolicLink(entry) {
        return !this._settings.followSymbolicLinks && entry.dirent.isSymbolicLink();
      }
      _isSkippedByPositivePatterns(entryPath, matcher) {
        return !this._settings.baseNameMatch && !matcher.match(entryPath);
      }
      _isSkippedByNegativePatterns(entryPath, patternsRe) {
        return !utils.pattern.matchAny(entryPath, patternsRe);
      }
    };
    exports2.default = DeepFilter;
  }
});

// ../../node_modules/fast-glob/out/providers/filters/entry.js
var require_entry = __commonJS({
  "../../node_modules/fast-glob/out/providers/filters/entry.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var utils = require_utils5();
    var EntryFilter = class {
      static {
        __name(this, "EntryFilter");
      }
      constructor(_settings, _micromatchOptions) {
        this._settings = _settings;
        this._micromatchOptions = _micromatchOptions;
        this.index = /* @__PURE__ */ new Map();
      }
      getFilter(positive, negative) {
        const [absoluteNegative, relativeNegative] = utils.pattern.partitionAbsoluteAndRelative(negative);
        const patterns = {
          positive: {
            all: utils.pattern.convertPatternsToRe(positive, this._micromatchOptions)
          },
          negative: {
            absolute: utils.pattern.convertPatternsToRe(absoluteNegative, Object.assign(Object.assign({}, this._micromatchOptions), { dot: true })),
            relative: utils.pattern.convertPatternsToRe(relativeNegative, Object.assign(Object.assign({}, this._micromatchOptions), { dot: true }))
          }
        };
        return (entry) => this._filter(entry, patterns);
      }
      _filter(entry, patterns) {
        const filepath = utils.path.removeLeadingDotSegment(entry.path);
        if (this._settings.unique && this._isDuplicateEntry(filepath)) {
          return false;
        }
        if (this._onlyFileFilter(entry) || this._onlyDirectoryFilter(entry)) {
          return false;
        }
        const isMatched = this._isMatchToPatternsSet(filepath, patterns, entry.dirent.isDirectory());
        if (this._settings.unique && isMatched) {
          this._createIndexRecord(filepath);
        }
        return isMatched;
      }
      _isDuplicateEntry(filepath) {
        return this.index.has(filepath);
      }
      _createIndexRecord(filepath) {
        this.index.set(filepath, void 0);
      }
      _onlyFileFilter(entry) {
        return this._settings.onlyFiles && !entry.dirent.isFile();
      }
      _onlyDirectoryFilter(entry) {
        return this._settings.onlyDirectories && !entry.dirent.isDirectory();
      }
      _isMatchToPatternsSet(filepath, patterns, isDirectory) {
        const isMatched = this._isMatchToPatterns(filepath, patterns.positive.all, isDirectory);
        if (!isMatched) {
          return false;
        }
        const isMatchedByRelativeNegative = this._isMatchToPatterns(filepath, patterns.negative.relative, isDirectory);
        if (isMatchedByRelativeNegative) {
          return false;
        }
        const isMatchedByAbsoluteNegative = this._isMatchToAbsoluteNegative(filepath, patterns.negative.absolute, isDirectory);
        if (isMatchedByAbsoluteNegative) {
          return false;
        }
        return true;
      }
      _isMatchToAbsoluteNegative(filepath, patternsRe, isDirectory) {
        if (patternsRe.length === 0) {
          return false;
        }
        const fullpath = utils.path.makeAbsolute(this._settings.cwd, filepath);
        return this._isMatchToPatterns(fullpath, patternsRe, isDirectory);
      }
      _isMatchToPatterns(filepath, patternsRe, isDirectory) {
        if (patternsRe.length === 0) {
          return false;
        }
        const isMatched = utils.pattern.matchAny(filepath, patternsRe);
        if (!isMatched && isDirectory) {
          return utils.pattern.matchAny(filepath + "/", patternsRe);
        }
        return isMatched;
      }
    };
    exports2.default = EntryFilter;
  }
});

// ../../node_modules/fast-glob/out/providers/filters/error.js
var require_error = __commonJS({
  "../../node_modules/fast-glob/out/providers/filters/error.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var utils = require_utils5();
    var ErrorFilter = class {
      static {
        __name(this, "ErrorFilter");
      }
      constructor(_settings) {
        this._settings = _settings;
      }
      getFilter() {
        return (error4) => this._isNonFatalError(error4);
      }
      _isNonFatalError(error4) {
        return utils.errno.isEnoentCodeError(error4) || this._settings.suppressErrors;
      }
    };
    exports2.default = ErrorFilter;
  }
});

// ../../node_modules/fast-glob/out/providers/transformers/entry.js
var require_entry2 = __commonJS({
  "../../node_modules/fast-glob/out/providers/transformers/entry.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var utils = require_utils5();
    var EntryTransformer = class {
      static {
        __name(this, "EntryTransformer");
      }
      constructor(_settings) {
        this._settings = _settings;
      }
      getTransformer() {
        return (entry) => this._transform(entry);
      }
      _transform(entry) {
        let filepath = entry.path;
        if (this._settings.absolute) {
          filepath = utils.path.makeAbsolute(this._settings.cwd, filepath);
          filepath = utils.path.unixify(filepath);
        }
        if (this._settings.markDirectories && entry.dirent.isDirectory()) {
          filepath += "/";
        }
        if (!this._settings.objectMode) {
          return filepath;
        }
        return Object.assign(Object.assign({}, entry), { path: filepath });
      }
    };
    exports2.default = EntryTransformer;
  }
});

// ../../node_modules/fast-glob/out/providers/provider.js
var require_provider = __commonJS({
  "../../node_modules/fast-glob/out/providers/provider.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var path47 = require("path");
    var deep_1 = require_deep();
    var entry_1 = require_entry();
    var error_1 = require_error();
    var entry_2 = require_entry2();
    var Provider = class {
      static {
        __name(this, "Provider");
      }
      constructor(_settings) {
        this._settings = _settings;
        this.errorFilter = new error_1.default(this._settings);
        this.entryFilter = new entry_1.default(this._settings, this._getMicromatchOptions());
        this.deepFilter = new deep_1.default(this._settings, this._getMicromatchOptions());
        this.entryTransformer = new entry_2.default(this._settings);
      }
      _getRootDirectory(task) {
        return path47.resolve(this._settings.cwd, task.base);
      }
      _getReaderOptions(task) {
        const basePath = task.base === "." ? "" : task.base;
        return {
          basePath,
          pathSegmentSeparator: "/",
          concurrency: this._settings.concurrency,
          deepFilter: this.deepFilter.getFilter(basePath, task.positive, task.negative),
          entryFilter: this.entryFilter.getFilter(task.positive, task.negative),
          errorFilter: this.errorFilter.getFilter(),
          followSymbolicLinks: this._settings.followSymbolicLinks,
          fs: this._settings.fs,
          stats: this._settings.stats,
          throwErrorOnBrokenSymbolicLink: this._settings.throwErrorOnBrokenSymbolicLink,
          transform: this.entryTransformer.getTransformer()
        };
      }
      _getMicromatchOptions() {
        return {
          dot: this._settings.dot,
          matchBase: this._settings.baseNameMatch,
          nobrace: !this._settings.braceExpansion,
          nocase: !this._settings.caseSensitiveMatch,
          noext: !this._settings.extglob,
          noglobstar: !this._settings.globstar,
          posix: true,
          strictSlashes: false
        };
      }
    };
    exports2.default = Provider;
  }
});

// ../../node_modules/fast-glob/out/providers/async.js
var require_async7 = __commonJS({
  "../../node_modules/fast-glob/out/providers/async.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var async_1 = require_async6();
    var provider_1 = require_provider();
    var ProviderAsync = class extends provider_1.default {
      static {
        __name(this, "ProviderAsync");
      }
      constructor() {
        super(...arguments);
        this._reader = new async_1.default(this._settings);
      }
      async read(task) {
        const root32 = this._getRootDirectory(task);
        const options = this._getReaderOptions(task);
        const entries = await this.api(root32, task, options);
        return entries.map((entry) => options.transform(entry));
      }
      api(root32, task, options) {
        if (task.dynamic) {
          return this._reader.dynamic(root32, options);
        }
        return this._reader.static(task.patterns, options);
      }
    };
    exports2.default = ProviderAsync;
  }
});

// ../../node_modules/fast-glob/out/providers/stream.js
var require_stream4 = __commonJS({
  "../../node_modules/fast-glob/out/providers/stream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var stream_1 = require("stream");
    var stream_2 = require_stream3();
    var provider_1 = require_provider();
    var ProviderStream = class extends provider_1.default {
      static {
        __name(this, "ProviderStream");
      }
      constructor() {
        super(...arguments);
        this._reader = new stream_2.default(this._settings);
      }
      read(task) {
        const root32 = this._getRootDirectory(task);
        const options = this._getReaderOptions(task);
        const source = this.api(root32, task, options);
        const destination = new stream_1.Readable({ objectMode: true, read: /* @__PURE__ */ __name(() => {
        }, "read") });
        source.once("error", (error4) => destination.emit("error", error4)).on("data", (entry) => destination.emit("data", options.transform(entry))).once("end", () => destination.emit("end"));
        destination.once("close", () => source.destroy());
        return destination;
      }
      api(root32, task, options) {
        if (task.dynamic) {
          return this._reader.dynamic(root32, options);
        }
        return this._reader.static(task.patterns, options);
      }
    };
    exports2.default = ProviderStream;
  }
});

// ../../node_modules/fast-glob/out/readers/sync.js
var require_sync5 = __commonJS({
  "../../node_modules/fast-glob/out/readers/sync.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var fsStat = require_out();
    var fsWalk = require_out3();
    var reader_1 = require_reader2();
    var ReaderSync = class extends reader_1.default {
      static {
        __name(this, "ReaderSync");
      }
      constructor() {
        super(...arguments);
        this._walkSync = fsWalk.walkSync;
        this._statSync = fsStat.statSync;
      }
      dynamic(root32, options) {
        return this._walkSync(root32, options);
      }
      static(patterns, options) {
        const entries = [];
        for (const pattern of patterns) {
          const filepath = this._getFullEntryPath(pattern);
          const entry = this._getEntry(filepath, pattern, options);
          if (entry === null || !options.entryFilter(entry)) {
            continue;
          }
          entries.push(entry);
        }
        return entries;
      }
      _getEntry(filepath, pattern, options) {
        try {
          const stats = this._getStat(filepath);
          return this._makeEntry(stats, pattern);
        } catch (error4) {
          if (options.errorFilter(error4)) {
            return null;
          }
          throw error4;
        }
      }
      _getStat(filepath) {
        return this._statSync(filepath, this._fsStatSettings);
      }
    };
    exports2.default = ReaderSync;
  }
});

// ../../node_modules/fast-glob/out/providers/sync.js
var require_sync6 = __commonJS({
  "../../node_modules/fast-glob/out/providers/sync.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var sync_1 = require_sync5();
    var provider_1 = require_provider();
    var ProviderSync = class extends provider_1.default {
      static {
        __name(this, "ProviderSync");
      }
      constructor() {
        super(...arguments);
        this._reader = new sync_1.default(this._settings);
      }
      read(task) {
        const root32 = this._getRootDirectory(task);
        const options = this._getReaderOptions(task);
        const entries = this.api(root32, task, options);
        return entries.map(options.transform);
      }
      api(root32, task, options) {
        if (task.dynamic) {
          return this._reader.dynamic(root32, options);
        }
        return this._reader.static(task.patterns, options);
      }
    };
    exports2.default = ProviderSync;
  }
});

// ../../node_modules/fast-glob/out/settings.js
var require_settings4 = __commonJS({
  "../../node_modules/fast-glob/out/settings.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.DEFAULT_FILE_SYSTEM_ADAPTER = void 0;
    var fs51 = require("fs");
    var os14 = require("os");
    var CPU_COUNT = Math.max(os14.cpus().length, 1);
    exports2.DEFAULT_FILE_SYSTEM_ADAPTER = {
      lstat: fs51.lstat,
      lstatSync: fs51.lstatSync,
      stat: fs51.stat,
      statSync: fs51.statSync,
      readdir: fs51.readdir,
      readdirSync: fs51.readdirSync
    };
    var Settings2 = class {
      static {
        __name(this, "Settings");
      }
      constructor(_options = {}) {
        this._options = _options;
        this.absolute = this._getValue(this._options.absolute, false);
        this.baseNameMatch = this._getValue(this._options.baseNameMatch, false);
        this.braceExpansion = this._getValue(this._options.braceExpansion, true);
        this.caseSensitiveMatch = this._getValue(this._options.caseSensitiveMatch, true);
        this.concurrency = this._getValue(this._options.concurrency, CPU_COUNT);
        this.cwd = this._getValue(this._options.cwd, process.cwd());
        this.deep = this._getValue(this._options.deep, Infinity);
        this.dot = this._getValue(this._options.dot, false);
        this.extglob = this._getValue(this._options.extglob, true);
        this.followSymbolicLinks = this._getValue(this._options.followSymbolicLinks, true);
        this.fs = this._getFileSystemMethods(this._options.fs);
        this.globstar = this._getValue(this._options.globstar, true);
        this.ignore = this._getValue(this._options.ignore, []);
        this.markDirectories = this._getValue(this._options.markDirectories, false);
        this.objectMode = this._getValue(this._options.objectMode, false);
        this.onlyDirectories = this._getValue(this._options.onlyDirectories, false);
        this.onlyFiles = this._getValue(this._options.onlyFiles, true);
        this.stats = this._getValue(this._options.stats, false);
        this.suppressErrors = this._getValue(this._options.suppressErrors, false);
        this.throwErrorOnBrokenSymbolicLink = this._getValue(this._options.throwErrorOnBrokenSymbolicLink, false);
        this.unique = this._getValue(this._options.unique, true);
        if (this.onlyDirectories) {
          this.onlyFiles = false;
        }
        if (this.stats) {
          this.objectMode = true;
        }
        this.ignore = [].concat(this.ignore);
      }
      _getValue(option, value) {
        return option === void 0 ? value : option;
      }
      _getFileSystemMethods(methods = {}) {
        return Object.assign(Object.assign({}, exports2.DEFAULT_FILE_SYSTEM_ADAPTER), methods);
      }
    };
    exports2.default = Settings2;
  }
});

// ../../node_modules/fast-glob/out/index.js
var require_out4 = __commonJS({
  "../../node_modules/fast-glob/out/index.js"(exports2, module2) {
    "use strict";
    var taskManager = require_tasks();
    var async_1 = require_async7();
    var stream_1 = require_stream4();
    var sync_1 = require_sync6();
    var settings_1 = require_settings4();
    var utils = require_utils5();
    async function FastGlob(source, options) {
      assertPatternsInput(source);
      const works = getWorks(source, async_1.default, options);
      const result2 = await Promise.all(works);
      return utils.array.flatten(result2);
    }
    __name(FastGlob, "FastGlob");
    (function(FastGlob2) {
      FastGlob2.glob = FastGlob2;
      FastGlob2.globSync = sync;
      FastGlob2.globStream = stream;
      FastGlob2.async = FastGlob2;
      function sync(source, options) {
        assertPatternsInput(source);
        const works = getWorks(source, sync_1.default, options);
        return utils.array.flatten(works);
      }
      __name(sync, "sync");
      FastGlob2.sync = sync;
      function stream(source, options) {
        assertPatternsInput(source);
        const works = getWorks(source, stream_1.default, options);
        return utils.stream.merge(works);
      }
      __name(stream, "stream");
      FastGlob2.stream = stream;
      function generateTasks(source, options) {
        assertPatternsInput(source);
        const patterns = [].concat(source);
        const settings = new settings_1.default(options);
        return taskManager.generate(patterns, settings);
      }
      __name(generateTasks, "generateTasks");
      FastGlob2.generateTasks = generateTasks;
      function isDynamicPattern(source, options) {
        assertPatternsInput(source);
        const settings = new settings_1.default(options);
        return utils.pattern.isDynamicPattern(source, settings);
      }
      __name(isDynamicPattern, "isDynamicPattern");
      FastGlob2.isDynamicPattern = isDynamicPattern;
      function escapePath(source) {
        assertPatternsInput(source);
        return utils.path.escape(source);
      }
      __name(escapePath, "escapePath");
      FastGlob2.escapePath = escapePath;
      function convertPathToPattern(source) {
        assertPatternsInput(source);
        return utils.path.convertPathToPattern(source);
      }
      __name(convertPathToPattern, "convertPathToPattern");
      FastGlob2.convertPathToPattern = convertPathToPattern;
      let posix;
      (function(posix2) {
        function escapePath2(source) {
          assertPatternsInput(source);
          return utils.path.escapePosixPath(source);
        }
        __name(escapePath2, "escapePath");
        posix2.escapePath = escapePath2;
        function convertPathToPattern2(source) {
          assertPatternsInput(source);
          return utils.path.convertPosixPathToPattern(source);
        }
        __name(convertPathToPattern2, "convertPathToPattern");
        posix2.convertPathToPattern = convertPathToPattern2;
      })(posix = FastGlob2.posix || (FastGlob2.posix = {}));
      let win32;
      (function(win322) {
        function escapePath2(source) {
          assertPatternsInput(source);
          return utils.path.escapeWindowsPath(source);
        }
        __name(escapePath2, "escapePath");
        win322.escapePath = escapePath2;
        function convertPathToPattern2(source) {
          assertPatternsInput(source);
          return utils.path.convertWindowsPathToPattern(source);
        }
        __name(convertPathToPattern2, "convertPathToPattern");
        win322.convertPathToPattern = convertPathToPattern2;
      })(win32 = FastGlob2.win32 || (FastGlob2.win32 = {}));
    })(FastGlob || (FastGlob = {}));
    function getWorks(source, _Provider, options) {
      const patterns = [].concat(source);
      const settings = new settings_1.default(options);
      const tasks = taskManager.generate(patterns, settings);
      const provider = new _Provider(settings);
      return tasks.map(provider.read, provider);
    }
    __name(getWorks, "getWorks");
    function assertPatternsInput(input) {
      const source = [].concat(input);
      const isValidSource = source.every((item) => utils.string.isString(item) && !utils.string.isEmpty(item));
      if (!isValidSource) {
        throw new TypeError("Patterns must be a string (non empty) or an array of strings");
      }
    }
    __name(assertPatternsInput, "assertPatternsInput");
    module2.exports = FastGlob;
  }
});

// ../../node_modules/buffer-crc32/dist/index.cjs
var require_dist = __commonJS({
  "../../node_modules/buffer-crc32/dist/index.cjs"(exports2, module2) {
    "use strict";
    function getDefaultExportFromCjs(x) {
      return x && x.__esModule && Object.prototype.hasOwnProperty.call(x, "default") ? x["default"] : x;
    }
    __name(getDefaultExportFromCjs, "getDefaultExportFromCjs");
    var CRC_TABLE = new Int32Array([
      0,
      1996959894,
      3993919788,
      2567524794,
      124634137,
      1886057615,
      3915621685,
      2657392035,
      249268274,
      2044508324,
      3772115230,
      2547177864,
      162941995,
      2125561021,
      3887607047,
      2428444049,
      498536548,
      1789927666,
      4089016648,
      2227061214,
      450548861,
      1843258603,
      4107580753,
      2211677639,
      325883990,
      1684777152,
      4251122042,
      2321926636,
      335633487,
      1661365465,
      4195302755,
      2366115317,
      997073096,
      1281953886,
      3579855332,
      2724688242,
      1006888145,
      1258607687,
      3524101629,
      2768942443,
      901097722,
      1119000684,
      3686517206,
      2898065728,
      853044451,
      1172266101,
      3705015759,
      2882616665,
      651767980,
      1373503546,
      3369554304,
      3218104598,
      565507253,
      1454621731,
      3485111705,
      3099436303,
      671266974,
      1594198024,
      3322730930,
      2970347812,
      795835527,
      1483230225,
      3244367275,
      3060149565,
      1994146192,
      31158534,
      2563907772,
      4023717930,
      1907459465,
      112637215,
      2680153253,
      3904427059,
      2013776290,
      251722036,
      2517215374,
      3775830040,
      2137656763,
      141376813,
      2439277719,
      3865271297,
      1802195444,
      476864866,
      2238001368,
      4066508878,
      1812370925,
      453092731,
      2181625025,
      4111451223,
      1706088902,
      314042704,
      2344532202,
      4240017532,
      1658658271,
      366619977,
      2362670323,
      4224994405,
      1303535960,
      984961486,
      2747007092,
      3569037538,
      1256170817,
      1037604311,
      2765210733,
      3554079995,
      1131014506,
      879679996,
      2909243462,
      3663771856,
      1141124467,
      855842277,
      2852801631,
      3708648649,
      1342533948,
      654459306,
      3188396048,
      3373015174,
      1466479909,
      544179635,
      3110523913,
      3462522015,
      1591671054,
      702138776,
      2966460450,
      3352799412,
      1504918807,
      783551873,
      3082640443,
      3233442989,
      3988292384,
      2596254646,
      62317068,
      1957810842,
      3939845945,
      2647816111,
      81470997,
      1943803523,
      3814918930,
      2489596804,
      225274430,
      2053790376,
      3826175755,
      2466906013,
      167816743,
      2097651377,
      4027552580,
      2265490386,
      503444072,
      1762050814,
      4150417245,
      2154129355,
      426522225,
      1852507879,
      4275313526,
      2312317920,
      282753626,
      1742555852,
      4189708143,
      2394877945,
      397917763,
      1622183637,
      3604390888,
      2714866558,
      953729732,
      1340076626,
      3518719985,
      2797360999,
      1068828381,
      1219638859,
      3624741850,
      2936675148,
      906185462,
      1090812512,
      3747672003,
      2825379669,
      829329135,
      1181335161,
      3412177804,
      3160834842,
      628085408,
      1382605366,
      3423369109,
      3138078467,
      570562233,
      1426400815,
      3317316542,
      2998733608,
      733239954,
      1555261956,
      3268935591,
      3050360625,
      752459403,
      1541320221,
      2607071920,
      3965973030,
      1969922972,
      40735498,
      2617837225,
      3943577151,
      1913087877,
      83908371,
      2512341634,
      3803740692,
      2075208622,
      213261112,
      2463272603,
      3855990285,
      2094854071,
      198958881,
      2262029012,
      4057260610,
      1759359992,
      534414190,
      2176718541,
      4139329115,
      1873836001,
      414664567,
      2282248934,
      4279200368,
      1711684554,
      285281116,
      2405801727,
      4167216745,
      1634467795,
      376229701,
      2685067896,
      3608007406,
      1308918612,
      956543938,
      2808555105,
      3495958263,
      1231636301,
      1047427035,
      2932959818,
      3654703836,
      1088359270,
      936918e3,
      2847714899,
      3736837829,
      1202900863,
      817233897,
      3183342108,
      3401237130,
      1404277552,
      615818150,
      3134207493,
      3453421203,
      1423857449,
      601450431,
      3009837614,
      3294710456,
      1567103746,
      711928724,
      3020668471,
      3272380065,
      1510334235,
      755167117
    ]);
    function ensureBuffer(input) {
      if (Buffer.isBuffer(input)) {
        return input;
      }
      if (typeof input === "number") {
        return Buffer.alloc(input);
      } else if (typeof input === "string") {
        return Buffer.from(input);
      } else {
        throw new Error("input must be buffer, number, or string, received " + typeof input);
      }
    }
    __name(ensureBuffer, "ensureBuffer");
    function bufferizeInt(num) {
      const tmp = ensureBuffer(4);
      tmp.writeInt32BE(num, 0);
      return tmp;
    }
    __name(bufferizeInt, "bufferizeInt");
    function _crc32(buf, previous) {
      buf = ensureBuffer(buf);
      if (Buffer.isBuffer(previous)) {
        previous = previous.readUInt32BE(0);
      }
      let crc = ~~previous ^ -1;
      for (var n10 = 0; n10 < buf.length; n10++) {
        crc = CRC_TABLE[(crc ^ buf[n10]) & 255] ^ crc >>> 8;
      }
      return crc ^ -1;
    }
    __name(_crc32, "_crc32");
    function crc32() {
      return bufferizeInt(_crc32.apply(null, arguments));
    }
    __name(crc32, "crc32");
    crc32.signed = function() {
      return _crc32.apply(null, arguments);
    };
    crc32.unsigned = function() {
      return _crc32.apply(null, arguments) >>> 0;
    };
    var bufferCrc32 = crc32;
    var index = /* @__PURE__ */ getDefaultExportFromCjs(bufferCrc32);
    module2.exports = index;
  }
});

// ../../node_modules/yazl/index.js
var require_yazl = __commonJS({
  "../../node_modules/yazl/index.js"(exports2) {
    var fs51 = require("fs");
    var Transform = require("stream").Transform;
    var PassThrough3 = require("stream").PassThrough;
    var zlib = require("zlib");
    var util11 = require("util");
    var EventEmitter2 = require("events").EventEmitter;
    var errorMonitor = require("events").errorMonitor;
    var crc32 = require_dist();
    exports2.ZipFile = ZipFile;
    exports2.dateToDosDateTime = dateToDosDateTime;
    util11.inherits(ZipFile, EventEmitter2);
    function ZipFile() {
      this.outputStream = new PassThrough3();
      this.entries = [];
      this.outputStreamCursor = 0;
      this.ended = false;
      this.allDone = false;
      this.forceZip64Eocd = false;
      this.errored = false;
      this.on(errorMonitor, function() {
        this.errored = true;
      });
    }
    __name(ZipFile, "ZipFile");
    ZipFile.prototype.addFile = function(realPath, metadataPath, options) {
      var self2 = this;
      metadataPath = validateMetadataPath(metadataPath, false);
      if (options == null) options = {};
      if (shouldIgnoreAdding(self2)) return;
      var entry = new Entry(metadataPath, false, options);
      self2.entries.push(entry);
      fs51.stat(realPath, function(err, stats) {
        if (err) return self2.emit("error", err);
        if (!stats.isFile()) return self2.emit("error", new Error("not a file: " + realPath));
        entry.uncompressedSize = stats.size;
        if (options.mtime == null) entry.setLastModDate(stats.mtime);
        if (options.mode == null) entry.setFileAttributesMode(stats.mode);
        entry.setFileDataPumpFunction(function() {
          var readStream = fs51.createReadStream(realPath);
          entry.state = Entry.FILE_DATA_IN_PROGRESS;
          readStream.on("error", function(err2) {
            self2.emit("error", err2);
          });
          pumpFileDataReadStream(self2, entry, readStream);
        });
        pumpEntries(self2);
      });
    };
    ZipFile.prototype.addReadStream = function(readStream, metadataPath, options) {
      this.addReadStreamLazy(metadataPath, options, function(cb) {
        cb(null, readStream);
      });
    };
    ZipFile.prototype.addReadStreamLazy = function(metadataPath, options, getReadStreamFunction) {
      var self2 = this;
      if (typeof options === "function") {
        getReadStreamFunction = options;
        options = null;
      }
      if (options == null) options = {};
      metadataPath = validateMetadataPath(metadataPath, false);
      if (shouldIgnoreAdding(self2)) return;
      var entry = new Entry(metadataPath, false, options);
      self2.entries.push(entry);
      entry.setFileDataPumpFunction(function() {
        entry.state = Entry.FILE_DATA_IN_PROGRESS;
        getReadStreamFunction(function(err, readStream) {
          if (err) return self2.emit("error", err);
          pumpFileDataReadStream(self2, entry, readStream);
        });
      });
      pumpEntries(self2);
    };
    ZipFile.prototype.addBuffer = function(buffer, metadataPath, options) {
      var self2 = this;
      metadataPath = validateMetadataPath(metadataPath, false);
      if (buffer.length > 1073741823) throw new Error("buffer too large: " + buffer.length + " > 1073741823");
      if (options == null) options = {};
      if (options.size != null) throw new Error("options.size not allowed");
      if (shouldIgnoreAdding(self2)) return;
      var entry = new Entry(metadataPath, false, options);
      entry.uncompressedSize = buffer.length;
      entry.crc32 = crc32.unsigned(buffer);
      entry.crcAndFileSizeKnown = true;
      self2.entries.push(entry);
      if (entry.compressionLevel === 0) {
        setCompressedBuffer(buffer);
      } else {
        zlib.deflateRaw(buffer, { level: entry.compressionLevel }, function(err, compressedBuffer) {
          setCompressedBuffer(compressedBuffer);
        });
      }
      function setCompressedBuffer(compressedBuffer) {
        entry.compressedSize = compressedBuffer.length;
        entry.setFileDataPumpFunction(function() {
          writeToOutputStream(self2, compressedBuffer);
          writeToOutputStream(self2, entry.getDataDescriptor());
          entry.state = Entry.FILE_DATA_DONE;
          setImmediate(function() {
            pumpEntries(self2);
          });
        });
        pumpEntries(self2);
      }
      __name(setCompressedBuffer, "setCompressedBuffer");
    };
    ZipFile.prototype.addEmptyDirectory = function(metadataPath, options) {
      var self2 = this;
      metadataPath = validateMetadataPath(metadataPath, true);
      if (options == null) options = {};
      if (options.size != null) throw new Error("options.size not allowed");
      if (options.compress != null) throw new Error("options.compress not allowed");
      if (options.compressionLevel != null) throw new Error("options.compressionLevel not allowed");
      if (shouldIgnoreAdding(self2)) return;
      var entry = new Entry(metadataPath, true, options);
      self2.entries.push(entry);
      entry.setFileDataPumpFunction(function() {
        writeToOutputStream(self2, entry.getDataDescriptor());
        entry.state = Entry.FILE_DATA_DONE;
        pumpEntries(self2);
      });
      pumpEntries(self2);
    };
    var eocdrSignatureBuffer = bufferFrom([80, 75, 5, 6]);
    ZipFile.prototype.end = function(options, calculatedTotalSizeCallback) {
      if (typeof options === "function") {
        calculatedTotalSizeCallback = options;
        options = null;
      }
      if (options == null) options = {};
      if (this.ended) return;
      this.ended = true;
      if (this.errored) return;
      this.calculatedTotalSizeCallback = calculatedTotalSizeCallback;
      this.forceZip64Eocd = !!options.forceZip64Format;
      if (options.comment) {
        if (typeof options.comment === "string") {
          this.comment = encodeCp437(options.comment);
        } else {
          this.comment = options.comment;
        }
        if (this.comment.length > 65535) throw new Error("comment is too large");
        if (bufferIncludes(this.comment, eocdrSignatureBuffer)) throw new Error("comment contains end of central directory record signature");
      } else {
        this.comment = EMPTY_BUFFER;
      }
      pumpEntries(this);
    };
    function writeToOutputStream(self2, buffer) {
      self2.outputStream.write(buffer);
      self2.outputStreamCursor += buffer.length;
    }
    __name(writeToOutputStream, "writeToOutputStream");
    function pumpFileDataReadStream(self2, entry, readStream) {
      var crc32Watcher = new Crc32Watcher();
      var uncompressedSizeCounter = new ByteCounter();
      var compressor = entry.compressionLevel !== 0 ? new zlib.DeflateRaw({ level: entry.compressionLevel }) : new PassThrough3();
      var compressedSizeCounter = new ByteCounter();
      readStream.pipe(crc32Watcher).pipe(uncompressedSizeCounter).pipe(compressor).pipe(compressedSizeCounter).pipe(self2.outputStream, { end: false });
      compressedSizeCounter.on("end", function() {
        entry.crc32 = crc32Watcher.crc32;
        if (entry.uncompressedSize == null) {
          entry.uncompressedSize = uncompressedSizeCounter.byteCount;
        } else {
          if (entry.uncompressedSize !== uncompressedSizeCounter.byteCount) return self2.emit("error", new Error("file data stream has unexpected number of bytes"));
        }
        entry.compressedSize = compressedSizeCounter.byteCount;
        self2.outputStreamCursor += entry.compressedSize;
        writeToOutputStream(self2, entry.getDataDescriptor());
        entry.state = Entry.FILE_DATA_DONE;
        pumpEntries(self2);
      });
    }
    __name(pumpFileDataReadStream, "pumpFileDataReadStream");
    function determineCompressionLevel(options) {
      if (options.compress != null && options.compressionLevel != null) {
        if (!!options.compress !== !!options.compressionLevel) throw new Error("conflicting settings for compress and compressionLevel");
      }
      if (options.compressionLevel != null) return options.compressionLevel;
      if (options.compress === false) return 0;
      return 6;
    }
    __name(determineCompressionLevel, "determineCompressionLevel");
    function pumpEntries(self2) {
      if (self2.allDone || self2.errored) return;
      if (self2.ended && self2.calculatedTotalSizeCallback != null) {
        var calculatedTotalSize = calculateTotalSize(self2);
        if (calculatedTotalSize != null) {
          self2.calculatedTotalSizeCallback(calculatedTotalSize);
          self2.calculatedTotalSizeCallback = null;
        }
      }
      var entry = getFirstNotDoneEntry();
      function getFirstNotDoneEntry() {
        for (var i32 = 0; i32 < self2.entries.length; i32++) {
          var entry2 = self2.entries[i32];
          if (entry2.state < Entry.FILE_DATA_DONE) return entry2;
        }
        return null;
      }
      __name(getFirstNotDoneEntry, "getFirstNotDoneEntry");
      if (entry != null) {
        if (entry.state < Entry.READY_TO_PUMP_FILE_DATA) return;
        if (entry.state === Entry.FILE_DATA_IN_PROGRESS) return;
        entry.relativeOffsetOfLocalHeader = self2.outputStreamCursor;
        var localFileHeader = entry.getLocalFileHeader();
        writeToOutputStream(self2, localFileHeader);
        entry.doFileDataPump();
      } else {
        if (self2.ended) {
          self2.offsetOfStartOfCentralDirectory = self2.outputStreamCursor;
          self2.entries.forEach(function(entry2) {
            var centralDirectoryRecord = entry2.getCentralDirectoryRecord();
            writeToOutputStream(self2, centralDirectoryRecord);
          });
          writeToOutputStream(self2, getEndOfCentralDirectoryRecord(self2));
          self2.outputStream.end();
          self2.allDone = true;
        }
      }
    }
    __name(pumpEntries, "pumpEntries");
    function calculateTotalSize(self2) {
      var pretendOutputCursor = 0;
      var centralDirectorySize = 0;
      for (var i32 = 0; i32 < self2.entries.length; i32++) {
        var entry = self2.entries[i32];
        if (entry.compressionLevel !== 0) return -1;
        if (entry.state >= Entry.READY_TO_PUMP_FILE_DATA) {
          if (entry.uncompressedSize == null) return -1;
        } else {
          if (entry.uncompressedSize == null) return null;
        }
        entry.relativeOffsetOfLocalHeader = pretendOutputCursor;
        var useZip64Format = entry.useZip64Format();
        pretendOutputCursor += LOCAL_FILE_HEADER_FIXED_SIZE + entry.utf8FileName.length;
        pretendOutputCursor += entry.uncompressedSize;
        if (!entry.crcAndFileSizeKnown) {
          if (useZip64Format) {
            pretendOutputCursor += ZIP64_DATA_DESCRIPTOR_SIZE;
          } else {
            pretendOutputCursor += DATA_DESCRIPTOR_SIZE;
          }
        }
        centralDirectorySize += CENTRAL_DIRECTORY_RECORD_FIXED_SIZE + entry.utf8FileName.length + entry.fileComment.length;
        if (!entry.forceDosTimestamp) {
          centralDirectorySize += INFO_ZIP_UNIVERSAL_TIMESTAMP_EXTRA_FIELD_SIZE;
        }
        if (useZip64Format) {
          centralDirectorySize += ZIP64_EXTENDED_INFORMATION_EXTRA_FIELD_SIZE;
        }
      }
      var endOfCentralDirectorySize = 0;
      if (self2.forceZip64Eocd || self2.entries.length >= 65535 || centralDirectorySize >= 65535 || pretendOutputCursor >= 4294967295) {
        endOfCentralDirectorySize += ZIP64_END_OF_CENTRAL_DIRECTORY_RECORD_SIZE + ZIP64_END_OF_CENTRAL_DIRECTORY_LOCATOR_SIZE;
      }
      endOfCentralDirectorySize += END_OF_CENTRAL_DIRECTORY_RECORD_SIZE + self2.comment.length;
      return pretendOutputCursor + centralDirectorySize + endOfCentralDirectorySize;
    }
    __name(calculateTotalSize, "calculateTotalSize");
    function shouldIgnoreAdding(self2) {
      if (self2.ended) throw new Error("cannot add entries after calling end()");
      if (self2.errored) return true;
      return false;
    }
    __name(shouldIgnoreAdding, "shouldIgnoreAdding");
    var ZIP64_END_OF_CENTRAL_DIRECTORY_RECORD_SIZE = 56;
    var ZIP64_END_OF_CENTRAL_DIRECTORY_LOCATOR_SIZE = 20;
    var END_OF_CENTRAL_DIRECTORY_RECORD_SIZE = 22;
    function getEndOfCentralDirectoryRecord(self2, actuallyJustTellMeHowLongItWouldBe) {
      var needZip64Format = false;
      var normalEntriesLength = self2.entries.length;
      if (self2.forceZip64Eocd || self2.entries.length >= 65535) {
        normalEntriesLength = 65535;
        needZip64Format = true;
      }
      var sizeOfCentralDirectory = self2.outputStreamCursor - self2.offsetOfStartOfCentralDirectory;
      var normalSizeOfCentralDirectory = sizeOfCentralDirectory;
      if (self2.forceZip64Eocd || sizeOfCentralDirectory >= 4294967295) {
        normalSizeOfCentralDirectory = 4294967295;
        needZip64Format = true;
      }
      var normalOffsetOfStartOfCentralDirectory = self2.offsetOfStartOfCentralDirectory;
      if (self2.forceZip64Eocd || self2.offsetOfStartOfCentralDirectory >= 4294967295) {
        normalOffsetOfStartOfCentralDirectory = 4294967295;
        needZip64Format = true;
      }
      if (actuallyJustTellMeHowLongItWouldBe) {
        if (needZip64Format) {
          return ZIP64_END_OF_CENTRAL_DIRECTORY_RECORD_SIZE + ZIP64_END_OF_CENTRAL_DIRECTORY_LOCATOR_SIZE + END_OF_CENTRAL_DIRECTORY_RECORD_SIZE;
        } else {
          return END_OF_CENTRAL_DIRECTORY_RECORD_SIZE;
        }
      }
      var eocdrBuffer = bufferAlloc(END_OF_CENTRAL_DIRECTORY_RECORD_SIZE + self2.comment.length);
      eocdrBuffer.writeUInt32LE(101010256, 0);
      eocdrBuffer.writeUInt16LE(0, 4);
      eocdrBuffer.writeUInt16LE(0, 6);
      eocdrBuffer.writeUInt16LE(normalEntriesLength, 8);
      eocdrBuffer.writeUInt16LE(normalEntriesLength, 10);
      eocdrBuffer.writeUInt32LE(normalSizeOfCentralDirectory, 12);
      eocdrBuffer.writeUInt32LE(normalOffsetOfStartOfCentralDirectory, 16);
      eocdrBuffer.writeUInt16LE(self2.comment.length, 20);
      self2.comment.copy(eocdrBuffer, 22);
      if (!needZip64Format) return eocdrBuffer;
      var zip64EocdrBuffer = bufferAlloc(ZIP64_END_OF_CENTRAL_DIRECTORY_RECORD_SIZE);
      zip64EocdrBuffer.writeUInt32LE(101075792, 0);
      writeUInt64LE(zip64EocdrBuffer, ZIP64_END_OF_CENTRAL_DIRECTORY_RECORD_SIZE - 12, 4);
      zip64EocdrBuffer.writeUInt16LE(VERSION_MADE_BY, 12);
      zip64EocdrBuffer.writeUInt16LE(VERSION_NEEDED_TO_EXTRACT_ZIP64, 14);
      zip64EocdrBuffer.writeUInt32LE(0, 16);
      zip64EocdrBuffer.writeUInt32LE(0, 20);
      writeUInt64LE(zip64EocdrBuffer, self2.entries.length, 24);
      writeUInt64LE(zip64EocdrBuffer, self2.entries.length, 32);
      writeUInt64LE(zip64EocdrBuffer, sizeOfCentralDirectory, 40);
      writeUInt64LE(zip64EocdrBuffer, self2.offsetOfStartOfCentralDirectory, 48);
      var zip64EocdlBuffer = bufferAlloc(ZIP64_END_OF_CENTRAL_DIRECTORY_LOCATOR_SIZE);
      zip64EocdlBuffer.writeUInt32LE(117853008, 0);
      zip64EocdlBuffer.writeUInt32LE(0, 4);
      writeUInt64LE(zip64EocdlBuffer, self2.outputStreamCursor, 8);
      zip64EocdlBuffer.writeUInt32LE(1, 16);
      return Buffer.concat([
        zip64EocdrBuffer,
        zip64EocdlBuffer,
        eocdrBuffer
      ]);
    }
    __name(getEndOfCentralDirectoryRecord, "getEndOfCentralDirectoryRecord");
    function validateMetadataPath(metadataPath, isDirectory) {
      if (metadataPath === "") throw new Error("empty metadataPath");
      metadataPath = metadataPath.replace(/\\/g, "/");
      if (/^[a-zA-Z]:/.test(metadataPath) || /^\//.test(metadataPath)) throw new Error("absolute path: " + metadataPath);
      if (metadataPath.split("/").indexOf("..") !== -1) throw new Error("invalid relative path: " + metadataPath);
      var looksLikeDirectory = /\/$/.test(metadataPath);
      if (isDirectory) {
        if (!looksLikeDirectory) metadataPath += "/";
      } else {
        if (looksLikeDirectory) throw new Error("file path cannot end with '/': " + metadataPath);
      }
      return metadataPath;
    }
    __name(validateMetadataPath, "validateMetadataPath");
    var EMPTY_BUFFER = bufferAlloc(0);
    function Entry(metadataPath, isDirectory, options) {
      this.utf8FileName = bufferFrom(metadataPath);
      if (this.utf8FileName.length > 65535) throw new Error("utf8 file name too long. " + utf8FileName.length + " > 65535");
      this.isDirectory = isDirectory;
      this.state = Entry.WAITING_FOR_METADATA;
      this.setLastModDate(options.mtime != null ? options.mtime : /* @__PURE__ */ new Date());
      this.forceDosTimestamp = !!options.forceDosTimestamp;
      if (options.mode != null) {
        this.setFileAttributesMode(options.mode);
      } else {
        this.setFileAttributesMode(isDirectory ? 16893 : 33204);
      }
      if (isDirectory) {
        this.crcAndFileSizeKnown = true;
        this.crc32 = 0;
        this.uncompressedSize = 0;
        this.compressedSize = 0;
      } else {
        this.crcAndFileSizeKnown = false;
        this.crc32 = null;
        this.uncompressedSize = null;
        this.compressedSize = null;
        if (options.size != null) this.uncompressedSize = options.size;
      }
      if (isDirectory) {
        this.compressionLevel = 0;
      } else {
        this.compressionLevel = determineCompressionLevel(options);
      }
      this.forceZip64Format = !!options.forceZip64Format;
      if (options.fileComment) {
        if (typeof options.fileComment === "string") {
          this.fileComment = bufferFrom(options.fileComment, "utf-8");
        } else {
          this.fileComment = options.fileComment;
        }
        if (this.fileComment.length > 65535) throw new Error("fileComment is too large");
      } else {
        this.fileComment = EMPTY_BUFFER;
      }
    }
    __name(Entry, "Entry");
    Entry.WAITING_FOR_METADATA = 0;
    Entry.READY_TO_PUMP_FILE_DATA = 1;
    Entry.FILE_DATA_IN_PROGRESS = 2;
    Entry.FILE_DATA_DONE = 3;
    Entry.prototype.setLastModDate = function(date7) {
      this.mtime = date7;
      var dosDateTime = dateToDosDateTime(date7);
      this.lastModFileTime = dosDateTime.time;
      this.lastModFileDate = dosDateTime.date;
    };
    Entry.prototype.setFileAttributesMode = function(mode) {
      if ((mode & 65535) !== mode) throw new Error("invalid mode. expected: 0 <= " + mode + " <= 65535");
      this.externalFileAttributes = mode << 16 >>> 0;
    };
    Entry.prototype.setFileDataPumpFunction = function(doFileDataPump) {
      this.doFileDataPump = doFileDataPump;
      this.state = Entry.READY_TO_PUMP_FILE_DATA;
    };
    Entry.prototype.useZip64Format = function() {
      return this.forceZip64Format || this.uncompressedSize != null && this.uncompressedSize > 4294967294 || this.compressedSize != null && this.compressedSize > 4294967294 || this.relativeOffsetOfLocalHeader != null && this.relativeOffsetOfLocalHeader > 4294967294;
    };
    var LOCAL_FILE_HEADER_FIXED_SIZE = 30;
    var VERSION_NEEDED_TO_EXTRACT_UTF8 = 20;
    var VERSION_NEEDED_TO_EXTRACT_ZIP64 = 45;
    var VERSION_MADE_BY = 3 << 8 | 63;
    var FILE_NAME_IS_UTF8 = 1 << 11;
    var UNKNOWN_CRC32_AND_FILE_SIZES = 1 << 3;
    Entry.prototype.getLocalFileHeader = function() {
      var crc322 = 0;
      var compressedSize = 0;
      var uncompressedSize = 0;
      if (this.crcAndFileSizeKnown) {
        crc322 = this.crc32;
        compressedSize = this.compressedSize;
        uncompressedSize = this.uncompressedSize;
      }
      var fixedSizeStuff = bufferAlloc(LOCAL_FILE_HEADER_FIXED_SIZE);
      var generalPurposeBitFlag = FILE_NAME_IS_UTF8;
      if (!this.crcAndFileSizeKnown) generalPurposeBitFlag |= UNKNOWN_CRC32_AND_FILE_SIZES;
      fixedSizeStuff.writeUInt32LE(67324752, 0);
      fixedSizeStuff.writeUInt16LE(VERSION_NEEDED_TO_EXTRACT_UTF8, 4);
      fixedSizeStuff.writeUInt16LE(generalPurposeBitFlag, 6);
      fixedSizeStuff.writeUInt16LE(this.getCompressionMethod(), 8);
      fixedSizeStuff.writeUInt16LE(this.lastModFileTime, 10);
      fixedSizeStuff.writeUInt16LE(this.lastModFileDate, 12);
      fixedSizeStuff.writeUInt32LE(crc322, 14);
      fixedSizeStuff.writeUInt32LE(compressedSize, 18);
      fixedSizeStuff.writeUInt32LE(uncompressedSize, 22);
      fixedSizeStuff.writeUInt16LE(this.utf8FileName.length, 26);
      fixedSizeStuff.writeUInt16LE(0, 28);
      return Buffer.concat([
        fixedSizeStuff,
        // file name (variable size)
        this.utf8FileName
        // extra field (variable size)
        // no extra fields
      ]);
    };
    var DATA_DESCRIPTOR_SIZE = 16;
    var ZIP64_DATA_DESCRIPTOR_SIZE = 24;
    Entry.prototype.getDataDescriptor = function() {
      if (this.crcAndFileSizeKnown) {
        return EMPTY_BUFFER;
      }
      if (!this.useZip64Format()) {
        var buffer = bufferAlloc(DATA_DESCRIPTOR_SIZE);
        buffer.writeUInt32LE(134695760, 0);
        buffer.writeUInt32LE(this.crc32, 4);
        buffer.writeUInt32LE(this.compressedSize, 8);
        buffer.writeUInt32LE(this.uncompressedSize, 12);
        return buffer;
      } else {
        var buffer = bufferAlloc(ZIP64_DATA_DESCRIPTOR_SIZE);
        buffer.writeUInt32LE(134695760, 0);
        buffer.writeUInt32LE(this.crc32, 4);
        writeUInt64LE(buffer, this.compressedSize, 8);
        writeUInt64LE(buffer, this.uncompressedSize, 16);
        return buffer;
      }
    };
    var CENTRAL_DIRECTORY_RECORD_FIXED_SIZE = 46;
    var INFO_ZIP_UNIVERSAL_TIMESTAMP_EXTRA_FIELD_SIZE = 9;
    var ZIP64_EXTENDED_INFORMATION_EXTRA_FIELD_SIZE = 28;
    Entry.prototype.getCentralDirectoryRecord = function() {
      var fixedSizeStuff = bufferAlloc(CENTRAL_DIRECTORY_RECORD_FIXED_SIZE);
      var generalPurposeBitFlag = FILE_NAME_IS_UTF8;
      if (!this.crcAndFileSizeKnown) generalPurposeBitFlag |= UNKNOWN_CRC32_AND_FILE_SIZES;
      var izutefBuffer = EMPTY_BUFFER;
      if (!this.forceDosTimestamp) {
        izutefBuffer = bufferAlloc(INFO_ZIP_UNIVERSAL_TIMESTAMP_EXTRA_FIELD_SIZE);
        izutefBuffer.writeUInt16LE(21589, 0);
        izutefBuffer.writeUInt16LE(INFO_ZIP_UNIVERSAL_TIMESTAMP_EXTRA_FIELD_SIZE - 4, 2);
        var EB_UT_FL_MTIME = 1 << 0;
        var EB_UT_FL_ATIME = 1 << 1;
        izutefBuffer.writeUInt8(EB_UT_FL_MTIME | EB_UT_FL_ATIME, 4);
        var timestamp = Math.floor(this.mtime.getTime() / 1e3);
        if (timestamp < -2147483648) timestamp = -2147483648;
        if (timestamp > 2147483647) timestamp = 2147483647;
        izutefBuffer.writeUInt32LE(timestamp, 5);
      }
      var normalCompressedSize = this.compressedSize;
      var normalUncompressedSize = this.uncompressedSize;
      var normalRelativeOffsetOfLocalHeader = this.relativeOffsetOfLocalHeader;
      var versionNeededToExtract = VERSION_NEEDED_TO_EXTRACT_UTF8;
      var zeiefBuffer = EMPTY_BUFFER;
      if (this.useZip64Format()) {
        normalCompressedSize = 4294967295;
        normalUncompressedSize = 4294967295;
        normalRelativeOffsetOfLocalHeader = 4294967295;
        versionNeededToExtract = VERSION_NEEDED_TO_EXTRACT_ZIP64;
        zeiefBuffer = bufferAlloc(ZIP64_EXTENDED_INFORMATION_EXTRA_FIELD_SIZE);
        zeiefBuffer.writeUInt16LE(1, 0);
        zeiefBuffer.writeUInt16LE(ZIP64_EXTENDED_INFORMATION_EXTRA_FIELD_SIZE - 4, 2);
        writeUInt64LE(zeiefBuffer, this.uncompressedSize, 4);
        writeUInt64LE(zeiefBuffer, this.compressedSize, 12);
        writeUInt64LE(zeiefBuffer, this.relativeOffsetOfLocalHeader, 20);
      }
      fixedSizeStuff.writeUInt32LE(33639248, 0);
      fixedSizeStuff.writeUInt16LE(VERSION_MADE_BY, 4);
      fixedSizeStuff.writeUInt16LE(versionNeededToExtract, 6);
      fixedSizeStuff.writeUInt16LE(generalPurposeBitFlag, 8);
      fixedSizeStuff.writeUInt16LE(this.getCompressionMethod(), 10);
      fixedSizeStuff.writeUInt16LE(this.lastModFileTime, 12);
      fixedSizeStuff.writeUInt16LE(this.lastModFileDate, 14);
      fixedSizeStuff.writeUInt32LE(this.crc32, 16);
      fixedSizeStuff.writeUInt32LE(normalCompressedSize, 20);
      fixedSizeStuff.writeUInt32LE(normalUncompressedSize, 24);
      fixedSizeStuff.writeUInt16LE(this.utf8FileName.length, 28);
      fixedSizeStuff.writeUInt16LE(izutefBuffer.length + zeiefBuffer.length, 30);
      fixedSizeStuff.writeUInt16LE(this.fileComment.length, 32);
      fixedSizeStuff.writeUInt16LE(0, 34);
      fixedSizeStuff.writeUInt16LE(0, 36);
      fixedSizeStuff.writeUInt32LE(this.externalFileAttributes, 38);
      fixedSizeStuff.writeUInt32LE(normalRelativeOffsetOfLocalHeader, 42);
      return Buffer.concat([
        fixedSizeStuff,
        // file name (variable size)
        this.utf8FileName,
        // extra field (variable size)
        izutefBuffer,
        zeiefBuffer,
        // file comment (variable size)
        this.fileComment
      ]);
    };
    Entry.prototype.getCompressionMethod = function() {
      var NO_COMPRESSION = 0;
      var DEFLATE_COMPRESSION = 8;
      return this.compressionLevel === 0 ? NO_COMPRESSION : DEFLATE_COMPRESSION;
    };
    var minDosDate = new Date(1980, 0, 1);
    var maxDosDate = new Date(2107, 11, 31, 23, 59, 58);
    function dateToDosDateTime(jsDate) {
      if (jsDate < minDosDate) jsDate = minDosDate;
      else if (jsDate > maxDosDate) jsDate = maxDosDate;
      var date7 = 0;
      date7 |= jsDate.getDate() & 31;
      date7 |= (jsDate.getMonth() + 1 & 15) << 5;
      date7 |= (jsDate.getFullYear() - 1980 & 127) << 9;
      var time7 = 0;
      time7 |= Math.floor(jsDate.getSeconds() / 2);
      time7 |= (jsDate.getMinutes() & 63) << 5;
      time7 |= (jsDate.getHours() & 31) << 11;
      return { date: date7, time: time7 };
    }
    __name(dateToDosDateTime, "dateToDosDateTime");
    function writeUInt64LE(buffer, n10, offset) {
      var high = Math.floor(n10 / 4294967296);
      var low = n10 % 4294967296;
      buffer.writeUInt32LE(low, offset);
      buffer.writeUInt32LE(high, offset + 4);
    }
    __name(writeUInt64LE, "writeUInt64LE");
    util11.inherits(ByteCounter, Transform);
    function ByteCounter(options) {
      Transform.call(this, options);
      this.byteCount = 0;
    }
    __name(ByteCounter, "ByteCounter");
    ByteCounter.prototype._transform = function(chunk, encoding, cb) {
      this.byteCount += chunk.length;
      cb(null, chunk);
    };
    util11.inherits(Crc32Watcher, Transform);
    function Crc32Watcher(options) {
      Transform.call(this, options);
      this.crc32 = 0;
    }
    __name(Crc32Watcher, "Crc32Watcher");
    Crc32Watcher.prototype._transform = function(chunk, encoding, cb) {
      this.crc32 = crc32.unsigned(chunk, this.crc32);
      cb(null, chunk);
    };
    var cp437 = "\0\u263A\u263B\u2665\u2666\u2663\u2660\u2022\u25D8\u25CB\u25D9\u2642\u2640\u266A\u266B\u263C\u25BA\u25C4\u2195\u203C\xB6\xA7\u25AC\u21A8\u2191\u2193\u2192\u2190\u221F\u2194\u25B2\u25BC !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~\u2302\xC7\xFC\xE9\xE2\xE4\xE0\xE5\xE7\xEA\xEB\xE8\xEF\xEE\xEC\xC4\xC5\xC9\xE6\xC6\xF4\xF6\xF2\xFB\xF9\xFF\xD6\xDC\xA2\xA3\xA5\u20A7\u0192\xE1\xED\xF3\xFA\xF1\xD1\xAA\xBA\xBF\u2310\xAC\xBD\xBC\xA1\xAB\xBB\u2591\u2592\u2593\u2502\u2524\u2561\u2562\u2556\u2555\u2563\u2551\u2557\u255D\u255C\u255B\u2510\u2514\u2534\u252C\u251C\u2500\u253C\u255E\u255F\u255A\u2554\u2569\u2566\u2560\u2550\u256C\u2567\u2568\u2564\u2565\u2559\u2558\u2552\u2553\u256B\u256A\u2518\u250C\u2588\u2584\u258C\u2590\u2580\u03B1\xDF\u0393\u03C0\u03A3\u03C3\xB5\u03C4\u03A6\u0398\u03A9\u03B4\u221E\u03C6\u03B5\u2229\u2261\xB1\u2265\u2264\u2320\u2321\xF7\u2248\xB0\u2219\xB7\u221A\u207F\xB2\u25A0\xA0";
    if (cp437.length !== 256) throw new Error("assertion failure");
    var reverseCp437 = null;
    function encodeCp437(string) {
      if (/^[\x20-\x7e]*$/.test(string)) {
        return bufferFrom(string, "utf-8");
      }
      if (reverseCp437 == null) {
        reverseCp437 = {};
        for (var i32 = 0; i32 < cp437.length; i32++) {
          reverseCp437[cp437[i32]] = i32;
        }
      }
      var result2 = bufferAlloc(string.length);
      for (var i32 = 0; i32 < string.length; i32++) {
        var b32 = reverseCp437[string[i32]];
        if (b32 == null) throw new Error("character not encodable in CP437: " + JSON.stringify(string[i32]));
        result2[i32] = b32;
      }
      return result2;
    }
    __name(encodeCp437, "encodeCp437");
    function bufferAlloc(size) {
      bufferAlloc = modern;
      try {
        return bufferAlloc(size);
      } catch (e32) {
        bufferAlloc = legacy;
        return bufferAlloc(size);
      }
      function modern(size2) {
        return Buffer.allocUnsafe(size2);
      }
      __name(modern, "modern");
      function legacy(size2) {
        return new Buffer(size2);
      }
      __name(legacy, "legacy");
    }
    __name(bufferAlloc, "bufferAlloc");
    function bufferFrom(something, encoding) {
      bufferFrom = modern;
      try {
        return bufferFrom(something, encoding);
      } catch (e32) {
        bufferFrom = legacy;
        return bufferFrom(something, encoding);
      }
      function modern(something2, encoding2) {
        return Buffer.from(something2, encoding2);
      }
      __name(modern, "modern");
      function legacy(something2, encoding2) {
        return new Buffer(something2, encoding2);
      }
      __name(legacy, "legacy");
    }
    __name(bufferFrom, "bufferFrom");
    function bufferIncludes(buffer, content) {
      bufferIncludes = modern;
      try {
        return bufferIncludes(buffer, content);
      } catch (e32) {
        bufferIncludes = legacy;
        return bufferIncludes(buffer, content);
      }
      function modern(buffer2, content2) {
        return buffer2.includes(content2);
      }
      __name(modern, "modern");
      function legacy(buffer2, content2) {
        for (var i32 = 0; i32 <= buffer2.length - content2.length; i32++) {
          for (var j32 = 0; ; j32++) {
            if (j32 === content2.length) return true;
            if (buffer2[i32 + j32] !== content2[j32]) break;
          }
        }
        return false;
      }
      __name(legacy, "legacy");
    }
    __name(bufferIncludes, "bufferIncludes");
  }
});

// ../@aws-cdk/private-tools/lib/zip/index.js
var require_zip = __commonJS({
  "../@aws-cdk/private-tools/lib/zip/index.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.zipDirectory = zipDirectory3;
    exports2.zipString = zipString2;
    var fs_1 = require("fs");
    var path47 = require("path");
    var fast_glob_1 = require_out4();
    var yazl_1 = require_yazl();
    function epoch() {
      return new Date(1980, 0, 1, 0, 0, 0);
    }
    __name(epoch, "epoch");
    async function zipDirectory3(directory, outputFile, eventEmitter = () => {
    }) {
      const temporaryOutputFile = `${outputFile}.${randomString()}._tmp`;
      await writeZipFile(directory, temporaryOutputFile);
      await moveIntoPlace(temporaryOutputFile, outputFile, eventEmitter);
    }
    __name(zipDirectory3, "zipDirectory");
    function zipString2(fileName, rawString) {
      return new Promise((resolve13, reject) => {
        const buffers = [];
        const zip2 = new yazl_1.ZipFile();
        zip2.outputStream.on("data", (chunk) => buffers.push(chunk));
        zip2.outputStream.on("error", reject);
        zip2.outputStream.on("end", () => resolve13(Buffer.concat(buffers)));
        zip2.addBuffer(Buffer.from(rawString), fileName, {
          mtime: epoch(),
          // reset date to get the same hash for the same content
          // Only emit the DOS timestamp (no UTC "universal time" extended field),
          // so the archive bytes do not depend on the machine's timezone.
          forceDosTimestamp: true
        });
        zip2.end();
      });
    }
    __name(zipString2, "zipString");
    function writeZipFile(directory, outputFile) {
      return new Promise(async (ok, fail) => {
        const globOptions = {
          dot: true,
          onlyFiles: true,
          followSymbolicLinks: true,
          cwd: directory
        };
        const files = (0, fast_glob_1.globSync)("**", globOptions);
        const zip2 = new yazl_1.ZipFile();
        zip2.outputStream.on("error", fail);
        const output = (0, fs_1.createWriteStream)(outputFile);
        output.on("error", fail);
        output.once("close", ok);
        zip2.outputStream.pipe(output);
        for (const file of files) {
          const fullPath = path47.resolve(directory, file);
          const [data3, stat8] = await Promise.all([fs_1.promises.readFile(fullPath), fs_1.promises.stat(fullPath)]);
          zip2.addBuffer(data3, file, {
            mtime: epoch(),
            // reset dates to get the same hash for the same content
            mode: stat8.mode,
            // Only emit the DOS timestamp (no UTC "universal time" extended field),
            // so the archive bytes do not depend on the machine's timezone.
            forceDosTimestamp: true
          });
        }
        zip2.end();
      });
    }
    __name(writeZipFile, "writeZipFile");
    async function moveIntoPlace(source, target, eventEmitter) {
      let delay = 100;
      let attempts = 5;
      while (true) {
        try {
          await fs_1.promises.rename(source, target);
          return;
        } catch (e32) {
          if (e32.code !== "EPERM" || attempts-- <= 0) {
            throw e32;
          }
          eventEmitter(e32.message);
          await sleep4(Math.floor(Math.random() * delay));
          delay *= 2;
        }
      }
    }
    __name(moveIntoPlace, "moveIntoPlace");
    function sleep4(ms) {
      return new Promise((ok) => setTimeout(ok, ms));
    }
    __name(sleep4, "sleep");
    function randomString() {
      return Math.random().toString(36).replace(/[^a-z0-9]+/g, "");
    }
    __name(randomString, "randomString");
  }
});

// ../@aws-cdk/cdk-assets-lib/lib/private/tools.ts
var tools_exports = {};
var init_tools = __esm({
  "../@aws-cdk/cdk-assets-lib/lib/private/tools.ts"() {
    "use strict";
    __reExport(tools_exports, __toESM(require_zip()));
  }
});

// ../@aws-cdk/cdk-assets-lib/lib/private/handlers/files.ts
async function objectExists(s3, bucket, key) {
  const response = await s3.listObjectsV2({
    Bucket: bucket,
    Prefix: key,
    MaxKeys: 1
  });
  return response.Contents != null && response.Contents.some(
    (object) => object.Key === key && (object.Size == null || object.Size > EMPTY_ZIP_FILE_SIZE)
  );
}
async function cached(cache32, key, factory) {
  if (cache32.has(key)) {
    return cache32.get(key);
  }
  const fresh = await factory(key);
  cache32.set(key, fresh);
  return fresh;
}
var import_fs, path9, import_cloud_assembly_schema, mime, EMPTY_ZIP_FILE_SIZE, FileAssetHandler, BucketInformation;
var init_files = __esm({
  "../@aws-cdk/cdk-assets-lib/lib/private/handlers/files.ts"() {
    "use strict";
    import_fs = require("fs");
    path9 = __toESM(require("path"));
    import_cloud_assembly_schema = __toESM(require_lib2());
    mime = __toESM(require_mime());
    init_client_options();
    init_progress();
    init_fs_extra();
    init_placeholders2();
    init_shell();
    init_tools();
    EMPTY_ZIP_FILE_SIZE = 22;
    FileAssetHandler = class {
      constructor(workDir, asset, host) {
        this.workDir = workDir;
        this.asset = asset;
        this.host = host;
        this.fileCacheRoot = path9.join(workDir, ".cache");
      }
      static {
        __name(this, "FileAssetHandler");
      }
      async build() {
      }
      async isPublished() {
        const destination = await replaceAwsPlaceholders(this.asset.destination, this.host.aws);
        const s3Url = `s3://${destination.bucketName}/${destination.objectKey}`;
        try {
          const s3 = await this.host.aws.s3Client(destinationToClientOptions(destination));
          this.host.emitMessage("check" /* CHECK */, `Check ${s3Url}`);
          if (await objectExists(s3, destination.bucketName, destination.objectKey)) {
            this.host.emitMessage("found" /* FOUND */, `Found ${s3Url}`);
            return true;
          }
        } catch (e32) {
          this.host.emitMessage("debug" /* DEBUG */, `${e32.message}`);
        }
        return false;
      }
      async publish(options = {}) {
        const destination = await replaceAwsPlaceholders(this.asset.destination, this.host.aws);
        const s3Url = `s3://${destination.bucketName}/${destination.objectKey}`;
        const clientOptions = destinationToClientOptions(destination);
        const s3 = await this.host.aws.s3Client(clientOptions);
        this.host.emitMessage("check" /* CHECK */, `Check ${s3Url}`);
        const bucketInfo = BucketInformation.for(this.host);
        const account = /* @__PURE__ */ __name(async () => (await this.host.aws.discoverTargetAccount(clientOptions)).accountId, "account");
        const allowCrossAccount = options.allowCrossAccount ?? true;
        switch (await bucketInfo.bucketOwnership(
          s3,
          destination.bucketName,
          allowCrossAccount ? void 0 : await account()
        )) {
          case 1 /* MINE */:
            break;
          case 0 /* DOES_NOT_EXIST */:
            throw new Error(
              `No bucket named '${destination.bucketName}'. Is account ${await account()} bootstrapped?`
            );
          case 2 /* NO_ACCESS */:
            throw new Error(
              `Bucket named '${destination.bucketName}' exists, but we dont have access to it.`
            );
          case 3 /* SOMEONE_ELSES_AND_HAVE_ACCESS */:
            if (!allowCrossAccount) {
              throw new Error(
                `\u2757\u2757 UNEXPECTED BUCKET OWNER DETECTED \u2757\u2757

              We've detected that the S3 bucket ${destination.bucketName} was
              originally created in account ${await account()} as part of the CloudFormation stack CDKToolkit,
              but now resides in a different AWS account. To prevent cross-account asset bucket access of your
              deployments, CDK will stop now.

              If this situation is intentional and you own the AWS account that the bucket has moved to, remove the
              resource named StagingBucket from the template of CloudFormation stack CDKToolkit and try again.

              If this situation is not intentional, we strongly recommend auditing your account to make sure all
              resources are configured the way you expect them [1]. For questions or concerns, please contact
              AWS Support [2].

              [1] https://repost.aws/knowledge-center/potential-account-compromise

              [2] https://aws.amazon.com/support`
              );
            }
            break;
        }
        if (!options.force && await objectExists(s3, destination.bucketName, destination.objectKey)) {
          this.host.emitMessage("found" /* FOUND */, `Found ${s3Url}`);
          return;
        }
        let paramsEncryption = {};
        const encryption2 = await bucketInfo.bucketEncryption(s3, destination.bucketName);
        switch (encryption2.type) {
          case "no_encryption":
            break;
          case "aes256":
            paramsEncryption = { ServerSideEncryption: "AES256" };
            break;
          case "kms":
            paramsEncryption = {
              ServerSideEncryption: "aws:kms",
              SSEKMSKeyId: encryption2.kmsKeyId
            };
            break;
          case "does_not_exist":
            this.host.emitMessage(
              "debug" /* DEBUG */,
              `No bucket named '${destination.bucketName}'. Is account ${await account()} bootstrapped?`
            );
            break;
          case "access_denied":
            this.host.emitMessage(
              "debug" /* DEBUG */,
              `Could not read encryption settings of bucket '${destination.bucketName}': uploading with default settings ("cdk bootstrap" to version 9 if your organization's policies prevent a successful upload or to get rid of this message).`
            );
            break;
        }
        if (this.host.aborted) {
          return;
        }
        const publishFile = this.asset.source.executable ? await this.externalPackageFile(this.asset.source.executable) : await this.packageFile(this.asset.source);
        this.host.emitMessage("upload" /* UPLOAD */, `Upload ${s3Url}`);
        const params = Object.assign(
          {},
          {
            Bucket: destination.bucketName,
            Key: destination.objectKey,
            Body: (0, import_fs.createReadStream)(publishFile.packagedPath),
            ContentType: publishFile.contentType,
            ChecksumAlgorithm: "SHA256"
          },
          paramsEncryption
        );
        await s3.upload(params);
      }
      async packageFile(source) {
        if (!source.path) {
          throw new Error(
            `'path' is expected in the File asset source, got: ${JSON.stringify(source)}`
          );
        }
        const fullPath = path9.resolve(this.workDir, source.path);
        if (source.packaging === import_cloud_assembly_schema.FileAssetPackaging.ZIP_DIRECTORY) {
          const contentType = "application/zip";
          await import_fs.promises.mkdir(this.fileCacheRoot, { recursive: true });
          const packagedPath = path9.join(this.fileCacheRoot, `${this.asset.id.assetId}.zip`);
          if (await pathExists(packagedPath)) {
            this.host.emitMessage("cached" /* CACHED */, `From cache ${packagedPath}`);
            return { packagedPath, contentType };
          }
          this.host.emitMessage("build" /* BUILD */, `Zip ${fullPath} -> ${packagedPath}`);
          await (0, tools_exports.zipDirectory)(fullPath, packagedPath, (m20) => this.host.emitMessage("debug" /* DEBUG */, m20));
          return { packagedPath, contentType };
        } else {
          const contentType = mime.getType(fullPath) ?? "application/octet-stream";
          return { packagedPath: fullPath, contentType };
        }
      }
      async externalPackageFile(executable) {
        this.host.emitMessage("build" /* BUILD */, `Building asset source using command: '${executable}'`);
        const shellEventPublisher = shellEventPublisherFromEventEmitter(this.host.emitMessage);
        return {
          packagedPath: (await shell(executable, { subprocessOutputDestination: "ignore", shellEventPublisher })).trim(),
          contentType: "application/zip"
        };
      }
    };
    __name(objectExists, "objectExists");
    BucketInformation = class _BucketInformation {
      constructor() {
        this.ownerships = /* @__PURE__ */ new Map();
        this.encryptions = /* @__PURE__ */ new Map();
      }
      static {
        __name(this, "BucketInformation");
      }
      static for(host) {
        const existing = _BucketInformation.caches.get(host);
        if (existing) {
          return existing;
        }
        const fresh = new _BucketInformation();
        _BucketInformation.caches.set(host, fresh);
        return fresh;
      }
      static {
        this.caches = /* @__PURE__ */ new WeakMap();
      }
      async bucketOwnership(s3, bucket, expectedAccount) {
        return cached(this.ownerships, bucket, async () => {
          const anyAccount = await this._bucketOwnership(s3, bucket);
          switch (anyAccount) {
            case 1 /* MINE */:
              if (expectedAccount && await this._bucketOwnership(s3, bucket, expectedAccount) === 2 /* NO_ACCESS */) {
                return 3 /* SOMEONE_ELSES_AND_HAVE_ACCESS */;
              }
              return 1 /* MINE */;
            default:
              return anyAccount;
          }
        });
      }
      async bucketEncryption(s3, bucket) {
        return cached(this.encryptions, bucket, () => this._bucketEncryption(s3, bucket));
      }
      async _bucketOwnership(s3, bucket, account) {
        try {
          await s3.getBucketLocation({ Bucket: bucket, ExpectedBucketOwner: account });
          return 1 /* MINE */;
        } catch (e32) {
          if (e32.name === "NoSuchBucket") {
            return 0 /* DOES_NOT_EXIST */;
          }
          if (["AccessDenied", "AllAccessDisabled"].includes(e32.name)) {
            return 2 /* NO_ACCESS */;
          }
          throw e32;
        }
      }
      async _bucketEncryption(s3, bucket) {
        try {
          const encryption = await s3.getBucketEncryption({ Bucket: bucket });
          const l20 = encryption?.ServerSideEncryptionConfiguration?.Rules?.length ?? 0;
          if (l20 > 0) {
            const apply = encryption?.ServerSideEncryptionConfiguration?.Rules?.at(
              0
            )?.ApplyServerSideEncryptionByDefault;
            let ssealgo = apply?.SSEAlgorithm;
            if (ssealgo === "AES256") return { type: "aes256" };
            if (ssealgo === "aws:kms") return { type: "kms", kmsKeyId: apply?.KMSMasterKeyID };
          }
          return { type: "no_encryption" };
        } catch (e32) {
          if (e32.name === "NoSuchBucket") {
            return { type: "does_not_exist" };
          }
          if (e32.name === "ServerSideEncryptionConfigurationNotFoundError") {
            return { type: "no_encryption" };
          }
          if (["AccessDenied", "AllAccessDisabled"].includes(e32.name)) {
            return { type: "access_denied" };
          }
          return { type: "no_encryption" };
        }
      }
    };
    __name(cached, "cached");
  }
});

// ../@aws-cdk/cdk-assets-lib/lib/asset-manifest.ts
var asset_manifest_exports = {};
__export(asset_manifest_exports, {
  AssetManifest: () => AssetManifest,
  DestinationIdentifier: () => DestinationIdentifier,
  DestinationPattern: () => DestinationPattern,
  DockerImageManifestEntry: () => DockerImageManifestEntry,
  FileManifestEntry: () => FileManifestEntry
});
function makeEntries(assets, ctor) {
  const ret = new Array();
  for (const [assetId, asset] of Object.entries(assets)) {
    for (const [destId, destination] of Object.entries(asset.destinations)) {
      ret.push(new ctor(new DestinationIdentifier(assetId, destId), asset.displayName, asset.source, destination));
    }
  }
  return ret;
}
function filterDict(xs, pred) {
  const ret = {};
  for (const [key, value] of Object.entries(xs)) {
    if (pred(value, key)) {
      ret[key] = value;
    }
  }
  return ret;
}
function prefixTreeChars(xs, prefix = "") {
  const ret = new Array();
  for (let i32 = 0; i32 < xs.length; i32++) {
    const isLast = i32 === xs.length - 1;
    const boxChar = isLast ? "\u2514" : "\u251C";
    ret.push(`${prefix}${boxChar}${xs[i32]}`);
  }
  return ret;
}
var fs10, path10, import_cloud_assembly_schema2, AssetManifest, ASSET_TYPES, FileManifestEntry, DockerImageManifestEntry, DestinationIdentifier, DestinationPattern;
var init_asset_manifest = __esm({
  "../@aws-cdk/cdk-assets-lib/lib/asset-manifest.ts"() {
    "use strict";
    fs10 = __toESM(require("fs"));
    path10 = __toESM(require("path"));
    import_cloud_assembly_schema2 = __toESM(require_lib2());
    AssetManifest = class _AssetManifest {
      constructor(directory, manifest) {
        this.manifest = manifest;
        this.directory = directory;
      }
      static {
        __name(this, "AssetManifest");
      }
      static {
        /**
         * The default name of the asset manifest in a cdk.out directory
         */
        this.DEFAULT_FILENAME = "assets.json";
      }
      /**
       * Load an asset manifest from the given file
       */
      static fromFile(fileName) {
        try {
          const obj = import_cloud_assembly_schema2.Manifest.loadAssetManifest(fileName);
          return new _AssetManifest(path10.dirname(fileName), obj);
        } catch (e32) {
          throw new Error(`Cannot read asset manifest '${fileName}': ${e32.message}`);
        }
      }
      /**
       * Load an asset manifest from the given file or directory
       *
       * If the argument given is a directoy, the default asset file name will be used.
       */
      static fromPath(filePath) {
        let st;
        try {
          st = fs10.statSync(filePath);
        } catch (e32) {
          throw new Error(`Cannot read asset manifest at '${filePath}': ${e32.message}`);
        }
        if (st.isDirectory()) {
          return _AssetManifest.fromFile(path10.join(filePath, _AssetManifest.DEFAULT_FILENAME));
        }
        return _AssetManifest.fromFile(filePath);
      }
      /**
       * Select a subset of assets and destinations from this manifest.
       *
       * Only assets with at least 1 selected destination are retained.
       *
       * If selection is not given, everything is returned.
       */
      select(selection) {
        if (selection === void 0) {
          return this;
        }
        const ret = {
          version: this.manifest.version,
          dockerImages: {},
          files: {}
        };
        for (const assetType of ASSET_TYPES) {
          for (const [assetId, asset] of Object.entries(this.manifest[assetType] || {})) {
            const filteredDestinations = filterDict(
              asset.destinations,
              (_, destId) => selection.some((sel) => sel.matches(new DestinationIdentifier(assetId, destId)))
            );
            if (Object.keys(filteredDestinations).length > 0) {
              ret[assetType][assetId] = {
                ...asset,
                destinations: filteredDestinations
              };
            }
          }
        }
        return new _AssetManifest(this.directory, ret);
      }
      /**
       * Describe the asset manifest as a list of strings
       */
      list() {
        return [
          ...describeAssets("file", this.manifest.files || {}),
          ...describeAssets("docker-image", this.manifest.dockerImages || {})
        ];
        function describeAssets(type, assets) {
          const ret = new Array();
          for (const [assetId, asset] of Object.entries(assets || {})) {
            ret.push(`${assetId} ${type} ${JSON.stringify(asset.source)}`);
            const destStrings = Object.entries(asset.destinations).map(
              ([destId, dest]) => ` ${assetId}:${destId} ${JSON.stringify(dest)}`
            );
            ret.push(...prefixTreeChars(destStrings, "  "));
          }
          return ret;
        }
        __name(describeAssets, "describeAssets");
      }
      /**
       * List of assets per destination
       *
       * Returns one asset for every publishable destination. Multiple asset
       * destinations may share the same asset source.
       */
      get entries() {
        return [
          ...makeEntries(this.manifest.files || {}, FileManifestEntry),
          ...makeEntries(this.manifest.dockerImages || {}, DockerImageManifestEntry)
        ];
      }
      /**
       * List of file assets, splat out to destinations
       */
      get files() {
        return makeEntries(this.manifest.files || {}, FileManifestEntry);
      }
    };
    __name(makeEntries, "makeEntries");
    ASSET_TYPES = ["files", "dockerImages"];
    FileManifestEntry = class {
      constructor(id, _displayName, source, destination) {
        this.id = id;
        this._displayName = _displayName;
        this.source = source;
        this.destination = destination;
        this.type = "file";
        this.genericSource = source;
        this.genericDestination = destination;
      }
      static {
        __name(this, "FileManifestEntry");
      }
      displayName(includeDestination) {
        if (includeDestination) {
          return this._displayName ? `${this._displayName} (${this.id.destinationId})` : `${this.id}`;
        } else {
          return this._displayName ? this._displayName : this.id.assetId;
        }
      }
    };
    DockerImageManifestEntry = class {
      constructor(id, _displayName, source, destination) {
        this.id = id;
        this._displayName = _displayName;
        this.source = source;
        this.destination = destination;
        this.type = "docker-image";
        this.genericSource = source;
        this.genericDestination = destination;
      }
      static {
        __name(this, "DockerImageManifestEntry");
      }
      displayName(includeDestination) {
        if (includeDestination) {
          return this._displayName ? `${this._displayName} (${this.id.destinationId})` : `${this.id}`;
        } else {
          return this._displayName ? this._displayName : this.id.assetId;
        }
      }
    };
    DestinationIdentifier = class {
      static {
        __name(this, "DestinationIdentifier");
      }
      constructor(assetId, destinationId) {
        this.assetId = assetId;
        this.destinationId = destinationId;
      }
      /**
       * Return a string representation for this asset identifier
       */
      toString() {
        return this.destinationId ? `${this.assetId}:${this.destinationId}` : this.assetId;
      }
    };
    __name(filterDict, "filterDict");
    DestinationPattern = class _DestinationPattern {
      static {
        __name(this, "DestinationPattern");
      }
      /**
       * Parse a ':'-separated string into an asset/destination identifier
       */
      static parse(s) {
        if (!s) {
          throw new Error("Empty string is not a valid destination identifier");
        }
        const parts = s.split(":").map((x) => x !== "*" ? x : void 0);
        if (parts.length === 1) {
          return new _DestinationPattern(parts[0]);
        }
        if (parts.length === 2) {
          return new _DestinationPattern(parts[0] || void 0, parts[1] || void 0);
        }
        throw new Error(`Asset identifier must contain at most 2 ':'-separated parts, got '${s}'`);
      }
      constructor(assetId, destinationId) {
        this.assetId = assetId;
        this.destinationId = destinationId;
      }
      /**
       * Whether or not this pattern matches the given identifier
       */
      matches(id) {
        return (this.assetId === void 0 || this.assetId === id.assetId) && (this.destinationId === void 0 || this.destinationId === id.destinationId);
      }
      /**
       * Return a string representation for this asset identifier
       */
      toString() {
        return `${this.assetId ?? "*"}:${this.destinationId ?? "*"}`;
      }
    };
    __name(prefixTreeChars, "prefixTreeChars");
  }
});

// ../@aws-cdk/cdk-assets-lib/lib/private/handlers/index.ts
function makeAssetHandler(manifest, asset, host, options) {
  if (asset instanceof FileManifestEntry) {
    return new FileAssetHandler(manifest.directory, asset, host);
  }
  if (asset instanceof DockerImageManifestEntry) {
    return new ContainerImageAssetHandler(manifest.directory, asset, host, options);
  }
  throw new Error(`Unrecognized asset type: '${asset}'`);
}
var init_handlers = __esm({
  "../@aws-cdk/cdk-assets-lib/lib/private/handlers/index.ts"() {
    "use strict";
    init_container_images();
    init_files();
    init_asset_manifest();
    __name(makeAssetHandler, "makeAssetHandler");
  }
});

// ../@aws-cdk/cdk-assets-lib/lib/private/p-limit.ts
function pLimit(concurrency) {
  const queue = [];
  let activeCount = 0;
  let stopped = false;
  function dispatch() {
    if (activeCount < concurrency && queue.length > 0) {
      const [fac, resolve13, reject] = queue.shift();
      activeCount++;
      fac().then(
        (r32) => {
          resumeNext();
          resolve13(r32);
        },
        (e32) => {
          resumeNext();
          reject(e32);
        }
      );
    }
  }
  __name(dispatch, "dispatch");
  function resumeNext() {
    activeCount--;
    if (stopped) {
      for (const [_, __, reject] of queue) {
        reject(new Error("Task has been cancelled"));
      }
      queue.splice(0, queue.length);
    }
    dispatch();
  }
  __name(resumeNext, "resumeNext");
  const ret = /* @__PURE__ */ __name((promiseFactory) => {
    return new Promise((resolve13, reject) => {
      queue.push([promiseFactory, resolve13, reject]);
      dispatch();
    });
  }, "ret");
  Object.defineProperties(ret, {
    dispose: {
      value: /* @__PURE__ */ __name(() => {
        stopped = true;
      }, "value")
    }
  });
  return ret;
}
var init_p_limit = __esm({
  "../@aws-cdk/cdk-assets-lib/lib/private/p-limit.ts"() {
    "use strict";
    __name(pLimit, "pLimit");
  }
});

// ../@aws-cdk/cdk-assets-lib/lib/publishing.ts
var publishing_exports = {};
__export(publishing_exports, {
  AssetPublishing: () => AssetPublishing
});
var AssetPublishing;
var init_publishing = __esm({
  "../@aws-cdk/cdk-assets-lib/lib/publishing.ts"() {
    "use strict";
    init_docker();
    init_handlers();
    init_p_limit();
    init_progress();
    AssetPublishing = class {
      constructor(manifest, options) {
        this.manifest = manifest;
        this.options = options;
        /**
         * The message for the IPublishProgress interface
         */
        this.message = "Starting";
        this.failures = new Array();
        this.completedOperations = 0;
        this.aborted = false;
        this.handlerCache = /* @__PURE__ */ new Map();
        this.assets = manifest.entries;
        this.totalOperations = this.assets.length;
        this.publishInParallel = options.publishInParallel ?? false;
        this.buildAssets = options.buildAssets ?? true;
        this.publishAssets = options.publishAssets ?? true;
        this.subprocessOutputDestination = options.subprocessOutputDestination ?? (options.quiet ? "ignore" : "stdio");
        const self2 = this;
        this.handlerHost = {
          aws: this.options.aws,
          get aborted() {
            return self2.aborted;
          },
          emitMessage(t, m20) {
            self2.progressEvent(t, m20);
          },
          dockerFactory: new DockerFactory()
        };
      }
      static {
        __name(this, "AssetPublishing");
      }
      /**
       * Publish all assets from the manifest
       */
      async publish(options = {}) {
        if (this.publishInParallel) {
          const limit = pLimit(20);
          await Promise.all(
            this.assets.map((asset) => limit(async () => this.publishAsset(asset, options)))
          );
        } else {
          for (const asset of this.assets) {
            if (!await this.publishAsset(asset, options)) {
              break;
            }
          }
        }
        if ((this.options.throwOnError ?? true) && this.failures.length > 0) {
          throw new Error(`Error publishing: ${this.failures.map((e32) => e32.error.message)}`);
        }
      }
      /**
       * Build a single asset from the manifest
       */
      async buildEntry(asset) {
        try {
          if (this.progressEvent("start" /* START */, `Building ${asset.displayName(false)}`)) {
            return false;
          }
          const handler = this.assetHandler(asset);
          await handler.build();
          if (this.aborted) {
            throw new Error("Aborted");
          }
          this.completedOperations++;
          if (this.progressEvent("success" /* SUCCESS */, `Built ${asset.displayName(false)}`)) {
            return false;
          }
        } catch (e32) {
          this.failures.push({ asset, error: e32 });
          this.completedOperations++;
          if (this.progressEvent("fail" /* FAIL */, e32.message)) {
            return false;
          }
        }
        return true;
      }
      /**
       * Publish a single asset from the manifest
       */
      async publishEntry(asset, options = {}) {
        try {
          if (this.progressEvent("start" /* START */, `Publishing ${asset.displayName(true)}`)) {
            return false;
          }
          const handler = this.assetHandler(asset);
          await handler.publish(options);
          if (this.aborted) {
            throw new Error("Aborted");
          }
          this.completedOperations++;
          if (this.progressEvent("success" /* SUCCESS */, `Published ${asset.displayName(true)}`)) {
            return false;
          }
        } catch (e32) {
          this.failures.push({ asset, error: e32 });
          this.completedOperations++;
          if (this.progressEvent("fail" /* FAIL */, e32.message)) {
            return false;
          }
        }
        return true;
      }
      /**
       * Return whether a single asset is published
       */
      isEntryPublished(asset) {
        const handler = this.assetHandler(asset);
        return handler.isPublished();
      }
      /**
       * publish an asset (used by 'publish()')
       * @param asset - The asset to publish
       * @returns false when publishing should stop
       */
      async publishAsset(asset, options = {}) {
        try {
          if (this.progressEvent("start" /* START */, `Publishing ${asset.displayName(true)}`)) {
            return false;
          }
          const handler = this.assetHandler(asset);
          if (this.buildAssets) {
            await handler.build();
          }
          if (this.publishAssets) {
            await handler.publish(options);
          }
          if (this.aborted) {
            throw new Error("Aborted");
          }
          this.completedOperations++;
          if (this.progressEvent("success" /* SUCCESS */, `Published ${asset.displayName(true)}`)) {
            return false;
          }
        } catch (e32) {
          this.failures.push({ asset, error: e32 });
          this.completedOperations++;
          if (this.progressEvent("fail" /* FAIL */, e32.message)) {
            return false;
          }
        }
        return true;
      }
      get percentComplete() {
        if (this.totalOperations === 0) {
          return 100;
        }
        return Math.floor(this.completedOperations / this.totalOperations * 100);
      }
      abort() {
        this.aborted = true;
      }
      get hasFailures() {
        return this.failures.length > 0;
      }
      /**
       * Publish a progress event to the listener, if present.
       *
       * Returns whether an abort is requested. Helper to get rid of repetitive code in publish().
       */
      progressEvent(event, message2) {
        this.message = message2;
        if (this.options.progressListener) {
          this.options.progressListener.onPublishEvent(event, this);
        }
        return this.aborted;
      }
      assetHandler(asset) {
        const existing = this.handlerCache.get(asset);
        if (existing) {
          return existing;
        }
        const ret = makeAssetHandler(this.manifest, asset, this.handlerHost, {
          subprocessOutputDestination: this.subprocessOutputDestination
        });
        this.handlerCache.set(asset, ret);
        return ret;
      }
    };
  }
});

// ../../node_modules/@smithy/types/dist-cjs/index.js
var require_dist_cjs = __commonJS({
  "../../node_modules/@smithy/types/dist-cjs/index.js"(exports2) {
    "use strict";
    exports2.HttpAuthLocation = void 0;
    (function(HttpAuthLocation) {
      HttpAuthLocation["HEADER"] = "header";
      HttpAuthLocation["QUERY"] = "query";
    })(exports2.HttpAuthLocation || (exports2.HttpAuthLocation = {}));
    exports2.HttpApiKeyAuthLocation = void 0;
    (function(HttpApiKeyAuthLocation3) {
      HttpApiKeyAuthLocation3["HEADER"] = "header";
      HttpApiKeyAuthLocation3["QUERY"] = "query";
    })(exports2.HttpApiKeyAuthLocation || (exports2.HttpApiKeyAuthLocation = {}));
    exports2.EndpointURLScheme = void 0;
    (function(EndpointURLScheme3) {
      EndpointURLScheme3["HTTP"] = "http";
      EndpointURLScheme3["HTTPS"] = "https";
    })(exports2.EndpointURLScheme || (exports2.EndpointURLScheme = {}));
    exports2.AlgorithmId = void 0;
    (function(AlgorithmId3) {
      AlgorithmId3["MD5"] = "md5";
      AlgorithmId3["CRC32"] = "crc32";
      AlgorithmId3["CRC32C"] = "crc32c";
      AlgorithmId3["SHA1"] = "sha1";
      AlgorithmId3["SHA256"] = "sha256";
    })(exports2.AlgorithmId || (exports2.AlgorithmId = {}));
    var getChecksumConfiguration3 = /* @__PURE__ */ __name((runtimeConfig) => {
      const checksumAlgorithms = [];
      if (runtimeConfig.sha256 !== void 0) {
        checksumAlgorithms.push({
          algorithmId: /* @__PURE__ */ __name(() => exports2.AlgorithmId.SHA256, "algorithmId"),
          checksumConstructor: /* @__PURE__ */ __name(() => runtimeConfig.sha256, "checksumConstructor")
        });
      }
      if (runtimeConfig.md5 != void 0) {
        checksumAlgorithms.push({
          algorithmId: /* @__PURE__ */ __name(() => exports2.AlgorithmId.MD5, "algorithmId"),
          checksumConstructor: /* @__PURE__ */ __name(() => runtimeConfig.md5, "checksumConstructor")
        });
      }
      return {
        addChecksumAlgorithm(algo) {
          checksumAlgorithms.push(algo);
        },
        checksumAlgorithms() {
          return checksumAlgorithms;
        }
      };
    }, "getChecksumConfiguration");
    var resolveChecksumRuntimeConfig3 = /* @__PURE__ */ __name((clientConfig) => {
      const runtimeConfig = {};
      clientConfig.checksumAlgorithms().forEach((checksumAlgorithm) => {
        runtimeConfig[checksumAlgorithm.algorithmId()] = checksumAlgorithm.checksumConstructor();
      });
      return runtimeConfig;
    }, "resolveChecksumRuntimeConfig");
    var getDefaultClientConfiguration3 = /* @__PURE__ */ __name((runtimeConfig) => {
      return getChecksumConfiguration3(runtimeConfig);
    }, "getDefaultClientConfiguration");
    var resolveDefaultRuntimeConfig30 = /* @__PURE__ */ __name((config2) => {
      return resolveChecksumRuntimeConfig3(config2);
    }, "resolveDefaultRuntimeConfig");
    exports2.FieldPosition = void 0;
    (function(FieldPosition6) {
      FieldPosition6[FieldPosition6["HEADER"] = 0] = "HEADER";
      FieldPosition6[FieldPosition6["TRAILER"] = 1] = "TRAILER";
    })(exports2.FieldPosition || (exports2.FieldPosition = {}));
    var SMITHY_CONTEXT_KEY9 = "__smithy_context";
    exports2.IniSectionType = void 0;
    (function(IniSectionType11) {
      IniSectionType11["PROFILE"] = "profile";
      IniSectionType11["SSO_SESSION"] = "sso-session";
      IniSectionType11["SERVICES"] = "services";
    })(exports2.IniSectionType || (exports2.IniSectionType = {}));
    exports2.RequestHandlerProtocol = void 0;
    (function(RequestHandlerProtocol) {
      RequestHandlerProtocol["HTTP_0_9"] = "http/0.9";
      RequestHandlerProtocol["HTTP_1_0"] = "http/1.0";
      RequestHandlerProtocol["TDS_8_0"] = "tds/8.0";
    })(exports2.RequestHandlerProtocol || (exports2.RequestHandlerProtocol = {}));
    exports2.SMITHY_CONTEXT_KEY = SMITHY_CONTEXT_KEY9;
    exports2.getDefaultClientConfiguration = getDefaultClientConfiguration3;
    exports2.resolveDefaultRuntimeConfig = resolveDefaultRuntimeConfig30;
  }
});

// ../../node_modules/@smithy/protocol-http/dist-cjs/index.js
var require_dist_cjs2 = __commonJS({
  "../../node_modules/@smithy/protocol-http/dist-cjs/index.js"(exports2) {
    "use strict";
    var types2 = require_dist_cjs();
    var getHttpHandlerExtensionConfiguration33 = /* @__PURE__ */ __name((runtimeConfig) => {
      return {
        setHttpHandler(handler) {
          runtimeConfig.httpHandler = handler;
        },
        httpHandler() {
          return runtimeConfig.httpHandler;
        },
        updateHttpClientConfig(key, value) {
          runtimeConfig.httpHandler?.updateHttpClientConfig(key, value);
        },
        httpHandlerConfigs() {
          return runtimeConfig.httpHandler.httpHandlerConfigs();
        }
      };
    }, "getHttpHandlerExtensionConfiguration");
    var resolveHttpHandlerRuntimeConfig33 = /* @__PURE__ */ __name((httpHandlerExtensionConfiguration) => {
      return {
        httpHandler: httpHandlerExtensionConfiguration.httpHandler()
      };
    }, "resolveHttpHandlerRuntimeConfig");
    var Field6 = class {
      static {
        __name(this, "Field");
      }
      name;
      kind;
      values;
      constructor({ name, kind = types2.FieldPosition.HEADER, values = [] }) {
        this.name = name;
        this.kind = kind;
        this.values = values;
      }
      add(value) {
        this.values.push(value);
      }
      set(values) {
        this.values = values;
      }
      remove(value) {
        this.values = this.values.filter((v) => v !== value);
      }
      toString() {
        return this.values.map((v) => v.includes(",") || v.includes(" ") ? `"${v}"` : v).join(", ");
      }
      get() {
        return this.values;
      }
    };
    var Fields6 = class {
      static {
        __name(this, "Fields");
      }
      entries = {};
      encoding;
      constructor({ fields = [], encoding = "utf-8" }) {
        fields.forEach(this.setField.bind(this));
        this.encoding = encoding;
      }
      setField(field) {
        this.entries[field.name.toLowerCase()] = field;
      }
      getField(name) {
        return this.entries[name.toLowerCase()];
      }
      removeField(name) {
        delete this.entries[name.toLowerCase()];
      }
      getByType(kind) {
        return Object.values(this.entries).filter((field) => field.kind === kind);
      }
    };
    var HttpRequest32 = class _HttpRequest {
      static {
        __name(this, "HttpRequest");
      }
      method;
      protocol;
      hostname;
      port;
      path;
      query;
      headers;
      username;
      password;
      fragment;
      body;
      constructor(options) {
        this.method = options.method || "GET";
        this.hostname = options.hostname || "localhost";
        this.port = options.port;
        this.query = options.query || {};
        this.headers = options.headers || {};
        this.body = options.body;
        this.protocol = options.protocol ? options.protocol.slice(-1) !== ":" ? `${options.protocol}:` : options.protocol : "https:";
        this.path = options.path ? options.path.charAt(0) !== "/" ? `/${options.path}` : options.path : "/";
        this.username = options.username;
        this.password = options.password;
        this.fragment = options.fragment;
      }
      static clone(request4) {
        const cloned = new _HttpRequest({
          ...request4,
          headers: { ...request4.headers }
        });
        if (cloned.query) {
          cloned.query = cloneQuery7(cloned.query);
        }
        return cloned;
      }
      static isInstance(request4) {
        if (!request4) {
          return false;
        }
        const req = request4;
        return "method" in req && "protocol" in req && "hostname" in req && "path" in req && typeof req["query"] === "object" && typeof req["headers"] === "object";
      }
      clone() {
        return _HttpRequest.clone(this);
      }
    };
    function cloneQuery7(query) {
      return Object.keys(query).reduce((carry, paramName) => {
        const param = query[paramName];
        return {
          ...carry,
          [paramName]: Array.isArray(param) ? [...param] : param
        };
      }, {});
    }
    __name(cloneQuery7, "cloneQuery");
    var HttpResponse18 = class {
      static {
        __name(this, "HttpResponse");
      }
      statusCode;
      reason;
      headers;
      body;
      constructor(options) {
        this.statusCode = options.statusCode;
        this.reason = options.reason;
        this.headers = options.headers || {};
        this.body = options.body;
      }
      static isInstance(response) {
        if (!response)
          return false;
        const resp = response;
        return typeof resp.statusCode === "number" && typeof resp.headers === "object";
      }
    };
    function isValidHostname6(hostname) {
      const hostPattern = /^[a-z0-9][a-z0-9\.\-]*[a-z0-9]$/;
      return hostPattern.test(hostname);
    }
    __name(isValidHostname6, "isValidHostname");
    exports2.Field = Field6;
    exports2.Fields = Fields6;
    exports2.HttpRequest = HttpRequest32;
    exports2.HttpResponse = HttpResponse18;
    exports2.getHttpHandlerExtensionConfiguration = getHttpHandlerExtensionConfiguration33;
    exports2.isValidHostname = isValidHostname6;
    exports2.resolveHttpHandlerRuntimeConfig = resolveHttpHandlerRuntimeConfig33;
  }
});

// ../../node_modules/@aws-sdk/middleware-host-header/dist-cjs/index.js
var require_dist_cjs3 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-host-header/dist-cjs/index.js"(exports2) {
    "use strict";
    var protocolHttp = require_dist_cjs2();
    function resolveHostHeaderConfig29(input) {
      return input;
    }
    __name(resolveHostHeaderConfig29, "resolveHostHeaderConfig");
    var hostHeaderMiddleware2 = /* @__PURE__ */ __name((options) => (next) => async (args) => {
      if (!protocolHttp.HttpRequest.isInstance(args.request))
        return next(args);
      const { request: request4 } = args;
      const { handlerProtocol = "" } = options.requestHandler.metadata || {};
      if (handlerProtocol.indexOf("h2") >= 0 && !request4.headers[":authority"]) {
        delete request4.headers["host"];
        request4.headers[":authority"] = request4.hostname + (request4.port ? ":" + request4.port : "");
      } else if (!request4.headers["host"]) {
        let host = request4.hostname;
        if (request4.port != null)
          host += `:${request4.port}`;
        request4.headers["host"] = host;
      }
      return next(args);
    }, "hostHeaderMiddleware");
    var hostHeaderMiddlewareOptions2 = {
      name: "hostHeaderMiddleware",
      step: "build",
      priority: "low",
      tags: ["HOST"],
      override: true
    };
    var getHostHeaderPlugin29 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(hostHeaderMiddleware2(options), hostHeaderMiddlewareOptions2);
      }, "applyToStack")
    }), "getHostHeaderPlugin");
    exports2.getHostHeaderPlugin = getHostHeaderPlugin29;
    exports2.hostHeaderMiddleware = hostHeaderMiddleware2;
    exports2.hostHeaderMiddlewareOptions = hostHeaderMiddlewareOptions2;
    exports2.resolveHostHeaderConfig = resolveHostHeaderConfig29;
  }
});

// ../../node_modules/@aws-sdk/middleware-logger/dist-cjs/index.js
var require_dist_cjs4 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-logger/dist-cjs/index.js"(exports2) {
    "use strict";
    var loggerMiddleware2 = /* @__PURE__ */ __name(() => (next, context) => async (args) => {
      try {
        const response = await next(args);
        const { clientName, commandName, logger: logger5, dynamoDbDocumentClientOptions = {} } = context;
        const { overrideInputFilterSensitiveLog, overrideOutputFilterSensitiveLog } = dynamoDbDocumentClientOptions;
        const inputFilterSensitiveLog = overrideInputFilterSensitiveLog ?? context.inputFilterSensitiveLog;
        const outputFilterSensitiveLog = overrideOutputFilterSensitiveLog ?? context.outputFilterSensitiveLog;
        const { $metadata, ...outputWithoutMetadata } = response.output;
        logger5?.info?.({
          clientName,
          commandName,
          input: inputFilterSensitiveLog(args.input),
          output: outputFilterSensitiveLog(outputWithoutMetadata),
          metadata: $metadata
        });
        return response;
      } catch (error4) {
        const { clientName, commandName, logger: logger5, dynamoDbDocumentClientOptions = {} } = context;
        const { overrideInputFilterSensitiveLog } = dynamoDbDocumentClientOptions;
        const inputFilterSensitiveLog = overrideInputFilterSensitiveLog ?? context.inputFilterSensitiveLog;
        logger5?.error?.({
          clientName,
          commandName,
          input: inputFilterSensitiveLog(args.input),
          error: error4,
          metadata: error4.$metadata
        });
        throw error4;
      }
    }, "loggerMiddleware");
    var loggerMiddlewareOptions2 = {
      name: "loggerMiddleware",
      tags: ["LOGGER"],
      step: "initialize",
      override: true
    };
    var getLoggerPlugin29 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(loggerMiddleware2(), loggerMiddlewareOptions2);
      }, "applyToStack")
    }), "getLoggerPlugin");
    exports2.getLoggerPlugin = getLoggerPlugin29;
    exports2.loggerMiddleware = loggerMiddleware2;
    exports2.loggerMiddlewareOptions = loggerMiddlewareOptions2;
  }
});

// ../../node_modules/@aws/lambda-invoke-store/dist-es/invoke-store.js
var invoke_store_exports = {};
__export(invoke_store_exports, {
  InvokeStore: () => InvokeStore,
  InvokeStoreBase: () => InvokeStoreBase
});
var PROTECTED_KEYS, NO_GLOBAL_AWS_LAMBDA, InvokeStoreBase, InvokeStoreSingle, InvokeStoreMulti, InvokeStore;
var init_invoke_store = __esm({
  "../../node_modules/@aws/lambda-invoke-store/dist-es/invoke-store.js"() {
    PROTECTED_KEYS = {
      REQUEST_ID: /* @__PURE__ */ Symbol.for("_AWS_LAMBDA_REQUEST_ID"),
      X_RAY_TRACE_ID: /* @__PURE__ */ Symbol.for("_AWS_LAMBDA_X_RAY_TRACE_ID"),
      TENANT_ID: /* @__PURE__ */ Symbol.for("_AWS_LAMBDA_TENANT_ID")
    };
    NO_GLOBAL_AWS_LAMBDA = ["true", "1"].includes(process.env?.AWS_LAMBDA_NODEJS_NO_GLOBAL_AWSLAMBDA ?? "");
    if (!NO_GLOBAL_AWS_LAMBDA) {
      globalThis.awslambda = globalThis.awslambda || {};
    }
    InvokeStoreBase = class {
      static {
        __name(this, "InvokeStoreBase");
      }
      static PROTECTED_KEYS = PROTECTED_KEYS;
      isProtectedKey(key) {
        return Object.values(PROTECTED_KEYS).includes(key);
      }
      getRequestId() {
        return this.get(PROTECTED_KEYS.REQUEST_ID) ?? "-";
      }
      getXRayTraceId() {
        return this.get(PROTECTED_KEYS.X_RAY_TRACE_ID);
      }
      getTenantId() {
        return this.get(PROTECTED_KEYS.TENANT_ID);
      }
    };
    InvokeStoreSingle = class extends InvokeStoreBase {
      static {
        __name(this, "InvokeStoreSingle");
      }
      currentContext;
      getContext() {
        return this.currentContext;
      }
      hasContext() {
        return this.currentContext !== void 0;
      }
      get(key) {
        return this.currentContext?.[key];
      }
      set(key, value) {
        if (this.isProtectedKey(key)) {
          throw new Error(`Cannot modify protected Lambda context field: ${String(key)}`);
        }
        this.currentContext = this.currentContext || {};
        this.currentContext[key] = value;
      }
      run(context, fn) {
        this.currentContext = context;
        return fn();
      }
    };
    InvokeStoreMulti = class _InvokeStoreMulti extends InvokeStoreBase {
      static {
        __name(this, "InvokeStoreMulti");
      }
      als;
      static async create() {
        const instance = new _InvokeStoreMulti();
        const asyncHooks = await import("node:async_hooks");
        instance.als = new asyncHooks.AsyncLocalStorage();
        return instance;
      }
      getContext() {
        return this.als.getStore();
      }
      hasContext() {
        return this.als.getStore() !== void 0;
      }
      get(key) {
        return this.als.getStore()?.[key];
      }
      set(key, value) {
        if (this.isProtectedKey(key)) {
          throw new Error(`Cannot modify protected Lambda context field: ${String(key)}`);
        }
        const store = this.als.getStore();
        if (!store) {
          throw new Error("No context available");
        }
        store[key] = value;
      }
      run(context, fn) {
        return this.als.run(context, fn);
      }
    };
    (function(InvokeStore2) {
      let instance = null;
      async function getInstanceAsync(forceInvokeStoreMulti) {
        if (!instance) {
          instance = (async () => {
            const isMulti = forceInvokeStoreMulti === true || "AWS_LAMBDA_MAX_CONCURRENCY" in process.env;
            const newInstance = isMulti ? await InvokeStoreMulti.create() : new InvokeStoreSingle();
            if (!NO_GLOBAL_AWS_LAMBDA && globalThis.awslambda?.InvokeStore) {
              return globalThis.awslambda.InvokeStore;
            } else if (!NO_GLOBAL_AWS_LAMBDA && globalThis.awslambda) {
              globalThis.awslambda.InvokeStore = newInstance;
              return newInstance;
            } else {
              return newInstance;
            }
          })();
        }
        return instance;
      }
      __name(getInstanceAsync, "getInstanceAsync");
      InvokeStore2.getInstanceAsync = getInstanceAsync;
      InvokeStore2._testing = process.env.AWS_LAMBDA_BENCHMARK_MODE === "1" ? {
        reset: /* @__PURE__ */ __name(() => {
          instance = null;
          if (globalThis.awslambda?.InvokeStore) {
            delete globalThis.awslambda.InvokeStore;
          }
          globalThis.awslambda = { InvokeStore: void 0 };
        }, "reset")
      } : void 0;
    })(InvokeStore || (InvokeStore = {}));
  }
});

// ../../node_modules/@aws-sdk/middleware-recursion-detection/dist-cjs/recursionDetectionMiddleware.js
var require_recursionDetectionMiddleware = __commonJS({
  "../../node_modules/@aws-sdk/middleware-recursion-detection/dist-cjs/recursionDetectionMiddleware.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.recursionDetectionMiddleware = void 0;
    var lambda_invoke_store_1 = (init_invoke_store(), __toCommonJS(invoke_store_exports));
    var protocol_http_1 = require_dist_cjs2();
    var TRACE_ID_HEADER_NAME2 = "X-Amzn-Trace-Id";
    var ENV_LAMBDA_FUNCTION_NAME2 = "AWS_LAMBDA_FUNCTION_NAME";
    var ENV_TRACE_ID2 = "_X_AMZN_TRACE_ID";
    var recursionDetectionMiddleware2 = /* @__PURE__ */ __name(() => (next) => async (args) => {
      const { request: request4 } = args;
      if (!protocol_http_1.HttpRequest.isInstance(request4)) {
        return next(args);
      }
      const traceIdHeader = Object.keys(request4.headers ?? {}).find((h32) => h32.toLowerCase() === TRACE_ID_HEADER_NAME2.toLowerCase()) ?? TRACE_ID_HEADER_NAME2;
      if (request4.headers.hasOwnProperty(traceIdHeader)) {
        return next(args);
      }
      const functionName = process.env[ENV_LAMBDA_FUNCTION_NAME2];
      const traceIdFromEnv = process.env[ENV_TRACE_ID2];
      const invokeStore = await lambda_invoke_store_1.InvokeStore.getInstanceAsync();
      const traceIdFromInvokeStore = invokeStore?.getXRayTraceId();
      const traceId = traceIdFromInvokeStore ?? traceIdFromEnv;
      const nonEmptyString = /* @__PURE__ */ __name((str) => typeof str === "string" && str.length > 0, "nonEmptyString");
      if (nonEmptyString(functionName) && nonEmptyString(traceId)) {
        request4.headers[TRACE_ID_HEADER_NAME2] = traceId;
      }
      return next({
        ...args,
        request: request4
      });
    }, "recursionDetectionMiddleware");
    exports2.recursionDetectionMiddleware = recursionDetectionMiddleware2;
  }
});

// ../../node_modules/@aws-sdk/middleware-recursion-detection/dist-cjs/index.js
var require_dist_cjs5 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-recursion-detection/dist-cjs/index.js"(exports2) {
    "use strict";
    var recursionDetectionMiddleware2 = require_recursionDetectionMiddleware();
    var recursionDetectionMiddlewareOptions2 = {
      step: "build",
      tags: ["RECURSION_DETECTION"],
      name: "recursionDetectionMiddleware",
      override: true,
      priority: "low"
    };
    var getRecursionDetectionPlugin29 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(recursionDetectionMiddleware2.recursionDetectionMiddleware(), recursionDetectionMiddlewareOptions2);
      }, "applyToStack")
    }), "getRecursionDetectionPlugin");
    exports2.getRecursionDetectionPlugin = getRecursionDetectionPlugin29;
    Object.prototype.hasOwnProperty.call(recursionDetectionMiddleware2, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: recursionDetectionMiddleware2["__proto__"]
    });
    Object.keys(recursionDetectionMiddleware2).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = recursionDetectionMiddleware2[k32];
    });
  }
});

// ../../node_modules/@smithy/core/dist-es/getSmithyContext.js
var import_types, getSmithyContext;
var init_getSmithyContext = __esm({
  "../../node_modules/@smithy/core/dist-es/getSmithyContext.js"() {
    import_types = __toESM(require_dist_cjs());
    getSmithyContext = /* @__PURE__ */ __name((context) => context[import_types.SMITHY_CONTEXT_KEY] || (context[import_types.SMITHY_CONTEXT_KEY] = {}), "getSmithyContext");
  }
});

// ../../node_modules/@smithy/util-middleware/dist-cjs/index.js
var require_dist_cjs6 = __commonJS({
  "../../node_modules/@smithy/util-middleware/dist-cjs/index.js"(exports2) {
    "use strict";
    var types2 = require_dist_cjs();
    var getSmithyContext39 = /* @__PURE__ */ __name((context) => context[types2.SMITHY_CONTEXT_KEY] || (context[types2.SMITHY_CONTEXT_KEY] = {}), "getSmithyContext");
    var normalizeProvider35 = /* @__PURE__ */ __name((input) => {
      if (typeof input === "function")
        return input;
      const promisified = Promise.resolve(input);
      return () => promisified;
    }, "normalizeProvider");
    exports2.getSmithyContext = getSmithyContext39;
    exports2.normalizeProvider = normalizeProvider35;
  }
});

// ../../node_modules/@smithy/core/dist-es/middleware-http-auth-scheme/resolveAuthOptions.js
var resolveAuthOptions;
var init_resolveAuthOptions = __esm({
  "../../node_modules/@smithy/core/dist-es/middleware-http-auth-scheme/resolveAuthOptions.js"() {
    resolveAuthOptions = /* @__PURE__ */ __name((candidateAuthOptions, authSchemePreference) => {
      if (!authSchemePreference || authSchemePreference.length === 0) {
        return candidateAuthOptions;
      }
      const preferredAuthOptions = [];
      for (const preferredSchemeName of authSchemePreference) {
        for (const candidateAuthOption of candidateAuthOptions) {
          const candidateAuthSchemeName = candidateAuthOption.schemeId.split("#")[1];
          if (candidateAuthSchemeName === preferredSchemeName) {
            preferredAuthOptions.push(candidateAuthOption);
          }
        }
      }
      for (const candidateAuthOption of candidateAuthOptions) {
        if (!preferredAuthOptions.find(({ schemeId }) => schemeId === candidateAuthOption.schemeId)) {
          preferredAuthOptions.push(candidateAuthOption);
        }
      }
      return preferredAuthOptions;
    }, "resolveAuthOptions");
  }
});

// ../../node_modules/@smithy/core/dist-es/middleware-http-auth-scheme/httpAuthSchemeMiddleware.js
function convertHttpAuthSchemesToMap(httpAuthSchemes) {
  const map5 = /* @__PURE__ */ new Map();
  for (const scheme of httpAuthSchemes) {
    map5.set(scheme.schemeId, scheme);
  }
  return map5;
}
var import_util_middleware, httpAuthSchemeMiddleware;
var init_httpAuthSchemeMiddleware = __esm({
  "../../node_modules/@smithy/core/dist-es/middleware-http-auth-scheme/httpAuthSchemeMiddleware.js"() {
    import_util_middleware = __toESM(require_dist_cjs6());
    init_resolveAuthOptions();
    __name(convertHttpAuthSchemesToMap, "convertHttpAuthSchemesToMap");
    httpAuthSchemeMiddleware = /* @__PURE__ */ __name((config2, mwOptions) => (next, context) => async (args) => {
      const options = config2.httpAuthSchemeProvider(await mwOptions.httpAuthSchemeParametersProvider(config2, context, args.input));
      const authSchemePreference = config2.authSchemePreference ? await config2.authSchemePreference() : [];
      const resolvedOptions = resolveAuthOptions(options, authSchemePreference);
      const authSchemes = convertHttpAuthSchemesToMap(config2.httpAuthSchemes);
      const smithyContext = (0, import_util_middleware.getSmithyContext)(context);
      const failureReasons = [];
      for (const option of resolvedOptions) {
        const scheme = authSchemes.get(option.schemeId);
        if (!scheme) {
          failureReasons.push(`HttpAuthScheme \`${option.schemeId}\` was not enabled for this service.`);
          continue;
        }
        const identityProvider = scheme.identityProvider(await mwOptions.identityProviderConfigProvider(config2));
        if (!identityProvider) {
          failureReasons.push(`HttpAuthScheme \`${option.schemeId}\` did not have an IdentityProvider configured.`);
          continue;
        }
        const { identityProperties = {}, signingProperties = {} } = option.propertiesExtractor?.(config2, context) || {};
        option.identityProperties = Object.assign(option.identityProperties || {}, identityProperties);
        option.signingProperties = Object.assign(option.signingProperties || {}, signingProperties);
        smithyContext.selectedHttpAuthScheme = {
          httpAuthOption: option,
          identity: await identityProvider(option.identityProperties),
          signer: scheme.signer
        };
        break;
      }
      if (!smithyContext.selectedHttpAuthScheme) {
        throw new Error(failureReasons.join("\n"));
      }
      return next(args);
    }, "httpAuthSchemeMiddleware");
  }
});

// ../../node_modules/@smithy/core/dist-es/middleware-http-auth-scheme/getHttpAuthSchemeEndpointRuleSetPlugin.js
var httpAuthSchemeEndpointRuleSetMiddlewareOptions, getHttpAuthSchemeEndpointRuleSetPlugin;
var init_getHttpAuthSchemeEndpointRuleSetPlugin = __esm({
  "../../node_modules/@smithy/core/dist-es/middleware-http-auth-scheme/getHttpAuthSchemeEndpointRuleSetPlugin.js"() {
    init_httpAuthSchemeMiddleware();
    httpAuthSchemeEndpointRuleSetMiddlewareOptions = {
      step: "serialize",
      tags: ["HTTP_AUTH_SCHEME"],
      name: "httpAuthSchemeMiddleware",
      override: true,
      relation: "before",
      toMiddleware: "endpointV2Middleware"
    };
    getHttpAuthSchemeEndpointRuleSetPlugin = /* @__PURE__ */ __name((config2, { httpAuthSchemeParametersProvider, identityProviderConfigProvider }) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.addRelativeTo(httpAuthSchemeMiddleware(config2, {
          httpAuthSchemeParametersProvider,
          identityProviderConfigProvider
        }), httpAuthSchemeEndpointRuleSetMiddlewareOptions);
      }, "applyToStack")
    }), "getHttpAuthSchemeEndpointRuleSetPlugin");
  }
});

// ../../node_modules/@smithy/core/dist-es/middleware-http-auth-scheme/getHttpAuthSchemePlugin.js
var httpAuthSchemeMiddlewareOptions, getHttpAuthSchemePlugin;
var init_getHttpAuthSchemePlugin = __esm({
  "../../node_modules/@smithy/core/dist-es/middleware-http-auth-scheme/getHttpAuthSchemePlugin.js"() {
    init_httpAuthSchemeMiddleware();
    httpAuthSchemeMiddlewareOptions = {
      step: "serialize",
      tags: ["HTTP_AUTH_SCHEME"],
      name: "httpAuthSchemeMiddleware",
      override: true,
      relation: "before",
      toMiddleware: "serializerMiddleware"
    };
    getHttpAuthSchemePlugin = /* @__PURE__ */ __name((config2, { httpAuthSchemeParametersProvider, identityProviderConfigProvider }) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.addRelativeTo(httpAuthSchemeMiddleware(config2, {
          httpAuthSchemeParametersProvider,
          identityProviderConfigProvider
        }), httpAuthSchemeMiddlewareOptions);
      }, "applyToStack")
    }), "getHttpAuthSchemePlugin");
  }
});

// ../../node_modules/@smithy/core/dist-es/middleware-http-auth-scheme/index.js
var init_middleware_http_auth_scheme = __esm({
  "../../node_modules/@smithy/core/dist-es/middleware-http-auth-scheme/index.js"() {
    init_httpAuthSchemeMiddleware();
    init_getHttpAuthSchemeEndpointRuleSetPlugin();
    init_getHttpAuthSchemePlugin();
  }
});

// ../../node_modules/@smithy/core/dist-es/middleware-http-signing/httpSigningMiddleware.js
var import_protocol_http, import_util_middleware2, defaultErrorHandler, defaultSuccessHandler, httpSigningMiddleware;
var init_httpSigningMiddleware = __esm({
  "../../node_modules/@smithy/core/dist-es/middleware-http-signing/httpSigningMiddleware.js"() {
    import_protocol_http = __toESM(require_dist_cjs2());
    import_util_middleware2 = __toESM(require_dist_cjs6());
    defaultErrorHandler = /* @__PURE__ */ __name((signingProperties) => (error4) => {
      throw error4;
    }, "defaultErrorHandler");
    defaultSuccessHandler = /* @__PURE__ */ __name((httpResponse, signingProperties) => {
    }, "defaultSuccessHandler");
    httpSigningMiddleware = /* @__PURE__ */ __name((config2) => (next, context) => async (args) => {
      if (!import_protocol_http.HttpRequest.isInstance(args.request)) {
        return next(args);
      }
      const smithyContext = (0, import_util_middleware2.getSmithyContext)(context);
      const scheme = smithyContext.selectedHttpAuthScheme;
      if (!scheme) {
        throw new Error(`No HttpAuthScheme was selected: unable to sign request`);
      }
      const { httpAuthOption: { signingProperties = {} }, identity, signer } = scheme;
      const output = await next({
        ...args,
        request: await signer.sign(args.request, identity, signingProperties)
      }).catch((signer.errorHandler || defaultErrorHandler)(signingProperties));
      (signer.successHandler || defaultSuccessHandler)(output.response, signingProperties);
      return output;
    }, "httpSigningMiddleware");
  }
});

// ../../node_modules/@smithy/core/dist-es/middleware-http-signing/getHttpSigningMiddleware.js
var httpSigningMiddlewareOptions, getHttpSigningPlugin;
var init_getHttpSigningMiddleware = __esm({
  "../../node_modules/@smithy/core/dist-es/middleware-http-signing/getHttpSigningMiddleware.js"() {
    init_httpSigningMiddleware();
    httpSigningMiddlewareOptions = {
      step: "finalizeRequest",
      tags: ["HTTP_SIGNING"],
      name: "httpSigningMiddleware",
      aliases: ["apiKeyMiddleware", "tokenMiddleware", "awsAuthMiddleware"],
      override: true,
      relation: "after",
      toMiddleware: "retryMiddleware"
    };
    getHttpSigningPlugin = /* @__PURE__ */ __name((config2) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.addRelativeTo(httpSigningMiddleware(config2), httpSigningMiddlewareOptions);
      }, "applyToStack")
    }), "getHttpSigningPlugin");
  }
});

// ../../node_modules/@smithy/core/dist-es/middleware-http-signing/index.js
var init_middleware_http_signing = __esm({
  "../../node_modules/@smithy/core/dist-es/middleware-http-signing/index.js"() {
    init_httpSigningMiddleware();
    init_getHttpSigningMiddleware();
  }
});

// ../../node_modules/@smithy/core/dist-es/normalizeProvider.js
var normalizeProvider;
var init_normalizeProvider = __esm({
  "../../node_modules/@smithy/core/dist-es/normalizeProvider.js"() {
    normalizeProvider = /* @__PURE__ */ __name((input) => {
      if (typeof input === "function")
        return input;
      const promisified = Promise.resolve(input);
      return () => promisified;
    }, "normalizeProvider");
  }
});

// ../../node_modules/@smithy/core/dist-es/pagination/createPaginator.js
function createPaginator(ClientCtor, CommandCtor, inputTokenName, outputTokenName, pageSizeTokenName) {
  return /* @__PURE__ */ __name(async function* paginateOperation(config2, input, ...additionalArguments) {
    const _input = input;
    let token = config2.startingToken ?? _input[inputTokenName];
    let hasNext = true;
    let page;
    while (hasNext) {
      _input[inputTokenName] = token;
      if (pageSizeTokenName) {
        _input[pageSizeTokenName] = _input[pageSizeTokenName] ?? config2.pageSize;
      }
      if (config2.client instanceof ClientCtor) {
        page = await makePagedClientRequest(CommandCtor, config2.client, input, config2.withCommand, ...additionalArguments);
      } else {
        throw new Error(`Invalid client, expected instance of ${ClientCtor.name}`);
      }
      yield page;
      const prevToken = token;
      token = get(page, outputTokenName);
      hasNext = !!(token && (!config2.stopOnSameToken || token !== prevToken));
    }
    return void 0;
  }, "paginateOperation");
}
var makePagedClientRequest, get;
var init_createPaginator = __esm({
  "../../node_modules/@smithy/core/dist-es/pagination/createPaginator.js"() {
    makePagedClientRequest = /* @__PURE__ */ __name(async (CommandCtor, client, input, withCommand = (_) => _, ...args) => {
      let command = new CommandCtor(input);
      command = withCommand(command) ?? command;
      return await client.send(command, ...args);
    }, "makePagedClientRequest");
    __name(createPaginator, "createPaginator");
    get = /* @__PURE__ */ __name((fromObject, path47) => {
      let cursor3 = fromObject;
      const pathComponents = path47.split(".");
      for (const step of pathComponents) {
        if (!cursor3 || typeof cursor3 !== "object") {
          return void 0;
        }
        cursor3 = cursor3[step];
      }
      return cursor3;
    }, "get");
  }
});

// ../../node_modules/@smithy/is-array-buffer/dist-cjs/index.js
var require_dist_cjs7 = __commonJS({
  "../../node_modules/@smithy/is-array-buffer/dist-cjs/index.js"(exports2) {
    "use strict";
    var isArrayBuffer7 = /* @__PURE__ */ __name((arg) => typeof ArrayBuffer === "function" && arg instanceof ArrayBuffer || Object.prototype.toString.call(arg) === "[object ArrayBuffer]", "isArrayBuffer");
    exports2.isArrayBuffer = isArrayBuffer7;
  }
});

// ../../node_modules/@smithy/util-buffer-from/dist-cjs/index.js
var require_dist_cjs8 = __commonJS({
  "../../node_modules/@smithy/util-buffer-from/dist-cjs/index.js"(exports2) {
    "use strict";
    var isArrayBuffer7 = require_dist_cjs7();
    var buffer = require("buffer");
    var fromArrayBuffer7 = /* @__PURE__ */ __name((input, offset = 0, length = input.byteLength - offset) => {
      if (!isArrayBuffer7.isArrayBuffer(input)) {
        throw new TypeError(`The "input" argument must be ArrayBuffer. Received type ${typeof input} (${input})`);
      }
      return buffer.Buffer.from(input, offset, length);
    }, "fromArrayBuffer");
    var fromString7 = /* @__PURE__ */ __name((input, encoding) => {
      if (typeof input !== "string") {
        throw new TypeError(`The "input" argument must be of type string. Received type ${typeof input} (${input})`);
      }
      return encoding ? buffer.Buffer.from(input, encoding) : buffer.Buffer.from(input);
    }, "fromString");
    exports2.fromArrayBuffer = fromArrayBuffer7;
    exports2.fromString = fromString7;
  }
});

// ../../node_modules/@smithy/util-base64/dist-cjs/fromBase64.js
var require_fromBase64 = __commonJS({
  "../../node_modules/@smithy/util-base64/dist-cjs/fromBase64.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromBase64 = void 0;
    var util_buffer_from_1 = require_dist_cjs8();
    var BASE64_REGEX7 = /^[A-Za-z0-9+/]*={0,2}$/;
    var fromBase6459 = /* @__PURE__ */ __name((input) => {
      if (input.length * 3 % 4 !== 0) {
        throw new TypeError(`Incorrect padding on base64 string.`);
      }
      if (!BASE64_REGEX7.exec(input)) {
        throw new TypeError(`Invalid base64 string.`);
      }
      const buffer = (0, util_buffer_from_1.fromString)(input, "base64");
      return new Uint8Array(buffer.buffer, buffer.byteOffset, buffer.byteLength);
    }, "fromBase64");
    exports2.fromBase64 = fromBase6459;
  }
});

// ../../node_modules/@smithy/util-utf8/dist-cjs/index.js
var require_dist_cjs9 = __commonJS({
  "../../node_modules/@smithy/util-utf8/dist-cjs/index.js"(exports2) {
    "use strict";
    var utilBufferFrom = require_dist_cjs8();
    var fromUtf842 = /* @__PURE__ */ __name((input) => {
      const buf = utilBufferFrom.fromString(input, "utf8");
      return new Uint8Array(buf.buffer, buf.byteOffset, buf.byteLength / Uint8Array.BYTES_PER_ELEMENT);
    }, "fromUtf8");
    var toUint8Array5 = /* @__PURE__ */ __name((data3) => {
      if (typeof data3 === "string") {
        return fromUtf842(data3);
      }
      if (ArrayBuffer.isView(data3)) {
        return new Uint8Array(data3.buffer, data3.byteOffset, data3.byteLength / Uint8Array.BYTES_PER_ELEMENT);
      }
      return new Uint8Array(data3);
    }, "toUint8Array");
    var toUtf862 = /* @__PURE__ */ __name((input) => {
      if (typeof input === "string") {
        return input;
      }
      if (typeof input !== "object" || typeof input.byteOffset !== "number" || typeof input.byteLength !== "number") {
        throw new Error("@smithy/util-utf8: toUtf8 encoder function only accepts string | Uint8Array.");
      }
      return utilBufferFrom.fromArrayBuffer(input.buffer, input.byteOffset, input.byteLength).toString("utf8");
    }, "toUtf8");
    exports2.fromUtf8 = fromUtf842;
    exports2.toUint8Array = toUint8Array5;
    exports2.toUtf8 = toUtf862;
  }
});

// ../../node_modules/@smithy/util-base64/dist-cjs/toBase64.js
var require_toBase64 = __commonJS({
  "../../node_modules/@smithy/util-base64/dist-cjs/toBase64.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.toBase64 = void 0;
    var util_buffer_from_1 = require_dist_cjs8();
    var util_utf8_1 = require_dist_cjs9();
    var toBase6467 = /* @__PURE__ */ __name((_input) => {
      let input;
      if (typeof _input === "string") {
        input = (0, util_utf8_1.fromUtf8)(_input);
      } else {
        input = _input;
      }
      if (typeof input !== "object" || typeof input.byteOffset !== "number" || typeof input.byteLength !== "number") {
        throw new Error("@smithy/util-base64: toBase64 encoder function only accepts string | Uint8Array.");
      }
      return (0, util_buffer_from_1.fromArrayBuffer)(input.buffer, input.byteOffset, input.byteLength).toString("base64");
    }, "toBase64");
    exports2.toBase64 = toBase6467;
  }
});

// ../../node_modules/@smithy/util-base64/dist-cjs/index.js
var require_dist_cjs10 = __commonJS({
  "../../node_modules/@smithy/util-base64/dist-cjs/index.js"(exports2) {
    "use strict";
    var fromBase6459 = require_fromBase64();
    var toBase6467 = require_toBase64();
    Object.prototype.hasOwnProperty.call(fromBase6459, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: fromBase6459["__proto__"]
    });
    Object.keys(fromBase6459).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = fromBase6459[k32];
    });
    Object.prototype.hasOwnProperty.call(toBase6467, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: toBase6467["__proto__"]
    });
    Object.keys(toBase6467).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = toBase6467[k32];
    });
  }
});

// ../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.js
var require_ChecksumStream = __commonJS({
  "../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ChecksumStream = void 0;
    var util_base64_1 = require_dist_cjs10();
    var stream_1 = require("stream");
    var ChecksumStream5 = class extends stream_1.Duplex {
      static {
        __name(this, "ChecksumStream");
      }
      expectedChecksum;
      checksumSourceLocation;
      checksum;
      source;
      base64Encoder;
      pendingCallback = null;
      constructor({ expectedChecksum, checksum, source, checksumSourceLocation, base64Encoder }) {
        super();
        if (typeof source.pipe === "function") {
          this.source = source;
        } else {
          throw new Error(`@smithy/util-stream: unsupported source type ${source?.constructor?.name ?? source} in ChecksumStream.`);
        }
        this.base64Encoder = base64Encoder ?? util_base64_1.toBase64;
        this.expectedChecksum = expectedChecksum;
        this.checksum = checksum;
        this.checksumSourceLocation = checksumSourceLocation;
        this.source.pipe(this);
      }
      _read(size) {
        if (this.pendingCallback) {
          const callback = this.pendingCallback;
          this.pendingCallback = null;
          callback();
        }
      }
      _write(chunk, encoding, callback) {
        try {
          this.checksum.update(chunk);
          const canPushMore = this.push(chunk);
          if (!canPushMore) {
            this.pendingCallback = callback;
            return;
          }
        } catch (e32) {
          return callback(e32);
        }
        return callback();
      }
      async _final(callback) {
        try {
          const digest = await this.checksum.digest();
          const received = this.base64Encoder(digest);
          if (this.expectedChecksum !== received) {
            return callback(new Error(`Checksum mismatch: expected "${this.expectedChecksum}" but received "${received}" in response header "${this.checksumSourceLocation}".`));
          }
        } catch (e32) {
          return callback(e32);
        }
        this.push(null);
        return callback();
      }
    };
    exports2.ChecksumStream = ChecksumStream5;
  }
});

// ../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/stream-type-check.js
var require_stream_type_check = __commonJS({
  "../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/stream-type-check.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isBlob = exports2.isReadableStream = void 0;
    var isReadableStream6 = /* @__PURE__ */ __name((stream) => typeof ReadableStream === "function" && (stream?.constructor?.name === ReadableStream.name || stream instanceof ReadableStream), "isReadableStream");
    exports2.isReadableStream = isReadableStream6;
    var isBlob3 = /* @__PURE__ */ __name((blob) => {
      return typeof Blob === "function" && (blob?.constructor?.name === Blob.name || blob instanceof Blob);
    }, "isBlob");
    exports2.isBlob = isBlob3;
  }
});

// ../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.browser.js
var require_ChecksumStream_browser = __commonJS({
  "../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ChecksumStream = void 0;
    var ReadableStreamRef3 = typeof ReadableStream === "function" ? ReadableStream : function() {
    };
    var ChecksumStream5 = class extends ReadableStreamRef3 {
      static {
        __name(this, "ChecksumStream");
      }
    };
    exports2.ChecksumStream = ChecksumStream5;
  }
});

// ../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.browser.js
var require_createChecksumStream_browser = __commonJS({
  "../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createChecksumStream = void 0;
    var util_base64_1 = require_dist_cjs10();
    var stream_type_check_1 = require_stream_type_check();
    var ChecksumStream_browser_1 = require_ChecksumStream_browser();
    var createChecksumStream5 = /* @__PURE__ */ __name(({ expectedChecksum, checksum, source, checksumSourceLocation, base64Encoder }) => {
      if (!(0, stream_type_check_1.isReadableStream)(source)) {
        throw new Error(`@smithy/util-stream: unsupported source type ${source?.constructor?.name ?? source} in ChecksumStream.`);
      }
      const encoder = base64Encoder ?? util_base64_1.toBase64;
      if (typeof TransformStream !== "function") {
        throw new Error("@smithy/util-stream: unable to instantiate ChecksumStream because API unavailable: ReadableStream/TransformStream.");
      }
      const transform = new TransformStream({
        start() {
        },
        async transform(chunk, controller) {
          checksum.update(chunk);
          controller.enqueue(chunk);
        },
        async flush(controller) {
          const digest = await checksum.digest();
          const received = encoder(digest);
          if (expectedChecksum !== received) {
            const error4 = new Error(`Checksum mismatch: expected "${expectedChecksum}" but received "${received}" in response header "${checksumSourceLocation}".`);
            controller.error(error4);
          } else {
            controller.terminate();
          }
        }
      });
      source.pipeThrough(transform);
      const readable = transform.readable;
      Object.setPrototypeOf(readable, ChecksumStream_browser_1.ChecksumStream.prototype);
      return readable;
    }, "createChecksumStream");
    exports2.createChecksumStream = createChecksumStream5;
  }
});

// ../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.js
var require_createChecksumStream = __commonJS({
  "../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createChecksumStream = createChecksumStream5;
    var stream_type_check_1 = require_stream_type_check();
    var ChecksumStream_1 = require_ChecksumStream();
    var createChecksumStream_browser_1 = require_createChecksumStream_browser();
    function createChecksumStream5(init) {
      if (typeof ReadableStream === "function" && (0, stream_type_check_1.isReadableStream)(init.source)) {
        return (0, createChecksumStream_browser_1.createChecksumStream)(init);
      }
      return new ChecksumStream_1.ChecksumStream(init);
    }
    __name(createChecksumStream5, "createChecksumStream");
  }
});

// ../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/ByteArrayCollector.js
var require_ByteArrayCollector = __commonJS({
  "../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/ByteArrayCollector.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ByteArrayCollector = void 0;
    var ByteArrayCollector3 = class {
      static {
        __name(this, "ByteArrayCollector");
      }
      allocByteArray;
      byteLength = 0;
      byteArrays = [];
      constructor(allocByteArray) {
        this.allocByteArray = allocByteArray;
      }
      push(byteArray) {
        this.byteArrays.push(byteArray);
        this.byteLength += byteArray.byteLength;
      }
      flush() {
        if (this.byteArrays.length === 1) {
          const bytes = this.byteArrays[0];
          this.reset();
          return bytes;
        }
        const aggregation = this.allocByteArray(this.byteLength);
        let cursor3 = 0;
        for (let i32 = 0; i32 < this.byteArrays.length; ++i32) {
          const bytes = this.byteArrays[i32];
          aggregation.set(bytes, cursor3);
          cursor3 += bytes.byteLength;
        }
        this.reset();
        return aggregation;
      }
      reset() {
        this.byteArrays = [];
        this.byteLength = 0;
      }
    };
    exports2.ByteArrayCollector = ByteArrayCollector3;
  }
});

// ../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadableStream.js
var require_createBufferedReadableStream = __commonJS({
  "../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadableStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createBufferedReadable = void 0;
    exports2.createBufferedReadableStream = createBufferedReadableStream3;
    exports2.merge = merge3;
    exports2.flush = flush3;
    exports2.sizeOf = sizeOf3;
    exports2.modeOf = modeOf3;
    var ByteArrayCollector_1 = require_ByteArrayCollector();
    function createBufferedReadableStream3(upstream, size, logger5) {
      const reader = upstream.getReader();
      let streamBufferingLoggedWarning = false;
      let bytesSeen = 0;
      const buffers = ["", new ByteArrayCollector_1.ByteArrayCollector((size2) => new Uint8Array(size2))];
      let mode = -1;
      const pull = /* @__PURE__ */ __name(async (controller) => {
        const { value, done } = await reader.read();
        const chunk = value;
        if (done) {
          if (mode !== -1) {
            const remainder = flush3(buffers, mode);
            if (sizeOf3(remainder) > 0) {
              controller.enqueue(remainder);
            }
          }
          controller.close();
        } else {
          const chunkMode = modeOf3(chunk, false);
          if (mode !== chunkMode) {
            if (mode >= 0) {
              controller.enqueue(flush3(buffers, mode));
            }
            mode = chunkMode;
          }
          if (mode === -1) {
            controller.enqueue(chunk);
            return;
          }
          const chunkSize = sizeOf3(chunk);
          bytesSeen += chunkSize;
          const bufferSize = sizeOf3(buffers[mode]);
          if (chunkSize >= size && bufferSize === 0) {
            controller.enqueue(chunk);
          } else {
            const newSize = merge3(buffers, mode, chunk);
            if (!streamBufferingLoggedWarning && bytesSeen > size * 2) {
              streamBufferingLoggedWarning = true;
              logger5?.warn(`@smithy/util-stream - stream chunk size ${chunkSize} is below threshold of ${size}, automatically buffering.`);
            }
            if (newSize >= size) {
              controller.enqueue(flush3(buffers, mode));
            } else {
              await pull(controller);
            }
          }
        }
      }, "pull");
      return new ReadableStream({
        pull
      });
    }
    __name(createBufferedReadableStream3, "createBufferedReadableStream");
    exports2.createBufferedReadable = createBufferedReadableStream3;
    function merge3(buffers, mode, chunk) {
      switch (mode) {
        case 0:
          buffers[0] += chunk;
          return sizeOf3(buffers[0]);
        case 1:
        case 2:
          buffers[mode].push(chunk);
          return sizeOf3(buffers[mode]);
      }
    }
    __name(merge3, "merge");
    function flush3(buffers, mode) {
      switch (mode) {
        case 0:
          const s = buffers[0];
          buffers[0] = "";
          return s;
        case 1:
        case 2:
          return buffers[mode].flush();
      }
      throw new Error(`@smithy/util-stream - invalid index ${mode} given to flush()`);
    }
    __name(flush3, "flush");
    function sizeOf3(chunk) {
      return chunk?.byteLength ?? chunk?.length ?? 0;
    }
    __name(sizeOf3, "sizeOf");
    function modeOf3(chunk, allowBuffer = true) {
      if (allowBuffer && typeof Buffer !== "undefined" && chunk instanceof Buffer) {
        return 2;
      }
      if (chunk instanceof Uint8Array) {
        return 1;
      }
      if (typeof chunk === "string") {
        return 0;
      }
      return -1;
    }
    __name(modeOf3, "modeOf");
  }
});

// ../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadable.js
var require_createBufferedReadable = __commonJS({
  "../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadable.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createBufferedReadable = createBufferedReadable3;
    var node_stream_1 = require("node:stream");
    var ByteArrayCollector_1 = require_ByteArrayCollector();
    var createBufferedReadableStream_1 = require_createBufferedReadableStream();
    var stream_type_check_1 = require_stream_type_check();
    function createBufferedReadable3(upstream, size, logger5) {
      if ((0, stream_type_check_1.isReadableStream)(upstream)) {
        return (0, createBufferedReadableStream_1.createBufferedReadableStream)(upstream, size, logger5);
      }
      const downstream = new node_stream_1.Readable({ read() {
      } });
      let streamBufferingLoggedWarning = false;
      let bytesSeen = 0;
      const buffers = [
        "",
        new ByteArrayCollector_1.ByteArrayCollector((size2) => new Uint8Array(size2)),
        new ByteArrayCollector_1.ByteArrayCollector((size2) => Buffer.from(new Uint8Array(size2)))
      ];
      let mode = -1;
      upstream.on("data", (chunk) => {
        const chunkMode = (0, createBufferedReadableStream_1.modeOf)(chunk, true);
        if (mode !== chunkMode) {
          if (mode >= 0) {
            downstream.push((0, createBufferedReadableStream_1.flush)(buffers, mode));
          }
          mode = chunkMode;
        }
        if (mode === -1) {
          downstream.push(chunk);
          return;
        }
        const chunkSize = (0, createBufferedReadableStream_1.sizeOf)(chunk);
        bytesSeen += chunkSize;
        const bufferSize = (0, createBufferedReadableStream_1.sizeOf)(buffers[mode]);
        if (chunkSize >= size && bufferSize === 0) {
          downstream.push(chunk);
        } else {
          const newSize = (0, createBufferedReadableStream_1.merge)(buffers, mode, chunk);
          if (!streamBufferingLoggedWarning && bytesSeen > size * 2) {
            streamBufferingLoggedWarning = true;
            logger5?.warn(`@smithy/util-stream - stream chunk size ${chunkSize} is below threshold of ${size}, automatically buffering.`);
          }
          if (newSize >= size) {
            downstream.push((0, createBufferedReadableStream_1.flush)(buffers, mode));
          }
        }
      });
      upstream.on("end", () => {
        if (mode !== -1) {
          const remainder = (0, createBufferedReadableStream_1.flush)(buffers, mode);
          if ((0, createBufferedReadableStream_1.sizeOf)(remainder) > 0) {
            downstream.push(remainder);
          }
        }
        downstream.push(null);
      });
      return downstream;
    }
    __name(createBufferedReadable3, "createBufferedReadable");
  }
});

// ../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.browser.js
var require_getAwsChunkedEncodingStream_browser = __commonJS({
  "../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getAwsChunkedEncodingStream = void 0;
    var getAwsChunkedEncodingStream5 = /* @__PURE__ */ __name((readableStream, options) => {
      const { base64Encoder, bodyLengthChecker, checksumAlgorithmFn, checksumLocationName, streamHasher } = options;
      const checksumRequired = base64Encoder !== void 0 && bodyLengthChecker !== void 0 && checksumAlgorithmFn !== void 0 && checksumLocationName !== void 0 && streamHasher !== void 0;
      const digest = checksumRequired ? streamHasher(checksumAlgorithmFn, readableStream) : void 0;
      const reader = readableStream.getReader();
      return new ReadableStream({
        async pull(controller) {
          const { value, done } = await reader.read();
          if (done) {
            controller.enqueue(`0\r
`);
            if (checksumRequired) {
              const checksum = base64Encoder(await digest);
              controller.enqueue(`${checksumLocationName}:${checksum}\r
`);
              controller.enqueue(`\r
`);
            }
            controller.close();
          } else {
            controller.enqueue(`${(bodyLengthChecker(value) || 0).toString(16)}\r
${value}\r
`);
          }
        }
      });
    }, "getAwsChunkedEncodingStream");
    exports2.getAwsChunkedEncodingStream = getAwsChunkedEncodingStream5;
  }
});

// ../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.js
var require_getAwsChunkedEncodingStream = __commonJS({
  "../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getAwsChunkedEncodingStream = getAwsChunkedEncodingStream5;
    var node_stream_1 = require("node:stream");
    var getAwsChunkedEncodingStream_browser_1 = require_getAwsChunkedEncodingStream_browser();
    var stream_type_check_1 = require_stream_type_check();
    function getAwsChunkedEncodingStream5(stream, options) {
      const readable = stream;
      const readableStream = stream;
      if ((0, stream_type_check_1.isReadableStream)(readableStream)) {
        return (0, getAwsChunkedEncodingStream_browser_1.getAwsChunkedEncodingStream)(readableStream, options);
      }
      const { base64Encoder, bodyLengthChecker, checksumAlgorithmFn, checksumLocationName, streamHasher } = options;
      const checksumRequired = base64Encoder !== void 0 && checksumAlgorithmFn !== void 0 && checksumLocationName !== void 0 && streamHasher !== void 0;
      const digest = checksumRequired ? streamHasher(checksumAlgorithmFn, readable) : void 0;
      const awsChunkedEncodingStream = new node_stream_1.Readable({
        read: /* @__PURE__ */ __name(() => {
        }, "read")
      });
      readable.on("data", (data3) => {
        const length = bodyLengthChecker(data3) || 0;
        if (length === 0) {
          return;
        }
        awsChunkedEncodingStream.push(`${length.toString(16)}\r
`);
        awsChunkedEncodingStream.push(data3);
        awsChunkedEncodingStream.push("\r\n");
      });
      readable.on("end", async () => {
        awsChunkedEncodingStream.push(`0\r
`);
        if (checksumRequired) {
          const checksum = base64Encoder(await digest);
          awsChunkedEncodingStream.push(`${checksumLocationName}:${checksum}\r
`);
          awsChunkedEncodingStream.push(`\r
`);
        }
        awsChunkedEncodingStream.push(null);
      });
      return awsChunkedEncodingStream;
    }
    __name(getAwsChunkedEncodingStream5, "getAwsChunkedEncodingStream");
  }
});

// ../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/headStream.browser.js
var require_headStream_browser = __commonJS({
  "../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/headStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.headStream = headStream5;
    async function headStream5(stream, bytes) {
      let byteLengthCounter = 0;
      const chunks2 = [];
      const reader = stream.getReader();
      let isDone = false;
      while (!isDone) {
        const { done, value } = await reader.read();
        if (value) {
          chunks2.push(value);
          byteLengthCounter += value?.byteLength ?? 0;
        }
        if (byteLengthCounter >= bytes) {
          break;
        }
        isDone = done;
      }
      reader.releaseLock();
      const collected = new Uint8Array(Math.min(bytes, byteLengthCounter));
      let offset = 0;
      for (const chunk of chunks2) {
        if (chunk.byteLength > collected.byteLength - offset) {
          collected.set(chunk.subarray(0, collected.byteLength - offset), offset);
          break;
        } else {
          collected.set(chunk, offset);
        }
        offset += chunk.length;
      }
      return collected;
    }
    __name(headStream5, "headStream");
  }
});

// ../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/headStream.js
var require_headStream = __commonJS({
  "../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/headStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.headStream = void 0;
    var stream_1 = require("stream");
    var headStream_browser_1 = require_headStream_browser();
    var stream_type_check_1 = require_stream_type_check();
    var headStream5 = /* @__PURE__ */ __name((stream, bytes) => {
      if ((0, stream_type_check_1.isReadableStream)(stream)) {
        return (0, headStream_browser_1.headStream)(stream, bytes);
      }
      return new Promise((resolve13, reject) => {
        const collector = new Collector8();
        collector.limit = bytes;
        stream.pipe(collector);
        stream.on("error", (err) => {
          collector.end();
          reject(err);
        });
        collector.on("error", reject);
        collector.on("finish", function() {
          const bytes2 = new Uint8Array(Buffer.concat(this.buffers));
          resolve13(bytes2);
        });
      });
    }, "headStream");
    exports2.headStream = headStream5;
    var Collector8 = class extends stream_1.Writable {
      static {
        __name(this, "Collector");
      }
      buffers = [];
      limit = Infinity;
      bytesBuffered = 0;
      _write(chunk, encoding, callback) {
        this.buffers.push(chunk);
        this.bytesBuffered += chunk.byteLength ?? 0;
        if (this.bytesBuffered >= this.limit) {
          const excess = this.bytesBuffered - this.limit;
          const tailBuffer = this.buffers[this.buffers.length - 1];
          this.buffers[this.buffers.length - 1] = tailBuffer.subarray(0, tailBuffer.byteLength - excess);
          this.emit("finish");
        }
        callback();
      }
    };
  }
});

// ../../node_modules/@smithy/util-uri-escape/dist-cjs/index.js
var require_dist_cjs11 = __commonJS({
  "../../node_modules/@smithy/util-uri-escape/dist-cjs/index.js"(exports2) {
    "use strict";
    var escapeUri6 = /* @__PURE__ */ __name((uri) => encodeURIComponent(uri).replace(/[!'()*]/g, hexEncode6), "escapeUri");
    var hexEncode6 = /* @__PURE__ */ __name((c32) => `%${c32.charCodeAt(0).toString(16).toUpperCase()}`, "hexEncode");
    var escapeUriPath6 = /* @__PURE__ */ __name((uri) => uri.split("/").map(escapeUri6).join("/"), "escapeUriPath");
    exports2.escapeUri = escapeUri6;
    exports2.escapeUriPath = escapeUriPath6;
  }
});

// ../../node_modules/@smithy/querystring-builder/dist-cjs/index.js
var require_dist_cjs12 = __commonJS({
  "../../node_modules/@smithy/querystring-builder/dist-cjs/index.js"(exports2) {
    "use strict";
    var utilUriEscape = require_dist_cjs11();
    function buildQueryString6(query) {
      const parts = [];
      for (let key of Object.keys(query).sort()) {
        const value = query[key];
        key = utilUriEscape.escapeUri(key);
        if (Array.isArray(value)) {
          for (let i32 = 0, iLen = value.length; i32 < iLen; i32++) {
            parts.push(`${key}=${utilUriEscape.escapeUri(value[i32])}`);
          }
        } else {
          let qsEntry = key;
          if (value || typeof value === "string") {
            qsEntry += `=${utilUriEscape.escapeUri(value)}`;
          }
          parts.push(qsEntry);
        }
      }
      return parts.join("&");
    }
    __name(buildQueryString6, "buildQueryString");
    exports2.buildQueryString = buildQueryString6;
  }
});

// ../../node_modules/@smithy/node-http-handler/dist-cjs/index.js
var require_dist_cjs13 = __commonJS({
  "../../node_modules/@smithy/node-http-handler/dist-cjs/index.js"(exports2) {
    "use strict";
    var protocolHttp = require_dist_cjs2();
    var querystringBuilder = require_dist_cjs12();
    var node_https = require("node:https");
    var node_stream = require("node:stream");
    var http2 = require("node:http2");
    function buildAbortError(abortSignal) {
      const reason = abortSignal && typeof abortSignal === "object" && "reason" in abortSignal ? abortSignal.reason : void 0;
      if (reason) {
        if (reason instanceof Error) {
          const abortError3 = new Error("Request aborted");
          abortError3.name = "AbortError";
          abortError3.cause = reason;
          return abortError3;
        }
        const abortError2 = new Error(String(reason));
        abortError2.name = "AbortError";
        return abortError2;
      }
      const abortError = new Error("Request aborted");
      abortError.name = "AbortError";
      return abortError;
    }
    __name(buildAbortError, "buildAbortError");
    var NODEJS_TIMEOUT_ERROR_CODES3 = ["ECONNRESET", "EPIPE", "ETIMEDOUT"];
    var getTransformedHeaders = /* @__PURE__ */ __name((headers) => {
      const transformedHeaders = {};
      for (const name of Object.keys(headers)) {
        const headerValues = headers[name];
        transformedHeaders[name] = Array.isArray(headerValues) ? headerValues.join(",") : headerValues;
      }
      return transformedHeaders;
    }, "getTransformedHeaders");
    var timing = {
      setTimeout: /* @__PURE__ */ __name((cb, ms) => setTimeout(cb, ms), "setTimeout"),
      clearTimeout: /* @__PURE__ */ __name((timeoutId) => clearTimeout(timeoutId), "clearTimeout")
    };
    var DEFER_EVENT_LISTENER_TIME$2 = 1e3;
    var setConnectionTimeout = /* @__PURE__ */ __name((request4, reject, timeoutInMs = 0) => {
      if (!timeoutInMs) {
        return -1;
      }
      const registerTimeout = /* @__PURE__ */ __name((offset) => {
        const timeoutId = timing.setTimeout(() => {
          request4.destroy();
          reject(Object.assign(new Error(`@smithy/node-http-handler - the request socket did not establish a connection with the server within the configured timeout of ${timeoutInMs} ms.`), {
            name: "TimeoutError"
          }));
        }, timeoutInMs - offset);
        const doWithSocket = /* @__PURE__ */ __name((socket) => {
          if (socket?.connecting) {
            socket.on("connect", () => {
              timing.clearTimeout(timeoutId);
            });
          } else {
            timing.clearTimeout(timeoutId);
          }
        }, "doWithSocket");
        if (request4.socket) {
          doWithSocket(request4.socket);
        } else {
          request4.on("socket", doWithSocket);
        }
      }, "registerTimeout");
      if (timeoutInMs < 2e3) {
        registerTimeout(0);
        return 0;
      }
      return timing.setTimeout(registerTimeout.bind(null, DEFER_EVENT_LISTENER_TIME$2), DEFER_EVENT_LISTENER_TIME$2);
    }, "setConnectionTimeout");
    var setRequestTimeout = /* @__PURE__ */ __name((req, reject, timeoutInMs = 0, throwOnRequestTimeout, logger5) => {
      if (timeoutInMs) {
        return timing.setTimeout(() => {
          let msg = `@smithy/node-http-handler - [${throwOnRequestTimeout ? "ERROR" : "WARN"}] a request has exceeded the configured ${timeoutInMs} ms requestTimeout.`;
          if (throwOnRequestTimeout) {
            const error4 = Object.assign(new Error(msg), {
              name: "TimeoutError",
              code: "ETIMEDOUT"
            });
            req.destroy(error4);
            reject(error4);
          } else {
            msg += ` Init client requestHandler with throwOnRequestTimeout=true to turn this into an error.`;
            logger5?.warn?.(msg);
          }
        }, timeoutInMs);
      }
      return -1;
    }, "setRequestTimeout");
    var DEFER_EVENT_LISTENER_TIME$1 = 3e3;
    var setSocketKeepAlive = /* @__PURE__ */ __name((request4, { keepAlive, keepAliveMsecs }, deferTimeMs = DEFER_EVENT_LISTENER_TIME$1) => {
      if (keepAlive !== true) {
        return -1;
      }
      const registerListener = /* @__PURE__ */ __name(() => {
        if (request4.socket) {
          request4.socket.setKeepAlive(keepAlive, keepAliveMsecs || 0);
        } else {
          request4.on("socket", (socket) => {
            socket.setKeepAlive(keepAlive, keepAliveMsecs || 0);
          });
        }
      }, "registerListener");
      if (deferTimeMs === 0) {
        registerListener();
        return 0;
      }
      return timing.setTimeout(registerListener, deferTimeMs);
    }, "setSocketKeepAlive");
    var DEFER_EVENT_LISTENER_TIME = 3e3;
    var setSocketTimeout = /* @__PURE__ */ __name((request4, reject, timeoutInMs = 0) => {
      const registerTimeout = /* @__PURE__ */ __name((offset) => {
        const timeout = timeoutInMs - offset;
        const onTimeout = /* @__PURE__ */ __name(() => {
          request4.destroy();
          reject(Object.assign(new Error(`@smithy/node-http-handler - the request socket timed out after ${timeoutInMs} ms of inactivity (configured by client requestHandler).`), { name: "TimeoutError" }));
        }, "onTimeout");
        if (request4.socket) {
          request4.socket.setTimeout(timeout, onTimeout);
          request4.on("close", () => request4.socket?.removeListener("timeout", onTimeout));
        } else {
          request4.setTimeout(timeout, onTimeout);
        }
      }, "registerTimeout");
      if (0 < timeoutInMs && timeoutInMs < 6e3) {
        registerTimeout(0);
        return 0;
      }
      return timing.setTimeout(registerTimeout.bind(null, timeoutInMs === 0 ? 0 : DEFER_EVENT_LISTENER_TIME), DEFER_EVENT_LISTENER_TIME);
    }, "setSocketTimeout");
    var MIN_WAIT_TIME = 6e3;
    async function writeRequestBody(httpRequest, request4, maxContinueTimeoutMs = MIN_WAIT_TIME, externalAgent = false) {
      const headers = request4.headers ?? {};
      const expect = headers.Expect || headers.expect;
      let timeoutId = -1;
      let sendBody = true;
      if (!externalAgent && expect === "100-continue") {
        sendBody = await Promise.race([
          new Promise((resolve13) => {
            timeoutId = Number(timing.setTimeout(() => resolve13(true), Math.max(MIN_WAIT_TIME, maxContinueTimeoutMs)));
          }),
          new Promise((resolve13) => {
            httpRequest.on("continue", () => {
              timing.clearTimeout(timeoutId);
              resolve13(true);
            });
            httpRequest.on("response", () => {
              timing.clearTimeout(timeoutId);
              resolve13(false);
            });
            httpRequest.on("error", () => {
              timing.clearTimeout(timeoutId);
              resolve13(false);
            });
          })
        ]);
      }
      if (sendBody) {
        writeBody(httpRequest, request4.body);
      }
    }
    __name(writeRequestBody, "writeRequestBody");
    function writeBody(httpRequest, body) {
      if (body instanceof node_stream.Readable) {
        body.pipe(httpRequest);
        return;
      }
      if (body) {
        const isBuffer = Buffer.isBuffer(body);
        const isString = typeof body === "string";
        if (isBuffer || isString) {
          if (isBuffer && body.byteLength === 0) {
            httpRequest.end();
          } else {
            httpRequest.end(body);
          }
          return;
        }
        const uint8 = body;
        if (typeof uint8 === "object" && uint8.buffer && typeof uint8.byteOffset === "number" && typeof uint8.byteLength === "number") {
          httpRequest.end(Buffer.from(uint8.buffer, uint8.byteOffset, uint8.byteLength));
          return;
        }
        httpRequest.end(Buffer.from(body));
        return;
      }
      httpRequest.end();
    }
    __name(writeBody, "writeBody");
    var DEFAULT_REQUEST_TIMEOUT = 0;
    var hAgent = void 0;
    var hRequest = void 0;
    var NodeHttpHandler = class _NodeHttpHandler {
      static {
        __name(this, "NodeHttpHandler");
      }
      config;
      configProvider;
      socketWarningTimestamp = 0;
      externalAgent = false;
      metadata = { handlerProtocol: "http/1.1" };
      static create(instanceOrOptions) {
        if (typeof instanceOrOptions?.handle === "function") {
          return instanceOrOptions;
        }
        return new _NodeHttpHandler(instanceOrOptions);
      }
      static checkSocketUsage(agent, socketWarningTimestamp, logger5 = console) {
        const { sockets, requests, maxSockets } = agent;
        if (typeof maxSockets !== "number" || maxSockets === Infinity) {
          return socketWarningTimestamp;
        }
        const interval = 15e3;
        if (Date.now() - interval < socketWarningTimestamp) {
          return socketWarningTimestamp;
        }
        if (sockets && requests) {
          for (const origin in sockets) {
            const socketsInUse = sockets[origin]?.length ?? 0;
            const requestsEnqueued = requests[origin]?.length ?? 0;
            if (socketsInUse >= maxSockets && requestsEnqueued >= 2 * maxSockets) {
              logger5?.warn?.(`@smithy/node-http-handler:WARN - socket usage at capacity=${socketsInUse} and ${requestsEnqueued} additional requests are enqueued.
See https://docs.aws.amazon.com/sdk-for-javascript/v3/developer-guide/node-configuring-maxsockets.html
or increase socketAcquisitionWarningTimeout=(millis) in the NodeHttpHandler config.`);
              return Date.now();
            }
          }
        }
        return socketWarningTimestamp;
      }
      constructor(options) {
        this.configProvider = new Promise((resolve13, reject) => {
          if (typeof options === "function") {
            options().then((_options) => {
              resolve13(this.resolveDefaultConfig(_options));
            }).catch(reject);
          } else {
            resolve13(this.resolveDefaultConfig(options));
          }
        });
      }
      destroy() {
        this.config?.httpAgent?.destroy();
        this.config?.httpsAgent?.destroy();
      }
      async handle(request4, { abortSignal, requestTimeout } = {}) {
        if (!this.config) {
          this.config = await this.configProvider;
        }
        const config2 = this.config;
        const isSSL = request4.protocol === "https:";
        if (!isSSL && !this.config.httpAgent) {
          this.config.httpAgent = await this.config.httpAgentProvider();
        }
        return new Promise((_resolve, _reject) => {
          let writeRequestBodyPromise = void 0;
          const timeouts = [];
          const resolve13 = /* @__PURE__ */ __name(async (arg) => {
            await writeRequestBodyPromise;
            timeouts.forEach(timing.clearTimeout);
            _resolve(arg);
          }, "resolve");
          const reject = /* @__PURE__ */ __name(async (arg) => {
            await writeRequestBodyPromise;
            timeouts.forEach(timing.clearTimeout);
            _reject(arg);
          }, "reject");
          if (abortSignal?.aborted) {
            const abortError = buildAbortError(abortSignal);
            reject(abortError);
            return;
          }
          const headers = request4.headers ?? {};
          const expectContinue = (headers.Expect ?? headers.expect) === "100-continue";
          let agent = isSSL ? config2.httpsAgent : config2.httpAgent;
          if (expectContinue && !this.externalAgent) {
            agent = new (isSSL ? node_https.Agent : hAgent)({
              keepAlive: false,
              maxSockets: Infinity
            });
          }
          timeouts.push(timing.setTimeout(() => {
            this.socketWarningTimestamp = _NodeHttpHandler.checkSocketUsage(agent, this.socketWarningTimestamp, config2.logger);
          }, config2.socketAcquisitionWarningTimeout ?? (config2.requestTimeout ?? 2e3) + (config2.connectionTimeout ?? 1e3)));
          const queryString = querystringBuilder.buildQueryString(request4.query || {});
          let auth = void 0;
          if (request4.username != null || request4.password != null) {
            const username = request4.username ?? "";
            const password = request4.password ?? "";
            auth = `${username}:${password}`;
          }
          let path47 = request4.path;
          if (queryString) {
            path47 += `?${queryString}`;
          }
          if (request4.fragment) {
            path47 += `#${request4.fragment}`;
          }
          let hostname = request4.hostname ?? "";
          if (hostname[0] === "[" && hostname.endsWith("]")) {
            hostname = request4.hostname.slice(1, -1);
          } else {
            hostname = request4.hostname;
          }
          const nodeHttpsOptions = {
            headers: request4.headers,
            host: hostname,
            method: request4.method,
            path: path47,
            port: request4.port,
            agent,
            auth
          };
          const requestFunc = isSSL ? node_https.request : hRequest;
          const req = requestFunc(nodeHttpsOptions, (res) => {
            const httpResponse = new protocolHttp.HttpResponse({
              statusCode: res.statusCode || -1,
              reason: res.statusMessage,
              headers: getTransformedHeaders(res.headers),
              body: res
            });
            resolve13({ response: httpResponse });
          });
          req.on("error", (err) => {
            if (NODEJS_TIMEOUT_ERROR_CODES3.includes(err.code)) {
              reject(Object.assign(err, { name: "TimeoutError" }));
            } else {
              reject(err);
            }
          });
          if (abortSignal) {
            const onAbort = /* @__PURE__ */ __name(() => {
              req.destroy();
              const abortError = buildAbortError(abortSignal);
              reject(abortError);
            }, "onAbort");
            if (typeof abortSignal.addEventListener === "function") {
              const signal = abortSignal;
              signal.addEventListener("abort", onAbort, { once: true });
              req.once("close", () => signal.removeEventListener("abort", onAbort));
            } else {
              abortSignal.onabort = onAbort;
            }
          }
          const effectiveRequestTimeout = requestTimeout ?? config2.requestTimeout;
          timeouts.push(setConnectionTimeout(req, reject, config2.connectionTimeout));
          timeouts.push(setRequestTimeout(req, reject, effectiveRequestTimeout, config2.throwOnRequestTimeout, config2.logger ?? console));
          timeouts.push(setSocketTimeout(req, reject, config2.socketTimeout));
          const httpAgent = nodeHttpsOptions.agent;
          if (typeof httpAgent === "object" && "keepAlive" in httpAgent) {
            timeouts.push(setSocketKeepAlive(req, {
              keepAlive: httpAgent.keepAlive,
              keepAliveMsecs: httpAgent.keepAliveMsecs
            }));
          }
          writeRequestBodyPromise = writeRequestBody(req, request4, effectiveRequestTimeout, this.externalAgent).catch((e32) => {
            timeouts.forEach(timing.clearTimeout);
            return _reject(e32);
          });
        });
      }
      updateHttpClientConfig(key, value) {
        this.config = void 0;
        this.configProvider = this.configProvider.then((config2) => {
          return {
            ...config2,
            [key]: value
          };
        });
      }
      httpHandlerConfigs() {
        return this.config ?? {};
      }
      resolveDefaultConfig(options) {
        const { requestTimeout, connectionTimeout, socketTimeout, socketAcquisitionWarningTimeout, httpAgent, httpsAgent, throwOnRequestTimeout, logger: logger5 } = options || {};
        const keepAlive = true;
        const maxSockets = 50;
        return {
          connectionTimeout,
          requestTimeout,
          socketTimeout,
          socketAcquisitionWarningTimeout,
          throwOnRequestTimeout,
          httpAgentProvider: /* @__PURE__ */ __name(async () => {
            const { Agent, request: request4 } = await import("node:http");
            hRequest = request4;
            hAgent = Agent;
            if (httpAgent instanceof hAgent || typeof httpAgent?.destroy === "function") {
              this.externalAgent = true;
              return httpAgent;
            }
            return new hAgent({ keepAlive, maxSockets, ...httpAgent });
          }, "httpAgentProvider"),
          httpsAgent: (() => {
            if (httpsAgent instanceof node_https.Agent || typeof httpsAgent?.destroy === "function") {
              this.externalAgent = true;
              return httpsAgent;
            }
            return new node_https.Agent({ keepAlive, maxSockets, ...httpsAgent });
          })(),
          logger: logger5
        };
      }
    };
    var ids = new Uint16Array(1);
    var ClientHttp2SessionRef = class {
      static {
        __name(this, "ClientHttp2SessionRef");
      }
      id = ids[0]++;
      total = 0;
      max = 0;
      session;
      refs = 0;
      constructor(session) {
        session.unref();
        this.session = session;
      }
      retain() {
        if (this.session.destroyed) {
          throw new Error("@smithy/node-http-handler - cannot acquire reference to destroyed session.");
        }
        this.refs += 1;
        this.total += 1;
        this.max = Math.max(this.refs, this.max);
        this.session.ref();
      }
      free() {
        if (this.session.destroyed) {
          return;
        }
        this.refs -= 1;
        if (this.refs === 0) {
          this.session.unref();
        }
        if (this.refs < 0) {
          throw new Error("@smithy/node-http-handler - ClientHttp2Session refcount at zero, cannot decrement.");
        }
      }
      deref() {
        return this.session;
      }
      close() {
        if (!this.session.closed) {
          this.session.close();
        }
      }
      destroy() {
        this.refs = 0;
        if (!this.session.destroyed) {
          this.session.destroy();
        }
      }
      useCount() {
        return this.refs;
      }
    };
    var NodeHttp2ConnectionPool = class {
      static {
        __name(this, "NodeHttp2ConnectionPool");
      }
      sessions = [];
      maxConcurrency = 0;
      constructor(sessions) {
        this.sessions = (sessions ?? []).map((session) => new ClientHttp2SessionRef(session));
      }
      poll() {
        let cleanup = false;
        for (const session of this.sessions) {
          if (session.deref().destroyed) {
            cleanup = true;
            continue;
          }
          if (!this.maxConcurrency || session.useCount() < this.maxConcurrency) {
            return session;
          }
        }
        if (cleanup) {
          for (const session of this.sessions) {
            if (session.deref().destroyed) {
              this.remove(session);
            }
          }
        }
      }
      offerLast(ref) {
        this.sessions.push(ref);
      }
      remove(ref) {
        const ix = this.sessions.indexOf(ref);
        if (ix > -1) {
          this.sessions.splice(ix, 1);
        }
      }
      [Symbol.iterator]() {
        return this.sessions[Symbol.iterator]();
      }
      setMaxConcurrency(maxConcurrency) {
        this.maxConcurrency = maxConcurrency;
      }
      destroy(ref) {
        this.remove(ref);
        ref.destroy();
      }
    };
    var NodeHttp2ConnectionManager = class {
      static {
        __name(this, "NodeHttp2ConnectionManager");
      }
      config;
      connectionPools = /* @__PURE__ */ new Map();
      constructor(config2) {
        this.config = config2;
        if (this.config.maxConcurrency && this.config.maxConcurrency <= 0) {
          throw new RangeError("maxConcurrency must be greater than zero.");
        }
      }
      lease(requestContext, connectionConfiguration) {
        const url = this.getUrlString(requestContext);
        const pool = this.getPool(url);
        if (!this.config.disableConcurrency && !connectionConfiguration.isEventStream) {
          const available = pool.poll();
          if (available) {
            available.retain();
            return available;
          }
        }
        const ref = new ClientHttp2SessionRef(http2.connect(url));
        const session = ref.deref();
        if (this.config.maxConcurrency) {
          session.settings({ maxConcurrentStreams: this.config.maxConcurrency }, (err) => {
            if (err) {
              throw new Error("Fail to set maxConcurrentStreams to " + this.config.maxConcurrency + "when creating new session for " + requestContext.destination.toString());
            }
          });
        }
        const graceful = /* @__PURE__ */ __name(() => {
          this.removeFromPoolAndClose(url, ref);
        }, "graceful");
        const ensureDestroyed = /* @__PURE__ */ __name(() => {
          this.removeFromPoolAndCheckedDestroy(url, ref);
        }, "ensureDestroyed");
        session.on("goaway", graceful);
        session.on("error", ensureDestroyed);
        session.on("frameError", ensureDestroyed);
        session.on("close", ensureDestroyed);
        if (connectionConfiguration.requestTimeout) {
          session.setTimeout(connectionConfiguration.requestTimeout, ensureDestroyed);
        }
        pool.offerLast(ref);
        ref.retain();
        return ref;
      }
      release(_requestContext, ref) {
        ref.free();
      }
      createIsolatedSession(requestContext, connectionConfiguration) {
        const url = this.getUrlString(requestContext);
        const ref = new ClientHttp2SessionRef(http2.connect(url));
        const session = ref.deref();
        session.settings({ maxConcurrentStreams: 1 });
        const ensureDestroyed = /* @__PURE__ */ __name(() => {
          ref.destroy();
        }, "ensureDestroyed");
        session.on("error", ensureDestroyed);
        session.on("frameError", ensureDestroyed);
        session.on("close", ensureDestroyed);
        if (connectionConfiguration.requestTimeout) {
          session.setTimeout(connectionConfiguration.requestTimeout, ensureDestroyed);
        }
        ref.retain();
        return ref;
      }
      destroy() {
        for (const [url, connectionPool] of this.connectionPools) {
          for (const session of [...connectionPool]) {
            session.destroy();
          }
          this.connectionPools.delete(url);
        }
      }
      setMaxConcurrentStreams(maxConcurrentStreams) {
        if (maxConcurrentStreams && maxConcurrentStreams <= 0) {
          throw new RangeError("maxConcurrentStreams must be greater than zero.");
        }
        this.config.maxConcurrency = maxConcurrentStreams;
        for (const pool of this.connectionPools.values()) {
          pool.setMaxConcurrency(maxConcurrentStreams);
        }
      }
      setDisableConcurrentStreams(disableConcurrentStreams) {
        this.config.disableConcurrency = disableConcurrentStreams;
      }
      debug() {
        const pools = {};
        for (const [url, pool] of this.connectionPools) {
          const sessions = [];
          for (const ref of pool) {
            sessions.push({
              id: ref.id,
              active: ref.useCount(),
              maxConcurrent: ref.max,
              totalRequests: ref.total
            });
          }
          pools[url] = { sessions };
        }
        return pools;
      }
      removeFromPoolAndClose(authority, ref) {
        this.connectionPools.get(authority)?.remove(ref);
        ref.close();
      }
      removeFromPoolAndCheckedDestroy(authority, ref) {
        this.connectionPools.get(authority)?.remove(ref);
        ref.destroy();
      }
      getPool(url) {
        if (!this.connectionPools.has(url)) {
          const pool = new NodeHttp2ConnectionPool();
          if (this.config.maxConcurrency) {
            pool.setMaxConcurrency(this.config.maxConcurrency);
          }
          this.connectionPools.set(url, pool);
        }
        return this.connectionPools.get(url);
      }
      getUrlString(request4) {
        return request4.destination.toString();
      }
    };
    var NodeHttp2Handler = class _NodeHttp2Handler {
      static {
        __name(this, "NodeHttp2Handler");
      }
      config;
      configProvider;
      metadata = { handlerProtocol: "h2" };
      connectionManager = new NodeHttp2ConnectionManager({});
      static create(instanceOrOptions) {
        if (typeof instanceOrOptions?.handle === "function") {
          return instanceOrOptions;
        }
        return new _NodeHttp2Handler(instanceOrOptions);
      }
      constructor(options) {
        this.configProvider = new Promise((resolve13, reject) => {
          if (typeof options === "function") {
            options().then((opts) => {
              resolve13(opts || {});
            }).catch(reject);
          } else {
            resolve13(options || {});
          }
        });
      }
      destroy() {
        this.connectionManager.destroy();
      }
      async handle(request4, { abortSignal, requestTimeout, isEventStream } = {}) {
        if (!this.config) {
          this.config = await this.configProvider;
          const { disableConcurrentStreams: disableConcurrentStreams2, maxConcurrentStreams } = this.config;
          this.connectionManager.setDisableConcurrentStreams(disableConcurrentStreams2 ?? false);
          if (maxConcurrentStreams) {
            this.connectionManager.setMaxConcurrentStreams(maxConcurrentStreams);
          }
        }
        const { requestTimeout: configRequestTimeout, disableConcurrentStreams } = this.config;
        const useIsolatedSession = disableConcurrentStreams || isEventStream;
        const effectiveRequestTimeout = requestTimeout ?? configRequestTimeout;
        return new Promise((_resolve, _reject) => {
          let fulfilled = false;
          let writeRequestBodyPromise = void 0;
          const resolve13 = /* @__PURE__ */ __name(async (arg) => {
            await writeRequestBodyPromise;
            _resolve(arg);
          }, "resolve");
          const reject = /* @__PURE__ */ __name(async (arg) => {
            await writeRequestBodyPromise;
            _reject(arg);
          }, "reject");
          if (abortSignal?.aborted) {
            fulfilled = true;
            const abortError = buildAbortError(abortSignal);
            reject(abortError);
            return;
          }
          const { hostname, method, port, protocol, query } = request4;
          let auth = "";
          if (request4.username != null || request4.password != null) {
            const username = request4.username ?? "";
            const password = request4.password ?? "";
            auth = `${username}:${password}@`;
          }
          const authority = `${protocol}//${auth}${hostname}${port ? `:${port}` : ""}`;
          const requestContext = { destination: new URL(authority) };
          const connectConfig = {
            requestTimeout: this.config?.sessionTimeout,
            isEventStream
          };
          const ref = useIsolatedSession ? this.connectionManager.createIsolatedSession(requestContext, connectConfig) : this.connectionManager.lease(requestContext, connectConfig);
          const session = ref.deref();
          const rejectWithDestroy = /* @__PURE__ */ __name((err) => {
            if (useIsolatedSession) {
              ref.destroy();
            }
            fulfilled = true;
            reject(err);
          }, "rejectWithDestroy");
          const queryString = querystringBuilder.buildQueryString(query ?? {});
          let path47 = request4.path;
          if (queryString) {
            path47 += `?${queryString}`;
          }
          if (request4.fragment) {
            path47 += `#${request4.fragment}`;
          }
          const clientHttp2Stream = session.request({
            ...request4.headers,
            [http2.constants.HTTP2_HEADER_PATH]: path47,
            [http2.constants.HTTP2_HEADER_METHOD]: method
          });
          if (effectiveRequestTimeout) {
            clientHttp2Stream.setTimeout(effectiveRequestTimeout, () => {
              clientHttp2Stream.close();
              const timeoutError = new Error(`Stream timed out because of no activity for ${effectiveRequestTimeout} ms`);
              timeoutError.name = "TimeoutError";
              rejectWithDestroy(timeoutError);
            });
          }
          if (abortSignal) {
            const onAbort = /* @__PURE__ */ __name(() => {
              clientHttp2Stream.close();
              const abortError = buildAbortError(abortSignal);
              rejectWithDestroy(abortError);
            }, "onAbort");
            if (typeof abortSignal.addEventListener === "function") {
              const signal = abortSignal;
              signal.addEventListener("abort", onAbort, { once: true });
              clientHttp2Stream.once("close", () => signal.removeEventListener("abort", onAbort));
            } else {
              abortSignal.onabort = onAbort;
            }
          }
          clientHttp2Stream.on("frameError", (type, code, id) => {
            rejectWithDestroy(new Error(`Frame type id ${type} in stream id ${id} has failed with code ${code}.`));
          });
          clientHttp2Stream.on("error", rejectWithDestroy);
          clientHttp2Stream.on("aborted", () => {
            rejectWithDestroy(new Error(`HTTP/2 stream is abnormally aborted in mid-communication with result code ${clientHttp2Stream.rstCode}.`));
          });
          clientHttp2Stream.on("response", (headers) => {
            const httpResponse = new protocolHttp.HttpResponse({
              statusCode: headers[":status"] ?? -1,
              headers: getTransformedHeaders(headers),
              body: clientHttp2Stream
            });
            fulfilled = true;
            resolve13({ response: httpResponse });
            if (useIsolatedSession) {
              session.close();
            }
          });
          clientHttp2Stream.on("close", () => {
            if (useIsolatedSession) {
              ref.destroy();
            } else {
              this.connectionManager.release(requestContext, ref);
            }
            if (!fulfilled) {
              rejectWithDestroy(new Error("Unexpected error: http2 request did not get a response"));
            }
          });
          writeRequestBodyPromise = writeRequestBody(clientHttp2Stream, request4, effectiveRequestTimeout);
        });
      }
      updateHttpClientConfig(key, value) {
        this.config = void 0;
        this.configProvider = this.configProvider.then((config2) => {
          return {
            ...config2,
            [key]: value
          };
        });
      }
      httpHandlerConfigs() {
        return this.config ?? {};
      }
    };
    var Collector8 = class extends node_stream.Writable {
      static {
        __name(this, "Collector");
      }
      bufferedBytes = [];
      _write(chunk, encoding, callback) {
        this.bufferedBytes.push(chunk);
        callback();
      }
    };
    var streamCollector42 = /* @__PURE__ */ __name((stream) => {
      if (isReadableStreamInstance6(stream)) {
        return collectReadableStream6(stream);
      }
      return new Promise((resolve13, reject) => {
        const collector = new Collector8();
        stream.pipe(collector);
        stream.on("error", (err) => {
          collector.end();
          reject(err);
        });
        collector.on("error", reject);
        collector.on("finish", function() {
          const bytes = new Uint8Array(Buffer.concat(this.bufferedBytes));
          resolve13(bytes);
        });
      });
    }, "streamCollector");
    var isReadableStreamInstance6 = /* @__PURE__ */ __name((stream) => typeof ReadableStream === "function" && stream instanceof ReadableStream, "isReadableStreamInstance");
    async function collectReadableStream6(stream) {
      const chunks2 = [];
      const reader = stream.getReader();
      let isDone = false;
      let length = 0;
      while (!isDone) {
        const { done, value } = await reader.read();
        if (value) {
          chunks2.push(value);
          length += value.length;
        }
        isDone = done;
      }
      const collected = new Uint8Array(length);
      let offset = 0;
      for (const chunk of chunks2) {
        collected.set(chunk, offset);
        offset += chunk.length;
      }
      return collected;
    }
    __name(collectReadableStream6, "collectReadableStream");
    exports2.DEFAULT_REQUEST_TIMEOUT = DEFAULT_REQUEST_TIMEOUT;
    exports2.NodeHttp2Handler = NodeHttp2Handler;
    exports2.NodeHttpHandler = NodeHttpHandler;
    exports2.streamCollector = streamCollector42;
  }
});

// ../../node_modules/@smithy/fetch-http-handler/dist-cjs/index.js
var require_dist_cjs14 = __commonJS({
  "../../node_modules/@smithy/fetch-http-handler/dist-cjs/index.js"(exports2) {
    "use strict";
    var protocolHttp = require_dist_cjs2();
    var querystringBuilder = require_dist_cjs12();
    var utilBase64 = require_dist_cjs10();
    function createRequest(url, requestOptions) {
      return new Request(url, requestOptions);
    }
    __name(createRequest, "createRequest");
    function requestTimeout(timeoutInMs = 0) {
      return new Promise((resolve13, reject) => {
        if (timeoutInMs) {
          setTimeout(() => {
            const timeoutError = new Error(`Request did not complete within ${timeoutInMs} ms`);
            timeoutError.name = "TimeoutError";
            reject(timeoutError);
          }, timeoutInMs);
        }
      });
    }
    __name(requestTimeout, "requestTimeout");
    var keepAliveSupport = {
      supported: void 0
    };
    var FetchHttpHandler = class _FetchHttpHandler {
      static {
        __name(this, "FetchHttpHandler");
      }
      config;
      configProvider;
      static create(instanceOrOptions) {
        if (typeof instanceOrOptions?.handle === "function") {
          return instanceOrOptions;
        }
        return new _FetchHttpHandler(instanceOrOptions);
      }
      constructor(options) {
        if (typeof options === "function") {
          this.configProvider = options().then((opts) => opts || {});
        } else {
          this.config = options ?? {};
          this.configProvider = Promise.resolve(this.config);
        }
        if (keepAliveSupport.supported === void 0) {
          keepAliveSupport.supported = Boolean(typeof Request !== "undefined" && "keepalive" in createRequest("https://[::1]"));
        }
      }
      destroy() {
      }
      async handle(request4, { abortSignal, requestTimeout: requestTimeout$1 } = {}) {
        if (!this.config) {
          this.config = await this.configProvider;
        }
        const requestTimeoutInMs = requestTimeout$1 ?? this.config.requestTimeout;
        const keepAlive = this.config.keepAlive === true;
        const credentials = this.config.credentials;
        if (abortSignal?.aborted) {
          const abortError = buildAbortError(abortSignal);
          return Promise.reject(abortError);
        }
        let path47 = request4.path;
        const queryString = querystringBuilder.buildQueryString(request4.query || {});
        if (queryString) {
          path47 += `?${queryString}`;
        }
        if (request4.fragment) {
          path47 += `#${request4.fragment}`;
        }
        let auth = "";
        if (request4.username != null || request4.password != null) {
          const username = request4.username ?? "";
          const password = request4.password ?? "";
          auth = `${username}:${password}@`;
        }
        const { port, method } = request4;
        const url = `${request4.protocol}//${auth}${request4.hostname}${port ? `:${port}` : ""}${path47}`;
        const body = method === "GET" || method === "HEAD" ? void 0 : request4.body;
        const requestOptions = {
          body,
          headers: new Headers(request4.headers),
          method,
          credentials
        };
        if (this.config?.cache) {
          requestOptions.cache = this.config.cache;
        }
        if (body) {
          requestOptions.duplex = "half";
        }
        if (typeof AbortController !== "undefined") {
          requestOptions.signal = abortSignal;
        }
        if (keepAliveSupport.supported) {
          requestOptions.keepalive = keepAlive;
        }
        if (typeof this.config.requestInit === "function") {
          Object.assign(requestOptions, this.config.requestInit(request4));
        }
        let removeSignalEventListener = /* @__PURE__ */ __name(() => {
        }, "removeSignalEventListener");
        const fetchRequest = createRequest(url, requestOptions);
        const raceOfPromises = [
          fetch(fetchRequest).then((response) => {
            const fetchHeaders = response.headers;
            const transformedHeaders = {};
            for (const pair of fetchHeaders.entries()) {
              transformedHeaders[pair[0]] = pair[1];
            }
            const hasReadableStream = response.body != void 0;
            if (!hasReadableStream) {
              return response.blob().then((body2) => ({
                response: new protocolHttp.HttpResponse({
                  headers: transformedHeaders,
                  reason: response.statusText,
                  statusCode: response.status,
                  body: body2
                })
              }));
            }
            return {
              response: new protocolHttp.HttpResponse({
                headers: transformedHeaders,
                reason: response.statusText,
                statusCode: response.status,
                body: response.body
              })
            };
          }),
          requestTimeout(requestTimeoutInMs)
        ];
        if (abortSignal) {
          raceOfPromises.push(new Promise((resolve13, reject) => {
            const onAbort = /* @__PURE__ */ __name(() => {
              const abortError = buildAbortError(abortSignal);
              reject(abortError);
            }, "onAbort");
            if (typeof abortSignal.addEventListener === "function") {
              const signal = abortSignal;
              signal.addEventListener("abort", onAbort, { once: true });
              removeSignalEventListener = /* @__PURE__ */ __name(() => signal.removeEventListener("abort", onAbort), "removeSignalEventListener");
            } else {
              abortSignal.onabort = onAbort;
            }
          }));
        }
        return Promise.race(raceOfPromises).finally(removeSignalEventListener);
      }
      updateHttpClientConfig(key, value) {
        this.config = void 0;
        this.configProvider = this.configProvider.then((config2) => {
          config2[key] = value;
          return config2;
        });
      }
      httpHandlerConfigs() {
        return this.config ?? {};
      }
    };
    function buildAbortError(abortSignal) {
      const reason = abortSignal && typeof abortSignal === "object" && "reason" in abortSignal ? abortSignal.reason : void 0;
      if (reason) {
        if (reason instanceof Error) {
          const abortError3 = new Error("Request aborted");
          abortError3.name = "AbortError";
          abortError3.cause = reason;
          return abortError3;
        }
        const abortError2 = new Error(String(reason));
        abortError2.name = "AbortError";
        return abortError2;
      }
      const abortError = new Error("Request aborted");
      abortError.name = "AbortError";
      return abortError;
    }
    __name(buildAbortError, "buildAbortError");
    var streamCollector42 = /* @__PURE__ */ __name(async (stream) => {
      if (typeof Blob === "function" && stream instanceof Blob || stream.constructor?.name === "Blob") {
        if (Blob.prototype.arrayBuffer !== void 0) {
          return new Uint8Array(await stream.arrayBuffer());
        }
        return collectBlob6(stream);
      }
      return collectStream6(stream);
    }, "streamCollector");
    async function collectBlob6(blob) {
      const base64 = await readToBase646(blob);
      const arrayBuffer = utilBase64.fromBase64(base64);
      return new Uint8Array(arrayBuffer);
    }
    __name(collectBlob6, "collectBlob");
    async function collectStream6(stream) {
      const chunks2 = [];
      const reader = stream.getReader();
      let isDone = false;
      let length = 0;
      while (!isDone) {
        const { done, value } = await reader.read();
        if (value) {
          chunks2.push(value);
          length += value.length;
        }
        isDone = done;
      }
      const collected = new Uint8Array(length);
      let offset = 0;
      for (const chunk of chunks2) {
        collected.set(chunk, offset);
        offset += chunk.length;
      }
      return collected;
    }
    __name(collectStream6, "collectStream");
    function readToBase646(blob) {
      return new Promise((resolve13, reject) => {
        const reader = new FileReader();
        reader.onloadend = () => {
          if (reader.readyState !== 2) {
            return reject(new Error("Reader aborted too early"));
          }
          const result2 = reader.result ?? "";
          const commaIndex = result2.indexOf(",");
          const dataOffset = commaIndex > -1 ? commaIndex + 1 : result2.length;
          resolve13(result2.substring(dataOffset));
        };
        reader.onabort = () => reject(new Error("Read aborted"));
        reader.onerror = () => reject(reader.error);
        reader.readAsDataURL(blob);
      });
    }
    __name(readToBase646, "readToBase64");
    exports2.FetchHttpHandler = FetchHttpHandler;
    exports2.keepAliveSupport = keepAliveSupport;
    exports2.streamCollector = streamCollector42;
  }
});

// ../../node_modules/@smithy/util-hex-encoding/dist-cjs/index.js
var require_dist_cjs15 = __commonJS({
  "../../node_modules/@smithy/util-hex-encoding/dist-cjs/index.js"(exports2) {
    "use strict";
    var SHORT_TO_HEX6 = {};
    var HEX_TO_SHORT6 = {};
    for (let i32 = 0; i32 < 256; i32++) {
      let encodedByte = i32.toString(16).toLowerCase();
      if (encodedByte.length === 1) {
        encodedByte = `0${encodedByte}`;
      }
      SHORT_TO_HEX6[i32] = encodedByte;
      HEX_TO_SHORT6[encodedByte] = i32;
    }
    function fromHex6(encoded) {
      if (encoded.length % 2 !== 0) {
        throw new Error("Hex encoded strings must have an even number length");
      }
      const out = new Uint8Array(encoded.length / 2);
      for (let i32 = 0; i32 < encoded.length; i32 += 2) {
        const encodedByte = encoded.slice(i32, i32 + 2).toLowerCase();
        if (encodedByte in HEX_TO_SHORT6) {
          out[i32 / 2] = HEX_TO_SHORT6[encodedByte];
        } else {
          throw new Error(`Cannot decode unrecognized sequence ${encodedByte} as hexadecimal`);
        }
      }
      return out;
    }
    __name(fromHex6, "fromHex");
    function toHex6(bytes) {
      let out = "";
      for (let i32 = 0; i32 < bytes.byteLength; i32++) {
        out += SHORT_TO_HEX6[bytes[i32]];
      }
      return out;
    }
    __name(toHex6, "toHex");
    exports2.fromHex = fromHex6;
    exports2.toHex = toHex6;
  }
});

// ../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.browser.js
var require_sdk_stream_mixin_browser = __commonJS({
  "../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.sdkStreamMixin = void 0;
    var fetch_http_handler_1 = require_dist_cjs14();
    var util_base64_1 = require_dist_cjs10();
    var util_hex_encoding_1 = require_dist_cjs15();
    var util_utf8_1 = require_dist_cjs9();
    var stream_type_check_1 = require_stream_type_check();
    var ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11 = "The stream has already been transformed.";
    var sdkStreamMixin12 = /* @__PURE__ */ __name((stream) => {
      if (!isBlobInstance6(stream) && !(0, stream_type_check_1.isReadableStream)(stream)) {
        const name = stream?.__proto__?.constructor?.name || stream;
        throw new Error(`Unexpected stream implementation, expect Blob or ReadableStream, got ${name}`);
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
        }
        transformed = true;
        return await (0, fetch_http_handler_1.streamCollector)(stream);
      }, "transformToByteArray");
      const blobToWebStream = /* @__PURE__ */ __name((blob) => {
        if (typeof blob.stream !== "function") {
          throw new Error("Cannot transform payload Blob to web stream. Please make sure the Blob.stream() is polyfilled.\nIf you are using React Native, this API is not yet supported, see: https://react-native.canny.io/feature-requests/p/fetch-streaming-body");
        }
        return blob.stream();
      }, "blobToWebStream");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === "base64") {
            return (0, util_base64_1.toBase64)(buf);
          } else if (encoding === "hex") {
            return (0, util_hex_encoding_1.toHex)(buf);
          } else if (encoding === void 0 || encoding === "utf8" || encoding === "utf-8") {
            return (0, util_utf8_1.toUtf8)(buf);
          } else if (typeof TextDecoder === "function") {
            return new TextDecoder(encoding).decode(buf);
          } else {
            throw new Error("TextDecoder is not available, please make sure polyfill is provided.");
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
          }
          transformed = true;
          if (isBlobInstance6(stream)) {
            return blobToWebStream(stream);
          } else if ((0, stream_type_check_1.isReadableStream)(stream)) {
            return stream;
          } else {
            throw new Error(`Cannot transform payload to web stream, got ${stream}`);
          }
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
    exports2.sdkStreamMixin = sdkStreamMixin12;
    var isBlobInstance6 = /* @__PURE__ */ __name((stream) => typeof Blob === "function" && stream instanceof Blob, "isBlobInstance");
  }
});

// ../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.js
var require_sdk_stream_mixin = __commonJS({
  "../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.sdkStreamMixin = void 0;
    var node_http_handler_1 = require_dist_cjs13();
    var util_buffer_from_1 = require_dist_cjs8();
    var stream_1 = require("stream");
    var sdk_stream_mixin_browser_1 = require_sdk_stream_mixin_browser();
    var ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11 = "The stream has already been transformed.";
    var sdkStreamMixin12 = /* @__PURE__ */ __name((stream) => {
      if (!(stream instanceof stream_1.Readable)) {
        try {
          return (0, sdk_stream_mixin_browser_1.sdkStreamMixin)(stream);
        } catch (e32) {
          const name = stream?.__proto__?.constructor?.name || stream;
          throw new Error(`Unexpected stream implementation, expect Stream.Readable instance, got ${name}`);
        }
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
        }
        transformed = true;
        return await (0, node_http_handler_1.streamCollector)(stream);
      }, "transformToByteArray");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === void 0 || Buffer.isEncoding(encoding)) {
            return (0, util_buffer_from_1.fromArrayBuffer)(buf.buffer, buf.byteOffset, buf.byteLength).toString(encoding);
          } else {
            const decoder = new TextDecoder(encoding);
            return decoder.decode(buf);
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
          }
          if (stream.readableFlowing !== null) {
            throw new Error("The stream has been consumed by other callbacks.");
          }
          if (typeof stream_1.Readable.toWeb !== "function") {
            throw new Error("Readable.toWeb() is not supported. Please ensure a polyfill is available.");
          }
          transformed = true;
          return stream_1.Readable.toWeb(stream);
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
    exports2.sdkStreamMixin = sdkStreamMixin12;
  }
});

// ../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/splitStream.browser.js
var require_splitStream_browser = __commonJS({
  "../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/splitStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.splitStream = splitStream5;
    async function splitStream5(stream) {
      if (typeof stream.stream === "function") {
        stream = stream.stream();
      }
      const readableStream = stream;
      return readableStream.tee();
    }
    __name(splitStream5, "splitStream");
  }
});

// ../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/splitStream.js
var require_splitStream = __commonJS({
  "../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/splitStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.splitStream = splitStream5;
    var stream_1 = require("stream");
    var splitStream_browser_1 = require_splitStream_browser();
    var stream_type_check_1 = require_stream_type_check();
    async function splitStream5(stream) {
      if ((0, stream_type_check_1.isReadableStream)(stream) || (0, stream_type_check_1.isBlob)(stream)) {
        return (0, splitStream_browser_1.splitStream)(stream);
      }
      const stream1 = new stream_1.PassThrough();
      const stream2 = new stream_1.PassThrough();
      stream.pipe(stream1);
      stream.pipe(stream2);
      return [stream1, stream2];
    }
    __name(splitStream5, "splitStream");
  }
});

// ../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/index.js
var require_dist_cjs16 = __commonJS({
  "../../node_modules/@smithy/core/node_modules/@smithy/util-stream/dist-cjs/index.js"(exports2) {
    "use strict";
    var utilBase64 = require_dist_cjs10();
    var utilUtf8 = require_dist_cjs9();
    var ChecksumStream5 = require_ChecksumStream();
    var createChecksumStream5 = require_createChecksumStream();
    var createBufferedReadable3 = require_createBufferedReadable();
    var getAwsChunkedEncodingStream5 = require_getAwsChunkedEncodingStream();
    var headStream5 = require_headStream();
    var sdkStreamMixin12 = require_sdk_stream_mixin();
    var splitStream5 = require_splitStream();
    var streamTypeCheck = require_stream_type_check();
    var Uint8ArrayBlobAdapter8 = class _Uint8ArrayBlobAdapter extends Uint8Array {
      static {
        __name(this, "Uint8ArrayBlobAdapter");
      }
      static fromString(source, encoding = "utf-8") {
        if (typeof source === "string") {
          if (encoding === "base64") {
            return _Uint8ArrayBlobAdapter.mutate(utilBase64.fromBase64(source));
          }
          return _Uint8ArrayBlobAdapter.mutate(utilUtf8.fromUtf8(source));
        }
        throw new Error(`Unsupported conversion from ${typeof source} to Uint8ArrayBlobAdapter.`);
      }
      static mutate(source) {
        Object.setPrototypeOf(source, _Uint8ArrayBlobAdapter.prototype);
        return source;
      }
      transformToString(encoding = "utf-8") {
        if (encoding === "base64") {
          return utilBase64.toBase64(this);
        }
        return utilUtf8.toUtf8(this);
      }
    };
    exports2.isBlob = streamTypeCheck.isBlob;
    exports2.isReadableStream = streamTypeCheck.isReadableStream;
    exports2.Uint8ArrayBlobAdapter = Uint8ArrayBlobAdapter8;
    Object.prototype.hasOwnProperty.call(ChecksumStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: ChecksumStream5["__proto__"]
    });
    Object.keys(ChecksumStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = ChecksumStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(createChecksumStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: createChecksumStream5["__proto__"]
    });
    Object.keys(createChecksumStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = createChecksumStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(createBufferedReadable3, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: createBufferedReadable3["__proto__"]
    });
    Object.keys(createBufferedReadable3).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = createBufferedReadable3[k32];
    });
    Object.prototype.hasOwnProperty.call(getAwsChunkedEncodingStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: getAwsChunkedEncodingStream5["__proto__"]
    });
    Object.keys(getAwsChunkedEncodingStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = getAwsChunkedEncodingStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(headStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: headStream5["__proto__"]
    });
    Object.keys(headStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = headStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(sdkStreamMixin12, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: sdkStreamMixin12["__proto__"]
    });
    Object.keys(sdkStreamMixin12).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = sdkStreamMixin12[k32];
    });
    Object.prototype.hasOwnProperty.call(splitStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: splitStream5["__proto__"]
    });
    Object.keys(splitStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = splitStream5[k32];
    });
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/protocols/collect-stream-body.js
var import_util_stream, collectBody;
var init_collect_stream_body = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/protocols/collect-stream-body.js"() {
    import_util_stream = __toESM(require_dist_cjs16());
    collectBody = /* @__PURE__ */ __name(async (streamBody = new Uint8Array(), context) => {
      if (streamBody instanceof Uint8Array) {
        return import_util_stream.Uint8ArrayBlobAdapter.mutate(streamBody);
      }
      if (!streamBody) {
        return import_util_stream.Uint8ArrayBlobAdapter.mutate(new Uint8Array());
      }
      const fromContext = context.streamCollector(streamBody);
      return import_util_stream.Uint8ArrayBlobAdapter.mutate(await fromContext);
    }, "collectBody");
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/protocols/extended-encode-uri-component.js
function extendedEncodeURIComponent(str) {
  return encodeURIComponent(str).replace(/[!'()*]/g, function(c32) {
    return "%" + c32.charCodeAt(0).toString(16).toUpperCase();
  });
}
var init_extended_encode_uri_component = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/protocols/extended-encode-uri-component.js"() {
    __name(extendedEncodeURIComponent, "extendedEncodeURIComponent");
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/schema/deref.js
var deref;
var init_deref = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/schema/deref.js"() {
    deref = /* @__PURE__ */ __name((schemaRef) => {
      if (typeof schemaRef === "function") {
        return schemaRef();
      }
      return schemaRef;
    }, "deref");
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/schema/schemas/operation.js
var operation;
var init_operation = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/schema/schemas/operation.js"() {
    operation = /* @__PURE__ */ __name((namespace, name, traits, input, output) => ({
      name,
      namespace,
      traits,
      input,
      output
    }), "operation");
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/schema/middleware/schemaDeserializationMiddleware.js
var import_protocol_http2, import_util_middleware3, schemaDeserializationMiddleware, findHeader;
var init_schemaDeserializationMiddleware = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/schema/middleware/schemaDeserializationMiddleware.js"() {
    import_protocol_http2 = __toESM(require_dist_cjs2());
    import_util_middleware3 = __toESM(require_dist_cjs6());
    init_operation();
    schemaDeserializationMiddleware = /* @__PURE__ */ __name((config2) => (next, context) => async (args) => {
      const { response } = await next(args);
      const { operationSchema } = (0, import_util_middleware3.getSmithyContext)(context);
      const [, ns, n10, t, i32, o10] = operationSchema ?? [];
      try {
        const parsed = await config2.protocol.deserializeResponse(operation(ns, n10, t, i32, o10), {
          ...config2,
          ...context
        }, response);
        return {
          response,
          output: parsed
        };
      } catch (error4) {
        Object.defineProperty(error4, "$response", {
          value: response,
          enumerable: false,
          writable: false,
          configurable: false
        });
        if (!("$metadata" in error4)) {
          const hint = `Deserialization error: to see the raw response, inspect the hidden field {error}.$response on this object.`;
          try {
            error4.message += "\n  " + hint;
          } catch (e32) {
            if (!context.logger || context.logger?.constructor?.name === "NoOpLogger") {
              console.warn(hint);
            } else {
              context.logger?.warn?.(hint);
            }
          }
          if (typeof error4.$responseBodyText !== "undefined") {
            if (error4.$response) {
              error4.$response.body = error4.$responseBodyText;
            }
          }
          try {
            if (import_protocol_http2.HttpResponse.isInstance(response)) {
              const { headers = {} } = response;
              const headerEntries = Object.entries(headers);
              error4.$metadata = {
                httpStatusCode: response.statusCode,
                requestId: findHeader(/^x-[\w-]+-request-?id$/, headerEntries),
                extendedRequestId: findHeader(/^x-[\w-]+-id-2$/, headerEntries),
                cfId: findHeader(/^x-[\w-]+-cf-id$/, headerEntries)
              };
            }
          } catch (e32) {
          }
        }
        throw error4;
      }
    }, "schemaDeserializationMiddleware");
    findHeader = /* @__PURE__ */ __name((pattern, headers) => {
      return (headers.find(([k32]) => {
        return k32.match(pattern);
      }) || [void 0, void 0])[1];
    }, "findHeader");
  }
});

// ../../node_modules/@smithy/querystring-parser/dist-cjs/index.js
var require_dist_cjs17 = __commonJS({
  "../../node_modules/@smithy/querystring-parser/dist-cjs/index.js"(exports2) {
    "use strict";
    function parseQueryString6(querystring) {
      const query = {};
      querystring = querystring.replace(/^\?/, "");
      if (querystring) {
        for (const pair of querystring.split("&")) {
          let [key, value = null] = pair.split("=");
          key = decodeURIComponent(key);
          if (value) {
            value = decodeURIComponent(value);
          }
          if (!(key in query)) {
            query[key] = value;
          } else if (Array.isArray(query[key])) {
            query[key].push(value);
          } else {
            query[key] = [query[key], value];
          }
        }
      }
      return query;
    }
    __name(parseQueryString6, "parseQueryString");
    exports2.parseQueryString = parseQueryString6;
  }
});

// ../../node_modules/@smithy/url-parser/dist-cjs/index.js
var require_dist_cjs18 = __commonJS({
  "../../node_modules/@smithy/url-parser/dist-cjs/index.js"(exports2) {
    "use strict";
    var querystringParser = require_dist_cjs17();
    var parseUrl34 = /* @__PURE__ */ __name((url) => {
      if (typeof url === "string") {
        return parseUrl34(new URL(url));
      }
      const { hostname, pathname, port, protocol, search } = url;
      let query;
      if (search) {
        query = querystringParser.parseQueryString(search);
      }
      return {
        hostname,
        port: port ? parseInt(port) : void 0,
        protocol,
        path: pathname,
        query
      };
    }, "parseUrl");
    exports2.parseUrl = parseUrl34;
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/endpoints/toEndpointV1.js
var import_url_parser, toEndpointV1;
var init_toEndpointV1 = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/endpoints/toEndpointV1.js"() {
    import_url_parser = __toESM(require_dist_cjs18());
    toEndpointV1 = /* @__PURE__ */ __name((endpoint) => {
      if (typeof endpoint === "object") {
        if ("url" in endpoint) {
          const v1Endpoint = (0, import_url_parser.parseUrl)(endpoint.url);
          if (endpoint.headers) {
            v1Endpoint.headers = {};
            for (const name in endpoint.headers) {
              v1Endpoint.headers[name.toLowerCase()] = endpoint.headers[name].join(", ");
            }
          }
          return v1Endpoint;
        }
        return endpoint;
      }
      return (0, import_url_parser.parseUrl)(endpoint);
    }, "toEndpointV1");
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/endpoints/index.js
var endpoints_exports = {};
__export(endpoints_exports, {
  toEndpointV1: () => toEndpointV1
});
var init_endpoints = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/endpoints/index.js"() {
    init_toEndpointV1();
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/schema/middleware/schemaSerializationMiddleware.js
var import_util_middleware4, schemaSerializationMiddleware;
var init_schemaSerializationMiddleware = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/schema/middleware/schemaSerializationMiddleware.js"() {
    init_endpoints();
    import_util_middleware4 = __toESM(require_dist_cjs6());
    init_operation();
    schemaSerializationMiddleware = /* @__PURE__ */ __name((config2) => (next, context) => async (args) => {
      const { operationSchema } = (0, import_util_middleware4.getSmithyContext)(context);
      const [, ns, n10, t, i32, o10] = operationSchema ?? [];
      const endpoint = context.endpointV2 ? async () => toEndpointV1(context.endpointV2) : config2.endpoint;
      const request4 = await config2.protocol.serializeRequest(operation(ns, n10, t, i32, o10), args.input, {
        ...config2,
        ...context,
        endpoint
      });
      return next({
        ...args,
        request: request4
      });
    }, "schemaSerializationMiddleware");
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/schema/middleware/getSchemaSerdePlugin.js
function getSchemaSerdePlugin(config2) {
  return {
    applyToStack: /* @__PURE__ */ __name((commandStack) => {
      commandStack.add(schemaSerializationMiddleware(config2), serializerMiddlewareOption);
      commandStack.add(schemaDeserializationMiddleware(config2), deserializerMiddlewareOption);
      config2.protocol.setSerdeContext(config2);
    }, "applyToStack")
  };
}
var deserializerMiddlewareOption, serializerMiddlewareOption;
var init_getSchemaSerdePlugin = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/schema/middleware/getSchemaSerdePlugin.js"() {
    init_schemaDeserializationMiddleware();
    init_schemaSerializationMiddleware();
    deserializerMiddlewareOption = {
      name: "deserializerMiddleware",
      step: "deserialize",
      tags: ["DESERIALIZER"],
      override: true
    };
    serializerMiddlewareOption = {
      name: "serializerMiddleware",
      step: "serialize",
      tags: ["SERIALIZER"],
      override: true
    };
    __name(getSchemaSerdePlugin, "getSchemaSerdePlugin");
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/schema/schemas/Schema.js
var Schema;
var init_Schema = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/schema/schemas/Schema.js"() {
    Schema = class {
      static {
        __name(this, "Schema");
      }
      name;
      namespace;
      traits;
      static assign(instance, values) {
        const schema = Object.assign(instance, values);
        return schema;
      }
      static [Symbol.hasInstance](lhs) {
        const isPrototype = this.prototype.isPrototypeOf(lhs);
        if (!isPrototype && typeof lhs === "object" && lhs !== null) {
          const list3 = lhs;
          return list3.symbol === this.symbol;
        }
        return isPrototype;
      }
      getName() {
        return this.namespace + "#" + this.name;
      }
    };
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/schema/schemas/ListSchema.js
var ListSchema, list;
var init_ListSchema = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/schema/schemas/ListSchema.js"() {
    init_Schema();
    ListSchema = class _ListSchema extends Schema {
      static {
        __name(this, "ListSchema");
      }
      static symbol = /* @__PURE__ */ Symbol.for("@smithy/lis");
      name;
      traits;
      valueSchema;
      symbol = _ListSchema.symbol;
    };
    list = /* @__PURE__ */ __name((namespace, name, traits, valueSchema) => Schema.assign(new ListSchema(), {
      name,
      namespace,
      traits,
      valueSchema
    }), "list");
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/schema/schemas/MapSchema.js
var MapSchema, map;
var init_MapSchema = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/schema/schemas/MapSchema.js"() {
    init_Schema();
    MapSchema = class _MapSchema extends Schema {
      static {
        __name(this, "MapSchema");
      }
      static symbol = /* @__PURE__ */ Symbol.for("@smithy/map");
      name;
      traits;
      keySchema;
      valueSchema;
      symbol = _MapSchema.symbol;
    };
    map = /* @__PURE__ */ __name((namespace, name, traits, keySchema, valueSchema) => Schema.assign(new MapSchema(), {
      name,
      namespace,
      traits,
      keySchema,
      valueSchema
    }), "map");
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/schema/schemas/OperationSchema.js
var OperationSchema, op;
var init_OperationSchema = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/schema/schemas/OperationSchema.js"() {
    init_Schema();
    OperationSchema = class _OperationSchema extends Schema {
      static {
        __name(this, "OperationSchema");
      }
      static symbol = /* @__PURE__ */ Symbol.for("@smithy/ope");
      name;
      traits;
      input;
      output;
      symbol = _OperationSchema.symbol;
    };
    op = /* @__PURE__ */ __name((namespace, name, traits, input, output) => Schema.assign(new OperationSchema(), {
      name,
      namespace,
      traits,
      input,
      output
    }), "op");
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/schema/schemas/StructureSchema.js
var StructureSchema, struct;
var init_StructureSchema = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/schema/schemas/StructureSchema.js"() {
    init_Schema();
    StructureSchema = class _StructureSchema extends Schema {
      static {
        __name(this, "StructureSchema");
      }
      static symbol = /* @__PURE__ */ Symbol.for("@smithy/str");
      name;
      traits;
      memberNames;
      memberList;
      symbol = _StructureSchema.symbol;
    };
    struct = /* @__PURE__ */ __name((namespace, name, traits, memberNames, memberList) => Schema.assign(new StructureSchema(), {
      name,
      namespace,
      traits,
      memberNames,
      memberList
    }), "struct");
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/schema/schemas/ErrorSchema.js
var ErrorSchema, error;
var init_ErrorSchema = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/schema/schemas/ErrorSchema.js"() {
    init_Schema();
    init_StructureSchema();
    ErrorSchema = class _ErrorSchema extends StructureSchema {
      static {
        __name(this, "ErrorSchema");
      }
      static symbol = /* @__PURE__ */ Symbol.for("@smithy/err");
      ctor;
      symbol = _ErrorSchema.symbol;
    };
    error = /* @__PURE__ */ __name((namespace, name, traits, memberNames, memberList, ctor) => Schema.assign(new ErrorSchema(), {
      name,
      namespace,
      traits,
      memberNames,
      memberList,
      ctor: null
    }), "error");
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/schema/schemas/translateTraits.js
function translateTraits(indicator) {
  if (typeof indicator === "object") {
    return indicator;
  }
  indicator = indicator | 0;
  if (traitsCache[indicator]) {
    return traitsCache[indicator];
  }
  const traits = {};
  let i32 = 0;
  for (const trait of [
    "httpLabel",
    "idempotent",
    "idempotencyToken",
    "sensitive",
    "httpPayload",
    "httpResponseCode",
    "httpQueryParams"
  ]) {
    if ((indicator >> i32++ & 1) === 1) {
      traits[trait] = 1;
    }
  }
  return traitsCache[indicator] = traits;
}
var traitsCache;
var init_translateTraits = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/schema/schemas/translateTraits.js"() {
    traitsCache = [];
    __name(translateTraits, "translateTraits");
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/schema/schemas/NormalizedSchema.js
function member(memberSchema, memberName) {
  if (memberSchema instanceof NormalizedSchema) {
    return Object.assign(memberSchema, {
      memberName,
      _isMemberSchema: true
    });
  }
  const internalCtorAccess = NormalizedSchema;
  return new internalCtorAccess(memberSchema, memberName);
}
var anno, simpleSchemaCacheN, simpleSchemaCacheS, NormalizedSchema, isMemberSchema, isStaticSchema;
var init_NormalizedSchema = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/schema/schemas/NormalizedSchema.js"() {
    init_deref();
    init_translateTraits();
    anno = {
      it: /* @__PURE__ */ Symbol.for("@smithy/nor-struct-it"),
      ns: /* @__PURE__ */ Symbol.for("@smithy/ns")
    };
    simpleSchemaCacheN = [];
    simpleSchemaCacheS = {};
    NormalizedSchema = class _NormalizedSchema {
      static {
        __name(this, "NormalizedSchema");
      }
      ref;
      memberName;
      static symbol = /* @__PURE__ */ Symbol.for("@smithy/nor");
      symbol = _NormalizedSchema.symbol;
      name;
      schema;
      _isMemberSchema;
      traits;
      memberTraits;
      normalizedTraits;
      constructor(ref, memberName) {
        this.ref = ref;
        this.memberName = memberName;
        const traitStack = [];
        let _ref = ref;
        let schema = ref;
        this._isMemberSchema = false;
        while (isMemberSchema(_ref)) {
          traitStack.push(_ref[1]);
          _ref = _ref[0];
          schema = deref(_ref);
          this._isMemberSchema = true;
        }
        if (traitStack.length > 0) {
          this.memberTraits = {};
          for (let i32 = traitStack.length - 1; i32 >= 0; --i32) {
            const traitSet = traitStack[i32];
            Object.assign(this.memberTraits, translateTraits(traitSet));
          }
        } else {
          this.memberTraits = 0;
        }
        if (schema instanceof _NormalizedSchema) {
          const computedMemberTraits = this.memberTraits;
          Object.assign(this, schema);
          this.memberTraits = Object.assign({}, computedMemberTraits, schema.getMemberTraits(), this.getMemberTraits());
          this.normalizedTraits = void 0;
          this.memberName = memberName ?? schema.memberName;
          return;
        }
        this.schema = deref(schema);
        if (isStaticSchema(this.schema)) {
          this.name = `${this.schema[1]}#${this.schema[2]}`;
          this.traits = this.schema[3];
        } else {
          this.name = this.memberName ?? String(schema);
          this.traits = 0;
        }
        if (this._isMemberSchema && !memberName) {
          throw new Error(`@smithy/core/schema - NormalizedSchema member init ${this.getName(true)} missing member name.`);
        }
      }
      static [Symbol.hasInstance](lhs) {
        const isPrototype = this.prototype.isPrototypeOf(lhs);
        if (!isPrototype && typeof lhs === "object" && lhs !== null) {
          const ns = lhs;
          return ns.symbol === this.symbol;
        }
        return isPrototype;
      }
      static of(ref) {
        const keyAble = typeof ref === "function" || typeof ref === "object" && ref !== null;
        if (typeof ref === "number") {
          if (simpleSchemaCacheN[ref]) {
            return simpleSchemaCacheN[ref];
          }
        } else if (typeof ref === "string") {
          if (simpleSchemaCacheS[ref]) {
            return simpleSchemaCacheS[ref];
          }
        } else if (keyAble) {
          if (ref[anno.ns]) {
            return ref[anno.ns];
          }
        }
        const sc = deref(ref);
        if (sc instanceof _NormalizedSchema) {
          return sc;
        }
        if (isMemberSchema(sc)) {
          const [ns2, traits] = sc;
          if (ns2 instanceof _NormalizedSchema) {
            Object.assign(ns2.getMergedTraits(), translateTraits(traits));
            return ns2;
          }
          throw new Error(`@smithy/core/schema - may not init unwrapped member schema=${JSON.stringify(ref, null, 2)}.`);
        }
        const ns = new _NormalizedSchema(sc);
        if (keyAble) {
          return ref[anno.ns] = ns;
        }
        if (typeof sc === "string") {
          return simpleSchemaCacheS[sc] = ns;
        }
        if (typeof sc === "number") {
          return simpleSchemaCacheN[sc] = ns;
        }
        return ns;
      }
      getSchema() {
        const sc = this.schema;
        if (Array.isArray(sc) && sc[0] === 0) {
          return sc[4];
        }
        return sc;
      }
      getName(withNamespace = false) {
        const { name } = this;
        const short = !withNamespace && name && name.includes("#");
        return short ? name.split("#")[1] : name || void 0;
      }
      getMemberName() {
        return this.memberName;
      }
      isMemberSchema() {
        return this._isMemberSchema;
      }
      isListSchema() {
        const sc = this.getSchema();
        return typeof sc === "number" ? sc >= 64 && sc < 128 : sc[0] === 1;
      }
      isMapSchema() {
        const sc = this.getSchema();
        return typeof sc === "number" ? sc >= 128 && sc <= 255 : sc[0] === 2;
      }
      isStructSchema() {
        const sc = this.getSchema();
        if (typeof sc !== "object") {
          return false;
        }
        const id = sc[0];
        return id === 3 || id === -3 || id === 4;
      }
      isUnionSchema() {
        const sc = this.getSchema();
        if (typeof sc !== "object") {
          return false;
        }
        return sc[0] === 4;
      }
      isBlobSchema() {
        const sc = this.getSchema();
        return sc === 21 || sc === 42;
      }
      isTimestampSchema() {
        const sc = this.getSchema();
        return typeof sc === "number" && sc >= 4 && sc <= 7;
      }
      isUnitSchema() {
        return this.getSchema() === "unit";
      }
      isDocumentSchema() {
        return this.getSchema() === 15;
      }
      isStringSchema() {
        return this.getSchema() === 0;
      }
      isBooleanSchema() {
        return this.getSchema() === 2;
      }
      isNumericSchema() {
        return this.getSchema() === 1;
      }
      isBigIntegerSchema() {
        return this.getSchema() === 17;
      }
      isBigDecimalSchema() {
        return this.getSchema() === 19;
      }
      isStreaming() {
        const { streaming } = this.getMergedTraits();
        return !!streaming || this.getSchema() === 42;
      }
      isIdempotencyToken() {
        return !!this.getMergedTraits().idempotencyToken;
      }
      getMergedTraits() {
        return this.normalizedTraits ?? (this.normalizedTraits = {
          ...this.getOwnTraits(),
          ...this.getMemberTraits()
        });
      }
      getMemberTraits() {
        return translateTraits(this.memberTraits);
      }
      getOwnTraits() {
        return translateTraits(this.traits);
      }
      getKeySchema() {
        const [isDoc, isMap] = [this.isDocumentSchema(), this.isMapSchema()];
        if (!isDoc && !isMap) {
          throw new Error(`@smithy/core/schema - cannot get key for non-map: ${this.getName(true)}`);
        }
        const schema = this.getSchema();
        const memberSchema = isDoc ? 15 : schema[4] ?? 0;
        return member([memberSchema, 0], "key");
      }
      getValueSchema() {
        const sc = this.getSchema();
        const [isDoc, isMap, isList] = [this.isDocumentSchema(), this.isMapSchema(), this.isListSchema()];
        const memberSchema = typeof sc === "number" ? 63 & sc : sc && typeof sc === "object" && (isMap || isList) ? sc[3 + sc[0]] : isDoc ? 15 : void 0;
        if (memberSchema != null) {
          return member([memberSchema, 0], isMap ? "value" : "member");
        }
        throw new Error(`@smithy/core/schema - ${this.getName(true)} has no value member.`);
      }
      getMemberSchema(memberName) {
        const struct3 = this.getSchema();
        if (this.isStructSchema() && struct3[4].includes(memberName)) {
          const i32 = struct3[4].indexOf(memberName);
          const memberSchema = struct3[5][i32];
          return member(isMemberSchema(memberSchema) ? memberSchema : [memberSchema, 0], memberName);
        }
        if (this.isDocumentSchema()) {
          return member([15, 0], memberName);
        }
        throw new Error(`@smithy/core/schema - ${this.getName(true)} has no member=${memberName}.`);
      }
      getMemberSchemas() {
        const buffer = {};
        try {
          for (const [k32, v] of this.structIterator()) {
            buffer[k32] = v;
          }
        } catch (ignored) {
        }
        return buffer;
      }
      getEventStreamMember() {
        if (this.isStructSchema()) {
          for (const [memberName, memberSchema] of this.structIterator()) {
            if (memberSchema.isStreaming() && memberSchema.isStructSchema()) {
              return memberName;
            }
          }
        }
        return "";
      }
      *structIterator() {
        if (this.isUnitSchema()) {
          return;
        }
        if (!this.isStructSchema()) {
          throw new Error("@smithy/core/schema - cannot iterate non-struct schema.");
        }
        const struct3 = this.getSchema();
        const z = struct3[4].length;
        let it = struct3[anno.it];
        if (it && z === it.length) {
          yield* it;
          return;
        }
        it = Array(z);
        for (let i32 = 0; i32 < z; ++i32) {
          const k32 = struct3[4][i32];
          const v = member([struct3[5][i32], 0], k32);
          yield it[i32] = [k32, v];
        }
        struct3[anno.it] = it;
      }
    };
    __name(member, "member");
    isMemberSchema = /* @__PURE__ */ __name((sc) => Array.isArray(sc) && sc.length === 2, "isMemberSchema");
    isStaticSchema = /* @__PURE__ */ __name((sc) => Array.isArray(sc) && sc.length >= 5, "isStaticSchema");
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/schema/schemas/SimpleSchema.js
var SimpleSchema, sim, simAdapter;
var init_SimpleSchema = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/schema/schemas/SimpleSchema.js"() {
    init_Schema();
    SimpleSchema = class _SimpleSchema extends Schema {
      static {
        __name(this, "SimpleSchema");
      }
      static symbol = /* @__PURE__ */ Symbol.for("@smithy/sim");
      name;
      schemaRef;
      traits;
      symbol = _SimpleSchema.symbol;
    };
    sim = /* @__PURE__ */ __name((namespace, name, schemaRef, traits) => Schema.assign(new SimpleSchema(), {
      name,
      namespace,
      traits,
      schemaRef
    }), "sim");
    simAdapter = /* @__PURE__ */ __name((namespace, name, traits, schemaRef) => Schema.assign(new SimpleSchema(), {
      name,
      namespace,
      traits,
      schemaRef
    }), "simAdapter");
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/schema/schemas/sentinels.js
var SCHEMA;
var init_sentinels = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/schema/schemas/sentinels.js"() {
    SCHEMA = {
      BLOB: 21,
      STREAMING_BLOB: 42,
      BOOLEAN: 2,
      STRING: 0,
      NUMERIC: 1,
      BIG_INTEGER: 17,
      BIG_DECIMAL: 19,
      DOCUMENT: 15,
      TIMESTAMP_DEFAULT: 4,
      TIMESTAMP_DATE_TIME: 5,
      TIMESTAMP_HTTP_DATE: 6,
      TIMESTAMP_EPOCH_SECONDS: 7,
      LIST_MODIFIER: 64,
      MAP_MODIFIER: 128
    };
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/schema/TypeRegistry.js
var TypeRegistry;
var init_TypeRegistry = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/schema/TypeRegistry.js"() {
    TypeRegistry = class _TypeRegistry {
      static {
        __name(this, "TypeRegistry");
      }
      namespace;
      schemas;
      exceptions;
      static registries = /* @__PURE__ */ new Map();
      constructor(namespace, schemas = /* @__PURE__ */ new Map(), exceptions = /* @__PURE__ */ new Map()) {
        this.namespace = namespace;
        this.schemas = schemas;
        this.exceptions = exceptions;
      }
      static for(namespace) {
        if (!_TypeRegistry.registries.has(namespace)) {
          _TypeRegistry.registries.set(namespace, new _TypeRegistry(namespace));
        }
        return _TypeRegistry.registries.get(namespace);
      }
      copyFrom(other) {
        const { schemas, exceptions } = this;
        for (const [k32, v] of other.schemas) {
          if (!schemas.has(k32)) {
            schemas.set(k32, v);
          }
        }
        for (const [k32, v] of other.exceptions) {
          if (!exceptions.has(k32)) {
            exceptions.set(k32, v);
          }
        }
      }
      register(shapeId, schema) {
        const qualifiedName = this.normalizeShapeId(shapeId);
        for (const r32 of [this, _TypeRegistry.for(qualifiedName.split("#")[0])]) {
          r32.schemas.set(qualifiedName, schema);
        }
      }
      getSchema(shapeId) {
        const id = this.normalizeShapeId(shapeId);
        if (!this.schemas.has(id)) {
          throw new Error(`@smithy/core/schema - schema not found for ${id}`);
        }
        return this.schemas.get(id);
      }
      registerError(es, ctor) {
        const $error = es;
        const ns = $error[1];
        for (const r32 of [this, _TypeRegistry.for(ns)]) {
          r32.schemas.set(ns + "#" + $error[2], $error);
          r32.exceptions.set($error, ctor);
        }
      }
      getErrorCtor(es) {
        const $error = es;
        if (this.exceptions.has($error)) {
          return this.exceptions.get($error);
        }
        const registry = _TypeRegistry.for($error[1]);
        return registry.exceptions.get($error);
      }
      getBaseException() {
        for (const exceptionKey of this.exceptions.keys()) {
          if (Array.isArray(exceptionKey)) {
            const [, ns, name] = exceptionKey;
            const id = ns + "#" + name;
            if (id.startsWith("smithy.ts.sdk.synthetic.") && id.endsWith("ServiceException")) {
              return exceptionKey;
            }
          }
        }
        return void 0;
      }
      find(predicate) {
        for (const schema of this.schemas.values()) {
          if (predicate(schema)) {
            return schema;
          }
        }
        return void 0;
      }
      clear() {
        this.schemas.clear();
        this.exceptions.clear();
      }
      normalizeShapeId(shapeId) {
        if (shapeId.includes("#")) {
          return shapeId;
        }
        return this.namespace + "#" + shapeId;
      }
    };
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/schema/index.js
var schema_exports = {};
__export(schema_exports, {
  ErrorSchema: () => ErrorSchema,
  ListSchema: () => ListSchema,
  MapSchema: () => MapSchema,
  NormalizedSchema: () => NormalizedSchema,
  OperationSchema: () => OperationSchema,
  SCHEMA: () => SCHEMA,
  Schema: () => Schema,
  SimpleSchema: () => SimpleSchema,
  StructureSchema: () => StructureSchema,
  TypeRegistry: () => TypeRegistry,
  deref: () => deref,
  deserializerMiddlewareOption: () => deserializerMiddlewareOption,
  error: () => error,
  getSchemaSerdePlugin: () => getSchemaSerdePlugin,
  isStaticSchema: () => isStaticSchema,
  list: () => list,
  map: () => map,
  op: () => op,
  operation: () => operation,
  serializerMiddlewareOption: () => serializerMiddlewareOption,
  sim: () => sim,
  simAdapter: () => simAdapter,
  simpleSchemaCacheN: () => simpleSchemaCacheN,
  simpleSchemaCacheS: () => simpleSchemaCacheS,
  struct: () => struct,
  traitsCache: () => traitsCache,
  translateTraits: () => translateTraits
});
var init_schema4 = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/schema/index.js"() {
    init_deref();
    init_getSchemaSerdePlugin();
    init_ListSchema();
    init_MapSchema();
    init_OperationSchema();
    init_operation();
    init_ErrorSchema();
    init_NormalizedSchema();
    init_Schema();
    init_SimpleSchema();
    init_StructureSchema();
    init_sentinels();
    init_translateTraits();
    init_TypeRegistry();
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/serde/copyDocumentWithTransform.js
var copyDocumentWithTransform;
var init_copyDocumentWithTransform = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/serde/copyDocumentWithTransform.js"() {
    copyDocumentWithTransform = /* @__PURE__ */ __name((source, schemaRef, transform = (_) => _) => source, "copyDocumentWithTransform");
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/serde/parse-utils.js
var parseBoolean, expectBoolean, expectNumber, MAX_FLOAT, expectFloat32, expectLong, expectInt, expectInt32, expectShort, expectByte, expectSizedInt, castInt, expectNonNull, expectObject, expectString, expectUnion, strictParseDouble, strictParseFloat, strictParseFloat32, NUMBER_REGEX, parseNumber, limitedParseDouble, handleFloat, limitedParseFloat, limitedParseFloat32, parseFloatString, strictParseLong, strictParseInt, strictParseInt32, strictParseShort, strictParseByte, stackTraceWarning, logger;
var init_parse_utils = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/serde/parse-utils.js"() {
    parseBoolean = /* @__PURE__ */ __name((value) => {
      switch (value) {
        case "true":
          return true;
        case "false":
          return false;
        default:
          throw new Error(`Unable to parse boolean value "${value}"`);
      }
    }, "parseBoolean");
    expectBoolean = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      if (typeof value === "number") {
        if (value === 0 || value === 1) {
          logger.warn(stackTraceWarning(`Expected boolean, got ${typeof value}: ${value}`));
        }
        if (value === 0) {
          return false;
        }
        if (value === 1) {
          return true;
        }
      }
      if (typeof value === "string") {
        const lower = value.toLowerCase();
        if (lower === "false" || lower === "true") {
          logger.warn(stackTraceWarning(`Expected boolean, got ${typeof value}: ${value}`));
        }
        if (lower === "false") {
          return false;
        }
        if (lower === "true") {
          return true;
        }
      }
      if (typeof value === "boolean") {
        return value;
      }
      throw new TypeError(`Expected boolean, got ${typeof value}: ${value}`);
    }, "expectBoolean");
    expectNumber = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      if (typeof value === "string") {
        const parsed = parseFloat(value);
        if (!Number.isNaN(parsed)) {
          if (String(parsed) !== String(value)) {
            logger.warn(stackTraceWarning(`Expected number but observed string: ${value}`));
          }
          return parsed;
        }
      }
      if (typeof value === "number") {
        return value;
      }
      throw new TypeError(`Expected number, got ${typeof value}: ${value}`);
    }, "expectNumber");
    MAX_FLOAT = Math.ceil(2 ** 127 * (2 - 2 ** -23));
    expectFloat32 = /* @__PURE__ */ __name((value) => {
      const expected = expectNumber(value);
      if (expected !== void 0 && !Number.isNaN(expected) && expected !== Infinity && expected !== -Infinity) {
        if (Math.abs(expected) > MAX_FLOAT) {
          throw new TypeError(`Expected 32-bit float, got ${value}`);
        }
      }
      return expected;
    }, "expectFloat32");
    expectLong = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      if (Number.isInteger(value) && !Number.isNaN(value)) {
        return value;
      }
      throw new TypeError(`Expected integer, got ${typeof value}: ${value}`);
    }, "expectLong");
    expectInt = expectLong;
    expectInt32 = /* @__PURE__ */ __name((value) => expectSizedInt(value, 32), "expectInt32");
    expectShort = /* @__PURE__ */ __name((value) => expectSizedInt(value, 16), "expectShort");
    expectByte = /* @__PURE__ */ __name((value) => expectSizedInt(value, 8), "expectByte");
    expectSizedInt = /* @__PURE__ */ __name((value, size) => {
      const expected = expectLong(value);
      if (expected !== void 0 && castInt(expected, size) !== expected) {
        throw new TypeError(`Expected ${size}-bit integer, got ${value}`);
      }
      return expected;
    }, "expectSizedInt");
    castInt = /* @__PURE__ */ __name((value, size) => {
      switch (size) {
        case 32:
          return Int32Array.of(value)[0];
        case 16:
          return Int16Array.of(value)[0];
        case 8:
          return Int8Array.of(value)[0];
      }
    }, "castInt");
    expectNonNull = /* @__PURE__ */ __name((value, location) => {
      if (value === null || value === void 0) {
        if (location) {
          throw new TypeError(`Expected a non-null value for ${location}`);
        }
        throw new TypeError("Expected a non-null value");
      }
      return value;
    }, "expectNonNull");
    expectObject = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      if (typeof value === "object" && !Array.isArray(value)) {
        return value;
      }
      const receivedType = Array.isArray(value) ? "array" : typeof value;
      throw new TypeError(`Expected object, got ${receivedType}: ${value}`);
    }, "expectObject");
    expectString = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      if (typeof value === "string") {
        return value;
      }
      if (["boolean", "number", "bigint"].includes(typeof value)) {
        logger.warn(stackTraceWarning(`Expected string, got ${typeof value}: ${value}`));
        return String(value);
      }
      throw new TypeError(`Expected string, got ${typeof value}: ${value}`);
    }, "expectString");
    expectUnion = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      const asObject = expectObject(value);
      const setKeys = [];
      for (const k32 in asObject) {
        if (asObject[k32] != null) {
          setKeys.push(k32);
        }
      }
      if (setKeys.length === 0) {
        throw new TypeError(`Unions must have exactly one non-null member. None were found.`);
      }
      if (setKeys.length > 1) {
        throw new TypeError(`Unions must have exactly one non-null member. Keys ${setKeys} were not null.`);
      }
      return asObject;
    }, "expectUnion");
    strictParseDouble = /* @__PURE__ */ __name((value) => {
      if (typeof value == "string") {
        return expectNumber(parseNumber(value));
      }
      return expectNumber(value);
    }, "strictParseDouble");
    strictParseFloat = strictParseDouble;
    strictParseFloat32 = /* @__PURE__ */ __name((value) => {
      if (typeof value == "string") {
        return expectFloat32(parseNumber(value));
      }
      return expectFloat32(value);
    }, "strictParseFloat32");
    NUMBER_REGEX = /(-?(?:0|[1-9]\d*)(?:\.\d+)?(?:[eE][+-]?\d+)?)|(-?Infinity)|(NaN)/g;
    parseNumber = /* @__PURE__ */ __name((value) => {
      const matches = value.match(NUMBER_REGEX);
      if (matches === null || matches[0].length !== value.length) {
        throw new TypeError(`Expected real number, got implicit NaN`);
      }
      return parseFloat(value);
    }, "parseNumber");
    limitedParseDouble = /* @__PURE__ */ __name((value) => {
      if (typeof value == "string") {
        return parseFloatString(value);
      }
      return expectNumber(value);
    }, "limitedParseDouble");
    handleFloat = limitedParseDouble;
    limitedParseFloat = limitedParseDouble;
    limitedParseFloat32 = /* @__PURE__ */ __name((value) => {
      if (typeof value == "string") {
        return parseFloatString(value);
      }
      return expectFloat32(value);
    }, "limitedParseFloat32");
    parseFloatString = /* @__PURE__ */ __name((value) => {
      switch (value) {
        case "NaN":
          return NaN;
        case "Infinity":
          return Infinity;
        case "-Infinity":
          return -Infinity;
        default:
          throw new Error(`Unable to parse float value: ${value}`);
      }
    }, "parseFloatString");
    strictParseLong = /* @__PURE__ */ __name((value) => {
      if (typeof value === "string") {
        return expectLong(parseNumber(value));
      }
      return expectLong(value);
    }, "strictParseLong");
    strictParseInt = strictParseLong;
    strictParseInt32 = /* @__PURE__ */ __name((value) => {
      if (typeof value === "string") {
        return expectInt32(parseNumber(value));
      }
      return expectInt32(value);
    }, "strictParseInt32");
    strictParseShort = /* @__PURE__ */ __name((value) => {
      if (typeof value === "string") {
        return expectShort(parseNumber(value));
      }
      return expectShort(value);
    }, "strictParseShort");
    strictParseByte = /* @__PURE__ */ __name((value) => {
      if (typeof value === "string") {
        return expectByte(parseNumber(value));
      }
      return expectByte(value);
    }, "strictParseByte");
    stackTraceWarning = /* @__PURE__ */ __name((message2) => {
      return String(new TypeError(message2).stack || message2).split("\n").slice(0, 5).filter((s) => !s.includes("stackTraceWarning")).join("\n");
    }, "stackTraceWarning");
    logger = {
      warn: console.warn
    };
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/serde/date-utils.js
function dateToUtcString(date7) {
  const year7 = date7.getUTCFullYear();
  const month = date7.getUTCMonth();
  const dayOfWeek = date7.getUTCDay();
  const dayOfMonthInt = date7.getUTCDate();
  const hoursInt = date7.getUTCHours();
  const minutesInt = date7.getUTCMinutes();
  const secondsInt = date7.getUTCSeconds();
  const dayOfMonthString = dayOfMonthInt < 10 ? `0${dayOfMonthInt}` : `${dayOfMonthInt}`;
  const hoursString = hoursInt < 10 ? `0${hoursInt}` : `${hoursInt}`;
  const minutesString = minutesInt < 10 ? `0${minutesInt}` : `${minutesInt}`;
  const secondsString = secondsInt < 10 ? `0${secondsInt}` : `${secondsInt}`;
  return `${DAYS[dayOfWeek]}, ${dayOfMonthString} ${MONTHS[month]} ${year7} ${hoursString}:${minutesString}:${secondsString} GMT`;
}
var DAYS, MONTHS, RFC3339, parseRfc3339DateTime, RFC3339_WITH_OFFSET, parseRfc3339DateTimeWithOffset, IMF_FIXDATE, RFC_850_DATE, ASC_TIME, parseRfc7231DateTime, parseEpochTimestamp, buildDate, parseTwoDigitYear, FIFTY_YEARS_IN_MILLIS, adjustRfc850Year, parseMonthByShortName, DAYS_IN_MONTH, validateDayOfMonth, isLeapYear, parseDateValue, parseMilliseconds, parseOffsetToMilliseconds, stripLeadingZeroes;
var init_date_utils = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/serde/date-utils.js"() {
    init_parse_utils();
    DAYS = ["Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"];
    MONTHS = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"];
    __name(dateToUtcString, "dateToUtcString");
    RFC3339 = new RegExp(/^(\d{4})-(\d{2})-(\d{2})[tT](\d{2}):(\d{2}):(\d{2})(?:\.(\d+))?[zZ]$/);
    parseRfc3339DateTime = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      if (typeof value !== "string") {
        throw new TypeError("RFC-3339 date-times must be expressed as strings");
      }
      const match = RFC3339.exec(value);
      if (!match) {
        throw new TypeError("Invalid RFC-3339 date-time value");
      }
      const [_, yearStr, monthStr, dayStr, hours, minutes, seconds, fractionalMilliseconds] = match;
      const year7 = strictParseShort(stripLeadingZeroes(yearStr));
      const month = parseDateValue(monthStr, "month", 1, 12);
      const day = parseDateValue(dayStr, "day", 1, 31);
      return buildDate(year7, month, day, { hours, minutes, seconds, fractionalMilliseconds });
    }, "parseRfc3339DateTime");
    RFC3339_WITH_OFFSET = new RegExp(/^(\d{4})-(\d{2})-(\d{2})[tT](\d{2}):(\d{2}):(\d{2})(?:\.(\d+))?(([-+]\d{2}\:\d{2})|[zZ])$/);
    parseRfc3339DateTimeWithOffset = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      if (typeof value !== "string") {
        throw new TypeError("RFC-3339 date-times must be expressed as strings");
      }
      const match = RFC3339_WITH_OFFSET.exec(value);
      if (!match) {
        throw new TypeError("Invalid RFC-3339 date-time value");
      }
      const [_, yearStr, monthStr, dayStr, hours, minutes, seconds, fractionalMilliseconds, offsetStr] = match;
      const year7 = strictParseShort(stripLeadingZeroes(yearStr));
      const month = parseDateValue(monthStr, "month", 1, 12);
      const day = parseDateValue(dayStr, "day", 1, 31);
      const date7 = buildDate(year7, month, day, { hours, minutes, seconds, fractionalMilliseconds });
      if (offsetStr.toUpperCase() != "Z") {
        date7.setTime(date7.getTime() - parseOffsetToMilliseconds(offsetStr));
      }
      return date7;
    }, "parseRfc3339DateTimeWithOffset");
    IMF_FIXDATE = new RegExp(/^(?:Mon|Tue|Wed|Thu|Fri|Sat|Sun), (\d{2}) (Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec) (\d{4}) (\d{1,2}):(\d{2}):(\d{2})(?:\.(\d+))? GMT$/);
    RFC_850_DATE = new RegExp(/^(?:Monday|Tuesday|Wednesday|Thursday|Friday|Saturday|Sunday), (\d{2})-(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)-(\d{2}) (\d{1,2}):(\d{2}):(\d{2})(?:\.(\d+))? GMT$/);
    ASC_TIME = new RegExp(/^(?:Mon|Tue|Wed|Thu|Fri|Sat|Sun) (Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec) ( [1-9]|\d{2}) (\d{1,2}):(\d{2}):(\d{2})(?:\.(\d+))? (\d{4})$/);
    parseRfc7231DateTime = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      if (typeof value !== "string") {
        throw new TypeError("RFC-7231 date-times must be expressed as strings");
      }
      let match = IMF_FIXDATE.exec(value);
      if (match) {
        const [_, dayStr, monthStr, yearStr, hours, minutes, seconds, fractionalMilliseconds] = match;
        return buildDate(strictParseShort(stripLeadingZeroes(yearStr)), parseMonthByShortName(monthStr), parseDateValue(dayStr, "day", 1, 31), { hours, minutes, seconds, fractionalMilliseconds });
      }
      match = RFC_850_DATE.exec(value);
      if (match) {
        const [_, dayStr, monthStr, yearStr, hours, minutes, seconds, fractionalMilliseconds] = match;
        return adjustRfc850Year(buildDate(parseTwoDigitYear(yearStr), parseMonthByShortName(monthStr), parseDateValue(dayStr, "day", 1, 31), {
          hours,
          minutes,
          seconds,
          fractionalMilliseconds
        }));
      }
      match = ASC_TIME.exec(value);
      if (match) {
        const [_, monthStr, dayStr, hours, minutes, seconds, fractionalMilliseconds, yearStr] = match;
        return buildDate(strictParseShort(stripLeadingZeroes(yearStr)), parseMonthByShortName(monthStr), parseDateValue(dayStr.trimLeft(), "day", 1, 31), { hours, minutes, seconds, fractionalMilliseconds });
      }
      throw new TypeError("Invalid RFC-7231 date-time value");
    }, "parseRfc7231DateTime");
    parseEpochTimestamp = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      let valueAsDouble;
      if (typeof value === "number") {
        valueAsDouble = value;
      } else if (typeof value === "string") {
        valueAsDouble = strictParseDouble(value);
      } else if (typeof value === "object" && value.tag === 1) {
        valueAsDouble = value.value;
      } else {
        throw new TypeError("Epoch timestamps must be expressed as floating point numbers or their string representation");
      }
      if (Number.isNaN(valueAsDouble) || valueAsDouble === Infinity || valueAsDouble === -Infinity) {
        throw new TypeError("Epoch timestamps must be valid, non-Infinite, non-NaN numerics");
      }
      return new Date(Math.round(valueAsDouble * 1e3));
    }, "parseEpochTimestamp");
    buildDate = /* @__PURE__ */ __name((year7, month, day, time7) => {
      const adjustedMonth = month - 1;
      validateDayOfMonth(year7, adjustedMonth, day);
      return new Date(Date.UTC(year7, adjustedMonth, day, parseDateValue(time7.hours, "hour", 0, 23), parseDateValue(time7.minutes, "minute", 0, 59), parseDateValue(time7.seconds, "seconds", 0, 60), parseMilliseconds(time7.fractionalMilliseconds)));
    }, "buildDate");
    parseTwoDigitYear = /* @__PURE__ */ __name((value) => {
      const thisYear = (/* @__PURE__ */ new Date()).getUTCFullYear();
      const valueInThisCentury = Math.floor(thisYear / 100) * 100 + strictParseShort(stripLeadingZeroes(value));
      if (valueInThisCentury < thisYear) {
        return valueInThisCentury + 100;
      }
      return valueInThisCentury;
    }, "parseTwoDigitYear");
    FIFTY_YEARS_IN_MILLIS = 50 * 365 * 24 * 60 * 60 * 1e3;
    adjustRfc850Year = /* @__PURE__ */ __name((input) => {
      if (input.getTime() - (/* @__PURE__ */ new Date()).getTime() > FIFTY_YEARS_IN_MILLIS) {
        return new Date(Date.UTC(input.getUTCFullYear() - 100, input.getUTCMonth(), input.getUTCDate(), input.getUTCHours(), input.getUTCMinutes(), input.getUTCSeconds(), input.getUTCMilliseconds()));
      }
      return input;
    }, "adjustRfc850Year");
    parseMonthByShortName = /* @__PURE__ */ __name((value) => {
      const monthIdx = MONTHS.indexOf(value);
      if (monthIdx < 0) {
        throw new TypeError(`Invalid month: ${value}`);
      }
      return monthIdx + 1;
    }, "parseMonthByShortName");
    DAYS_IN_MONTH = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];
    validateDayOfMonth = /* @__PURE__ */ __name((year7, month, day) => {
      let maxDays = DAYS_IN_MONTH[month];
      if (month === 1 && isLeapYear(year7)) {
        maxDays = 29;
      }
      if (day > maxDays) {
        throw new TypeError(`Invalid day for ${MONTHS[month]} in ${year7}: ${day}`);
      }
    }, "validateDayOfMonth");
    isLeapYear = /* @__PURE__ */ __name((year7) => {
      return year7 % 4 === 0 && (year7 % 100 !== 0 || year7 % 400 === 0);
    }, "isLeapYear");
    parseDateValue = /* @__PURE__ */ __name((value, type, lower, upper) => {
      const dateVal = strictParseByte(stripLeadingZeroes(value));
      if (dateVal < lower || dateVal > upper) {
        throw new TypeError(`${type} must be between ${lower} and ${upper}, inclusive`);
      }
      return dateVal;
    }, "parseDateValue");
    parseMilliseconds = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return 0;
      }
      return strictParseFloat32("0." + value) * 1e3;
    }, "parseMilliseconds");
    parseOffsetToMilliseconds = /* @__PURE__ */ __name((value) => {
      const directionStr = value[0];
      let direction = 1;
      if (directionStr == "+") {
        direction = 1;
      } else if (directionStr == "-") {
        direction = -1;
      } else {
        throw new TypeError(`Offset direction, ${directionStr}, must be "+" or "-"`);
      }
      const hour = Number(value.substring(1, 3));
      const minute = Number(value.substring(4, 6));
      return direction * (hour * 60 + minute) * 60 * 1e3;
    }, "parseOffsetToMilliseconds");
    stripLeadingZeroes = /* @__PURE__ */ __name((value) => {
      let idx = 0;
      while (idx < value.length - 1 && value.charAt(idx) === "0") {
        idx++;
      }
      if (idx === 0) {
        return value;
      }
      return value.slice(idx);
    }, "stripLeadingZeroes");
  }
});

// ../../node_modules/tslib/tslib.es6.mjs
var tslib_es6_exports = {};
__export(tslib_es6_exports, {
  __addDisposableResource: () => __addDisposableResource,
  __assign: () => __assign,
  __asyncDelegator: () => __asyncDelegator,
  __asyncGenerator: () => __asyncGenerator,
  __asyncValues: () => __asyncValues,
  __await: () => __await,
  __awaiter: () => __awaiter,
  __classPrivateFieldGet: () => __classPrivateFieldGet,
  __classPrivateFieldIn: () => __classPrivateFieldIn,
  __classPrivateFieldSet: () => __classPrivateFieldSet,
  __createBinding: () => __createBinding,
  __decorate: () => __decorate,
  __disposeResources: () => __disposeResources,
  __esDecorate: () => __esDecorate,
  __exportStar: () => __exportStar,
  __extends: () => __extends,
  __generator: () => __generator,
  __importDefault: () => __importDefault,
  __importStar: () => __importStar,
  __makeTemplateObject: () => __makeTemplateObject,
  __metadata: () => __metadata,
  __param: () => __param,
  __propKey: () => __propKey,
  __read: () => __read,
  __rest: () => __rest,
  __rewriteRelativeImportExtension: () => __rewriteRelativeImportExtension,
  __runInitializers: () => __runInitializers,
  __setFunctionName: () => __setFunctionName,
  __spread: () => __spread,
  __spreadArray: () => __spreadArray,
  __spreadArrays: () => __spreadArrays,
  __values: () => __values,
  default: () => tslib_es6_default
});
function __extends(d32, b32) {
  if (typeof b32 !== "function" && b32 !== null)
    throw new TypeError("Class extends value " + String(b32) + " is not a constructor or null");
  extendStatics(d32, b32);
  function __() {
    this.constructor = d32;
  }
  __name(__, "__");
  d32.prototype = b32 === null ? Object.create(b32) : (__.prototype = b32.prototype, new __());
}
function __rest(s, e32) {
  var t = {};
  for (var p10 in s) if (Object.prototype.hasOwnProperty.call(s, p10) && e32.indexOf(p10) < 0)
    t[p10] = s[p10];
  if (s != null && typeof Object.getOwnPropertySymbols === "function")
    for (var i32 = 0, p10 = Object.getOwnPropertySymbols(s); i32 < p10.length; i32++) {
      if (e32.indexOf(p10[i32]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p10[i32]))
        t[p10[i32]] = s[p10[i32]];
    }
  return t;
}
function __decorate(decorators, target, key, desc) {
  var c32 = arguments.length, r32 = c32 < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d32;
  if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r32 = Reflect.decorate(decorators, target, key, desc);
  else for (var i32 = decorators.length - 1; i32 >= 0; i32--) if (d32 = decorators[i32]) r32 = (c32 < 3 ? d32(r32) : c32 > 3 ? d32(target, key, r32) : d32(target, key)) || r32;
  return c32 > 3 && r32 && Object.defineProperty(target, key, r32), r32;
}
function __param(paramIndex, decorator) {
  return function(target, key) {
    decorator(target, key, paramIndex);
  };
}
function __esDecorate(ctor, descriptorIn, decorators, contextIn, initializers, extraInitializers) {
  function accept(f32) {
    if (f32 !== void 0 && typeof f32 !== "function") throw new TypeError("Function expected");
    return f32;
  }
  __name(accept, "accept");
  var kind = contextIn.kind, key = kind === "getter" ? "get" : kind === "setter" ? "set" : "value";
  var target = !descriptorIn && ctor ? contextIn["static"] ? ctor : ctor.prototype : null;
  var descriptor = descriptorIn || (target ? Object.getOwnPropertyDescriptor(target, contextIn.name) : {});
  var _, done = false;
  for (var i32 = decorators.length - 1; i32 >= 0; i32--) {
    var context = {};
    for (var p10 in contextIn) context[p10] = p10 === "access" ? {} : contextIn[p10];
    for (var p10 in contextIn.access) context.access[p10] = contextIn.access[p10];
    context.addInitializer = function(f32) {
      if (done) throw new TypeError("Cannot add initializers after decoration has completed");
      extraInitializers.push(accept(f32 || null));
    };
    var result2 = (0, decorators[i32])(kind === "accessor" ? { get: descriptor.get, set: descriptor.set } : descriptor[key], context);
    if (kind === "accessor") {
      if (result2 === void 0) continue;
      if (result2 === null || typeof result2 !== "object") throw new TypeError("Object expected");
      if (_ = accept(result2.get)) descriptor.get = _;
      if (_ = accept(result2.set)) descriptor.set = _;
      if (_ = accept(result2.init)) initializers.unshift(_);
    } else if (_ = accept(result2)) {
      if (kind === "field") initializers.unshift(_);
      else descriptor[key] = _;
    }
  }
  if (target) Object.defineProperty(target, contextIn.name, descriptor);
  done = true;
}
function __runInitializers(thisArg, initializers, value) {
  var useValue = arguments.length > 2;
  for (var i32 = 0; i32 < initializers.length; i32++) {
    value = useValue ? initializers[i32].call(thisArg, value) : initializers[i32].call(thisArg);
  }
  return useValue ? value : void 0;
}
function __propKey(x) {
  return typeof x === "symbol" ? x : "".concat(x);
}
function __setFunctionName(f32, name, prefix) {
  if (typeof name === "symbol") name = name.description ? "[".concat(name.description, "]") : "";
  return Object.defineProperty(f32, "name", { configurable: true, value: prefix ? "".concat(prefix, " ", name) : name });
}
function __metadata(metadataKey, metadataValue) {
  if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(metadataKey, metadataValue);
}
function __awaiter(thisArg, _arguments, P, generator) {
  function adopt(value) {
    return value instanceof P ? value : new P(function(resolve13) {
      resolve13(value);
    });
  }
  __name(adopt, "adopt");
  return new (P || (P = Promise))(function(resolve13, reject) {
    function fulfilled(value) {
      try {
        step(generator.next(value));
      } catch (e32) {
        reject(e32);
      }
    }
    __name(fulfilled, "fulfilled");
    function rejected(value) {
      try {
        step(generator["throw"](value));
      } catch (e32) {
        reject(e32);
      }
    }
    __name(rejected, "rejected");
    function step(result2) {
      result2.done ? resolve13(result2.value) : adopt(result2.value).then(fulfilled, rejected);
    }
    __name(step, "step");
    step((generator = generator.apply(thisArg, _arguments || [])).next());
  });
}
function __generator(thisArg, body) {
  var _ = { label: 0, sent: /* @__PURE__ */ __name(function() {
    if (t[0] & 1) throw t[1];
    return t[1];
  }, "sent"), trys: [], ops: [] }, f32, y, t, g32 = Object.create((typeof Iterator === "function" ? Iterator : Object).prototype);
  return g32.next = verb(0), g32["throw"] = verb(1), g32["return"] = verb(2), typeof Symbol === "function" && (g32[Symbol.iterator] = function() {
    return this;
  }), g32;
  function verb(n10) {
    return function(v) {
      return step([n10, v]);
    };
  }
  __name(verb, "verb");
  function step(op3) {
    if (f32) throw new TypeError("Generator is already executing.");
    while (g32 && (g32 = 0, op3[0] && (_ = 0)), _) try {
      if (f32 = 1, y && (t = op3[0] & 2 ? y["return"] : op3[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op3[1])).done) return t;
      if (y = 0, t) op3 = [op3[0] & 2, t.value];
      switch (op3[0]) {
        case 0:
        case 1:
          t = op3;
          break;
        case 4:
          _.label++;
          return { value: op3[1], done: false };
        case 5:
          _.label++;
          y = op3[1];
          op3 = [0];
          continue;
        case 7:
          op3 = _.ops.pop();
          _.trys.pop();
          continue;
        default:
          if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op3[0] === 6 || op3[0] === 2)) {
            _ = 0;
            continue;
          }
          if (op3[0] === 3 && (!t || op3[1] > t[0] && op3[1] < t[3])) {
            _.label = op3[1];
            break;
          }
          if (op3[0] === 6 && _.label < t[1]) {
            _.label = t[1];
            t = op3;
            break;
          }
          if (t && _.label < t[2]) {
            _.label = t[2];
            _.ops.push(op3);
            break;
          }
          if (t[2]) _.ops.pop();
          _.trys.pop();
          continue;
      }
      op3 = body.call(thisArg, _);
    } catch (e32) {
      op3 = [6, e32];
      y = 0;
    } finally {
      f32 = t = 0;
    }
    if (op3[0] & 5) throw op3[1];
    return { value: op3[0] ? op3[1] : void 0, done: true };
  }
  __name(step, "step");
}
function __exportStar(m20, o10) {
  for (var p10 in m20) if (p10 !== "default" && !Object.prototype.hasOwnProperty.call(o10, p10)) __createBinding(o10, m20, p10);
}
function __values(o10) {
  var s = typeof Symbol === "function" && Symbol.iterator, m20 = s && o10[s], i32 = 0;
  if (m20) return m20.call(o10);
  if (o10 && typeof o10.length === "number") return {
    next: /* @__PURE__ */ __name(function() {
      if (o10 && i32 >= o10.length) o10 = void 0;
      return { value: o10 && o10[i32++], done: !o10 };
    }, "next")
  };
  throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
}
function __read(o10, n10) {
  var m20 = typeof Symbol === "function" && o10[Symbol.iterator];
  if (!m20) return o10;
  var i32 = m20.call(o10), r32, ar = [], e32;
  try {
    while ((n10 === void 0 || n10-- > 0) && !(r32 = i32.next()).done) ar.push(r32.value);
  } catch (error4) {
    e32 = { error: error4 };
  } finally {
    try {
      if (r32 && !r32.done && (m20 = i32["return"])) m20.call(i32);
    } finally {
      if (e32) throw e32.error;
    }
  }
  return ar;
}
function __spread() {
  for (var ar = [], i32 = 0; i32 < arguments.length; i32++)
    ar = ar.concat(__read(arguments[i32]));
  return ar;
}
function __spreadArrays() {
  for (var s = 0, i32 = 0, il = arguments.length; i32 < il; i32++) s += arguments[i32].length;
  for (var r32 = Array(s), k32 = 0, i32 = 0; i32 < il; i32++)
    for (var a32 = arguments[i32], j32 = 0, jl = a32.length; j32 < jl; j32++, k32++)
      r32[k32] = a32[j32];
  return r32;
}
function __spreadArray(to, from, pack) {
  if (pack || arguments.length === 2) for (var i32 = 0, l20 = from.length, ar; i32 < l20; i32++) {
    if (ar || !(i32 in from)) {
      if (!ar) ar = Array.prototype.slice.call(from, 0, i32);
      ar[i32] = from[i32];
    }
  }
  return to.concat(ar || Array.prototype.slice.call(from));
}
function __await(v) {
  return this instanceof __await ? (this.v = v, this) : new __await(v);
}
function __asyncGenerator(thisArg, _arguments, generator) {
  if (!Symbol.asyncIterator) throw new TypeError("Symbol.asyncIterator is not defined.");
  var g32 = generator.apply(thisArg, _arguments || []), i32, q10 = [];
  return i32 = Object.create((typeof AsyncIterator === "function" ? AsyncIterator : Object).prototype), verb("next"), verb("throw"), verb("return", awaitReturn), i32[Symbol.asyncIterator] = function() {
    return this;
  }, i32;
  function awaitReturn(f32) {
    return function(v) {
      return Promise.resolve(v).then(f32, reject);
    };
  }
  __name(awaitReturn, "awaitReturn");
  function verb(n10, f32) {
    if (g32[n10]) {
      i32[n10] = function(v) {
        return new Promise(function(a32, b32) {
          q10.push([n10, v, a32, b32]) > 1 || resume(n10, v);
        });
      };
      if (f32) i32[n10] = f32(i32[n10]);
    }
  }
  __name(verb, "verb");
  function resume(n10, v) {
    try {
      step(g32[n10](v));
    } catch (e32) {
      settle(q10[0][3], e32);
    }
  }
  __name(resume, "resume");
  function step(r32) {
    r32.value instanceof __await ? Promise.resolve(r32.value.v).then(fulfill, reject) : settle(q10[0][2], r32);
  }
  __name(step, "step");
  function fulfill(value) {
    resume("next", value);
  }
  __name(fulfill, "fulfill");
  function reject(value) {
    resume("throw", value);
  }
  __name(reject, "reject");
  function settle(f32, v) {
    if (f32(v), q10.shift(), q10.length) resume(q10[0][0], q10[0][1]);
  }
  __name(settle, "settle");
}
function __asyncDelegator(o10) {
  var i32, p10;
  return i32 = {}, verb("next"), verb("throw", function(e32) {
    throw e32;
  }), verb("return"), i32[Symbol.iterator] = function() {
    return this;
  }, i32;
  function verb(n10, f32) {
    i32[n10] = o10[n10] ? function(v) {
      return (p10 = !p10) ? { value: __await(o10[n10](v)), done: false } : f32 ? f32(v) : v;
    } : f32;
  }
  __name(verb, "verb");
}
function __asyncValues(o10) {
  if (!Symbol.asyncIterator) throw new TypeError("Symbol.asyncIterator is not defined.");
  var m20 = o10[Symbol.asyncIterator], i32;
  return m20 ? m20.call(o10) : (o10 = typeof __values === "function" ? __values(o10) : o10[Symbol.iterator](), i32 = {}, verb("next"), verb("throw"), verb("return"), i32[Symbol.asyncIterator] = function() {
    return this;
  }, i32);
  function verb(n10) {
    i32[n10] = o10[n10] && function(v) {
      return new Promise(function(resolve13, reject) {
        v = o10[n10](v), settle(resolve13, reject, v.done, v.value);
      });
    };
  }
  __name(verb, "verb");
  function settle(resolve13, reject, d32, v) {
    Promise.resolve(v).then(function(v2) {
      resolve13({ value: v2, done: d32 });
    }, reject);
  }
  __name(settle, "settle");
}
function __makeTemplateObject(cooked, raw) {
  if (Object.defineProperty) {
    Object.defineProperty(cooked, "raw", { value: raw });
  } else {
    cooked.raw = raw;
  }
  return cooked;
}
function __importStar(mod) {
  if (mod && mod.__esModule) return mod;
  var result2 = {};
  if (mod != null) {
    for (var k32 = ownKeys(mod), i32 = 0; i32 < k32.length; i32++) if (k32[i32] !== "default") __createBinding(result2, mod, k32[i32]);
  }
  __setModuleDefault(result2, mod);
  return result2;
}
function __importDefault(mod) {
  return mod && mod.__esModule ? mod : { default: mod };
}
function __classPrivateFieldGet(receiver, state13, kind, f32) {
  if (kind === "a" && !f32) throw new TypeError("Private accessor was defined without a getter");
  if (typeof state13 === "function" ? receiver !== state13 || !f32 : !state13.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
  return kind === "m" ? f32 : kind === "a" ? f32.call(receiver) : f32 ? f32.value : state13.get(receiver);
}
function __classPrivateFieldSet(receiver, state13, value, kind, f32) {
  if (kind === "m") throw new TypeError("Private method is not writable");
  if (kind === "a" && !f32) throw new TypeError("Private accessor was defined without a setter");
  if (typeof state13 === "function" ? receiver !== state13 || !f32 : !state13.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
  return kind === "a" ? f32.call(receiver, value) : f32 ? f32.value = value : state13.set(receiver, value), value;
}
function __classPrivateFieldIn(state13, receiver) {
  if (receiver === null || typeof receiver !== "object" && typeof receiver !== "function") throw new TypeError("Cannot use 'in' operator on non-object");
  return typeof state13 === "function" ? receiver === state13 : state13.has(receiver);
}
function __addDisposableResource(env3, value, async) {
  if (value !== null && value !== void 0) {
    if (typeof value !== "object" && typeof value !== "function") throw new TypeError("Object expected.");
    var dispose, inner;
    if (async) {
      if (!Symbol.asyncDispose) throw new TypeError("Symbol.asyncDispose is not defined.");
      dispose = value[Symbol.asyncDispose];
    }
    if (dispose === void 0) {
      if (!Symbol.dispose) throw new TypeError("Symbol.dispose is not defined.");
      dispose = value[Symbol.dispose];
      if (async) inner = dispose;
    }
    if (typeof dispose !== "function") throw new TypeError("Object not disposable.");
    if (inner) dispose = /* @__PURE__ */ __name(function() {
      try {
        inner.call(this);
      } catch (e32) {
        return Promise.reject(e32);
      }
    }, "dispose");
    env3.stack.push({ value, dispose, async });
  } else if (async) {
    env3.stack.push({ async: true });
  }
  return value;
}
function __disposeResources(env3) {
  function fail(e32) {
    env3.error = env3.hasError ? new _SuppressedError(e32, env3.error, "An error was suppressed during disposal.") : e32;
    env3.hasError = true;
  }
  __name(fail, "fail");
  var r32, s = 0;
  function next() {
    while (r32 = env3.stack.pop()) {
      try {
        if (!r32.async && s === 1) return s = 0, env3.stack.push(r32), Promise.resolve().then(next);
        if (r32.dispose) {
          var result2 = r32.dispose.call(r32.value);
          if (r32.async) return s |= 2, Promise.resolve(result2).then(next, function(e32) {
            fail(e32);
            return next();
          });
        } else s |= 1;
      } catch (e32) {
        fail(e32);
      }
    }
    if (s === 1) return env3.hasError ? Promise.reject(env3.error) : Promise.resolve();
    if (env3.hasError) throw env3.error;
  }
  __name(next, "next");
  return next();
}
function __rewriteRelativeImportExtension(path47, preserveJsx) {
  if (typeof path47 === "string" && /^\.\.?\//.test(path47)) {
    return path47.replace(/\.(tsx)$|((?:\.d)?)((?:\.[^./]+?)?)\.([cm]?)ts$/i, function(m20, tsx, d32, ext, cm) {
      return tsx ? preserveJsx ? ".jsx" : ".js" : d32 && (!ext || !cm) ? m20 : d32 + ext + "." + cm.toLowerCase() + "js";
    });
  }
  return path47;
}
var extendStatics, __assign, __createBinding, __setModuleDefault, ownKeys, _SuppressedError, tslib_es6_default;
var init_tslib_es6 = __esm({
  "../../node_modules/tslib/tslib.es6.mjs"() {
    extendStatics = /* @__PURE__ */ __name(function(d32, b32) {
      extendStatics = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(d33, b33) {
        d33.__proto__ = b33;
      } || function(d33, b33) {
        for (var p10 in b33) if (Object.prototype.hasOwnProperty.call(b33, p10)) d33[p10] = b33[p10];
      };
      return extendStatics(d32, b32);
    }, "extendStatics");
    __name(__extends, "__extends");
    __assign = /* @__PURE__ */ __name(function() {
      __assign = Object.assign || /* @__PURE__ */ __name(function __assign2(t) {
        for (var s, i32 = 1, n10 = arguments.length; i32 < n10; i32++) {
          s = arguments[i32];
          for (var p10 in s) if (Object.prototype.hasOwnProperty.call(s, p10)) t[p10] = s[p10];
        }
        return t;
      }, "__assign");
      return __assign.apply(this, arguments);
    }, "__assign");
    __name(__rest, "__rest");
    __name(__decorate, "__decorate");
    __name(__param, "__param");
    __name(__esDecorate, "__esDecorate");
    __name(__runInitializers, "__runInitializers");
    __name(__propKey, "__propKey");
    __name(__setFunctionName, "__setFunctionName");
    __name(__metadata, "__metadata");
    __name(__awaiter, "__awaiter");
    __name(__generator, "__generator");
    __createBinding = Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    });
    __name(__exportStar, "__exportStar");
    __name(__values, "__values");
    __name(__read, "__read");
    __name(__spread, "__spread");
    __name(__spreadArrays, "__spreadArrays");
    __name(__spreadArray, "__spreadArray");
    __name(__await, "__await");
    __name(__asyncGenerator, "__asyncGenerator");
    __name(__asyncDelegator, "__asyncDelegator");
    __name(__asyncValues, "__asyncValues");
    __name(__makeTemplateObject, "__makeTemplateObject");
    __setModuleDefault = Object.create ? (function(o10, v) {
      Object.defineProperty(o10, "default", { enumerable: true, value: v });
    }) : function(o10, v) {
      o10["default"] = v;
    };
    ownKeys = /* @__PURE__ */ __name(function(o10) {
      ownKeys = Object.getOwnPropertyNames || function(o11) {
        var ar = [];
        for (var k32 in o11) if (Object.prototype.hasOwnProperty.call(o11, k32)) ar[ar.length] = k32;
        return ar;
      };
      return ownKeys(o10);
    }, "ownKeys");
    __name(__importStar, "__importStar");
    __name(__importDefault, "__importDefault");
    __name(__classPrivateFieldGet, "__classPrivateFieldGet");
    __name(__classPrivateFieldSet, "__classPrivateFieldSet");
    __name(__classPrivateFieldIn, "__classPrivateFieldIn");
    __name(__addDisposableResource, "__addDisposableResource");
    _SuppressedError = typeof SuppressedError === "function" ? SuppressedError : function(error4, suppressed, message2) {
      var e32 = new Error(message2);
      return e32.name = "SuppressedError", e32.error = error4, e32.suppressed = suppressed, e32;
    };
    __name(__disposeResources, "__disposeResources");
    __name(__rewriteRelativeImportExtension, "__rewriteRelativeImportExtension");
    tslib_es6_default = {
      __extends,
      __assign,
      __rest,
      __decorate,
      __param,
      __esDecorate,
      __runInitializers,
      __propKey,
      __setFunctionName,
      __metadata,
      __awaiter,
      __generator,
      __createBinding,
      __exportStar,
      __values,
      __read,
      __spread,
      __spreadArrays,
      __spreadArray,
      __await,
      __asyncGenerator,
      __asyncDelegator,
      __asyncValues,
      __makeTemplateObject,
      __importStar,
      __importDefault,
      __classPrivateFieldGet,
      __classPrivateFieldSet,
      __classPrivateFieldIn,
      __addDisposableResource,
      __disposeResources,
      __rewriteRelativeImportExtension
    };
  }
});

// ../../node_modules/@smithy/uuid/dist-cjs/randomUUID.js
var require_randomUUID = __commonJS({
  "../../node_modules/@smithy/uuid/dist-cjs/randomUUID.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.randomUUID = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var crypto_1 = tslib_1.__importDefault(require("crypto"));
    exports2.randomUUID = crypto_1.default.randomUUID.bind(crypto_1.default);
  }
});

// ../../node_modules/@smithy/uuid/dist-cjs/index.js
var require_dist_cjs19 = __commonJS({
  "../../node_modules/@smithy/uuid/dist-cjs/index.js"(exports2) {
    "use strict";
    var randomUUID12 = require_randomUUID();
    var decimalToHex7 = Array.from({ length: 256 }, (_, i32) => i32.toString(16).padStart(2, "0"));
    var v47 = /* @__PURE__ */ __name(() => {
      if (randomUUID12.randomUUID) {
        return randomUUID12.randomUUID();
      }
      const rnds = new Uint8Array(16);
      crypto.getRandomValues(rnds);
      rnds[6] = rnds[6] & 15 | 64;
      rnds[8] = rnds[8] & 63 | 128;
      return decimalToHex7[rnds[0]] + decimalToHex7[rnds[1]] + decimalToHex7[rnds[2]] + decimalToHex7[rnds[3]] + "-" + decimalToHex7[rnds[4]] + decimalToHex7[rnds[5]] + "-" + decimalToHex7[rnds[6]] + decimalToHex7[rnds[7]] + "-" + decimalToHex7[rnds[8]] + decimalToHex7[rnds[9]] + "-" + decimalToHex7[rnds[10]] + decimalToHex7[rnds[11]] + decimalToHex7[rnds[12]] + decimalToHex7[rnds[13]] + decimalToHex7[rnds[14]] + decimalToHex7[rnds[15]];
    }, "v4");
    exports2.v4 = v47;
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/serde/generateIdempotencyToken.js
var import_uuid;
var init_generateIdempotencyToken = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/serde/generateIdempotencyToken.js"() {
    import_uuid = __toESM(require_dist_cjs19());
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/serde/lazy-json.js
var LazyJsonString;
var init_lazy_json = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/serde/lazy-json.js"() {
    LazyJsonString = /* @__PURE__ */ __name(function LazyJsonString2(val) {
      const str = Object.assign(new String(val), {
        deserializeJSON() {
          return JSON.parse(String(val));
        },
        toString() {
          return String(val);
        },
        toJSON() {
          return String(val);
        }
      });
      return str;
    }, "LazyJsonString");
    LazyJsonString.from = (object) => {
      if (object && typeof object === "object" && (object instanceof LazyJsonString || "deserializeJSON" in object)) {
        return object;
      } else if (typeof object === "string" || Object.getPrototypeOf(object) === String.prototype) {
        return LazyJsonString(String(object));
      }
      return LazyJsonString(JSON.stringify(object));
    };
    LazyJsonString.fromObject = LazyJsonString.from;
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/serde/quote-header.js
function quoteHeader(part) {
  if (part.includes(",") || part.includes('"')) {
    part = `"${part.replace(/"/g, '\\"')}"`;
  }
  return part;
}
var init_quote_header = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/serde/quote-header.js"() {
    __name(quoteHeader, "quoteHeader");
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/serde/schema-serde-lib/schema-date-utils.js
function range(v, min, max) {
  const _v = Number(v);
  if (_v < min || _v > max) {
    throw new Error(`Value ${_v} out of range [${min}, ${max}]`);
  }
}
var ddd, mmm, time, date, year, RFC3339_WITH_OFFSET2, IMF_FIXDATE2, RFC_850_DATE2, ASC_TIME2, months, _parseEpochTimestamp, _parseRfc3339DateTimeWithOffset, _parseRfc7231DateTime;
var init_schema_date_utils = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/serde/schema-serde-lib/schema-date-utils.js"() {
    ddd = `(?:Mon|Tue|Wed|Thu|Fri|Sat|Sun)(?:[ne|u?r]?s?day)?`;
    mmm = `(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)`;
    time = `(\\d?\\d):(\\d{2}):(\\d{2})(?:\\.(\\d+))?`;
    date = `(\\d?\\d)`;
    year = `(\\d{4})`;
    RFC3339_WITH_OFFSET2 = new RegExp(/^(\d{4})-(\d\d)-(\d\d)[tT](\d\d):(\d\d):(\d\d)(\.(\d+))?(([-+]\d\d:\d\d)|[zZ])$/);
    IMF_FIXDATE2 = new RegExp(`^${ddd}, ${date} ${mmm} ${year} ${time} GMT$`);
    RFC_850_DATE2 = new RegExp(`^${ddd}, ${date}-${mmm}-(\\d\\d) ${time} GMT$`);
    ASC_TIME2 = new RegExp(`^${ddd} ${mmm} ( [1-9]|\\d\\d) ${time} ${year}$`);
    months = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"];
    _parseEpochTimestamp = /* @__PURE__ */ __name((value) => {
      if (value == null) {
        return void 0;
      }
      let num = NaN;
      if (typeof value === "number") {
        num = value;
      } else if (typeof value === "string") {
        if (!/^-?\d*\.?\d+$/.test(value)) {
          throw new TypeError(`parseEpochTimestamp - numeric string invalid.`);
        }
        num = Number.parseFloat(value);
      } else if (typeof value === "object" && value.tag === 1) {
        num = value.value;
      }
      if (isNaN(num) || Math.abs(num) === Infinity) {
        throw new TypeError("Epoch timestamps must be valid finite numbers.");
      }
      return new Date(Math.round(num * 1e3));
    }, "_parseEpochTimestamp");
    _parseRfc3339DateTimeWithOffset = /* @__PURE__ */ __name((value) => {
      if (value == null) {
        return void 0;
      }
      if (typeof value !== "string") {
        throw new TypeError("RFC3339 timestamps must be strings");
      }
      const matches = RFC3339_WITH_OFFSET2.exec(value);
      if (!matches) {
        throw new TypeError(`Invalid RFC3339 timestamp format ${value}`);
      }
      const [, yearStr, monthStr, dayStr, hours, minutes, seconds, , ms, offsetStr] = matches;
      range(monthStr, 1, 12);
      range(dayStr, 1, 31);
      range(hours, 0, 23);
      range(minutes, 0, 59);
      range(seconds, 0, 60);
      const date7 = new Date(Date.UTC(Number(yearStr), Number(monthStr) - 1, Number(dayStr), Number(hours), Number(minutes), Number(seconds), Number(ms) ? Math.round(parseFloat(`0.${ms}`) * 1e3) : 0));
      date7.setUTCFullYear(Number(yearStr));
      if (offsetStr.toUpperCase() != "Z") {
        const [, sign, offsetH, offsetM] = /([+-])(\d\d):(\d\d)/.exec(offsetStr) || [void 0, "+", 0, 0];
        const scalar = sign === "-" ? 1 : -1;
        date7.setTime(date7.getTime() + scalar * (Number(offsetH) * 60 * 60 * 1e3 + Number(offsetM) * 60 * 1e3));
      }
      return date7;
    }, "_parseRfc3339DateTimeWithOffset");
    _parseRfc7231DateTime = /* @__PURE__ */ __name((value) => {
      if (value == null) {
        return void 0;
      }
      if (typeof value !== "string") {
        throw new TypeError("RFC7231 timestamps must be strings.");
      }
      let day;
      let month;
      let year7;
      let hour;
      let minute;
      let second;
      let fraction;
      let matches;
      if (matches = IMF_FIXDATE2.exec(value)) {
        [, day, month, year7, hour, minute, second, fraction] = matches;
      } else if (matches = RFC_850_DATE2.exec(value)) {
        [, day, month, year7, hour, minute, second, fraction] = matches;
        year7 = (Number(year7) + 1900).toString();
      } else if (matches = ASC_TIME2.exec(value)) {
        [, month, day, hour, minute, second, fraction, year7] = matches;
      }
      if (year7 && second) {
        const timestamp = Date.UTC(Number(year7), months.indexOf(month), Number(day), Number(hour), Number(minute), Number(second), fraction ? Math.round(parseFloat(`0.${fraction}`) * 1e3) : 0);
        range(day, 1, 31);
        range(hour, 0, 23);
        range(minute, 0, 59);
        range(second, 0, 60);
        const date7 = new Date(timestamp);
        date7.setUTCFullYear(Number(year7));
        return date7;
      }
      throw new TypeError(`Invalid RFC7231 date-time value ${value}.`);
    }, "_parseRfc7231DateTime");
    __name(range, "range");
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/serde/split-every.js
function splitEvery(value, delimiter2, numDelimiters) {
  if (numDelimiters <= 0 || !Number.isInteger(numDelimiters)) {
    throw new Error("Invalid number of delimiters (" + numDelimiters + ") for splitEvery.");
  }
  const segments = value.split(delimiter2);
  if (numDelimiters === 1) {
    return segments;
  }
  const compoundSegments = [];
  let currentSegment = "";
  for (let i32 = 0; i32 < segments.length; i32++) {
    if (currentSegment === "") {
      currentSegment = segments[i32];
    } else {
      currentSegment += delimiter2 + segments[i32];
    }
    if ((i32 + 1) % numDelimiters === 0) {
      compoundSegments.push(currentSegment);
      currentSegment = "";
    }
  }
  if (currentSegment !== "") {
    compoundSegments.push(currentSegment);
  }
  return compoundSegments;
}
var init_split_every = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/serde/split-every.js"() {
    __name(splitEvery, "splitEvery");
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/serde/split-header.js
var splitHeader;
var init_split_header = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/serde/split-header.js"() {
    splitHeader = /* @__PURE__ */ __name((value) => {
      const z = value.length;
      const values = [];
      let withinQuotes = false;
      let prevChar = void 0;
      let anchor = 0;
      for (let i32 = 0; i32 < z; ++i32) {
        const char = value[i32];
        switch (char) {
          case `"`:
            if (prevChar !== "\\") {
              withinQuotes = !withinQuotes;
            }
            break;
          case ",":
            if (!withinQuotes) {
              values.push(value.slice(anchor, i32));
              anchor = i32 + 1;
            }
            break;
          default:
        }
        prevChar = char;
      }
      values.push(value.slice(anchor));
      return values.map((v) => {
        v = v.trim();
        const z2 = v.length;
        if (z2 < 2) {
          return v;
        }
        if (v[0] === `"` && v[z2 - 1] === `"`) {
          v = v.slice(1, z2 - 1);
        }
        return v.replace(/\\"/g, '"');
      });
    }, "splitHeader");
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/serde/value/NumericValue.js
function nv(input) {
  return new NumericValue(String(input), "bigDecimal");
}
var format, NumericValue;
var init_NumericValue = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/serde/value/NumericValue.js"() {
    format = /^-?\d*(\.\d+)?$/;
    NumericValue = class _NumericValue {
      static {
        __name(this, "NumericValue");
      }
      string;
      type;
      constructor(string, type) {
        this.string = string;
        this.type = type;
        if (!format.test(string)) {
          throw new Error(`@smithy/core/serde - NumericValue must only contain [0-9], at most one decimal point ".", and an optional negation prefix "-".`);
        }
      }
      toString() {
        return this.string;
      }
      static [Symbol.hasInstance](object) {
        if (!object || typeof object !== "object") {
          return false;
        }
        const _nv = object;
        return _NumericValue.prototype.isPrototypeOf(object) || _nv.type === "bigDecimal" && format.test(_nv.string);
      }
    };
    __name(nv, "nv");
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/serde/index.js
var serde_exports = {};
__export(serde_exports, {
  LazyJsonString: () => LazyJsonString,
  NumericValue: () => NumericValue,
  _parseEpochTimestamp: () => _parseEpochTimestamp,
  _parseRfc3339DateTimeWithOffset: () => _parseRfc3339DateTimeWithOffset,
  _parseRfc7231DateTime: () => _parseRfc7231DateTime,
  copyDocumentWithTransform: () => copyDocumentWithTransform,
  dateToUtcString: () => dateToUtcString,
  expectBoolean: () => expectBoolean,
  expectByte: () => expectByte,
  expectFloat32: () => expectFloat32,
  expectInt: () => expectInt,
  expectInt32: () => expectInt32,
  expectLong: () => expectLong,
  expectNonNull: () => expectNonNull,
  expectNumber: () => expectNumber,
  expectObject: () => expectObject,
  expectShort: () => expectShort,
  expectString: () => expectString,
  expectUnion: () => expectUnion,
  generateIdempotencyToken: () => import_uuid.v4,
  handleFloat: () => handleFloat,
  limitedParseDouble: () => limitedParseDouble,
  limitedParseFloat: () => limitedParseFloat,
  limitedParseFloat32: () => limitedParseFloat32,
  logger: () => logger,
  nv: () => nv,
  parseBoolean: () => parseBoolean,
  parseEpochTimestamp: () => parseEpochTimestamp,
  parseRfc3339DateTime: () => parseRfc3339DateTime,
  parseRfc3339DateTimeWithOffset: () => parseRfc3339DateTimeWithOffset,
  parseRfc7231DateTime: () => parseRfc7231DateTime,
  quoteHeader: () => quoteHeader,
  splitEvery: () => splitEvery,
  splitHeader: () => splitHeader,
  strictParseByte: () => strictParseByte,
  strictParseDouble: () => strictParseDouble,
  strictParseFloat: () => strictParseFloat,
  strictParseFloat32: () => strictParseFloat32,
  strictParseInt: () => strictParseInt,
  strictParseInt32: () => strictParseInt32,
  strictParseLong: () => strictParseLong,
  strictParseShort: () => strictParseShort
});
var init_serde = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/serde/index.js"() {
    init_copyDocumentWithTransform();
    init_date_utils();
    init_generateIdempotencyToken();
    init_lazy_json();
    init_parse_utils();
    init_quote_header();
    init_schema_date_utils();
    init_split_every();
    init_split_header();
    init_NumericValue();
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/protocols/SerdeContext.js
var SerdeContext;
var init_SerdeContext = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/protocols/SerdeContext.js"() {
    SerdeContext = class {
      static {
        __name(this, "SerdeContext");
      }
      serdeContext;
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
      }
    };
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/event-streams/EventStreamSerde.js
var import_util_utf8, EventStreamSerde;
var init_EventStreamSerde = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/event-streams/EventStreamSerde.js"() {
    import_util_utf8 = __toESM(require_dist_cjs9());
    EventStreamSerde = class {
      static {
        __name(this, "EventStreamSerde");
      }
      marshaller;
      serializer;
      deserializer;
      serdeContext;
      defaultContentType;
      constructor({ marshaller, serializer, deserializer, serdeContext, defaultContentType }) {
        this.marshaller = marshaller;
        this.serializer = serializer;
        this.deserializer = deserializer;
        this.serdeContext = serdeContext;
        this.defaultContentType = defaultContentType;
      }
      async serializeEventStream({ eventStream, requestSchema, initialRequest }) {
        const marshaller = this.marshaller;
        const eventStreamMember = requestSchema.getEventStreamMember();
        const unionSchema = requestSchema.getMemberSchema(eventStreamMember);
        const serializer = this.serializer;
        const defaultContentType = this.defaultContentType;
        const initialRequestMarker = /* @__PURE__ */ Symbol("initialRequestMarker");
        const eventStreamIterable = {
          async *[Symbol.asyncIterator]() {
            if (initialRequest) {
              const headers = {
                ":event-type": { type: "string", value: "initial-request" },
                ":message-type": { type: "string", value: "event" },
                ":content-type": { type: "string", value: defaultContentType }
              };
              serializer.write(requestSchema, initialRequest);
              const body = serializer.flush();
              yield {
                [initialRequestMarker]: true,
                headers,
                body
              };
            }
            for await (const page of eventStream) {
              yield page;
            }
          }
        };
        return marshaller.serialize(eventStreamIterable, (event) => {
          if (event[initialRequestMarker]) {
            return {
              headers: event.headers,
              body: event.body
            };
          }
          let unionMember = "";
          for (const key in event) {
            if (key !== "__type") {
              unionMember = key;
              break;
            }
          }
          const { additionalHeaders, body, eventType, explicitPayloadContentType } = this.writeEventBody(unionMember, unionSchema, event);
          const headers = {
            ":event-type": { type: "string", value: eventType },
            ":message-type": { type: "string", value: "event" },
            ":content-type": { type: "string", value: explicitPayloadContentType ?? defaultContentType },
            ...additionalHeaders
          };
          return {
            headers,
            body
          };
        });
      }
      async deserializeEventStream({ response, responseSchema, initialResponseContainer }) {
        const marshaller = this.marshaller;
        const eventStreamMember = responseSchema.getEventStreamMember();
        const unionSchema = responseSchema.getMemberSchema(eventStreamMember);
        const memberSchemas = unionSchema.getMemberSchemas();
        const initialResponseMarker = /* @__PURE__ */ Symbol("initialResponseMarker");
        const asyncIterable = marshaller.deserialize(response.body, async (event) => {
          let unionMember = "";
          for (const key in event) {
            if (key !== "__type") {
              unionMember = key;
              break;
            }
          }
          const body = event[unionMember].body;
          if (unionMember === "initial-response") {
            const dataObject = await this.deserializer.read(responseSchema, body);
            delete dataObject[eventStreamMember];
            return {
              [initialResponseMarker]: true,
              ...dataObject
            };
          } else if (unionMember in memberSchemas) {
            const eventStreamSchema = memberSchemas[unionMember];
            if (eventStreamSchema.isStructSchema()) {
              const out = {};
              let hasBindings = false;
              for (const [name, member7] of eventStreamSchema.structIterator()) {
                const { eventHeader, eventPayload } = member7.getMergedTraits();
                hasBindings = hasBindings || Boolean(eventHeader || eventPayload);
                if (eventPayload) {
                  if (member7.isBlobSchema()) {
                    out[name] = body;
                  } else if (member7.isStringSchema()) {
                    out[name] = (this.serdeContext?.utf8Encoder ?? import_util_utf8.toUtf8)(body);
                  } else if (member7.isStructSchema()) {
                    out[name] = await this.deserializer.read(member7, body);
                  }
                } else if (eventHeader) {
                  const value = event[unionMember].headers[name]?.value;
                  if (value != null) {
                    if (member7.isNumericSchema()) {
                      if (value && typeof value === "object" && "bytes" in value) {
                        out[name] = BigInt(value.toString());
                      } else {
                        out[name] = Number(value);
                      }
                    } else {
                      out[name] = value;
                    }
                  }
                }
              }
              if (hasBindings) {
                return {
                  [unionMember]: out
                };
              }
              if (body.byteLength === 0) {
                return {
                  [unionMember]: {}
                };
              }
            }
            return {
              [unionMember]: await this.deserializer.read(eventStreamSchema, body)
            };
          } else {
            return {
              $unknown: event
            };
          }
        });
        const asyncIterator = asyncIterable[Symbol.asyncIterator]();
        const firstEvent = await asyncIterator.next();
        if (firstEvent.done) {
          return asyncIterable;
        }
        if (firstEvent.value?.[initialResponseMarker]) {
          if (!responseSchema) {
            throw new Error("@smithy::core/protocols - initial-response event encountered in event stream but no response schema given.");
          }
          for (const key in firstEvent.value) {
            initialResponseContainer[key] = firstEvent.value[key];
          }
        }
        return {
          async *[Symbol.asyncIterator]() {
            if (!firstEvent?.value?.[initialResponseMarker]) {
              yield firstEvent.value;
            }
            while (true) {
              const { done, value } = await asyncIterator.next();
              if (done) {
                break;
              }
              yield value;
            }
          }
        };
      }
      writeEventBody(unionMember, unionSchema, event) {
        const serializer = this.serializer;
        let eventType = unionMember;
        let explicitPayloadMember = null;
        let explicitPayloadContentType;
        const isKnownSchema = (() => {
          const struct3 = unionSchema.getSchema();
          return struct3[4].includes(unionMember);
        })();
        const additionalHeaders = {};
        if (!isKnownSchema) {
          const [type, value] = event[unionMember];
          eventType = type;
          serializer.write(15, value);
        } else {
          const eventSchema = unionSchema.getMemberSchema(unionMember);
          if (eventSchema.isStructSchema()) {
            for (const [memberName, memberSchema] of eventSchema.structIterator()) {
              const { eventHeader, eventPayload } = memberSchema.getMergedTraits();
              if (eventPayload) {
                explicitPayloadMember = memberName;
              } else if (eventHeader) {
                const value = event[unionMember][memberName];
                let type = "binary";
                if (memberSchema.isNumericSchema()) {
                  if ((-2) ** 31 <= value && value <= 2 ** 31 - 1) {
                    type = "integer";
                  } else {
                    type = "long";
                  }
                } else if (memberSchema.isTimestampSchema()) {
                  type = "timestamp";
                } else if (memberSchema.isStringSchema()) {
                  type = "string";
                } else if (memberSchema.isBooleanSchema()) {
                  type = "boolean";
                }
                if (value != null) {
                  additionalHeaders[memberName] = {
                    type,
                    value
                  };
                  delete event[unionMember][memberName];
                }
              }
            }
            if (explicitPayloadMember !== null) {
              const payloadSchema = eventSchema.getMemberSchema(explicitPayloadMember);
              if (payloadSchema.isBlobSchema()) {
                explicitPayloadContentType = "application/octet-stream";
              } else if (payloadSchema.isStringSchema()) {
                explicitPayloadContentType = "text/plain";
              }
              serializer.write(payloadSchema, event[unionMember][explicitPayloadMember]);
            } else {
              serializer.write(eventSchema, event[unionMember]);
            }
          } else if (eventSchema.isUnitSchema()) {
            serializer.write(eventSchema, {});
          } else {
            throw new Error("@smithy/core/event-streams - non-struct member not supported in event stream union.");
          }
        }
        const messageSerialization = serializer.flush() ?? new Uint8Array();
        const body = typeof messageSerialization === "string" ? (this.serdeContext?.utf8Decoder ?? import_util_utf8.fromUtf8)(messageSerialization) : messageSerialization;
        return {
          body,
          eventType,
          explicitPayloadContentType,
          additionalHeaders
        };
      }
    };
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/event-streams/index.js
var event_streams_exports = {};
__export(event_streams_exports, {
  EventStreamSerde: () => EventStreamSerde
});
var init_event_streams = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/event-streams/index.js"() {
    init_EventStreamSerde();
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/protocols/HttpProtocol.js
var import_protocol_http3, HttpProtocol;
var init_HttpProtocol = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/protocols/HttpProtocol.js"() {
    init_schema4();
    import_protocol_http3 = __toESM(require_dist_cjs2());
    init_SerdeContext();
    HttpProtocol = class extends SerdeContext {
      static {
        __name(this, "HttpProtocol");
      }
      options;
      compositeErrorRegistry;
      constructor(options) {
        super();
        this.options = options;
        this.compositeErrorRegistry = TypeRegistry.for(options.defaultNamespace);
        for (const etr of options.errorTypeRegistries ?? []) {
          this.compositeErrorRegistry.copyFrom(etr);
        }
      }
      getRequestType() {
        return import_protocol_http3.HttpRequest;
      }
      getResponseType() {
        return import_protocol_http3.HttpResponse;
      }
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
        this.serializer.setSerdeContext(serdeContext);
        this.deserializer.setSerdeContext(serdeContext);
        if (this.getPayloadCodec()) {
          this.getPayloadCodec().setSerdeContext(serdeContext);
        }
      }
      updateServiceEndpoint(request4, endpoint) {
        if ("url" in endpoint) {
          request4.protocol = endpoint.url.protocol;
          request4.hostname = endpoint.url.hostname;
          request4.port = endpoint.url.port ? Number(endpoint.url.port) : void 0;
          request4.path = endpoint.url.pathname;
          request4.fragment = endpoint.url.hash || void 0;
          request4.username = endpoint.url.username || void 0;
          request4.password = endpoint.url.password || void 0;
          if (!request4.query) {
            request4.query = {};
          }
          for (const [k32, v] of endpoint.url.searchParams.entries()) {
            request4.query[k32] = v;
          }
          if (endpoint.headers) {
            for (const name in endpoint.headers) {
              request4.headers[name] = endpoint.headers[name].join(", ");
            }
          }
          return request4;
        } else {
          request4.protocol = endpoint.protocol;
          request4.hostname = endpoint.hostname;
          request4.port = endpoint.port ? Number(endpoint.port) : void 0;
          request4.path = endpoint.path;
          request4.query = {
            ...endpoint.query
          };
          if (endpoint.headers) {
            for (const name in endpoint.headers) {
              request4.headers[name] = endpoint.headers[name];
            }
          }
          return request4;
        }
      }
      setHostPrefix(request4, operationSchema, input) {
        if (this.serdeContext?.disableHostPrefix) {
          return;
        }
        const inputNs = NormalizedSchema.of(operationSchema.input);
        const opTraits = translateTraits(operationSchema.traits ?? {});
        if (opTraits.endpoint) {
          let hostPrefix = opTraits.endpoint?.[0];
          if (typeof hostPrefix === "string") {
            for (const [name, member7] of inputNs.structIterator()) {
              if (!member7.getMergedTraits().hostLabel) {
                continue;
              }
              const replacement = input[name];
              if (typeof replacement !== "string") {
                throw new Error(`@smithy/core/schema - ${name} in input must be a string as hostLabel.`);
              }
              hostPrefix = hostPrefix.replace(`{${name}}`, replacement);
            }
            request4.hostname = hostPrefix + request4.hostname;
          }
        }
      }
      deserializeMetadata(output) {
        return {
          httpStatusCode: output.statusCode,
          requestId: output.headers["x-amzn-requestid"] ?? output.headers["x-amzn-request-id"] ?? output.headers["x-amz-request-id"],
          extendedRequestId: output.headers["x-amz-id-2"],
          cfId: output.headers["x-amz-cf-id"]
        };
      }
      async serializeEventStream({ eventStream, requestSchema, initialRequest }) {
        const eventStreamSerde = await this.loadEventStreamCapability();
        return eventStreamSerde.serializeEventStream({
          eventStream,
          requestSchema,
          initialRequest
        });
      }
      async deserializeEventStream({ response, responseSchema, initialResponseContainer }) {
        const eventStreamSerde = await this.loadEventStreamCapability();
        return eventStreamSerde.deserializeEventStream({
          response,
          responseSchema,
          initialResponseContainer
        });
      }
      async loadEventStreamCapability() {
        const { EventStreamSerde: EventStreamSerde7 } = await Promise.resolve().then(() => (init_event_streams(), event_streams_exports));
        return new EventStreamSerde7({
          marshaller: this.getEventStreamMarshaller(),
          serializer: this.serializer,
          deserializer: this.deserializer,
          serdeContext: this.serdeContext,
          defaultContentType: this.getDefaultContentType()
        });
      }
      getDefaultContentType() {
        throw new Error(`@smithy/core/protocols - ${this.constructor.name} getDefaultContentType() implementation missing.`);
      }
      async deserializeHttpMessage(schema, context, response, arg4, arg5) {
        void schema;
        void context;
        void response;
        void arg4;
        void arg5;
        return [];
      }
      getEventStreamMarshaller() {
        const context = this.serdeContext;
        if (!context.eventStreamMarshaller) {
          throw new Error("@smithy/core - HttpProtocol: eventStreamMarshaller missing in serdeContext.");
        }
        return context.eventStreamMarshaller;
      }
    };
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/protocols/HttpBindingProtocol.js
var import_protocol_http4, import_util_stream2, HttpBindingProtocol;
var init_HttpBindingProtocol = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/protocols/HttpBindingProtocol.js"() {
    init_schema4();
    init_serde();
    import_protocol_http4 = __toESM(require_dist_cjs2());
    import_util_stream2 = __toESM(require_dist_cjs16());
    init_collect_stream_body();
    init_extended_encode_uri_component();
    init_HttpProtocol();
    HttpBindingProtocol = class extends HttpProtocol {
      static {
        __name(this, "HttpBindingProtocol");
      }
      async serializeRequest(operationSchema, _input, context) {
        const input = _input && typeof _input === "object" ? _input : {};
        const serializer = this.serializer;
        const query = {};
        const headers = {};
        const endpoint = await context.endpoint();
        const ns = NormalizedSchema.of(operationSchema?.input);
        const payloadMemberNames = [];
        const payloadMemberSchemas = [];
        let hasNonHttpBindingMember = false;
        let payload3;
        const request4 = new import_protocol_http4.HttpRequest({
          protocol: "",
          hostname: "",
          port: void 0,
          path: "",
          fragment: void 0,
          query,
          headers,
          body: void 0
        });
        if (endpoint) {
          this.updateServiceEndpoint(request4, endpoint);
          this.setHostPrefix(request4, operationSchema, input);
          const opTraits = translateTraits(operationSchema.traits);
          if (opTraits.http) {
            request4.method = opTraits.http[0];
            const [path47, search] = opTraits.http[1].split("?");
            if (request4.path == "/") {
              request4.path = path47;
            } else {
              request4.path += path47;
            }
            const traitSearchParams = new URLSearchParams(search ?? "");
            for (const [key, value] of traitSearchParams) {
              query[key] = value;
            }
          }
        }
        for (const [memberName, memberNs] of ns.structIterator()) {
          const memberTraits = memberNs.getMergedTraits() ?? {};
          const inputMemberValue = input[memberName];
          if (inputMemberValue == null && !memberNs.isIdempotencyToken()) {
            if (memberTraits.httpLabel) {
              if (request4.path.includes(`{${memberName}+}`) || request4.path.includes(`{${memberName}}`)) {
                throw new Error(`No value provided for input HTTP label: ${memberName}.`);
              }
            }
            continue;
          }
          if (memberTraits.httpPayload) {
            const isStreaming = memberNs.isStreaming();
            if (isStreaming) {
              const isEventStream = memberNs.isStructSchema();
              if (isEventStream) {
                if (input[memberName]) {
                  payload3 = await this.serializeEventStream({
                    eventStream: input[memberName],
                    requestSchema: ns
                  });
                }
              } else {
                payload3 = inputMemberValue;
              }
            } else {
              serializer.write(memberNs, inputMemberValue);
              payload3 = serializer.flush();
            }
          } else if (memberTraits.httpLabel) {
            serializer.write(memberNs, inputMemberValue);
            const replacement = serializer.flush();
            if (request4.path.includes(`{${memberName}+}`)) {
              request4.path = request4.path.replace(`{${memberName}+}`, replacement.split("/").map(extendedEncodeURIComponent).join("/"));
            } else if (request4.path.includes(`{${memberName}}`)) {
              request4.path = request4.path.replace(`{${memberName}}`, extendedEncodeURIComponent(replacement));
            }
          } else if (memberTraits.httpHeader) {
            serializer.write(memberNs, inputMemberValue);
            headers[memberTraits.httpHeader.toLowerCase()] = String(serializer.flush());
          } else if (typeof memberTraits.httpPrefixHeaders === "string") {
            for (const key in inputMemberValue) {
              const val = inputMemberValue[key];
              const amalgam = memberTraits.httpPrefixHeaders + key;
              serializer.write([memberNs.getValueSchema(), { httpHeader: amalgam }], val);
              headers[amalgam.toLowerCase()] = serializer.flush();
            }
          } else if (memberTraits.httpQuery || memberTraits.httpQueryParams) {
            this.serializeQuery(memberNs, inputMemberValue, query);
          } else {
            hasNonHttpBindingMember = true;
            payloadMemberNames.push(memberName);
            payloadMemberSchemas.push(memberNs);
          }
        }
        if (hasNonHttpBindingMember && input) {
          const [namespace, name] = (ns.getName(true) ?? "#Unknown").split("#");
          const requiredMembers = ns.getSchema()[6];
          const payloadSchema = [
            3,
            namespace,
            name,
            ns.getMergedTraits(),
            payloadMemberNames,
            payloadMemberSchemas,
            void 0
          ];
          if (requiredMembers) {
            payloadSchema[6] = requiredMembers;
          } else {
            payloadSchema.pop();
          }
          serializer.write(payloadSchema, input);
          payload3 = serializer.flush();
        }
        request4.headers = headers;
        request4.query = query;
        request4.body = payload3;
        return request4;
      }
      serializeQuery(ns, data3, query) {
        const serializer = this.serializer;
        const traits = ns.getMergedTraits();
        if (traits.httpQueryParams) {
          for (const key in data3) {
            if (!(key in query)) {
              const val = data3[key];
              const valueSchema = ns.getValueSchema();
              Object.assign(valueSchema.getMergedTraits(), {
                ...traits,
                httpQuery: key,
                httpQueryParams: void 0
              });
              this.serializeQuery(valueSchema, val, query);
            }
          }
          return;
        }
        if (ns.isListSchema()) {
          const sparse = !!ns.getMergedTraits().sparse;
          const buffer = [];
          for (const item of data3) {
            serializer.write([ns.getValueSchema(), traits], item);
            const serializable = serializer.flush();
            if (sparse || serializable !== void 0) {
              buffer.push(serializable);
            }
          }
          query[traits.httpQuery] = buffer;
        } else {
          serializer.write([ns, traits], data3);
          query[traits.httpQuery] = serializer.flush();
        }
      }
      async deserializeResponse(operationSchema, context, response) {
        const deserializer = this.deserializer;
        const ns = NormalizedSchema.of(operationSchema.output);
        const dataObject = {};
        if (response.statusCode >= 300) {
          const bytes = await collectBody(response.body, context);
          if (bytes.byteLength > 0) {
            Object.assign(dataObject, await deserializer.read(15, bytes));
          }
          await this.handleError(operationSchema, context, response, dataObject, this.deserializeMetadata(response));
          throw new Error("@smithy/core/protocols - HTTP Protocol error handler failed to throw.");
        }
        for (const header in response.headers) {
          const value = response.headers[header];
          delete response.headers[header];
          response.headers[header.toLowerCase()] = value;
        }
        const nonHttpBindingMembers = await this.deserializeHttpMessage(ns, context, response, dataObject);
        if (nonHttpBindingMembers.length) {
          const bytes = await collectBody(response.body, context);
          if (bytes.byteLength > 0) {
            const dataFromBody = await deserializer.read(ns, bytes);
            for (const member7 of nonHttpBindingMembers) {
              if (dataFromBody[member7] != null) {
                dataObject[member7] = dataFromBody[member7];
              }
            }
          }
        } else if (nonHttpBindingMembers.discardResponseBody) {
          await collectBody(response.body, context);
        }
        dataObject.$metadata = this.deserializeMetadata(response);
        return dataObject;
      }
      async deserializeHttpMessage(schema, context, response, arg4, arg5) {
        let dataObject;
        if (arg4 instanceof Set) {
          dataObject = arg5;
        } else {
          dataObject = arg4;
        }
        let discardResponseBody = true;
        const deserializer = this.deserializer;
        const ns = NormalizedSchema.of(schema);
        const nonHttpBindingMembers = [];
        for (const [memberName, memberSchema] of ns.structIterator()) {
          const memberTraits = memberSchema.getMemberTraits();
          if (memberTraits.httpPayload) {
            discardResponseBody = false;
            const isStreaming = memberSchema.isStreaming();
            if (isStreaming) {
              const isEventStream = memberSchema.isStructSchema();
              if (isEventStream) {
                dataObject[memberName] = await this.deserializeEventStream({
                  response,
                  responseSchema: ns
                });
              } else {
                dataObject[memberName] = (0, import_util_stream2.sdkStreamMixin)(response.body);
              }
            } else if (response.body) {
              const bytes = await collectBody(response.body, context);
              if (bytes.byteLength > 0) {
                dataObject[memberName] = await deserializer.read(memberSchema, bytes);
              }
            }
          } else if (memberTraits.httpHeader) {
            const key = String(memberTraits.httpHeader).toLowerCase();
            const value = response.headers[key];
            if (null != value) {
              if (memberSchema.isListSchema()) {
                const headerListValueSchema = memberSchema.getValueSchema();
                headerListValueSchema.getMergedTraits().httpHeader = key;
                let sections;
                if (headerListValueSchema.isTimestampSchema() && headerListValueSchema.getSchema() === 4) {
                  sections = splitEvery(value, ",", 2);
                } else {
                  sections = splitHeader(value);
                }
                const list3 = [];
                for (const section of sections) {
                  list3.push(await deserializer.read(headerListValueSchema, section.trim()));
                }
                dataObject[memberName] = list3;
              } else {
                dataObject[memberName] = await deserializer.read(memberSchema, value);
              }
            }
          } else if (memberTraits.httpPrefixHeaders !== void 0) {
            dataObject[memberName] = {};
            for (const header in response.headers) {
              if (header.startsWith(memberTraits.httpPrefixHeaders)) {
                const value = response.headers[header];
                const valueSchema = memberSchema.getValueSchema();
                valueSchema.getMergedTraits().httpHeader = header;
                dataObject[memberName][header.slice(memberTraits.httpPrefixHeaders.length)] = await deserializer.read(valueSchema, value);
              }
            }
          } else if (memberTraits.httpResponseCode) {
            dataObject[memberName] = response.statusCode;
          } else {
            nonHttpBindingMembers.push(memberName);
          }
        }
        nonHttpBindingMembers.discardResponseBody = discardResponseBody;
        return nonHttpBindingMembers;
      }
    };
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/protocols/RpcProtocol.js
var import_protocol_http5, RpcProtocol;
var init_RpcProtocol = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/protocols/RpcProtocol.js"() {
    init_schema4();
    import_protocol_http5 = __toESM(require_dist_cjs2());
    init_collect_stream_body();
    init_HttpProtocol();
    RpcProtocol = class extends HttpProtocol {
      static {
        __name(this, "RpcProtocol");
      }
      async serializeRequest(operationSchema, _input, context) {
        const serializer = this.serializer;
        const query = {};
        const headers = {};
        const endpoint = await context.endpoint();
        const ns = NormalizedSchema.of(operationSchema?.input);
        const schema = ns.getSchema();
        let payload3;
        const input = _input && typeof _input === "object" ? _input : {};
        const request4 = new import_protocol_http5.HttpRequest({
          protocol: "",
          hostname: "",
          port: void 0,
          path: "/",
          fragment: void 0,
          query,
          headers,
          body: void 0
        });
        if (endpoint) {
          this.updateServiceEndpoint(request4, endpoint);
          this.setHostPrefix(request4, operationSchema, input);
        }
        if (input) {
          const eventStreamMember = ns.getEventStreamMember();
          if (eventStreamMember) {
            if (input[eventStreamMember]) {
              const initialRequest = {};
              for (const [memberName, memberSchema] of ns.structIterator()) {
                if (memberName !== eventStreamMember && input[memberName]) {
                  serializer.write(memberSchema, input[memberName]);
                  initialRequest[memberName] = serializer.flush();
                }
              }
              payload3 = await this.serializeEventStream({
                eventStream: input[eventStreamMember],
                requestSchema: ns,
                initialRequest
              });
            }
          } else {
            serializer.write(schema, input);
            payload3 = serializer.flush();
          }
        }
        request4.headers = Object.assign(request4.headers, headers);
        request4.query = query;
        request4.body = payload3;
        request4.method = "POST";
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        const deserializer = this.deserializer;
        const ns = NormalizedSchema.of(operationSchema.output);
        const dataObject = {};
        if (response.statusCode >= 300) {
          const bytes = await collectBody(response.body, context);
          if (bytes.byteLength > 0) {
            Object.assign(dataObject, await deserializer.read(15, bytes));
          }
          await this.handleError(operationSchema, context, response, dataObject, this.deserializeMetadata(response));
          throw new Error("@smithy/core/protocols - RPC Protocol error handler failed to throw.");
        }
        for (const header in response.headers) {
          const value = response.headers[header];
          delete response.headers[header];
          response.headers[header.toLowerCase()] = value;
        }
        const eventStreamMember = ns.getEventStreamMember();
        if (eventStreamMember) {
          dataObject[eventStreamMember] = await this.deserializeEventStream({
            response,
            responseSchema: ns,
            initialResponseContainer: dataObject
          });
        } else {
          const bytes = await collectBody(response.body, context);
          if (bytes.byteLength > 0) {
            Object.assign(dataObject, await deserializer.read(ns, bytes));
          }
        }
        dataObject.$metadata = this.deserializeMetadata(response);
        return dataObject;
      }
    };
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/protocols/resolve-path.js
var resolvedPath;
var init_resolve_path = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/protocols/resolve-path.js"() {
    init_extended_encode_uri_component();
    resolvedPath = /* @__PURE__ */ __name((resolvedPath7, input, memberName, labelValueProvider, uriLabel, isGreedyLabel) => {
      if (input != null && input[memberName] !== void 0) {
        const labelValue = labelValueProvider();
        if (labelValue == null || labelValue.length <= 0) {
          throw new Error("Empty value provided for input HTTP label: " + memberName + ".");
        }
        resolvedPath7 = resolvedPath7.replace(uriLabel, isGreedyLabel ? labelValue.split("/").map((segment) => extendedEncodeURIComponent(segment)).join("/") : extendedEncodeURIComponent(labelValue));
      } else {
        throw new Error("No value provided for input HTTP label: " + memberName + ".");
      }
      return resolvedPath7;
    }, "resolvedPath");
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/protocols/requestBuilder.js
function requestBuilder(input, context) {
  return new RequestBuilder(input, context);
}
var import_protocol_http6, RequestBuilder;
var init_requestBuilder = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/protocols/requestBuilder.js"() {
    import_protocol_http6 = __toESM(require_dist_cjs2());
    init_resolve_path();
    __name(requestBuilder, "requestBuilder");
    RequestBuilder = class {
      static {
        __name(this, "RequestBuilder");
      }
      input;
      context;
      query = {};
      method = "";
      headers = {};
      path = "";
      body = null;
      hostname = "";
      resolvePathStack = [];
      constructor(input, context) {
        this.input = input;
        this.context = context;
      }
      async build() {
        const { hostname, protocol = "https", port, path: basePath } = await this.context.endpoint();
        this.path = basePath;
        for (const resolvePath of this.resolvePathStack) {
          resolvePath(this.path);
        }
        return new import_protocol_http6.HttpRequest({
          protocol,
          hostname: this.hostname || hostname,
          port,
          method: this.method,
          path: this.path,
          query: this.query,
          body: this.body,
          headers: this.headers
        });
      }
      hn(hostname) {
        this.hostname = hostname;
        return this;
      }
      bp(uriLabel) {
        this.resolvePathStack.push((basePath) => {
          this.path = `${basePath?.endsWith("/") ? basePath.slice(0, -1) : basePath || ""}` + uriLabel;
        });
        return this;
      }
      p(memberName, labelValueProvider, uriLabel, isGreedyLabel) {
        this.resolvePathStack.push((path47) => {
          this.path = resolvedPath(path47, this.input, memberName, labelValueProvider, uriLabel, isGreedyLabel);
        });
        return this;
      }
      h(headers) {
        this.headers = headers;
        return this;
      }
      q(query) {
        this.query = query;
        return this;
      }
      b(body) {
        this.body = body;
        return this;
      }
      m(method) {
        this.method = method;
        return this;
      }
    };
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/protocols/serde/determineTimestampFormat.js
function determineTimestampFormat(ns, settings) {
  if (settings.timestampFormat.useTrait) {
    if (ns.isTimestampSchema() && (ns.getSchema() === 5 || ns.getSchema() === 6 || ns.getSchema() === 7)) {
      return ns.getSchema();
    }
  }
  const { httpLabel, httpPrefixHeaders, httpHeader, httpQuery } = ns.getMergedTraits();
  const bindingFormat = settings.httpBindings ? typeof httpPrefixHeaders === "string" || Boolean(httpHeader) ? 6 : Boolean(httpQuery) || Boolean(httpLabel) ? 5 : void 0 : void 0;
  return bindingFormat ?? settings.timestampFormat.default;
}
var init_determineTimestampFormat = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/protocols/serde/determineTimestampFormat.js"() {
    __name(determineTimestampFormat, "determineTimestampFormat");
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/protocols/serde/FromStringShapeDeserializer.js
var import_util_base64, import_util_utf82, FromStringShapeDeserializer;
var init_FromStringShapeDeserializer = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/protocols/serde/FromStringShapeDeserializer.js"() {
    init_schema4();
    init_serde();
    import_util_base64 = __toESM(require_dist_cjs10());
    import_util_utf82 = __toESM(require_dist_cjs9());
    init_SerdeContext();
    init_determineTimestampFormat();
    FromStringShapeDeserializer = class extends SerdeContext {
      static {
        __name(this, "FromStringShapeDeserializer");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      read(_schema, data3) {
        const ns = NormalizedSchema.of(_schema);
        if (ns.isListSchema()) {
          return splitHeader(data3).map((item) => this.read(ns.getValueSchema(), item));
        }
        if (ns.isBlobSchema()) {
          return (this.serdeContext?.base64Decoder ?? import_util_base64.fromBase64)(data3);
        }
        if (ns.isTimestampSchema()) {
          const format32 = determineTimestampFormat(ns, this.settings);
          switch (format32) {
            case 5:
              return _parseRfc3339DateTimeWithOffset(data3);
            case 6:
              return _parseRfc7231DateTime(data3);
            case 7:
              return _parseEpochTimestamp(data3);
            default:
              console.warn("Missing timestamp format, parsing value with Date constructor:", data3);
              return new Date(data3);
          }
        }
        if (ns.isStringSchema()) {
          const mediaType = ns.getMergedTraits().mediaType;
          let intermediateValue = data3;
          if (mediaType) {
            if (ns.getMergedTraits().httpHeader) {
              intermediateValue = this.base64ToUtf8(intermediateValue);
            }
            const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
            if (isJson) {
              intermediateValue = LazyJsonString.from(intermediateValue);
            }
            return intermediateValue;
          }
        }
        if (ns.isNumericSchema()) {
          return Number(data3);
        }
        if (ns.isBigIntegerSchema()) {
          return BigInt(data3);
        }
        if (ns.isBigDecimalSchema()) {
          return new NumericValue(data3, "bigDecimal");
        }
        if (ns.isBooleanSchema()) {
          return String(data3).toLowerCase() === "true";
        }
        return data3;
      }
      base64ToUtf8(base64String) {
        return (this.serdeContext?.utf8Encoder ?? import_util_utf82.toUtf8)((this.serdeContext?.base64Decoder ?? import_util_base64.fromBase64)(base64String));
      }
    };
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/protocols/serde/HttpInterceptingShapeDeserializer.js
var import_util_utf83, HttpInterceptingShapeDeserializer;
var init_HttpInterceptingShapeDeserializer = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/protocols/serde/HttpInterceptingShapeDeserializer.js"() {
    init_schema4();
    import_util_utf83 = __toESM(require_dist_cjs9());
    init_SerdeContext();
    init_FromStringShapeDeserializer();
    HttpInterceptingShapeDeserializer = class extends SerdeContext {
      static {
        __name(this, "HttpInterceptingShapeDeserializer");
      }
      codecDeserializer;
      stringDeserializer;
      constructor(codecDeserializer, codecSettings) {
        super();
        this.codecDeserializer = codecDeserializer;
        this.stringDeserializer = new FromStringShapeDeserializer(codecSettings);
      }
      setSerdeContext(serdeContext) {
        this.stringDeserializer.setSerdeContext(serdeContext);
        this.codecDeserializer.setSerdeContext(serdeContext);
        this.serdeContext = serdeContext;
      }
      read(schema, data3) {
        const ns = NormalizedSchema.of(schema);
        const traits = ns.getMergedTraits();
        const toString = this.serdeContext?.utf8Encoder ?? import_util_utf83.toUtf8;
        if (traits.httpHeader || traits.httpResponseCode) {
          return this.stringDeserializer.read(ns, toString(data3));
        }
        if (traits.httpPayload) {
          if (ns.isBlobSchema()) {
            const toBytes = this.serdeContext?.utf8Decoder ?? import_util_utf83.fromUtf8;
            if (typeof data3 === "string") {
              return toBytes(data3);
            }
            return data3;
          } else if (ns.isStringSchema()) {
            if ("byteLength" in data3) {
              return toString(data3);
            }
            return data3;
          }
        }
        return this.codecDeserializer.read(ns, data3);
      }
    };
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/protocols/serde/ToStringShapeSerializer.js
var import_util_base642, ToStringShapeSerializer;
var init_ToStringShapeSerializer = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/protocols/serde/ToStringShapeSerializer.js"() {
    init_schema4();
    init_serde();
    import_util_base642 = __toESM(require_dist_cjs10());
    init_SerdeContext();
    init_determineTimestampFormat();
    ToStringShapeSerializer = class extends SerdeContext {
      static {
        __name(this, "ToStringShapeSerializer");
      }
      settings;
      stringBuffer = "";
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value) {
        const ns = NormalizedSchema.of(schema);
        switch (typeof value) {
          case "object":
            if (value === null) {
              this.stringBuffer = "null";
              return;
            }
            if (ns.isTimestampSchema()) {
              if (!(value instanceof Date)) {
                throw new Error(`@smithy/core/protocols - received non-Date value ${value} when schema expected Date in ${ns.getName(true)}`);
              }
              const format32 = determineTimestampFormat(ns, this.settings);
              switch (format32) {
                case 5:
                  this.stringBuffer = value.toISOString().replace(".000Z", "Z");
                  break;
                case 6:
                  this.stringBuffer = dateToUtcString(value);
                  break;
                case 7:
                  this.stringBuffer = String(value.getTime() / 1e3);
                  break;
                default:
                  console.warn("Missing timestamp format, using epoch seconds", value);
                  this.stringBuffer = String(value.getTime() / 1e3);
              }
              return;
            }
            if (ns.isBlobSchema() && "byteLength" in value) {
              this.stringBuffer = (this.serdeContext?.base64Encoder ?? import_util_base642.toBase64)(value);
              return;
            }
            if (ns.isListSchema() && Array.isArray(value)) {
              let buffer = "";
              for (const item of value) {
                this.write([ns.getValueSchema(), ns.getMergedTraits()], item);
                const headerItem = this.flush();
                const serialized = ns.getValueSchema().isTimestampSchema() ? headerItem : quoteHeader(headerItem);
                if (buffer !== "") {
                  buffer += ", ";
                }
                buffer += serialized;
              }
              this.stringBuffer = buffer;
              return;
            }
            this.stringBuffer = JSON.stringify(value, null, 2);
            break;
          case "string":
            const mediaType = ns.getMergedTraits().mediaType;
            let intermediateValue = value;
            if (mediaType) {
              const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
              if (isJson) {
                intermediateValue = LazyJsonString.from(intermediateValue);
              }
              if (ns.getMergedTraits().httpHeader) {
                this.stringBuffer = (this.serdeContext?.base64Encoder ?? import_util_base642.toBase64)(intermediateValue.toString());
                return;
              }
            }
            this.stringBuffer = value;
            break;
          default:
            if (ns.isIdempotencyToken()) {
              this.stringBuffer = (0, import_uuid.v4)();
            } else {
              this.stringBuffer = String(value);
            }
        }
      }
      flush() {
        const buffer = this.stringBuffer;
        this.stringBuffer = "";
        return buffer;
      }
    };
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/protocols/serde/HttpInterceptingShapeSerializer.js
var HttpInterceptingShapeSerializer;
var init_HttpInterceptingShapeSerializer = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/protocols/serde/HttpInterceptingShapeSerializer.js"() {
    init_schema4();
    init_ToStringShapeSerializer();
    HttpInterceptingShapeSerializer = class {
      static {
        __name(this, "HttpInterceptingShapeSerializer");
      }
      codecSerializer;
      stringSerializer;
      buffer;
      constructor(codecSerializer, codecSettings, stringSerializer = new ToStringShapeSerializer(codecSettings)) {
        this.codecSerializer = codecSerializer;
        this.stringSerializer = stringSerializer;
      }
      setSerdeContext(serdeContext) {
        this.codecSerializer.setSerdeContext(serdeContext);
        this.stringSerializer.setSerdeContext(serdeContext);
      }
      write(schema, value) {
        const ns = NormalizedSchema.of(schema);
        const traits = ns.getMergedTraits();
        if (traits.httpHeader || traits.httpLabel || traits.httpQuery) {
          this.stringSerializer.write(ns, value);
          this.buffer = this.stringSerializer.flush();
          return;
        }
        return this.codecSerializer.write(ns, value);
      }
      flush() {
        if (this.buffer !== void 0) {
          const buffer = this.buffer;
          this.buffer = void 0;
          return buffer;
        }
        return this.codecSerializer.flush();
      }
    };
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/protocols/index.js
var protocols_exports = {};
__export(protocols_exports, {
  FromStringShapeDeserializer: () => FromStringShapeDeserializer,
  HttpBindingProtocol: () => HttpBindingProtocol,
  HttpInterceptingShapeDeserializer: () => HttpInterceptingShapeDeserializer,
  HttpInterceptingShapeSerializer: () => HttpInterceptingShapeSerializer,
  HttpProtocol: () => HttpProtocol,
  RequestBuilder: () => RequestBuilder,
  RpcProtocol: () => RpcProtocol,
  SerdeContext: () => SerdeContext,
  ToStringShapeSerializer: () => ToStringShapeSerializer,
  collectBody: () => collectBody,
  determineTimestampFormat: () => determineTimestampFormat,
  extendedEncodeURIComponent: () => extendedEncodeURIComponent,
  requestBuilder: () => requestBuilder,
  resolvedPath: () => resolvedPath
});
var init_protocols = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/protocols/index.js"() {
    init_collect_stream_body();
    init_extended_encode_uri_component();
    init_HttpBindingProtocol();
    init_HttpProtocol();
    init_RpcProtocol();
    init_requestBuilder();
    init_resolve_path();
    init_FromStringShapeDeserializer();
    init_HttpInterceptingShapeDeserializer();
    init_HttpInterceptingShapeSerializer();
    init_ToStringShapeSerializer();
    init_determineTimestampFormat();
    init_SerdeContext();
  }
});

// ../../node_modules/@smithy/core/dist-es/request-builder/requestBuilder.js
var init_requestBuilder2 = __esm({
  "../../node_modules/@smithy/core/dist-es/request-builder/requestBuilder.js"() {
    init_protocols();
  }
});

// ../../node_modules/@smithy/core/dist-es/setFeature.js
function setFeature(context, feature, value) {
  if (!context.__smithy_context) {
    context.__smithy_context = {
      features: {}
    };
  } else if (!context.__smithy_context.features) {
    context.__smithy_context.features = {};
  }
  context.__smithy_context.features[feature] = value;
}
var init_setFeature = __esm({
  "../../node_modules/@smithy/core/dist-es/setFeature.js"() {
    __name(setFeature, "setFeature");
  }
});

// ../../node_modules/@smithy/core/dist-es/util-identity-and-auth/DefaultIdentityProviderConfig.js
var DefaultIdentityProviderConfig;
var init_DefaultIdentityProviderConfig = __esm({
  "../../node_modules/@smithy/core/dist-es/util-identity-and-auth/DefaultIdentityProviderConfig.js"() {
    DefaultIdentityProviderConfig = class {
      static {
        __name(this, "DefaultIdentityProviderConfig");
      }
      authSchemes = /* @__PURE__ */ new Map();
      constructor(config2) {
        for (const key in config2) {
          const value = config2[key];
          if (value !== void 0) {
            this.authSchemes.set(key, value);
          }
        }
      }
      getIdentityProvider(schemeId) {
        return this.authSchemes.get(schemeId);
      }
    };
  }
});

// ../../node_modules/@smithy/core/dist-es/util-identity-and-auth/httpAuthSchemes/httpApiKeyAuth.js
var import_protocol_http7, import_types2, HttpApiKeyAuthSigner;
var init_httpApiKeyAuth = __esm({
  "../../node_modules/@smithy/core/dist-es/util-identity-and-auth/httpAuthSchemes/httpApiKeyAuth.js"() {
    import_protocol_http7 = __toESM(require_dist_cjs2());
    import_types2 = __toESM(require_dist_cjs());
    HttpApiKeyAuthSigner = class {
      static {
        __name(this, "HttpApiKeyAuthSigner");
      }
      async sign(httpRequest, identity, signingProperties) {
        if (!signingProperties) {
          throw new Error("request could not be signed with `apiKey` since the `name` and `in` signer properties are missing");
        }
        if (!signingProperties.name) {
          throw new Error("request could not be signed with `apiKey` since the `name` signer property is missing");
        }
        if (!signingProperties.in) {
          throw new Error("request could not be signed with `apiKey` since the `in` signer property is missing");
        }
        if (!identity.apiKey) {
          throw new Error("request could not be signed with `apiKey` since the `apiKey` is not defined");
        }
        const clonedRequest = import_protocol_http7.HttpRequest.clone(httpRequest);
        if (signingProperties.in === import_types2.HttpApiKeyAuthLocation.QUERY) {
          clonedRequest.query[signingProperties.name] = identity.apiKey;
        } else if (signingProperties.in === import_types2.HttpApiKeyAuthLocation.HEADER) {
          clonedRequest.headers[signingProperties.name] = signingProperties.scheme ? `${signingProperties.scheme} ${identity.apiKey}` : identity.apiKey;
        } else {
          throw new Error("request can only be signed with `apiKey` locations `query` or `header`, but found: `" + signingProperties.in + "`");
        }
        return clonedRequest;
      }
    };
  }
});

// ../../node_modules/@smithy/core/dist-es/util-identity-and-auth/httpAuthSchemes/httpBearerAuth.js
var import_protocol_http8, HttpBearerAuthSigner;
var init_httpBearerAuth = __esm({
  "../../node_modules/@smithy/core/dist-es/util-identity-and-auth/httpAuthSchemes/httpBearerAuth.js"() {
    import_protocol_http8 = __toESM(require_dist_cjs2());
    HttpBearerAuthSigner = class {
      static {
        __name(this, "HttpBearerAuthSigner");
      }
      async sign(httpRequest, identity, signingProperties) {
        const clonedRequest = import_protocol_http8.HttpRequest.clone(httpRequest);
        if (!identity.token) {
          throw new Error("request could not be signed with `token` since the `token` is not defined");
        }
        clonedRequest.headers["Authorization"] = `Bearer ${identity.token}`;
        return clonedRequest;
      }
    };
  }
});

// ../../node_modules/@smithy/core/dist-es/util-identity-and-auth/httpAuthSchemes/noAuth.js
var NoAuthSigner;
var init_noAuth = __esm({
  "../../node_modules/@smithy/core/dist-es/util-identity-and-auth/httpAuthSchemes/noAuth.js"() {
    NoAuthSigner = class {
      static {
        __name(this, "NoAuthSigner");
      }
      async sign(httpRequest, identity, signingProperties) {
        return httpRequest;
      }
    };
  }
});

// ../../node_modules/@smithy/core/dist-es/util-identity-and-auth/httpAuthSchemes/index.js
var init_httpAuthSchemes = __esm({
  "../../node_modules/@smithy/core/dist-es/util-identity-and-auth/httpAuthSchemes/index.js"() {
    init_httpApiKeyAuth();
    init_httpBearerAuth();
    init_noAuth();
  }
});

// ../../node_modules/@smithy/core/dist-es/util-identity-and-auth/memoizeIdentityProvider.js
var createIsIdentityExpiredFunction, EXPIRATION_MS, isIdentityExpired, doesIdentityRequireRefresh, memoizeIdentityProvider;
var init_memoizeIdentityProvider = __esm({
  "../../node_modules/@smithy/core/dist-es/util-identity-and-auth/memoizeIdentityProvider.js"() {
    createIsIdentityExpiredFunction = /* @__PURE__ */ __name((expirationMs) => /* @__PURE__ */ __name(function isIdentityExpired3(identity) {
      return doesIdentityRequireRefresh(identity) && identity.expiration.getTime() - Date.now() < expirationMs;
    }, "isIdentityExpired"), "createIsIdentityExpiredFunction");
    EXPIRATION_MS = 3e5;
    isIdentityExpired = createIsIdentityExpiredFunction(EXPIRATION_MS);
    doesIdentityRequireRefresh = /* @__PURE__ */ __name((identity) => identity.expiration !== void 0, "doesIdentityRequireRefresh");
    memoizeIdentityProvider = /* @__PURE__ */ __name((provider, isExpired, requiresRefresh) => {
      if (provider === void 0) {
        return void 0;
      }
      const normalizedProvider = typeof provider !== "function" ? async () => Promise.resolve(provider) : provider;
      let resolved;
      let pending;
      let hasResult;
      let isConstant = false;
      const coalesceProvider = /* @__PURE__ */ __name(async (options) => {
        if (!pending) {
          pending = normalizedProvider(options);
        }
        try {
          resolved = await pending;
          hasResult = true;
          isConstant = false;
        } finally {
          pending = void 0;
        }
        return resolved;
      }, "coalesceProvider");
      if (isExpired === void 0) {
        return async (options) => {
          if (!hasResult || options?.forceRefresh) {
            resolved = await coalesceProvider(options);
          }
          return resolved;
        };
      }
      return async (options) => {
        if (!hasResult || options?.forceRefresh) {
          resolved = await coalesceProvider(options);
        }
        if (isConstant) {
          return resolved;
        }
        if (!requiresRefresh(resolved)) {
          isConstant = true;
          return resolved;
        }
        if (isExpired(resolved)) {
          await coalesceProvider(options);
          return resolved;
        }
        return resolved;
      };
    }, "memoizeIdentityProvider");
  }
});

// ../../node_modules/@smithy/core/dist-es/util-identity-and-auth/index.js
var init_util_identity_and_auth = __esm({
  "../../node_modules/@smithy/core/dist-es/util-identity-and-auth/index.js"() {
    init_DefaultIdentityProviderConfig();
    init_httpAuthSchemes();
    init_memoizeIdentityProvider();
  }
});

// ../../node_modules/@smithy/core/dist-es/index.js
var dist_es_exports = {};
__export(dist_es_exports, {
  DefaultIdentityProviderConfig: () => DefaultIdentityProviderConfig,
  EXPIRATION_MS: () => EXPIRATION_MS,
  HttpApiKeyAuthSigner: () => HttpApiKeyAuthSigner,
  HttpBearerAuthSigner: () => HttpBearerAuthSigner,
  NoAuthSigner: () => NoAuthSigner,
  createIsIdentityExpiredFunction: () => createIsIdentityExpiredFunction,
  createPaginator: () => createPaginator,
  doesIdentityRequireRefresh: () => doesIdentityRequireRefresh,
  getHttpAuthSchemeEndpointRuleSetPlugin: () => getHttpAuthSchemeEndpointRuleSetPlugin,
  getHttpAuthSchemePlugin: () => getHttpAuthSchemePlugin,
  getHttpSigningPlugin: () => getHttpSigningPlugin,
  getSmithyContext: () => getSmithyContext,
  httpAuthSchemeEndpointRuleSetMiddlewareOptions: () => httpAuthSchemeEndpointRuleSetMiddlewareOptions,
  httpAuthSchemeMiddleware: () => httpAuthSchemeMiddleware,
  httpAuthSchemeMiddlewareOptions: () => httpAuthSchemeMiddlewareOptions,
  httpSigningMiddleware: () => httpSigningMiddleware,
  httpSigningMiddlewareOptions: () => httpSigningMiddlewareOptions,
  isIdentityExpired: () => isIdentityExpired,
  memoizeIdentityProvider: () => memoizeIdentityProvider,
  normalizeProvider: () => normalizeProvider,
  requestBuilder: () => requestBuilder,
  setFeature: () => setFeature
});
var init_dist_es = __esm({
  "../../node_modules/@smithy/core/dist-es/index.js"() {
    init_getSmithyContext();
    init_middleware_http_auth_scheme();
    init_middleware_http_signing();
    init_normalizeProvider();
    init_createPaginator();
    init_requestBuilder2();
    init_setFeature();
    init_util_identity_and_auth();
  }
});

// ../../node_modules/@smithy/util-endpoints/dist-cjs/index.js
var require_dist_cjs20 = __commonJS({
  "../../node_modules/@smithy/util-endpoints/dist-cjs/index.js"(exports2) {
    "use strict";
    var types2 = require_dist_cjs();
    var BinaryDecisionDiagram30 = class _BinaryDecisionDiagram {
      static {
        __name(this, "BinaryDecisionDiagram");
      }
      nodes;
      root;
      conditions;
      results;
      constructor(bdd32, root32, conditions, results) {
        this.nodes = bdd32;
        this.root = root32;
        this.conditions = conditions;
        this.results = results;
      }
      static from(bdd32, root32, conditions, results) {
        return new _BinaryDecisionDiagram(bdd32, root32, conditions, results);
      }
    };
    var EndpointCache30 = class {
      static {
        __name(this, "EndpointCache");
      }
      capacity;
      data = /* @__PURE__ */ new Map();
      parameters = [];
      constructor({ size, params }) {
        this.capacity = size ?? 50;
        if (params) {
          this.parameters = params;
        }
      }
      get(endpointParams, resolver) {
        const key = this.hash(endpointParams);
        if (key === false) {
          return resolver();
        }
        if (!this.data.has(key)) {
          if (this.data.size > this.capacity + 10) {
            const keys = this.data.keys();
            let i32 = 0;
            while (true) {
              const { value, done } = keys.next();
              this.data.delete(value);
              if (done || ++i32 > 10) {
                break;
              }
            }
          }
          this.data.set(key, resolver());
        }
        return this.data.get(key);
      }
      size() {
        return this.data.size;
      }
      hash(endpointParams) {
        let buffer = "";
        const { parameters } = this;
        if (parameters.length === 0) {
          return false;
        }
        for (const param of parameters) {
          const val = String(endpointParams[param] ?? "");
          if (val.includes("|;")) {
            return false;
          }
          buffer += val + "|;";
        }
        return buffer;
      }
    };
    var EndpointError3 = class extends Error {
      static {
        __name(this, "EndpointError");
      }
      constructor(message2) {
        super(message2);
        this.name = "EndpointError";
      }
    };
    var debugId3 = "endpoints";
    function toDebugString3(input) {
      if (typeof input !== "object" || input == null) {
        return input;
      }
      if ("ref" in input) {
        return `$${toDebugString3(input.ref)}`;
      }
      if ("fn" in input) {
        return `${input.fn}(${(input.argv || []).map(toDebugString3).join(", ")})`;
      }
      return JSON.stringify(input, null, 2);
    }
    __name(toDebugString3, "toDebugString");
    var customEndpointFunctions30 = {};
    var booleanEquals3 = /* @__PURE__ */ __name((value1, value2) => value1 === value2, "booleanEquals");
    function coalesce3(...args) {
      for (const arg of args) {
        if (arg != null) {
          return arg;
        }
      }
      return void 0;
    }
    __name(coalesce3, "coalesce");
    var getAttrPathList3 = /* @__PURE__ */ __name((path47) => {
      const parts = path47.split(".");
      const pathList = [];
      for (const part of parts) {
        const squareBracketIndex = part.indexOf("[");
        if (squareBracketIndex !== -1) {
          if (part.indexOf("]") !== part.length - 1) {
            throw new EndpointError3(`Path: '${path47}' does not end with ']'`);
          }
          const arrayIndex = part.slice(squareBracketIndex + 1, -1);
          if (Number.isNaN(parseInt(arrayIndex))) {
            throw new EndpointError3(`Invalid array index: '${arrayIndex}' in path: '${path47}'`);
          }
          if (squareBracketIndex !== 0) {
            pathList.push(part.slice(0, squareBracketIndex));
          }
          pathList.push(arrayIndex);
        } else {
          pathList.push(part);
        }
      }
      return pathList;
    }, "getAttrPathList");
    var getAttr3 = /* @__PURE__ */ __name((value, path47) => getAttrPathList3(path47).reduce((acc, index) => {
      if (typeof acc !== "object") {
        throw new EndpointError3(`Index '${index}' in '${path47}' not found in '${JSON.stringify(value)}'`);
      } else if (Array.isArray(acc)) {
        const i32 = parseInt(index);
        return acc[i32 < 0 ? acc.length + i32 : i32];
      }
      return acc[index];
    }, value), "getAttr");
    var isSet3 = /* @__PURE__ */ __name((value) => value != null, "isSet");
    var VALID_HOST_LABEL_REGEX4 = new RegExp(`^(?!.*-$)(?!-)[a-zA-Z0-9-]{1,63}$`);
    var isValidHostLabel4 = /* @__PURE__ */ __name((value, allowSubDomains = false) => {
      if (!allowSubDomains) {
        return VALID_HOST_LABEL_REGEX4.test(value);
      }
      const labels = value.split(".");
      for (const label of labels) {
        if (!isValidHostLabel4(label)) {
          return false;
        }
      }
      return true;
    }, "isValidHostLabel");
    function ite3(condition, trueValue, falseValue) {
      return condition ? trueValue : falseValue;
    }
    __name(ite3, "ite");
    var not3 = /* @__PURE__ */ __name((value) => !value, "not");
    var IP_V4_REGEX3 = new RegExp(`^(?:25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]\\d|\\d)(?:\\.(?:25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]\\d|\\d)){3}$`);
    var isIpAddress3 = /* @__PURE__ */ __name((value) => IP_V4_REGEX3.test(value) || value.startsWith("[") && value.endsWith("]"), "isIpAddress");
    var DEFAULT_PORTS3 = {
      [types2.EndpointURLScheme.HTTP]: 80,
      [types2.EndpointURLScheme.HTTPS]: 443
    };
    var parseURL3 = /* @__PURE__ */ __name((value) => {
      const whatwgURL = (() => {
        try {
          if (value instanceof URL) {
            return value;
          }
          if (typeof value === "object" && "hostname" in value) {
            const { hostname: hostname2, port, protocol: protocol2 = "", path: path47 = "", query = {} } = value;
            const url = new URL(`${protocol2}//${hostname2}${port ? `:${port}` : ""}${path47}`);
            url.search = Object.entries(query).map(([k32, v]) => `${k32}=${v}`).join("&");
            return url;
          }
          return new URL(value);
        } catch (error4) {
          return null;
        }
      })();
      if (!whatwgURL) {
        console.error(`Unable to parse ${JSON.stringify(value)} as a whatwg URL.`);
        return null;
      }
      const urlString = whatwgURL.href;
      const { host, hostname, pathname, protocol, search } = whatwgURL;
      if (search) {
        return null;
      }
      const scheme = protocol.slice(0, -1);
      if (!Object.values(types2.EndpointURLScheme).includes(scheme)) {
        return null;
      }
      const isIp = isIpAddress3(hostname);
      const inputContainsDefaultPort = urlString.includes(`${host}:${DEFAULT_PORTS3[scheme]}`) || typeof value === "string" && value.includes(`${host}:${DEFAULT_PORTS3[scheme]}`);
      const authority = `${host}${inputContainsDefaultPort ? `:${DEFAULT_PORTS3[scheme]}` : ``}`;
      return {
        scheme,
        authority,
        path: pathname,
        normalizedPath: pathname.endsWith("/") ? pathname : `${pathname}/`,
        isIp
      };
    }, "parseURL");
    function split4(value, delimiter2, limit) {
      if (limit === 1) {
        return [value];
      }
      if (value === "") {
        return [""];
      }
      const parts = value.split(delimiter2);
      if (limit === 0) {
        return parts;
      }
      return parts.slice(0, limit - 1).concat(parts.slice(1).join(delimiter2));
    }
    __name(split4, "split");
    var stringEquals3 = /* @__PURE__ */ __name((value1, value2) => value1 === value2, "stringEquals");
    var substring3 = /* @__PURE__ */ __name((input, start, stop, reverse) => {
      if (input == null || start >= stop || input.length < stop || /[^\u0000-\u007f]/.test(input)) {
        return null;
      }
      if (!reverse) {
        return input.substring(start, stop);
      }
      return input.substring(input.length - stop, input.length - start);
    }, "substring");
    var uriEncode3 = /* @__PURE__ */ __name((value) => encodeURIComponent(value).replace(/[!*'()]/g, (c32) => `%${c32.charCodeAt(0).toString(16).toUpperCase()}`), "uriEncode");
    var endpointFunctions3 = {
      booleanEquals: booleanEquals3,
      coalesce: coalesce3,
      getAttr: getAttr3,
      isSet: isSet3,
      isValidHostLabel: isValidHostLabel4,
      ite: ite3,
      not: not3,
      parseURL: parseURL3,
      split: split4,
      stringEquals: stringEquals3,
      substring: substring3,
      uriEncode: uriEncode3
    };
    var evaluateTemplate3 = /* @__PURE__ */ __name((template, options) => {
      const evaluatedTemplateArr = [];
      const { referenceRecord, endpointParams } = options;
      let currentIndex = 0;
      while (currentIndex < template.length) {
        const openingBraceIndex = template.indexOf("{", currentIndex);
        if (openingBraceIndex === -1) {
          evaluatedTemplateArr.push(template.slice(currentIndex));
          break;
        }
        evaluatedTemplateArr.push(template.slice(currentIndex, openingBraceIndex));
        const closingBraceIndex = template.indexOf("}", openingBraceIndex);
        if (closingBraceIndex === -1) {
          evaluatedTemplateArr.push(template.slice(openingBraceIndex));
          break;
        }
        if (template[openingBraceIndex + 1] === "{" && template[closingBraceIndex + 1] === "}") {
          evaluatedTemplateArr.push(template.slice(openingBraceIndex + 1, closingBraceIndex));
          currentIndex = closingBraceIndex + 2;
        }
        const parameterName = template.substring(openingBraceIndex + 1, closingBraceIndex);
        if (parameterName.includes("#")) {
          const [refName, attrName] = parameterName.split("#");
          evaluatedTemplateArr.push(getAttr3(referenceRecord[refName] ?? endpointParams[refName], attrName));
        } else {
          evaluatedTemplateArr.push(referenceRecord[parameterName] ?? endpointParams[parameterName]);
        }
        currentIndex = closingBraceIndex + 1;
      }
      return evaluatedTemplateArr.join("");
    }, "evaluateTemplate");
    var getReferenceValue3 = /* @__PURE__ */ __name(({ ref }, options) => {
      return options.referenceRecord[ref] ?? options.endpointParams[ref];
    }, "getReferenceValue");
    var evaluateExpression3 = /* @__PURE__ */ __name((obj, keyName, options) => {
      if (typeof obj === "string") {
        return evaluateTemplate3(obj, options);
      } else if (obj["fn"]) {
        return group$2.callFunction(obj, options);
      } else if (obj["ref"]) {
        return getReferenceValue3(obj, options);
      }
      throw new EndpointError3(`'${keyName}': ${String(obj)} is not a string, function or reference.`);
    }, "evaluateExpression");
    var callFunction3 = /* @__PURE__ */ __name(({ fn, argv }, options) => {
      const evaluatedArgs = Array(argv.length);
      for (let i32 = 0; i32 < evaluatedArgs.length; ++i32) {
        const arg = argv[i32];
        if (typeof arg === "boolean" || typeof arg === "number") {
          evaluatedArgs[i32] = arg;
        } else {
          evaluatedArgs[i32] = group$2.evaluateExpression(arg, "arg", options);
        }
      }
      const namespaceSeparatorIndex = fn.indexOf(".");
      if (namespaceSeparatorIndex !== -1) {
        const namespaceFunctions = customEndpointFunctions30[fn.slice(0, namespaceSeparatorIndex)];
        const customFunction = namespaceFunctions?.[fn.slice(namespaceSeparatorIndex + 1)];
        if (typeof customFunction === "function") {
          return customFunction(...evaluatedArgs);
        }
      }
      const callable = endpointFunctions3[fn];
      if (typeof callable === "function") {
        return callable(...evaluatedArgs);
      }
      throw new Error(`function ${fn} not loaded in endpointFunctions.`);
    }, "callFunction");
    var group$2 = {
      evaluateExpression: evaluateExpression3,
      callFunction: callFunction3
    };
    var evaluateCondition3 = /* @__PURE__ */ __name((condition, options) => {
      const { assign } = condition;
      if (assign && assign in options.referenceRecord) {
        throw new EndpointError3(`'${assign}' is already defined in Reference Record.`);
      }
      const value = callFunction3(condition, options);
      options.logger?.debug?.(`${debugId3} evaluateCondition: ${toDebugString3(condition)} = ${toDebugString3(value)}`);
      const result2 = value === "" ? true : !!value;
      if (assign != null) {
        return { result: result2, toAssign: { name: assign, value } };
      }
      return { result: result2 };
    }, "evaluateCondition");
    var getEndpointHeaders3 = /* @__PURE__ */ __name((headers, options) => Object.entries(headers ?? {}).reduce((acc, [headerKey, headerVal]) => {
      acc[headerKey] = headerVal.map((headerValEntry) => {
        const processedExpr = evaluateExpression3(headerValEntry, "Header value entry", options);
        if (typeof processedExpr !== "string") {
          throw new EndpointError3(`Header '${headerKey}' value '${processedExpr}' is not a string`);
        }
        return processedExpr;
      });
      return acc;
    }, {}), "getEndpointHeaders");
    var getEndpointProperties3 = /* @__PURE__ */ __name((properties, options) => Object.entries(properties).reduce((acc, [propertyKey, propertyVal]) => {
      acc[propertyKey] = group$1.getEndpointProperty(propertyVal, options);
      return acc;
    }, {}), "getEndpointProperties");
    var getEndpointProperty3 = /* @__PURE__ */ __name((property, options) => {
      if (Array.isArray(property)) {
        return property.map((propertyEntry) => getEndpointProperty3(propertyEntry, options));
      }
      switch (typeof property) {
        case "string":
          return evaluateTemplate3(property, options);
        case "object":
          if (property === null) {
            throw new EndpointError3(`Unexpected endpoint property: ${property}`);
          }
          return group$1.getEndpointProperties(property, options);
        case "boolean":
          return property;
        default:
          throw new EndpointError3(`Unexpected endpoint property type: ${typeof property}`);
      }
    }, "getEndpointProperty");
    var group$1 = {
      getEndpointProperty: getEndpointProperty3,
      getEndpointProperties: getEndpointProperties3
    };
    var getEndpointUrl3 = /* @__PURE__ */ __name((endpointUrl, options) => {
      const expression = evaluateExpression3(endpointUrl, "Endpoint URL", options);
      if (typeof expression === "string") {
        try {
          return new URL(expression);
        } catch (error4) {
          console.error(`Failed to construct URL with ${expression}`, error4);
          throw error4;
        }
      }
      throw new EndpointError3(`Endpoint URL must be a string, got ${typeof expression}`);
    }, "getEndpointUrl");
    var RESULT3 = 1e8;
    var decideEndpoint30 = /* @__PURE__ */ __name((bdd32, options) => {
      const { nodes: nodes32, root: root32, results, conditions } = bdd32;
      let ref = root32;
      const referenceRecord = {};
      const closure = {
        referenceRecord,
        endpointParams: options.endpointParams,
        logger: options.logger
      };
      while (ref !== 1 && ref !== -1 && ref < RESULT3) {
        const node_i = 3 * (Math.abs(ref) - 1);
        const [condition_i, highRef, lowRef] = [nodes32[node_i], nodes32[node_i + 1], nodes32[node_i + 2]];
        const [fn, argv, assign] = conditions[condition_i];
        const evaluation = evaluateCondition3({ fn, assign, argv }, closure);
        if (evaluation.toAssign) {
          const { name, value } = evaluation.toAssign;
          referenceRecord[name] = value;
        }
        ref = ref >= 0 === evaluation.result ? highRef : lowRef;
      }
      if (ref >= RESULT3) {
        const result2 = results[ref - RESULT3];
        if (result2[0] === -1) {
          const [, errorExpression] = result2;
          throw new EndpointError3(evaluateExpression3(errorExpression, "Error", closure));
        }
        const [url, properties, headers] = result2;
        return {
          url: getEndpointUrl3(url, closure),
          properties: getEndpointProperties3(properties, closure),
          headers: getEndpointHeaders3(headers ?? {}, closure)
        };
      }
      throw new EndpointError3(`No matching endpoint.`);
    }, "decideEndpoint");
    var evaluateConditions3 = /* @__PURE__ */ __name((conditions = [], options) => {
      const conditionsReferenceRecord = {};
      const conditionOptions = {
        ...options,
        referenceRecord: { ...options.referenceRecord }
      };
      let didAssign = false;
      for (const condition of conditions) {
        const { result: result2, toAssign } = evaluateCondition3(condition, conditionOptions);
        if (!result2) {
          return { result: result2 };
        }
        if (toAssign) {
          didAssign = true;
          conditionsReferenceRecord[toAssign.name] = toAssign.value;
          conditionOptions.referenceRecord[toAssign.name] = toAssign.value;
          options.logger?.debug?.(`${debugId3} assign: ${toAssign.name} := ${toDebugString3(toAssign.value)}`);
        }
      }
      if (didAssign) {
        return { result: true, referenceRecord: conditionsReferenceRecord };
      }
      return { result: true };
    }, "evaluateConditions");
    var evaluateEndpointRule3 = /* @__PURE__ */ __name((endpointRule, options) => {
      const { conditions, endpoint } = endpointRule;
      const { result: result2, referenceRecord } = evaluateConditions3(conditions, options);
      if (!result2) {
        return;
      }
      const endpointRuleOptions = referenceRecord ? {
        ...options,
        referenceRecord: { ...options.referenceRecord, ...referenceRecord }
      } : options;
      const { url, properties, headers } = endpoint;
      options.logger?.debug?.(`${debugId3} Resolving endpoint from template: ${toDebugString3(endpoint)}`);
      const endpointToReturn = { url: getEndpointUrl3(url, endpointRuleOptions) };
      if (headers != null) {
        endpointToReturn.headers = getEndpointHeaders3(headers, endpointRuleOptions);
      }
      if (properties != null) {
        endpointToReturn.properties = getEndpointProperties3(properties, endpointRuleOptions);
      }
      return endpointToReturn;
    }, "evaluateEndpointRule");
    var evaluateErrorRule3 = /* @__PURE__ */ __name((errorRule, options) => {
      const { conditions, error: error4 } = errorRule;
      const { result: result2, referenceRecord } = evaluateConditions3(conditions, options);
      if (!result2) {
        return;
      }
      const errorRuleOptions = referenceRecord ? {
        ...options,
        referenceRecord: { ...options.referenceRecord, ...referenceRecord }
      } : options;
      throw new EndpointError3(evaluateExpression3(error4, "Error", errorRuleOptions));
    }, "evaluateErrorRule");
    var evaluateRules3 = /* @__PURE__ */ __name((rules, options) => {
      for (const rule of rules) {
        if (rule.type === "endpoint") {
          const endpointOrUndefined = evaluateEndpointRule3(rule, options);
          if (endpointOrUndefined) {
            return endpointOrUndefined;
          }
        } else if (rule.type === "error") {
          evaluateErrorRule3(rule, options);
        } else if (rule.type === "tree") {
          const endpointOrUndefined = group7.evaluateTreeRule(rule, options);
          if (endpointOrUndefined) {
            return endpointOrUndefined;
          }
        } else {
          throw new EndpointError3(`Unknown endpoint rule: ${rule}`);
        }
      }
      throw new EndpointError3(`Rules evaluation failed`);
    }, "evaluateRules");
    var evaluateTreeRule3 = /* @__PURE__ */ __name((treeRule, options) => {
      const { conditions, rules } = treeRule;
      const { result: result2, referenceRecord } = evaluateConditions3(conditions, options);
      if (!result2) {
        return;
      }
      const treeRuleOptions = referenceRecord ? { ...options, referenceRecord: { ...options.referenceRecord, ...referenceRecord } } : options;
      return group7.evaluateRules(rules, treeRuleOptions);
    }, "evaluateTreeRule");
    var group7 = {
      evaluateRules: evaluateRules3,
      evaluateTreeRule: evaluateTreeRule3
    };
    var resolveEndpoint3 = /* @__PURE__ */ __name((ruleSetObject, options) => {
      const { endpointParams, logger: logger5 } = options;
      const { parameters, rules } = ruleSetObject;
      options.logger?.debug?.(`${debugId3} Initial EndpointParams: ${toDebugString3(endpointParams)}`);
      for (const paramKey in parameters) {
        const parameter = parameters[paramKey];
        const endpointParam = endpointParams[paramKey];
        if (endpointParam == null && parameter.default != null) {
          endpointParams[paramKey] = parameter.default;
          continue;
        }
        if (parameter.required && endpointParam == null) {
          throw new EndpointError3(`Missing required parameter: '${paramKey}'`);
        }
      }
      const endpoint = evaluateRules3(rules, { endpointParams, logger: logger5, referenceRecord: {} });
      options.logger?.debug?.(`${debugId3} Resolved endpoint: ${toDebugString3(endpoint)}`);
      return endpoint;
    }, "resolveEndpoint");
    exports2.BinaryDecisionDiagram = BinaryDecisionDiagram30;
    exports2.EndpointCache = EndpointCache30;
    exports2.EndpointError = EndpointError3;
    exports2.customEndpointFunctions = customEndpointFunctions30;
    exports2.decideEndpoint = decideEndpoint30;
    exports2.isIpAddress = isIpAddress3;
    exports2.isValidHostLabel = isValidHostLabel4;
    exports2.resolveEndpoint = resolveEndpoint3;
  }
});

// ../../node_modules/@aws-sdk/util-endpoints/dist-cjs/index.js
var require_dist_cjs21 = __commonJS({
  "../../node_modules/@aws-sdk/util-endpoints/dist-cjs/index.js"(exports2) {
    "use strict";
    var utilEndpoints = require_dist_cjs20();
    var urlParser = require_dist_cjs18();
    var isVirtualHostableS3Bucket2 = /* @__PURE__ */ __name((value, allowSubDomains = false) => {
      if (allowSubDomains) {
        for (const label of value.split(".")) {
          if (!isVirtualHostableS3Bucket2(label)) {
            return false;
          }
        }
        return true;
      }
      if (!utilEndpoints.isValidHostLabel(value)) {
        return false;
      }
      if (value.length < 3 || value.length > 63) {
        return false;
      }
      if (value !== value.toLowerCase()) {
        return false;
      }
      if (utilEndpoints.isIpAddress(value)) {
        return false;
      }
      return true;
    }, "isVirtualHostableS3Bucket");
    var ARN_DELIMITER2 = ":";
    var RESOURCE_DELIMITER2 = "/";
    var parseArn2 = /* @__PURE__ */ __name((value) => {
      const segments = value.split(ARN_DELIMITER2);
      if (segments.length < 6)
        return null;
      const [arn, partition5, service, region, accountId, ...resourcePath] = segments;
      if (arn !== "arn" || partition5 === "" || service === "" || resourcePath.join(ARN_DELIMITER2) === "")
        return null;
      const resourceId = resourcePath.map((resource) => resource.split(RESOURCE_DELIMITER2)).flat();
      return {
        partition: partition5,
        service,
        region,
        accountId,
        resourceId
      };
    }, "parseArn");
    var partitions = [
      {
        id: "aws",
        outputs: {
          dnsSuffix: "amazonaws.com",
          dualStackDnsSuffix: "api.aws",
          implicitGlobalRegion: "us-east-1",
          name: "aws",
          supportsDualStack: true,
          supportsFIPS: true
        },
        regionRegex: "^(us|eu|ap|sa|ca|me|af|il|mx)\\-\\w+\\-\\d+$",
        regions: {
          "af-south-1": {
            description: "Africa (Cape Town)"
          },
          "ap-east-1": {
            description: "Asia Pacific (Hong Kong)"
          },
          "ap-east-2": {
            description: "Asia Pacific (Taipei)"
          },
          "ap-northeast-1": {
            description: "Asia Pacific (Tokyo)"
          },
          "ap-northeast-2": {
            description: "Asia Pacific (Seoul)"
          },
          "ap-northeast-3": {
            description: "Asia Pacific (Osaka)"
          },
          "ap-south-1": {
            description: "Asia Pacific (Mumbai)"
          },
          "ap-south-2": {
            description: "Asia Pacific (Hyderabad)"
          },
          "ap-southeast-1": {
            description: "Asia Pacific (Singapore)"
          },
          "ap-southeast-2": {
            description: "Asia Pacific (Sydney)"
          },
          "ap-southeast-3": {
            description: "Asia Pacific (Jakarta)"
          },
          "ap-southeast-4": {
            description: "Asia Pacific (Melbourne)"
          },
          "ap-southeast-5": {
            description: "Asia Pacific (Malaysia)"
          },
          "ap-southeast-6": {
            description: "Asia Pacific (New Zealand)"
          },
          "ap-southeast-7": {
            description: "Asia Pacific (Thailand)"
          },
          "aws-global": {
            description: "aws global region"
          },
          "ca-central-1": {
            description: "Canada (Central)"
          },
          "ca-west-1": {
            description: "Canada West (Calgary)"
          },
          "eu-central-1": {
            description: "Europe (Frankfurt)"
          },
          "eu-central-2": {
            description: "Europe (Zurich)"
          },
          "eu-north-1": {
            description: "Europe (Stockholm)"
          },
          "eu-south-1": {
            description: "Europe (Milan)"
          },
          "eu-south-2": {
            description: "Europe (Spain)"
          },
          "eu-west-1": {
            description: "Europe (Ireland)"
          },
          "eu-west-2": {
            description: "Europe (London)"
          },
          "eu-west-3": {
            description: "Europe (Paris)"
          },
          "il-central-1": {
            description: "Israel (Tel Aviv)"
          },
          "me-central-1": {
            description: "Middle East (UAE)"
          },
          "me-south-1": {
            description: "Middle East (Bahrain)"
          },
          "mx-central-1": {
            description: "Mexico (Central)"
          },
          "sa-east-1": {
            description: "South America (Sao Paulo)"
          },
          "us-east-1": {
            description: "US East (N. Virginia)"
          },
          "us-east-2": {
            description: "US East (Ohio)"
          },
          "us-west-1": {
            description: "US West (N. California)"
          },
          "us-west-2": {
            description: "US West (Oregon)"
          }
        }
      },
      {
        id: "aws-cn",
        outputs: {
          dnsSuffix: "amazonaws.com.cn",
          dualStackDnsSuffix: "api.amazonwebservices.com.cn",
          implicitGlobalRegion: "cn-northwest-1",
          name: "aws-cn",
          supportsDualStack: true,
          supportsFIPS: true
        },
        regionRegex: "^cn\\-\\w+\\-\\d+$",
        regions: {
          "aws-cn-global": {
            description: "aws-cn global region"
          },
          "cn-north-1": {
            description: "China (Beijing)"
          },
          "cn-northwest-1": {
            description: "China (Ningxia)"
          }
        }
      },
      {
        id: "aws-eusc",
        outputs: {
          dnsSuffix: "amazonaws.eu",
          dualStackDnsSuffix: "api.amazonwebservices.eu",
          implicitGlobalRegion: "eusc-de-east-1",
          name: "aws-eusc",
          supportsDualStack: true,
          supportsFIPS: true
        },
        regionRegex: "^eusc\\-(de)\\-\\w+\\-\\d+$",
        regions: {
          "eusc-de-east-1": {
            description: "AWS European Sovereign Cloud (Germany)"
          }
        }
      },
      {
        id: "aws-iso",
        outputs: {
          dnsSuffix: "c2s.ic.gov",
          dualStackDnsSuffix: "api.aws.ic.gov",
          implicitGlobalRegion: "us-iso-east-1",
          name: "aws-iso",
          supportsDualStack: true,
          supportsFIPS: true
        },
        regionRegex: "^us\\-iso\\-\\w+\\-\\d+$",
        regions: {
          "aws-iso-global": {
            description: "aws-iso global region"
          },
          "us-iso-east-1": {
            description: "US ISO East"
          },
          "us-iso-west-1": {
            description: "US ISO WEST"
          }
        }
      },
      {
        id: "aws-iso-b",
        outputs: {
          dnsSuffix: "sc2s.sgov.gov",
          dualStackDnsSuffix: "api.aws.scloud",
          implicitGlobalRegion: "us-isob-east-1",
          name: "aws-iso-b",
          supportsDualStack: true,
          supportsFIPS: true
        },
        regionRegex: "^us\\-isob\\-\\w+\\-\\d+$",
        regions: {
          "aws-iso-b-global": {
            description: "aws-iso-b global region"
          },
          "us-isob-east-1": {
            description: "US ISOB East (Ohio)"
          },
          "us-isob-west-1": {
            description: "US ISOB West"
          }
        }
      },
      {
        id: "aws-iso-e",
        outputs: {
          dnsSuffix: "cloud.adc-e.uk",
          dualStackDnsSuffix: "api.cloud-aws.adc-e.uk",
          implicitGlobalRegion: "eu-isoe-west-1",
          name: "aws-iso-e",
          supportsDualStack: true,
          supportsFIPS: true
        },
        regionRegex: "^eu\\-isoe\\-\\w+\\-\\d+$",
        regions: {
          "aws-iso-e-global": {
            description: "aws-iso-e global region"
          },
          "eu-isoe-west-1": {
            description: "EU ISOE West"
          }
        }
      },
      {
        id: "aws-iso-f",
        outputs: {
          dnsSuffix: "csp.hci.ic.gov",
          dualStackDnsSuffix: "api.aws.hci.ic.gov",
          implicitGlobalRegion: "us-isof-south-1",
          name: "aws-iso-f",
          supportsDualStack: true,
          supportsFIPS: true
        },
        regionRegex: "^us\\-isof\\-\\w+\\-\\d+$",
        regions: {
          "aws-iso-f-global": {
            description: "aws-iso-f global region"
          },
          "us-isof-east-1": {
            description: "US ISOF EAST"
          },
          "us-isof-south-1": {
            description: "US ISOF SOUTH"
          }
        }
      },
      {
        id: "aws-us-gov",
        outputs: {
          dnsSuffix: "amazonaws.com",
          dualStackDnsSuffix: "api.aws",
          implicitGlobalRegion: "us-gov-west-1",
          name: "aws-us-gov",
          supportsDualStack: true,
          supportsFIPS: true
        },
        regionRegex: "^us\\-gov\\-\\w+\\-\\d+$",
        regions: {
          "aws-us-gov-global": {
            description: "aws-us-gov global region"
          },
          "us-gov-east-1": {
            description: "AWS GovCloud (US-East)"
          },
          "us-gov-west-1": {
            description: "AWS GovCloud (US-West)"
          }
        }
      }
    ];
    var version = "1.1";
    var partitionsInfo2 = {
      partitions,
      version
    };
    var selectedPartitionsInfo2 = partitionsInfo2;
    var selectedUserAgentPrefix2 = "";
    var partition4 = /* @__PURE__ */ __name((value) => {
      const { partitions: partitions2 } = selectedPartitionsInfo2;
      for (const partition5 of partitions2) {
        const { regions, outputs } = partition5;
        for (const [region, regionData] of Object.entries(regions)) {
          if (region === value) {
            return {
              ...outputs,
              ...regionData
            };
          }
        }
      }
      for (const partition5 of partitions2) {
        const { regionRegex, outputs } = partition5;
        if (new RegExp(regionRegex).test(value)) {
          return {
            ...outputs
          };
        }
      }
      const DEFAULT_PARTITION = partitions2.find((partition5) => partition5.id === "aws");
      if (!DEFAULT_PARTITION) {
        throw new Error("Provided region was not found in the partition array or regex, and default partition with id 'aws' doesn't exist.");
      }
      return {
        ...DEFAULT_PARTITION.outputs
      };
    }, "partition");
    var setPartitionInfo2 = /* @__PURE__ */ __name((partitionsInfo3, userAgentPrefix = "") => {
      selectedPartitionsInfo2 = partitionsInfo3;
      selectedUserAgentPrefix2 = userAgentPrefix;
    }, "setPartitionInfo");
    var useDefaultPartitionInfo2 = /* @__PURE__ */ __name(() => {
      setPartitionInfo2(partitionsInfo2, "");
    }, "useDefaultPartitionInfo");
    var getUserAgentPrefix2 = /* @__PURE__ */ __name(() => selectedUserAgentPrefix2, "getUserAgentPrefix");
    var awsEndpointFunctions29 = {
      isVirtualHostableS3Bucket: isVirtualHostableS3Bucket2,
      parseArn: parseArn2,
      partition: partition4
    };
    utilEndpoints.customEndpointFunctions.aws = awsEndpointFunctions29;
    var resolveDefaultAwsRegionalEndpointsConfig2 = /* @__PURE__ */ __name((input) => {
      if (typeof input.endpointProvider !== "function") {
        throw new Error("@aws-sdk/util-endpoint - endpointProvider and endpoint missing in config for this client.");
      }
      const { endpoint } = input;
      if (endpoint === void 0) {
        input.endpoint = async () => {
          return toEndpointV17(input.endpointProvider({
            Region: typeof input.region === "function" ? await input.region() : input.region,
            UseDualStack: typeof input.useDualstackEndpoint === "function" ? await input.useDualstackEndpoint() : input.useDualstackEndpoint,
            UseFIPS: typeof input.useFipsEndpoint === "function" ? await input.useFipsEndpoint() : input.useFipsEndpoint,
            Endpoint: void 0
          }, { logger: input.logger }));
        };
      }
      return input;
    }, "resolveDefaultAwsRegionalEndpointsConfig");
    var toEndpointV17 = /* @__PURE__ */ __name((endpoint) => urlParser.parseUrl(endpoint.url), "toEndpointV1");
    exports2.EndpointError = utilEndpoints.EndpointError;
    exports2.isIpAddress = utilEndpoints.isIpAddress;
    exports2.resolveEndpoint = utilEndpoints.resolveEndpoint;
    exports2.awsEndpointFunctions = awsEndpointFunctions29;
    exports2.getUserAgentPrefix = getUserAgentPrefix2;
    exports2.partition = partition4;
    exports2.resolveDefaultAwsRegionalEndpointsConfig = resolveDefaultAwsRegionalEndpointsConfig2;
    exports2.setPartitionInfo = setPartitionInfo2;
    exports2.toEndpointV1 = toEndpointV17;
    exports2.useDefaultPartitionInfo = useDefaultPartitionInfo2;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/client/emitWarningIfUnsupportedVersion.js
var state, emitWarningIfUnsupportedVersion;
var init_emitWarningIfUnsupportedVersion = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/client/emitWarningIfUnsupportedVersion.js"() {
    state = {
      warningEmitted: false
    };
    emitWarningIfUnsupportedVersion = /* @__PURE__ */ __name((version) => {
      if (version && !state.warningEmitted) {
        if (process.env.AWS_SDK_JS_NODE_VERSION_SUPPORT_WARNING_DISABLED === "true") {
          state.warningEmitted = true;
          return;
        }
        const userMajorVersion = parseInt(version.substring(1, version.indexOf(".")));
        const vv = 22;
        if (userMajorVersion < vv) {
          state.warningEmitted = true;
          process.emitWarning(`NodeVersionSupportWarning: The AWS SDK for JavaScript (v3)
versions published after the first week of January 2027
will require node >=${vv}. You are running node ${version}.

To continue receiving updates to AWS services, bug fixes,
and security updates please upgrade to node >=${vv}.

More information can be found at: https://a.co/c895JFp`);
        }
      }
    }, "emitWarningIfUnsupportedVersion");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/client/longPollMiddleware.js
var longPollMiddleware, longPollMiddlewareOptions, getLongPollPlugin;
var init_longPollMiddleware = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/client/longPollMiddleware.js"() {
    longPollMiddleware = /* @__PURE__ */ __name(() => (next, context) => async (args) => {
      context.__retryLongPoll = true;
      return next(args);
    }, "longPollMiddleware");
    longPollMiddlewareOptions = {
      name: "longPollMiddleware",
      tags: ["RETRY"],
      step: "initialize",
      override: true
    };
    getLongPollPlugin = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(longPollMiddleware(), longPollMiddlewareOptions);
      }, "applyToStack")
    }), "getLongPollPlugin");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/client/setCredentialFeature.js
function setCredentialFeature(credentials, feature, value) {
  if (!credentials.$source) {
    credentials.$source = {};
  }
  credentials.$source[feature] = value;
  return credentials;
}
var init_setCredentialFeature = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/client/setCredentialFeature.js"() {
    __name(setCredentialFeature, "setCredentialFeature");
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/isStreamingPayload/isStreamingPayload.js
var import_node_stream, isStreamingPayload;
var init_isStreamingPayload = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/isStreamingPayload/isStreamingPayload.js"() {
    import_node_stream = require("node:stream");
    isStreamingPayload = /* @__PURE__ */ __name((request4) => request4?.body instanceof import_node_stream.Readable || typeof ReadableStream !== "undefined" && request4?.body instanceof ReadableStream, "isStreamingPayload");
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/transport/httpRequest.js
function cloneQuery(query) {
  return Object.keys(query).reduce((carry, paramName) => {
    const param = query[paramName];
    return {
      ...carry,
      [paramName]: Array.isArray(param) ? [...param] : param
    };
  }, {});
}
var HttpRequest8;
var init_httpRequest = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/transport/httpRequest.js"() {
    HttpRequest8 = class _HttpRequest {
      static {
        __name(this, "HttpRequest");
      }
      method;
      protocol;
      hostname;
      port;
      path;
      query;
      headers;
      username;
      password;
      fragment;
      body;
      constructor(options) {
        this.method = options.method || "GET";
        this.hostname = options.hostname || "localhost";
        this.port = options.port;
        this.query = options.query || {};
        this.headers = options.headers || {};
        this.body = options.body;
        this.protocol = options.protocol ? options.protocol.slice(-1) !== ":" ? `${options.protocol}:` : options.protocol : "https:";
        this.path = options.path ? options.path.charAt(0) !== "/" ? `/${options.path}` : options.path : "/";
        this.username = options.username;
        this.password = options.password;
        this.fragment = options.fragment;
      }
      static clone(request4) {
        const cloned = new _HttpRequest({
          ...request4,
          headers: { ...request4.headers }
        });
        if (cloned.query) {
          cloned.query = cloneQuery(cloned.query);
        }
        return cloned;
      }
      static isInstance(request4) {
        if (!request4) {
          return false;
        }
        const req = request4;
        return "method" in req && "protocol" in req && "hostname" in req && "path" in req && typeof req["query"] === "object" && typeof req["headers"] === "object";
      }
      clone() {
        return _HttpRequest.clone(this);
      }
    };
    __name(cloneQuery, "cloneQuery");
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/transport/httpResponse.js
var HttpResponse3;
var init_httpResponse = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/transport/httpResponse.js"() {
    HttpResponse3 = class {
      static {
        __name(this, "HttpResponse");
      }
      statusCode;
      reason;
      headers;
      body;
      constructor(options) {
        this.statusCode = options.statusCode;
        this.reason = options.reason;
        this.headers = options.headers || {};
        this.body = options.body;
      }
      static isInstance(response) {
        if (!response)
          return false;
        const resp = response;
        return typeof resp.statusCode === "number" && typeof resp.headers === "object";
      }
    };
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/transport/normalizeProvider.js
var normalizeProvider2;
var init_normalizeProvider2 = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/transport/normalizeProvider.js"() {
    normalizeProvider2 = /* @__PURE__ */ __name((input) => {
      if (typeof input === "function")
        return input;
      const promisified = Promise.resolve(input);
      return () => promisified;
    }, "normalizeProvider");
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/transport/index.js
var init_transport = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/transport/index.js"() {
    init_httpRequest();
    init_httpResponse();
    init_normalizeProvider2();
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/NoOpLogger.js
var NoOpLogger;
var init_NoOpLogger = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/NoOpLogger.js"() {
    NoOpLogger = class {
      static {
        __name(this, "NoOpLogger");
      }
      trace() {
      }
      debug() {
      }
      info() {
      }
      warn() {
      }
      error() {
      }
    };
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/client/index.js
var init_client = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/client/index.js"() {
    init_transport();
    init_NoOpLogger();
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/serde/is-array-buffer/is-array-buffer.js
var isArrayBuffer;
var init_is_array_buffer = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/serde/is-array-buffer/is-array-buffer.js"() {
    isArrayBuffer = /* @__PURE__ */ __name((arg) => typeof ArrayBuffer === "function" && arg instanceof ArrayBuffer || Object.prototype.toString.call(arg) === "[object ArrayBuffer]", "isArrayBuffer");
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/serde/util-buffer-from/buffer-from.js
var fromArrayBuffer, fromString;
var init_buffer_from = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/serde/util-buffer-from/buffer-from.js"() {
    init_is_array_buffer();
    fromArrayBuffer = /* @__PURE__ */ __name((input, offset = 0, length = input.byteLength - offset) => {
      if (!isArrayBuffer(input)) {
        throw new TypeError(`The "input" argument must be ArrayBuffer. Received type ${typeof input} (${input})`);
      }
      return Buffer.from(input, offset, length);
    }, "fromArrayBuffer");
    fromString = /* @__PURE__ */ __name((input, encoding) => {
      if (typeof input !== "string") {
        throw new TypeError(`The "input" argument must be of type string. Received type ${typeof input} (${input})`);
      }
      return encoding ? Buffer.from(input, encoding) : Buffer.from(input);
    }, "fromString");
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/fromBase64.js
var BASE64_REGEX, fromBase642;
var init_fromBase64 = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/fromBase64.js"() {
    init_buffer_from();
    BASE64_REGEX = /^[A-Za-z0-9+/]*={0,2}$/;
    fromBase642 = /* @__PURE__ */ __name((input) => {
      if (input.length * 3 % 4 !== 0) {
        throw new TypeError(`Incorrect padding on base64 string.`);
      }
      if (!BASE64_REGEX.exec(input)) {
        throw new TypeError(`Invalid base64 string.`);
      }
      const buffer = fromString(input, "base64");
      return new Uint8Array(buffer.buffer, buffer.byteOffset, buffer.byteLength);
    }, "fromBase64");
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/fromUtf8.js
var fromUtf83;
var init_fromUtf8 = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/fromUtf8.js"() {
    init_buffer_from();
    fromUtf83 = /* @__PURE__ */ __name((input) => {
      const buf = fromString(input, "utf8");
      return new Uint8Array(buf.buffer, buf.byteOffset, buf.byteLength / Uint8Array.BYTES_PER_ELEMENT);
    }, "fromUtf8");
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/toBase64.js
var toBase642;
var init_toBase64 = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/toBase64.js"() {
    init_buffer_from();
    init_fromUtf8();
    toBase642 = /* @__PURE__ */ __name((_input) => {
      let input;
      if (typeof _input === "string") {
        input = fromUtf83(_input);
      } else {
        input = _input;
      }
      if (typeof input !== "object" || typeof input.byteOffset !== "number" || typeof input.byteLength !== "number") {
        throw new Error("@smithy/util-base64: toBase64 encoder function only accepts string | Uint8Array.");
      }
      return fromArrayBuffer(input.buffer, input.byteOffset, input.byteLength).toString("base64");
    }, "toBase64");
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/blob/Uint8ArrayBlobAdapter.js
function bindUint8ArrayBlobAdapter(toUtf862, fromUtf842, toBase6467, fromBase6459) {
  return class Uint8ArrayBlobAdapter8 extends Uint8Array {
    static {
      __name(this, "Uint8ArrayBlobAdapter");
    }
    static fromString(source, encoding = "utf-8") {
      if (typeof source === "string") {
        if (encoding === "base64") {
          return Uint8ArrayBlobAdapter8.mutate(fromBase6459(source));
        }
        return Uint8ArrayBlobAdapter8.mutate(fromUtf842(source));
      }
      throw new Error(`Unsupported conversion from ${typeof source} to Uint8ArrayBlobAdapter.`);
    }
    static mutate(source) {
      Object.setPrototypeOf(source, Uint8ArrayBlobAdapter8.prototype);
      return source;
    }
    transformToString(encoding = "utf-8") {
      if (encoding === "base64") {
        return toBase6467(this);
      }
      return toUtf862(this);
    }
  };
}
var init_Uint8ArrayBlobAdapter = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/blob/Uint8ArrayBlobAdapter.js"() {
    __name(bindUint8ArrayBlobAdapter, "bindUint8ArrayBlobAdapter");
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/toUtf8.js
var toUtf84;
var init_toUtf8 = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/toUtf8.js"() {
    init_buffer_from();
    toUtf84 = /* @__PURE__ */ __name((input) => {
      if (typeof input === "string") {
        return input;
      }
      if (typeof input !== "object" || typeof input.byteOffset !== "number" || typeof input.byteLength !== "number") {
        throw new Error("@smithy/util-utf8: toUtf8 encoder function only accepts string | Uint8Array.");
      }
      return fromArrayBuffer(input.buffer, input.byteOffset, input.byteLength).toString("utf8");
    }, "toUtf8");
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/serde/uuid/v4.js
function bindV4(getRandomValues7) {
  if (typeof crypto !== "undefined" && typeof crypto.randomUUID === "function") {
    return () => crypto.randomUUID();
  }
  return () => {
    const rnds = new Uint8Array(16);
    getRandomValues7(rnds);
    rnds[6] = rnds[6] & 15 | 64;
    rnds[8] = rnds[8] & 63 | 128;
    return decimalToHex[rnds[0]] + decimalToHex[rnds[1]] + decimalToHex[rnds[2]] + decimalToHex[rnds[3]] + "-" + decimalToHex[rnds[4]] + decimalToHex[rnds[5]] + "-" + decimalToHex[rnds[6]] + decimalToHex[rnds[7]] + "-" + decimalToHex[rnds[8]] + decimalToHex[rnds[9]] + "-" + decimalToHex[rnds[10]] + decimalToHex[rnds[11]] + decimalToHex[rnds[12]] + decimalToHex[rnds[13]] + decimalToHex[rnds[14]] + decimalToHex[rnds[15]];
  };
}
var decimalToHex;
var init_v4 = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/serde/uuid/v4.js"() {
    decimalToHex = Array.from({ length: 256 }, (_, i32) => i32.toString(16).padStart(2, "0"));
    __name(bindV4, "bindV4");
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/serde/parse-utils.js
var expectNumber2, MAX_FLOAT2, expectFloat322, expectLong2, expectShort2, expectByte2, expectSizedInt2, castInt2, strictParseFloat322, NUMBER_REGEX2, parseNumber2, strictParseShort2, strictParseByte2, stackTraceWarning2, logger2;
var init_parse_utils2 = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/serde/parse-utils.js"() {
    expectNumber2 = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      if (typeof value === "string") {
        const parsed = parseFloat(value);
        if (!Number.isNaN(parsed)) {
          if (String(parsed) !== String(value)) {
            logger2.warn(stackTraceWarning2(`Expected number but observed string: ${value}`));
          }
          return parsed;
        }
      }
      if (typeof value === "number") {
        return value;
      }
      throw new TypeError(`Expected number, got ${typeof value}: ${value}`);
    }, "expectNumber");
    MAX_FLOAT2 = Math.ceil(2 ** 127 * (2 - 2 ** -23));
    expectFloat322 = /* @__PURE__ */ __name((value) => {
      const expected = expectNumber2(value);
      if (expected !== void 0 && !Number.isNaN(expected) && expected !== Infinity && expected !== -Infinity) {
        if (Math.abs(expected) > MAX_FLOAT2) {
          throw new TypeError(`Expected 32-bit float, got ${value}`);
        }
      }
      return expected;
    }, "expectFloat32");
    expectLong2 = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      if (Number.isInteger(value) && !Number.isNaN(value)) {
        return value;
      }
      throw new TypeError(`Expected integer, got ${typeof value}: ${value}`);
    }, "expectLong");
    expectShort2 = /* @__PURE__ */ __name((value) => expectSizedInt2(value, 16), "expectShort");
    expectByte2 = /* @__PURE__ */ __name((value) => expectSizedInt2(value, 8), "expectByte");
    expectSizedInt2 = /* @__PURE__ */ __name((value, size) => {
      const expected = expectLong2(value);
      if (expected !== void 0 && castInt2(expected, size) !== expected) {
        throw new TypeError(`Expected ${size}-bit integer, got ${value}`);
      }
      return expected;
    }, "expectSizedInt");
    castInt2 = /* @__PURE__ */ __name((value, size) => {
      switch (size) {
        case 32:
          return Int32Array.of(value)[0];
        case 16:
          return Int16Array.of(value)[0];
        case 8:
          return Int8Array.of(value)[0];
      }
    }, "castInt");
    strictParseFloat322 = /* @__PURE__ */ __name((value) => {
      if (typeof value == "string") {
        return expectFloat322(parseNumber2(value));
      }
      return expectFloat322(value);
    }, "strictParseFloat32");
    NUMBER_REGEX2 = /(-?(?:0|[1-9]\d*)(?:\.\d+)?(?:[eE][+-]?\d+)?)|(-?Infinity)|(NaN)/g;
    parseNumber2 = /* @__PURE__ */ __name((value) => {
      const matches = value.match(NUMBER_REGEX2);
      if (matches === null || matches[0].length !== value.length) {
        throw new TypeError(`Expected real number, got implicit NaN`);
      }
      return parseFloat(value);
    }, "parseNumber");
    strictParseShort2 = /* @__PURE__ */ __name((value) => {
      if (typeof value === "string") {
        return expectShort2(parseNumber2(value));
      }
      return expectShort2(value);
    }, "strictParseShort");
    strictParseByte2 = /* @__PURE__ */ __name((value) => {
      if (typeof value === "string") {
        return expectByte2(parseNumber2(value));
      }
      return expectByte2(value);
    }, "strictParseByte");
    stackTraceWarning2 = /* @__PURE__ */ __name((message2) => {
      return String(new TypeError(message2).stack || message2).split("\n").slice(0, 5).filter((s) => !s.includes("stackTraceWarning")).join("\n");
    }, "stackTraceWarning");
    logger2 = {
      warn: console.warn
    };
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/serde/date-utils.js
var MONTHS2, RFC33392, RFC3339_WITH_OFFSET3, IMF_FIXDATE3, RFC_850_DATE3, ASC_TIME3, parseRfc7231DateTime2, buildDate2, parseTwoDigitYear2, FIFTY_YEARS_IN_MILLIS2, adjustRfc850Year2, parseMonthByShortName2, DAYS_IN_MONTH2, validateDayOfMonth2, isLeapYear2, parseDateValue2, parseMilliseconds2, stripLeadingZeroes2;
var init_date_utils2 = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/serde/date-utils.js"() {
    init_parse_utils2();
    MONTHS2 = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"];
    RFC33392 = new RegExp(/^(\d{4})-(\d{2})-(\d{2})[tT](\d{2}):(\d{2}):(\d{2})(?:\.(\d+))?[zZ]$/);
    RFC3339_WITH_OFFSET3 = new RegExp(/^(\d{4})-(\d{2})-(\d{2})[tT](\d{2}):(\d{2}):(\d{2})(?:\.(\d+))?(([-+]\d{2}\:\d{2})|[zZ])$/);
    IMF_FIXDATE3 = new RegExp(/^(?:Mon|Tue|Wed|Thu|Fri|Sat|Sun), (\d{2}) (Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec) (\d{4}) (\d{1,2}):(\d{2}):(\d{2})(?:\.(\d+))? GMT$/);
    RFC_850_DATE3 = new RegExp(/^(?:Monday|Tuesday|Wednesday|Thursday|Friday|Saturday|Sunday), (\d{2})-(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)-(\d{2}) (\d{1,2}):(\d{2}):(\d{2})(?:\.(\d+))? GMT$/);
    ASC_TIME3 = new RegExp(/^(?:Mon|Tue|Wed|Thu|Fri|Sat|Sun) (Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec) ( [1-9]|\d{2}) (\d{1,2}):(\d{2}):(\d{2})(?:\.(\d+))? (\d{4})$/);
    parseRfc7231DateTime2 = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      if (typeof value !== "string") {
        throw new TypeError("RFC-7231 date-times must be expressed as strings");
      }
      let match = IMF_FIXDATE3.exec(value);
      if (match) {
        const [_, dayStr, monthStr, yearStr, hours, minutes, seconds, fractionalMilliseconds] = match;
        return buildDate2(strictParseShort2(stripLeadingZeroes2(yearStr)), parseMonthByShortName2(monthStr), parseDateValue2(dayStr, "day", 1, 31), { hours, minutes, seconds, fractionalMilliseconds });
      }
      match = RFC_850_DATE3.exec(value);
      if (match) {
        const [_, dayStr, monthStr, yearStr, hours, minutes, seconds, fractionalMilliseconds] = match;
        return adjustRfc850Year2(buildDate2(parseTwoDigitYear2(yearStr), parseMonthByShortName2(monthStr), parseDateValue2(dayStr, "day", 1, 31), {
          hours,
          minutes,
          seconds,
          fractionalMilliseconds
        }));
      }
      match = ASC_TIME3.exec(value);
      if (match) {
        const [_, monthStr, dayStr, hours, minutes, seconds, fractionalMilliseconds, yearStr] = match;
        return buildDate2(strictParseShort2(stripLeadingZeroes2(yearStr)), parseMonthByShortName2(monthStr), parseDateValue2(dayStr.trimLeft(), "day", 1, 31), { hours, minutes, seconds, fractionalMilliseconds });
      }
      throw new TypeError("Invalid RFC-7231 date-time value");
    }, "parseRfc7231DateTime");
    buildDate2 = /* @__PURE__ */ __name((year7, month, day, time7) => {
      const adjustedMonth = month - 1;
      validateDayOfMonth2(year7, adjustedMonth, day);
      return new Date(Date.UTC(year7, adjustedMonth, day, parseDateValue2(time7.hours, "hour", 0, 23), parseDateValue2(time7.minutes, "minute", 0, 59), parseDateValue2(time7.seconds, "seconds", 0, 60), parseMilliseconds2(time7.fractionalMilliseconds)));
    }, "buildDate");
    parseTwoDigitYear2 = /* @__PURE__ */ __name((value) => {
      const thisYear = (/* @__PURE__ */ new Date()).getUTCFullYear();
      const valueInThisCentury = Math.floor(thisYear / 100) * 100 + strictParseShort2(stripLeadingZeroes2(value));
      if (valueInThisCentury < thisYear) {
        return valueInThisCentury + 100;
      }
      return valueInThisCentury;
    }, "parseTwoDigitYear");
    FIFTY_YEARS_IN_MILLIS2 = 50 * 365 * 24 * 60 * 60 * 1e3;
    adjustRfc850Year2 = /* @__PURE__ */ __name((input) => {
      if (input.getTime() - (/* @__PURE__ */ new Date()).getTime() > FIFTY_YEARS_IN_MILLIS2) {
        return new Date(Date.UTC(input.getUTCFullYear() - 100, input.getUTCMonth(), input.getUTCDate(), input.getUTCHours(), input.getUTCMinutes(), input.getUTCSeconds(), input.getUTCMilliseconds()));
      }
      return input;
    }, "adjustRfc850Year");
    parseMonthByShortName2 = /* @__PURE__ */ __name((value) => {
      const monthIdx = MONTHS2.indexOf(value);
      if (monthIdx < 0) {
        throw new TypeError(`Invalid month: ${value}`);
      }
      return monthIdx + 1;
    }, "parseMonthByShortName");
    DAYS_IN_MONTH2 = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];
    validateDayOfMonth2 = /* @__PURE__ */ __name((year7, month, day) => {
      let maxDays = DAYS_IN_MONTH2[month];
      if (month === 1 && isLeapYear2(year7)) {
        maxDays = 29;
      }
      if (day > maxDays) {
        throw new TypeError(`Invalid day for ${MONTHS2[month]} in ${year7}: ${day}`);
      }
    }, "validateDayOfMonth");
    isLeapYear2 = /* @__PURE__ */ __name((year7) => {
      return year7 % 4 === 0 && (year7 % 100 !== 0 || year7 % 400 === 0);
    }, "isLeapYear");
    parseDateValue2 = /* @__PURE__ */ __name((value, type, lower, upper) => {
      const dateVal = strictParseByte2(stripLeadingZeroes2(value));
      if (dateVal < lower || dateVal > upper) {
        throw new TypeError(`${type} must be between ${lower} and ${upper}, inclusive`);
      }
      return dateVal;
    }, "parseDateValue");
    parseMilliseconds2 = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return 0;
      }
      return strictParseFloat322("0." + value) * 1e3;
    }, "parseMilliseconds");
    stripLeadingZeroes2 = /* @__PURE__ */ __name((value) => {
      let idx = 0;
      while (idx < value.length - 1 && value.charAt(idx) === "0") {
        idx++;
      }
      if (idx === 0) {
        return value;
      }
      return value.slice(idx);
    }, "stripLeadingZeroes");
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/serde/index.js
var import_node_crypto, Uint8ArrayBlobAdapter2, _getRandomValues, v4;
var init_serde2 = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/serde/index.js"() {
    import_node_crypto = require("node:crypto");
    init_fromBase64();
    init_toBase64();
    init_Uint8ArrayBlobAdapter();
    init_fromUtf8();
    init_toUtf8();
    init_v4();
    init_date_utils2();
    Uint8ArrayBlobAdapter2 = class extends bindUint8ArrayBlobAdapter(toUtf84, fromUtf83, toBase642, fromBase642) {
      static {
        __name(this, "Uint8ArrayBlobAdapter");
      }
    };
    _getRandomValues = import_node_crypto.getRandomValues;
    v4 = bindV4(_getRandomValues);
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/protocols/collect-stream-body.js
var init_collect_stream_body2 = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/protocols/collect-stream-body.js"() {
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/protocols/extended-encode-uri-component.js
var init_extended_encode_uri_component2 = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/protocols/extended-encode-uri-component.js"() {
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/protocols/SerdeContext.js
var init_SerdeContext2 = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/protocols/SerdeContext.js"() {
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/protocols/HttpProtocol.js
var init_HttpProtocol2 = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/protocols/HttpProtocol.js"() {
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/protocols/HttpBindingProtocol.js
var init_HttpBindingProtocol2 = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/protocols/HttpBindingProtocol.js"() {
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/protocols/RpcProtocol.js
var init_RpcProtocol2 = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/protocols/RpcProtocol.js"() {
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/protocols/resolve-path.js
var init_resolve_path2 = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/protocols/resolve-path.js"() {
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/protocols/requestBuilder.js
var init_requestBuilder3 = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/protocols/requestBuilder.js"() {
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/protocols/serde/determineTimestampFormat.js
var init_determineTimestampFormat2 = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/protocols/serde/determineTimestampFormat.js"() {
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/protocols/serde/FromStringShapeDeserializer.js
var init_FromStringShapeDeserializer2 = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/protocols/serde/FromStringShapeDeserializer.js"() {
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/protocols/serde/HttpInterceptingShapeDeserializer.js
var init_HttpInterceptingShapeDeserializer2 = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/protocols/serde/HttpInterceptingShapeDeserializer.js"() {
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/protocols/serde/ToStringShapeSerializer.js
var init_ToStringShapeSerializer2 = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/protocols/serde/ToStringShapeSerializer.js"() {
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/protocols/serde/HttpInterceptingShapeSerializer.js
var init_HttpInterceptingShapeSerializer2 = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/protocols/serde/HttpInterceptingShapeSerializer.js"() {
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/protocols/index.js
var init_protocols2 = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/protocols/index.js"() {
    init_collect_stream_body2();
    init_extended_encode_uri_component2();
    init_HttpBindingProtocol2();
    init_HttpProtocol2();
    init_RpcProtocol2();
    init_requestBuilder3();
    init_resolve_path2();
    init_FromStringShapeDeserializer2();
    init_HttpInterceptingShapeDeserializer2();
    init_HttpInterceptingShapeSerializer2();
    init_ToStringShapeSerializer2();
    init_determineTimestampFormat2();
    init_SerdeContext2();
    init_transport();
    init_transport();
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/service-error-classification/constants.js
var CLOCK_SKEW_ERROR_CODES, THROTTLING_ERROR_CODES, TRANSIENT_ERROR_CODES, TRANSIENT_ERROR_STATUS_CODES, NODEJS_TIMEOUT_ERROR_CODES, NODEJS_NETWORK_ERROR_CODES;
var init_constants = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/service-error-classification/constants.js"() {
    CLOCK_SKEW_ERROR_CODES = [
      "AuthFailure",
      "InvalidSignatureException",
      "RequestExpired",
      "RequestInTheFuture",
      "RequestTimeTooSkewed",
      "SignatureDoesNotMatch"
    ];
    THROTTLING_ERROR_CODES = [
      "BandwidthLimitExceeded",
      "EC2ThrottledException",
      "LimitExceededException",
      "PriorRequestNotComplete",
      "ProvisionedThroughputExceededException",
      "RequestLimitExceeded",
      "RequestThrottled",
      "RequestThrottledException",
      "SlowDown",
      "ThrottledException",
      "Throttling",
      "ThrottlingException",
      "TooManyRequestsException",
      "TransactionInProgressException"
    ];
    TRANSIENT_ERROR_CODES = ["TimeoutError", "RequestTimeout", "RequestTimeoutException"];
    TRANSIENT_ERROR_STATUS_CODES = [500, 502, 503, 504];
    NODEJS_TIMEOUT_ERROR_CODES = ["ECONNRESET", "ECONNREFUSED", "EPIPE", "ETIMEDOUT"];
    NODEJS_NETWORK_ERROR_CODES = ["EHOSTUNREACH", "ENETUNREACH", "ENOTFOUND", "EAI_AGAIN"];
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/service-error-classification/service-error-classification.js
function isNodeJsHttp2TransientError(error4) {
  return error4.code === "ERR_HTTP2_STREAM_ERROR" && error4.message.includes("NGHTTP2_REFUSED_STREAM");
}
var isRetryableByTrait, isClockSkewError, isClockSkewCorrectedError, isBrowserNetworkError, isThrottlingError, isTransientError, isServerError;
var init_service_error_classification = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/service-error-classification/service-error-classification.js"() {
    init_constants();
    isRetryableByTrait = /* @__PURE__ */ __name((error4) => error4?.$retryable !== void 0, "isRetryableByTrait");
    isClockSkewError = /* @__PURE__ */ __name((error4) => CLOCK_SKEW_ERROR_CODES.includes(error4.name), "isClockSkewError");
    isClockSkewCorrectedError = /* @__PURE__ */ __name((error4) => error4.$metadata?.clockSkewCorrected, "isClockSkewCorrectedError");
    isBrowserNetworkError = /* @__PURE__ */ __name((error4) => {
      const errorMessages = /* @__PURE__ */ new Set([
        "Failed to fetch",
        "NetworkError when attempting to fetch resource",
        "The Internet connection appears to be offline",
        "Load failed",
        "Network request failed"
      ]);
      const isValid = error4 && error4 instanceof TypeError;
      if (!isValid) {
        return false;
      }
      return errorMessages.has(error4.message);
    }, "isBrowserNetworkError");
    isThrottlingError = /* @__PURE__ */ __name((error4) => error4.$metadata?.httpStatusCode === 429 || THROTTLING_ERROR_CODES.includes(error4.name) || error4.$retryable?.throttling == true, "isThrottlingError");
    isTransientError = /* @__PURE__ */ __name((error4, depth = 0) => isRetryableByTrait(error4) || isClockSkewCorrectedError(error4) || error4.name === "InvalidSignatureException" && error4.message?.includes("Signature expired") || TRANSIENT_ERROR_CODES.includes(error4.name) || NODEJS_TIMEOUT_ERROR_CODES.includes(error4?.code || "") || NODEJS_NETWORK_ERROR_CODES.includes(error4?.code || "") || TRANSIENT_ERROR_STATUS_CODES.includes(error4.$metadata?.httpStatusCode || 0) || isBrowserNetworkError(error4) || isNodeJsHttp2TransientError(error4) || error4.cause !== void 0 && depth <= 10 && isTransientError(error4.cause, depth + 1), "isTransientError");
    isServerError = /* @__PURE__ */ __name((error4) => {
      if (error4.$metadata?.httpStatusCode !== void 0) {
        const statusCode = error4.$metadata.httpStatusCode;
        if (500 <= statusCode && statusCode <= 599 && !isTransientError(error4)) {
          return true;
        }
        return false;
      }
      return false;
    }, "isServerError");
    __name(isNodeJsHttp2TransientError, "isNodeJsHttp2TransientError");
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/constants.js
var DEFAULT_RETRY_DELAY_BASE, MAXIMUM_RETRY_DELAY, THROTTLING_RETRY_DELAY_BASE, INITIAL_RETRY_TOKENS, RETRY_COST, TIMEOUT_RETRY_COST, NO_RETRY_INCREMENT, INVOCATION_ID_HEADER, REQUEST_HEADER;
var init_constants2 = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/constants.js"() {
    DEFAULT_RETRY_DELAY_BASE = 100;
    MAXIMUM_RETRY_DELAY = 20 * 1e3;
    THROTTLING_RETRY_DELAY_BASE = 500;
    INITIAL_RETRY_TOKENS = 500;
    RETRY_COST = 5;
    TIMEOUT_RETRY_COST = 10;
    NO_RETRY_INCREMENT = 1;
    INVOCATION_ID_HEADER = "amz-sdk-invocation-id";
    REQUEST_HEADER = "amz-sdk-request";
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/parseRetryAfterHeader.js
function parseRetryAfterHeader(response, logger5) {
  if (!HttpResponse3.isInstance(response)) {
    return;
  }
  for (const header of Object.keys(response.headers)) {
    const h32 = header.toLowerCase();
    if (h32 === "retry-after") {
      const retryAfter = response.headers[header];
      let retryAfterSeconds = NaN;
      if (retryAfter.endsWith("GMT")) {
        try {
          const date7 = parseRfc7231DateTime2(retryAfter);
          retryAfterSeconds = (date7.getTime() - Date.now()) / 1e3;
        } catch (e32) {
          logger5?.trace?.("Failed to parse retry-after header");
          logger5?.trace?.(e32);
        }
      } else if (retryAfter.match(/ GMT, ((\d+)|(\d+\.\d+))$/)) {
        retryAfterSeconds = Number(retryAfter.match(/ GMT, ([\d.]+)$/)?.[1]);
      } else if (retryAfter.match(/^((\d+)|(\d+\.\d+))$/)) {
        retryAfterSeconds = Number(retryAfter);
      } else if (Date.parse(retryAfter) >= Date.now()) {
        retryAfterSeconds = (Date.parse(retryAfter) - Date.now()) / 1e3;
      }
      if (isNaN(retryAfterSeconds)) {
        return;
      }
      return new Date(Date.now() + retryAfterSeconds * 1e3);
    } else if (h32 === "x-amz-retry-after") {
      const v = response.headers[header];
      const backoffMilliseconds = Number(v);
      if (isNaN(backoffMilliseconds)) {
        logger5?.trace?.(`Failed to parse x-amz-retry-after=${v}`);
        return;
      }
      return new Date(Date.now() + backoffMilliseconds);
    }
  }
}
function getRetryAfterHint(response, logger5) {
  return parseRetryAfterHeader(response, logger5);
}
var init_parseRetryAfterHeader = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/parseRetryAfterHeader.js"() {
    init_protocols2();
    init_serde2();
    __name(parseRetryAfterHeader, "parseRetryAfterHeader");
    __name(getRetryAfterHint, "getRetryAfterHint");
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/util.js
var asSdkError;
var init_util2 = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/util.js"() {
    asSdkError = /* @__PURE__ */ __name((error4) => {
      if (error4 instanceof Error)
        return error4;
      if (error4 instanceof Object)
        return Object.assign(new Error(), error4);
      if (typeof error4 === "string")
        return new Error(error4);
      return new Error(`AWS SDK error wrapper for ${error4}`);
    }, "asSdkError");
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/retryMiddleware.js
function bindRetryMiddleware(isStreamingPayload3) {
  return (options) => (next, context) => async (args) => {
    let retryStrategy = await options.retryStrategy();
    const maxAttempts = await options.maxAttempts();
    if (isRetryStrategyV2(retryStrategy)) {
      retryStrategy = retryStrategy;
      let retryToken = await retryStrategy.acquireInitialRetryToken((context["partition_id"] ?? "") + (context.__retryLongPoll ? ":longpoll" : ""));
      let lastError = new Error();
      let attempts = 0;
      let totalRetryDelay = 0;
      const { request: request4 } = args;
      const isRequest = HttpRequest8.isInstance(request4);
      if (isRequest) {
        request4.headers[INVOCATION_ID_HEADER] = v4();
      }
      while (true) {
        try {
          if (isRequest) {
            request4.headers[REQUEST_HEADER] = `attempt=${attempts + 1}; max=${maxAttempts}`;
          }
          const { response, output } = await next(args);
          retryStrategy.recordSuccess(retryToken);
          output.$metadata.attempts = attempts + 1;
          output.$metadata.totalRetryDelay = totalRetryDelay;
          return { response, output };
        } catch (e32) {
          const retryErrorInfo = getRetryErrorInfo(e32, options.logger);
          lastError = asSdkError(e32);
          if (isRequest && isStreamingPayload3(request4)) {
            (context.logger instanceof NoOpLogger ? console : context.logger)?.warn("An error was encountered in a non-retryable streaming request.");
            throw lastError;
          }
          try {
            retryToken = await retryStrategy.refreshRetryTokenForRetry(retryToken, retryErrorInfo);
          } catch (refreshError) {
            if (!lastError.$metadata) {
              lastError.$metadata = {};
            }
            lastError.$metadata.attempts = attempts + 1;
            lastError.$metadata.totalRetryDelay = totalRetryDelay;
            throw lastError;
          }
          attempts = retryToken.getRetryCount();
          const delay = retryToken.getRetryDelay();
          totalRetryDelay += (retryToken?.$retryLog?.acquisitionDelay ?? 0) + delay;
          if (delay > 0) {
            await cooldown(delay);
          }
        }
      }
    } else {
      retryStrategy = retryStrategy;
      if (retryStrategy?.mode) {
        context.userAgent = [...context.userAgent || [], ["cfg/retry-mode", retryStrategy.mode]];
      }
      return retryStrategy.retry(next, args);
    }
  };
}
function bindGetRetryPlugin(isStreamingPayload3) {
  const retryMiddleware3 = bindRetryMiddleware(isStreamingPayload3);
  return (options) => ({
    applyToStack: /* @__PURE__ */ __name((clientStack) => {
      clientStack.add(retryMiddleware3(options), retryMiddlewareOptions);
    }, "applyToStack")
  });
}
var cooldown, isRetryStrategyV2, getRetryErrorInfo, getRetryErrorType, retryMiddlewareOptions;
var init_retryMiddleware = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/retryMiddleware.js"() {
    init_client();
    init_protocols2();
    init_serde2();
    init_service_error_classification();
    init_constants2();
    init_parseRetryAfterHeader();
    init_util2();
    __name(bindRetryMiddleware, "bindRetryMiddleware");
    cooldown = /* @__PURE__ */ __name((ms) => new Promise((resolve13) => setTimeout(resolve13, ms)), "cooldown");
    isRetryStrategyV2 = /* @__PURE__ */ __name((retryStrategy) => typeof retryStrategy.acquireInitialRetryToken !== "undefined" && typeof retryStrategy.refreshRetryTokenForRetry !== "undefined" && typeof retryStrategy.recordSuccess !== "undefined", "isRetryStrategyV2");
    getRetryErrorInfo = /* @__PURE__ */ __name((error4, logger5) => {
      const errorInfo = {
        error: error4,
        errorType: getRetryErrorType(error4)
      };
      const retryAfterHint = parseRetryAfterHeader(error4.$response, logger5);
      if (retryAfterHint) {
        errorInfo.retryAfterHint = retryAfterHint;
      }
      return errorInfo;
    }, "getRetryErrorInfo");
    getRetryErrorType = /* @__PURE__ */ __name((error4) => {
      if (isThrottlingError(error4))
        return "THROTTLING";
      if (isTransientError(error4))
        return "TRANSIENT";
      if (isServerError(error4))
        return "SERVER_ERROR";
      return "CLIENT_ERROR";
    }, "getRetryErrorType");
    retryMiddlewareOptions = {
      name: "retryMiddleware",
      tags: ["RETRY"],
      step: "finalizeRequest",
      priority: "high",
      override: true
    };
    __name(bindGetRetryPlugin, "bindGetRetryPlugin");
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/DefaultRateLimiter.js
var DefaultRateLimiter;
var init_DefaultRateLimiter = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/DefaultRateLimiter.js"() {
    init_service_error_classification();
    DefaultRateLimiter = class _DefaultRateLimiter {
      static {
        __name(this, "DefaultRateLimiter");
      }
      static setTimeoutFn = setTimeout;
      beta;
      minCapacity;
      minFillRate;
      scaleConstant;
      smooth;
      enabled = false;
      availableTokens = 0;
      lastMaxRate = 0;
      measuredTxRate = 0;
      requestCount = 0;
      fillRate;
      lastThrottleTime;
      lastTimestamp = 0;
      lastTxRateBucket;
      maxCapacity;
      timeWindow = 0;
      constructor(options) {
        this.beta = options?.beta ?? 0.7;
        this.minCapacity = options?.minCapacity ?? 1;
        this.minFillRate = options?.minFillRate ?? 0.5;
        this.scaleConstant = options?.scaleConstant ?? 0.4;
        this.smooth = options?.smooth ?? 0.8;
        this.lastThrottleTime = this.getCurrentTimeInSeconds();
        this.lastTxRateBucket = Math.floor(this.getCurrentTimeInSeconds());
        this.fillRate = this.minFillRate;
        this.maxCapacity = this.minCapacity;
      }
      async getSendToken() {
        return this.acquireTokenBucket(1);
      }
      updateClientSendingRate(response) {
        let calculatedRate;
        this.updateMeasuredRate();
        const retryErrorInfo = response;
        const isThrottling = retryErrorInfo?.errorType === "THROTTLING" || isThrottlingError(retryErrorInfo?.error ?? response);
        if (isThrottling) {
          const rateToUse = !this.enabled ? this.measuredTxRate : Math.min(this.measuredTxRate, this.fillRate);
          this.lastMaxRate = rateToUse;
          this.calculateTimeWindow();
          this.lastThrottleTime = this.getCurrentTimeInSeconds();
          calculatedRate = this.cubicThrottle(rateToUse);
          this.enableTokenBucket();
        } else {
          this.calculateTimeWindow();
          calculatedRate = this.cubicSuccess(this.getCurrentTimeInSeconds());
        }
        const newRate = Math.min(calculatedRate, 2 * this.measuredTxRate);
        this.updateTokenBucketRate(newRate);
      }
      getCurrentTimeInSeconds() {
        return Date.now() / 1e3;
      }
      async acquireTokenBucket(amount) {
        if (!this.enabled) {
          return;
        }
        this.refillTokenBucket();
        while (amount > this.availableTokens) {
          const delay = (amount - this.availableTokens) / this.fillRate * 1e3;
          await new Promise((resolve13) => _DefaultRateLimiter.setTimeoutFn(resolve13, delay));
          this.refillTokenBucket();
        }
        this.availableTokens = this.availableTokens - amount;
      }
      refillTokenBucket() {
        const timestamp = this.getCurrentTimeInSeconds();
        if (!this.lastTimestamp) {
          this.lastTimestamp = timestamp;
          return;
        }
        const fillAmount = (timestamp - this.lastTimestamp) * this.fillRate;
        this.availableTokens = Math.min(this.maxCapacity, this.availableTokens + fillAmount);
        this.lastTimestamp = timestamp;
      }
      calculateTimeWindow() {
        this.timeWindow = this.getPrecise(Math.pow(this.lastMaxRate * (1 - this.beta) / this.scaleConstant, 1 / 3));
      }
      cubicThrottle(rateToUse) {
        return this.getPrecise(rateToUse * this.beta);
      }
      cubicSuccess(timestamp) {
        return this.getPrecise(this.scaleConstant * Math.pow(timestamp - this.lastThrottleTime - this.timeWindow, 3) + this.lastMaxRate);
      }
      enableTokenBucket() {
        this.enabled = true;
      }
      updateTokenBucketRate(newRate) {
        this.refillTokenBucket();
        this.fillRate = Math.max(newRate, this.minFillRate);
        this.maxCapacity = Math.max(newRate, this.minCapacity);
        this.availableTokens = Math.min(this.availableTokens, this.maxCapacity);
      }
      updateMeasuredRate() {
        const t = this.getCurrentTimeInSeconds();
        const timeBucket = Math.floor(t * 2) / 2;
        this.requestCount++;
        if (timeBucket > this.lastTxRateBucket) {
          const currentRate = this.requestCount / (timeBucket - this.lastTxRateBucket);
          this.measuredTxRate = this.getPrecise(currentRate * this.smooth + this.measuredTxRate * (1 - this.smooth));
          this.requestCount = 0;
          this.lastTxRateBucket = timeBucket;
        }
      }
      getPrecise(num) {
        return parseFloat(num.toFixed(8));
      }
    };
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/retries-2026-config.js
var Retry;
var init_retries_2026_config = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/retries-2026-config.js"() {
    Retry = class _Retry {
      static {
        __name(this, "Retry");
      }
      static v2026 = typeof process !== "undefined" && process.env?.SMITHY_NEW_RETRIES_2026 === "true";
      static delay() {
        return _Retry.v2026 ? 50 : 100;
      }
      static throttlingDelay() {
        return _Retry.v2026 ? 1e3 : 500;
      }
      static cost() {
        return _Retry.v2026 ? 14 : 5;
      }
      static throttlingCost() {
        return _Retry.v2026 ? 5 : 10;
      }
      static modifiedCostType() {
        return _Retry.v2026 ? "THROTTLING" : "TRANSIENT";
      }
    };
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/DefaultRetryBackoffStrategy.js
var DefaultRetryBackoffStrategy;
var init_DefaultRetryBackoffStrategy = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/DefaultRetryBackoffStrategy.js"() {
    init_constants2();
    init_retries_2026_config();
    DefaultRetryBackoffStrategy = class {
      static {
        __name(this, "DefaultRetryBackoffStrategy");
      }
      x = Retry.delay();
      computeNextBackoffDelay(i32) {
        const b32 = Math.random();
        const r32 = 2;
        const t_i = b32 * Math.min(this.x * r32 ** i32, MAXIMUM_RETRY_DELAY);
        return Math.floor(t_i);
      }
      setDelayBase(delay) {
        this.x = delay;
      }
    };
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/DefaultRetryToken.js
var DefaultRetryToken;
var init_DefaultRetryToken = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/DefaultRetryToken.js"() {
    init_constants2();
    DefaultRetryToken = class {
      static {
        __name(this, "DefaultRetryToken");
      }
      delay;
      count;
      cost;
      longPoll;
      $retryLog = {
        acquisitionDelay: 0
      };
      constructor(delay, count, cost, longPoll) {
        this.delay = delay;
        this.count = count;
        this.cost = cost;
        this.longPoll = longPoll;
      }
      getRetryCount() {
        return this.count;
      }
      getRetryDelay() {
        return Math.min(MAXIMUM_RETRY_DELAY, this.delay);
      }
      getRetryCost() {
        return this.cost;
      }
      isLongPoll() {
        return this.longPoll;
      }
    };
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/config.js
var RETRY_MODES, DEFAULT_MAX_ATTEMPTS, DEFAULT_RETRY_MODE;
var init_config = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/config.js"() {
    (function(RETRY_MODES3) {
      RETRY_MODES3["STANDARD"] = "standard";
      RETRY_MODES3["ADAPTIVE"] = "adaptive";
    })(RETRY_MODES || (RETRY_MODES = {}));
    DEFAULT_MAX_ATTEMPTS = 3;
    DEFAULT_RETRY_MODE = RETRY_MODES.STANDARD;
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/StandardRetryStrategy.js
var refusal, StandardRetryStrategy;
var init_StandardRetryStrategy = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/StandardRetryStrategy.js"() {
    init_DefaultRetryBackoffStrategy();
    init_DefaultRetryToken();
    init_config();
    init_constants2();
    init_retries_2026_config();
    refusal = {
      incompatible: 1,
      attempts: 2,
      capacity: 3
    };
    StandardRetryStrategy = class {
      static {
        __name(this, "StandardRetryStrategy");
      }
      mode = RETRY_MODES.STANDARD;
      retryBackoffStrategy;
      capacity = INITIAL_RETRY_TOKENS;
      maxAttemptsProvider;
      baseDelay;
      constructor(arg1) {
        if (typeof arg1 === "number") {
          this.maxAttemptsProvider = async () => arg1;
        } else if (typeof arg1 === "function") {
          this.maxAttemptsProvider = arg1;
        } else if (arg1 && typeof arg1 === "object") {
          this.maxAttemptsProvider = async () => arg1.maxAttempts;
          this.baseDelay = arg1.baseDelay;
          this.retryBackoffStrategy = arg1.backoff;
        }
        this.maxAttemptsProvider ??= async () => DEFAULT_MAX_ATTEMPTS;
        this.baseDelay ??= Retry.delay();
        this.retryBackoffStrategy ??= new DefaultRetryBackoffStrategy();
      }
      async acquireInitialRetryToken(retryTokenScope) {
        return new DefaultRetryToken(Retry.delay(), 0, void 0, Retry.v2026 && retryTokenScope.includes(":longpoll"));
      }
      async refreshRetryTokenForRetry(token, errorInfo) {
        const maxAttempts = await this.getMaxAttempts();
        const retryCode = this.retryCode(token, errorInfo, maxAttempts);
        const shouldRetry = retryCode === 0;
        const isLongPoll = token.isLongPoll?.();
        if (shouldRetry || isLongPoll) {
          const errorType = errorInfo.errorType;
          this.retryBackoffStrategy.setDelayBase(errorType === "THROTTLING" ? Retry.throttlingDelay() : this.baseDelay);
          const delayFromErrorType = this.retryBackoffStrategy.computeNextBackoffDelay(token.getRetryCount());
          let retryDelay = delayFromErrorType;
          if (errorInfo.retryAfterHint instanceof Date) {
            retryDelay = Math.max(delayFromErrorType, Math.min(errorInfo.retryAfterHint.getTime() - Date.now(), delayFromErrorType + 5e3));
          }
          if (!shouldRetry) {
            const longPollBackoff = Retry.v2026 && retryCode === refusal.capacity && isLongPoll ? retryDelay : 0;
            if (longPollBackoff > 0) {
              await new Promise((r32) => setTimeout(r32, longPollBackoff));
            }
          } else {
            const capacityCost = this.getCapacityCost(errorType);
            this.capacity -= capacityCost;
            const nextToken = new DefaultRetryToken(0, token.getRetryCount() + 1, capacityCost, token.isLongPoll?.() ?? false);
            await new Promise((r32) => setTimeout(r32, retryDelay));
            nextToken.$retryLog.acquisitionDelay = retryDelay;
            return nextToken;
          }
        }
        throw new Error("No retry token available");
      }
      recordSuccess(token) {
        this.capacity = Math.min(INITIAL_RETRY_TOKENS, this.capacity + (token.getRetryCost() ?? NO_RETRY_INCREMENT));
      }
      getCapacity() {
        return this.capacity;
      }
      async maxAttempts() {
        return this.maxAttemptsProvider();
      }
      async getMaxAttempts() {
        try {
          return await this.maxAttemptsProvider();
        } catch (error4) {
          console.warn(`Max attempts provider could not resolve. Using default of ${DEFAULT_MAX_ATTEMPTS}`);
          return DEFAULT_MAX_ATTEMPTS;
        }
      }
      retryCode(tokenToRenew, errorInfo, maxAttempts) {
        const attempts = tokenToRenew.getRetryCount() + 1;
        const retryableStatus = this.isRetryableError(errorInfo.errorType) ? 0 : refusal.incompatible;
        const attemptStatus = attempts < maxAttempts ? 0 : refusal.attempts;
        const capacityStatus = this.capacity >= this.getCapacityCost(errorInfo.errorType) ? 0 : refusal.capacity;
        return retryableStatus || attemptStatus || capacityStatus;
      }
      getCapacityCost(errorType) {
        return errorType === Retry.modifiedCostType() ? Retry.throttlingCost() : Retry.cost();
      }
      isRetryableError(errorType) {
        return errorType === "THROTTLING" || errorType === "TRANSIENT";
      }
    };
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/AdaptiveRetryStrategy.js
var AdaptiveRetryStrategy;
var init_AdaptiveRetryStrategy = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/AdaptiveRetryStrategy.js"() {
    init_DefaultRateLimiter();
    init_StandardRetryStrategy();
    init_config();
    AdaptiveRetryStrategy = class {
      static {
        __name(this, "AdaptiveRetryStrategy");
      }
      mode = RETRY_MODES.ADAPTIVE;
      rateLimiter;
      standardRetryStrategy;
      constructor(maxAttemptsProvider, options) {
        const { rateLimiter } = options ?? {};
        this.rateLimiter = rateLimiter ?? new DefaultRateLimiter();
        this.standardRetryStrategy = options ? new StandardRetryStrategy({
          maxAttempts: typeof maxAttemptsProvider === "number" ? maxAttemptsProvider : 3,
          ...options
        }) : new StandardRetryStrategy(maxAttemptsProvider);
      }
      async acquireInitialRetryToken(retryTokenScope) {
        const token = await this.standardRetryStrategy.acquireInitialRetryToken(retryTokenScope);
        await this.rateLimiter.getSendToken();
        return token;
      }
      async refreshRetryTokenForRetry(tokenToRenew, errorInfo) {
        this.rateLimiter.updateClientSendingRate(errorInfo);
        const token = await this.standardRetryStrategy.refreshRetryTokenForRetry(tokenToRenew, errorInfo);
        await this.rateLimiter.getSendToken();
        return token;
      }
      recordSuccess(token) {
        this.rateLimiter.updateClientSendingRate({});
        this.standardRetryStrategy.recordSuccess(token);
      }
      async maxAttemptsProvider() {
        return this.standardRetryStrategy.maxAttempts();
      }
    };
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/ConfiguredRetryStrategy.js
var ConfiguredRetryStrategy;
var init_ConfiguredRetryStrategy = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/ConfiguredRetryStrategy.js"() {
    init_StandardRetryStrategy();
    init_retries_2026_config();
    ConfiguredRetryStrategy = class extends StandardRetryStrategy {
      static {
        __name(this, "ConfiguredRetryStrategy");
      }
      computeNextBackoffDelay;
      constructor(maxAttempts, computeNextBackoffDelay = Retry.delay()) {
        super(typeof maxAttempts === "function" ? maxAttempts : async () => maxAttempts);
        if (typeof computeNextBackoffDelay === "number") {
          this.computeNextBackoffDelay = () => computeNextBackoffDelay;
        } else {
          this.computeNextBackoffDelay = computeNextBackoffDelay;
        }
        this.retryBackoffStrategy.computeNextBackoffDelay = (completedAttempt) => {
          const nextAttempt = completedAttempt + 1;
          return this.computeNextBackoffDelay(nextAttempt);
        };
      }
    };
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/retry-pre-sra-deprecated/defaultRetryQuota.js
var getDefaultRetryQuota;
var init_defaultRetryQuota = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/retry-pre-sra-deprecated/defaultRetryQuota.js"() {
    init_constants2();
    getDefaultRetryQuota = /* @__PURE__ */ __name((initialRetryTokens, options) => {
      const MAX_CAPACITY = initialRetryTokens;
      const noRetryIncrement = options?.noRetryIncrement ?? NO_RETRY_INCREMENT;
      const retryCost = options?.retryCost ?? RETRY_COST;
      const timeoutRetryCost = options?.timeoutRetryCost ?? TIMEOUT_RETRY_COST;
      let availableCapacity = initialRetryTokens;
      const getCapacityAmount = /* @__PURE__ */ __name((error4) => error4.name === "TimeoutError" ? timeoutRetryCost : retryCost, "getCapacityAmount");
      const hasRetryTokens = /* @__PURE__ */ __name((error4) => getCapacityAmount(error4) <= availableCapacity, "hasRetryTokens");
      const retrieveRetryTokens = /* @__PURE__ */ __name((error4) => {
        if (!hasRetryTokens(error4)) {
          throw new Error("No retry token available");
        }
        const capacityAmount = getCapacityAmount(error4);
        availableCapacity -= capacityAmount;
        return capacityAmount;
      }, "retrieveRetryTokens");
      const releaseRetryTokens = /* @__PURE__ */ __name((capacityReleaseAmount) => {
        availableCapacity += capacityReleaseAmount ?? noRetryIncrement;
        availableCapacity = Math.min(availableCapacity, MAX_CAPACITY);
      }, "releaseRetryTokens");
      return Object.freeze({
        hasRetryTokens,
        retrieveRetryTokens,
        releaseRetryTokens
      });
    }, "getDefaultRetryQuota");
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/retry-pre-sra-deprecated/delayDecider.js
var defaultDelayDecider;
var init_delayDecider = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/retry-pre-sra-deprecated/delayDecider.js"() {
    init_constants2();
    defaultDelayDecider = /* @__PURE__ */ __name((delayBase, attempts) => Math.floor(Math.min(MAXIMUM_RETRY_DELAY, Math.random() * 2 ** attempts * delayBase)), "defaultDelayDecider");
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/retry-pre-sra-deprecated/retryDecider.js
var defaultRetryDecider;
var init_retryDecider = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/retry-pre-sra-deprecated/retryDecider.js"() {
    init_service_error_classification();
    defaultRetryDecider = /* @__PURE__ */ __name((error4) => {
      if (!error4) {
        return false;
      }
      return isRetryableByTrait(error4) || isClockSkewError(error4) || isThrottlingError(error4) || isTransientError(error4);
    }, "defaultRetryDecider");
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/retry-pre-sra-deprecated/StandardRetryStrategy.js
var StandardRetryStrategy2, getDelayFromRetryAfterHeader;
var init_StandardRetryStrategy2 = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/retry-pre-sra-deprecated/StandardRetryStrategy.js"() {
    init_protocols2();
    init_serde2();
    init_service_error_classification();
    init_config();
    init_constants2();
    init_util2();
    init_defaultRetryQuota();
    init_delayDecider();
    init_retryDecider();
    StandardRetryStrategy2 = class {
      static {
        __name(this, "StandardRetryStrategy");
      }
      maxAttemptsProvider;
      retryDecider;
      delayDecider;
      retryQuota;
      mode = RETRY_MODES.STANDARD;
      constructor(maxAttemptsProvider, options) {
        this.maxAttemptsProvider = maxAttemptsProvider;
        this.retryDecider = options?.retryDecider ?? defaultRetryDecider;
        this.delayDecider = options?.delayDecider ?? defaultDelayDecider;
        this.retryQuota = options?.retryQuota ?? getDefaultRetryQuota(INITIAL_RETRY_TOKENS);
      }
      shouldRetry(error4, attempts, maxAttempts) {
        return attempts < maxAttempts && this.retryDecider(error4) && this.retryQuota.hasRetryTokens(error4);
      }
      async getMaxAttempts() {
        let maxAttempts;
        try {
          maxAttempts = await this.maxAttemptsProvider();
        } catch (error4) {
          maxAttempts = DEFAULT_MAX_ATTEMPTS;
        }
        return maxAttempts;
      }
      async retry(next, args, options) {
        let retryTokenAmount;
        let attempts = 0;
        let totalDelay = 0;
        const maxAttempts = await this.getMaxAttempts();
        const { request: request4 } = args;
        if (HttpRequest8.isInstance(request4)) {
          request4.headers[INVOCATION_ID_HEADER] = v4();
        }
        while (true) {
          try {
            if (HttpRequest8.isInstance(request4)) {
              request4.headers[REQUEST_HEADER] = `attempt=${attempts + 1}; max=${maxAttempts}`;
            }
            if (options?.beforeRequest) {
              await options.beforeRequest();
            }
            const { response, output } = await next(args);
            if (options?.afterRequest) {
              options.afterRequest(response);
            }
            this.retryQuota.releaseRetryTokens(retryTokenAmount);
            output.$metadata.attempts = attempts + 1;
            output.$metadata.totalRetryDelay = totalDelay;
            return { response, output };
          } catch (e32) {
            const err = asSdkError(e32);
            attempts++;
            if (this.shouldRetry(err, attempts, maxAttempts)) {
              retryTokenAmount = this.retryQuota.retrieveRetryTokens(err);
              const delayFromDecider = this.delayDecider(isThrottlingError(err) ? THROTTLING_RETRY_DELAY_BASE : DEFAULT_RETRY_DELAY_BASE, attempts);
              const delayFromResponse = getDelayFromRetryAfterHeader(err.$response);
              const delay = Math.max(delayFromResponse || 0, delayFromDecider);
              totalDelay += delay;
              await new Promise((resolve13) => setTimeout(resolve13, delay));
              continue;
            }
            if (!err.$metadata) {
              err.$metadata = {};
            }
            err.$metadata.attempts = attempts;
            err.$metadata.totalRetryDelay = totalDelay;
            throw err;
          }
        }
      }
    };
    getDelayFromRetryAfterHeader = /* @__PURE__ */ __name((response) => {
      if (!HttpResponse3.isInstance(response))
        return;
      const retryAfterHeaderName = Object.keys(response.headers).find((key) => key.toLowerCase() === "retry-after");
      if (!retryAfterHeaderName)
        return;
      const retryAfter = response.headers[retryAfterHeaderName];
      const retryAfterSeconds = Number(retryAfter);
      if (!Number.isNaN(retryAfterSeconds))
        return retryAfterSeconds * 1e3;
      const retryAfterDate = new Date(retryAfter);
      return retryAfterDate.getTime() - Date.now();
    }, "getDelayFromRetryAfterHeader");
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/retry-pre-sra-deprecated/AdaptiveRetryStrategy.js
var AdaptiveRetryStrategy2;
var init_AdaptiveRetryStrategy2 = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/retry-pre-sra-deprecated/AdaptiveRetryStrategy.js"() {
    init_DefaultRateLimiter();
    init_config();
    init_StandardRetryStrategy2();
    AdaptiveRetryStrategy2 = class extends StandardRetryStrategy2 {
      static {
        __name(this, "AdaptiveRetryStrategy");
      }
      rateLimiter;
      constructor(maxAttemptsProvider, options) {
        const { rateLimiter, ...superOptions } = options ?? {};
        super(maxAttemptsProvider, superOptions);
        this.rateLimiter = rateLimiter ?? new DefaultRateLimiter();
        this.mode = RETRY_MODES.ADAPTIVE;
      }
      async retry(next, args) {
        return super.retry(next, args, {
          beforeRequest: /* @__PURE__ */ __name(async () => {
            return this.rateLimiter.getSendToken();
          }, "beforeRequest"),
          afterRequest: /* @__PURE__ */ __name((response) => {
            this.rateLimiter.updateClientSendingRate(response);
          }, "afterRequest")
        });
      }
    };
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/configurations.js
var ENV_MAX_ATTEMPTS, CONFIG_MAX_ATTEMPTS, NODE_MAX_ATTEMPT_CONFIG_OPTIONS, resolveRetryConfig, ENV_RETRY_MODE, CONFIG_RETRY_MODE, NODE_RETRY_MODE_CONFIG_OPTIONS;
var init_configurations = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/configurations.js"() {
    init_client();
    init_AdaptiveRetryStrategy();
    init_StandardRetryStrategy();
    init_config();
    init_retries_2026_config();
    ENV_MAX_ATTEMPTS = "AWS_MAX_ATTEMPTS";
    CONFIG_MAX_ATTEMPTS = "max_attempts";
    NODE_MAX_ATTEMPT_CONFIG_OPTIONS = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => {
        const value = env3[ENV_MAX_ATTEMPTS];
        if (!value)
          return void 0;
        const maxAttempt = parseInt(value);
        if (Number.isNaN(maxAttempt)) {
          throw new Error(`Environment variable ${ENV_MAX_ATTEMPTS} mast be a number, got "${value}"`);
        }
        return maxAttempt;
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => {
        const value = profile[CONFIG_MAX_ATTEMPTS];
        if (!value)
          return void 0;
        const maxAttempt = parseInt(value);
        if (Number.isNaN(maxAttempt)) {
          throw new Error(`Shared config file entry ${CONFIG_MAX_ATTEMPTS} mast be a number, got "${value}"`);
        }
        return maxAttempt;
      }, "configFileSelector"),
      default: DEFAULT_MAX_ATTEMPTS
    };
    resolveRetryConfig = /* @__PURE__ */ __name((input, defaults) => {
      const { retryStrategy, retryMode } = input;
      const { defaultMaxAttempts = DEFAULT_MAX_ATTEMPTS, defaultBaseDelay = Retry.delay() } = defaults ?? {};
      const maxAttemptsProvider = normalizeProvider2(input.maxAttempts ?? defaultMaxAttempts);
      let controller = retryStrategy ? Promise.resolve(retryStrategy) : void 0;
      const getDefault = /* @__PURE__ */ __name(async () => {
        const maxAttempts = await maxAttemptsProvider();
        const adaptive = await normalizeProvider2(retryMode)() === RETRY_MODES.ADAPTIVE;
        if (adaptive) {
          return new AdaptiveRetryStrategy(maxAttemptsProvider, {
            maxAttempts,
            baseDelay: defaultBaseDelay
          });
        }
        return new StandardRetryStrategy({
          maxAttempts,
          baseDelay: defaultBaseDelay
        });
      }, "getDefault");
      return Object.assign(input, {
        maxAttempts: maxAttemptsProvider,
        retryStrategy: /* @__PURE__ */ __name(() => controller ??= getDefault(), "retryStrategy")
      });
    }, "resolveRetryConfig");
    ENV_RETRY_MODE = "AWS_RETRY_MODE";
    CONFIG_RETRY_MODE = "retry_mode";
    NODE_RETRY_MODE_CONFIG_OPTIONS = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[ENV_RETRY_MODE], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[CONFIG_RETRY_MODE], "configFileSelector"),
      default: DEFAULT_RETRY_MODE
    };
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/omitRetryHeadersMiddleware.js
var omitRetryHeadersMiddleware, omitRetryHeadersMiddlewareOptions, getOmitRetryHeadersPlugin;
var init_omitRetryHeadersMiddleware = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/omitRetryHeadersMiddleware.js"() {
    init_protocols2();
    init_constants2();
    omitRetryHeadersMiddleware = /* @__PURE__ */ __name(() => (next) => async (args) => {
      const { request: request4 } = args;
      if (HttpRequest8.isInstance(request4)) {
        delete request4.headers[INVOCATION_ID_HEADER];
        delete request4.headers[REQUEST_HEADER];
      }
      return next(args);
    }, "omitRetryHeadersMiddleware");
    omitRetryHeadersMiddlewareOptions = {
      name: "omitRetryHeadersMiddleware",
      tags: ["RETRY", "HEADERS", "OMIT_RETRY_HEADERS"],
      relation: "before",
      toMiddleware: "awsAuthMiddleware",
      override: true
    };
    getOmitRetryHeadersPlugin = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.addRelativeTo(omitRetryHeadersMiddleware(), omitRetryHeadersMiddlewareOptions);
      }, "applyToStack")
    }), "getOmitRetryHeadersPlugin");
  }
});

// ../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/index.js
var retry_exports = {};
__export(retry_exports, {
  AdaptiveRetryStrategy: () => AdaptiveRetryStrategy,
  CONFIG_MAX_ATTEMPTS: () => CONFIG_MAX_ATTEMPTS,
  CONFIG_RETRY_MODE: () => CONFIG_RETRY_MODE,
  ConfiguredRetryStrategy: () => ConfiguredRetryStrategy,
  DEFAULT_MAX_ATTEMPTS: () => DEFAULT_MAX_ATTEMPTS,
  DEFAULT_RETRY_DELAY_BASE: () => DEFAULT_RETRY_DELAY_BASE,
  DEFAULT_RETRY_MODE: () => DEFAULT_RETRY_MODE,
  DefaultRateLimiter: () => DefaultRateLimiter,
  DeprecatedAdaptiveRetryStrategy: () => AdaptiveRetryStrategy2,
  DeprecatedStandardRetryStrategy: () => StandardRetryStrategy2,
  ENV_MAX_ATTEMPTS: () => ENV_MAX_ATTEMPTS,
  ENV_RETRY_MODE: () => ENV_RETRY_MODE,
  INITIAL_RETRY_TOKENS: () => INITIAL_RETRY_TOKENS,
  INVOCATION_ID_HEADER: () => INVOCATION_ID_HEADER,
  MAXIMUM_RETRY_DELAY: () => MAXIMUM_RETRY_DELAY,
  NODE_MAX_ATTEMPT_CONFIG_OPTIONS: () => NODE_MAX_ATTEMPT_CONFIG_OPTIONS,
  NODE_RETRY_MODE_CONFIG_OPTIONS: () => NODE_RETRY_MODE_CONFIG_OPTIONS,
  NO_RETRY_INCREMENT: () => NO_RETRY_INCREMENT,
  REQUEST_HEADER: () => REQUEST_HEADER,
  RETRY_COST: () => RETRY_COST,
  RETRY_MODES: () => RETRY_MODES,
  Retry: () => Retry,
  StandardRetryStrategy: () => StandardRetryStrategy,
  THROTTLING_RETRY_DELAY_BASE: () => THROTTLING_RETRY_DELAY_BASE,
  TIMEOUT_RETRY_COST: () => TIMEOUT_RETRY_COST,
  defaultDelayDecider: () => defaultDelayDecider,
  defaultRetryDecider: () => defaultRetryDecider,
  getOmitRetryHeadersPlugin: () => getOmitRetryHeadersPlugin,
  getRetryAfterHint: () => getRetryAfterHint,
  getRetryPlugin: () => getRetryPlugin,
  isBrowserNetworkError: () => isBrowserNetworkError,
  isClockSkewCorrectedError: () => isClockSkewCorrectedError,
  isClockSkewError: () => isClockSkewError,
  isNodeJsHttp2TransientError: () => isNodeJsHttp2TransientError,
  isRetryableByTrait: () => isRetryableByTrait,
  isServerError: () => isServerError,
  isThrottlingError: () => isThrottlingError,
  isTransientError: () => isTransientError,
  omitRetryHeadersMiddleware: () => omitRetryHeadersMiddleware,
  omitRetryHeadersMiddlewareOptions: () => omitRetryHeadersMiddlewareOptions,
  resolveRetryConfig: () => resolveRetryConfig,
  retryMiddleware: () => retryMiddleware,
  retryMiddlewareOptions: () => retryMiddlewareOptions
});
var retryMiddleware, getRetryPlugin;
var init_retry = __esm({
  "../../node_modules/@smithy/util-retry/node_modules/@smithy/core/dist-es/submodules/retry/index.js"() {
    init_isStreamingPayload();
    init_retryMiddleware();
    init_service_error_classification();
    init_AdaptiveRetryStrategy();
    init_ConfiguredRetryStrategy();
    init_DefaultRateLimiter();
    init_StandardRetryStrategy();
    init_config();
    init_constants2();
    init_retries_2026_config();
    init_AdaptiveRetryStrategy2();
    init_StandardRetryStrategy2();
    init_delayDecider();
    init_retryDecider();
    init_configurations();
    init_omitRetryHeadersMiddleware();
    init_retryMiddleware();
    init_parseRetryAfterHeader();
    retryMiddleware = bindRetryMiddleware(isStreamingPayload);
    getRetryPlugin = bindGetRetryPlugin(isStreamingPayload);
  }
});

// ../../node_modules/@smithy/util-retry/dist-cjs/index.js
var require_dist_cjs22 = __commonJS({
  "../../node_modules/@smithy/util-retry/dist-cjs/index.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.TIMEOUT_RETRY_COST = exports2.THROTTLING_RETRY_DELAY_BASE = exports2.Retry = exports2.RETRY_MODES = exports2.RETRY_COST = exports2.NO_RETRY_INCREMENT = exports2.REQUEST_HEADER = exports2.MAXIMUM_RETRY_DELAY = exports2.INVOCATION_ID_HEADER = exports2.INITIAL_RETRY_TOKENS = exports2.DEFAULT_RETRY_MODE = exports2.DEFAULT_RETRY_DELAY_BASE = exports2.DEFAULT_MAX_ATTEMPTS = exports2.StandardRetryStrategy = exports2.DefaultRateLimiter = exports2.ConfiguredRetryStrategy = exports2.AdaptiveRetryStrategy = void 0;
    var retry_1 = (init_retry(), __toCommonJS(retry_exports));
    Object.defineProperty(exports2, "AdaptiveRetryStrategy", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return retry_1.AdaptiveRetryStrategy;
    }, "get") });
    Object.defineProperty(exports2, "ConfiguredRetryStrategy", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return retry_1.ConfiguredRetryStrategy;
    }, "get") });
    Object.defineProperty(exports2, "DefaultRateLimiter", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return retry_1.DefaultRateLimiter;
    }, "get") });
    Object.defineProperty(exports2, "StandardRetryStrategy", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return retry_1.StandardRetryStrategy;
    }, "get") });
    Object.defineProperty(exports2, "DEFAULT_MAX_ATTEMPTS", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return retry_1.DEFAULT_MAX_ATTEMPTS;
    }, "get") });
    Object.defineProperty(exports2, "DEFAULT_RETRY_DELAY_BASE", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return retry_1.DEFAULT_RETRY_DELAY_BASE;
    }, "get") });
    Object.defineProperty(exports2, "DEFAULT_RETRY_MODE", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return retry_1.DEFAULT_RETRY_MODE;
    }, "get") });
    Object.defineProperty(exports2, "INITIAL_RETRY_TOKENS", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return retry_1.INITIAL_RETRY_TOKENS;
    }, "get") });
    Object.defineProperty(exports2, "INVOCATION_ID_HEADER", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return retry_1.INVOCATION_ID_HEADER;
    }, "get") });
    Object.defineProperty(exports2, "MAXIMUM_RETRY_DELAY", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return retry_1.MAXIMUM_RETRY_DELAY;
    }, "get") });
    Object.defineProperty(exports2, "REQUEST_HEADER", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return retry_1.REQUEST_HEADER;
    }, "get") });
    Object.defineProperty(exports2, "NO_RETRY_INCREMENT", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return retry_1.NO_RETRY_INCREMENT;
    }, "get") });
    Object.defineProperty(exports2, "RETRY_COST", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return retry_1.RETRY_COST;
    }, "get") });
    Object.defineProperty(exports2, "RETRY_MODES", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return retry_1.RETRY_MODES;
    }, "get") });
    Object.defineProperty(exports2, "Retry", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return retry_1.Retry;
    }, "get") });
    Object.defineProperty(exports2, "THROTTLING_RETRY_DELAY_BASE", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return retry_1.THROTTLING_RETRY_DELAY_BASE;
    }, "get") });
    Object.defineProperty(exports2, "TIMEOUT_RETRY_COST", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return retry_1.TIMEOUT_RETRY_COST;
    }, "get") });
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/client/setFeature.js
function setFeature2(context, feature, value) {
  if (!context.__aws_sdk_context) {
    context.__aws_sdk_context = {
      features: {}
    };
  } else if (!context.__aws_sdk_context.features) {
    context.__aws_sdk_context.features = {};
  }
  context.__aws_sdk_context.features[feature] = value;
}
var import_util_retry;
var init_setFeature2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/client/setFeature.js"() {
    import_util_retry = __toESM(require_dist_cjs22());
    import_util_retry.Retry.v2026 ||= typeof process === "object" && process.env?.AWS_NEW_RETRIES_2026 === "true";
    __name(setFeature2, "setFeature");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/client/setTokenFeature.js
function setTokenFeature(token, feature, value) {
  if (!token.$source) {
    token.$source = {};
  }
  token.$source[feature] = value;
  return token;
}
var init_setTokenFeature = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/client/setTokenFeature.js"() {
    __name(setTokenFeature, "setTokenFeature");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/client/index.js
var client_exports = {};
__export(client_exports, {
  emitWarningIfUnsupportedVersion: () => emitWarningIfUnsupportedVersion,
  getLongPollPlugin: () => getLongPollPlugin,
  setCredentialFeature: () => setCredentialFeature,
  setFeature: () => setFeature2,
  setTokenFeature: () => setTokenFeature,
  state: () => state
});
var init_client2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/client/index.js"() {
    init_emitWarningIfUnsupportedVersion();
    init_longPollMiddleware();
    init_setCredentialFeature();
    init_setFeature2();
    init_setTokenFeature();
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/middleware-user-agent/dist-cjs/index.js
var require_dist_cjs23 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/middleware-user-agent/dist-cjs/index.js"(exports2) {
    "use strict";
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var utilEndpoints = require_dist_cjs21();
    var protocolHttp = require_dist_cjs2();
    var client = (init_client2(), __toCommonJS(client_exports));
    var utilRetry = require_dist_cjs22();
    var DEFAULT_UA_APP_ID2 = void 0;
    function isValidUserAgentAppId2(appId) {
      if (appId === void 0) {
        return true;
      }
      return typeof appId === "string" && appId.length <= 50;
    }
    __name(isValidUserAgentAppId2, "isValidUserAgentAppId");
    function resolveUserAgentConfig29(input) {
      const normalizedAppIdProvider = core.normalizeProvider(input.userAgentAppId ?? DEFAULT_UA_APP_ID2);
      const { customUserAgent } = input;
      return Object.assign(input, {
        customUserAgent: typeof customUserAgent === "string" ? [[customUserAgent]] : customUserAgent,
        userAgentAppId: /* @__PURE__ */ __name(async () => {
          const appId = await normalizedAppIdProvider();
          if (!isValidUserAgentAppId2(appId)) {
            const logger5 = input.logger?.constructor?.name === "NoOpLogger" || !input.logger ? console : input.logger;
            if (typeof appId !== "string") {
              logger5?.warn("userAgentAppId must be a string or undefined.");
            } else if (appId.length > 50) {
              logger5?.warn("The provided userAgentAppId exceeds the maximum length of 50 characters.");
            }
          }
          return appId;
        }, "userAgentAppId")
      });
    }
    __name(resolveUserAgentConfig29, "resolveUserAgentConfig");
    var ACCOUNT_ID_ENDPOINT_REGEX2 = /\d{12}\.ddb/;
    async function checkFeatures2(context, config2, args) {
      const request4 = args.request;
      if (request4?.headers?.["smithy-protocol"] === "rpc-v2-cbor") {
        client.setFeature(context, "PROTOCOL_RPC_V2_CBOR", "M");
      }
      if (typeof config2.retryStrategy === "function") {
        const retryStrategy = await config2.retryStrategy();
        if (typeof retryStrategy.mode === "string") {
          switch (retryStrategy.mode) {
            case utilRetry.RETRY_MODES.ADAPTIVE:
              client.setFeature(context, "RETRY_MODE_ADAPTIVE", "F");
              break;
            case utilRetry.RETRY_MODES.STANDARD:
              client.setFeature(context, "RETRY_MODE_STANDARD", "E");
              break;
          }
        }
      }
      if (typeof config2.accountIdEndpointMode === "function") {
        const endpointV2 = context.endpointV2;
        if (String(endpointV2?.url?.hostname).match(ACCOUNT_ID_ENDPOINT_REGEX2)) {
          client.setFeature(context, "ACCOUNT_ID_ENDPOINT", "O");
        }
        switch (await config2.accountIdEndpointMode?.()) {
          case "disabled":
            client.setFeature(context, "ACCOUNT_ID_MODE_DISABLED", "Q");
            break;
          case "preferred":
            client.setFeature(context, "ACCOUNT_ID_MODE_PREFERRED", "P");
            break;
          case "required":
            client.setFeature(context, "ACCOUNT_ID_MODE_REQUIRED", "R");
            break;
        }
      }
      const identity = context.__smithy_context?.selectedHttpAuthScheme?.identity;
      if (identity?.$source) {
        const credentials = identity;
        if (credentials.accountId) {
          client.setFeature(context, "RESOLVED_ACCOUNT_ID", "T");
        }
        for (const [key, value] of Object.entries(credentials.$source ?? {})) {
          client.setFeature(context, key, value);
        }
      }
    }
    __name(checkFeatures2, "checkFeatures");
    var USER_AGENT3 = "user-agent";
    var X_AMZ_USER_AGENT2 = "x-amz-user-agent";
    var SPACE2 = " ";
    var UA_NAME_SEPARATOR2 = "/";
    var UA_NAME_ESCAPE_REGEX2 = /[^!$%&'*+\-.^_`|~\w]/g;
    var UA_VALUE_ESCAPE_REGEX2 = /[^!$%&'*+\-.^_`|~\w#]/g;
    var UA_ESCAPE_CHAR2 = "-";
    var BYTE_LIMIT2 = 1024;
    function encodeFeatures2(features) {
      let buffer = "";
      for (const key in features) {
        const val = features[key];
        if (buffer.length + val.length + 1 <= BYTE_LIMIT2) {
          if (buffer.length) {
            buffer += "," + val;
          } else {
            buffer += val;
          }
          continue;
        }
        break;
      }
      return buffer;
    }
    __name(encodeFeatures2, "encodeFeatures");
    var userAgentMiddleware2 = /* @__PURE__ */ __name((options) => (next, context) => async (args) => {
      const { request: request4 } = args;
      if (!protocolHttp.HttpRequest.isInstance(request4)) {
        return next(args);
      }
      const { headers } = request4;
      const userAgent = context?.userAgent?.map(escapeUserAgent2) || [];
      const defaultUserAgent2 = (await options.defaultUserAgentProvider()).map(escapeUserAgent2);
      await checkFeatures2(context, options, args);
      const awsContext = context;
      defaultUserAgent2.push(`m/${encodeFeatures2(Object.assign({}, context.__smithy_context?.features, awsContext.__aws_sdk_context?.features))}`);
      const customUserAgent = options?.customUserAgent?.map(escapeUserAgent2) || [];
      const appId = await options.userAgentAppId();
      if (appId) {
        defaultUserAgent2.push(escapeUserAgent2([`app`, `${appId}`]));
      }
      const prefix = utilEndpoints.getUserAgentPrefix();
      const sdkUserAgentValue = (prefix ? [prefix] : []).concat([...defaultUserAgent2, ...userAgent, ...customUserAgent]).join(SPACE2);
      const normalUAValue = [
        ...defaultUserAgent2.filter((section) => section.startsWith("aws-sdk-")),
        ...customUserAgent
      ].join(SPACE2);
      if (options.runtime !== "browser") {
        if (normalUAValue) {
          headers[X_AMZ_USER_AGENT2] = headers[X_AMZ_USER_AGENT2] ? `${headers[USER_AGENT3]} ${normalUAValue}` : normalUAValue;
        }
        headers[USER_AGENT3] = sdkUserAgentValue;
      } else {
        headers[X_AMZ_USER_AGENT2] = sdkUserAgentValue;
      }
      return next({
        ...args,
        request: request4
      });
    }, "userAgentMiddleware");
    var escapeUserAgent2 = /* @__PURE__ */ __name((userAgentPair) => {
      const name = userAgentPair[0].split(UA_NAME_SEPARATOR2).map((part) => part.replace(UA_NAME_ESCAPE_REGEX2, UA_ESCAPE_CHAR2)).join(UA_NAME_SEPARATOR2);
      const version = userAgentPair[1]?.replace(UA_VALUE_ESCAPE_REGEX2, UA_ESCAPE_CHAR2);
      const prefixSeparatorIndex = name.indexOf(UA_NAME_SEPARATOR2);
      const prefix = name.substring(0, prefixSeparatorIndex);
      let uaName = name.substring(prefixSeparatorIndex + 1);
      if (prefix === "api") {
        uaName = uaName.toLowerCase();
      }
      return [prefix, uaName, version].filter((item) => item && item.length > 0).reduce((acc, item, index) => {
        switch (index) {
          case 0:
            return item;
          case 1:
            return `${acc}/${item}`;
          default:
            return `${acc}#${item}`;
        }
      }, "");
    }, "escapeUserAgent");
    var getUserAgentMiddlewareOptions2 = {
      name: "getUserAgentMiddleware",
      step: "build",
      priority: "low",
      tags: ["SET_USER_AGENT", "USER_AGENT"],
      override: true
    };
    var getUserAgentPlugin29 = /* @__PURE__ */ __name((config2) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(userAgentMiddleware2(config2), getUserAgentMiddlewareOptions2);
      }, "applyToStack")
    }), "getUserAgentPlugin");
    exports2.DEFAULT_UA_APP_ID = DEFAULT_UA_APP_ID2;
    exports2.getUserAgentMiddlewareOptions = getUserAgentMiddlewareOptions2;
    exports2.getUserAgentPlugin = getUserAgentPlugin29;
    exports2.resolveUserAgentConfig = resolveUserAgentConfig29;
    exports2.userAgentMiddleware = userAgentMiddleware2;
  }
});

// ../../node_modules/@smithy/util-config-provider/dist-cjs/index.js
var require_dist_cjs24 = __commonJS({
  "../../node_modules/@smithy/util-config-provider/dist-cjs/index.js"(exports2) {
    "use strict";
    var booleanSelector3 = /* @__PURE__ */ __name((obj, key, type) => {
      if (!(key in obj))
        return void 0;
      if (obj[key] === "true")
        return true;
      if (obj[key] === "false")
        return false;
      throw new Error(`Cannot load ${type} "${key}". Expected "true" or "false", got ${obj[key]}.`);
    }, "booleanSelector");
    var numberSelector3 = /* @__PURE__ */ __name((obj, key, type) => {
      if (!(key in obj))
        return void 0;
      const numberValue = parseInt(obj[key], 10);
      if (Number.isNaN(numberValue)) {
        throw new TypeError(`Cannot load ${type} '${key}'. Expected number, got '${obj[key]}'.`);
      }
      return numberValue;
    }, "numberSelector");
    exports2.SelectorType = void 0;
    (function(SelectorType3) {
      SelectorType3["ENV"] = "env";
      SelectorType3["CONFIG"] = "shared config entry";
    })(exports2.SelectorType || (exports2.SelectorType = {}));
    exports2.booleanSelector = booleanSelector3;
    exports2.numberSelector = numberSelector3;
  }
});

// ../../node_modules/@smithy/config-resolver/dist-cjs/index.js
var require_dist_cjs25 = __commonJS({
  "../../node_modules/@smithy/config-resolver/dist-cjs/index.js"(exports2) {
    "use strict";
    var utilConfigProvider = require_dist_cjs24();
    var utilMiddleware = require_dist_cjs6();
    var utilEndpoints = require_dist_cjs20();
    var ENV_USE_DUALSTACK_ENDPOINT3 = "AWS_USE_DUALSTACK_ENDPOINT";
    var CONFIG_USE_DUALSTACK_ENDPOINT3 = "use_dualstack_endpoint";
    var DEFAULT_USE_DUALSTACK_ENDPOINT3 = false;
    var NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS30 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => utilConfigProvider.booleanSelector(env3, ENV_USE_DUALSTACK_ENDPOINT3, utilConfigProvider.SelectorType.ENV), "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => utilConfigProvider.booleanSelector(profile, CONFIG_USE_DUALSTACK_ENDPOINT3, utilConfigProvider.SelectorType.CONFIG), "configFileSelector"),
      default: false
    };
    var nodeDualstackConfigSelectors3 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => utilConfigProvider.booleanSelector(env3, ENV_USE_DUALSTACK_ENDPOINT3, utilConfigProvider.SelectorType.ENV), "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => utilConfigProvider.booleanSelector(profile, CONFIG_USE_DUALSTACK_ENDPOINT3, utilConfigProvider.SelectorType.CONFIG), "configFileSelector"),
      default: void 0
    };
    var ENV_USE_FIPS_ENDPOINT3 = "AWS_USE_FIPS_ENDPOINT";
    var CONFIG_USE_FIPS_ENDPOINT3 = "use_fips_endpoint";
    var DEFAULT_USE_FIPS_ENDPOINT3 = false;
    var NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS30 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => utilConfigProvider.booleanSelector(env3, ENV_USE_FIPS_ENDPOINT3, utilConfigProvider.SelectorType.ENV), "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => utilConfigProvider.booleanSelector(profile, CONFIG_USE_FIPS_ENDPOINT3, utilConfigProvider.SelectorType.CONFIG), "configFileSelector"),
      default: false
    };
    var nodeFipsConfigSelectors3 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => utilConfigProvider.booleanSelector(env3, ENV_USE_FIPS_ENDPOINT3, utilConfigProvider.SelectorType.ENV), "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => utilConfigProvider.booleanSelector(profile, CONFIG_USE_FIPS_ENDPOINT3, utilConfigProvider.SelectorType.CONFIG), "configFileSelector"),
      default: void 0
    };
    var resolveCustomEndpointsConfig3 = /* @__PURE__ */ __name((input) => {
      const { tls, endpoint, urlParser, useDualstackEndpoint } = input;
      return Object.assign(input, {
        tls: tls ?? true,
        endpoint: utilMiddleware.normalizeProvider(typeof endpoint === "string" ? urlParser(endpoint) : endpoint),
        isCustomEndpoint: true,
        useDualstackEndpoint: utilMiddleware.normalizeProvider(useDualstackEndpoint ?? false)
      });
    }, "resolveCustomEndpointsConfig");
    var getEndpointFromRegion3 = /* @__PURE__ */ __name(async (input) => {
      const { tls = true } = input;
      const region = await input.region();
      const dnsHostRegex = new RegExp(/^([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9-]{0,61}[a-zA-Z0-9])$/);
      if (!dnsHostRegex.test(region)) {
        throw new Error("Invalid region in client config");
      }
      const useDualstackEndpoint = await input.useDualstackEndpoint();
      const useFipsEndpoint = await input.useFipsEndpoint();
      const { hostname } = await input.regionInfoProvider(region, { useDualstackEndpoint, useFipsEndpoint }) ?? {};
      if (!hostname) {
        throw new Error("Cannot resolve hostname from client config");
      }
      return input.urlParser(`${tls ? "https:" : "http:"}//${hostname}`);
    }, "getEndpointFromRegion");
    var resolveEndpointsConfig3 = /* @__PURE__ */ __name((input) => {
      const useDualstackEndpoint = utilMiddleware.normalizeProvider(input.useDualstackEndpoint ?? false);
      const { endpoint, useFipsEndpoint, urlParser, tls } = input;
      return Object.assign(input, {
        tls: tls ?? true,
        endpoint: endpoint ? utilMiddleware.normalizeProvider(typeof endpoint === "string" ? urlParser(endpoint) : endpoint) : () => getEndpointFromRegion3({ ...input, useDualstackEndpoint, useFipsEndpoint }),
        isCustomEndpoint: !!endpoint,
        useDualstackEndpoint
      });
    }, "resolveEndpointsConfig");
    var REGION_ENV_NAME3 = "AWS_REGION";
    var REGION_INI_NAME3 = "region";
    var NODE_REGION_CONFIG_OPTIONS31 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[REGION_ENV_NAME3], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[REGION_INI_NAME3], "configFileSelector"),
      default: /* @__PURE__ */ __name(() => {
        throw new Error("Region is missing");
      }, "default")
    };
    var NODE_REGION_CONFIG_FILE_OPTIONS31 = {
      preferredFile: "credentials"
    };
    var validRegions3 = /* @__PURE__ */ new Set();
    var checkRegion3 = /* @__PURE__ */ __name((region, check = utilEndpoints.isValidHostLabel) => {
      if (!validRegions3.has(region) && !check(region)) {
        if (region === "*") {
          console.warn(`@smithy/config-resolver WARN - Please use the caller region instead of "*". See "sigv4a" in https://github.com/aws/aws-sdk-js-v3/blob/main/supplemental-docs/CLIENTS.md.`);
        } else {
          throw new Error(`Region not accepted: region="${region}" is not a valid hostname component.`);
        }
      } else {
        validRegions3.add(region);
      }
    }, "checkRegion");
    var isFipsRegion3 = /* @__PURE__ */ __name((region) => typeof region === "string" && (region.startsWith("fips-") || region.endsWith("-fips")), "isFipsRegion");
    var getRealRegion3 = /* @__PURE__ */ __name((region) => isFipsRegion3(region) ? ["fips-aws-global", "aws-fips"].includes(region) ? "us-east-1" : region.replace(/fips-(dkr-|prod-)?|-fips/, "") : region, "getRealRegion");
    var resolveRegionConfig30 = /* @__PURE__ */ __name((input) => {
      const { region, useFipsEndpoint } = input;
      if (!region) {
        throw new Error("Region is missing");
      }
      return Object.assign(input, {
        region: /* @__PURE__ */ __name(async () => {
          const providedRegion = typeof region === "function" ? await region() : region;
          const realRegion = getRealRegion3(providedRegion);
          checkRegion3(realRegion);
          return realRegion;
        }, "region"),
        useFipsEndpoint: /* @__PURE__ */ __name(async () => {
          const providedRegion = typeof region === "string" ? region : await region();
          if (isFipsRegion3(providedRegion)) {
            return true;
          }
          return typeof useFipsEndpoint !== "function" ? Promise.resolve(!!useFipsEndpoint) : useFipsEndpoint();
        }, "useFipsEndpoint")
      });
    }, "resolveRegionConfig");
    var getHostnameFromVariants3 = /* @__PURE__ */ __name((variants = [], { useFipsEndpoint, useDualstackEndpoint }) => variants.find(({ tags }) => useFipsEndpoint === tags.includes("fips") && useDualstackEndpoint === tags.includes("dualstack"))?.hostname, "getHostnameFromVariants");
    var getResolvedHostname3 = /* @__PURE__ */ __name((resolvedRegion, { regionHostname, partitionHostname }) => regionHostname ? regionHostname : partitionHostname ? partitionHostname.replace("{region}", resolvedRegion) : void 0, "getResolvedHostname");
    var getResolvedPartition3 = /* @__PURE__ */ __name((region, { partitionHash }) => Object.keys(partitionHash || {}).find((key) => partitionHash[key].regions.includes(region)) ?? "aws", "getResolvedPartition");
    var getResolvedSigningRegion3 = /* @__PURE__ */ __name((hostname, { signingRegion, regionRegex, useFipsEndpoint }) => {
      if (signingRegion) {
        return signingRegion;
      } else if (useFipsEndpoint) {
        const regionRegexJs = regionRegex.replace("\\\\", "\\").replace(/^\^/g, "\\.").replace(/\$$/g, "\\.");
        const regionRegexmatchArray = hostname.match(regionRegexJs);
        if (regionRegexmatchArray) {
          return regionRegexmatchArray[0].slice(1, -1);
        }
      }
    }, "getResolvedSigningRegion");
    var getRegionInfo3 = /* @__PURE__ */ __name((region, { useFipsEndpoint = false, useDualstackEndpoint = false, signingService, regionHash, partitionHash }) => {
      const partition4 = getResolvedPartition3(region, { partitionHash });
      const resolvedRegion = region in regionHash ? region : partitionHash[partition4]?.endpoint ?? region;
      const hostnameOptions = { useFipsEndpoint, useDualstackEndpoint };
      const regionHostname = getHostnameFromVariants3(regionHash[resolvedRegion]?.variants, hostnameOptions);
      const partitionHostname = getHostnameFromVariants3(partitionHash[partition4]?.variants, hostnameOptions);
      const hostname = getResolvedHostname3(resolvedRegion, { regionHostname, partitionHostname });
      if (hostname === void 0) {
        throw new Error(`Endpoint resolution failed for: ${{ resolvedRegion, useFipsEndpoint, useDualstackEndpoint }}`);
      }
      const signingRegion = getResolvedSigningRegion3(hostname, {
        signingRegion: regionHash[resolvedRegion]?.signingRegion,
        regionRegex: partitionHash[partition4].regionRegex,
        useFipsEndpoint
      });
      return {
        partition: partition4,
        signingService,
        hostname,
        ...signingRegion && { signingRegion },
        ...regionHash[resolvedRegion]?.signingService && {
          signingService: regionHash[resolvedRegion].signingService
        }
      };
    }, "getRegionInfo");
    exports2.CONFIG_USE_DUALSTACK_ENDPOINT = CONFIG_USE_DUALSTACK_ENDPOINT3;
    exports2.CONFIG_USE_FIPS_ENDPOINT = CONFIG_USE_FIPS_ENDPOINT3;
    exports2.DEFAULT_USE_DUALSTACK_ENDPOINT = DEFAULT_USE_DUALSTACK_ENDPOINT3;
    exports2.DEFAULT_USE_FIPS_ENDPOINT = DEFAULT_USE_FIPS_ENDPOINT3;
    exports2.ENV_USE_DUALSTACK_ENDPOINT = ENV_USE_DUALSTACK_ENDPOINT3;
    exports2.ENV_USE_FIPS_ENDPOINT = ENV_USE_FIPS_ENDPOINT3;
    exports2.NODE_REGION_CONFIG_FILE_OPTIONS = NODE_REGION_CONFIG_FILE_OPTIONS31;
    exports2.NODE_REGION_CONFIG_OPTIONS = NODE_REGION_CONFIG_OPTIONS31;
    exports2.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS = NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS30;
    exports2.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS = NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS30;
    exports2.REGION_ENV_NAME = REGION_ENV_NAME3;
    exports2.REGION_INI_NAME = REGION_INI_NAME3;
    exports2.getRegionInfo = getRegionInfo3;
    exports2.nodeDualstackConfigSelectors = nodeDualstackConfigSelectors3;
    exports2.nodeFipsConfigSelectors = nodeFipsConfigSelectors3;
    exports2.resolveCustomEndpointsConfig = resolveCustomEndpointsConfig3;
    exports2.resolveEndpointsConfig = resolveEndpointsConfig3;
    exports2.resolveRegionConfig = resolveRegionConfig30;
  }
});

// ../../node_modules/@smithy/middleware-content-length/dist-cjs/index.js
var require_dist_cjs26 = __commonJS({
  "../../node_modules/@smithy/middleware-content-length/dist-cjs/index.js"(exports2) {
    "use strict";
    var protocolHttp = require_dist_cjs2();
    var CONTENT_LENGTH_HEADER6 = "content-length";
    function contentLengthMiddleware6(bodyLengthChecker) {
      return (next) => async (args) => {
        const request4 = args.request;
        if (protocolHttp.HttpRequest.isInstance(request4)) {
          const { body, headers } = request4;
          if (body && Object.keys(headers).map((str) => str.toLowerCase()).indexOf(CONTENT_LENGTH_HEADER6) === -1) {
            try {
              const length = bodyLengthChecker(body);
              request4.headers = {
                ...request4.headers,
                [CONTENT_LENGTH_HEADER6]: String(length)
              };
            } catch (error4) {
            }
          }
        }
        return next({
          ...args,
          request: request4
        });
      };
    }
    __name(contentLengthMiddleware6, "contentLengthMiddleware");
    var contentLengthMiddlewareOptions6 = {
      step: "build",
      tags: ["SET_CONTENT_LENGTH", "CONTENT_LENGTH"],
      name: "contentLengthMiddleware",
      override: true
    };
    var getContentLengthPlugin33 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(contentLengthMiddleware6(options.bodyLengthChecker), contentLengthMiddlewareOptions6);
      }, "applyToStack")
    }), "getContentLengthPlugin");
    exports2.contentLengthMiddleware = contentLengthMiddleware6;
    exports2.contentLengthMiddlewareOptions = contentLengthMiddlewareOptions6;
    exports2.getContentLengthPlugin = getContentLengthPlugin33;
  }
});

// ../../node_modules/@smithy/property-provider/dist-cjs/index.js
var require_dist_cjs27 = __commonJS({
  "../../node_modules/@smithy/property-provider/dist-cjs/index.js"(exports2) {
    "use strict";
    var ProviderError14 = class _ProviderError extends Error {
      static {
        __name(this, "ProviderError");
      }
      name = "ProviderError";
      tryNextLink;
      constructor(message2, options = true) {
        let logger5;
        let tryNextLink = true;
        if (typeof options === "boolean") {
          logger5 = void 0;
          tryNextLink = options;
        } else if (options != null && typeof options === "object") {
          logger5 = options.logger;
          tryNextLink = options.tryNextLink ?? true;
        }
        super(message2);
        this.tryNextLink = tryNextLink;
        Object.setPrototypeOf(this, _ProviderError.prototype);
        logger5?.debug?.(`@smithy/property-provider ${tryNextLink ? "->" : "(!)"} ${message2}`);
      }
      static from(error4, options = true) {
        return Object.assign(new this(error4.message, options), error4);
      }
    };
    var CredentialsProviderError5 = class _CredentialsProviderError extends ProviderError14 {
      static {
        __name(this, "CredentialsProviderError");
      }
      name = "CredentialsProviderError";
      constructor(message2, options = true) {
        super(message2, options);
        Object.setPrototypeOf(this, _CredentialsProviderError.prototype);
      }
    };
    var TokenProviderError3 = class _TokenProviderError extends ProviderError14 {
      static {
        __name(this, "TokenProviderError");
      }
      name = "TokenProviderError";
      constructor(message2, options = true) {
        super(message2, options);
        Object.setPrototypeOf(this, _TokenProviderError.prototype);
      }
    };
    var chain5 = /* @__PURE__ */ __name((...providers) => async () => {
      if (providers.length === 0) {
        throw new ProviderError14("No providers in chain");
      }
      let lastProviderError;
      for (const provider of providers) {
        try {
          const credentials = await provider();
          return credentials;
        } catch (err) {
          lastProviderError = err;
          if (err?.tryNextLink) {
            continue;
          }
          throw err;
        }
      }
      throw lastProviderError;
    }, "chain");
    var fromStatic5 = /* @__PURE__ */ __name((staticValue) => () => Promise.resolve(staticValue), "fromStatic");
    var memoize6 = /* @__PURE__ */ __name((provider, isExpired, requiresRefresh) => {
      let resolved;
      let pending;
      let hasResult;
      let isConstant = false;
      const coalesceProvider = /* @__PURE__ */ __name(async () => {
        if (!pending) {
          pending = provider();
        }
        try {
          resolved = await pending;
          hasResult = true;
          isConstant = false;
        } finally {
          pending = void 0;
        }
        return resolved;
      }, "coalesceProvider");
      if (isExpired === void 0) {
        return async (options) => {
          if (!hasResult || options?.forceRefresh) {
            resolved = await coalesceProvider();
          }
          return resolved;
        };
      }
      return async (options) => {
        if (!hasResult || options?.forceRefresh) {
          resolved = await coalesceProvider();
        }
        if (isConstant) {
          return resolved;
        }
        if (requiresRefresh && !requiresRefresh(resolved)) {
          isConstant = true;
          return resolved;
        }
        if (isExpired(resolved)) {
          await coalesceProvider();
          return resolved;
        }
        return resolved;
      };
    }, "memoize");
    exports2.CredentialsProviderError = CredentialsProviderError5;
    exports2.ProviderError = ProviderError14;
    exports2.TokenProviderError = TokenProviderError3;
    exports2.chain = chain5;
    exports2.fromStatic = fromStatic5;
    exports2.memoize = memoize6;
  }
});

// ../../node_modules/@smithy/shared-ini-file-loader/dist-cjs/getHomeDir.js
var require_getHomeDir = __commonJS({
  "../../node_modules/@smithy/shared-ini-file-loader/dist-cjs/getHomeDir.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getHomeDir = void 0;
    var os_1 = require("os");
    var path_1 = require("path");
    var homeDirCache5 = {};
    var getHomeDirCacheKey5 = /* @__PURE__ */ __name(() => {
      if (process && process.geteuid) {
        return `${process.geteuid()}`;
      }
      return "DEFAULT";
    }, "getHomeDirCacheKey");
    var getHomeDir5 = /* @__PURE__ */ __name(() => {
      const { HOME, USERPROFILE, HOMEPATH, HOMEDRIVE = `C:${path_1.sep}` } = process.env;
      if (HOME)
        return HOME;
      if (USERPROFILE)
        return USERPROFILE;
      if (HOMEPATH)
        return `${HOMEDRIVE}${HOMEPATH}`;
      const homeDirCacheKey = getHomeDirCacheKey5();
      if (!homeDirCache5[homeDirCacheKey])
        homeDirCache5[homeDirCacheKey] = (0, os_1.homedir)();
      return homeDirCache5[homeDirCacheKey];
    }, "getHomeDir");
    exports2.getHomeDir = getHomeDir5;
  }
});

// ../../node_modules/@smithy/shared-ini-file-loader/dist-cjs/getSSOTokenFilepath.js
var require_getSSOTokenFilepath = __commonJS({
  "../../node_modules/@smithy/shared-ini-file-loader/dist-cjs/getSSOTokenFilepath.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getSSOTokenFilepath = void 0;
    var crypto_1 = require("crypto");
    var path_1 = require("path");
    var getHomeDir_1 = require_getHomeDir();
    var getSSOTokenFilepath3 = /* @__PURE__ */ __name((id) => {
      const hasher = (0, crypto_1.createHash)("sha1");
      const cacheName = hasher.update(id).digest("hex");
      return (0, path_1.join)((0, getHomeDir_1.getHomeDir)(), ".aws", "sso", "cache", `${cacheName}.json`);
    }, "getSSOTokenFilepath");
    exports2.getSSOTokenFilepath = getSSOTokenFilepath3;
  }
});

// ../../node_modules/@smithy/shared-ini-file-loader/dist-cjs/getSSOTokenFromFile.js
var require_getSSOTokenFromFile = __commonJS({
  "../../node_modules/@smithy/shared-ini-file-loader/dist-cjs/getSSOTokenFromFile.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getSSOTokenFromFile = exports2.tokenIntercept = void 0;
    var promises_1 = require("fs/promises");
    var getSSOTokenFilepath_1 = require_getSSOTokenFilepath();
    exports2.tokenIntercept = {};
    var getSSOTokenFromFile3 = /* @__PURE__ */ __name(async (id) => {
      if (exports2.tokenIntercept[id]) {
        return exports2.tokenIntercept[id];
      }
      const ssoTokenFilepath = (0, getSSOTokenFilepath_1.getSSOTokenFilepath)(id);
      const ssoTokenText = await (0, promises_1.readFile)(ssoTokenFilepath, "utf8");
      return JSON.parse(ssoTokenText);
    }, "getSSOTokenFromFile");
    exports2.getSSOTokenFromFile = getSSOTokenFromFile3;
  }
});

// ../../node_modules/@smithy/shared-ini-file-loader/dist-cjs/readFile.js
var require_readFile = __commonJS({
  "../../node_modules/@smithy/shared-ini-file-loader/dist-cjs/readFile.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.readFile = exports2.fileIntercept = exports2.filePromises = void 0;
    var promises_1 = require("node:fs/promises");
    exports2.filePromises = {};
    exports2.fileIntercept = {};
    var readFile15 = /* @__PURE__ */ __name((path47, options) => {
      if (exports2.fileIntercept[path47] !== void 0) {
        return exports2.fileIntercept[path47];
      }
      if (!exports2.filePromises[path47] || options?.ignoreCache) {
        exports2.filePromises[path47] = (0, promises_1.readFile)(path47, "utf8");
      }
      return exports2.filePromises[path47];
    }, "readFile");
    exports2.readFile = readFile15;
  }
});

// ../../node_modules/@smithy/shared-ini-file-loader/dist-cjs/index.js
var require_dist_cjs28 = __commonJS({
  "../../node_modules/@smithy/shared-ini-file-loader/dist-cjs/index.js"(exports2) {
    "use strict";
    var getHomeDir5 = require_getHomeDir();
    var getSSOTokenFilepath3 = require_getSSOTokenFilepath();
    var getSSOTokenFromFile3 = require_getSSOTokenFromFile();
    var path47 = require("path");
    var types2 = require_dist_cjs();
    var readFile15 = require_readFile();
    var ENV_PROFILE5 = "AWS_PROFILE";
    var DEFAULT_PROFILE5 = "default";
    var getProfileName5 = /* @__PURE__ */ __name((init) => init.profile || process.env[ENV_PROFILE5] || DEFAULT_PROFILE5, "getProfileName");
    var CONFIG_PREFIX_SEPARATOR5 = ".";
    var getConfigData5 = /* @__PURE__ */ __name((data3) => Object.entries(data3).filter(([key]) => {
      const indexOfSeparator = key.indexOf(CONFIG_PREFIX_SEPARATOR5);
      if (indexOfSeparator === -1) {
        return false;
      }
      return Object.values(types2.IniSectionType).includes(key.substring(0, indexOfSeparator));
    }).reduce((acc, [key, value]) => {
      const indexOfSeparator = key.indexOf(CONFIG_PREFIX_SEPARATOR5);
      const updatedKey = key.substring(0, indexOfSeparator) === types2.IniSectionType.PROFILE ? key.substring(indexOfSeparator + 1) : key;
      acc[updatedKey] = value;
      return acc;
    }, {
      ...data3.default && { default: data3.default }
    }), "getConfigData");
    var ENV_CONFIG_PATH5 = "AWS_CONFIG_FILE";
    var getConfigFilepath5 = /* @__PURE__ */ __name(() => process.env[ENV_CONFIG_PATH5] || path47.join(getHomeDir5.getHomeDir(), ".aws", "config"), "getConfigFilepath");
    var ENV_CREDENTIALS_PATH5 = "AWS_SHARED_CREDENTIALS_FILE";
    var getCredentialsFilepath5 = /* @__PURE__ */ __name(() => process.env[ENV_CREDENTIALS_PATH5] || path47.join(getHomeDir5.getHomeDir(), ".aws", "credentials"), "getCredentialsFilepath");
    var prefixKeyRegex5 = /^([\w-]+)\s(["'])?([\w-@\+\.%:/]+)\2$/;
    var profileNameBlockList5 = ["__proto__", "profile __proto__"];
    var parseIni5 = /* @__PURE__ */ __name((iniData) => {
      const map5 = {};
      let currentSection;
      let currentSubSection;
      for (const iniLine of iniData.split(/\r?\n/)) {
        const trimmedLine = iniLine.split(/(^|\s)[;#]/)[0].trim();
        const isSection = trimmedLine[0] === "[" && trimmedLine[trimmedLine.length - 1] === "]";
        if (isSection) {
          currentSection = void 0;
          currentSubSection = void 0;
          const sectionName = trimmedLine.substring(1, trimmedLine.length - 1);
          const matches = prefixKeyRegex5.exec(sectionName);
          if (matches) {
            const [, prefix, , name] = matches;
            if (Object.values(types2.IniSectionType).includes(prefix)) {
              currentSection = [prefix, name].join(CONFIG_PREFIX_SEPARATOR5);
            }
          } else {
            currentSection = sectionName;
          }
          if (profileNameBlockList5.includes(sectionName)) {
            throw new Error(`Found invalid profile name "${sectionName}"`);
          }
        } else if (currentSection) {
          const indexOfEqualsSign = trimmedLine.indexOf("=");
          if (![0, -1].includes(indexOfEqualsSign)) {
            const [name, value] = [
              trimmedLine.substring(0, indexOfEqualsSign).trim(),
              trimmedLine.substring(indexOfEqualsSign + 1).trim()
            ];
            if (value === "") {
              currentSubSection = name;
            } else {
              if (currentSubSection && iniLine.trimStart() === iniLine) {
                currentSubSection = void 0;
              }
              map5[currentSection] = map5[currentSection] || {};
              const key = currentSubSection ? [currentSubSection, name].join(CONFIG_PREFIX_SEPARATOR5) : name;
              map5[currentSection][key] = value;
            }
          }
        }
      }
      return map5;
    }, "parseIni");
    var swallowError$1 = /* @__PURE__ */ __name(() => ({}), "swallowError$1");
    var loadSharedConfigFiles6 = /* @__PURE__ */ __name(async (init = {}) => {
      const { filepath = getCredentialsFilepath5(), configFilepath = getConfigFilepath5() } = init;
      const homeDir = getHomeDir5.getHomeDir();
      const relativeHomeDirPrefix = "~/";
      let resolvedFilepath = filepath;
      if (filepath.startsWith(relativeHomeDirPrefix)) {
        resolvedFilepath = path47.join(homeDir, filepath.slice(2));
      }
      let resolvedConfigFilepath = configFilepath;
      if (configFilepath.startsWith(relativeHomeDirPrefix)) {
        resolvedConfigFilepath = path47.join(homeDir, configFilepath.slice(2));
      }
      const parsedFiles = await Promise.all([
        readFile15.readFile(resolvedConfigFilepath, {
          ignoreCache: init.ignoreCache
        }).then(parseIni5).then(getConfigData5).catch(swallowError$1),
        readFile15.readFile(resolvedFilepath, {
          ignoreCache: init.ignoreCache
        }).then(parseIni5).catch(swallowError$1)
      ]);
      return {
        configFile: parsedFiles[0],
        credentialsFile: parsedFiles[1]
      };
    }, "loadSharedConfigFiles");
    var getSsoSessionData3 = /* @__PURE__ */ __name((data3) => Object.entries(data3).filter(([key]) => key.startsWith(types2.IniSectionType.SSO_SESSION + CONFIG_PREFIX_SEPARATOR5)).reduce((acc, [key, value]) => ({ ...acc, [key.substring(key.indexOf(CONFIG_PREFIX_SEPARATOR5) + 1)]: value }), {}), "getSsoSessionData");
    var swallowError7 = /* @__PURE__ */ __name(() => ({}), "swallowError");
    var loadSsoSessionData3 = /* @__PURE__ */ __name(async (init = {}) => readFile15.readFile(init.configFilepath ?? getConfigFilepath5()).then(parseIni5).then(getSsoSessionData3).catch(swallowError7), "loadSsoSessionData");
    var mergeConfigFiles3 = /* @__PURE__ */ __name((...files) => {
      const merged = {};
      for (const file of files) {
        for (const [key, values] of Object.entries(file)) {
          if (merged[key] !== void 0) {
            Object.assign(merged[key], values);
          } else {
            merged[key] = values;
          }
        }
      }
      return merged;
    }, "mergeConfigFiles");
    var parseKnownFiles3 = /* @__PURE__ */ __name(async (init) => {
      const parsedFiles = await loadSharedConfigFiles6(init);
      return mergeConfigFiles3(parsedFiles.configFile, parsedFiles.credentialsFile);
    }, "parseKnownFiles");
    var externalDataInterceptor3 = {
      getFileRecord() {
        return readFile15.fileIntercept;
      },
      interceptFile(path48, contents) {
        readFile15.fileIntercept[path48] = Promise.resolve(contents);
      },
      getTokenRecord() {
        return getSSOTokenFromFile3.tokenIntercept;
      },
      interceptToken(id, contents) {
        getSSOTokenFromFile3.tokenIntercept[id] = contents;
      }
    };
    exports2.getSSOTokenFromFile = getSSOTokenFromFile3.getSSOTokenFromFile;
    exports2.readFile = readFile15.readFile;
    exports2.CONFIG_PREFIX_SEPARATOR = CONFIG_PREFIX_SEPARATOR5;
    exports2.DEFAULT_PROFILE = DEFAULT_PROFILE5;
    exports2.ENV_PROFILE = ENV_PROFILE5;
    exports2.externalDataInterceptor = externalDataInterceptor3;
    exports2.getProfileName = getProfileName5;
    exports2.loadSharedConfigFiles = loadSharedConfigFiles6;
    exports2.loadSsoSessionData = loadSsoSessionData3;
    exports2.parseKnownFiles = parseKnownFiles3;
    Object.prototype.hasOwnProperty.call(getHomeDir5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: getHomeDir5["__proto__"]
    });
    Object.keys(getHomeDir5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = getHomeDir5[k32];
    });
    Object.prototype.hasOwnProperty.call(getSSOTokenFilepath3, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: getSSOTokenFilepath3["__proto__"]
    });
    Object.keys(getSSOTokenFilepath3).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = getSSOTokenFilepath3[k32];
    });
  }
});

// ../../node_modules/@smithy/node-config-provider/dist-cjs/index.js
var require_dist_cjs29 = __commonJS({
  "../../node_modules/@smithy/node-config-provider/dist-cjs/index.js"(exports2) {
    "use strict";
    var propertyProvider = require_dist_cjs27();
    var sharedIniFileLoader = require_dist_cjs28();
    function getSelectorName5(functionString) {
      try {
        const constants3 = new Set(Array.from(functionString.match(/([A-Z_]){3,}/g) ?? []));
        constants3.delete("CONFIG");
        constants3.delete("CONFIG_PREFIX_SEPARATOR");
        constants3.delete("ENV");
        return [...constants3].join(", ");
      } catch (e32) {
        return functionString;
      }
    }
    __name(getSelectorName5, "getSelectorName");
    var fromEnv6 = /* @__PURE__ */ __name((envVarSelector, options) => async () => {
      try {
        const config2 = envVarSelector(process.env, options);
        if (config2 === void 0) {
          throw new Error();
        }
        return config2;
      } catch (e32) {
        throw new propertyProvider.CredentialsProviderError(e32.message || `Not found in ENV: ${getSelectorName5(envVarSelector.toString())}`, { logger: options?.logger });
      }
    }, "fromEnv");
    var fromSharedConfigFiles5 = /* @__PURE__ */ __name((configSelector, { preferredFile = "config", ...init } = {}) => async () => {
      const profile = sharedIniFileLoader.getProfileName(init);
      const { configFile, credentialsFile } = await sharedIniFileLoader.loadSharedConfigFiles(init);
      const profileFromCredentials = credentialsFile[profile] || {};
      const profileFromConfig = configFile[profile] || {};
      const mergedProfile = preferredFile === "config" ? { ...profileFromCredentials, ...profileFromConfig } : { ...profileFromConfig, ...profileFromCredentials };
      try {
        const cfgFile = preferredFile === "config" ? configFile : credentialsFile;
        const configValue = configSelector(mergedProfile, cfgFile);
        if (configValue === void 0) {
          throw new Error();
        }
        return configValue;
      } catch (e32) {
        throw new propertyProvider.CredentialsProviderError(e32.message || `Not found in config files w/ profile [${profile}]: ${getSelectorName5(configSelector.toString())}`, { logger: init.logger });
      }
    }, "fromSharedConfigFiles");
    var isFunction5 = /* @__PURE__ */ __name((func) => typeof func === "function", "isFunction");
    var fromStatic5 = /* @__PURE__ */ __name((defaultValue2) => isFunction5(defaultValue2) ? async () => await defaultValue2() : propertyProvider.fromStatic(defaultValue2), "fromStatic");
    var loadConfig6 = /* @__PURE__ */ __name(({ environmentVariableSelector, configFileSelector, default: defaultValue2 }, configuration = {}) => {
      const { signingName, logger: logger5 } = configuration;
      const envOptions = { signingName, logger: logger5 };
      return propertyProvider.memoize(propertyProvider.chain(fromEnv6(environmentVariableSelector, envOptions), fromSharedConfigFiles5(configFileSelector, configuration), fromStatic5(defaultValue2)));
    }, "loadConfig");
    exports2.loadConfig = loadConfig6;
  }
});

// ../../node_modules/@smithy/middleware-endpoint/dist-cjs/adaptors/getEndpointUrlConfig.js
var require_getEndpointUrlConfig = __commonJS({
  "../../node_modules/@smithy/middleware-endpoint/dist-cjs/adaptors/getEndpointUrlConfig.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getEndpointUrlConfig = void 0;
    var shared_ini_file_loader_1 = require_dist_cjs28();
    var ENV_ENDPOINT_URL5 = "AWS_ENDPOINT_URL";
    var CONFIG_ENDPOINT_URL5 = "endpoint_url";
    var getEndpointUrlConfig5 = /* @__PURE__ */ __name((serviceId) => ({
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => {
        const serviceSuffixParts = serviceId.split(" ").map((w) => w.toUpperCase());
        const serviceEndpointUrl = env3[[ENV_ENDPOINT_URL5, ...serviceSuffixParts].join("_")];
        if (serviceEndpointUrl)
          return serviceEndpointUrl;
        const endpointUrl = env3[ENV_ENDPOINT_URL5];
        if (endpointUrl)
          return endpointUrl;
        return void 0;
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile, config2) => {
        if (config2 && profile.services) {
          const servicesSection = config2[["services", profile.services].join(shared_ini_file_loader_1.CONFIG_PREFIX_SEPARATOR)];
          if (servicesSection) {
            const servicePrefixParts = serviceId.split(" ").map((w) => w.toLowerCase());
            const endpointUrl2 = servicesSection[[servicePrefixParts.join("_"), CONFIG_ENDPOINT_URL5].join(shared_ini_file_loader_1.CONFIG_PREFIX_SEPARATOR)];
            if (endpointUrl2)
              return endpointUrl2;
          }
        }
        const endpointUrl = profile[CONFIG_ENDPOINT_URL5];
        if (endpointUrl)
          return endpointUrl;
        return void 0;
      }, "configFileSelector"),
      default: void 0
    }), "getEndpointUrlConfig");
    exports2.getEndpointUrlConfig = getEndpointUrlConfig5;
  }
});

// ../../node_modules/@smithy/middleware-endpoint/dist-cjs/adaptors/getEndpointFromConfig.js
var require_getEndpointFromConfig = __commonJS({
  "../../node_modules/@smithy/middleware-endpoint/dist-cjs/adaptors/getEndpointFromConfig.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getEndpointFromConfig = void 0;
    var node_config_provider_1 = require_dist_cjs29();
    var getEndpointUrlConfig_1 = require_getEndpointUrlConfig();
    var getEndpointFromConfig5 = /* @__PURE__ */ __name(async (serviceId) => (0, node_config_provider_1.loadConfig)((0, getEndpointUrlConfig_1.getEndpointUrlConfig)(serviceId ?? ""))(), "getEndpointFromConfig");
    exports2.getEndpointFromConfig = getEndpointFromConfig5;
  }
});

// ../../node_modules/@smithy/middleware-serde/dist-cjs/index.js
var require_dist_cjs30 = __commonJS({
  "../../node_modules/@smithy/middleware-serde/dist-cjs/index.js"(exports2) {
    "use strict";
    var protocolHttp = require_dist_cjs2();
    var endpoints = (init_endpoints(), __toCommonJS(endpoints_exports));
    var deserializerMiddleware3 = /* @__PURE__ */ __name((options, deserializer) => (next, context) => async (args) => {
      const { response } = await next(args);
      try {
        const parsed = await deserializer(response, options);
        return {
          response,
          output: parsed
        };
      } catch (error4) {
        Object.defineProperty(error4, "$response", {
          value: response,
          enumerable: false,
          writable: false,
          configurable: false
        });
        if (!("$metadata" in error4)) {
          const hint = `Deserialization error: to see the raw response, inspect the hidden field {error}.$response on this object.`;
          try {
            error4.message += "\n  " + hint;
          } catch (e32) {
            if (!context.logger || context.logger?.constructor?.name === "NoOpLogger") {
              console.warn(hint);
            } else {
              context.logger?.warn?.(hint);
            }
          }
          if (typeof error4.$responseBodyText !== "undefined") {
            if (error4.$response) {
              error4.$response.body = error4.$responseBodyText;
            }
          }
          try {
            if (protocolHttp.HttpResponse.isInstance(response)) {
              const { headers = {} } = response;
              const headerEntries = Object.entries(headers);
              error4.$metadata = {
                httpStatusCode: response.statusCode,
                requestId: findHeader5(/^x-[\w-]+-request-?id$/, headerEntries),
                extendedRequestId: findHeader5(/^x-[\w-]+-id-2$/, headerEntries),
                cfId: findHeader5(/^x-[\w-]+-cf-id$/, headerEntries)
              };
            }
          } catch (e32) {
          }
        }
        throw error4;
      }
    }, "deserializerMiddleware");
    var findHeader5 = /* @__PURE__ */ __name((pattern, headers) => {
      return (headers.find(([k32]) => {
        return k32.match(pattern);
      }) || [void 0, void 0])[1];
    }, "findHeader");
    var serializerMiddleware3 = /* @__PURE__ */ __name((options, serializer) => (next, context) => async (args) => {
      const endpointConfig = options;
      const endpoint = context.endpointV2 ? async () => endpoints.toEndpointV1(context.endpointV2) : endpointConfig.endpoint;
      if (!endpoint) {
        throw new Error("No valid endpoint provider available.");
      }
      const request4 = await serializer(args.input, { ...options, endpoint });
      return next({
        ...args,
        request: request4
      });
    }, "serializerMiddleware");
    var deserializerMiddlewareOption5 = {
      name: "deserializerMiddleware",
      step: "deserialize",
      tags: ["DESERIALIZER"],
      override: true
    };
    var serializerMiddlewareOption9 = {
      name: "serializerMiddleware",
      step: "serialize",
      tags: ["SERIALIZER"],
      override: true
    };
    function getSerdePlugin3(config2, serializer, deserializer) {
      return {
        applyToStack: /* @__PURE__ */ __name((commandStack) => {
          commandStack.add(deserializerMiddleware3(config2, deserializer), deserializerMiddlewareOption5);
          commandStack.add(serializerMiddleware3(config2, serializer), serializerMiddlewareOption9);
        }, "applyToStack")
      };
    }
    __name(getSerdePlugin3, "getSerdePlugin");
    exports2.deserializerMiddleware = deserializerMiddleware3;
    exports2.deserializerMiddlewareOption = deserializerMiddlewareOption5;
    exports2.getSerdePlugin = getSerdePlugin3;
    exports2.serializerMiddleware = serializerMiddleware3;
    exports2.serializerMiddlewareOption = serializerMiddlewareOption9;
  }
});

// ../../node_modules/@smithy/middleware-endpoint/dist-cjs/index.js
var require_dist_cjs31 = __commonJS({
  "../../node_modules/@smithy/middleware-endpoint/dist-cjs/index.js"(exports2) {
    "use strict";
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var utilMiddleware = require_dist_cjs6();
    var getEndpointFromConfig5 = require_getEndpointFromConfig();
    var urlParser = require_dist_cjs18();
    var middlewareSerde = require_dist_cjs30();
    var resolveParamsForS35 = /* @__PURE__ */ __name(async (endpointParams) => {
      const bucket = endpointParams?.Bucket || "";
      if (typeof endpointParams.Bucket === "string") {
        endpointParams.Bucket = bucket.replace(/#/g, encodeURIComponent("#")).replace(/\?/g, encodeURIComponent("?"));
      }
      if (isArnBucketName5(bucket)) {
        if (endpointParams.ForcePathStyle === true) {
          throw new Error("Path-style addressing cannot be used with ARN buckets");
        }
      } else if (!isDnsCompatibleBucketName5(bucket) || bucket.indexOf(".") !== -1 && !String(endpointParams.Endpoint).startsWith("http:") || bucket.toLowerCase() !== bucket || bucket.length < 3) {
        endpointParams.ForcePathStyle = true;
      }
      if (endpointParams.DisableMultiRegionAccessPoints) {
        endpointParams.disableMultiRegionAccessPoints = true;
        endpointParams.DisableMRAP = true;
      }
      return endpointParams;
    }, "resolveParamsForS3");
    var DOMAIN_PATTERN5 = /^[a-z0-9][a-z0-9\.\-]{1,61}[a-z0-9]$/;
    var IP_ADDRESS_PATTERN5 = /(\d+\.){3}\d+/;
    var DOTS_PATTERN5 = /\.\./;
    var isDnsCompatibleBucketName5 = /* @__PURE__ */ __name((bucketName) => DOMAIN_PATTERN5.test(bucketName) && !IP_ADDRESS_PATTERN5.test(bucketName) && !DOTS_PATTERN5.test(bucketName), "isDnsCompatibleBucketName");
    var isArnBucketName5 = /* @__PURE__ */ __name((bucketName) => {
      const [arn, partition4, service, , , bucket] = bucketName.split(":");
      const isArn = arn === "arn" && bucketName.split(":").length >= 6;
      const isValidArn = Boolean(isArn && partition4 && service && bucket);
      if (isArn && !isValidArn) {
        throw new Error(`Invalid ARN: ${bucketName} was an invalid ARN.`);
      }
      return isValidArn;
    }, "isArnBucketName");
    var createConfigValueProvider5 = /* @__PURE__ */ __name((configKey, canonicalEndpointParamKey, config2, isClientContextParam = false) => {
      const configProvider = /* @__PURE__ */ __name(async () => {
        let configValue;
        if (isClientContextParam) {
          const clientContextParams = config2.clientContextParams;
          const nestedValue = clientContextParams?.[configKey];
          configValue = nestedValue ?? config2[configKey] ?? config2[canonicalEndpointParamKey];
        } else {
          configValue = config2[configKey] ?? config2[canonicalEndpointParamKey];
        }
        if (typeof configValue === "function") {
          return configValue();
        }
        return configValue;
      }, "configProvider");
      if (configKey === "credentialScope" || canonicalEndpointParamKey === "CredentialScope") {
        return async () => {
          const credentials = typeof config2.credentials === "function" ? await config2.credentials() : config2.credentials;
          const configValue = credentials?.credentialScope ?? credentials?.CredentialScope;
          return configValue;
        };
      }
      if (configKey === "accountId" || canonicalEndpointParamKey === "AccountId") {
        return async () => {
          const credentials = typeof config2.credentials === "function" ? await config2.credentials() : config2.credentials;
          const configValue = credentials?.accountId ?? credentials?.AccountId;
          return configValue;
        };
      }
      if (configKey === "endpoint" || canonicalEndpointParamKey === "endpoint") {
        return async () => {
          if (config2.isCustomEndpoint === false) {
            return void 0;
          }
          const endpoint = await configProvider();
          if (endpoint && typeof endpoint === "object") {
            if ("url" in endpoint) {
              return endpoint.url.href;
            }
            if ("hostname" in endpoint) {
              const { protocol, hostname, port, path: path47 } = endpoint;
              return `${protocol}//${hostname}${port ? ":" + port : ""}${path47}`;
            }
          }
          return endpoint;
        };
      }
      return configProvider;
    }, "createConfigValueProvider");
    var toEndpointV17 = /* @__PURE__ */ __name((endpoint) => {
      if (typeof endpoint === "object") {
        if ("url" in endpoint) {
          const v1Endpoint = urlParser.parseUrl(endpoint.url);
          if (endpoint.headers) {
            v1Endpoint.headers = {};
            for (const [name, values] of Object.entries(endpoint.headers)) {
              v1Endpoint.headers[name.toLowerCase()] = values.join(", ");
            }
          }
          return v1Endpoint;
        }
        return endpoint;
      }
      return urlParser.parseUrl(endpoint);
    }, "toEndpointV1");
    var getEndpointFromInstructions7 = /* @__PURE__ */ __name(async (commandInput, instructionsSupplier, clientConfig, context) => {
      if (!clientConfig.isCustomEndpoint) {
        let endpointFromConfig;
        if (clientConfig.serviceConfiguredEndpoint) {
          endpointFromConfig = await clientConfig.serviceConfiguredEndpoint();
        } else {
          endpointFromConfig = await getEndpointFromConfig5.getEndpointFromConfig(clientConfig.serviceId);
        }
        if (endpointFromConfig) {
          clientConfig.endpoint = () => Promise.resolve(toEndpointV17(endpointFromConfig));
          clientConfig.isCustomEndpoint = true;
        }
      }
      const endpointParams = await resolveParams13(commandInput, instructionsSupplier, clientConfig);
      if (typeof clientConfig.endpointProvider !== "function") {
        throw new Error("config.endpointProvider is not set.");
      }
      const endpoint = clientConfig.endpointProvider(endpointParams, context);
      if (clientConfig.isCustomEndpoint && clientConfig.endpoint) {
        const customEndpoint = await clientConfig.endpoint();
        if (customEndpoint?.headers) {
          endpoint.headers ??= {};
          for (const [name, value] of Object.entries(customEndpoint.headers)) {
            endpoint.headers[name] = Array.isArray(value) ? value : [value];
          }
        }
      }
      return endpoint;
    }, "getEndpointFromInstructions");
    var resolveParams13 = /* @__PURE__ */ __name(async (commandInput, instructionsSupplier, clientConfig) => {
      const endpointParams = {};
      const instructions = instructionsSupplier?.getEndpointParameterInstructions?.() || {};
      for (const [name, instruction] of Object.entries(instructions)) {
        switch (instruction.type) {
          case "staticContextParams":
            endpointParams[name] = instruction.value;
            break;
          case "contextParams":
            endpointParams[name] = commandInput[instruction.name];
            break;
          case "clientContextParams":
          case "builtInParams":
            endpointParams[name] = await createConfigValueProvider5(instruction.name, name, clientConfig, instruction.type !== "builtInParams")();
            break;
          case "operationContextParams":
            endpointParams[name] = instruction.get(commandInput);
            break;
          default:
            throw new Error("Unrecognized endpoint parameter instruction: " + JSON.stringify(instruction));
        }
      }
      if (Object.keys(instructions).length === 0) {
        Object.assign(endpointParams, clientConfig);
      }
      if (String(clientConfig.serviceId).toLowerCase() === "s3") {
        await resolveParamsForS35(endpointParams);
      }
      return endpointParams;
    }, "resolveParams");
    var endpointMiddleware5 = /* @__PURE__ */ __name(({ config: config2, instructions }) => {
      return (next, context) => async (args) => {
        if (config2.isCustomEndpoint) {
          core.setFeature(context, "ENDPOINT_OVERRIDE", "N");
        }
        const endpoint = await getEndpointFromInstructions7(args.input, {
          getEndpointParameterInstructions() {
            return instructions;
          }
        }, { ...config2 }, context);
        context.endpointV2 = endpoint;
        context.authSchemes = endpoint.properties?.authSchemes;
        const authScheme = context.authSchemes?.[0];
        if (authScheme) {
          context["signing_region"] = authScheme.signingRegion;
          context["signing_service"] = authScheme.signingName;
          const smithyContext = utilMiddleware.getSmithyContext(context);
          const httpAuthOption = smithyContext?.selectedHttpAuthScheme?.httpAuthOption;
          if (httpAuthOption) {
            httpAuthOption.signingProperties = Object.assign(httpAuthOption.signingProperties || {}, {
              signing_region: authScheme.signingRegion,
              signingRegion: authScheme.signingRegion,
              signing_service: authScheme.signingName,
              signingName: authScheme.signingName,
              signingRegionSet: authScheme.signingRegionSet
            }, authScheme.properties);
          }
        }
        return next({
          ...args
        });
      };
    }, "endpointMiddleware");
    var endpointMiddlewareOptions5 = {
      step: "serialize",
      tags: ["ENDPOINT_PARAMETERS", "ENDPOINT_V2", "ENDPOINT"],
      name: "endpointV2Middleware",
      override: true,
      relation: "before",
      toMiddleware: middlewareSerde.serializerMiddlewareOption.name
    };
    var getEndpointPlugin41 = /* @__PURE__ */ __name((config2, instructions) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.addRelativeTo(endpointMiddleware5({
          config: config2,
          instructions
        }), endpointMiddlewareOptions5);
      }, "applyToStack")
    }), "getEndpointPlugin");
    var resolveEndpointConfig32 = /* @__PURE__ */ __name((input) => {
      const tls = input.tls ?? true;
      const { endpoint, useDualstackEndpoint, useFipsEndpoint } = input;
      const customEndpointProvider = endpoint != null ? async () => toEndpointV17(await utilMiddleware.normalizeProvider(endpoint)()) : void 0;
      const isCustomEndpoint = !!endpoint;
      const resolvedConfig = Object.assign(input, {
        endpoint: customEndpointProvider,
        tls,
        isCustomEndpoint,
        useDualstackEndpoint: utilMiddleware.normalizeProvider(useDualstackEndpoint ?? false),
        useFipsEndpoint: utilMiddleware.normalizeProvider(useFipsEndpoint ?? false)
      });
      let configuredEndpointPromise = void 0;
      resolvedConfig.serviceConfiguredEndpoint = async () => {
        if (input.serviceId && !configuredEndpointPromise) {
          configuredEndpointPromise = getEndpointFromConfig5.getEndpointFromConfig(input.serviceId);
        }
        return configuredEndpointPromise;
      };
      return resolvedConfig;
    }, "resolveEndpointConfig");
    var resolveEndpointRequiredConfig3 = /* @__PURE__ */ __name((input) => {
      const { endpoint } = input;
      if (endpoint === void 0) {
        input.endpoint = async () => {
          throw new Error("@smithy/middleware-endpoint: (default endpointRuleSet) endpoint is not set - you must configure an endpoint.");
        };
      }
      return input;
    }, "resolveEndpointRequiredConfig");
    exports2.endpointMiddleware = endpointMiddleware5;
    exports2.endpointMiddlewareOptions = endpointMiddlewareOptions5;
    exports2.getEndpointFromInstructions = getEndpointFromInstructions7;
    exports2.getEndpointPlugin = getEndpointPlugin41;
    exports2.resolveEndpointConfig = resolveEndpointConfig32;
    exports2.resolveEndpointRequiredConfig = resolveEndpointRequiredConfig3;
    exports2.resolveParams = resolveParams13;
    exports2.toEndpointV1 = toEndpointV17;
  }
});

// ../../node_modules/@smithy/service-error-classification/dist-cjs/index.js
var require_dist_cjs32 = __commonJS({
  "../../node_modules/@smithy/service-error-classification/dist-cjs/index.js"(exports2) {
    "use strict";
    var CLOCK_SKEW_ERROR_CODES3 = [
      "AuthFailure",
      "InvalidSignatureException",
      "RequestExpired",
      "RequestInTheFuture",
      "RequestTimeTooSkewed",
      "SignatureDoesNotMatch"
    ];
    var THROTTLING_ERROR_CODES3 = [
      "BandwidthLimitExceeded",
      "EC2ThrottledException",
      "LimitExceededException",
      "PriorRequestNotComplete",
      "ProvisionedThroughputExceededException",
      "RequestLimitExceeded",
      "RequestThrottled",
      "RequestThrottledException",
      "SlowDown",
      "ThrottledException",
      "Throttling",
      "ThrottlingException",
      "TooManyRequestsException",
      "TransactionInProgressException"
    ];
    var TRANSIENT_ERROR_CODES3 = ["TimeoutError", "RequestTimeout", "RequestTimeoutException"];
    var TRANSIENT_ERROR_STATUS_CODES3 = [500, 502, 503, 504];
    var NODEJS_TIMEOUT_ERROR_CODES3 = ["ECONNRESET", "ECONNREFUSED", "EPIPE", "ETIMEDOUT"];
    var NODEJS_NETWORK_ERROR_CODES3 = ["EHOSTUNREACH", "ENETUNREACH", "ENOTFOUND"];
    var isRetryableByTrait3 = /* @__PURE__ */ __name((error4) => error4?.$retryable !== void 0, "isRetryableByTrait");
    var isClockSkewError3 = /* @__PURE__ */ __name((error4) => CLOCK_SKEW_ERROR_CODES3.includes(error4.name), "isClockSkewError");
    var isClockSkewCorrectedError3 = /* @__PURE__ */ __name((error4) => error4.$metadata?.clockSkewCorrected, "isClockSkewCorrectedError");
    var isBrowserNetworkError3 = /* @__PURE__ */ __name((error4) => {
      const errorMessages = /* @__PURE__ */ new Set([
        "Failed to fetch",
        "NetworkError when attempting to fetch resource",
        "The Internet connection appears to be offline",
        "Load failed",
        "Network request failed"
      ]);
      const isValid = error4 && error4 instanceof TypeError;
      if (!isValid) {
        return false;
      }
      return errorMessages.has(error4.message);
    }, "isBrowserNetworkError");
    var isThrottlingError3 = /* @__PURE__ */ __name((error4) => error4.$metadata?.httpStatusCode === 429 || THROTTLING_ERROR_CODES3.includes(error4.name) || error4.$retryable?.throttling == true, "isThrottlingError");
    var isTransientError3 = /* @__PURE__ */ __name((error4, depth = 0) => isRetryableByTrait3(error4) || isClockSkewCorrectedError3(error4) || error4.name === "InvalidSignatureException" && error4.message?.includes("Signature expired") || TRANSIENT_ERROR_CODES3.includes(error4.name) || NODEJS_TIMEOUT_ERROR_CODES3.includes(error4?.code || "") || NODEJS_NETWORK_ERROR_CODES3.includes(error4?.code || "") || TRANSIENT_ERROR_STATUS_CODES3.includes(error4.$metadata?.httpStatusCode || 0) || isBrowserNetworkError3(error4) || isNodeJsHttp2TransientError3(error4) || error4.cause !== void 0 && depth <= 10 && isTransientError3(error4.cause, depth + 1), "isTransientError");
    var isServerError3 = /* @__PURE__ */ __name((error4) => {
      if (error4.$metadata?.httpStatusCode !== void 0) {
        const statusCode = error4.$metadata.httpStatusCode;
        if (500 <= statusCode && statusCode <= 599 && !isTransientError3(error4)) {
          return true;
        }
        return false;
      }
      return false;
    }, "isServerError");
    function isNodeJsHttp2TransientError3(error4) {
      return error4.code === "ERR_HTTP2_STREAM_ERROR" && error4.message.includes("NGHTTP2_REFUSED_STREAM");
    }
    __name(isNodeJsHttp2TransientError3, "isNodeJsHttp2TransientError");
    exports2.isBrowserNetworkError = isBrowserNetworkError3;
    exports2.isClockSkewCorrectedError = isClockSkewCorrectedError3;
    exports2.isClockSkewError = isClockSkewError3;
    exports2.isNodeJsHttp2TransientError = isNodeJsHttp2TransientError3;
    exports2.isRetryableByTrait = isRetryableByTrait3;
    exports2.isServerError = isServerError3;
    exports2.isThrottlingError = isThrottlingError3;
    exports2.isTransientError = isTransientError3;
  }
});

// ../../node_modules/@smithy/middleware-stack/dist-cjs/index.js
var require_dist_cjs33 = __commonJS({
  "../../node_modules/@smithy/middleware-stack/dist-cjs/index.js"(exports2) {
    "use strict";
    var getAllAliases3 = /* @__PURE__ */ __name((name, aliases) => {
      const _aliases = [];
      if (name) {
        _aliases.push(name);
      }
      if (aliases) {
        for (const alias of aliases) {
          _aliases.push(alias);
        }
      }
      return _aliases;
    }, "getAllAliases");
    var getMiddlewareNameWithAliases3 = /* @__PURE__ */ __name((name, aliases) => {
      return `${name || "anonymous"}${aliases && aliases.length > 0 ? ` (a.k.a. ${aliases.join(",")})` : ""}`;
    }, "getMiddlewareNameWithAliases");
    var constructStack3 = /* @__PURE__ */ __name(() => {
      let absoluteEntries = [];
      let relativeEntries = [];
      let identifyOnResolve = false;
      const entriesNameSet = /* @__PURE__ */ new Set();
      const sort = /* @__PURE__ */ __name((entries) => entries.sort((a32, b32) => stepWeights3[b32.step] - stepWeights3[a32.step] || priorityWeights3[b32.priority || "normal"] - priorityWeights3[a32.priority || "normal"]), "sort");
      const removeByName = /* @__PURE__ */ __name((toRemove) => {
        let isRemoved = false;
        const filterCb = /* @__PURE__ */ __name((entry) => {
          const aliases = getAllAliases3(entry.name, entry.aliases);
          if (aliases.includes(toRemove)) {
            isRemoved = true;
            for (const alias of aliases) {
              entriesNameSet.delete(alias);
            }
            return false;
          }
          return true;
        }, "filterCb");
        absoluteEntries = absoluteEntries.filter(filterCb);
        relativeEntries = relativeEntries.filter(filterCb);
        return isRemoved;
      }, "removeByName");
      const removeByReference = /* @__PURE__ */ __name((toRemove) => {
        let isRemoved = false;
        const filterCb = /* @__PURE__ */ __name((entry) => {
          if (entry.middleware === toRemove) {
            isRemoved = true;
            for (const alias of getAllAliases3(entry.name, entry.aliases)) {
              entriesNameSet.delete(alias);
            }
            return false;
          }
          return true;
        }, "filterCb");
        absoluteEntries = absoluteEntries.filter(filterCb);
        relativeEntries = relativeEntries.filter(filterCb);
        return isRemoved;
      }, "removeByReference");
      const cloneTo = /* @__PURE__ */ __name((toStack) => {
        absoluteEntries.forEach((entry) => {
          toStack.add(entry.middleware, { ...entry });
        });
        relativeEntries.forEach((entry) => {
          toStack.addRelativeTo(entry.middleware, { ...entry });
        });
        toStack.identifyOnResolve?.(stack.identifyOnResolve());
        return toStack;
      }, "cloneTo");
      const expandRelativeMiddlewareList = /* @__PURE__ */ __name((from) => {
        const expandedMiddlewareList = [];
        from.before.forEach((entry) => {
          if (entry.before.length === 0 && entry.after.length === 0) {
            expandedMiddlewareList.push(entry);
          } else {
            expandedMiddlewareList.push(...expandRelativeMiddlewareList(entry));
          }
        });
        expandedMiddlewareList.push(from);
        from.after.reverse().forEach((entry) => {
          if (entry.before.length === 0 && entry.after.length === 0) {
            expandedMiddlewareList.push(entry);
          } else {
            expandedMiddlewareList.push(...expandRelativeMiddlewareList(entry));
          }
        });
        return expandedMiddlewareList;
      }, "expandRelativeMiddlewareList");
      const getMiddlewareList = /* @__PURE__ */ __name((debug2 = false) => {
        const normalizedAbsoluteEntries = [];
        const normalizedRelativeEntries = [];
        const normalizedEntriesNameMap = {};
        absoluteEntries.forEach((entry) => {
          const normalizedEntry = {
            ...entry,
            before: [],
            after: []
          };
          for (const alias of getAllAliases3(normalizedEntry.name, normalizedEntry.aliases)) {
            normalizedEntriesNameMap[alias] = normalizedEntry;
          }
          normalizedAbsoluteEntries.push(normalizedEntry);
        });
        relativeEntries.forEach((entry) => {
          const normalizedEntry = {
            ...entry,
            before: [],
            after: []
          };
          for (const alias of getAllAliases3(normalizedEntry.name, normalizedEntry.aliases)) {
            normalizedEntriesNameMap[alias] = normalizedEntry;
          }
          normalizedRelativeEntries.push(normalizedEntry);
        });
        normalizedRelativeEntries.forEach((entry) => {
          if (entry.toMiddleware) {
            const toMiddleware = normalizedEntriesNameMap[entry.toMiddleware];
            if (toMiddleware === void 0) {
              if (debug2) {
                return;
              }
              throw new Error(`${entry.toMiddleware} is not found when adding ${getMiddlewareNameWithAliases3(entry.name, entry.aliases)} middleware ${entry.relation} ${entry.toMiddleware}`);
            }
            if (entry.relation === "after") {
              toMiddleware.after.push(entry);
            }
            if (entry.relation === "before") {
              toMiddleware.before.push(entry);
            }
          }
        });
        const mainChain = sort(normalizedAbsoluteEntries).map(expandRelativeMiddlewareList).reduce((wholeList, expandedMiddlewareList) => {
          wholeList.push(...expandedMiddlewareList);
          return wholeList;
        }, []);
        return mainChain;
      }, "getMiddlewareList");
      const stack = {
        add: /* @__PURE__ */ __name((middleware, options = {}) => {
          const { name, override, aliases: _aliases } = options;
          const entry = {
            step: "initialize",
            priority: "normal",
            middleware,
            ...options
          };
          const aliases = getAllAliases3(name, _aliases);
          if (aliases.length > 0) {
            if (aliases.some((alias) => entriesNameSet.has(alias))) {
              if (!override)
                throw new Error(`Duplicate middleware name '${getMiddlewareNameWithAliases3(name, _aliases)}'`);
              for (const alias of aliases) {
                const toOverrideIndex = absoluteEntries.findIndex((entry2) => entry2.name === alias || entry2.aliases?.some((a32) => a32 === alias));
                if (toOverrideIndex === -1) {
                  continue;
                }
                const toOverride = absoluteEntries[toOverrideIndex];
                if (toOverride.step !== entry.step || entry.priority !== toOverride.priority) {
                  throw new Error(`"${getMiddlewareNameWithAliases3(toOverride.name, toOverride.aliases)}" middleware with ${toOverride.priority} priority in ${toOverride.step} step cannot be overridden by "${getMiddlewareNameWithAliases3(name, _aliases)}" middleware with ${entry.priority} priority in ${entry.step} step.`);
                }
                absoluteEntries.splice(toOverrideIndex, 1);
              }
            }
            for (const alias of aliases) {
              entriesNameSet.add(alias);
            }
          }
          absoluteEntries.push(entry);
        }, "add"),
        addRelativeTo: /* @__PURE__ */ __name((middleware, options) => {
          const { name, override, aliases: _aliases } = options;
          const entry = {
            middleware,
            ...options
          };
          const aliases = getAllAliases3(name, _aliases);
          if (aliases.length > 0) {
            if (aliases.some((alias) => entriesNameSet.has(alias))) {
              if (!override)
                throw new Error(`Duplicate middleware name '${getMiddlewareNameWithAliases3(name, _aliases)}'`);
              for (const alias of aliases) {
                const toOverrideIndex = relativeEntries.findIndex((entry2) => entry2.name === alias || entry2.aliases?.some((a32) => a32 === alias));
                if (toOverrideIndex === -1) {
                  continue;
                }
                const toOverride = relativeEntries[toOverrideIndex];
                if (toOverride.toMiddleware !== entry.toMiddleware || toOverride.relation !== entry.relation) {
                  throw new Error(`"${getMiddlewareNameWithAliases3(toOverride.name, toOverride.aliases)}" middleware ${toOverride.relation} "${toOverride.toMiddleware}" middleware cannot be overridden by "${getMiddlewareNameWithAliases3(name, _aliases)}" middleware ${entry.relation} "${entry.toMiddleware}" middleware.`);
                }
                relativeEntries.splice(toOverrideIndex, 1);
              }
            }
            for (const alias of aliases) {
              entriesNameSet.add(alias);
            }
          }
          relativeEntries.push(entry);
        }, "addRelativeTo"),
        clone: /* @__PURE__ */ __name(() => cloneTo(constructStack3()), "clone"),
        use: /* @__PURE__ */ __name((plugin) => {
          plugin.applyToStack(stack);
        }, "use"),
        remove: /* @__PURE__ */ __name((toRemove) => {
          if (typeof toRemove === "string")
            return removeByName(toRemove);
          else
            return removeByReference(toRemove);
        }, "remove"),
        removeByTag: /* @__PURE__ */ __name((toRemove) => {
          let isRemoved = false;
          const filterCb = /* @__PURE__ */ __name((entry) => {
            const { tags, name, aliases: _aliases } = entry;
            if (tags && tags.includes(toRemove)) {
              const aliases = getAllAliases3(name, _aliases);
              for (const alias of aliases) {
                entriesNameSet.delete(alias);
              }
              isRemoved = true;
              return false;
            }
            return true;
          }, "filterCb");
          absoluteEntries = absoluteEntries.filter(filterCb);
          relativeEntries = relativeEntries.filter(filterCb);
          return isRemoved;
        }, "removeByTag"),
        concat: /* @__PURE__ */ __name((from) => {
          const cloned = cloneTo(constructStack3());
          cloned.use(from);
          cloned.identifyOnResolve(identifyOnResolve || cloned.identifyOnResolve() || (from.identifyOnResolve?.() ?? false));
          return cloned;
        }, "concat"),
        applyToStack: cloneTo,
        identify: /* @__PURE__ */ __name(() => {
          return getMiddlewareList(true).map((mw) => {
            const step = mw.step ?? mw.relation + " " + mw.toMiddleware;
            return getMiddlewareNameWithAliases3(mw.name, mw.aliases) + " - " + step;
          });
        }, "identify"),
        identifyOnResolve(toggle) {
          if (typeof toggle === "boolean")
            identifyOnResolve = toggle;
          return identifyOnResolve;
        },
        resolve: /* @__PURE__ */ __name((handler, context) => {
          for (const middleware of getMiddlewareList().map((entry) => entry.middleware).reverse()) {
            handler = middleware(handler, context);
          }
          if (identifyOnResolve) {
            console.log(stack.identify());
          }
          return handler;
        }, "resolve")
      };
      return stack;
    }, "constructStack");
    var stepWeights3 = {
      initialize: 5,
      serialize: 4,
      build: 3,
      finalizeRequest: 2,
      deserialize: 1
    };
    var priorityWeights3 = {
      high: 3,
      normal: 2,
      low: 1
    };
    exports2.constructStack = constructStack3;
  }
});

// ../../node_modules/@smithy/smithy-client/dist-cjs/index.js
var require_dist_cjs34 = __commonJS({
  "../../node_modules/@smithy/smithy-client/dist-cjs/index.js"(exports2) {
    "use strict";
    var middlewareStack = require_dist_cjs33();
    var types2 = require_dist_cjs();
    var schema = (init_schema4(), __toCommonJS(schema_exports));
    var serde = (init_serde(), __toCommonJS(serde_exports));
    var protocols = (init_protocols(), __toCommonJS(protocols_exports));
    var Client3 = class {
      static {
        __name(this, "Client");
      }
      config;
      middlewareStack = middlewareStack.constructStack();
      initConfig;
      handlers;
      constructor(config2) {
        this.config = config2;
        const { protocol, protocolSettings } = config2;
        if (protocolSettings) {
          if (typeof protocol === "function") {
            config2.protocol = new protocol(protocolSettings);
          }
        }
      }
      send(command, optionsOrCb, cb) {
        const options = typeof optionsOrCb !== "function" ? optionsOrCb : void 0;
        const callback = typeof optionsOrCb === "function" ? optionsOrCb : cb;
        const useHandlerCache = options === void 0 && this.config.cacheMiddleware === true;
        let handler;
        if (useHandlerCache) {
          if (!this.handlers) {
            this.handlers = /* @__PURE__ */ new WeakMap();
          }
          const handlers = this.handlers;
          if (handlers.has(command.constructor)) {
            handler = handlers.get(command.constructor);
          } else {
            handler = command.resolveMiddleware(this.middlewareStack, this.config, options);
            handlers.set(command.constructor, handler);
          }
        } else {
          delete this.handlers;
          handler = command.resolveMiddleware(this.middlewareStack, this.config, options);
        }
        if (callback) {
          handler(command).then((result2) => callback(null, result2.output), (err) => callback(err)).catch(() => {
          });
        } else {
          return handler(command).then((result2) => result2.output);
        }
      }
      destroy() {
        this.config?.requestHandler?.destroy?.();
        delete this.handlers;
      }
    };
    var SENSITIVE_STRING$1 = "***SensitiveInformation***";
    function schemaLogFilter3(schema$1, data3) {
      if (data3 == null) {
        return data3;
      }
      const ns = schema.NormalizedSchema.of(schema$1);
      if (ns.getMergedTraits().sensitive) {
        return SENSITIVE_STRING$1;
      }
      if (ns.isListSchema()) {
        const isSensitive = !!ns.getValueSchema().getMergedTraits().sensitive;
        if (isSensitive) {
          return SENSITIVE_STRING$1;
        }
      } else if (ns.isMapSchema()) {
        const isSensitive = !!ns.getKeySchema().getMergedTraits().sensitive || !!ns.getValueSchema().getMergedTraits().sensitive;
        if (isSensitive) {
          return SENSITIVE_STRING$1;
        }
      } else if (ns.isStructSchema() && typeof data3 === "object") {
        const object = data3;
        const newObject = {};
        for (const [member7, memberNs] of ns.structIterator()) {
          if (object[member7] != null) {
            newObject[member7] = schemaLogFilter3(memberNs, object[member7]);
          }
        }
        return newObject;
      }
      return data3;
    }
    __name(schemaLogFilter3, "schemaLogFilter");
    var Command3 = class {
      static {
        __name(this, "Command");
      }
      middlewareStack = middlewareStack.constructStack();
      schema;
      static classBuilder() {
        return new ClassBuilder3();
      }
      resolveMiddlewareWithContext(clientStack, configuration, options, { middlewareFn, clientName, commandName, inputFilterSensitiveLog, outputFilterSensitiveLog, smithyContext, additionalContext, CommandCtor }) {
        for (const mw of middlewareFn.bind(this)(CommandCtor, clientStack, configuration, options)) {
          this.middlewareStack.use(mw);
        }
        const stack = clientStack.concat(this.middlewareStack);
        const { logger: logger5 } = configuration;
        const handlerExecutionContext = {
          logger: logger5,
          clientName,
          commandName,
          inputFilterSensitiveLog,
          outputFilterSensitiveLog,
          [types2.SMITHY_CONTEXT_KEY]: {
            commandInstance: this,
            ...smithyContext
          },
          ...additionalContext
        };
        const { requestHandler } = configuration;
        let requestOptions = options ?? {};
        if (smithyContext.eventStream) {
          requestOptions = {
            isEventStream: true,
            ...requestOptions
          };
        }
        return stack.resolve((request4) => requestHandler.handle(request4.request, requestOptions), handlerExecutionContext);
      }
    };
    var ClassBuilder3 = class {
      static {
        __name(this, "ClassBuilder");
      }
      _init = /* @__PURE__ */ __name(() => {
      }, "_init");
      _ep = {};
      _middlewareFn = /* @__PURE__ */ __name(() => [], "_middlewareFn");
      _commandName = "";
      _clientName = "";
      _additionalContext = {};
      _smithyContext = {};
      _inputFilterSensitiveLog = void 0;
      _outputFilterSensitiveLog = void 0;
      _serializer = null;
      _deserializer = null;
      _operationSchema;
      init(cb) {
        this._init = cb;
      }
      ep(endpointParameterInstructions) {
        this._ep = endpointParameterInstructions;
        return this;
      }
      m(middlewareSupplier) {
        this._middlewareFn = middlewareSupplier;
        return this;
      }
      s(service, operation3, smithyContext = {}) {
        this._smithyContext = {
          service,
          operation: operation3,
          ...smithyContext
        };
        return this;
      }
      c(additionalContext = {}) {
        this._additionalContext = additionalContext;
        return this;
      }
      n(clientName, commandName) {
        this._clientName = clientName;
        this._commandName = commandName;
        return this;
      }
      f(inputFilter = (_) => _, outputFilter = (_) => _) {
        this._inputFilterSensitiveLog = inputFilter;
        this._outputFilterSensitiveLog = outputFilter;
        return this;
      }
      ser(serializer) {
        this._serializer = serializer;
        return this;
      }
      de(deserializer) {
        this._deserializer = deserializer;
        return this;
      }
      sc(operation3) {
        this._operationSchema = operation3;
        this._smithyContext.operationSchema = operation3;
        return this;
      }
      build() {
        const closure = this;
        let CommandRef;
        return CommandRef = class extends Command3 {
          static {
            __name(this, "CommandRef");
          }
          input;
          static getEndpointParameterInstructions() {
            return closure._ep;
          }
          constructor(...[input]) {
            super();
            this.input = input ?? {};
            closure._init(this);
            this.schema = closure._operationSchema;
          }
          resolveMiddleware(stack, configuration, options) {
            const op3 = closure._operationSchema;
            const input = op3?.[4] ?? op3?.input;
            const output = op3?.[5] ?? op3?.output;
            return this.resolveMiddlewareWithContext(stack, configuration, options, {
              CommandCtor: CommandRef,
              middlewareFn: closure._middlewareFn,
              clientName: closure._clientName,
              commandName: closure._commandName,
              inputFilterSensitiveLog: closure._inputFilterSensitiveLog ?? (op3 ? schemaLogFilter3.bind(null, input) : (_) => _),
              outputFilterSensitiveLog: closure._outputFilterSensitiveLog ?? (op3 ? schemaLogFilter3.bind(null, output) : (_) => _),
              smithyContext: closure._smithyContext,
              additionalContext: closure._additionalContext
            });
          }
          serialize = closure._serializer;
          deserialize = closure._deserializer;
        };
      }
    };
    var SENSITIVE_STRING5 = "***SensitiveInformation***";
    var createAggregatedClient30 = /* @__PURE__ */ __name((commands32, Client4, options) => {
      for (const [command, CommandCtor] of Object.entries(commands32)) {
        const methodImpl = /* @__PURE__ */ __name(async function(args, optionsOrCb, cb) {
          const command2 = new CommandCtor(args);
          if (typeof optionsOrCb === "function") {
            this.send(command2, optionsOrCb);
          } else if (typeof cb === "function") {
            if (typeof optionsOrCb !== "object")
              throw new Error(`Expected http options but got ${typeof optionsOrCb}`);
            this.send(command2, optionsOrCb || {}, cb);
          } else {
            return this.send(command2, optionsOrCb);
          }
        }, "methodImpl");
        const methodName = (command[0].toLowerCase() + command.slice(1)).replace(/Command$/, "");
        Client4.prototype[methodName] = methodImpl;
      }
      const { paginators = {}, waiters = {} } = options ?? {};
      for (const [paginatorName, paginatorFn] of Object.entries(paginators)) {
        if (Client4.prototype[paginatorName] === void 0) {
          Client4.prototype[paginatorName] = function(commandInput = {}, paginationConfiguration, ...rest) {
            return paginatorFn({
              ...paginationConfiguration,
              client: this
            }, commandInput, ...rest);
          };
        }
      }
      for (const [waiterName, waiterFn] of Object.entries(waiters)) {
        if (Client4.prototype[waiterName] === void 0) {
          Client4.prototype[waiterName] = async function(commandInput = {}, waiterConfiguration, ...rest) {
            let config2 = waiterConfiguration;
            if (typeof waiterConfiguration === "number") {
              config2 = {
                maxWaitTime: waiterConfiguration
              };
            }
            return waiterFn({
              ...config2,
              client: this
            }, commandInput, ...rest);
          };
        }
      }
    }, "createAggregatedClient");
    var ServiceException4 = class _ServiceException extends Error {
      static {
        __name(this, "ServiceException");
      }
      $fault;
      $response;
      $retryable;
      $metadata;
      constructor(options) {
        super(options.message);
        Object.setPrototypeOf(this, Object.getPrototypeOf(this).constructor.prototype);
        this.name = options.name;
        this.$fault = options.$fault;
        this.$metadata = options.$metadata;
      }
      static isInstance(value) {
        if (!value)
          return false;
        const candidate = value;
        return _ServiceException.prototype.isPrototypeOf(candidate) || Boolean(candidate.$fault) && Boolean(candidate.$metadata) && (candidate.$fault === "client" || candidate.$fault === "server");
      }
      static [Symbol.hasInstance](instance) {
        if (!instance)
          return false;
        const candidate = instance;
        if (this === _ServiceException) {
          return _ServiceException.isInstance(instance);
        }
        if (_ServiceException.isInstance(instance)) {
          if (candidate.name && this.name) {
            return this.prototype.isPrototypeOf(instance) || candidate.name === this.name;
          }
          return this.prototype.isPrototypeOf(instance);
        }
        return false;
      }
    };
    var decorateServiceException13 = /* @__PURE__ */ __name((exception, additions = {}) => {
      Object.entries(additions).filter(([, v]) => v !== void 0).forEach(([k32, v]) => {
        if (exception[k32] == void 0 || exception[k32] === "") {
          exception[k32] = v;
        }
      });
      const message2 = exception.message || exception.Message || "UnknownError";
      exception.message = message2;
      delete exception.Message;
      return exception;
    }, "decorateServiceException");
    var throwDefaultError3 = /* @__PURE__ */ __name(({ output, parsedBody, exceptionCtor, errorCode }) => {
      const $metadata = deserializeMetadata3(output);
      const statusCode = $metadata.httpStatusCode ? $metadata.httpStatusCode + "" : void 0;
      const response = new exceptionCtor({
        name: parsedBody?.code || parsedBody?.Code || errorCode || statusCode || "UnknownError",
        $fault: "client",
        $metadata
      });
      throw decorateServiceException13(response, parsedBody);
    }, "throwDefaultError");
    var withBaseException3 = /* @__PURE__ */ __name((ExceptionCtor) => {
      return ({ output, parsedBody, errorCode }) => {
        throwDefaultError3({ output, parsedBody, exceptionCtor: ExceptionCtor, errorCode });
      };
    }, "withBaseException");
    var deserializeMetadata3 = /* @__PURE__ */ __name((output) => ({
      httpStatusCode: output.statusCode,
      requestId: output.headers["x-amzn-requestid"] ?? output.headers["x-amzn-request-id"] ?? output.headers["x-amz-request-id"],
      extendedRequestId: output.headers["x-amz-id-2"],
      cfId: output.headers["x-amz-cf-id"]
    }), "deserializeMetadata");
    var loadConfigsForDefaultMode30 = /* @__PURE__ */ __name((mode) => {
      switch (mode) {
        case "standard":
          return {
            retryMode: "standard",
            connectionTimeout: 3100
          };
        case "in-region":
          return {
            retryMode: "standard",
            connectionTimeout: 1100
          };
        case "cross-region":
          return {
            retryMode: "standard",
            connectionTimeout: 3100
          };
        case "mobile":
          return {
            retryMode: "standard",
            connectionTimeout: 3e4
          };
        default:
          return {};
      }
    }, "loadConfigsForDefaultMode");
    var warningEmitted3 = false;
    var emitWarningIfUnsupportedVersion42 = /* @__PURE__ */ __name((version) => {
      if (version && !warningEmitted3 && parseInt(version.substring(1, version.indexOf("."))) < 16) {
        warningEmitted3 = true;
      }
    }, "emitWarningIfUnsupportedVersion");
    var knownAlgorithms3 = Object.values(types2.AlgorithmId);
    var getChecksumConfiguration3 = /* @__PURE__ */ __name((runtimeConfig) => {
      const checksumAlgorithms = [];
      for (const id in types2.AlgorithmId) {
        const algorithmId = types2.AlgorithmId[id];
        if (runtimeConfig[algorithmId] === void 0) {
          continue;
        }
        checksumAlgorithms.push({
          algorithmId: /* @__PURE__ */ __name(() => algorithmId, "algorithmId"),
          checksumConstructor: /* @__PURE__ */ __name(() => runtimeConfig[algorithmId], "checksumConstructor")
        });
      }
      for (const [id, ChecksumCtor] of Object.entries(runtimeConfig.checksumAlgorithms ?? {})) {
        checksumAlgorithms.push({
          algorithmId: /* @__PURE__ */ __name(() => id, "algorithmId"),
          checksumConstructor: /* @__PURE__ */ __name(() => ChecksumCtor, "checksumConstructor")
        });
      }
      return {
        addChecksumAlgorithm(algo) {
          runtimeConfig.checksumAlgorithms = runtimeConfig.checksumAlgorithms ?? {};
          const id = algo.algorithmId();
          const ctor = algo.checksumConstructor();
          if (knownAlgorithms3.includes(id)) {
            runtimeConfig.checksumAlgorithms[id.toUpperCase()] = ctor;
          } else {
            runtimeConfig.checksumAlgorithms[id] = ctor;
          }
          checksumAlgorithms.push(algo);
        },
        checksumAlgorithms() {
          return checksumAlgorithms;
        }
      };
    }, "getChecksumConfiguration");
    var resolveChecksumRuntimeConfig3 = /* @__PURE__ */ __name((clientConfig) => {
      const runtimeConfig = {};
      clientConfig.checksumAlgorithms().forEach((checksumAlgorithm) => {
        const id = checksumAlgorithm.algorithmId();
        if (knownAlgorithms3.includes(id)) {
          runtimeConfig[id] = checksumAlgorithm.checksumConstructor();
        }
      });
      return runtimeConfig;
    }, "resolveChecksumRuntimeConfig");
    var getRetryConfiguration3 = /* @__PURE__ */ __name((runtimeConfig) => {
      return {
        setRetryStrategy(retryStrategy) {
          runtimeConfig.retryStrategy = retryStrategy;
        },
        retryStrategy() {
          return runtimeConfig.retryStrategy;
        }
      };
    }, "getRetryConfiguration");
    var resolveRetryRuntimeConfig3 = /* @__PURE__ */ __name((retryStrategyConfiguration) => {
      const runtimeConfig = {};
      runtimeConfig.retryStrategy = retryStrategyConfiguration.retryStrategy();
      return runtimeConfig;
    }, "resolveRetryRuntimeConfig");
    var getDefaultExtensionConfiguration30 = /* @__PURE__ */ __name((runtimeConfig) => {
      return Object.assign(getChecksumConfiguration3(runtimeConfig), getRetryConfiguration3(runtimeConfig));
    }, "getDefaultExtensionConfiguration");
    var getDefaultClientConfiguration3 = getDefaultExtensionConfiguration30;
    var resolveDefaultRuntimeConfig30 = /* @__PURE__ */ __name((config2) => {
      return Object.assign(resolveChecksumRuntimeConfig3(config2), resolveRetryRuntimeConfig3(config2));
    }, "resolveDefaultRuntimeConfig");
    var getArrayIfSingleItem3 = /* @__PURE__ */ __name((mayBeArray) => Array.isArray(mayBeArray) ? mayBeArray : [mayBeArray], "getArrayIfSingleItem");
    var getValueFromTextNode20 = /* @__PURE__ */ __name((obj) => {
      const textNodeName = "#text";
      for (const key in obj) {
        if (obj.hasOwnProperty(key) && obj[key][textNodeName] !== void 0) {
          obj[key] = obj[key][textNodeName];
        } else if (typeof obj[key] === "object" && obj[key] !== null) {
          obj[key] = getValueFromTextNode20(obj[key]);
        }
      }
      return obj;
    }, "getValueFromTextNode");
    var isSerializableHeaderValue3 = /* @__PURE__ */ __name((value) => {
      return value != null;
    }, "isSerializableHeaderValue");
    var NoOpLogger31 = class {
      static {
        __name(this, "NoOpLogger");
      }
      trace() {
      }
      debug() {
      }
      info() {
      }
      warn() {
      }
      error() {
      }
    };
    function map5(arg0, arg1, arg2) {
      let target;
      let filter;
      let instructions;
      if (typeof arg1 === "undefined" && typeof arg2 === "undefined") {
        target = {};
        instructions = arg0;
      } else {
        target = arg0;
        if (typeof arg1 === "function") {
          filter = arg1;
          instructions = arg2;
          return mapWithFilter3(target, filter, instructions);
        } else {
          instructions = arg1;
        }
      }
      for (const key of Object.keys(instructions)) {
        if (!Array.isArray(instructions[key])) {
          target[key] = instructions[key];
          continue;
        }
        applyInstruction3(target, null, instructions, key);
      }
      return target;
    }
    __name(map5, "map");
    var convertMap3 = /* @__PURE__ */ __name((target) => {
      const output = {};
      for (const [k32, v] of Object.entries(target || {})) {
        output[k32] = [, v];
      }
      return output;
    }, "convertMap");
    var take3 = /* @__PURE__ */ __name((source, instructions) => {
      const out = {};
      for (const key in instructions) {
        applyInstruction3(out, source, instructions, key);
      }
      return out;
    }, "take");
    var mapWithFilter3 = /* @__PURE__ */ __name((target, filter, instructions) => {
      return map5(target, Object.entries(instructions).reduce((_instructions, [key, value]) => {
        if (Array.isArray(value)) {
          _instructions[key] = value;
        } else {
          if (typeof value === "function") {
            _instructions[key] = [filter, value()];
          } else {
            _instructions[key] = [filter, value];
          }
        }
        return _instructions;
      }, {}));
    }, "mapWithFilter");
    var applyInstruction3 = /* @__PURE__ */ __name((target, source, instructions, targetKey) => {
      if (source !== null) {
        let instruction = instructions[targetKey];
        if (typeof instruction === "function") {
          instruction = [, instruction];
        }
        const [filter2 = nonNullish3, valueFn = pass3, sourceKey = targetKey] = instruction;
        if (typeof filter2 === "function" && filter2(source[sourceKey]) || typeof filter2 !== "function" && !!filter2) {
          target[targetKey] = valueFn(source[sourceKey]);
        }
        return;
      }
      let [filter, value] = instructions[targetKey];
      if (typeof value === "function") {
        let _value;
        const defaultFilterPassed = filter === void 0 && (_value = value()) != null;
        const customFilterPassed = typeof filter === "function" && !!filter(void 0) || typeof filter !== "function" && !!filter;
        if (defaultFilterPassed) {
          target[targetKey] = _value;
        } else if (customFilterPassed) {
          target[targetKey] = value();
        }
      } else {
        const defaultFilterPassed = filter === void 0 && value != null;
        const customFilterPassed = typeof filter === "function" && !!filter(value) || typeof filter !== "function" && !!filter;
        if (defaultFilterPassed || customFilterPassed) {
          target[targetKey] = value;
        }
      }
    }, "applyInstruction");
    var nonNullish3 = /* @__PURE__ */ __name((_) => _ != null, "nonNullish");
    var pass3 = /* @__PURE__ */ __name((_) => _, "pass");
    var serializeFloat3 = /* @__PURE__ */ __name((value) => {
      if (value !== value) {
        return "NaN";
      }
      switch (value) {
        case Infinity:
          return "Infinity";
        case -Infinity:
          return "-Infinity";
        default:
          return value;
      }
    }, "serializeFloat");
    var serializeDateTime3 = /* @__PURE__ */ __name((date7) => date7.toISOString().replace(".000Z", "Z"), "serializeDateTime");
    var _json3 = /* @__PURE__ */ __name((obj) => {
      if (obj == null) {
        return {};
      }
      if (Array.isArray(obj)) {
        return obj.filter((_) => _ != null).map(_json3);
      }
      if (typeof obj === "object") {
        const target = {};
        for (const key of Object.keys(obj)) {
          if (obj[key] == null) {
            continue;
          }
          target[key] = _json3(obj[key]);
        }
        return target;
      }
      return obj;
    }, "_json");
    exports2.collectBody = protocols.collectBody;
    exports2.extendedEncodeURIComponent = protocols.extendedEncodeURIComponent;
    exports2.resolvedPath = protocols.resolvedPath;
    exports2.Client = Client3;
    exports2.Command = Command3;
    exports2.NoOpLogger = NoOpLogger31;
    exports2.SENSITIVE_STRING = SENSITIVE_STRING5;
    exports2.ServiceException = ServiceException4;
    exports2._json = _json3;
    exports2.convertMap = convertMap3;
    exports2.createAggregatedClient = createAggregatedClient30;
    exports2.decorateServiceException = decorateServiceException13;
    exports2.emitWarningIfUnsupportedVersion = emitWarningIfUnsupportedVersion42;
    exports2.getArrayIfSingleItem = getArrayIfSingleItem3;
    exports2.getDefaultClientConfiguration = getDefaultClientConfiguration3;
    exports2.getDefaultExtensionConfiguration = getDefaultExtensionConfiguration30;
    exports2.getValueFromTextNode = getValueFromTextNode20;
    exports2.isSerializableHeaderValue = isSerializableHeaderValue3;
    exports2.loadConfigsForDefaultMode = loadConfigsForDefaultMode30;
    exports2.map = map5;
    exports2.resolveDefaultRuntimeConfig = resolveDefaultRuntimeConfig30;
    exports2.serializeDateTime = serializeDateTime3;
    exports2.serializeFloat = serializeFloat3;
    exports2.take = take3;
    exports2.throwDefaultError = throwDefaultError3;
    exports2.withBaseException = withBaseException3;
    Object.prototype.hasOwnProperty.call(serde, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: serde["__proto__"]
    });
    Object.keys(serde).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = serde[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/middleware-retry/dist-cjs/isStreamingPayload/isStreamingPayload.js
var require_isStreamingPayload = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/middleware-retry/dist-cjs/isStreamingPayload/isStreamingPayload.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isStreamingPayload = void 0;
    var stream_1 = require("stream");
    var isStreamingPayload3 = /* @__PURE__ */ __name((request4) => request4?.body instanceof stream_1.Readable || typeof ReadableStream !== "undefined" && request4?.body instanceof ReadableStream, "isStreamingPayload");
    exports2.isStreamingPayload = isStreamingPayload3;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/middleware-retry/dist-cjs/index.js
var require_dist_cjs35 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/middleware-retry/dist-cjs/index.js"(exports2) {
    "use strict";
    var utilRetry = require_dist_cjs22();
    var protocolHttp = require_dist_cjs2();
    var serviceErrorClassification = require_dist_cjs32();
    var uuid = require_dist_cjs19();
    var utilMiddleware = require_dist_cjs6();
    var smithyClient = require_dist_cjs34();
    var isStreamingPayload3 = require_isStreamingPayload();
    var serde = (init_serde(), __toCommonJS(serde_exports));
    var asSdkError3 = /* @__PURE__ */ __name((error4) => {
      if (error4 instanceof Error)
        return error4;
      if (error4 instanceof Object)
        return Object.assign(new Error(), error4);
      if (typeof error4 === "string")
        return new Error(error4);
      return new Error(`AWS SDK error wrapper for ${error4}`);
    }, "asSdkError");
    var getDefaultRetryQuota3 = /* @__PURE__ */ __name((initialRetryTokens, options) => {
      const MAX_CAPACITY = initialRetryTokens;
      const noRetryIncrement = utilRetry.NO_RETRY_INCREMENT;
      const retryCost = utilRetry.RETRY_COST;
      const timeoutRetryCost = utilRetry.TIMEOUT_RETRY_COST;
      let availableCapacity = initialRetryTokens;
      const getCapacityAmount = /* @__PURE__ */ __name((error4) => error4.name === "TimeoutError" ? timeoutRetryCost : retryCost, "getCapacityAmount");
      const hasRetryTokens = /* @__PURE__ */ __name((error4) => getCapacityAmount(error4) <= availableCapacity, "hasRetryTokens");
      const retrieveRetryTokens = /* @__PURE__ */ __name((error4) => {
        if (!hasRetryTokens(error4)) {
          throw new Error("No retry token available");
        }
        const capacityAmount = getCapacityAmount(error4);
        availableCapacity -= capacityAmount;
        return capacityAmount;
      }, "retrieveRetryTokens");
      const releaseRetryTokens = /* @__PURE__ */ __name((capacityReleaseAmount) => {
        availableCapacity += capacityReleaseAmount ?? noRetryIncrement;
        availableCapacity = Math.min(availableCapacity, MAX_CAPACITY);
      }, "releaseRetryTokens");
      return Object.freeze({
        hasRetryTokens,
        retrieveRetryTokens,
        releaseRetryTokens
      });
    }, "getDefaultRetryQuota");
    var defaultDelayDecider3 = /* @__PURE__ */ __name((delayBase, attempts) => Math.floor(Math.min(utilRetry.MAXIMUM_RETRY_DELAY, Math.random() * 2 ** attempts * delayBase)), "defaultDelayDecider");
    var defaultRetryDecider3 = /* @__PURE__ */ __name((error4) => {
      if (!error4) {
        return false;
      }
      return serviceErrorClassification.isRetryableByTrait(error4) || serviceErrorClassification.isClockSkewError(error4) || serviceErrorClassification.isThrottlingError(error4) || serviceErrorClassification.isTransientError(error4);
    }, "defaultRetryDecider");
    var StandardRetryStrategy5 = class {
      static {
        __name(this, "StandardRetryStrategy");
      }
      maxAttemptsProvider;
      retryDecider;
      delayDecider;
      retryQuota;
      mode = utilRetry.RETRY_MODES.STANDARD;
      constructor(maxAttemptsProvider, options) {
        this.maxAttemptsProvider = maxAttemptsProvider;
        this.retryDecider = options?.retryDecider ?? defaultRetryDecider3;
        this.delayDecider = options?.delayDecider ?? defaultDelayDecider3;
        this.retryQuota = options?.retryQuota ?? getDefaultRetryQuota3(utilRetry.INITIAL_RETRY_TOKENS);
      }
      shouldRetry(error4, attempts, maxAttempts) {
        return attempts < maxAttempts && this.retryDecider(error4) && this.retryQuota.hasRetryTokens(error4);
      }
      async getMaxAttempts() {
        let maxAttempts;
        try {
          maxAttempts = await this.maxAttemptsProvider();
        } catch (error4) {
          maxAttempts = utilRetry.DEFAULT_MAX_ATTEMPTS;
        }
        return maxAttempts;
      }
      async retry(next, args, options) {
        let retryTokenAmount;
        let attempts = 0;
        let totalDelay = 0;
        const maxAttempts = await this.getMaxAttempts();
        const { request: request4 } = args;
        if (protocolHttp.HttpRequest.isInstance(request4)) {
          request4.headers[utilRetry.INVOCATION_ID_HEADER] = uuid.v4();
        }
        while (true) {
          try {
            if (protocolHttp.HttpRequest.isInstance(request4)) {
              request4.headers[utilRetry.REQUEST_HEADER] = `attempt=${attempts + 1}; max=${maxAttempts}`;
            }
            if (options?.beforeRequest) {
              await options.beforeRequest();
            }
            const { response, output } = await next(args);
            if (options?.afterRequest) {
              options.afterRequest(response);
            }
            this.retryQuota.releaseRetryTokens(retryTokenAmount);
            output.$metadata.attempts = attempts + 1;
            output.$metadata.totalRetryDelay = totalDelay;
            return { response, output };
          } catch (e32) {
            const err = asSdkError3(e32);
            attempts++;
            if (this.shouldRetry(err, attempts, maxAttempts)) {
              retryTokenAmount = this.retryQuota.retrieveRetryTokens(err);
              const delayFromDecider = this.delayDecider(serviceErrorClassification.isThrottlingError(err) ? utilRetry.THROTTLING_RETRY_DELAY_BASE : utilRetry.DEFAULT_RETRY_DELAY_BASE, attempts);
              const delayFromResponse = getDelayFromRetryAfterHeader3(err.$response);
              const delay = Math.max(delayFromResponse || 0, delayFromDecider);
              totalDelay += delay;
              await new Promise((resolve13) => setTimeout(resolve13, delay));
              continue;
            }
            if (!err.$metadata) {
              err.$metadata = {};
            }
            err.$metadata.attempts = attempts;
            err.$metadata.totalRetryDelay = totalDelay;
            throw err;
          }
        }
      }
    };
    var getDelayFromRetryAfterHeader3 = /* @__PURE__ */ __name((response) => {
      if (!protocolHttp.HttpResponse.isInstance(response))
        return;
      const retryAfterHeaderName = Object.keys(response.headers).find((key) => key.toLowerCase() === "retry-after");
      if (!retryAfterHeaderName)
        return;
      const retryAfter = response.headers[retryAfterHeaderName];
      const retryAfterSeconds = Number(retryAfter);
      if (!Number.isNaN(retryAfterSeconds))
        return retryAfterSeconds * 1e3;
      const retryAfterDate = new Date(retryAfter);
      return retryAfterDate.getTime() - Date.now();
    }, "getDelayFromRetryAfterHeader");
    var AdaptiveRetryStrategy5 = class extends StandardRetryStrategy5 {
      static {
        __name(this, "AdaptiveRetryStrategy");
      }
      rateLimiter;
      constructor(maxAttemptsProvider, options) {
        const { rateLimiter, ...superOptions } = options ?? {};
        super(maxAttemptsProvider, superOptions);
        this.rateLimiter = rateLimiter ?? new utilRetry.DefaultRateLimiter();
        this.mode = utilRetry.RETRY_MODES.ADAPTIVE;
      }
      async retry(next, args) {
        return super.retry(next, args, {
          beforeRequest: /* @__PURE__ */ __name(async () => {
            return this.rateLimiter.getSendToken();
          }, "beforeRequest"),
          afterRequest: /* @__PURE__ */ __name((response) => {
            this.rateLimiter.updateClientSendingRate(response);
          }, "afterRequest")
        });
      }
    };
    var ENV_MAX_ATTEMPTS3 = "AWS_MAX_ATTEMPTS";
    var CONFIG_MAX_ATTEMPTS3 = "max_attempts";
    var NODE_MAX_ATTEMPT_CONFIG_OPTIONS30 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => {
        const value = env3[ENV_MAX_ATTEMPTS3];
        if (!value)
          return void 0;
        const maxAttempt = parseInt(value);
        if (Number.isNaN(maxAttempt)) {
          throw new Error(`Environment variable ${ENV_MAX_ATTEMPTS3} mast be a number, got "${value}"`);
        }
        return maxAttempt;
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => {
        const value = profile[CONFIG_MAX_ATTEMPTS3];
        if (!value)
          return void 0;
        const maxAttempt = parseInt(value);
        if (Number.isNaN(maxAttempt)) {
          throw new Error(`Shared config file entry ${CONFIG_MAX_ATTEMPTS3} mast be a number, got "${value}"`);
        }
        return maxAttempt;
      }, "configFileSelector"),
      default: utilRetry.DEFAULT_MAX_ATTEMPTS
    };
    var resolveRetryConfig30 = /* @__PURE__ */ __name((input) => {
      const { retryStrategy, retryMode } = input;
      const maxAttempts = utilMiddleware.normalizeProvider(input.maxAttempts ?? utilRetry.DEFAULT_MAX_ATTEMPTS);
      let controller = retryStrategy ? Promise.resolve(retryStrategy) : void 0;
      const getDefault = /* @__PURE__ */ __name(async () => await utilMiddleware.normalizeProvider(retryMode)() === utilRetry.RETRY_MODES.ADAPTIVE ? new utilRetry.AdaptiveRetryStrategy(maxAttempts) : new utilRetry.StandardRetryStrategy(maxAttempts), "getDefault");
      return Object.assign(input, {
        maxAttempts,
        retryStrategy: /* @__PURE__ */ __name(() => controller ??= getDefault(), "retryStrategy")
      });
    }, "resolveRetryConfig");
    var ENV_RETRY_MODE3 = "AWS_RETRY_MODE";
    var CONFIG_RETRY_MODE3 = "retry_mode";
    var NODE_RETRY_MODE_CONFIG_OPTIONS30 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[ENV_RETRY_MODE3], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[CONFIG_RETRY_MODE3], "configFileSelector"),
      default: utilRetry.DEFAULT_RETRY_MODE
    };
    var omitRetryHeadersMiddleware3 = /* @__PURE__ */ __name(() => (next) => async (args) => {
      const { request: request4 } = args;
      if (protocolHttp.HttpRequest.isInstance(request4)) {
        delete request4.headers[utilRetry.INVOCATION_ID_HEADER];
        delete request4.headers[utilRetry.REQUEST_HEADER];
      }
      return next(args);
    }, "omitRetryHeadersMiddleware");
    var omitRetryHeadersMiddlewareOptions3 = {
      name: "omitRetryHeadersMiddleware",
      tags: ["RETRY", "HEADERS", "OMIT_RETRY_HEADERS"],
      relation: "before",
      toMiddleware: "awsAuthMiddleware",
      override: true
    };
    var getOmitRetryHeadersPlugin3 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.addRelativeTo(omitRetryHeadersMiddleware3(), omitRetryHeadersMiddlewareOptions3);
      }, "applyToStack")
    }), "getOmitRetryHeadersPlugin");
    function parseRetryAfterHeader3(response, logger5) {
      if (!protocolHttp.HttpResponse.isInstance(response)) {
        return;
      }
      for (const header of Object.keys(response.headers)) {
        const h32 = header.toLowerCase();
        if (h32 === "retry-after") {
          const retryAfter = response.headers[header];
          let retryAfterSeconds = NaN;
          if (retryAfter.endsWith("GMT")) {
            try {
              const date7 = serde.parseRfc7231DateTime(retryAfter);
              retryAfterSeconds = (date7.getTime() - Date.now()) / 1e3;
            } catch (e32) {
              logger5?.trace?.("Failed to parse retry-after header");
              logger5?.trace?.(e32);
            }
          } else if (retryAfter.match(/ GMT, ((\d+)|(\d+\.\d+))$/)) {
            retryAfterSeconds = Number(retryAfter.match(/ GMT, ([\d.]+)$/)?.[1]);
          } else if (retryAfter.match(/^((\d+)|(\d+\.\d+))$/)) {
            retryAfterSeconds = Number(retryAfter);
          } else if (Date.parse(retryAfter) >= Date.now()) {
            retryAfterSeconds = (Date.parse(retryAfter) - Date.now()) / 1e3;
          }
          if (isNaN(retryAfterSeconds)) {
            return;
          }
          return new Date(Date.now() + retryAfterSeconds * 1e3);
        } else if (h32 === "x-amz-retry-after") {
          const v = response.headers[header];
          const backoffMilliseconds = Number(v);
          if (isNaN(backoffMilliseconds)) {
            logger5?.trace?.(`Failed to parse x-amz-retry-after=${v}`);
            return;
          }
          return new Date(Date.now() + backoffMilliseconds);
        }
      }
    }
    __name(parseRetryAfterHeader3, "parseRetryAfterHeader");
    function getRetryAfterHint3(response, logger5) {
      return parseRetryAfterHeader3(response, logger5);
    }
    __name(getRetryAfterHint3, "getRetryAfterHint");
    var retryMiddleware3 = /* @__PURE__ */ __name((options) => (next, context) => async (args) => {
      let retryStrategy = await options.retryStrategy();
      const maxAttempts = await options.maxAttempts();
      if (isRetryStrategyV23(retryStrategy)) {
        retryStrategy = retryStrategy;
        let retryToken = await retryStrategy.acquireInitialRetryToken((context["partition_id"] ?? "") + (context.__retryLongPoll ? ":longpoll" : ""));
        let lastError = new Error();
        let attempts = 0;
        let totalRetryDelay = 0;
        const { request: request4 } = args;
        const isRequest = protocolHttp.HttpRequest.isInstance(request4);
        if (isRequest) {
          request4.headers[utilRetry.INVOCATION_ID_HEADER] = uuid.v4();
        }
        while (true) {
          try {
            if (isRequest) {
              request4.headers[utilRetry.REQUEST_HEADER] = `attempt=${attempts + 1}; max=${maxAttempts}`;
            }
            const { response, output } = await next(args);
            retryStrategy.recordSuccess(retryToken);
            output.$metadata.attempts = attempts + 1;
            output.$metadata.totalRetryDelay = totalRetryDelay;
            return { response, output };
          } catch (e32) {
            const retryErrorInfo = getRetryErrorInfo3(e32, options.logger);
            lastError = asSdkError3(e32);
            if (isRequest && isStreamingPayload3.isStreamingPayload(request4)) {
              (context.logger instanceof smithyClient.NoOpLogger ? console : context.logger)?.warn("An error was encountered in a non-retryable streaming request.");
              throw lastError;
            }
            try {
              retryToken = await retryStrategy.refreshRetryTokenForRetry(retryToken, retryErrorInfo);
            } catch (refreshError) {
              if (typeof refreshError.$backoff === "number") {
                await cooldown3(refreshError.$backoff);
              }
              if (!lastError.$metadata) {
                lastError.$metadata = {};
              }
              lastError.$metadata.attempts = attempts + 1;
              lastError.$metadata.totalRetryDelay = totalRetryDelay;
              throw lastError;
            }
            attempts = retryToken.getRetryCount();
            const delay = retryToken.getRetryDelay();
            totalRetryDelay += delay;
            await cooldown3(delay);
          }
        }
      } else {
        retryStrategy = retryStrategy;
        if (retryStrategy?.mode) {
          context.userAgent = [...context.userAgent || [], ["cfg/retry-mode", retryStrategy.mode]];
        }
        return retryStrategy.retry(next, args);
      }
    }, "retryMiddleware");
    var cooldown3 = /* @__PURE__ */ __name((ms) => new Promise((resolve13) => setTimeout(resolve13, ms)), "cooldown");
    var isRetryStrategyV23 = /* @__PURE__ */ __name((retryStrategy) => typeof retryStrategy.acquireInitialRetryToken !== "undefined" && typeof retryStrategy.refreshRetryTokenForRetry !== "undefined" && typeof retryStrategy.recordSuccess !== "undefined", "isRetryStrategyV2");
    var getRetryErrorInfo3 = /* @__PURE__ */ __name((error4, logger5) => {
      const errorInfo = {
        error: error4,
        errorType: getRetryErrorType3(error4)
      };
      const retryAfterHint = parseRetryAfterHeader3(error4.$response, logger5);
      if (retryAfterHint) {
        errorInfo.retryAfterHint = retryAfterHint;
      }
      return errorInfo;
    }, "getRetryErrorInfo");
    var getRetryErrorType3 = /* @__PURE__ */ __name((error4) => {
      if (serviceErrorClassification.isThrottlingError(error4))
        return "THROTTLING";
      if (serviceErrorClassification.isTransientError(error4))
        return "TRANSIENT";
      if (serviceErrorClassification.isServerError(error4))
        return "SERVER_ERROR";
      return "CLIENT_ERROR";
    }, "getRetryErrorType");
    var retryMiddlewareOptions3 = {
      name: "retryMiddleware",
      tags: ["RETRY"],
      step: "finalizeRequest",
      priority: "high",
      override: true
    };
    var getRetryPlugin30 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(retryMiddleware3(options), retryMiddlewareOptions3);
      }, "applyToStack")
    }), "getRetryPlugin");
    exports2.AdaptiveRetryStrategy = AdaptiveRetryStrategy5;
    exports2.CONFIG_MAX_ATTEMPTS = CONFIG_MAX_ATTEMPTS3;
    exports2.CONFIG_RETRY_MODE = CONFIG_RETRY_MODE3;
    exports2.ENV_MAX_ATTEMPTS = ENV_MAX_ATTEMPTS3;
    exports2.ENV_RETRY_MODE = ENV_RETRY_MODE3;
    exports2.NODE_MAX_ATTEMPT_CONFIG_OPTIONS = NODE_MAX_ATTEMPT_CONFIG_OPTIONS30;
    exports2.NODE_RETRY_MODE_CONFIG_OPTIONS = NODE_RETRY_MODE_CONFIG_OPTIONS30;
    exports2.StandardRetryStrategy = StandardRetryStrategy5;
    exports2.defaultDelayDecider = defaultDelayDecider3;
    exports2.defaultRetryDecider = defaultRetryDecider3;
    exports2.getOmitRetryHeadersPlugin = getOmitRetryHeadersPlugin3;
    exports2.getRetryAfterHint = getRetryAfterHint3;
    exports2.getRetryPlugin = getRetryPlugin30;
    exports2.omitRetryHeadersMiddleware = omitRetryHeadersMiddleware3;
    exports2.omitRetryHeadersMiddlewareOptions = omitRetryHeadersMiddlewareOptions3;
    exports2.resolveRetryConfig = resolveRetryConfig30;
    exports2.retryMiddleware = retryMiddleware3;
    exports2.retryMiddlewareOptions = retryMiddlewareOptions3;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getDateHeader.js
var import_protocol_http9, getDateHeader;
var init_getDateHeader = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getDateHeader.js"() {
    import_protocol_http9 = __toESM(require_dist_cjs2());
    getDateHeader = /* @__PURE__ */ __name((response) => import_protocol_http9.HttpResponse.isInstance(response) ? response.headers?.date ?? response.headers?.Date : void 0, "getDateHeader");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getSkewCorrectedDate.js
var getSkewCorrectedDate;
var init_getSkewCorrectedDate = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getSkewCorrectedDate.js"() {
    getSkewCorrectedDate = /* @__PURE__ */ __name((systemClockOffset) => new Date(Date.now() + systemClockOffset), "getSkewCorrectedDate");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/isClockSkewed.js
var isClockSkewed;
var init_isClockSkewed = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/isClockSkewed.js"() {
    init_getSkewCorrectedDate();
    isClockSkewed = /* @__PURE__ */ __name((clockTime, systemClockOffset) => Math.abs(getSkewCorrectedDate(systemClockOffset).getTime() - clockTime) >= 3e5, "isClockSkewed");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getUpdatedSystemClockOffset.js
var getUpdatedSystemClockOffset;
var init_getUpdatedSystemClockOffset = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getUpdatedSystemClockOffset.js"() {
    init_isClockSkewed();
    getUpdatedSystemClockOffset = /* @__PURE__ */ __name((clockTime, currentSystemClockOffset) => {
      const clockTimeInMs = Date.parse(clockTime);
      if (isClockSkewed(clockTimeInMs, currentSystemClockOffset)) {
        return clockTimeInMs - Date.now();
      }
      return currentSystemClockOffset;
    }, "getUpdatedSystemClockOffset");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/index.js
var init_utils = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/index.js"() {
    init_getDateHeader();
    init_getSkewCorrectedDate();
    init_getUpdatedSystemClockOffset();
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4Signer.js
var import_protocol_http10, throwSigningPropertyError, validateSigningProperties, AwsSdkSigV4Signer, AWSSDKSigV4Signer;
var init_AwsSdkSigV4Signer = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4Signer.js"() {
    import_protocol_http10 = __toESM(require_dist_cjs2());
    init_utils();
    throwSigningPropertyError = /* @__PURE__ */ __name((name, property) => {
      if (!property) {
        throw new Error(`Property \`${name}\` is not resolved for AWS SDK SigV4Auth`);
      }
      return property;
    }, "throwSigningPropertyError");
    validateSigningProperties = /* @__PURE__ */ __name(async (signingProperties) => {
      const context = throwSigningPropertyError("context", signingProperties.context);
      const config2 = throwSigningPropertyError("config", signingProperties.config);
      const authScheme = context.endpointV2?.properties?.authSchemes?.[0];
      const signerFunction = throwSigningPropertyError("signer", config2.signer);
      const signer = await signerFunction(authScheme);
      const signingRegion = signingProperties?.signingRegion;
      const signingRegionSet = signingProperties?.signingRegionSet;
      const signingName = signingProperties?.signingName;
      return {
        config: config2,
        signer,
        signingRegion,
        signingRegionSet,
        signingName
      };
    }, "validateSigningProperties");
    AwsSdkSigV4Signer = class {
      static {
        __name(this, "AwsSdkSigV4Signer");
      }
      async sign(httpRequest, identity, signingProperties) {
        if (!import_protocol_http10.HttpRequest.isInstance(httpRequest)) {
          throw new Error("The request is not an instance of `HttpRequest` and cannot be signed");
        }
        const validatedProps = await validateSigningProperties(signingProperties);
        const { config: config2, signer } = validatedProps;
        let { signingRegion, signingName } = validatedProps;
        const handlerExecutionContext = signingProperties.context;
        if (handlerExecutionContext?.authSchemes?.length ?? 0 > 1) {
          const [first, second] = handlerExecutionContext.authSchemes;
          if (first?.name === "sigv4a" && second?.name === "sigv4") {
            signingRegion = second?.signingRegion ?? signingRegion;
            signingName = second?.signingName ?? signingName;
          }
        }
        const signedRequest = await signer.sign(httpRequest, {
          signingDate: getSkewCorrectedDate(config2.systemClockOffset),
          signingRegion,
          signingService: signingName
        });
        return signedRequest;
      }
      errorHandler(signingProperties) {
        return (error4) => {
          const serverTime = error4.ServerTime ?? getDateHeader(error4.$response);
          if (serverTime) {
            const config2 = throwSigningPropertyError("config", signingProperties.config);
            const initialSystemClockOffset = config2.systemClockOffset;
            config2.systemClockOffset = getUpdatedSystemClockOffset(serverTime, config2.systemClockOffset);
            const clockSkewCorrected = config2.systemClockOffset !== initialSystemClockOffset;
            if (clockSkewCorrected && error4.$metadata) {
              error4.$metadata.clockSkewCorrected = true;
            }
          }
          throw error4;
        };
      }
      successHandler(httpResponse, signingProperties) {
        const dateHeader = getDateHeader(httpResponse);
        if (dateHeader) {
          const config2 = throwSigningPropertyError("config", signingProperties.config);
          config2.systemClockOffset = getUpdatedSystemClockOffset(dateHeader, config2.systemClockOffset);
        }
      }
    };
    AWSSDKSigV4Signer = AwsSdkSigV4Signer;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4ASigner.js
var import_protocol_http11, AwsSdkSigV4ASigner;
var init_AwsSdkSigV4ASigner = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4ASigner.js"() {
    import_protocol_http11 = __toESM(require_dist_cjs2());
    init_utils();
    init_AwsSdkSigV4Signer();
    AwsSdkSigV4ASigner = class extends AwsSdkSigV4Signer {
      static {
        __name(this, "AwsSdkSigV4ASigner");
      }
      async sign(httpRequest, identity, signingProperties) {
        if (!import_protocol_http11.HttpRequest.isInstance(httpRequest)) {
          throw new Error("The request is not an instance of `HttpRequest` and cannot be signed");
        }
        const { config: config2, signer, signingRegion, signingRegionSet, signingName } = await validateSigningProperties(signingProperties);
        const configResolvedSigningRegionSet = await config2.sigv4aSigningRegionSet?.();
        const multiRegionOverride = (configResolvedSigningRegionSet ?? signingRegionSet ?? [signingRegion]).join(",");
        const signedRequest = await signer.sign(httpRequest, {
          signingDate: getSkewCorrectedDate(config2.systemClockOffset),
          signingRegion: multiRegionOverride,
          signingService: signingName
        });
        return signedRequest;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getArrayForCommaSeparatedString.js
var getArrayForCommaSeparatedString;
var init_getArrayForCommaSeparatedString = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getArrayForCommaSeparatedString.js"() {
    getArrayForCommaSeparatedString = /* @__PURE__ */ __name((str) => typeof str === "string" && str.length > 0 ? str.split(",").map((item) => item.trim()) : [], "getArrayForCommaSeparatedString");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getBearerTokenEnvKey.js
var getBearerTokenEnvKey;
var init_getBearerTokenEnvKey = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getBearerTokenEnvKey.js"() {
    getBearerTokenEnvKey = /* @__PURE__ */ __name((signingName) => `AWS_BEARER_TOKEN_${signingName.replace(/[\s-]/g, "_").toUpperCase()}`, "getBearerTokenEnvKey");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/NODE_AUTH_SCHEME_PREFERENCE_OPTIONS.js
var NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY, NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY, NODE_AUTH_SCHEME_PREFERENCE_OPTIONS;
var init_NODE_AUTH_SCHEME_PREFERENCE_OPTIONS = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/NODE_AUTH_SCHEME_PREFERENCE_OPTIONS.js"() {
    init_getArrayForCommaSeparatedString();
    init_getBearerTokenEnvKey();
    NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY = "AWS_AUTH_SCHEME_PREFERENCE";
    NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY = "auth_scheme_preference";
    NODE_AUTH_SCHEME_PREFERENCE_OPTIONS = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3, options) => {
        if (options?.signingName) {
          const bearerTokenKey = getBearerTokenEnvKey(options.signingName);
          if (bearerTokenKey in env3)
            return ["httpBearerAuth"];
        }
        if (!(NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY in env3))
          return void 0;
        return getArrayForCommaSeparatedString(env3[NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY]);
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => {
        if (!(NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY in profile))
          return void 0;
        return getArrayForCommaSeparatedString(profile[NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY]);
      }, "configFileSelector"),
      default: []
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4AConfig.js
var import_property_provider, resolveAwsSdkSigV4AConfig, NODE_SIGV4A_CONFIG_OPTIONS;
var init_resolveAwsSdkSigV4AConfig = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4AConfig.js"() {
    init_dist_es();
    import_property_provider = __toESM(require_dist_cjs27());
    resolveAwsSdkSigV4AConfig = /* @__PURE__ */ __name((config2) => {
      config2.sigv4aSigningRegionSet = normalizeProvider(config2.sigv4aSigningRegionSet);
      return config2;
    }, "resolveAwsSdkSigV4AConfig");
    NODE_SIGV4A_CONFIG_OPTIONS = {
      environmentVariableSelector(env3) {
        if (env3.AWS_SIGV4A_SIGNING_REGION_SET) {
          return env3.AWS_SIGV4A_SIGNING_REGION_SET.split(",").map((_) => _.trim());
        }
        throw new import_property_provider.ProviderError("AWS_SIGV4A_SIGNING_REGION_SET not set in env.", {
          tryNextLink: true
        });
      },
      configFileSelector(profile) {
        if (profile.sigv4a_signing_region_set) {
          return (profile.sigv4a_signing_region_set ?? "").split(",").map((_) => _.trim());
        }
        throw new import_property_provider.ProviderError("sigv4a_signing_region_set not set in profile.", {
          tryNextLink: true
        });
      },
      default: void 0
    };
  }
});

// ../../node_modules/@smithy/signature-v4/dist-cjs/index.js
var require_dist_cjs36 = __commonJS({
  "../../node_modules/@smithy/signature-v4/dist-cjs/index.js"(exports2) {
    "use strict";
    var utilHexEncoding = require_dist_cjs15();
    var utilUtf8 = require_dist_cjs9();
    var isArrayBuffer7 = require_dist_cjs7();
    var protocolHttp = require_dist_cjs2();
    var utilMiddleware = require_dist_cjs6();
    var utilUriEscape = require_dist_cjs11();
    var ALGORITHM_QUERY_PARAM = "X-Amz-Algorithm";
    var CREDENTIAL_QUERY_PARAM = "X-Amz-Credential";
    var AMZ_DATE_QUERY_PARAM = "X-Amz-Date";
    var SIGNED_HEADERS_QUERY_PARAM = "X-Amz-SignedHeaders";
    var EXPIRES_QUERY_PARAM = "X-Amz-Expires";
    var SIGNATURE_QUERY_PARAM = "X-Amz-Signature";
    var TOKEN_QUERY_PARAM = "X-Amz-Security-Token";
    var REGION_SET_PARAM = "X-Amz-Region-Set";
    var AUTH_HEADER = "authorization";
    var AMZ_DATE_HEADER = AMZ_DATE_QUERY_PARAM.toLowerCase();
    var DATE_HEADER = "date";
    var GENERATED_HEADERS = [AUTH_HEADER, AMZ_DATE_HEADER, DATE_HEADER];
    var SIGNATURE_HEADER = SIGNATURE_QUERY_PARAM.toLowerCase();
    var SHA256_HEADER = "x-amz-content-sha256";
    var TOKEN_HEADER = TOKEN_QUERY_PARAM.toLowerCase();
    var HOST_HEADER = "host";
    var ALWAYS_UNSIGNABLE_HEADERS = {
      authorization: true,
      "cache-control": true,
      connection: true,
      expect: true,
      from: true,
      "keep-alive": true,
      "max-forwards": true,
      pragma: true,
      referer: true,
      te: true,
      trailer: true,
      "transfer-encoding": true,
      upgrade: true,
      "user-agent": true,
      "x-amzn-trace-id": true
    };
    var PROXY_HEADER_PATTERN = /^proxy-/;
    var SEC_HEADER_PATTERN = /^sec-/;
    var UNSIGNABLE_PATTERNS = [/^proxy-/i, /^sec-/i];
    var ALGORITHM_IDENTIFIER = "AWS4-HMAC-SHA256";
    var ALGORITHM_IDENTIFIER_V4A = "AWS4-ECDSA-P256-SHA256";
    var EVENT_ALGORITHM_IDENTIFIER = "AWS4-HMAC-SHA256-PAYLOAD";
    var UNSIGNED_PAYLOAD = "UNSIGNED-PAYLOAD";
    var MAX_CACHE_SIZE = 50;
    var KEY_TYPE_IDENTIFIER = "aws4_request";
    var MAX_PRESIGNED_TTL = 60 * 60 * 24 * 7;
    var signingKeyCache = {};
    var cacheQueue = [];
    var createScope = /* @__PURE__ */ __name((shortDate, region, service) => `${shortDate}/${region}/${service}/${KEY_TYPE_IDENTIFIER}`, "createScope");
    var getSigningKey = /* @__PURE__ */ __name(async (sha256Constructor, credentials, shortDate, region, service) => {
      const credsHash = await hmac(sha256Constructor, credentials.secretAccessKey, credentials.accessKeyId);
      const cacheKey = `${shortDate}:${region}:${service}:${utilHexEncoding.toHex(credsHash)}:${credentials.sessionToken}`;
      if (cacheKey in signingKeyCache) {
        return signingKeyCache[cacheKey];
      }
      cacheQueue.push(cacheKey);
      while (cacheQueue.length > MAX_CACHE_SIZE) {
        delete signingKeyCache[cacheQueue.shift()];
      }
      let key = `AWS4${credentials.secretAccessKey}`;
      for (const signable of [shortDate, region, service, KEY_TYPE_IDENTIFIER]) {
        key = await hmac(sha256Constructor, key, signable);
      }
      return signingKeyCache[cacheKey] = key;
    }, "getSigningKey");
    var clearCredentialCache = /* @__PURE__ */ __name(() => {
      cacheQueue.length = 0;
      Object.keys(signingKeyCache).forEach((cacheKey) => {
        delete signingKeyCache[cacheKey];
      });
    }, "clearCredentialCache");
    var hmac = /* @__PURE__ */ __name((ctor, secret, data3) => {
      const hash = new ctor(secret);
      hash.update(utilUtf8.toUint8Array(data3));
      return hash.digest();
    }, "hmac");
    var getCanonicalHeaders = /* @__PURE__ */ __name(({ headers }, unsignableHeaders, signableHeaders) => {
      const canonical = {};
      for (const headerName of Object.keys(headers).sort()) {
        if (headers[headerName] == void 0) {
          continue;
        }
        const canonicalHeaderName = headerName.toLowerCase();
        if (canonicalHeaderName in ALWAYS_UNSIGNABLE_HEADERS || unsignableHeaders?.has(canonicalHeaderName) || PROXY_HEADER_PATTERN.test(canonicalHeaderName) || SEC_HEADER_PATTERN.test(canonicalHeaderName)) {
          if (!signableHeaders || signableHeaders && !signableHeaders.has(canonicalHeaderName)) {
            continue;
          }
        }
        canonical[canonicalHeaderName] = headers[headerName].trim().replace(/\s+/g, " ");
      }
      return canonical;
    }, "getCanonicalHeaders");
    var getPayloadHash = /* @__PURE__ */ __name(async ({ headers, body }, hashConstructor) => {
      for (const headerName of Object.keys(headers)) {
        if (headerName.toLowerCase() === SHA256_HEADER) {
          return headers[headerName];
        }
      }
      if (body == void 0) {
        return "e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855";
      } else if (typeof body === "string" || ArrayBuffer.isView(body) || isArrayBuffer7.isArrayBuffer(body)) {
        const hashCtor = new hashConstructor();
        hashCtor.update(utilUtf8.toUint8Array(body));
        return utilHexEncoding.toHex(await hashCtor.digest());
      }
      return UNSIGNED_PAYLOAD;
    }, "getPayloadHash");
    var HeaderFormatter = class {
      static {
        __name(this, "HeaderFormatter");
      }
      format(headers) {
        const chunks2 = [];
        for (const headerName of Object.keys(headers)) {
          const bytes = utilUtf8.fromUtf8(headerName);
          chunks2.push(Uint8Array.from([bytes.byteLength]), bytes, this.formatHeaderValue(headers[headerName]));
        }
        const out = new Uint8Array(chunks2.reduce((carry, bytes) => carry + bytes.byteLength, 0));
        let position = 0;
        for (const chunk of chunks2) {
          out.set(chunk, position);
          position += chunk.byteLength;
        }
        return out;
      }
      formatHeaderValue(header) {
        switch (header.type) {
          case "boolean":
            return Uint8Array.from([header.value ? 0 : 1]);
          case "byte":
            return Uint8Array.from([2, header.value]);
          case "short":
            const shortView = new DataView(new ArrayBuffer(3));
            shortView.setUint8(0, 3);
            shortView.setInt16(1, header.value, false);
            return new Uint8Array(shortView.buffer);
          case "integer":
            const intView = new DataView(new ArrayBuffer(5));
            intView.setUint8(0, 4);
            intView.setInt32(1, header.value, false);
            return new Uint8Array(intView.buffer);
          case "long":
            const longBytes = new Uint8Array(9);
            longBytes[0] = 5;
            longBytes.set(header.value.bytes, 1);
            return longBytes;
          case "binary":
            const binView = new DataView(new ArrayBuffer(3 + header.value.byteLength));
            binView.setUint8(0, 6);
            binView.setUint16(1, header.value.byteLength, false);
            const binBytes = new Uint8Array(binView.buffer);
            binBytes.set(header.value, 3);
            return binBytes;
          case "string":
            const utf8Bytes = utilUtf8.fromUtf8(header.value);
            const strView = new DataView(new ArrayBuffer(3 + utf8Bytes.byteLength));
            strView.setUint8(0, 7);
            strView.setUint16(1, utf8Bytes.byteLength, false);
            const strBytes = new Uint8Array(strView.buffer);
            strBytes.set(utf8Bytes, 3);
            return strBytes;
          case "timestamp":
            const tsBytes = new Uint8Array(9);
            tsBytes[0] = 8;
            tsBytes.set(Int646.fromNumber(header.value.valueOf()).bytes, 1);
            return tsBytes;
          case "uuid":
            if (!UUID_PATTERN6.test(header.value)) {
              throw new Error(`Invalid UUID received: ${header.value}`);
            }
            const uuidBytes = new Uint8Array(17);
            uuidBytes[0] = 9;
            uuidBytes.set(utilHexEncoding.fromHex(header.value.replace(/\-/g, "")), 1);
            return uuidBytes;
        }
      }
    };
    var HEADER_VALUE_TYPE6;
    (function(HEADER_VALUE_TYPE7) {
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["boolTrue"] = 0] = "boolTrue";
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["boolFalse"] = 1] = "boolFalse";
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["byte"] = 2] = "byte";
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["short"] = 3] = "short";
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["integer"] = 4] = "integer";
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["long"] = 5] = "long";
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["byteArray"] = 6] = "byteArray";
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["string"] = 7] = "string";
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["timestamp"] = 8] = "timestamp";
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["uuid"] = 9] = "uuid";
    })(HEADER_VALUE_TYPE6 || (HEADER_VALUE_TYPE6 = {}));
    var UUID_PATTERN6 = /^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$/;
    var Int646 = class _Int64 {
      static {
        __name(this, "Int64");
      }
      bytes;
      constructor(bytes) {
        this.bytes = bytes;
        if (bytes.byteLength !== 8) {
          throw new Error("Int64 buffers must be exactly 8 bytes");
        }
      }
      static fromNumber(number) {
        if (number > 9223372036854776e3 || number < -9223372036854776e3) {
          throw new Error(`${number} is too large (or, if negative, too small) to represent as an Int64`);
        }
        const bytes = new Uint8Array(8);
        for (let i32 = 7, remaining = Math.abs(Math.round(number)); i32 > -1 && remaining > 0; i32--, remaining /= 256) {
          bytes[i32] = remaining;
        }
        if (number < 0) {
          negate6(bytes);
        }
        return new _Int64(bytes);
      }
      valueOf() {
        const bytes = this.bytes.slice(0);
        const negative = bytes[0] & 128;
        if (negative) {
          negate6(bytes);
        }
        return parseInt(utilHexEncoding.toHex(bytes), 16) * (negative ? -1 : 1);
      }
      toString() {
        return String(this.valueOf());
      }
    };
    function negate6(bytes) {
      for (let i32 = 0; i32 < 8; i32++) {
        bytes[i32] ^= 255;
      }
      for (let i32 = 7; i32 > -1; i32--) {
        bytes[i32]++;
        if (bytes[i32] !== 0)
          break;
      }
    }
    __name(negate6, "negate");
    var hasHeader = /* @__PURE__ */ __name((soughtHeader, headers) => {
      soughtHeader = soughtHeader.toLowerCase();
      for (const headerName of Object.keys(headers)) {
        if (soughtHeader === headerName.toLowerCase()) {
          return true;
        }
      }
      return false;
    }, "hasHeader");
    var moveHeadersToQuery = /* @__PURE__ */ __name((request4, options = {}) => {
      const { headers, query = {} } = protocolHttp.HttpRequest.clone(request4);
      for (const name of Object.keys(headers)) {
        const lname = name.toLowerCase();
        if (lname.slice(0, 6) === "x-amz-" && !options.unhoistableHeaders?.has(lname) || options.hoistableHeaders?.has(lname)) {
          query[name] = headers[name];
          delete headers[name];
        }
      }
      return {
        ...request4,
        headers,
        query
      };
    }, "moveHeadersToQuery");
    var prepareRequest = /* @__PURE__ */ __name((request4) => {
      request4 = protocolHttp.HttpRequest.clone(request4);
      for (const headerName of Object.keys(request4.headers)) {
        if (GENERATED_HEADERS.indexOf(headerName.toLowerCase()) > -1) {
          delete request4.headers[headerName];
        }
      }
      return request4;
    }, "prepareRequest");
    var getCanonicalQuery = /* @__PURE__ */ __name(({ query = {} }) => {
      const keys = [];
      const serialized = {};
      for (const key of Object.keys(query)) {
        if (key.toLowerCase() === SIGNATURE_HEADER) {
          continue;
        }
        const encodedKey = utilUriEscape.escapeUri(key);
        keys.push(encodedKey);
        const value = query[key];
        if (typeof value === "string") {
          serialized[encodedKey] = `${encodedKey}=${utilUriEscape.escapeUri(value)}`;
        } else if (Array.isArray(value)) {
          serialized[encodedKey] = value.slice(0).reduce((encoded, value2) => encoded.concat([`${encodedKey}=${utilUriEscape.escapeUri(value2)}`]), []).sort().join("&");
        }
      }
      return keys.sort().map((key) => serialized[key]).filter((serialized2) => serialized2).join("&");
    }, "getCanonicalQuery");
    var iso8601 = /* @__PURE__ */ __name((time7) => toDate(time7).toISOString().replace(/\.\d{3}Z$/, "Z"), "iso8601");
    var toDate = /* @__PURE__ */ __name((time7) => {
      if (typeof time7 === "number") {
        return new Date(time7 * 1e3);
      }
      if (typeof time7 === "string") {
        if (Number(time7)) {
          return new Date(Number(time7) * 1e3);
        }
        return new Date(time7);
      }
      return time7;
    }, "toDate");
    var SignatureV4Base = class {
      static {
        __name(this, "SignatureV4Base");
      }
      service;
      regionProvider;
      credentialProvider;
      sha256;
      uriEscapePath;
      applyChecksum;
      constructor({ applyChecksum, credentials, region, service, sha256, uriEscapePath = true }) {
        this.service = service;
        this.sha256 = sha256;
        this.uriEscapePath = uriEscapePath;
        this.applyChecksum = typeof applyChecksum === "boolean" ? applyChecksum : true;
        this.regionProvider = utilMiddleware.normalizeProvider(region);
        this.credentialProvider = utilMiddleware.normalizeProvider(credentials);
      }
      createCanonicalRequest(request4, canonicalHeaders, payloadHash) {
        const sortedHeaders = Object.keys(canonicalHeaders).sort();
        return `${request4.method}
${this.getCanonicalPath(request4)}
${getCanonicalQuery(request4)}
${sortedHeaders.map((name) => `${name}:${canonicalHeaders[name]}`).join("\n")}

${sortedHeaders.join(";")}
${payloadHash}`;
      }
      async createStringToSign(longDate, credentialScope, canonicalRequest, algorithmIdentifier) {
        const hash = new this.sha256();
        hash.update(utilUtf8.toUint8Array(canonicalRequest));
        const hashedRequest = await hash.digest();
        return `${algorithmIdentifier}
${longDate}
${credentialScope}
${utilHexEncoding.toHex(hashedRequest)}`;
      }
      getCanonicalPath({ path: path47 }) {
        if (this.uriEscapePath) {
          const normalizedPathSegments = [];
          for (const pathSegment of path47.split("/")) {
            if (pathSegment?.length === 0)
              continue;
            if (pathSegment === ".")
              continue;
            if (pathSegment === "..") {
              normalizedPathSegments.pop();
            } else {
              normalizedPathSegments.push(pathSegment);
            }
          }
          const normalizedPath = `${path47?.startsWith("/") ? "/" : ""}${normalizedPathSegments.join("/")}${normalizedPathSegments.length > 0 && path47?.endsWith("/") ? "/" : ""}`;
          const doubleEncoded = utilUriEscape.escapeUri(normalizedPath);
          return doubleEncoded.replace(/%2F/g, "/");
        }
        return path47;
      }
      validateResolvedCredentials(credentials) {
        if (typeof credentials !== "object" || typeof credentials.accessKeyId !== "string" || typeof credentials.secretAccessKey !== "string") {
          throw new Error("Resolved credential object is not valid");
        }
      }
      formatDate(now) {
        const longDate = iso8601(now).replace(/[\-:]/g, "");
        return {
          longDate,
          shortDate: longDate.slice(0, 8)
        };
      }
      getCanonicalHeaderList(headers) {
        return Object.keys(headers).sort().join(";");
      }
    };
    var SignatureV411 = class extends SignatureV4Base {
      static {
        __name(this, "SignatureV4");
      }
      headerFormatter = new HeaderFormatter();
      constructor({ applyChecksum, credentials, region, service, sha256, uriEscapePath = true }) {
        super({
          applyChecksum,
          credentials,
          region,
          service,
          sha256,
          uriEscapePath
        });
      }
      async presign(originalRequest, options = {}) {
        const { signingDate = /* @__PURE__ */ new Date(), expiresIn = 3600, unsignableHeaders, unhoistableHeaders, signableHeaders, hoistableHeaders, signingRegion, signingService } = options;
        const credentials = await this.credentialProvider();
        this.validateResolvedCredentials(credentials);
        const region = signingRegion ?? await this.regionProvider();
        const { longDate, shortDate } = this.formatDate(signingDate);
        if (expiresIn > MAX_PRESIGNED_TTL) {
          return Promise.reject("Signature version 4 presigned URLs must have an expiration date less than one week in the future");
        }
        const scope = createScope(shortDate, region, signingService ?? this.service);
        const request4 = moveHeadersToQuery(prepareRequest(originalRequest), { unhoistableHeaders, hoistableHeaders });
        if (credentials.sessionToken) {
          request4.query[TOKEN_QUERY_PARAM] = credentials.sessionToken;
        }
        request4.query[ALGORITHM_QUERY_PARAM] = ALGORITHM_IDENTIFIER;
        request4.query[CREDENTIAL_QUERY_PARAM] = `${credentials.accessKeyId}/${scope}`;
        request4.query[AMZ_DATE_QUERY_PARAM] = longDate;
        request4.query[EXPIRES_QUERY_PARAM] = expiresIn.toString(10);
        const canonicalHeaders = getCanonicalHeaders(request4, unsignableHeaders, signableHeaders);
        request4.query[SIGNED_HEADERS_QUERY_PARAM] = this.getCanonicalHeaderList(canonicalHeaders);
        request4.query[SIGNATURE_QUERY_PARAM] = await this.getSignature(longDate, scope, this.getSigningKey(credentials, region, shortDate, signingService), this.createCanonicalRequest(request4, canonicalHeaders, await getPayloadHash(originalRequest, this.sha256)));
        return request4;
      }
      async sign(toSign, options) {
        if (typeof toSign === "string") {
          return this.signString(toSign, options);
        } else if (toSign.headers && toSign.payload) {
          return this.signEvent(toSign, options);
        } else if (toSign.message) {
          return this.signMessage(toSign, options);
        } else {
          return this.signRequest(toSign, options);
        }
      }
      async signEvent({ headers, payload: payload3 }, { signingDate = /* @__PURE__ */ new Date(), priorSignature, signingRegion, signingService, eventStreamCredentials }) {
        const region = signingRegion ?? await this.regionProvider();
        const { shortDate, longDate } = this.formatDate(signingDate);
        const scope = createScope(shortDate, region, signingService ?? this.service);
        const hashedPayload = await getPayloadHash({ headers: {}, body: payload3 }, this.sha256);
        const hash = new this.sha256();
        hash.update(headers);
        const hashedHeaders = utilHexEncoding.toHex(await hash.digest());
        const stringToSign = [
          EVENT_ALGORITHM_IDENTIFIER,
          longDate,
          scope,
          priorSignature,
          hashedHeaders,
          hashedPayload
        ].join("\n");
        return this.signString(stringToSign, {
          signingDate,
          signingRegion: region,
          signingService,
          eventStreamCredentials
        });
      }
      async signMessage(signableMessage, { signingDate = /* @__PURE__ */ new Date(), signingRegion, signingService, eventStreamCredentials }) {
        const promise = this.signEvent({
          headers: this.headerFormatter.format(signableMessage.message.headers),
          payload: signableMessage.message.body
        }, {
          signingDate,
          signingRegion,
          signingService,
          priorSignature: signableMessage.priorSignature,
          eventStreamCredentials
        });
        return promise.then((signature) => {
          return { message: signableMessage.message, signature };
        });
      }
      async signString(stringToSign, { signingDate = /* @__PURE__ */ new Date(), signingRegion, signingService, eventStreamCredentials } = {}) {
        const credentials = eventStreamCredentials ?? await this.credentialProvider();
        this.validateResolvedCredentials(credentials);
        const region = signingRegion ?? await this.regionProvider();
        const { shortDate } = this.formatDate(signingDate);
        const hash = new this.sha256(await this.getSigningKey(credentials, region, shortDate, signingService));
        hash.update(utilUtf8.toUint8Array(stringToSign));
        return utilHexEncoding.toHex(await hash.digest());
      }
      async signRequest(requestToSign, { signingDate = /* @__PURE__ */ new Date(), signableHeaders, unsignableHeaders, signingRegion, signingService } = {}) {
        const credentials = await this.credentialProvider();
        this.validateResolvedCredentials(credentials);
        const region = signingRegion ?? await this.regionProvider();
        const request4 = prepareRequest(requestToSign);
        const { longDate, shortDate } = this.formatDate(signingDate);
        const scope = createScope(shortDate, region, signingService ?? this.service);
        request4.headers[AMZ_DATE_HEADER] = longDate;
        if (credentials.sessionToken) {
          request4.headers[TOKEN_HEADER] = credentials.sessionToken;
        }
        const payloadHash = await getPayloadHash(request4, this.sha256);
        if (!hasHeader(SHA256_HEADER, request4.headers) && this.applyChecksum) {
          request4.headers[SHA256_HEADER] = payloadHash;
        }
        const canonicalHeaders = getCanonicalHeaders(request4, unsignableHeaders, signableHeaders);
        const signature = await this.getSignature(longDate, scope, this.getSigningKey(credentials, region, shortDate, signingService), this.createCanonicalRequest(request4, canonicalHeaders, payloadHash));
        request4.headers[AUTH_HEADER] = `${ALGORITHM_IDENTIFIER} Credential=${credentials.accessKeyId}/${scope}, SignedHeaders=${this.getCanonicalHeaderList(canonicalHeaders)}, Signature=${signature}`;
        return request4;
      }
      async getSignature(longDate, credentialScope, keyPromise, canonicalRequest) {
        const stringToSign = await this.createStringToSign(longDate, credentialScope, canonicalRequest, ALGORITHM_IDENTIFIER);
        const hash = new this.sha256(await keyPromise);
        hash.update(utilUtf8.toUint8Array(stringToSign));
        return utilHexEncoding.toHex(await hash.digest());
      }
      getSigningKey(credentials, region, shortDate, service) {
        return getSigningKey(this.sha256, credentials, shortDate, region, service || this.service);
      }
    };
    var signatureV4aContainer = {
      SignatureV4a: null
    };
    exports2.ALGORITHM_IDENTIFIER = ALGORITHM_IDENTIFIER;
    exports2.ALGORITHM_IDENTIFIER_V4A = ALGORITHM_IDENTIFIER_V4A;
    exports2.ALGORITHM_QUERY_PARAM = ALGORITHM_QUERY_PARAM;
    exports2.ALWAYS_UNSIGNABLE_HEADERS = ALWAYS_UNSIGNABLE_HEADERS;
    exports2.AMZ_DATE_HEADER = AMZ_DATE_HEADER;
    exports2.AMZ_DATE_QUERY_PARAM = AMZ_DATE_QUERY_PARAM;
    exports2.AUTH_HEADER = AUTH_HEADER;
    exports2.CREDENTIAL_QUERY_PARAM = CREDENTIAL_QUERY_PARAM;
    exports2.DATE_HEADER = DATE_HEADER;
    exports2.EVENT_ALGORITHM_IDENTIFIER = EVENT_ALGORITHM_IDENTIFIER;
    exports2.EXPIRES_QUERY_PARAM = EXPIRES_QUERY_PARAM;
    exports2.GENERATED_HEADERS = GENERATED_HEADERS;
    exports2.HOST_HEADER = HOST_HEADER;
    exports2.KEY_TYPE_IDENTIFIER = KEY_TYPE_IDENTIFIER;
    exports2.MAX_CACHE_SIZE = MAX_CACHE_SIZE;
    exports2.MAX_PRESIGNED_TTL = MAX_PRESIGNED_TTL;
    exports2.PROXY_HEADER_PATTERN = PROXY_HEADER_PATTERN;
    exports2.REGION_SET_PARAM = REGION_SET_PARAM;
    exports2.SEC_HEADER_PATTERN = SEC_HEADER_PATTERN;
    exports2.SHA256_HEADER = SHA256_HEADER;
    exports2.SIGNATURE_HEADER = SIGNATURE_HEADER;
    exports2.SIGNATURE_QUERY_PARAM = SIGNATURE_QUERY_PARAM;
    exports2.SIGNED_HEADERS_QUERY_PARAM = SIGNED_HEADERS_QUERY_PARAM;
    exports2.SignatureV4 = SignatureV411;
    exports2.SignatureV4Base = SignatureV4Base;
    exports2.TOKEN_HEADER = TOKEN_HEADER;
    exports2.TOKEN_QUERY_PARAM = TOKEN_QUERY_PARAM;
    exports2.UNSIGNABLE_PATTERNS = UNSIGNABLE_PATTERNS;
    exports2.UNSIGNED_PAYLOAD = UNSIGNED_PAYLOAD;
    exports2.clearCredentialCache = clearCredentialCache;
    exports2.createScope = createScope;
    exports2.getCanonicalHeaders = getCanonicalHeaders;
    exports2.getCanonicalQuery = getCanonicalQuery;
    exports2.getPayloadHash = getPayloadHash;
    exports2.getSigningKey = getSigningKey;
    exports2.hasHeader = hasHeader;
    exports2.moveHeadersToQuery = moveHeadersToQuery;
    exports2.prepareRequest = prepareRequest;
    exports2.signatureV4aContainer = signatureV4aContainer;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4Config.js
function normalizeCredentialProvider(config2, { credentials, credentialDefaultProvider }) {
  let credentialsProvider;
  if (credentials) {
    if (!credentials?.memoized) {
      credentialsProvider = memoizeIdentityProvider(credentials, isIdentityExpired, doesIdentityRequireRefresh);
    } else {
      credentialsProvider = credentials;
    }
  } else {
    if (credentialDefaultProvider) {
      credentialsProvider = normalizeProvider(credentialDefaultProvider(Object.assign({}, config2, {
        parentClientConfig: config2
      })));
    } else {
      credentialsProvider = /* @__PURE__ */ __name(async () => {
        throw new Error("@aws-sdk/core::resolveAwsSdkSigV4Config - `credentials` not provided and no credentialDefaultProvider was configured.");
      }, "credentialsProvider");
    }
  }
  credentialsProvider.memoized = true;
  return credentialsProvider;
}
function bindCallerConfig(config2, credentialsProvider) {
  if (credentialsProvider.configBound) {
    return credentialsProvider;
  }
  const fn = /* @__PURE__ */ __name(async (options) => credentialsProvider({ ...options, callerClientConfig: config2 }), "fn");
  fn.memoized = credentialsProvider.memoized;
  fn.configBound = true;
  return fn;
}
var import_signature_v4, resolveAwsSdkSigV4Config, resolveAWSSDKSigV4Config;
var init_resolveAwsSdkSigV4Config = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4Config.js"() {
    init_client2();
    init_dist_es();
    import_signature_v4 = __toESM(require_dist_cjs36());
    resolveAwsSdkSigV4Config = /* @__PURE__ */ __name((config2) => {
      let inputCredentials = config2.credentials;
      let isUserSupplied = !!config2.credentials;
      let resolvedCredentials = void 0;
      Object.defineProperty(config2, "credentials", {
        set(credentials) {
          if (credentials && credentials !== inputCredentials && credentials !== resolvedCredentials) {
            isUserSupplied = true;
          }
          inputCredentials = credentials;
          const memoizedProvider = normalizeCredentialProvider(config2, {
            credentials: inputCredentials,
            credentialDefaultProvider: config2.credentialDefaultProvider
          });
          const boundProvider = bindCallerConfig(config2, memoizedProvider);
          if (isUserSupplied && !boundProvider.attributed) {
            const isCredentialObject = typeof inputCredentials === "object" && inputCredentials !== null;
            resolvedCredentials = /* @__PURE__ */ __name(async (options) => {
              const creds = await boundProvider(options);
              const attributedCreds = creds;
              if (isCredentialObject && (!attributedCreds.$source || Object.keys(attributedCreds.$source).length === 0)) {
                return setCredentialFeature(attributedCreds, "CREDENTIALS_CODE", "e");
              }
              return attributedCreds;
            }, "resolvedCredentials");
            resolvedCredentials.memoized = boundProvider.memoized;
            resolvedCredentials.configBound = boundProvider.configBound;
            resolvedCredentials.attributed = true;
          } else {
            resolvedCredentials = boundProvider;
          }
        },
        get() {
          return resolvedCredentials;
        },
        enumerable: true,
        configurable: true
      });
      config2.credentials = inputCredentials;
      const { signingEscapePath = true, systemClockOffset = config2.systemClockOffset || 0, sha256 } = config2;
      let signer;
      if (config2.signer) {
        signer = normalizeProvider(config2.signer);
      } else if (config2.regionInfoProvider) {
        signer = /* @__PURE__ */ __name(() => normalizeProvider(config2.region)().then(async (region) => [
          await config2.regionInfoProvider(region, {
            useFipsEndpoint: await config2.useFipsEndpoint(),
            useDualstackEndpoint: await config2.useDualstackEndpoint()
          }) || {},
          region
        ]).then(([regionInfo, region]) => {
          const { signingRegion, signingService } = regionInfo;
          config2.signingRegion = config2.signingRegion || signingRegion || region;
          config2.signingName = config2.signingName || signingService || config2.serviceId;
          const params = {
            ...config2,
            credentials: config2.credentials,
            region: config2.signingRegion,
            service: config2.signingName,
            sha256,
            uriEscapePath: signingEscapePath
          };
          const SignerCtor = config2.signerConstructor || import_signature_v4.SignatureV4;
          return new SignerCtor(params);
        }), "signer");
      } else {
        signer = /* @__PURE__ */ __name(async (authScheme) => {
          authScheme = Object.assign({}, {
            name: "sigv4",
            signingName: config2.signingName || config2.defaultSigningName,
            signingRegion: await normalizeProvider(config2.region)(),
            properties: {}
          }, authScheme);
          const signingRegion = authScheme.signingRegion;
          const signingService = authScheme.signingName;
          config2.signingRegion = config2.signingRegion || signingRegion;
          config2.signingName = config2.signingName || signingService || config2.serviceId;
          const params = {
            ...config2,
            credentials: config2.credentials,
            region: config2.signingRegion,
            service: config2.signingName,
            sha256,
            uriEscapePath: signingEscapePath
          };
          const SignerCtor = config2.signerConstructor || import_signature_v4.SignatureV4;
          return new SignerCtor(params);
        }, "signer");
      }
      const resolvedConfig = Object.assign(config2, {
        systemClockOffset,
        signingEscapePath,
        signer
      });
      return resolvedConfig;
    }, "resolveAwsSdkSigV4Config");
    resolveAWSSDKSigV4Config = resolveAwsSdkSigV4Config;
    __name(normalizeCredentialProvider, "normalizeCredentialProvider");
    __name(bindCallerConfig, "bindCallerConfig");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/index.js
var init_aws_sdk = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/index.js"() {
    init_AwsSdkSigV4Signer();
    init_AwsSdkSigV4ASigner();
    init_NODE_AUTH_SCHEME_PREFERENCE_OPTIONS();
    init_resolveAwsSdkSigV4AConfig();
    init_resolveAwsSdkSigV4Config();
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/index.js
var httpAuthSchemes_exports = {};
__export(httpAuthSchemes_exports, {
  AWSSDKSigV4Signer: () => AWSSDKSigV4Signer,
  AwsSdkSigV4ASigner: () => AwsSdkSigV4ASigner,
  AwsSdkSigV4Signer: () => AwsSdkSigV4Signer,
  NODE_AUTH_SCHEME_PREFERENCE_OPTIONS: () => NODE_AUTH_SCHEME_PREFERENCE_OPTIONS,
  NODE_SIGV4A_CONFIG_OPTIONS: () => NODE_SIGV4A_CONFIG_OPTIONS,
  getBearerTokenEnvKey: () => getBearerTokenEnvKey,
  resolveAWSSDKSigV4Config: () => resolveAWSSDKSigV4Config,
  resolveAwsSdkSigV4AConfig: () => resolveAwsSdkSigV4AConfig,
  resolveAwsSdkSigV4Config: () => resolveAwsSdkSigV4Config,
  validateSigningProperties: () => validateSigningProperties
});
var init_httpAuthSchemes2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/index.js"() {
    init_aws_sdk();
    init_getBearerTokenEnvKey();
  }
});

// ../../node_modules/@aws-sdk/client-ecr/dist-cjs/auth/httpAuthSchemeProvider.js
var require_httpAuthSchemeProvider = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/dist-cjs/auth/httpAuthSchemeProvider.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.resolveHttpAuthSchemeConfig = exports2.defaultECRHttpAuthSchemeProvider = exports2.defaultECRHttpAuthSchemeParametersProvider = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes2(), __toCommonJS(httpAuthSchemes_exports));
    var util_middleware_1 = require_dist_cjs6();
    var defaultECRHttpAuthSchemeParametersProvider = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, util_middleware_1.getSmithyContext)(context).operation,
        region: await (0, util_middleware_1.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultECRHttpAuthSchemeParametersProvider");
    exports2.defaultECRHttpAuthSchemeParametersProvider = defaultECRHttpAuthSchemeParametersProvider;
    function createAwsAuthSigv4HttpAuthOption32(authParameters) {
      return {
        schemeId: "aws.auth#sigv4",
        signingProperties: {
          name: "ecr",
          region: authParameters.region
        },
        propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
          signingProperties: {
            config: config2,
            context
          }
        }), "propertiesExtractor")
      };
    }
    __name(createAwsAuthSigv4HttpAuthOption32, "createAwsAuthSigv4HttpAuthOption");
    var defaultECRHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption32(authParameters));
        }
      }
      return options;
    }, "defaultECRHttpAuthSchemeProvider");
    exports2.defaultECRHttpAuthSchemeProvider = defaultECRHttpAuthSchemeProvider;
    var resolveHttpAuthSchemeConfig32 = /* @__PURE__ */ __name((config2) => {
      const config_0 = (0, httpAuthSchemes_1.resolveAwsSdkSigV4Config)(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, util_middleware_1.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
    exports2.resolveHttpAuthSchemeConfig = resolveHttpAuthSchemeConfig32;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/package.json
var require_package = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/package.json"(exports2, module2) {
    module2.exports = {
      name: "@aws-sdk/client-ecr",
      description: "AWS SDK for JavaScript Ecr Client for Node.js, Browser and React Native",
      version: "3.1041.0",
      scripts: {
        build: "concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline client-ecr",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        "extract:docs": "api-extractor run --local",
        "generate:client": "node ../../scripts/generate-clients/single-service --solo ecr",
        "test:e2e": "yarn g:vitest run -c vitest.config.e2e.mts --mode development",
        "test:e2e:watch": "yarn g:vitest watch -c vitest.config.e2e.mts",
        "test:index": "tsc --noEmit ./test/index-types.ts && node ./test/index-objects.spec.mjs"
      },
      main: "./dist-cjs/index.js",
      types: "./dist-types/index.d.ts",
      module: "./dist-es/index.js",
      sideEffects: false,
      dependencies: {
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.8",
        "@aws-sdk/credential-provider-node": "^3.972.39",
        "@aws-sdk/middleware-host-header": "^3.972.10",
        "@aws-sdk/middleware-logger": "^3.972.10",
        "@aws-sdk/middleware-recursion-detection": "^3.972.11",
        "@aws-sdk/middleware-user-agent": "^3.972.38",
        "@aws-sdk/region-config-resolver": "^3.972.13",
        "@aws-sdk/types": "^3.973.8",
        "@aws-sdk/util-endpoints": "^3.996.8",
        "@aws-sdk/util-user-agent-browser": "^3.972.10",
        "@aws-sdk/util-user-agent-node": "^3.973.24",
        "@smithy/config-resolver": "^4.4.17",
        "@smithy/core": "^3.23.17",
        "@smithy/fetch-http-handler": "^5.3.17",
        "@smithy/hash-node": "^4.2.14",
        "@smithy/invalid-dependency": "^4.2.14",
        "@smithy/middleware-content-length": "^4.2.14",
        "@smithy/middleware-endpoint": "^4.4.32",
        "@smithy/middleware-retry": "^4.5.7",
        "@smithy/middleware-serde": "^4.2.20",
        "@smithy/middleware-stack": "^4.2.14",
        "@smithy/node-config-provider": "^4.3.14",
        "@smithy/node-http-handler": "^4.6.1",
        "@smithy/protocol-http": "^5.3.14",
        "@smithy/smithy-client": "^4.12.13",
        "@smithy/types": "^4.14.1",
        "@smithy/url-parser": "^4.2.14",
        "@smithy/util-base64": "^4.3.2",
        "@smithy/util-body-length-browser": "^4.2.2",
        "@smithy/util-body-length-node": "^4.2.3",
        "@smithy/util-defaults-mode-browser": "^4.3.49",
        "@smithy/util-defaults-mode-node": "^4.2.54",
        "@smithy/util-endpoints": "^3.4.2",
        "@smithy/util-middleware": "^4.2.14",
        "@smithy/util-retry": "^4.3.6",
        "@smithy/util-utf8": "^4.2.2",
        "@smithy/util-waiter": "^4.3.0",
        tslib: "^2.6.2"
      },
      devDependencies: {
        "@tsconfig/node20": "20.1.8",
        "@types/node": "^20.14.8",
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3"
      },
      engines: {
        node: ">=20.0.0"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "dist-*/**"
      ],
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      browser: {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.browser"
      },
      "react-native": {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.native"
      },
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/clients/client-ecr",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "clients/client-ecr"
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-env/dist-cjs/index.js
var require_dist_cjs37 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-env/dist-cjs/index.js"(exports2) {
    "use strict";
    var client = (init_client2(), __toCommonJS(client_exports));
    var propertyProvider = require_dist_cjs27();
    var ENV_KEY = "AWS_ACCESS_KEY_ID";
    var ENV_SECRET = "AWS_SECRET_ACCESS_KEY";
    var ENV_SESSION = "AWS_SESSION_TOKEN";
    var ENV_EXPIRATION = "AWS_CREDENTIAL_EXPIRATION";
    var ENV_CREDENTIAL_SCOPE = "AWS_CREDENTIAL_SCOPE";
    var ENV_ACCOUNT_ID = "AWS_ACCOUNT_ID";
    var fromEnv6 = /* @__PURE__ */ __name((init) => async () => {
      init?.logger?.debug("@aws-sdk/credential-provider-env - fromEnv");
      const accessKeyId = process.env[ENV_KEY];
      const secretAccessKey = process.env[ENV_SECRET];
      const sessionToken = process.env[ENV_SESSION];
      const expiry = process.env[ENV_EXPIRATION];
      const credentialScope = process.env[ENV_CREDENTIAL_SCOPE];
      const accountId = process.env[ENV_ACCOUNT_ID];
      if (accessKeyId && secretAccessKey) {
        const credentials = {
          accessKeyId,
          secretAccessKey,
          ...sessionToken && { sessionToken },
          ...expiry && { expiration: new Date(expiry) },
          ...credentialScope && { credentialScope },
          ...accountId && { accountId }
        };
        client.setCredentialFeature(credentials, "CREDENTIALS_ENV_VARS", "g");
        return credentials;
      }
      throw new propertyProvider.CredentialsProviderError("Unable to find environment variable credentials.", { logger: init?.logger });
    }, "fromEnv");
    exports2.ENV_ACCOUNT_ID = ENV_ACCOUNT_ID;
    exports2.ENV_CREDENTIAL_SCOPE = ENV_CREDENTIAL_SCOPE;
    exports2.ENV_EXPIRATION = ENV_EXPIRATION;
    exports2.ENV_KEY = ENV_KEY;
    exports2.ENV_SECRET = ENV_SECRET;
    exports2.ENV_SESSION = ENV_SESSION;
    exports2.fromEnv = fromEnv6;
  }
});

// ../../node_modules/@smithy/credential-provider-imds/dist-cjs/index.js
var require_dist_cjs38 = __commonJS({
  "../../node_modules/@smithy/credential-provider-imds/dist-cjs/index.js"(exports2) {
    "use strict";
    var propertyProvider = require_dist_cjs27();
    var url = require("url");
    var buffer = require("buffer");
    var http = require("http");
    var nodeConfigProvider = require_dist_cjs29();
    var urlParser = require_dist_cjs18();
    function httpRequest(options) {
      return new Promise((resolve13, reject) => {
        const req = http.request({
          method: "GET",
          ...options,
          hostname: options.hostname?.replace(/^\[(.+)\]$/, "$1")
        });
        req.on("error", (err) => {
          reject(Object.assign(new propertyProvider.ProviderError("Unable to connect to instance metadata service"), err));
          req.destroy();
        });
        req.on("timeout", () => {
          reject(new propertyProvider.ProviderError("TimeoutError from instance metadata service"));
          req.destroy();
        });
        req.on("response", (res) => {
          const { statusCode = 400 } = res;
          if (statusCode < 200 || 300 <= statusCode) {
            reject(Object.assign(new propertyProvider.ProviderError("Error response received from instance metadata service"), { statusCode }));
            req.destroy();
          }
          const chunks2 = [];
          res.on("data", (chunk) => {
            chunks2.push(chunk);
          });
          res.on("end", () => {
            resolve13(buffer.Buffer.concat(chunks2));
            req.destroy();
          });
        });
        req.end();
      });
    }
    __name(httpRequest, "httpRequest");
    var isImdsCredentials = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.AccessKeyId === "string" && typeof arg.SecretAccessKey === "string" && typeof arg.Token === "string" && typeof arg.Expiration === "string", "isImdsCredentials");
    var fromImdsCredentials = /* @__PURE__ */ __name((creds) => ({
      accessKeyId: creds.AccessKeyId,
      secretAccessKey: creds.SecretAccessKey,
      sessionToken: creds.Token,
      expiration: new Date(creds.Expiration),
      ...creds.AccountId && { accountId: creds.AccountId }
    }), "fromImdsCredentials");
    var DEFAULT_TIMEOUT2 = 1e3;
    var DEFAULT_MAX_RETRIES = 0;
    var providerConfigFromInit = /* @__PURE__ */ __name(({ maxRetries = DEFAULT_MAX_RETRIES, timeout = DEFAULT_TIMEOUT2 }) => ({ maxRetries, timeout }), "providerConfigFromInit");
    var retry = /* @__PURE__ */ __name((toRetry, maxRetries) => {
      let promise = toRetry();
      for (let i32 = 0; i32 < maxRetries; i32++) {
        promise = promise.catch(toRetry);
      }
      return promise;
    }, "retry");
    var ENV_CMDS_FULL_URI = "AWS_CONTAINER_CREDENTIALS_FULL_URI";
    var ENV_CMDS_RELATIVE_URI = "AWS_CONTAINER_CREDENTIALS_RELATIVE_URI";
    var ENV_CMDS_AUTH_TOKEN = "AWS_CONTAINER_AUTHORIZATION_TOKEN";
    var fromContainerMetadata = /* @__PURE__ */ __name((init = {}) => {
      const { timeout, maxRetries } = providerConfigFromInit(init);
      return () => retry(async () => {
        const requestOptions = await getCmdsUri({ logger: init.logger });
        const credsResponse = JSON.parse(await requestFromEcsImds(timeout, requestOptions));
        if (!isImdsCredentials(credsResponse)) {
          throw new propertyProvider.CredentialsProviderError("Invalid response received from instance metadata service.", {
            logger: init.logger
          });
        }
        return fromImdsCredentials(credsResponse);
      }, maxRetries);
    }, "fromContainerMetadata");
    var requestFromEcsImds = /* @__PURE__ */ __name(async (timeout, options) => {
      if (process.env[ENV_CMDS_AUTH_TOKEN]) {
        options.headers = {
          ...options.headers,
          Authorization: process.env[ENV_CMDS_AUTH_TOKEN]
        };
      }
      const buffer2 = await httpRequest({
        ...options,
        timeout
      });
      return buffer2.toString();
    }, "requestFromEcsImds");
    var CMDS_IP = "169.254.170.2";
    var GREENGRASS_HOSTS = {
      localhost: true,
      "127.0.0.1": true
    };
    var GREENGRASS_PROTOCOLS = {
      "http:": true,
      "https:": true
    };
    var getCmdsUri = /* @__PURE__ */ __name(async ({ logger: logger5 }) => {
      if (process.env[ENV_CMDS_RELATIVE_URI]) {
        return {
          hostname: CMDS_IP,
          path: process.env[ENV_CMDS_RELATIVE_URI]
        };
      }
      if (process.env[ENV_CMDS_FULL_URI]) {
        const parsed = url.parse(process.env[ENV_CMDS_FULL_URI]);
        if (!parsed.hostname || !(parsed.hostname in GREENGRASS_HOSTS)) {
          throw new propertyProvider.CredentialsProviderError(`${parsed.hostname} is not a valid container metadata service hostname`, {
            tryNextLink: false,
            logger: logger5
          });
        }
        if (!parsed.protocol || !(parsed.protocol in GREENGRASS_PROTOCOLS)) {
          throw new propertyProvider.CredentialsProviderError(`${parsed.protocol} is not a valid container metadata service protocol`, {
            tryNextLink: false,
            logger: logger5
          });
        }
        return {
          ...parsed,
          port: parsed.port ? parseInt(parsed.port, 10) : void 0
        };
      }
      throw new propertyProvider.CredentialsProviderError(`The container metadata credential provider cannot be used unless the ${ENV_CMDS_RELATIVE_URI} or ${ENV_CMDS_FULL_URI} environment variable is set`, {
        tryNextLink: false,
        logger: logger5
      });
    }, "getCmdsUri");
    var InstanceMetadataV1FallbackError = class _InstanceMetadataV1FallbackError extends propertyProvider.CredentialsProviderError {
      static {
        __name(this, "InstanceMetadataV1FallbackError");
      }
      tryNextLink;
      name = "InstanceMetadataV1FallbackError";
      constructor(message2, tryNextLink = true) {
        super(message2, tryNextLink);
        this.tryNextLink = tryNextLink;
        Object.setPrototypeOf(this, _InstanceMetadataV1FallbackError.prototype);
      }
    };
    exports2.Endpoint = void 0;
    (function(Endpoint) {
      Endpoint["IPv4"] = "http://169.254.169.254";
      Endpoint["IPv6"] = "http://[fd00:ec2::254]";
    })(exports2.Endpoint || (exports2.Endpoint = {}));
    var ENV_ENDPOINT_NAME = "AWS_EC2_METADATA_SERVICE_ENDPOINT";
    var CONFIG_ENDPOINT_NAME = "ec2_metadata_service_endpoint";
    var ENDPOINT_CONFIG_OPTIONS = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[ENV_ENDPOINT_NAME], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[CONFIG_ENDPOINT_NAME], "configFileSelector"),
      default: void 0
    };
    var EndpointMode;
    (function(EndpointMode2) {
      EndpointMode2["IPv4"] = "IPv4";
      EndpointMode2["IPv6"] = "IPv6";
    })(EndpointMode || (EndpointMode = {}));
    var ENV_ENDPOINT_MODE_NAME = "AWS_EC2_METADATA_SERVICE_ENDPOINT_MODE";
    var CONFIG_ENDPOINT_MODE_NAME = "ec2_metadata_service_endpoint_mode";
    var ENDPOINT_MODE_CONFIG_OPTIONS = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[ENV_ENDPOINT_MODE_NAME], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[CONFIG_ENDPOINT_MODE_NAME], "configFileSelector"),
      default: EndpointMode.IPv4
    };
    var getInstanceMetadataEndpoint = /* @__PURE__ */ __name(async () => urlParser.parseUrl(await getFromEndpointConfig() || await getFromEndpointModeConfig()), "getInstanceMetadataEndpoint");
    var getFromEndpointConfig = /* @__PURE__ */ __name(async () => nodeConfigProvider.loadConfig(ENDPOINT_CONFIG_OPTIONS)(), "getFromEndpointConfig");
    var getFromEndpointModeConfig = /* @__PURE__ */ __name(async () => {
      const endpointMode = await nodeConfigProvider.loadConfig(ENDPOINT_MODE_CONFIG_OPTIONS)();
      switch (endpointMode) {
        case EndpointMode.IPv4:
          return exports2.Endpoint.IPv4;
        case EndpointMode.IPv6:
          return exports2.Endpoint.IPv6;
        default:
          throw new Error(`Unsupported endpoint mode: ${endpointMode}. Select from ${Object.values(EndpointMode)}`);
      }
    }, "getFromEndpointModeConfig");
    var STATIC_STABILITY_REFRESH_INTERVAL_SECONDS = 5 * 60;
    var STATIC_STABILITY_REFRESH_INTERVAL_JITTER_WINDOW_SECONDS = 5 * 60;
    var STATIC_STABILITY_DOC_URL = "https://docs.aws.amazon.com/sdkref/latest/guide/feature-static-credentials.html";
    var getExtendedInstanceMetadataCredentials = /* @__PURE__ */ __name((credentials, logger5) => {
      const refreshInterval = STATIC_STABILITY_REFRESH_INTERVAL_SECONDS + Math.floor(Math.random() * STATIC_STABILITY_REFRESH_INTERVAL_JITTER_WINDOW_SECONDS);
      const newExpiration = new Date(Date.now() + refreshInterval * 1e3);
      logger5.warn(`Attempting credential expiration extension due to a credential service availability issue. A refresh of these credentials will be attempted after ${new Date(newExpiration)}.
For more information, please visit: ` + STATIC_STABILITY_DOC_URL);
      const originalExpiration = credentials.originalExpiration ?? credentials.expiration;
      return {
        ...credentials,
        ...originalExpiration ? { originalExpiration } : {},
        expiration: newExpiration
      };
    }, "getExtendedInstanceMetadataCredentials");
    var staticStabilityProvider = /* @__PURE__ */ __name((provider, options = {}) => {
      const logger5 = options?.logger || console;
      let pastCredentials;
      return async () => {
        let credentials;
        try {
          credentials = await provider();
          if (credentials.expiration && credentials.expiration.getTime() < Date.now()) {
            credentials = getExtendedInstanceMetadataCredentials(credentials, logger5);
          }
        } catch (e32) {
          if (pastCredentials) {
            logger5.warn("Credential renew failed: ", e32);
            credentials = getExtendedInstanceMetadataCredentials(pastCredentials, logger5);
          } else {
            throw e32;
          }
        }
        pastCredentials = credentials;
        return credentials;
      };
    }, "staticStabilityProvider");
    var IMDS_PATH = "/latest/meta-data/iam/security-credentials/";
    var IMDS_TOKEN_PATH = "/latest/api/token";
    var AWS_EC2_METADATA_V1_DISABLED = "AWS_EC2_METADATA_V1_DISABLED";
    var PROFILE_AWS_EC2_METADATA_V1_DISABLED = "ec2_metadata_v1_disabled";
    var X_AWS_EC2_METADATA_TOKEN = "x-aws-ec2-metadata-token";
    var fromInstanceMetadata = /* @__PURE__ */ __name((init = {}) => staticStabilityProvider(getInstanceMetadataProvider(init), { logger: init.logger }), "fromInstanceMetadata");
    var getInstanceMetadataProvider = /* @__PURE__ */ __name((init = {}) => {
      let disableFetchToken = false;
      const { logger: logger5, profile } = init;
      const { timeout, maxRetries } = providerConfigFromInit(init);
      const getCredentials = /* @__PURE__ */ __name(async (maxRetries2, options) => {
        const isImdsV1Fallback = disableFetchToken || options.headers?.[X_AWS_EC2_METADATA_TOKEN] == null;
        if (isImdsV1Fallback) {
          let fallbackBlockedFromProfile = false;
          let fallbackBlockedFromProcessEnv = false;
          const configValue = await nodeConfigProvider.loadConfig({
            environmentVariableSelector: /* @__PURE__ */ __name((env3) => {
              const envValue = env3[AWS_EC2_METADATA_V1_DISABLED];
              fallbackBlockedFromProcessEnv = !!envValue && envValue !== "false";
              if (envValue === void 0) {
                throw new propertyProvider.CredentialsProviderError(`${AWS_EC2_METADATA_V1_DISABLED} not set in env, checking config file next.`, { logger: init.logger });
              }
              return fallbackBlockedFromProcessEnv;
            }, "environmentVariableSelector"),
            configFileSelector: /* @__PURE__ */ __name((profile2) => {
              const profileValue = profile2[PROFILE_AWS_EC2_METADATA_V1_DISABLED];
              fallbackBlockedFromProfile = !!profileValue && profileValue !== "false";
              return fallbackBlockedFromProfile;
            }, "configFileSelector"),
            default: false
          }, {
            profile
          })();
          if (init.ec2MetadataV1Disabled || configValue) {
            const causes = [];
            if (init.ec2MetadataV1Disabled)
              causes.push("credential provider initialization (runtime option ec2MetadataV1Disabled)");
            if (fallbackBlockedFromProfile)
              causes.push(`config file profile (${PROFILE_AWS_EC2_METADATA_V1_DISABLED})`);
            if (fallbackBlockedFromProcessEnv)
              causes.push(`process environment variable (${AWS_EC2_METADATA_V1_DISABLED})`);
            throw new InstanceMetadataV1FallbackError(`AWS EC2 Metadata v1 fallback has been blocked by AWS SDK configuration in the following: [${causes.join(", ")}].`);
          }
        }
        const imdsProfile = (await retry(async () => {
          let profile2;
          try {
            profile2 = await getProfile(options);
          } catch (err) {
            if (err.statusCode === 401) {
              disableFetchToken = false;
            }
            throw err;
          }
          return profile2;
        }, maxRetries2)).trim();
        return retry(async () => {
          let creds;
          try {
            creds = await getCredentialsFromProfile(imdsProfile, options, init);
          } catch (err) {
            if (err.statusCode === 401) {
              disableFetchToken = false;
            }
            throw err;
          }
          return creds;
        }, maxRetries2);
      }, "getCredentials");
      return async () => {
        const endpoint = await getInstanceMetadataEndpoint();
        if (disableFetchToken) {
          logger5?.debug("AWS SDK Instance Metadata", "using v1 fallback (no token fetch)");
          return getCredentials(maxRetries, { ...endpoint, timeout });
        } else {
          let token;
          try {
            token = (await getMetadataToken({ ...endpoint, timeout })).toString();
          } catch (error4) {
            if (error4?.statusCode === 400) {
              throw Object.assign(error4, {
                message: "EC2 Metadata token request returned error"
              });
            } else if (error4.message === "TimeoutError" || [403, 404, 405].includes(error4.statusCode)) {
              disableFetchToken = true;
            }
            logger5?.debug("AWS SDK Instance Metadata", "using v1 fallback (initial)");
            return getCredentials(maxRetries, { ...endpoint, timeout });
          }
          return getCredentials(maxRetries, {
            ...endpoint,
            headers: {
              [X_AWS_EC2_METADATA_TOKEN]: token
            },
            timeout
          });
        }
      };
    }, "getInstanceMetadataProvider");
    var getMetadataToken = /* @__PURE__ */ __name(async (options) => httpRequest({
      ...options,
      path: IMDS_TOKEN_PATH,
      method: "PUT",
      headers: {
        "x-aws-ec2-metadata-token-ttl-seconds": "21600"
      }
    }), "getMetadataToken");
    var getProfile = /* @__PURE__ */ __name(async (options) => (await httpRequest({ ...options, path: IMDS_PATH })).toString(), "getProfile");
    var getCredentialsFromProfile = /* @__PURE__ */ __name(async (profile, options, init) => {
      const credentialsResponse = JSON.parse((await httpRequest({
        ...options,
        path: IMDS_PATH + profile
      })).toString());
      if (!isImdsCredentials(credentialsResponse)) {
        throw new propertyProvider.CredentialsProviderError("Invalid response received from instance metadata service.", {
          logger: init.logger
        });
      }
      return fromImdsCredentials(credentialsResponse);
    }, "getCredentialsFromProfile");
    exports2.DEFAULT_MAX_RETRIES = DEFAULT_MAX_RETRIES;
    exports2.DEFAULT_TIMEOUT = DEFAULT_TIMEOUT2;
    exports2.ENV_CMDS_AUTH_TOKEN = ENV_CMDS_AUTH_TOKEN;
    exports2.ENV_CMDS_FULL_URI = ENV_CMDS_FULL_URI;
    exports2.ENV_CMDS_RELATIVE_URI = ENV_CMDS_RELATIVE_URI;
    exports2.fromContainerMetadata = fromContainerMetadata;
    exports2.fromInstanceMetadata = fromInstanceMetadata;
    exports2.getInstanceMetadataEndpoint = getInstanceMetadataEndpoint;
    exports2.httpRequest = httpRequest;
    exports2.providerConfigFromInit = providerConfigFromInit;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/checkUrl.js
var require_checkUrl = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/checkUrl.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.checkUrl = void 0;
    var property_provider_1 = require_dist_cjs27();
    var ECS_CONTAINER_HOST = "169.254.170.2";
    var EKS_CONTAINER_HOST_IPv4 = "169.254.170.23";
    var EKS_CONTAINER_HOST_IPv6 = "[fd00:ec2::23]";
    var checkUrl = /* @__PURE__ */ __name((url, logger5) => {
      if (url.protocol === "https:") {
        return;
      }
      if (url.hostname === ECS_CONTAINER_HOST || url.hostname === EKS_CONTAINER_HOST_IPv4 || url.hostname === EKS_CONTAINER_HOST_IPv6) {
        return;
      }
      if (url.hostname.includes("[")) {
        if (url.hostname === "[::1]" || url.hostname === "[0000:0000:0000:0000:0000:0000:0000:0001]") {
          return;
        }
      } else {
        if (url.hostname === "localhost") {
          return;
        }
        const ipComponents = url.hostname.split(".");
        const inRange = /* @__PURE__ */ __name((component) => {
          const num = parseInt(component, 10);
          return 0 <= num && num <= 255;
        }, "inRange");
        if (ipComponents[0] === "127" && inRange(ipComponents[1]) && inRange(ipComponents[2]) && inRange(ipComponents[3]) && ipComponents.length === 4) {
          return;
        }
      }
      throw new property_provider_1.CredentialsProviderError(`URL not accepted. It must either be HTTPS or match one of the following:
  - loopback CIDR 127.0.0.0/8 or [::1/128]
  - ECS container host 169.254.170.2
  - EKS container host 169.254.170.23 or [fd00:ec2::23]`, { logger: logger5 });
    }, "checkUrl");
    exports2.checkUrl = checkUrl;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.js
var require_ChecksumStream2 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ChecksumStream = void 0;
    var util_base64_1 = require_dist_cjs10();
    var stream_1 = require("stream");
    var ChecksumStream5 = class extends stream_1.Duplex {
      static {
        __name(this, "ChecksumStream");
      }
      expectedChecksum;
      checksumSourceLocation;
      checksum;
      source;
      base64Encoder;
      pendingCallback = null;
      constructor({ expectedChecksum, checksum, source, checksumSourceLocation, base64Encoder }) {
        super();
        if (typeof source.pipe === "function") {
          this.source = source;
        } else {
          throw new Error(`@smithy/util-stream: unsupported source type ${source?.constructor?.name ?? source} in ChecksumStream.`);
        }
        this.base64Encoder = base64Encoder ?? util_base64_1.toBase64;
        this.expectedChecksum = expectedChecksum;
        this.checksum = checksum;
        this.checksumSourceLocation = checksumSourceLocation;
        this.source.pipe(this);
      }
      _read(size) {
        if (this.pendingCallback) {
          const callback = this.pendingCallback;
          this.pendingCallback = null;
          callback();
        }
      }
      _write(chunk, encoding, callback) {
        try {
          this.checksum.update(chunk);
          const canPushMore = this.push(chunk);
          if (!canPushMore) {
            this.pendingCallback = callback;
            return;
          }
        } catch (e32) {
          return callback(e32);
        }
        return callback();
      }
      async _final(callback) {
        try {
          const digest = await this.checksum.digest();
          const received = this.base64Encoder(digest);
          if (this.expectedChecksum !== received) {
            return callback(new Error(`Checksum mismatch: expected "${this.expectedChecksum}" but received "${received}" in response header "${this.checksumSourceLocation}".`));
          }
        } catch (e32) {
          return callback(e32);
        }
        this.push(null);
        return callback();
      }
    };
    exports2.ChecksumStream = ChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/stream-type-check.js
var require_stream_type_check2 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/stream-type-check.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isBlob = exports2.isReadableStream = void 0;
    var isReadableStream6 = /* @__PURE__ */ __name((stream) => typeof ReadableStream === "function" && (stream?.constructor?.name === ReadableStream.name || stream instanceof ReadableStream), "isReadableStream");
    exports2.isReadableStream = isReadableStream6;
    var isBlob3 = /* @__PURE__ */ __name((blob) => {
      return typeof Blob === "function" && (blob?.constructor?.name === Blob.name || blob instanceof Blob);
    }, "isBlob");
    exports2.isBlob = isBlob3;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.browser.js
var require_ChecksumStream_browser2 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ChecksumStream = void 0;
    var ReadableStreamRef3 = typeof ReadableStream === "function" ? ReadableStream : function() {
    };
    var ChecksumStream5 = class extends ReadableStreamRef3 {
      static {
        __name(this, "ChecksumStream");
      }
    };
    exports2.ChecksumStream = ChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.browser.js
var require_createChecksumStream_browser2 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createChecksumStream = void 0;
    var util_base64_1 = require_dist_cjs10();
    var stream_type_check_1 = require_stream_type_check2();
    var ChecksumStream_browser_1 = require_ChecksumStream_browser2();
    var createChecksumStream5 = /* @__PURE__ */ __name(({ expectedChecksum, checksum, source, checksumSourceLocation, base64Encoder }) => {
      if (!(0, stream_type_check_1.isReadableStream)(source)) {
        throw new Error(`@smithy/util-stream: unsupported source type ${source?.constructor?.name ?? source} in ChecksumStream.`);
      }
      const encoder = base64Encoder ?? util_base64_1.toBase64;
      if (typeof TransformStream !== "function") {
        throw new Error("@smithy/util-stream: unable to instantiate ChecksumStream because API unavailable: ReadableStream/TransformStream.");
      }
      const transform = new TransformStream({
        start() {
        },
        async transform(chunk, controller) {
          checksum.update(chunk);
          controller.enqueue(chunk);
        },
        async flush(controller) {
          const digest = await checksum.digest();
          const received = encoder(digest);
          if (expectedChecksum !== received) {
            const error4 = new Error(`Checksum mismatch: expected "${expectedChecksum}" but received "${received}" in response header "${checksumSourceLocation}".`);
            controller.error(error4);
          } else {
            controller.terminate();
          }
        }
      });
      source.pipeThrough(transform);
      const readable = transform.readable;
      Object.setPrototypeOf(readable, ChecksumStream_browser_1.ChecksumStream.prototype);
      return readable;
    }, "createChecksumStream");
    exports2.createChecksumStream = createChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.js
var require_createChecksumStream2 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createChecksumStream = createChecksumStream5;
    var stream_type_check_1 = require_stream_type_check2();
    var ChecksumStream_1 = require_ChecksumStream2();
    var createChecksumStream_browser_1 = require_createChecksumStream_browser2();
    function createChecksumStream5(init) {
      if (typeof ReadableStream === "function" && (0, stream_type_check_1.isReadableStream)(init.source)) {
        return (0, createChecksumStream_browser_1.createChecksumStream)(init);
      }
      return new ChecksumStream_1.ChecksumStream(init);
    }
    __name(createChecksumStream5, "createChecksumStream");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/ByteArrayCollector.js
var require_ByteArrayCollector2 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/ByteArrayCollector.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ByteArrayCollector = void 0;
    var ByteArrayCollector3 = class {
      static {
        __name(this, "ByteArrayCollector");
      }
      allocByteArray;
      byteLength = 0;
      byteArrays = [];
      constructor(allocByteArray) {
        this.allocByteArray = allocByteArray;
      }
      push(byteArray) {
        this.byteArrays.push(byteArray);
        this.byteLength += byteArray.byteLength;
      }
      flush() {
        if (this.byteArrays.length === 1) {
          const bytes = this.byteArrays[0];
          this.reset();
          return bytes;
        }
        const aggregation = this.allocByteArray(this.byteLength);
        let cursor3 = 0;
        for (let i32 = 0; i32 < this.byteArrays.length; ++i32) {
          const bytes = this.byteArrays[i32];
          aggregation.set(bytes, cursor3);
          cursor3 += bytes.byteLength;
        }
        this.reset();
        return aggregation;
      }
      reset() {
        this.byteArrays = [];
        this.byteLength = 0;
      }
    };
    exports2.ByteArrayCollector = ByteArrayCollector3;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadableStream.js
var require_createBufferedReadableStream2 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadableStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createBufferedReadable = void 0;
    exports2.createBufferedReadableStream = createBufferedReadableStream3;
    exports2.merge = merge3;
    exports2.flush = flush3;
    exports2.sizeOf = sizeOf3;
    exports2.modeOf = modeOf3;
    var ByteArrayCollector_1 = require_ByteArrayCollector2();
    function createBufferedReadableStream3(upstream, size, logger5) {
      const reader = upstream.getReader();
      let streamBufferingLoggedWarning = false;
      let bytesSeen = 0;
      const buffers = ["", new ByteArrayCollector_1.ByteArrayCollector((size2) => new Uint8Array(size2))];
      let mode = -1;
      const pull = /* @__PURE__ */ __name(async (controller) => {
        const { value, done } = await reader.read();
        const chunk = value;
        if (done) {
          if (mode !== -1) {
            const remainder = flush3(buffers, mode);
            if (sizeOf3(remainder) > 0) {
              controller.enqueue(remainder);
            }
          }
          controller.close();
        } else {
          const chunkMode = modeOf3(chunk, false);
          if (mode !== chunkMode) {
            if (mode >= 0) {
              controller.enqueue(flush3(buffers, mode));
            }
            mode = chunkMode;
          }
          if (mode === -1) {
            controller.enqueue(chunk);
            return;
          }
          const chunkSize = sizeOf3(chunk);
          bytesSeen += chunkSize;
          const bufferSize = sizeOf3(buffers[mode]);
          if (chunkSize >= size && bufferSize === 0) {
            controller.enqueue(chunk);
          } else {
            const newSize = merge3(buffers, mode, chunk);
            if (!streamBufferingLoggedWarning && bytesSeen > size * 2) {
              streamBufferingLoggedWarning = true;
              logger5?.warn(`@smithy/util-stream - stream chunk size ${chunkSize} is below threshold of ${size}, automatically buffering.`);
            }
            if (newSize >= size) {
              controller.enqueue(flush3(buffers, mode));
            } else {
              await pull(controller);
            }
          }
        }
      }, "pull");
      return new ReadableStream({
        pull
      });
    }
    __name(createBufferedReadableStream3, "createBufferedReadableStream");
    exports2.createBufferedReadable = createBufferedReadableStream3;
    function merge3(buffers, mode, chunk) {
      switch (mode) {
        case 0:
          buffers[0] += chunk;
          return sizeOf3(buffers[0]);
        case 1:
        case 2:
          buffers[mode].push(chunk);
          return sizeOf3(buffers[mode]);
      }
    }
    __name(merge3, "merge");
    function flush3(buffers, mode) {
      switch (mode) {
        case 0:
          const s = buffers[0];
          buffers[0] = "";
          return s;
        case 1:
        case 2:
          return buffers[mode].flush();
      }
      throw new Error(`@smithy/util-stream - invalid index ${mode} given to flush()`);
    }
    __name(flush3, "flush");
    function sizeOf3(chunk) {
      return chunk?.byteLength ?? chunk?.length ?? 0;
    }
    __name(sizeOf3, "sizeOf");
    function modeOf3(chunk, allowBuffer = true) {
      if (allowBuffer && typeof Buffer !== "undefined" && chunk instanceof Buffer) {
        return 2;
      }
      if (chunk instanceof Uint8Array) {
        return 1;
      }
      if (typeof chunk === "string") {
        return 0;
      }
      return -1;
    }
    __name(modeOf3, "modeOf");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadable.js
var require_createBufferedReadable2 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadable.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createBufferedReadable = createBufferedReadable3;
    var node_stream_1 = require("node:stream");
    var ByteArrayCollector_1 = require_ByteArrayCollector2();
    var createBufferedReadableStream_1 = require_createBufferedReadableStream2();
    var stream_type_check_1 = require_stream_type_check2();
    function createBufferedReadable3(upstream, size, logger5) {
      if ((0, stream_type_check_1.isReadableStream)(upstream)) {
        return (0, createBufferedReadableStream_1.createBufferedReadableStream)(upstream, size, logger5);
      }
      const downstream = new node_stream_1.Readable({ read() {
      } });
      let streamBufferingLoggedWarning = false;
      let bytesSeen = 0;
      const buffers = [
        "",
        new ByteArrayCollector_1.ByteArrayCollector((size2) => new Uint8Array(size2)),
        new ByteArrayCollector_1.ByteArrayCollector((size2) => Buffer.from(new Uint8Array(size2)))
      ];
      let mode = -1;
      upstream.on("data", (chunk) => {
        const chunkMode = (0, createBufferedReadableStream_1.modeOf)(chunk, true);
        if (mode !== chunkMode) {
          if (mode >= 0) {
            downstream.push((0, createBufferedReadableStream_1.flush)(buffers, mode));
          }
          mode = chunkMode;
        }
        if (mode === -1) {
          downstream.push(chunk);
          return;
        }
        const chunkSize = (0, createBufferedReadableStream_1.sizeOf)(chunk);
        bytesSeen += chunkSize;
        const bufferSize = (0, createBufferedReadableStream_1.sizeOf)(buffers[mode]);
        if (chunkSize >= size && bufferSize === 0) {
          downstream.push(chunk);
        } else {
          const newSize = (0, createBufferedReadableStream_1.merge)(buffers, mode, chunk);
          if (!streamBufferingLoggedWarning && bytesSeen > size * 2) {
            streamBufferingLoggedWarning = true;
            logger5?.warn(`@smithy/util-stream - stream chunk size ${chunkSize} is below threshold of ${size}, automatically buffering.`);
          }
          if (newSize >= size) {
            downstream.push((0, createBufferedReadableStream_1.flush)(buffers, mode));
          }
        }
      });
      upstream.on("end", () => {
        if (mode !== -1) {
          const remainder = (0, createBufferedReadableStream_1.flush)(buffers, mode);
          if ((0, createBufferedReadableStream_1.sizeOf)(remainder) > 0) {
            downstream.push(remainder);
          }
        }
        downstream.push(null);
      });
      return downstream;
    }
    __name(createBufferedReadable3, "createBufferedReadable");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.browser.js
var require_getAwsChunkedEncodingStream_browser2 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getAwsChunkedEncodingStream = void 0;
    var getAwsChunkedEncodingStream5 = /* @__PURE__ */ __name((readableStream, options) => {
      const { base64Encoder, bodyLengthChecker, checksumAlgorithmFn, checksumLocationName, streamHasher } = options;
      const checksumRequired = base64Encoder !== void 0 && bodyLengthChecker !== void 0 && checksumAlgorithmFn !== void 0 && checksumLocationName !== void 0 && streamHasher !== void 0;
      const digest = checksumRequired ? streamHasher(checksumAlgorithmFn, readableStream) : void 0;
      const reader = readableStream.getReader();
      return new ReadableStream({
        async pull(controller) {
          const { value, done } = await reader.read();
          if (done) {
            controller.enqueue(`0\r
`);
            if (checksumRequired) {
              const checksum = base64Encoder(await digest);
              controller.enqueue(`${checksumLocationName}:${checksum}\r
`);
              controller.enqueue(`\r
`);
            }
            controller.close();
          } else {
            controller.enqueue(`${(bodyLengthChecker(value) || 0).toString(16)}\r
${value}\r
`);
          }
        }
      });
    }, "getAwsChunkedEncodingStream");
    exports2.getAwsChunkedEncodingStream = getAwsChunkedEncodingStream5;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.js
var require_getAwsChunkedEncodingStream2 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getAwsChunkedEncodingStream = getAwsChunkedEncodingStream5;
    var node_stream_1 = require("node:stream");
    var getAwsChunkedEncodingStream_browser_1 = require_getAwsChunkedEncodingStream_browser2();
    var stream_type_check_1 = require_stream_type_check2();
    function getAwsChunkedEncodingStream5(stream, options) {
      const readable = stream;
      const readableStream = stream;
      if ((0, stream_type_check_1.isReadableStream)(readableStream)) {
        return (0, getAwsChunkedEncodingStream_browser_1.getAwsChunkedEncodingStream)(readableStream, options);
      }
      const { base64Encoder, bodyLengthChecker, checksumAlgorithmFn, checksumLocationName, streamHasher } = options;
      const checksumRequired = base64Encoder !== void 0 && checksumAlgorithmFn !== void 0 && checksumLocationName !== void 0 && streamHasher !== void 0;
      const digest = checksumRequired ? streamHasher(checksumAlgorithmFn, readable) : void 0;
      const awsChunkedEncodingStream = new node_stream_1.Readable({
        read: /* @__PURE__ */ __name(() => {
        }, "read")
      });
      readable.on("data", (data3) => {
        const length = bodyLengthChecker(data3) || 0;
        if (length === 0) {
          return;
        }
        awsChunkedEncodingStream.push(`${length.toString(16)}\r
`);
        awsChunkedEncodingStream.push(data3);
        awsChunkedEncodingStream.push("\r\n");
      });
      readable.on("end", async () => {
        awsChunkedEncodingStream.push(`0\r
`);
        if (checksumRequired) {
          const checksum = base64Encoder(await digest);
          awsChunkedEncodingStream.push(`${checksumLocationName}:${checksum}\r
`);
          awsChunkedEncodingStream.push(`\r
`);
        }
        awsChunkedEncodingStream.push(null);
      });
      return awsChunkedEncodingStream;
    }
    __name(getAwsChunkedEncodingStream5, "getAwsChunkedEncodingStream");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/headStream.browser.js
var require_headStream_browser2 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/headStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.headStream = headStream5;
    async function headStream5(stream, bytes) {
      let byteLengthCounter = 0;
      const chunks2 = [];
      const reader = stream.getReader();
      let isDone = false;
      while (!isDone) {
        const { done, value } = await reader.read();
        if (value) {
          chunks2.push(value);
          byteLengthCounter += value?.byteLength ?? 0;
        }
        if (byteLengthCounter >= bytes) {
          break;
        }
        isDone = done;
      }
      reader.releaseLock();
      const collected = new Uint8Array(Math.min(bytes, byteLengthCounter));
      let offset = 0;
      for (const chunk of chunks2) {
        if (chunk.byteLength > collected.byteLength - offset) {
          collected.set(chunk.subarray(0, collected.byteLength - offset), offset);
          break;
        } else {
          collected.set(chunk, offset);
        }
        offset += chunk.length;
      }
      return collected;
    }
    __name(headStream5, "headStream");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/headStream.js
var require_headStream2 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/headStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.headStream = void 0;
    var stream_1 = require("stream");
    var headStream_browser_1 = require_headStream_browser2();
    var stream_type_check_1 = require_stream_type_check2();
    var headStream5 = /* @__PURE__ */ __name((stream, bytes) => {
      if ((0, stream_type_check_1.isReadableStream)(stream)) {
        return (0, headStream_browser_1.headStream)(stream, bytes);
      }
      return new Promise((resolve13, reject) => {
        const collector = new Collector8();
        collector.limit = bytes;
        stream.pipe(collector);
        stream.on("error", (err) => {
          collector.end();
          reject(err);
        });
        collector.on("error", reject);
        collector.on("finish", function() {
          const bytes2 = new Uint8Array(Buffer.concat(this.buffers));
          resolve13(bytes2);
        });
      });
    }, "headStream");
    exports2.headStream = headStream5;
    var Collector8 = class extends stream_1.Writable {
      static {
        __name(this, "Collector");
      }
      buffers = [];
      limit = Infinity;
      bytesBuffered = 0;
      _write(chunk, encoding, callback) {
        this.buffers.push(chunk);
        this.bytesBuffered += chunk.byteLength ?? 0;
        if (this.bytesBuffered >= this.limit) {
          const excess = this.bytesBuffered - this.limit;
          const tailBuffer = this.buffers[this.buffers.length - 1];
          this.buffers[this.buffers.length - 1] = tailBuffer.subarray(0, tailBuffer.byteLength - excess);
          this.emit("finish");
        }
        callback();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.browser.js
var require_sdk_stream_mixin_browser2 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.sdkStreamMixin = void 0;
    var fetch_http_handler_1 = require_dist_cjs14();
    var util_base64_1 = require_dist_cjs10();
    var util_hex_encoding_1 = require_dist_cjs15();
    var util_utf8_1 = require_dist_cjs9();
    var stream_type_check_1 = require_stream_type_check2();
    var ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11 = "The stream has already been transformed.";
    var sdkStreamMixin12 = /* @__PURE__ */ __name((stream) => {
      if (!isBlobInstance6(stream) && !(0, stream_type_check_1.isReadableStream)(stream)) {
        const name = stream?.__proto__?.constructor?.name || stream;
        throw new Error(`Unexpected stream implementation, expect Blob or ReadableStream, got ${name}`);
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
        }
        transformed = true;
        return await (0, fetch_http_handler_1.streamCollector)(stream);
      }, "transformToByteArray");
      const blobToWebStream = /* @__PURE__ */ __name((blob) => {
        if (typeof blob.stream !== "function") {
          throw new Error("Cannot transform payload Blob to web stream. Please make sure the Blob.stream() is polyfilled.\nIf you are using React Native, this API is not yet supported, see: https://react-native.canny.io/feature-requests/p/fetch-streaming-body");
        }
        return blob.stream();
      }, "blobToWebStream");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === "base64") {
            return (0, util_base64_1.toBase64)(buf);
          } else if (encoding === "hex") {
            return (0, util_hex_encoding_1.toHex)(buf);
          } else if (encoding === void 0 || encoding === "utf8" || encoding === "utf-8") {
            return (0, util_utf8_1.toUtf8)(buf);
          } else if (typeof TextDecoder === "function") {
            return new TextDecoder(encoding).decode(buf);
          } else {
            throw new Error("TextDecoder is not available, please make sure polyfill is provided.");
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
          }
          transformed = true;
          if (isBlobInstance6(stream)) {
            return blobToWebStream(stream);
          } else if ((0, stream_type_check_1.isReadableStream)(stream)) {
            return stream;
          } else {
            throw new Error(`Cannot transform payload to web stream, got ${stream}`);
          }
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
    exports2.sdkStreamMixin = sdkStreamMixin12;
    var isBlobInstance6 = /* @__PURE__ */ __name((stream) => typeof Blob === "function" && stream instanceof Blob, "isBlobInstance");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.js
var require_sdk_stream_mixin2 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.sdkStreamMixin = void 0;
    var node_http_handler_1 = require_dist_cjs13();
    var util_buffer_from_1 = require_dist_cjs8();
    var stream_1 = require("stream");
    var sdk_stream_mixin_browser_1 = require_sdk_stream_mixin_browser2();
    var ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11 = "The stream has already been transformed.";
    var sdkStreamMixin12 = /* @__PURE__ */ __name((stream) => {
      if (!(stream instanceof stream_1.Readable)) {
        try {
          return (0, sdk_stream_mixin_browser_1.sdkStreamMixin)(stream);
        } catch (e32) {
          const name = stream?.__proto__?.constructor?.name || stream;
          throw new Error(`Unexpected stream implementation, expect Stream.Readable instance, got ${name}`);
        }
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
        }
        transformed = true;
        return await (0, node_http_handler_1.streamCollector)(stream);
      }, "transformToByteArray");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === void 0 || Buffer.isEncoding(encoding)) {
            return (0, util_buffer_from_1.fromArrayBuffer)(buf.buffer, buf.byteOffset, buf.byteLength).toString(encoding);
          } else {
            const decoder = new TextDecoder(encoding);
            return decoder.decode(buf);
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
          }
          if (stream.readableFlowing !== null) {
            throw new Error("The stream has been consumed by other callbacks.");
          }
          if (typeof stream_1.Readable.toWeb !== "function") {
            throw new Error("Readable.toWeb() is not supported. Please ensure a polyfill is available.");
          }
          transformed = true;
          return stream_1.Readable.toWeb(stream);
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
    exports2.sdkStreamMixin = sdkStreamMixin12;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/splitStream.browser.js
var require_splitStream_browser2 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/splitStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.splitStream = splitStream5;
    async function splitStream5(stream) {
      if (typeof stream.stream === "function") {
        stream = stream.stream();
      }
      const readableStream = stream;
      return readableStream.tee();
    }
    __name(splitStream5, "splitStream");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/splitStream.js
var require_splitStream2 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/splitStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.splitStream = splitStream5;
    var stream_1 = require("stream");
    var splitStream_browser_1 = require_splitStream_browser2();
    var stream_type_check_1 = require_stream_type_check2();
    async function splitStream5(stream) {
      if ((0, stream_type_check_1.isReadableStream)(stream) || (0, stream_type_check_1.isBlob)(stream)) {
        return (0, splitStream_browser_1.splitStream)(stream);
      }
      const stream1 = new stream_1.PassThrough();
      const stream2 = new stream_1.PassThrough();
      stream.pipe(stream1);
      stream.pipe(stream2);
      return [stream1, stream2];
    }
    __name(splitStream5, "splitStream");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/index.js
var require_dist_cjs39 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-stream/dist-cjs/index.js"(exports2) {
    "use strict";
    var utilBase64 = require_dist_cjs10();
    var utilUtf8 = require_dist_cjs9();
    var ChecksumStream5 = require_ChecksumStream2();
    var createChecksumStream5 = require_createChecksumStream2();
    var createBufferedReadable3 = require_createBufferedReadable2();
    var getAwsChunkedEncodingStream5 = require_getAwsChunkedEncodingStream2();
    var headStream5 = require_headStream2();
    var sdkStreamMixin12 = require_sdk_stream_mixin2();
    var splitStream5 = require_splitStream2();
    var streamTypeCheck = require_stream_type_check2();
    var Uint8ArrayBlobAdapter8 = class _Uint8ArrayBlobAdapter extends Uint8Array {
      static {
        __name(this, "Uint8ArrayBlobAdapter");
      }
      static fromString(source, encoding = "utf-8") {
        if (typeof source === "string") {
          if (encoding === "base64") {
            return _Uint8ArrayBlobAdapter.mutate(utilBase64.fromBase64(source));
          }
          return _Uint8ArrayBlobAdapter.mutate(utilUtf8.fromUtf8(source));
        }
        throw new Error(`Unsupported conversion from ${typeof source} to Uint8ArrayBlobAdapter.`);
      }
      static mutate(source) {
        Object.setPrototypeOf(source, _Uint8ArrayBlobAdapter.prototype);
        return source;
      }
      transformToString(encoding = "utf-8") {
        if (encoding === "base64") {
          return utilBase64.toBase64(this);
        }
        return utilUtf8.toUtf8(this);
      }
    };
    exports2.isBlob = streamTypeCheck.isBlob;
    exports2.isReadableStream = streamTypeCheck.isReadableStream;
    exports2.Uint8ArrayBlobAdapter = Uint8ArrayBlobAdapter8;
    Object.prototype.hasOwnProperty.call(ChecksumStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: ChecksumStream5["__proto__"]
    });
    Object.keys(ChecksumStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = ChecksumStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(createChecksumStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: createChecksumStream5["__proto__"]
    });
    Object.keys(createChecksumStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = createChecksumStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(createBufferedReadable3, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: createBufferedReadable3["__proto__"]
    });
    Object.keys(createBufferedReadable3).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = createBufferedReadable3[k32];
    });
    Object.prototype.hasOwnProperty.call(getAwsChunkedEncodingStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: getAwsChunkedEncodingStream5["__proto__"]
    });
    Object.keys(getAwsChunkedEncodingStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = getAwsChunkedEncodingStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(headStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: headStream5["__proto__"]
    });
    Object.keys(headStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = headStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(sdkStreamMixin12, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: sdkStreamMixin12["__proto__"]
    });
    Object.keys(sdkStreamMixin12).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = sdkStreamMixin12[k32];
    });
    Object.prototype.hasOwnProperty.call(splitStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: splitStream5["__proto__"]
    });
    Object.keys(splitStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = splitStream5[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/requestHelpers.js
var require_requestHelpers = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/requestHelpers.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createGetRequest = createGetRequest;
    exports2.getCredentials = getCredentials;
    var property_provider_1 = require_dist_cjs27();
    var protocol_http_1 = require_dist_cjs2();
    var smithy_client_1 = require_dist_cjs34();
    var util_stream_1 = require_dist_cjs39();
    function createGetRequest(url) {
      return new protocol_http_1.HttpRequest({
        protocol: url.protocol,
        hostname: url.hostname,
        port: Number(url.port),
        path: url.pathname,
        query: Array.from(url.searchParams.entries()).reduce((acc, [k32, v]) => {
          acc[k32] = v;
          return acc;
        }, {}),
        fragment: url.hash
      });
    }
    __name(createGetRequest, "createGetRequest");
    async function getCredentials(response, logger5) {
      const stream = (0, util_stream_1.sdkStreamMixin)(response.body);
      const str = await stream.transformToString();
      if (response.statusCode === 200) {
        const parsed = JSON.parse(str);
        if (typeof parsed.AccessKeyId !== "string" || typeof parsed.SecretAccessKey !== "string" || typeof parsed.Token !== "string" || typeof parsed.Expiration !== "string") {
          throw new property_provider_1.CredentialsProviderError("HTTP credential provider response not of the required format, an object matching: { AccessKeyId: string, SecretAccessKey: string, Token: string, Expiration: string(rfc3339) }", { logger: logger5 });
        }
        return {
          accessKeyId: parsed.AccessKeyId,
          secretAccessKey: parsed.SecretAccessKey,
          sessionToken: parsed.Token,
          expiration: (0, smithy_client_1.parseRfc3339DateTime)(parsed.Expiration)
        };
      }
      if (response.statusCode >= 400 && response.statusCode < 500) {
        let parsedBody = {};
        try {
          parsedBody = JSON.parse(str);
        } catch (e32) {
        }
        throw Object.assign(new property_provider_1.CredentialsProviderError(`Server responded with status: ${response.statusCode}`, { logger: logger5 }), {
          Code: parsedBody.Code,
          Message: parsedBody.Message
        });
      }
      throw new property_provider_1.CredentialsProviderError(`Server responded with status: ${response.statusCode}`, { logger: logger5 });
    }
    __name(getCredentials, "getCredentials");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/retry-wrapper.js
var require_retry_wrapper = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/retry-wrapper.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.retryWrapper = void 0;
    var retryWrapper = /* @__PURE__ */ __name((toRetry, maxRetries, delayMs) => {
      return async () => {
        for (let i32 = 0; i32 < maxRetries; ++i32) {
          try {
            return await toRetry();
          } catch (e32) {
            await new Promise((resolve13) => setTimeout(resolve13, delayMs));
          }
        }
        return await toRetry();
      };
    }, "retryWrapper");
    exports2.retryWrapper = retryWrapper;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/fromHttp.js
var require_fromHttp = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/fromHttp.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromHttp = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var client_1 = (init_client2(), __toCommonJS(client_exports));
    var node_http_handler_1 = require_dist_cjs13();
    var property_provider_1 = require_dist_cjs27();
    var promises_1 = tslib_1.__importDefault(require("node:fs/promises"));
    var checkUrl_1 = require_checkUrl();
    var requestHelpers_1 = require_requestHelpers();
    var retry_wrapper_1 = require_retry_wrapper();
    var AWS_CONTAINER_CREDENTIALS_RELATIVE_URI = "AWS_CONTAINER_CREDENTIALS_RELATIVE_URI";
    var DEFAULT_LINK_LOCAL_HOST = "http://169.254.170.2";
    var AWS_CONTAINER_CREDENTIALS_FULL_URI = "AWS_CONTAINER_CREDENTIALS_FULL_URI";
    var AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE = "AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE";
    var AWS_CONTAINER_AUTHORIZATION_TOKEN = "AWS_CONTAINER_AUTHORIZATION_TOKEN";
    var fromHttp = /* @__PURE__ */ __name((options = {}) => {
      options.logger?.debug("@aws-sdk/credential-provider-http - fromHttp");
      let host;
      const relative5 = options.awsContainerCredentialsRelativeUri ?? process.env[AWS_CONTAINER_CREDENTIALS_RELATIVE_URI];
      const full = options.awsContainerCredentialsFullUri ?? process.env[AWS_CONTAINER_CREDENTIALS_FULL_URI];
      const token = options.awsContainerAuthorizationToken ?? process.env[AWS_CONTAINER_AUTHORIZATION_TOKEN];
      const tokenFile = options.awsContainerAuthorizationTokenFile ?? process.env[AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE];
      const warn2 = options.logger?.constructor?.name === "NoOpLogger" || !options.logger?.warn ? console.warn : options.logger.warn.bind(options.logger);
      if (relative5 && full) {
        warn2("@aws-sdk/credential-provider-http: you have set both awsContainerCredentialsRelativeUri and awsContainerCredentialsFullUri.");
        warn2("awsContainerCredentialsFullUri will take precedence.");
      }
      if (token && tokenFile) {
        warn2("@aws-sdk/credential-provider-http: you have set both awsContainerAuthorizationToken and awsContainerAuthorizationTokenFile.");
        warn2("awsContainerAuthorizationToken will take precedence.");
      }
      if (full) {
        host = full;
      } else if (relative5) {
        host = `${DEFAULT_LINK_LOCAL_HOST}${relative5}`;
      } else {
        throw new property_provider_1.CredentialsProviderError(`No HTTP credential provider host provided.
Set AWS_CONTAINER_CREDENTIALS_FULL_URI or AWS_CONTAINER_CREDENTIALS_RELATIVE_URI.`, { logger: options.logger });
      }
      const url = new URL(host);
      (0, checkUrl_1.checkUrl)(url, options.logger);
      const requestHandler = node_http_handler_1.NodeHttpHandler.create({
        requestTimeout: options.timeout ?? 1e3,
        connectionTimeout: options.timeout ?? 1e3
      });
      return (0, retry_wrapper_1.retryWrapper)(async () => {
        const request4 = (0, requestHelpers_1.createGetRequest)(url);
        if (token) {
          request4.headers.Authorization = token;
        } else if (tokenFile) {
          request4.headers.Authorization = (await promises_1.default.readFile(tokenFile)).toString();
        }
        try {
          const result2 = await requestHandler.handle(request4);
          return (0, requestHelpers_1.getCredentials)(result2.response).then((creds) => (0, client_1.setCredentialFeature)(creds, "CREDENTIALS_HTTP", "z"));
        } catch (e32) {
          throw new property_provider_1.CredentialsProviderError(String(e32), { logger: options.logger });
        }
      }, options.maxRetries ?? 3, options.timeout ?? 1e3);
    }, "fromHttp");
    exports2.fromHttp = fromHttp;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-http/dist-cjs/index.js
var require_dist_cjs40 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-http/dist-cjs/index.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromHttp = void 0;
    var fromHttp_1 = require_fromHttp();
    Object.defineProperty(exports2, "fromHttp", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return fromHttp_1.fromHttp;
    }, "get") });
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/client/emitWarningIfUnsupportedVersion.js
var state2, emitWarningIfUnsupportedVersion2;
var init_emitWarningIfUnsupportedVersion2 = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/client/emitWarningIfUnsupportedVersion.js"() {
    state2 = {
      warningEmitted: false
    };
    emitWarningIfUnsupportedVersion2 = /* @__PURE__ */ __name((version) => {
      if (version && !state2.warningEmitted) {
        if (process.env.AWS_SDK_JS_NODE_VERSION_SUPPORT_WARNING_DISABLED === "true") {
          state2.warningEmitted = true;
          return;
        }
        const userMajorVersion = parseInt(version.substring(1, version.indexOf(".")));
        const vv = 22;
        if (userMajorVersion < vv) {
          state2.warningEmitted = true;
          process.emitWarning(`NodeVersionSupportWarning: The AWS SDK for JavaScript (v3)
versions published after the first week of January 2027
will require node >=${vv}. You are running node ${version}.

To continue receiving updates to AWS services, bug fixes,
and security updates please upgrade to node >=${vv}.

More information can be found at: https://a.co/c895JFp`);
        }
      }
    }, "emitWarningIfUnsupportedVersion");
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/client/longPollMiddleware.js
var longPollMiddleware2, longPollMiddlewareOptions2, getLongPollPlugin2;
var init_longPollMiddleware2 = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/client/longPollMiddleware.js"() {
    longPollMiddleware2 = /* @__PURE__ */ __name(() => (next, context) => async (args) => {
      context.__retryLongPoll = true;
      return next(args);
    }, "longPollMiddleware");
    longPollMiddlewareOptions2 = {
      name: "longPollMiddleware",
      tags: ["RETRY"],
      step: "initialize",
      override: true
    };
    getLongPollPlugin2 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(longPollMiddleware2(), longPollMiddlewareOptions2);
      }, "applyToStack")
    }), "getLongPollPlugin");
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/client/setCredentialFeature.js
function setCredentialFeature2(credentials, feature, value) {
  if (!credentials.$source) {
    credentials.$source = {};
  }
  credentials.$source[feature] = value;
  return credentials;
}
var init_setCredentialFeature2 = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/client/setCredentialFeature.js"() {
    __name(setCredentialFeature2, "setCredentialFeature");
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/client/setFeature.js
function setFeature3(context, feature, value) {
  if (!context.__aws_sdk_context) {
    context.__aws_sdk_context = {
      features: {}
    };
  } else if (!context.__aws_sdk_context.features) {
    context.__aws_sdk_context.features = {};
  }
  context.__aws_sdk_context.features[feature] = value;
}
var import_util_retry2;
var init_setFeature3 = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/client/setFeature.js"() {
    import_util_retry2 = __toESM(require_dist_cjs22());
    import_util_retry2.Retry.v2026 ||= typeof process === "object" && process.env?.AWS_NEW_RETRIES_2026 === "true";
    __name(setFeature3, "setFeature");
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/client/setTokenFeature.js
function setTokenFeature2(token, feature, value) {
  if (!token.$source) {
    token.$source = {};
  }
  token.$source[feature] = value;
  return token;
}
var init_setTokenFeature2 = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/client/setTokenFeature.js"() {
    __name(setTokenFeature2, "setTokenFeature");
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/client/index.js
var client_exports2 = {};
__export(client_exports2, {
  emitWarningIfUnsupportedVersion: () => emitWarningIfUnsupportedVersion2,
  getLongPollPlugin: () => getLongPollPlugin2,
  setCredentialFeature: () => setCredentialFeature2,
  setFeature: () => setFeature3,
  setTokenFeature: () => setTokenFeature2,
  state: () => state2
});
var init_client3 = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/client/index.js"() {
    init_emitWarningIfUnsupportedVersion2();
    init_longPollMiddleware2();
    init_setCredentialFeature2();
    init_setFeature3();
    init_setTokenFeature2();
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getDateHeader.js
var import_protocol_http12, getDateHeader2;
var init_getDateHeader2 = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getDateHeader.js"() {
    import_protocol_http12 = __toESM(require_dist_cjs2());
    getDateHeader2 = /* @__PURE__ */ __name((response) => import_protocol_http12.HttpResponse.isInstance(response) ? response.headers?.date ?? response.headers?.Date : void 0, "getDateHeader");
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getSkewCorrectedDate.js
var getSkewCorrectedDate2;
var init_getSkewCorrectedDate2 = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getSkewCorrectedDate.js"() {
    getSkewCorrectedDate2 = /* @__PURE__ */ __name((systemClockOffset) => new Date(Date.now() + systemClockOffset), "getSkewCorrectedDate");
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/isClockSkewed.js
var isClockSkewed2;
var init_isClockSkewed2 = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/isClockSkewed.js"() {
    init_getSkewCorrectedDate2();
    isClockSkewed2 = /* @__PURE__ */ __name((clockTime, systemClockOffset) => Math.abs(getSkewCorrectedDate2(systemClockOffset).getTime() - clockTime) >= 3e5, "isClockSkewed");
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getUpdatedSystemClockOffset.js
var getUpdatedSystemClockOffset2;
var init_getUpdatedSystemClockOffset2 = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getUpdatedSystemClockOffset.js"() {
    init_isClockSkewed2();
    getUpdatedSystemClockOffset2 = /* @__PURE__ */ __name((clockTime, currentSystemClockOffset) => {
      const clockTimeInMs = Date.parse(clockTime);
      if (isClockSkewed2(clockTimeInMs, currentSystemClockOffset)) {
        return clockTimeInMs - Date.now();
      }
      return currentSystemClockOffset;
    }, "getUpdatedSystemClockOffset");
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/index.js
var init_utils2 = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/index.js"() {
    init_getDateHeader2();
    init_getSkewCorrectedDate2();
    init_getUpdatedSystemClockOffset2();
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4Signer.js
var import_protocol_http13, throwSigningPropertyError2, validateSigningProperties2, AwsSdkSigV4Signer2, AWSSDKSigV4Signer2;
var init_AwsSdkSigV4Signer2 = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4Signer.js"() {
    import_protocol_http13 = __toESM(require_dist_cjs2());
    init_utils2();
    throwSigningPropertyError2 = /* @__PURE__ */ __name((name, property) => {
      if (!property) {
        throw new Error(`Property \`${name}\` is not resolved for AWS SDK SigV4Auth`);
      }
      return property;
    }, "throwSigningPropertyError");
    validateSigningProperties2 = /* @__PURE__ */ __name(async (signingProperties) => {
      const context = throwSigningPropertyError2("context", signingProperties.context);
      const config2 = throwSigningPropertyError2("config", signingProperties.config);
      const authScheme = context.endpointV2?.properties?.authSchemes?.[0];
      const signerFunction = throwSigningPropertyError2("signer", config2.signer);
      const signer = await signerFunction(authScheme);
      const signingRegion = signingProperties?.signingRegion;
      const signingRegionSet = signingProperties?.signingRegionSet;
      const signingName = signingProperties?.signingName;
      return {
        config: config2,
        signer,
        signingRegion,
        signingRegionSet,
        signingName
      };
    }, "validateSigningProperties");
    AwsSdkSigV4Signer2 = class {
      static {
        __name(this, "AwsSdkSigV4Signer");
      }
      async sign(httpRequest, identity, signingProperties) {
        if (!import_protocol_http13.HttpRequest.isInstance(httpRequest)) {
          throw new Error("The request is not an instance of `HttpRequest` and cannot be signed");
        }
        const validatedProps = await validateSigningProperties2(signingProperties);
        const { config: config2, signer } = validatedProps;
        let { signingRegion, signingName } = validatedProps;
        const handlerExecutionContext = signingProperties.context;
        if (handlerExecutionContext?.authSchemes?.length ?? 0 > 1) {
          const [first, second] = handlerExecutionContext.authSchemes;
          if (first?.name === "sigv4a" && second?.name === "sigv4") {
            signingRegion = second?.signingRegion ?? signingRegion;
            signingName = second?.signingName ?? signingName;
          }
        }
        const signedRequest = await signer.sign(httpRequest, {
          signingDate: getSkewCorrectedDate2(config2.systemClockOffset),
          signingRegion,
          signingService: signingName
        });
        return signedRequest;
      }
      errorHandler(signingProperties) {
        return (error4) => {
          const serverTime = error4.ServerTime ?? getDateHeader2(error4.$response);
          if (serverTime) {
            const config2 = throwSigningPropertyError2("config", signingProperties.config);
            const initialSystemClockOffset = config2.systemClockOffset;
            config2.systemClockOffset = getUpdatedSystemClockOffset2(serverTime, config2.systemClockOffset);
            const clockSkewCorrected = config2.systemClockOffset !== initialSystemClockOffset;
            if (clockSkewCorrected && error4.$metadata) {
              error4.$metadata.clockSkewCorrected = true;
            }
          }
          throw error4;
        };
      }
      successHandler(httpResponse, signingProperties) {
        const dateHeader = getDateHeader2(httpResponse);
        if (dateHeader) {
          const config2 = throwSigningPropertyError2("config", signingProperties.config);
          config2.systemClockOffset = getUpdatedSystemClockOffset2(dateHeader, config2.systemClockOffset);
        }
      }
    };
    AWSSDKSigV4Signer2 = AwsSdkSigV4Signer2;
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4ASigner.js
var import_protocol_http14, AwsSdkSigV4ASigner2;
var init_AwsSdkSigV4ASigner2 = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4ASigner.js"() {
    import_protocol_http14 = __toESM(require_dist_cjs2());
    init_utils2();
    init_AwsSdkSigV4Signer2();
    AwsSdkSigV4ASigner2 = class extends AwsSdkSigV4Signer2 {
      static {
        __name(this, "AwsSdkSigV4ASigner");
      }
      async sign(httpRequest, identity, signingProperties) {
        if (!import_protocol_http14.HttpRequest.isInstance(httpRequest)) {
          throw new Error("The request is not an instance of `HttpRequest` and cannot be signed");
        }
        const { config: config2, signer, signingRegion, signingRegionSet, signingName } = await validateSigningProperties2(signingProperties);
        const configResolvedSigningRegionSet = await config2.sigv4aSigningRegionSet?.();
        const multiRegionOverride = (configResolvedSigningRegionSet ?? signingRegionSet ?? [signingRegion]).join(",");
        const signedRequest = await signer.sign(httpRequest, {
          signingDate: getSkewCorrectedDate2(config2.systemClockOffset),
          signingRegion: multiRegionOverride,
          signingService: signingName
        });
        return signedRequest;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getArrayForCommaSeparatedString.js
var getArrayForCommaSeparatedString2;
var init_getArrayForCommaSeparatedString2 = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getArrayForCommaSeparatedString.js"() {
    getArrayForCommaSeparatedString2 = /* @__PURE__ */ __name((str) => typeof str === "string" && str.length > 0 ? str.split(",").map((item) => item.trim()) : [], "getArrayForCommaSeparatedString");
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getBearerTokenEnvKey.js
var getBearerTokenEnvKey2;
var init_getBearerTokenEnvKey2 = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getBearerTokenEnvKey.js"() {
    getBearerTokenEnvKey2 = /* @__PURE__ */ __name((signingName) => `AWS_BEARER_TOKEN_${signingName.replace(/[\s-]/g, "_").toUpperCase()}`, "getBearerTokenEnvKey");
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/NODE_AUTH_SCHEME_PREFERENCE_OPTIONS.js
var NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY2, NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY2, NODE_AUTH_SCHEME_PREFERENCE_OPTIONS2;
var init_NODE_AUTH_SCHEME_PREFERENCE_OPTIONS2 = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/NODE_AUTH_SCHEME_PREFERENCE_OPTIONS.js"() {
    init_getArrayForCommaSeparatedString2();
    init_getBearerTokenEnvKey2();
    NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY2 = "AWS_AUTH_SCHEME_PREFERENCE";
    NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY2 = "auth_scheme_preference";
    NODE_AUTH_SCHEME_PREFERENCE_OPTIONS2 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3, options) => {
        if (options?.signingName) {
          const bearerTokenKey = getBearerTokenEnvKey2(options.signingName);
          if (bearerTokenKey in env3)
            return ["httpBearerAuth"];
        }
        if (!(NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY2 in env3))
          return void 0;
        return getArrayForCommaSeparatedString2(env3[NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY2]);
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => {
        if (!(NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY2 in profile))
          return void 0;
        return getArrayForCommaSeparatedString2(profile[NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY2]);
      }, "configFileSelector"),
      default: []
    };
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4AConfig.js
var import_property_provider2, resolveAwsSdkSigV4AConfig2, NODE_SIGV4A_CONFIG_OPTIONS2;
var init_resolveAwsSdkSigV4AConfig2 = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4AConfig.js"() {
    init_dist_es();
    import_property_provider2 = __toESM(require_dist_cjs27());
    resolveAwsSdkSigV4AConfig2 = /* @__PURE__ */ __name((config2) => {
      config2.sigv4aSigningRegionSet = normalizeProvider(config2.sigv4aSigningRegionSet);
      return config2;
    }, "resolveAwsSdkSigV4AConfig");
    NODE_SIGV4A_CONFIG_OPTIONS2 = {
      environmentVariableSelector(env3) {
        if (env3.AWS_SIGV4A_SIGNING_REGION_SET) {
          return env3.AWS_SIGV4A_SIGNING_REGION_SET.split(",").map((_) => _.trim());
        }
        throw new import_property_provider2.ProviderError("AWS_SIGV4A_SIGNING_REGION_SET not set in env.", {
          tryNextLink: true
        });
      },
      configFileSelector(profile) {
        if (profile.sigv4a_signing_region_set) {
          return (profile.sigv4a_signing_region_set ?? "").split(",").map((_) => _.trim());
        }
        throw new import_property_provider2.ProviderError("sigv4a_signing_region_set not set in profile.", {
          tryNextLink: true
        });
      },
      default: void 0
    };
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4Config.js
function normalizeCredentialProvider2(config2, { credentials, credentialDefaultProvider }) {
  let credentialsProvider;
  if (credentials) {
    if (!credentials?.memoized) {
      credentialsProvider = memoizeIdentityProvider(credentials, isIdentityExpired, doesIdentityRequireRefresh);
    } else {
      credentialsProvider = credentials;
    }
  } else {
    if (credentialDefaultProvider) {
      credentialsProvider = normalizeProvider(credentialDefaultProvider(Object.assign({}, config2, {
        parentClientConfig: config2
      })));
    } else {
      credentialsProvider = /* @__PURE__ */ __name(async () => {
        throw new Error("@aws-sdk/core::resolveAwsSdkSigV4Config - `credentials` not provided and no credentialDefaultProvider was configured.");
      }, "credentialsProvider");
    }
  }
  credentialsProvider.memoized = true;
  return credentialsProvider;
}
function bindCallerConfig2(config2, credentialsProvider) {
  if (credentialsProvider.configBound) {
    return credentialsProvider;
  }
  const fn = /* @__PURE__ */ __name(async (options) => credentialsProvider({ ...options, callerClientConfig: config2 }), "fn");
  fn.memoized = credentialsProvider.memoized;
  fn.configBound = true;
  return fn;
}
var import_signature_v42, resolveAwsSdkSigV4Config2, resolveAWSSDKSigV4Config2;
var init_resolveAwsSdkSigV4Config2 = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4Config.js"() {
    init_client3();
    init_dist_es();
    import_signature_v42 = __toESM(require_dist_cjs36());
    resolveAwsSdkSigV4Config2 = /* @__PURE__ */ __name((config2) => {
      let inputCredentials = config2.credentials;
      let isUserSupplied = !!config2.credentials;
      let resolvedCredentials = void 0;
      Object.defineProperty(config2, "credentials", {
        set(credentials) {
          if (credentials && credentials !== inputCredentials && credentials !== resolvedCredentials) {
            isUserSupplied = true;
          }
          inputCredentials = credentials;
          const memoizedProvider = normalizeCredentialProvider2(config2, {
            credentials: inputCredentials,
            credentialDefaultProvider: config2.credentialDefaultProvider
          });
          const boundProvider = bindCallerConfig2(config2, memoizedProvider);
          if (isUserSupplied && !boundProvider.attributed) {
            const isCredentialObject = typeof inputCredentials === "object" && inputCredentials !== null;
            resolvedCredentials = /* @__PURE__ */ __name(async (options) => {
              const creds = await boundProvider(options);
              const attributedCreds = creds;
              if (isCredentialObject && (!attributedCreds.$source || Object.keys(attributedCreds.$source).length === 0)) {
                return setCredentialFeature2(attributedCreds, "CREDENTIALS_CODE", "e");
              }
              return attributedCreds;
            }, "resolvedCredentials");
            resolvedCredentials.memoized = boundProvider.memoized;
            resolvedCredentials.configBound = boundProvider.configBound;
            resolvedCredentials.attributed = true;
          } else {
            resolvedCredentials = boundProvider;
          }
        },
        get() {
          return resolvedCredentials;
        },
        enumerable: true,
        configurable: true
      });
      config2.credentials = inputCredentials;
      const { signingEscapePath = true, systemClockOffset = config2.systemClockOffset || 0, sha256 } = config2;
      let signer;
      if (config2.signer) {
        signer = normalizeProvider(config2.signer);
      } else if (config2.regionInfoProvider) {
        signer = /* @__PURE__ */ __name(() => normalizeProvider(config2.region)().then(async (region) => [
          await config2.regionInfoProvider(region, {
            useFipsEndpoint: await config2.useFipsEndpoint(),
            useDualstackEndpoint: await config2.useDualstackEndpoint()
          }) || {},
          region
        ]).then(([regionInfo, region]) => {
          const { signingRegion, signingService } = regionInfo;
          config2.signingRegion = config2.signingRegion || signingRegion || region;
          config2.signingName = config2.signingName || signingService || config2.serviceId;
          const params = {
            ...config2,
            credentials: config2.credentials,
            region: config2.signingRegion,
            service: config2.signingName,
            sha256,
            uriEscapePath: signingEscapePath
          };
          const SignerCtor = config2.signerConstructor || import_signature_v42.SignatureV4;
          return new SignerCtor(params);
        }), "signer");
      } else {
        signer = /* @__PURE__ */ __name(async (authScheme) => {
          authScheme = Object.assign({}, {
            name: "sigv4",
            signingName: config2.signingName || config2.defaultSigningName,
            signingRegion: await normalizeProvider(config2.region)(),
            properties: {}
          }, authScheme);
          const signingRegion = authScheme.signingRegion;
          const signingService = authScheme.signingName;
          config2.signingRegion = config2.signingRegion || signingRegion;
          config2.signingName = config2.signingName || signingService || config2.serviceId;
          const params = {
            ...config2,
            credentials: config2.credentials,
            region: config2.signingRegion,
            service: config2.signingName,
            sha256,
            uriEscapePath: signingEscapePath
          };
          const SignerCtor = config2.signerConstructor || import_signature_v42.SignatureV4;
          return new SignerCtor(params);
        }, "signer");
      }
      const resolvedConfig = Object.assign(config2, {
        systemClockOffset,
        signingEscapePath,
        signer
      });
      return resolvedConfig;
    }, "resolveAwsSdkSigV4Config");
    resolveAWSSDKSigV4Config2 = resolveAwsSdkSigV4Config2;
    __name(normalizeCredentialProvider2, "normalizeCredentialProvider");
    __name(bindCallerConfig2, "bindCallerConfig");
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/index.js
var init_aws_sdk2 = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/index.js"() {
    init_AwsSdkSigV4Signer2();
    init_AwsSdkSigV4ASigner2();
    init_NODE_AUTH_SCHEME_PREFERENCE_OPTIONS2();
    init_resolveAwsSdkSigV4AConfig2();
    init_resolveAwsSdkSigV4Config2();
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/index.js
var httpAuthSchemes_exports2 = {};
__export(httpAuthSchemes_exports2, {
  AWSSDKSigV4Signer: () => AWSSDKSigV4Signer2,
  AwsSdkSigV4ASigner: () => AwsSdkSigV4ASigner2,
  AwsSdkSigV4Signer: () => AwsSdkSigV4Signer2,
  NODE_AUTH_SCHEME_PREFERENCE_OPTIONS: () => NODE_AUTH_SCHEME_PREFERENCE_OPTIONS2,
  NODE_SIGV4A_CONFIG_OPTIONS: () => NODE_SIGV4A_CONFIG_OPTIONS2,
  getBearerTokenEnvKey: () => getBearerTokenEnvKey2,
  resolveAWSSDKSigV4Config: () => resolveAWSSDKSigV4Config2,
  resolveAwsSdkSigV4AConfig: () => resolveAwsSdkSigV4AConfig2,
  resolveAwsSdkSigV4Config: () => resolveAwsSdkSigV4Config2,
  validateSigningProperties: () => validateSigningProperties2
});
var init_httpAuthSchemes3 = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/index.js"() {
    init_aws_sdk2();
    init_getBearerTokenEnvKey2();
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/middleware-user-agent/dist-cjs/index.js
var require_dist_cjs41 = __commonJS({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/middleware-user-agent/dist-cjs/index.js"(exports2) {
    "use strict";
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var utilEndpoints = require_dist_cjs21();
    var protocolHttp = require_dist_cjs2();
    var client = (init_client3(), __toCommonJS(client_exports2));
    var utilRetry = require_dist_cjs22();
    var DEFAULT_UA_APP_ID2 = void 0;
    function isValidUserAgentAppId2(appId) {
      if (appId === void 0) {
        return true;
      }
      return typeof appId === "string" && appId.length <= 50;
    }
    __name(isValidUserAgentAppId2, "isValidUserAgentAppId");
    function resolveUserAgentConfig29(input) {
      const normalizedAppIdProvider = core.normalizeProvider(input.userAgentAppId ?? DEFAULT_UA_APP_ID2);
      const { customUserAgent } = input;
      return Object.assign(input, {
        customUserAgent: typeof customUserAgent === "string" ? [[customUserAgent]] : customUserAgent,
        userAgentAppId: /* @__PURE__ */ __name(async () => {
          const appId = await normalizedAppIdProvider();
          if (!isValidUserAgentAppId2(appId)) {
            const logger5 = input.logger?.constructor?.name === "NoOpLogger" || !input.logger ? console : input.logger;
            if (typeof appId !== "string") {
              logger5?.warn("userAgentAppId must be a string or undefined.");
            } else if (appId.length > 50) {
              logger5?.warn("The provided userAgentAppId exceeds the maximum length of 50 characters.");
            }
          }
          return appId;
        }, "userAgentAppId")
      });
    }
    __name(resolveUserAgentConfig29, "resolveUserAgentConfig");
    var ACCOUNT_ID_ENDPOINT_REGEX2 = /\d{12}\.ddb/;
    async function checkFeatures2(context, config2, args) {
      const request4 = args.request;
      if (request4?.headers?.["smithy-protocol"] === "rpc-v2-cbor") {
        client.setFeature(context, "PROTOCOL_RPC_V2_CBOR", "M");
      }
      if (typeof config2.retryStrategy === "function") {
        const retryStrategy = await config2.retryStrategy();
        if (typeof retryStrategy.mode === "string") {
          switch (retryStrategy.mode) {
            case utilRetry.RETRY_MODES.ADAPTIVE:
              client.setFeature(context, "RETRY_MODE_ADAPTIVE", "F");
              break;
            case utilRetry.RETRY_MODES.STANDARD:
              client.setFeature(context, "RETRY_MODE_STANDARD", "E");
              break;
          }
        }
      }
      if (typeof config2.accountIdEndpointMode === "function") {
        const endpointV2 = context.endpointV2;
        if (String(endpointV2?.url?.hostname).match(ACCOUNT_ID_ENDPOINT_REGEX2)) {
          client.setFeature(context, "ACCOUNT_ID_ENDPOINT", "O");
        }
        switch (await config2.accountIdEndpointMode?.()) {
          case "disabled":
            client.setFeature(context, "ACCOUNT_ID_MODE_DISABLED", "Q");
            break;
          case "preferred":
            client.setFeature(context, "ACCOUNT_ID_MODE_PREFERRED", "P");
            break;
          case "required":
            client.setFeature(context, "ACCOUNT_ID_MODE_REQUIRED", "R");
            break;
        }
      }
      const identity = context.__smithy_context?.selectedHttpAuthScheme?.identity;
      if (identity?.$source) {
        const credentials = identity;
        if (credentials.accountId) {
          client.setFeature(context, "RESOLVED_ACCOUNT_ID", "T");
        }
        for (const [key, value] of Object.entries(credentials.$source ?? {})) {
          client.setFeature(context, key, value);
        }
      }
    }
    __name(checkFeatures2, "checkFeatures");
    var USER_AGENT3 = "user-agent";
    var X_AMZ_USER_AGENT2 = "x-amz-user-agent";
    var SPACE2 = " ";
    var UA_NAME_SEPARATOR2 = "/";
    var UA_NAME_ESCAPE_REGEX2 = /[^!$%&'*+\-.^_`|~\w]/g;
    var UA_VALUE_ESCAPE_REGEX2 = /[^!$%&'*+\-.^_`|~\w#]/g;
    var UA_ESCAPE_CHAR2 = "-";
    var BYTE_LIMIT2 = 1024;
    function encodeFeatures2(features) {
      let buffer = "";
      for (const key in features) {
        const val = features[key];
        if (buffer.length + val.length + 1 <= BYTE_LIMIT2) {
          if (buffer.length) {
            buffer += "," + val;
          } else {
            buffer += val;
          }
          continue;
        }
        break;
      }
      return buffer;
    }
    __name(encodeFeatures2, "encodeFeatures");
    var userAgentMiddleware2 = /* @__PURE__ */ __name((options) => (next, context) => async (args) => {
      const { request: request4 } = args;
      if (!protocolHttp.HttpRequest.isInstance(request4)) {
        return next(args);
      }
      const { headers } = request4;
      const userAgent = context?.userAgent?.map(escapeUserAgent2) || [];
      const defaultUserAgent2 = (await options.defaultUserAgentProvider()).map(escapeUserAgent2);
      await checkFeatures2(context, options, args);
      const awsContext = context;
      defaultUserAgent2.push(`m/${encodeFeatures2(Object.assign({}, context.__smithy_context?.features, awsContext.__aws_sdk_context?.features))}`);
      const customUserAgent = options?.customUserAgent?.map(escapeUserAgent2) || [];
      const appId = await options.userAgentAppId();
      if (appId) {
        defaultUserAgent2.push(escapeUserAgent2([`app`, `${appId}`]));
      }
      const prefix = utilEndpoints.getUserAgentPrefix();
      const sdkUserAgentValue = (prefix ? [prefix] : []).concat([...defaultUserAgent2, ...userAgent, ...customUserAgent]).join(SPACE2);
      const normalUAValue = [
        ...defaultUserAgent2.filter((section) => section.startsWith("aws-sdk-")),
        ...customUserAgent
      ].join(SPACE2);
      if (options.runtime !== "browser") {
        if (normalUAValue) {
          headers[X_AMZ_USER_AGENT2] = headers[X_AMZ_USER_AGENT2] ? `${headers[USER_AGENT3]} ${normalUAValue}` : normalUAValue;
        }
        headers[USER_AGENT3] = sdkUserAgentValue;
      } else {
        headers[X_AMZ_USER_AGENT2] = sdkUserAgentValue;
      }
      return next({
        ...args,
        request: request4
      });
    }, "userAgentMiddleware");
    var escapeUserAgent2 = /* @__PURE__ */ __name((userAgentPair) => {
      const name = userAgentPair[0].split(UA_NAME_SEPARATOR2).map((part) => part.replace(UA_NAME_ESCAPE_REGEX2, UA_ESCAPE_CHAR2)).join(UA_NAME_SEPARATOR2);
      const version = userAgentPair[1]?.replace(UA_VALUE_ESCAPE_REGEX2, UA_ESCAPE_CHAR2);
      const prefixSeparatorIndex = name.indexOf(UA_NAME_SEPARATOR2);
      const prefix = name.substring(0, prefixSeparatorIndex);
      let uaName = name.substring(prefixSeparatorIndex + 1);
      if (prefix === "api") {
        uaName = uaName.toLowerCase();
      }
      return [prefix, uaName, version].filter((item) => item && item.length > 0).reduce((acc, item, index) => {
        switch (index) {
          case 0:
            return item;
          case 1:
            return `${acc}/${item}`;
          default:
            return `${acc}#${item}`;
        }
      }, "");
    }, "escapeUserAgent");
    var getUserAgentMiddlewareOptions2 = {
      name: "getUserAgentMiddleware",
      step: "build",
      priority: "low",
      tags: ["SET_USER_AGENT", "USER_AGENT"],
      override: true
    };
    var getUserAgentPlugin29 = /* @__PURE__ */ __name((config2) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(userAgentMiddleware2(config2), getUserAgentMiddlewareOptions2);
      }, "applyToStack")
    }), "getUserAgentPlugin");
    exports2.DEFAULT_UA_APP_ID = DEFAULT_UA_APP_ID2;
    exports2.getUserAgentMiddlewareOptions = getUserAgentMiddlewareOptions2;
    exports2.getUserAgentPlugin = getUserAgentPlugin29;
    exports2.resolveUserAgentConfig = resolveUserAgentConfig29;
    exports2.userAgentMiddleware = userAgentMiddleware2;
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@smithy/middleware-retry/dist-cjs/isStreamingPayload/isStreamingPayload.js
var require_isStreamingPayload2 = __commonJS({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@smithy/middleware-retry/dist-cjs/isStreamingPayload/isStreamingPayload.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isStreamingPayload = void 0;
    var stream_1 = require("stream");
    var isStreamingPayload3 = /* @__PURE__ */ __name((request4) => request4?.body instanceof stream_1.Readable || typeof ReadableStream !== "undefined" && request4?.body instanceof ReadableStream, "isStreamingPayload");
    exports2.isStreamingPayload = isStreamingPayload3;
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@smithy/middleware-retry/dist-cjs/index.js
var require_dist_cjs42 = __commonJS({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@smithy/middleware-retry/dist-cjs/index.js"(exports2) {
    "use strict";
    var utilRetry = require_dist_cjs22();
    var protocolHttp = require_dist_cjs2();
    var serviceErrorClassification = require_dist_cjs32();
    var uuid = require_dist_cjs19();
    var utilMiddleware = require_dist_cjs6();
    var smithyClient = require_dist_cjs34();
    var isStreamingPayload3 = require_isStreamingPayload2();
    var serde = (init_serde(), __toCommonJS(serde_exports));
    var asSdkError3 = /* @__PURE__ */ __name((error4) => {
      if (error4 instanceof Error)
        return error4;
      if (error4 instanceof Object)
        return Object.assign(new Error(), error4);
      if (typeof error4 === "string")
        return new Error(error4);
      return new Error(`AWS SDK error wrapper for ${error4}`);
    }, "asSdkError");
    var getDefaultRetryQuota3 = /* @__PURE__ */ __name((initialRetryTokens, options) => {
      const MAX_CAPACITY = initialRetryTokens;
      const noRetryIncrement = utilRetry.NO_RETRY_INCREMENT;
      const retryCost = utilRetry.RETRY_COST;
      const timeoutRetryCost = utilRetry.TIMEOUT_RETRY_COST;
      let availableCapacity = initialRetryTokens;
      const getCapacityAmount = /* @__PURE__ */ __name((error4) => error4.name === "TimeoutError" ? timeoutRetryCost : retryCost, "getCapacityAmount");
      const hasRetryTokens = /* @__PURE__ */ __name((error4) => getCapacityAmount(error4) <= availableCapacity, "hasRetryTokens");
      const retrieveRetryTokens = /* @__PURE__ */ __name((error4) => {
        if (!hasRetryTokens(error4)) {
          throw new Error("No retry token available");
        }
        const capacityAmount = getCapacityAmount(error4);
        availableCapacity -= capacityAmount;
        return capacityAmount;
      }, "retrieveRetryTokens");
      const releaseRetryTokens = /* @__PURE__ */ __name((capacityReleaseAmount) => {
        availableCapacity += capacityReleaseAmount ?? noRetryIncrement;
        availableCapacity = Math.min(availableCapacity, MAX_CAPACITY);
      }, "releaseRetryTokens");
      return Object.freeze({
        hasRetryTokens,
        retrieveRetryTokens,
        releaseRetryTokens
      });
    }, "getDefaultRetryQuota");
    var defaultDelayDecider3 = /* @__PURE__ */ __name((delayBase, attempts) => Math.floor(Math.min(utilRetry.MAXIMUM_RETRY_DELAY, Math.random() * 2 ** attempts * delayBase)), "defaultDelayDecider");
    var defaultRetryDecider3 = /* @__PURE__ */ __name((error4) => {
      if (!error4) {
        return false;
      }
      return serviceErrorClassification.isRetryableByTrait(error4) || serviceErrorClassification.isClockSkewError(error4) || serviceErrorClassification.isThrottlingError(error4) || serviceErrorClassification.isTransientError(error4);
    }, "defaultRetryDecider");
    var StandardRetryStrategy5 = class {
      static {
        __name(this, "StandardRetryStrategy");
      }
      maxAttemptsProvider;
      retryDecider;
      delayDecider;
      retryQuota;
      mode = utilRetry.RETRY_MODES.STANDARD;
      constructor(maxAttemptsProvider, options) {
        this.maxAttemptsProvider = maxAttemptsProvider;
        this.retryDecider = options?.retryDecider ?? defaultRetryDecider3;
        this.delayDecider = options?.delayDecider ?? defaultDelayDecider3;
        this.retryQuota = options?.retryQuota ?? getDefaultRetryQuota3(utilRetry.INITIAL_RETRY_TOKENS);
      }
      shouldRetry(error4, attempts, maxAttempts) {
        return attempts < maxAttempts && this.retryDecider(error4) && this.retryQuota.hasRetryTokens(error4);
      }
      async getMaxAttempts() {
        let maxAttempts;
        try {
          maxAttempts = await this.maxAttemptsProvider();
        } catch (error4) {
          maxAttempts = utilRetry.DEFAULT_MAX_ATTEMPTS;
        }
        return maxAttempts;
      }
      async retry(next, args, options) {
        let retryTokenAmount;
        let attempts = 0;
        let totalDelay = 0;
        const maxAttempts = await this.getMaxAttempts();
        const { request: request4 } = args;
        if (protocolHttp.HttpRequest.isInstance(request4)) {
          request4.headers[utilRetry.INVOCATION_ID_HEADER] = uuid.v4();
        }
        while (true) {
          try {
            if (protocolHttp.HttpRequest.isInstance(request4)) {
              request4.headers[utilRetry.REQUEST_HEADER] = `attempt=${attempts + 1}; max=${maxAttempts}`;
            }
            if (options?.beforeRequest) {
              await options.beforeRequest();
            }
            const { response, output } = await next(args);
            if (options?.afterRequest) {
              options.afterRequest(response);
            }
            this.retryQuota.releaseRetryTokens(retryTokenAmount);
            output.$metadata.attempts = attempts + 1;
            output.$metadata.totalRetryDelay = totalDelay;
            return { response, output };
          } catch (e32) {
            const err = asSdkError3(e32);
            attempts++;
            if (this.shouldRetry(err, attempts, maxAttempts)) {
              retryTokenAmount = this.retryQuota.retrieveRetryTokens(err);
              const delayFromDecider = this.delayDecider(serviceErrorClassification.isThrottlingError(err) ? utilRetry.THROTTLING_RETRY_DELAY_BASE : utilRetry.DEFAULT_RETRY_DELAY_BASE, attempts);
              const delayFromResponse = getDelayFromRetryAfterHeader3(err.$response);
              const delay = Math.max(delayFromResponse || 0, delayFromDecider);
              totalDelay += delay;
              await new Promise((resolve13) => setTimeout(resolve13, delay));
              continue;
            }
            if (!err.$metadata) {
              err.$metadata = {};
            }
            err.$metadata.attempts = attempts;
            err.$metadata.totalRetryDelay = totalDelay;
            throw err;
          }
        }
      }
    };
    var getDelayFromRetryAfterHeader3 = /* @__PURE__ */ __name((response) => {
      if (!protocolHttp.HttpResponse.isInstance(response))
        return;
      const retryAfterHeaderName = Object.keys(response.headers).find((key) => key.toLowerCase() === "retry-after");
      if (!retryAfterHeaderName)
        return;
      const retryAfter = response.headers[retryAfterHeaderName];
      const retryAfterSeconds = Number(retryAfter);
      if (!Number.isNaN(retryAfterSeconds))
        return retryAfterSeconds * 1e3;
      const retryAfterDate = new Date(retryAfter);
      return retryAfterDate.getTime() - Date.now();
    }, "getDelayFromRetryAfterHeader");
    var AdaptiveRetryStrategy5 = class extends StandardRetryStrategy5 {
      static {
        __name(this, "AdaptiveRetryStrategy");
      }
      rateLimiter;
      constructor(maxAttemptsProvider, options) {
        const { rateLimiter, ...superOptions } = options ?? {};
        super(maxAttemptsProvider, superOptions);
        this.rateLimiter = rateLimiter ?? new utilRetry.DefaultRateLimiter();
        this.mode = utilRetry.RETRY_MODES.ADAPTIVE;
      }
      async retry(next, args) {
        return super.retry(next, args, {
          beforeRequest: /* @__PURE__ */ __name(async () => {
            return this.rateLimiter.getSendToken();
          }, "beforeRequest"),
          afterRequest: /* @__PURE__ */ __name((response) => {
            this.rateLimiter.updateClientSendingRate(response);
          }, "afterRequest")
        });
      }
    };
    var ENV_MAX_ATTEMPTS3 = "AWS_MAX_ATTEMPTS";
    var CONFIG_MAX_ATTEMPTS3 = "max_attempts";
    var NODE_MAX_ATTEMPT_CONFIG_OPTIONS30 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => {
        const value = env3[ENV_MAX_ATTEMPTS3];
        if (!value)
          return void 0;
        const maxAttempt = parseInt(value);
        if (Number.isNaN(maxAttempt)) {
          throw new Error(`Environment variable ${ENV_MAX_ATTEMPTS3} mast be a number, got "${value}"`);
        }
        return maxAttempt;
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => {
        const value = profile[CONFIG_MAX_ATTEMPTS3];
        if (!value)
          return void 0;
        const maxAttempt = parseInt(value);
        if (Number.isNaN(maxAttempt)) {
          throw new Error(`Shared config file entry ${CONFIG_MAX_ATTEMPTS3} mast be a number, got "${value}"`);
        }
        return maxAttempt;
      }, "configFileSelector"),
      default: utilRetry.DEFAULT_MAX_ATTEMPTS
    };
    var resolveRetryConfig30 = /* @__PURE__ */ __name((input) => {
      const { retryStrategy, retryMode } = input;
      const maxAttempts = utilMiddleware.normalizeProvider(input.maxAttempts ?? utilRetry.DEFAULT_MAX_ATTEMPTS);
      let controller = retryStrategy ? Promise.resolve(retryStrategy) : void 0;
      const getDefault = /* @__PURE__ */ __name(async () => await utilMiddleware.normalizeProvider(retryMode)() === utilRetry.RETRY_MODES.ADAPTIVE ? new utilRetry.AdaptiveRetryStrategy(maxAttempts) : new utilRetry.StandardRetryStrategy(maxAttempts), "getDefault");
      return Object.assign(input, {
        maxAttempts,
        retryStrategy: /* @__PURE__ */ __name(() => controller ??= getDefault(), "retryStrategy")
      });
    }, "resolveRetryConfig");
    var ENV_RETRY_MODE3 = "AWS_RETRY_MODE";
    var CONFIG_RETRY_MODE3 = "retry_mode";
    var NODE_RETRY_MODE_CONFIG_OPTIONS30 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[ENV_RETRY_MODE3], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[CONFIG_RETRY_MODE3], "configFileSelector"),
      default: utilRetry.DEFAULT_RETRY_MODE
    };
    var omitRetryHeadersMiddleware3 = /* @__PURE__ */ __name(() => (next) => async (args) => {
      const { request: request4 } = args;
      if (protocolHttp.HttpRequest.isInstance(request4)) {
        delete request4.headers[utilRetry.INVOCATION_ID_HEADER];
        delete request4.headers[utilRetry.REQUEST_HEADER];
      }
      return next(args);
    }, "omitRetryHeadersMiddleware");
    var omitRetryHeadersMiddlewareOptions3 = {
      name: "omitRetryHeadersMiddleware",
      tags: ["RETRY", "HEADERS", "OMIT_RETRY_HEADERS"],
      relation: "before",
      toMiddleware: "awsAuthMiddleware",
      override: true
    };
    var getOmitRetryHeadersPlugin3 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.addRelativeTo(omitRetryHeadersMiddleware3(), omitRetryHeadersMiddlewareOptions3);
      }, "applyToStack")
    }), "getOmitRetryHeadersPlugin");
    function parseRetryAfterHeader3(response, logger5) {
      if (!protocolHttp.HttpResponse.isInstance(response)) {
        return;
      }
      for (const header of Object.keys(response.headers)) {
        const h32 = header.toLowerCase();
        if (h32 === "retry-after") {
          const retryAfter = response.headers[header];
          let retryAfterSeconds = NaN;
          if (retryAfter.endsWith("GMT")) {
            try {
              const date7 = serde.parseRfc7231DateTime(retryAfter);
              retryAfterSeconds = (date7.getTime() - Date.now()) / 1e3;
            } catch (e32) {
              logger5?.trace?.("Failed to parse retry-after header");
              logger5?.trace?.(e32);
            }
          } else if (retryAfter.match(/ GMT, ((\d+)|(\d+\.\d+))$/)) {
            retryAfterSeconds = Number(retryAfter.match(/ GMT, ([\d.]+)$/)?.[1]);
          } else if (retryAfter.match(/^((\d+)|(\d+\.\d+))$/)) {
            retryAfterSeconds = Number(retryAfter);
          } else if (Date.parse(retryAfter) >= Date.now()) {
            retryAfterSeconds = (Date.parse(retryAfter) - Date.now()) / 1e3;
          }
          if (isNaN(retryAfterSeconds)) {
            return;
          }
          return new Date(Date.now() + retryAfterSeconds * 1e3);
        } else if (h32 === "x-amz-retry-after") {
          const v = response.headers[header];
          const backoffMilliseconds = Number(v);
          if (isNaN(backoffMilliseconds)) {
            logger5?.trace?.(`Failed to parse x-amz-retry-after=${v}`);
            return;
          }
          return new Date(Date.now() + backoffMilliseconds);
        }
      }
    }
    __name(parseRetryAfterHeader3, "parseRetryAfterHeader");
    function getRetryAfterHint3(response, logger5) {
      return parseRetryAfterHeader3(response, logger5);
    }
    __name(getRetryAfterHint3, "getRetryAfterHint");
    var retryMiddleware3 = /* @__PURE__ */ __name((options) => (next, context) => async (args) => {
      let retryStrategy = await options.retryStrategy();
      const maxAttempts = await options.maxAttempts();
      if (isRetryStrategyV23(retryStrategy)) {
        retryStrategy = retryStrategy;
        let retryToken = await retryStrategy.acquireInitialRetryToken((context["partition_id"] ?? "") + (context.__retryLongPoll ? ":longpoll" : ""));
        let lastError = new Error();
        let attempts = 0;
        let totalRetryDelay = 0;
        const { request: request4 } = args;
        const isRequest = protocolHttp.HttpRequest.isInstance(request4);
        if (isRequest) {
          request4.headers[utilRetry.INVOCATION_ID_HEADER] = uuid.v4();
        }
        while (true) {
          try {
            if (isRequest) {
              request4.headers[utilRetry.REQUEST_HEADER] = `attempt=${attempts + 1}; max=${maxAttempts}`;
            }
            const { response, output } = await next(args);
            retryStrategy.recordSuccess(retryToken);
            output.$metadata.attempts = attempts + 1;
            output.$metadata.totalRetryDelay = totalRetryDelay;
            return { response, output };
          } catch (e32) {
            const retryErrorInfo = getRetryErrorInfo3(e32, options.logger);
            lastError = asSdkError3(e32);
            if (isRequest && isStreamingPayload3.isStreamingPayload(request4)) {
              (context.logger instanceof smithyClient.NoOpLogger ? console : context.logger)?.warn("An error was encountered in a non-retryable streaming request.");
              throw lastError;
            }
            try {
              retryToken = await retryStrategy.refreshRetryTokenForRetry(retryToken, retryErrorInfo);
            } catch (refreshError) {
              if (typeof refreshError.$backoff === "number") {
                await cooldown3(refreshError.$backoff);
              }
              if (!lastError.$metadata) {
                lastError.$metadata = {};
              }
              lastError.$metadata.attempts = attempts + 1;
              lastError.$metadata.totalRetryDelay = totalRetryDelay;
              throw lastError;
            }
            attempts = retryToken.getRetryCount();
            const delay = retryToken.getRetryDelay();
            totalRetryDelay += delay;
            await cooldown3(delay);
          }
        }
      } else {
        retryStrategy = retryStrategy;
        if (retryStrategy?.mode) {
          context.userAgent = [...context.userAgent || [], ["cfg/retry-mode", retryStrategy.mode]];
        }
        return retryStrategy.retry(next, args);
      }
    }, "retryMiddleware");
    var cooldown3 = /* @__PURE__ */ __name((ms) => new Promise((resolve13) => setTimeout(resolve13, ms)), "cooldown");
    var isRetryStrategyV23 = /* @__PURE__ */ __name((retryStrategy) => typeof retryStrategy.acquireInitialRetryToken !== "undefined" && typeof retryStrategy.refreshRetryTokenForRetry !== "undefined" && typeof retryStrategy.recordSuccess !== "undefined", "isRetryStrategyV2");
    var getRetryErrorInfo3 = /* @__PURE__ */ __name((error4, logger5) => {
      const errorInfo = {
        error: error4,
        errorType: getRetryErrorType3(error4)
      };
      const retryAfterHint = parseRetryAfterHeader3(error4.$response, logger5);
      if (retryAfterHint) {
        errorInfo.retryAfterHint = retryAfterHint;
      }
      return errorInfo;
    }, "getRetryErrorInfo");
    var getRetryErrorType3 = /* @__PURE__ */ __name((error4) => {
      if (serviceErrorClassification.isThrottlingError(error4))
        return "THROTTLING";
      if (serviceErrorClassification.isTransientError(error4))
        return "TRANSIENT";
      if (serviceErrorClassification.isServerError(error4))
        return "SERVER_ERROR";
      return "CLIENT_ERROR";
    }, "getRetryErrorType");
    var retryMiddlewareOptions3 = {
      name: "retryMiddleware",
      tags: ["RETRY"],
      step: "finalizeRequest",
      priority: "high",
      override: true
    };
    var getRetryPlugin30 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(retryMiddleware3(options), retryMiddlewareOptions3);
      }, "applyToStack")
    }), "getRetryPlugin");
    exports2.AdaptiveRetryStrategy = AdaptiveRetryStrategy5;
    exports2.CONFIG_MAX_ATTEMPTS = CONFIG_MAX_ATTEMPTS3;
    exports2.CONFIG_RETRY_MODE = CONFIG_RETRY_MODE3;
    exports2.ENV_MAX_ATTEMPTS = ENV_MAX_ATTEMPTS3;
    exports2.ENV_RETRY_MODE = ENV_RETRY_MODE3;
    exports2.NODE_MAX_ATTEMPT_CONFIG_OPTIONS = NODE_MAX_ATTEMPT_CONFIG_OPTIONS30;
    exports2.NODE_RETRY_MODE_CONFIG_OPTIONS = NODE_RETRY_MODE_CONFIG_OPTIONS30;
    exports2.StandardRetryStrategy = StandardRetryStrategy5;
    exports2.defaultDelayDecider = defaultDelayDecider3;
    exports2.defaultRetryDecider = defaultRetryDecider3;
    exports2.getOmitRetryHeadersPlugin = getOmitRetryHeadersPlugin3;
    exports2.getRetryAfterHint = getRetryAfterHint3;
    exports2.getRetryPlugin = getRetryPlugin30;
    exports2.omitRetryHeadersMiddleware = omitRetryHeadersMiddleware3;
    exports2.omitRetryHeadersMiddlewareOptions = omitRetryHeadersMiddlewareOptions3;
    exports2.resolveRetryConfig = resolveRetryConfig30;
    exports2.retryMiddleware = retryMiddleware3;
    exports2.retryMiddlewareOptions = retryMiddlewareOptions3;
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "sso-oauth",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var import_util_middleware5, defaultSSOOIDCHttpAuthSchemeParametersProvider, defaultSSOOIDCHttpAuthSchemeProvider, resolveHttpAuthSchemeConfig;
var init_httpAuthSchemeProvider = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes3();
    import_util_middleware5 = __toESM(require_dist_cjs6());
    defaultSSOOIDCHttpAuthSchemeParametersProvider = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, import_util_middleware5.getSmithyContext)(context).operation,
        region: await (0, import_util_middleware5.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultSSOOIDCHttpAuthSchemeParametersProvider");
    __name(createAwsAuthSigv4HttpAuthOption, "createAwsAuthSigv4HttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption, "createSmithyApiNoAuthHttpAuthOption");
    defaultSSOOIDCHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "CreateToken": {
          options.push(createSmithyApiNoAuthHttpAuthOption(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption(authParameters));
        }
      }
      return options;
    }, "defaultSSOOIDCHttpAuthSchemeProvider");
    resolveHttpAuthSchemeConfig = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveAwsSdkSigV4Config2(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, import_util_middleware5.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/endpoint/EndpointParameters.js
var resolveClientEndpointParameters, commonParams;
var init_EndpointParameters = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "sso-oauth"
      });
    }, "resolveClientEndpointParameters");
    commonParams = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/package.json
var package_default;
var init_package = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/package.json"() {
    package_default = {
      name: "@aws-sdk/nested-clients",
      version: "3.997.6",
      description: "Nested clients for AWS SDK packages.",
      main: "./dist-cjs/index.js",
      module: "./dist-es/index.js",
      types: "./dist-types/index.d.ts",
      scripts: {
        build: "yarn lint && concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline nested-clients",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        lint: "node ../../scripts/validation/submodules-linter.js --pkg nested-clients",
        test: "yarn g:vitest run",
        "test:watch": "yarn g:vitest watch"
      },
      engines: {
        node: ">=20.0.0"
      },
      sideEffects: false,
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      dependencies: {
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.8",
        "@aws-sdk/middleware-host-header": "^3.972.10",
        "@aws-sdk/middleware-logger": "^3.972.10",
        "@aws-sdk/middleware-recursion-detection": "^3.972.11",
        "@aws-sdk/middleware-user-agent": "^3.972.38",
        "@aws-sdk/region-config-resolver": "^3.972.13",
        "@aws-sdk/signature-v4-multi-region": "^3.996.25",
        "@aws-sdk/types": "^3.973.8",
        "@aws-sdk/util-endpoints": "^3.996.8",
        "@aws-sdk/util-user-agent-browser": "^3.972.10",
        "@aws-sdk/util-user-agent-node": "^3.973.24",
        "@smithy/config-resolver": "^4.4.17",
        "@smithy/core": "^3.23.17",
        "@smithy/fetch-http-handler": "^5.3.17",
        "@smithy/hash-node": "^4.2.14",
        "@smithy/invalid-dependency": "^4.2.14",
        "@smithy/middleware-content-length": "^4.2.14",
        "@smithy/middleware-endpoint": "^4.4.32",
        "@smithy/middleware-retry": "^4.5.7",
        "@smithy/middleware-serde": "^4.2.20",
        "@smithy/middleware-stack": "^4.2.14",
        "@smithy/node-config-provider": "^4.3.14",
        "@smithy/node-http-handler": "^4.6.1",
        "@smithy/protocol-http": "^5.3.14",
        "@smithy/smithy-client": "^4.12.13",
        "@smithy/types": "^4.14.1",
        "@smithy/url-parser": "^4.2.14",
        "@smithy/util-base64": "^4.3.2",
        "@smithy/util-body-length-browser": "^4.2.2",
        "@smithy/util-body-length-node": "^4.2.3",
        "@smithy/util-defaults-mode-browser": "^4.3.49",
        "@smithy/util-defaults-mode-node": "^4.2.54",
        "@smithy/util-endpoints": "^3.4.2",
        "@smithy/util-middleware": "^4.2.14",
        "@smithy/util-retry": "^4.3.6",
        "@smithy/util-utf8": "^4.2.2",
        tslib: "^2.6.2"
      },
      devDependencies: {
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "./cognito-identity.d.ts",
        "./cognito-identity.js",
        "./signin.d.ts",
        "./signin.js",
        "./sso-oidc.d.ts",
        "./sso-oidc.js",
        "./sso.d.ts",
        "./sso.js",
        "./sts.d.ts",
        "./sts.js",
        "dist-*/**"
      ],
      browser: {
        "./dist-es/submodules/cognito-identity/runtimeConfig": "./dist-es/submodules/cognito-identity/runtimeConfig.browser",
        "./dist-es/submodules/signin/runtimeConfig": "./dist-es/submodules/signin/runtimeConfig.browser",
        "./dist-es/submodules/sso-oidc/runtimeConfig": "./dist-es/submodules/sso-oidc/runtimeConfig.browser",
        "./dist-es/submodules/sso/runtimeConfig": "./dist-es/submodules/sso/runtimeConfig.browser",
        "./dist-es/submodules/sts/runtimeConfig": "./dist-es/submodules/sts/runtimeConfig.browser"
      },
      "react-native": {},
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/packages/nested-clients",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "packages/nested-clients"
      },
      exports: {
        "./package.json": "./package.json",
        "./sso-oidc": {
          types: "./dist-types/submodules/sso-oidc/index.d.ts",
          module: "./dist-es/submodules/sso-oidc/index.js",
          node: "./dist-cjs/submodules/sso-oidc/index.js",
          import: "./dist-es/submodules/sso-oidc/index.js",
          require: "./dist-cjs/submodules/sso-oidc/index.js"
        },
        "./sts": {
          types: "./dist-types/submodules/sts/index.d.ts",
          module: "./dist-es/submodules/sts/index.js",
          node: "./dist-cjs/submodules/sts/index.js",
          import: "./dist-es/submodules/sts/index.js",
          require: "./dist-cjs/submodules/sts/index.js"
        },
        "./signin": {
          types: "./dist-types/submodules/signin/index.d.ts",
          module: "./dist-es/submodules/signin/index.js",
          node: "./dist-cjs/submodules/signin/index.js",
          import: "./dist-es/submodules/signin/index.js",
          require: "./dist-cjs/submodules/signin/index.js"
        },
        "./cognito-identity": {
          types: "./dist-types/submodules/cognito-identity/index.d.ts",
          module: "./dist-es/submodules/cognito-identity/index.js",
          node: "./dist-cjs/submodules/cognito-identity/index.js",
          import: "./dist-es/submodules/cognito-identity/index.js",
          require: "./dist-cjs/submodules/cognito-identity/index.js"
        },
        "./sso": {
          types: "./dist-types/submodules/sso/index.d.ts",
          module: "./dist-es/submodules/sso/index.js",
          node: "./dist-cjs/submodules/sso/index.js",
          import: "./dist-es/submodules/sso/index.js",
          require: "./dist-cjs/submodules/sso/index.js"
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/util-user-agent-node/dist-cjs/index.js
var require_dist_cjs43 = __commonJS({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/util-user-agent-node/dist-cjs/index.js"(exports2) {
    "use strict";
    var node_os = require("node:os");
    var node_process = require("node:process");
    var utilConfigProvider = require_dist_cjs24();
    var promises5 = require("node:fs/promises");
    var node_path = require("node:path");
    var middlewareUserAgent = require_dist_cjs41();
    var getRuntimeUserAgentPair2 = /* @__PURE__ */ __name(() => {
      const runtimesToCheck = ["deno", "bun", "llrt"];
      for (const runtime of runtimesToCheck) {
        if (node_process.versions[runtime]) {
          return [`md/${runtime}`, node_process.versions[runtime]];
        }
      }
      return ["md/nodejs", node_process.versions.node];
    }, "getRuntimeUserAgentPair");
    var getNodeModulesParentDirs2 = /* @__PURE__ */ __name((dirname14) => {
      const cwd = process.cwd();
      if (!dirname14) {
        return [cwd];
      }
      const normalizedPath = node_path.normalize(dirname14);
      const parts = normalizedPath.split(node_path.sep);
      const nodeModulesIndex = parts.indexOf("node_modules");
      const parentDir = nodeModulesIndex !== -1 ? parts.slice(0, nodeModulesIndex).join(node_path.sep) : normalizedPath;
      if (cwd === parentDir) {
        return [cwd];
      }
      return [parentDir, cwd];
    }, "getNodeModulesParentDirs");
    var SEMVER_REGEX2 = /^(0|[1-9]\d*)\.(0|[1-9]\d*)\.(0|[1-9]\d*)(?:-((?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*)(?:\.(?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*))*))?(?:\+[0-9a-zA-Z-]+(?:\.[0-9a-zA-Z-]+)*)?$/;
    var getSanitizedTypeScriptVersion2 = /* @__PURE__ */ __name((version = "") => {
      const match = version.match(SEMVER_REGEX2);
      if (!match) {
        return void 0;
      }
      const [major6, minor, patch, prerelease] = [match[1], match[2], match[3], match[4]];
      return prerelease ? `${major6}.${minor}.${patch}-${prerelease}` : `${major6}.${minor}.${patch}`;
    }, "getSanitizedTypeScriptVersion");
    var ALLOWED_PREFIXES2 = ["^", "~", ">=", "<=", ">", "<"];
    var ALLOWED_DIST_TAGS2 = ["latest", "beta", "dev", "rc", "insiders", "next"];
    var getSanitizedDevTypeScriptVersion2 = /* @__PURE__ */ __name((version = "") => {
      if (ALLOWED_DIST_TAGS2.includes(version)) {
        return version;
      }
      const prefix = ALLOWED_PREFIXES2.find((p10) => version.startsWith(p10)) ?? "";
      const sanitizedTypeScriptVersion = getSanitizedTypeScriptVersion2(version.slice(prefix.length));
      if (!sanitizedTypeScriptVersion) {
        return void 0;
      }
      return `${prefix}${sanitizedTypeScriptVersion}`;
    }, "getSanitizedDevTypeScriptVersion");
    var tscVersion2;
    var TS_PACKAGE_JSON2 = node_path.join("node_modules", "typescript", "package.json");
    var getTypeScriptUserAgentPair2 = /* @__PURE__ */ __name(async () => {
      if (tscVersion2 === null) {
        return void 0;
      } else if (typeof tscVersion2 === "string") {
        return ["md/tsc", tscVersion2];
      }
      let isTypeScriptDetectionDisabled = false;
      try {
        isTypeScriptDetectionDisabled = utilConfigProvider.booleanSelector(process.env, "AWS_SDK_JS_TYPESCRIPT_DETECTION_DISABLED", utilConfigProvider.SelectorType.ENV) || false;
      } catch {
      }
      if (isTypeScriptDetectionDisabled) {
        tscVersion2 = null;
        return void 0;
      }
      const dirname14 = typeof __dirname !== "undefined" ? __dirname : void 0;
      const nodeModulesParentDirs = getNodeModulesParentDirs2(dirname14);
      let versionFromApp;
      for (const nodeModulesParentDir of nodeModulesParentDirs) {
        try {
          const appPackageJsonPath = node_path.join(nodeModulesParentDir, "package.json");
          const packageJson = await promises5.readFile(appPackageJsonPath, "utf-8");
          const { dependencies, devDependencies } = JSON.parse(packageJson);
          const version = devDependencies?.typescript ?? dependencies?.typescript;
          if (typeof version !== "string") {
            continue;
          }
          versionFromApp = version;
          break;
        } catch {
        }
      }
      if (!versionFromApp) {
        tscVersion2 = null;
        return void 0;
      }
      let versionFromNodeModules;
      for (const nodeModulesParentDir of nodeModulesParentDirs) {
        try {
          const tsPackageJsonPath = node_path.join(nodeModulesParentDir, TS_PACKAGE_JSON2);
          const packageJson = await promises5.readFile(tsPackageJsonPath, "utf-8");
          const { version } = JSON.parse(packageJson);
          const sanitizedVersion2 = getSanitizedTypeScriptVersion2(version);
          if (typeof sanitizedVersion2 !== "string") {
            continue;
          }
          versionFromNodeModules = sanitizedVersion2;
          break;
        } catch {
        }
      }
      if (versionFromNodeModules) {
        tscVersion2 = versionFromNodeModules;
        return ["md/tsc", tscVersion2];
      }
      const sanitizedVersion = getSanitizedDevTypeScriptVersion2(versionFromApp);
      if (typeof sanitizedVersion !== "string") {
        tscVersion2 = null;
        return void 0;
      }
      tscVersion2 = `dev_${sanitizedVersion}`;
      return ["md/tsc", tscVersion2];
    }, "getTypeScriptUserAgentPair");
    var crtAvailability2 = {
      isCrtAvailable: false
    };
    var isCrtAvailable2 = /* @__PURE__ */ __name(() => {
      if (crtAvailability2.isCrtAvailable) {
        return ["md/crt-avail"];
      }
      return null;
    }, "isCrtAvailable");
    var createDefaultUserAgentProvider29 = /* @__PURE__ */ __name(({ serviceId, clientVersion }) => {
      const runtimeUserAgentPair = getRuntimeUserAgentPair2();
      return async (config2) => {
        const sections = [
          ["aws-sdk-js", clientVersion],
          ["ua", "2.1"],
          [`os/${node_os.platform()}`, node_os.release()],
          ["lang/js"],
          runtimeUserAgentPair
        ];
        const typescriptUserAgentPair = await getTypeScriptUserAgentPair2();
        if (typescriptUserAgentPair) {
          sections.push(typescriptUserAgentPair);
        }
        const crtAvailable = isCrtAvailable2();
        if (crtAvailable) {
          sections.push(crtAvailable);
        }
        if (serviceId) {
          sections.push([`api/${serviceId}`, clientVersion]);
        }
        if (node_process.env.AWS_EXECUTION_ENV) {
          sections.push([`exec-env/${node_process.env.AWS_EXECUTION_ENV}`]);
        }
        const appId = await config2?.userAgentAppId?.();
        const resolvedUserAgent = appId ? [...sections, [`app/${appId}`]] : [...sections];
        return resolvedUserAgent;
      };
    }, "createDefaultUserAgentProvider");
    var defaultUserAgent2 = createDefaultUserAgentProvider29;
    var UA_APP_ID_ENV_NAME2 = "AWS_SDK_UA_APP_ID";
    var UA_APP_ID_INI_NAME2 = "sdk_ua_app_id";
    var UA_APP_ID_INI_NAME_DEPRECATED2 = "sdk-ua-app-id";
    var NODE_APP_ID_CONFIG_OPTIONS29 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[UA_APP_ID_ENV_NAME2], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[UA_APP_ID_INI_NAME2] ?? profile[UA_APP_ID_INI_NAME_DEPRECATED2], "configFileSelector"),
      default: middlewareUserAgent.DEFAULT_UA_APP_ID
    };
    exports2.NODE_APP_ID_CONFIG_OPTIONS = NODE_APP_ID_CONFIG_OPTIONS29;
    exports2.UA_APP_ID_ENV_NAME = UA_APP_ID_ENV_NAME2;
    exports2.UA_APP_ID_INI_NAME = UA_APP_ID_INI_NAME2;
    exports2.createDefaultUserAgentProvider = createDefaultUserAgentProvider29;
    exports2.crtAvailability = crtAvailability2;
    exports2.defaultUserAgent = defaultUserAgent2;
  }
});

// ../../node_modules/@smithy/hash-node/dist-cjs/index.js
var require_dist_cjs44 = __commonJS({
  "../../node_modules/@smithy/hash-node/dist-cjs/index.js"(exports2) {
    "use strict";
    var utilBufferFrom = require_dist_cjs8();
    var utilUtf8 = require_dist_cjs9();
    var buffer = require("buffer");
    var crypto4 = require("crypto");
    var Hash30 = class {
      static {
        __name(this, "Hash");
      }
      algorithmIdentifier;
      secret;
      hash;
      constructor(algorithmIdentifier, secret) {
        this.algorithmIdentifier = algorithmIdentifier;
        this.secret = secret;
        this.reset();
      }
      update(toHash, encoding) {
        this.hash.update(utilUtf8.toUint8Array(castSourceData3(toHash, encoding)));
      }
      digest() {
        return Promise.resolve(this.hash.digest());
      }
      reset() {
        this.hash = this.secret ? crypto4.createHmac(this.algorithmIdentifier, castSourceData3(this.secret)) : crypto4.createHash(this.algorithmIdentifier);
      }
    };
    function castSourceData3(toCast, encoding) {
      if (buffer.Buffer.isBuffer(toCast)) {
        return toCast;
      }
      if (typeof toCast === "string") {
        return utilBufferFrom.fromString(toCast, encoding);
      }
      if (ArrayBuffer.isView(toCast)) {
        return utilBufferFrom.fromArrayBuffer(toCast.buffer, toCast.byteOffset, toCast.byteLength);
      }
      return utilBufferFrom.fromArrayBuffer(toCast);
    }
    __name(castSourceData3, "castSourceData");
    exports2.Hash = Hash30;
  }
});

// ../../node_modules/@smithy/util-body-length-node/dist-cjs/index.js
var require_dist_cjs45 = __commonJS({
  "../../node_modules/@smithy/util-body-length-node/dist-cjs/index.js"(exports2) {
    "use strict";
    var node_fs = require("node:fs");
    var calculateBodyLength30 = /* @__PURE__ */ __name((body) => {
      if (!body) {
        return 0;
      }
      if (typeof body === "string") {
        return Buffer.byteLength(body);
      } else if (typeof body.byteLength === "number") {
        return body.byteLength;
      } else if (typeof body.size === "number") {
        return body.size;
      } else if (typeof body.start === "number" && typeof body.end === "number") {
        return body.end + 1 - body.start;
      } else if (body instanceof node_fs.ReadStream) {
        if (body.path != null) {
          return node_fs.lstatSync(body.path).size;
        } else if (typeof body.fd === "number") {
          return node_fs.fstatSync(body.fd).size;
        }
      }
      throw new Error(`Body Length computation failed for ${body}`);
    }, "calculateBodyLength");
    exports2.calculateBodyLength = calculateBodyLength30;
  }
});

// ../../node_modules/@smithy/util-defaults-mode-node/dist-cjs/index.js
var require_dist_cjs46 = __commonJS({
  "../../node_modules/@smithy/util-defaults-mode-node/dist-cjs/index.js"(exports2) {
    "use strict";
    var configResolver = require_dist_cjs25();
    var nodeConfigProvider = require_dist_cjs29();
    var propertyProvider = require_dist_cjs27();
    var AWS_EXECUTION_ENV3 = "AWS_EXECUTION_ENV";
    var AWS_REGION_ENV3 = "AWS_REGION";
    var AWS_DEFAULT_REGION_ENV3 = "AWS_DEFAULT_REGION";
    var ENV_IMDS_DISABLED3 = "AWS_EC2_METADATA_DISABLED";
    var DEFAULTS_MODE_OPTIONS3 = ["in-region", "cross-region", "mobile", "standard", "legacy"];
    var IMDS_REGION_PATH3 = "/latest/meta-data/placement/region";
    var AWS_DEFAULTS_MODE_ENV3 = "AWS_DEFAULTS_MODE";
    var AWS_DEFAULTS_MODE_CONFIG3 = "defaults_mode";
    var NODE_DEFAULTS_MODE_CONFIG_OPTIONS3 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => {
        return env3[AWS_DEFAULTS_MODE_ENV3];
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => {
        return profile[AWS_DEFAULTS_MODE_CONFIG3];
      }, "configFileSelector"),
      default: "legacy"
    };
    var resolveDefaultsModeConfig30 = /* @__PURE__ */ __name(({ region = nodeConfigProvider.loadConfig(configResolver.NODE_REGION_CONFIG_OPTIONS), defaultsMode = nodeConfigProvider.loadConfig(NODE_DEFAULTS_MODE_CONFIG_OPTIONS3) } = {}) => propertyProvider.memoize(async () => {
      const mode = typeof defaultsMode === "function" ? await defaultsMode() : defaultsMode;
      switch (mode?.toLowerCase()) {
        case "auto":
          return resolveNodeDefaultsModeAuto3(region);
        case "in-region":
        case "cross-region":
        case "mobile":
        case "standard":
        case "legacy":
          return Promise.resolve(mode?.toLocaleLowerCase());
        case void 0:
          return Promise.resolve("legacy");
        default:
          throw new Error(`Invalid parameter for "defaultsMode", expect ${DEFAULTS_MODE_OPTIONS3.join(", ")}, got ${mode}`);
      }
    }), "resolveDefaultsModeConfig");
    var resolveNodeDefaultsModeAuto3 = /* @__PURE__ */ __name(async (clientRegion) => {
      if (clientRegion) {
        const resolvedRegion = typeof clientRegion === "function" ? await clientRegion() : clientRegion;
        const inferredRegion = await inferPhysicalRegion3();
        if (!inferredRegion) {
          return "standard";
        }
        if (resolvedRegion === inferredRegion) {
          return "in-region";
        } else {
          return "cross-region";
        }
      }
      return "standard";
    }, "resolveNodeDefaultsModeAuto");
    var inferPhysicalRegion3 = /* @__PURE__ */ __name(async () => {
      if (process.env[AWS_EXECUTION_ENV3] && (process.env[AWS_REGION_ENV3] || process.env[AWS_DEFAULT_REGION_ENV3])) {
        return process.env[AWS_REGION_ENV3] ?? process.env[AWS_DEFAULT_REGION_ENV3];
      }
      if (!process.env[ENV_IMDS_DISABLED3]) {
        try {
          const { getInstanceMetadataEndpoint, httpRequest } = await Promise.resolve().then(() => __toESM(require_dist_cjs38()));
          const endpoint = await getInstanceMetadataEndpoint();
          return (await httpRequest({ ...endpoint, path: IMDS_REGION_PATH3 })).toString();
        } catch (e32) {
        }
      }
    }, "inferPhysicalRegion");
    exports2.resolveDefaultsModeConfig = resolveDefaultsModeConfig30;
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/cbor/cbor-types.js
function alloc(size) {
  return typeof Buffer !== "undefined" ? Buffer.alloc(size) : new Uint8Array(size);
}
function tag(data3) {
  data3[tagSymbol] = true;
  return data3;
}
var majorUint64, majorNegativeInt64, majorUnstructuredByteString, majorUtf8String, majorList, majorMap, majorTag, majorSpecial, specialFalse, specialTrue, specialNull, specialUndefined, extendedOneByte, extendedFloat16, extendedFloat32, extendedFloat64, minorIndefinite, tagSymbol;
var init_cbor_types = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/cbor/cbor-types.js"() {
    majorUint64 = 0;
    majorNegativeInt64 = 1;
    majorUnstructuredByteString = 2;
    majorUtf8String = 3;
    majorList = 4;
    majorMap = 5;
    majorTag = 6;
    majorSpecial = 7;
    specialFalse = 20;
    specialTrue = 21;
    specialNull = 22;
    specialUndefined = 23;
    extendedOneByte = 24;
    extendedFloat16 = 25;
    extendedFloat32 = 26;
    extendedFloat64 = 27;
    minorIndefinite = 31;
    __name(alloc, "alloc");
    tagSymbol = /* @__PURE__ */ Symbol("@smithy/core/cbor::tagSymbol");
    __name(tag, "tag");
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/cbor/cbor-decode.js
function setPayload(bytes) {
  payload = bytes;
  dataView = new DataView(payload.buffer, payload.byteOffset, payload.byteLength);
}
function decode(at, to) {
  if (at >= to) {
    throw new Error("unexpected end of (decode) payload.");
  }
  const major6 = (payload[at] & 224) >> 5;
  const minor = payload[at] & 31;
  switch (major6) {
    case majorUint64:
    case majorNegativeInt64:
    case majorTag:
      let unsignedInt;
      let offset;
      if (minor < 24) {
        unsignedInt = minor;
        offset = 1;
      } else {
        switch (minor) {
          case extendedOneByte:
          case extendedFloat16:
          case extendedFloat32:
          case extendedFloat64:
            const countLength = minorValueToArgumentLength[minor];
            const countOffset = countLength + 1;
            offset = countOffset;
            if (to - at < countOffset) {
              throw new Error(`countLength ${countLength} greater than remaining buf len.`);
            }
            const countIndex = at + 1;
            if (countLength === 1) {
              unsignedInt = payload[countIndex];
            } else if (countLength === 2) {
              unsignedInt = dataView.getUint16(countIndex);
            } else if (countLength === 4) {
              unsignedInt = dataView.getUint32(countIndex);
            } else {
              unsignedInt = dataView.getBigUint64(countIndex);
            }
            break;
          default:
            throw new Error(`unexpected minor value ${minor}.`);
        }
      }
      if (major6 === majorUint64) {
        _offset = offset;
        return castBigInt(unsignedInt);
      } else if (major6 === majorNegativeInt64) {
        let negativeInt;
        if (typeof unsignedInt === "bigint") {
          negativeInt = BigInt(-1) - unsignedInt;
        } else {
          negativeInt = -1 - unsignedInt;
        }
        _offset = offset;
        return castBigInt(negativeInt);
      } else {
        if (minor === 2 || minor === 3) {
          const length = decodeCount(at + offset, to);
          let b32 = BigInt(0);
          const start = at + offset + _offset;
          for (let i32 = start; i32 < start + length; ++i32) {
            b32 = b32 << BigInt(8) | BigInt(payload[i32]);
          }
          _offset = offset + _offset + length;
          return minor === 3 ? -b32 - BigInt(1) : b32;
        } else if (minor === 4) {
          const decimalFraction = decode(at + offset, to);
          const [exponent, mantissa] = decimalFraction;
          const normalizer = mantissa < 0 ? -1 : 1;
          const mantissaStr = "0".repeat(Math.abs(exponent) + 1) + String(BigInt(normalizer) * BigInt(mantissa));
          let numericString;
          const sign = mantissa < 0 ? "-" : "";
          numericString = exponent === 0 ? mantissaStr : mantissaStr.slice(0, mantissaStr.length + exponent) + "." + mantissaStr.slice(exponent);
          numericString = numericString.replace(/^0+/g, "");
          if (numericString === "") {
            numericString = "0";
          }
          if (numericString[0] === ".") {
            numericString = "0" + numericString;
          }
          numericString = sign + numericString;
          _offset = offset + _offset;
          return nv(numericString);
        } else {
          const value = decode(at + offset, to);
          const valueOffset = _offset;
          _offset = offset + valueOffset;
          return tag({ tag: castBigInt(unsignedInt), value });
        }
      }
    case majorUtf8String:
    case majorMap:
    case majorList:
    case majorUnstructuredByteString:
      if (minor === minorIndefinite) {
        switch (major6) {
          case majorUtf8String:
            return decodeUtf8StringIndefinite(at, to);
          case majorMap:
            return decodeMapIndefinite(at, to);
          case majorList:
            return decodeListIndefinite(at, to);
          case majorUnstructuredByteString:
            return decodeUnstructuredByteStringIndefinite(at, to);
        }
      } else {
        switch (major6) {
          case majorUtf8String:
            return decodeUtf8String(at, to);
          case majorMap:
            return decodeMap(at, to);
          case majorList:
            return decodeList(at, to);
          case majorUnstructuredByteString:
            return decodeUnstructuredByteString(at, to);
        }
      }
    default:
      return decodeSpecial(at, to);
  }
}
function bytesToUtf8(bytes, at, to) {
  if (USE_BUFFER && bytes.constructor?.name === "Buffer") {
    return bytes.toString("utf-8", at, to);
  }
  if (textDecoder) {
    return textDecoder.decode(bytes.subarray(at, to));
  }
  return (0, import_util_utf84.toUtf8)(bytes.subarray(at, to));
}
function demote(bigInteger) {
  const num = Number(bigInteger);
  if (num < Number.MIN_SAFE_INTEGER || Number.MAX_SAFE_INTEGER < num) {
    console.warn(new Error(`@smithy/core/cbor - truncating BigInt(${bigInteger}) to ${num} with loss of precision.`));
  }
  return num;
}
function bytesToFloat16(a32, b32) {
  const sign = a32 >> 7;
  const exponent = (a32 & 124) >> 2;
  const fraction = (a32 & 3) << 8 | b32;
  const scalar = sign === 0 ? 1 : -1;
  let exponentComponent;
  let summation;
  if (exponent === 0) {
    if (fraction === 0) {
      return 0;
    } else {
      exponentComponent = Math.pow(2, 1 - 15);
      summation = 0;
    }
  } else if (exponent === 31) {
    if (fraction === 0) {
      return scalar * Infinity;
    } else {
      return NaN;
    }
  } else {
    exponentComponent = Math.pow(2, exponent - 15);
    summation = 1;
  }
  summation += fraction / 1024;
  return scalar * (exponentComponent * summation);
}
function decodeCount(at, to) {
  const minor = payload[at] & 31;
  if (minor < 24) {
    _offset = 1;
    return minor;
  }
  if (minor === extendedOneByte || minor === extendedFloat16 || minor === extendedFloat32 || minor === extendedFloat64) {
    const countLength = minorValueToArgumentLength[minor];
    _offset = countLength + 1;
    if (to - at < _offset) {
      throw new Error(`countLength ${countLength} greater than remaining buf len.`);
    }
    const countIndex = at + 1;
    if (countLength === 1) {
      return payload[countIndex];
    } else if (countLength === 2) {
      return dataView.getUint16(countIndex);
    } else if (countLength === 4) {
      return dataView.getUint32(countIndex);
    }
    return demote(dataView.getBigUint64(countIndex));
  }
  throw new Error(`unexpected minor value ${minor}.`);
}
function decodeUtf8String(at, to) {
  const length = decodeCount(at, to);
  const offset = _offset;
  at += offset;
  if (to - at < length) {
    throw new Error(`string len ${length} greater than remaining buf len.`);
  }
  const value = bytesToUtf8(payload, at, at + length);
  _offset = offset + length;
  return value;
}
function decodeUtf8StringIndefinite(at, to) {
  at += 1;
  const vector = [];
  for (const base = at; at < to; ) {
    if (payload[at] === 255) {
      const data3 = alloc(vector.length);
      data3.set(vector, 0);
      _offset = at - base + 2;
      return bytesToUtf8(data3, 0, data3.length);
    }
    const major6 = (payload[at] & 224) >> 5;
    const minor = payload[at] & 31;
    if (major6 !== majorUtf8String) {
      throw new Error(`unexpected major type ${major6} in indefinite string.`);
    }
    if (minor === minorIndefinite) {
      throw new Error("nested indefinite string.");
    }
    const bytes = decodeUnstructuredByteString(at, to);
    const length = _offset;
    at += length;
    for (let i32 = 0; i32 < bytes.length; ++i32) {
      vector.push(bytes[i32]);
    }
  }
  throw new Error("expected break marker.");
}
function decodeUnstructuredByteString(at, to) {
  const length = decodeCount(at, to);
  const offset = _offset;
  at += offset;
  if (to - at < length) {
    throw new Error(`unstructured byte string len ${length} greater than remaining buf len.`);
  }
  const value = payload.subarray(at, at + length);
  _offset = offset + length;
  return value;
}
function decodeUnstructuredByteStringIndefinite(at, to) {
  at += 1;
  const vector = [];
  for (const base = at; at < to; ) {
    if (payload[at] === 255) {
      const data3 = alloc(vector.length);
      data3.set(vector, 0);
      _offset = at - base + 2;
      return data3;
    }
    const major6 = (payload[at] & 224) >> 5;
    const minor = payload[at] & 31;
    if (major6 !== majorUnstructuredByteString) {
      throw new Error(`unexpected major type ${major6} in indefinite string.`);
    }
    if (minor === minorIndefinite) {
      throw new Error("nested indefinite string.");
    }
    const bytes = decodeUnstructuredByteString(at, to);
    const length = _offset;
    at += length;
    for (let i32 = 0; i32 < bytes.length; ++i32) {
      vector.push(bytes[i32]);
    }
  }
  throw new Error("expected break marker.");
}
function decodeList(at, to) {
  const listDataLength = decodeCount(at, to);
  const offset = _offset;
  at += offset;
  const base = at;
  const list3 = Array(listDataLength);
  for (let i32 = 0; i32 < listDataLength; ++i32) {
    const item = decode(at, to);
    const itemOffset = _offset;
    list3[i32] = item;
    at += itemOffset;
  }
  _offset = offset + (at - base);
  return list3;
}
function decodeListIndefinite(at, to) {
  at += 1;
  const list3 = [];
  for (const base = at; at < to; ) {
    if (payload[at] === 255) {
      _offset = at - base + 2;
      return list3;
    }
    const item = decode(at, to);
    const n10 = _offset;
    at += n10;
    list3.push(item);
  }
  throw new Error("expected break marker.");
}
function decodeMap(at, to) {
  const mapDataLength = decodeCount(at, to);
  const offset = _offset;
  at += offset;
  const base = at;
  const map5 = {};
  for (let i32 = 0; i32 < mapDataLength; ++i32) {
    if (at >= to) {
      throw new Error("unexpected end of map payload.");
    }
    const major6 = (payload[at] & 224) >> 5;
    if (major6 !== majorUtf8String) {
      throw new Error(`unexpected major type ${major6} for map key at index ${at}.`);
    }
    const key = decode(at, to);
    at += _offset;
    const value = decode(at, to);
    at += _offset;
    map5[key] = value;
  }
  _offset = offset + (at - base);
  return map5;
}
function decodeMapIndefinite(at, to) {
  at += 1;
  const base = at;
  const map5 = {};
  for (; at < to; ) {
    if (at >= to) {
      throw new Error("unexpected end of map payload.");
    }
    if (payload[at] === 255) {
      _offset = at - base + 2;
      return map5;
    }
    const major6 = (payload[at] & 224) >> 5;
    if (major6 !== majorUtf8String) {
      throw new Error(`unexpected major type ${major6} for map key.`);
    }
    const key = decode(at, to);
    at += _offset;
    const value = decode(at, to);
    at += _offset;
    map5[key] = value;
  }
  throw new Error("expected break marker.");
}
function decodeSpecial(at, to) {
  const minor = payload[at] & 31;
  switch (minor) {
    case specialTrue:
    case specialFalse:
      _offset = 1;
      return minor === specialTrue;
    case specialNull:
      _offset = 1;
      return null;
    case specialUndefined:
      _offset = 1;
      return null;
    case extendedFloat16:
      if (to - at < 3) {
        throw new Error("incomplete float16 at end of buf.");
      }
      _offset = 3;
      return bytesToFloat16(payload[at + 1], payload[at + 2]);
    case extendedFloat32:
      if (to - at < 5) {
        throw new Error("incomplete float32 at end of buf.");
      }
      _offset = 5;
      return dataView.getFloat32(at + 1);
    case extendedFloat64:
      if (to - at < 9) {
        throw new Error("incomplete float64 at end of buf.");
      }
      _offset = 9;
      return dataView.getFloat64(at + 1);
    default:
      throw new Error(`unexpected minor value ${minor}.`);
  }
}
function castBigInt(bigInt) {
  if (typeof bigInt === "number") {
    return bigInt;
  }
  const num = Number(bigInt);
  if (Number.MIN_SAFE_INTEGER <= num && num <= Number.MAX_SAFE_INTEGER) {
    return num;
  }
  return bigInt;
}
var import_util_utf84, USE_TEXT_DECODER, USE_BUFFER, payload, dataView, textDecoder, _offset, minorValueToArgumentLength;
var init_cbor_decode = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/cbor/cbor-decode.js"() {
    init_serde();
    import_util_utf84 = __toESM(require_dist_cjs9());
    init_cbor_types();
    USE_TEXT_DECODER = typeof TextDecoder !== "undefined";
    USE_BUFFER = typeof Buffer !== "undefined";
    payload = alloc(0);
    dataView = new DataView(payload.buffer, payload.byteOffset, payload.byteLength);
    textDecoder = USE_TEXT_DECODER ? new TextDecoder() : null;
    _offset = 0;
    __name(setPayload, "setPayload");
    __name(decode, "decode");
    __name(bytesToUtf8, "bytesToUtf8");
    __name(demote, "demote");
    minorValueToArgumentLength = {
      [extendedOneByte]: 1,
      [extendedFloat16]: 2,
      [extendedFloat32]: 4,
      [extendedFloat64]: 8
    };
    __name(bytesToFloat16, "bytesToFloat16");
    __name(decodeCount, "decodeCount");
    __name(decodeUtf8String, "decodeUtf8String");
    __name(decodeUtf8StringIndefinite, "decodeUtf8StringIndefinite");
    __name(decodeUnstructuredByteString, "decodeUnstructuredByteString");
    __name(decodeUnstructuredByteStringIndefinite, "decodeUnstructuredByteStringIndefinite");
    __name(decodeList, "decodeList");
    __name(decodeListIndefinite, "decodeListIndefinite");
    __name(decodeMap, "decodeMap");
    __name(decodeMapIndefinite, "decodeMapIndefinite");
    __name(decodeSpecial, "decodeSpecial");
    __name(castBigInt, "castBigInt");
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/cbor/cbor-encode.js
function ensureSpace(bytes) {
  const remaining = data.byteLength - cursor;
  if (remaining < bytes) {
    if (cursor < 16e6) {
      resize(Math.max(data.byteLength * 4, data.byteLength + bytes));
    } else {
      resize(data.byteLength + bytes + 16e6);
    }
  }
}
function toUint8Array() {
  const out = alloc(cursor);
  out.set(data.subarray(0, cursor), 0);
  cursor = 0;
  return out;
}
function resize(size) {
  const old = data;
  data = alloc(size);
  if (old) {
    if (old.copy) {
      old.copy(data, 0, 0, old.byteLength);
    } else {
      data.set(old, 0);
    }
  }
  dataView2 = new DataView(data.buffer, data.byteOffset, data.byteLength);
}
function encodeHeader(major6, value) {
  if (value < 24) {
    data[cursor++] = major6 << 5 | value;
  } else if (value < 1 << 8) {
    data[cursor++] = major6 << 5 | 24;
    data[cursor++] = value;
  } else if (value < 1 << 16) {
    data[cursor++] = major6 << 5 | extendedFloat16;
    dataView2.setUint16(cursor, value);
    cursor += 2;
  } else if (value < 2 ** 32) {
    data[cursor++] = major6 << 5 | extendedFloat32;
    dataView2.setUint32(cursor, value);
    cursor += 4;
  } else {
    data[cursor++] = major6 << 5 | extendedFloat64;
    dataView2.setBigUint64(cursor, typeof value === "bigint" ? value : BigInt(value));
    cursor += 8;
  }
}
function encode(_input) {
  const encodeStack = [_input];
  while (encodeStack.length) {
    const input = encodeStack.pop();
    ensureSpace(typeof input === "string" ? input.length * 4 : 64);
    if (typeof input === "string") {
      if (USE_BUFFER2) {
        encodeHeader(majorUtf8String, Buffer.byteLength(input));
        cursor += data.write(input, cursor);
      } else {
        const bytes = (0, import_util_utf85.fromUtf8)(input);
        encodeHeader(majorUtf8String, bytes.byteLength);
        data.set(bytes, cursor);
        cursor += bytes.byteLength;
      }
      continue;
    } else if (typeof input === "number") {
      if (Number.isInteger(input)) {
        const nonNegative = input >= 0;
        const major6 = nonNegative ? majorUint64 : majorNegativeInt64;
        const value = nonNegative ? input : -input - 1;
        if (value < 24) {
          data[cursor++] = major6 << 5 | value;
        } else if (value < 256) {
          data[cursor++] = major6 << 5 | 24;
          data[cursor++] = value;
        } else if (value < 65536) {
          data[cursor++] = major6 << 5 | extendedFloat16;
          data[cursor++] = value >> 8;
          data[cursor++] = value;
        } else if (value < 4294967296) {
          data[cursor++] = major6 << 5 | extendedFloat32;
          dataView2.setUint32(cursor, value);
          cursor += 4;
        } else {
          data[cursor++] = major6 << 5 | extendedFloat64;
          dataView2.setBigUint64(cursor, BigInt(value));
          cursor += 8;
        }
        continue;
      }
      data[cursor++] = majorSpecial << 5 | extendedFloat64;
      dataView2.setFloat64(cursor, input);
      cursor += 8;
      continue;
    } else if (typeof input === "bigint") {
      const nonNegative = input >= 0;
      const major6 = nonNegative ? majorUint64 : majorNegativeInt64;
      const value = nonNegative ? input : -input - BigInt(1);
      const n10 = Number(value);
      if (n10 < 24) {
        data[cursor++] = major6 << 5 | n10;
      } else if (n10 < 256) {
        data[cursor++] = major6 << 5 | 24;
        data[cursor++] = n10;
      } else if (n10 < 65536) {
        data[cursor++] = major6 << 5 | extendedFloat16;
        data[cursor++] = n10 >> 8;
        data[cursor++] = n10 & 255;
      } else if (n10 < 4294967296) {
        data[cursor++] = major6 << 5 | extendedFloat32;
        dataView2.setUint32(cursor, n10);
        cursor += 4;
      } else if (value < BigInt("18446744073709551616")) {
        data[cursor++] = major6 << 5 | extendedFloat64;
        dataView2.setBigUint64(cursor, value);
        cursor += 8;
      } else {
        const binaryBigInt = value.toString(2);
        const bigIntBytes = new Uint8Array(Math.ceil(binaryBigInt.length / 8));
        let b32 = value;
        let i32 = 0;
        while (bigIntBytes.byteLength - ++i32 >= 0) {
          bigIntBytes[bigIntBytes.byteLength - i32] = Number(b32 & BigInt(255));
          b32 >>= BigInt(8);
        }
        ensureSpace(bigIntBytes.byteLength * 2);
        data[cursor++] = nonNegative ? 194 : 195;
        if (USE_BUFFER2) {
          encodeHeader(majorUnstructuredByteString, Buffer.byteLength(bigIntBytes));
        } else {
          encodeHeader(majorUnstructuredByteString, bigIntBytes.byteLength);
        }
        data.set(bigIntBytes, cursor);
        cursor += bigIntBytes.byteLength;
      }
      continue;
    } else if (input === null) {
      data[cursor++] = majorSpecial << 5 | specialNull;
      continue;
    } else if (typeof input === "boolean") {
      data[cursor++] = majorSpecial << 5 | (input ? specialTrue : specialFalse);
      continue;
    } else if (typeof input === "undefined") {
      throw new Error("@smithy/core/cbor: client may not serialize undefined value.");
    } else if (Array.isArray(input)) {
      for (let i32 = input.length - 1; i32 >= 0; --i32) {
        encodeStack.push(input[i32]);
      }
      encodeHeader(majorList, input.length);
      continue;
    } else if (typeof input.byteLength === "number") {
      ensureSpace(input.length * 2);
      encodeHeader(majorUnstructuredByteString, input.length);
      data.set(input, cursor);
      cursor += input.byteLength;
      continue;
    } else if (typeof input === "object") {
      if (input instanceof NumericValue) {
        const decimalIndex = input.string.indexOf(".");
        const exponent = decimalIndex === -1 ? 0 : decimalIndex - input.string.length + 1;
        const mantissa = BigInt(input.string.replace(".", ""));
        data[cursor++] = 196;
        encodeStack.push(mantissa);
        encodeStack.push(exponent);
        encodeHeader(majorList, 2);
        continue;
      }
      if (input[tagSymbol]) {
        if ("tag" in input && "value" in input) {
          encodeStack.push(input.value);
          encodeHeader(majorTag, input.tag);
          continue;
        } else {
          throw new Error("tag encountered with missing fields, need 'tag' and 'value', found: " + JSON.stringify(input));
        }
      }
      const keys = Object.keys(input);
      for (let i32 = keys.length - 1; i32 >= 0; --i32) {
        const key = keys[i32];
        encodeStack.push(input[key]);
        encodeStack.push(key);
      }
      encodeHeader(majorMap, keys.length);
      continue;
    }
    throw new Error(`data type ${input?.constructor?.name ?? typeof input} not compatible for encoding.`);
  }
}
var import_util_utf85, USE_BUFFER2, initialSize, data, dataView2, cursor;
var init_cbor_encode = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/cbor/cbor-encode.js"() {
    init_serde();
    import_util_utf85 = __toESM(require_dist_cjs9());
    init_cbor_types();
    USE_BUFFER2 = typeof Buffer !== "undefined";
    initialSize = 2048;
    data = alloc(initialSize);
    dataView2 = new DataView(data.buffer, data.byteOffset, data.byteLength);
    cursor = 0;
    __name(ensureSpace, "ensureSpace");
    __name(toUint8Array, "toUint8Array");
    __name(resize, "resize");
    __name(encodeHeader, "encodeHeader");
    __name(encode, "encode");
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/cbor/cbor.js
var cbor;
var init_cbor = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/cbor/cbor.js"() {
    init_cbor_decode();
    init_cbor_encode();
    cbor = {
      deserialize(payload3) {
        setPayload(payload3);
        return decode(0, payload3.length);
      },
      serialize(input) {
        try {
          encode(input);
          return toUint8Array();
        } catch (e32) {
          toUint8Array();
          throw e32;
        }
      },
      resizeEncodingBuffer(size) {
        resize(size);
      }
    };
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/cbor/parseCborBody.js
var dateToTag, loadSmithyRpcV2CborErrorCode;
var init_parseCborBody = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/cbor/parseCborBody.js"() {
    init_cbor_types();
    dateToTag = /* @__PURE__ */ __name((date7) => {
      return tag({
        tag: 1,
        value: date7.getTime() / 1e3
      });
    }, "dateToTag");
    loadSmithyRpcV2CborErrorCode = /* @__PURE__ */ __name((output, data3) => {
      const sanitizeErrorCode12 = /* @__PURE__ */ __name((rawValue) => {
        let cleanValue = rawValue;
        if (typeof cleanValue === "number") {
          cleanValue = cleanValue.toString();
        }
        if (cleanValue.indexOf(",") >= 0) {
          cleanValue = cleanValue.split(",")[0];
        }
        if (cleanValue.indexOf(":") >= 0) {
          cleanValue = cleanValue.split(":")[0];
        }
        if (cleanValue.indexOf("#") >= 0) {
          cleanValue = cleanValue.split("#")[1];
        }
        return cleanValue;
      }, "sanitizeErrorCode");
      if (data3["__type"] !== void 0) {
        return sanitizeErrorCode12(data3["__type"]);
      }
      let codeKey;
      for (const key in data3) {
        if (key.toLowerCase() === "code") {
          codeKey = key;
          break;
        }
      }
      if (codeKey && data3[codeKey] !== void 0) {
        return sanitizeErrorCode12(data3[codeKey]);
      }
    }, "loadSmithyRpcV2CborErrorCode");
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/cbor/CborCodec.js
var import_util_base643, CborCodec, CborShapeSerializer, CborShapeDeserializer;
var init_CborCodec = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/cbor/CborCodec.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    init_serde();
    import_util_base643 = __toESM(require_dist_cjs10());
    init_cbor();
    init_parseCborBody();
    CborCodec = class extends SerdeContext {
      static {
        __name(this, "CborCodec");
      }
      createSerializer() {
        const serializer = new CborShapeSerializer();
        serializer.setSerdeContext(this.serdeContext);
        return serializer;
      }
      createDeserializer() {
        const deserializer = new CborShapeDeserializer();
        deserializer.setSerdeContext(this.serdeContext);
        return deserializer;
      }
    };
    CborShapeSerializer = class extends SerdeContext {
      static {
        __name(this, "CborShapeSerializer");
      }
      value;
      write(schema, value) {
        this.value = this.serialize(schema, value);
      }
      serialize(schema, source) {
        const ns = NormalizedSchema.of(schema);
        if (source == null) {
          if (ns.isIdempotencyToken()) {
            return (0, import_uuid.v4)();
          }
          return source;
        }
        if (ns.isBlobSchema()) {
          if (typeof source === "string") {
            return (this.serdeContext?.base64Decoder ?? import_util_base643.fromBase64)(source);
          }
          return source;
        }
        if (ns.isTimestampSchema()) {
          if (typeof source === "number" || typeof source === "bigint") {
            return dateToTag(new Date(Number(source) / 1e3 | 0));
          }
          return dateToTag(source);
        }
        if (typeof source === "function" || typeof source === "object") {
          const sourceObject = source;
          if (ns.isListSchema() && Array.isArray(sourceObject)) {
            const sparse = !!ns.getMergedTraits().sparse;
            const newArray = [];
            let i32 = 0;
            for (const item of sourceObject) {
              const value = this.serialize(ns.getValueSchema(), item);
              if (value != null || sparse) {
                newArray[i32++] = value;
              }
            }
            return newArray;
          }
          if (sourceObject instanceof Date) {
            return dateToTag(sourceObject);
          }
          const newObject = {};
          if (ns.isMapSchema()) {
            const sparse = !!ns.getMergedTraits().sparse;
            for (const key in sourceObject) {
              const value = this.serialize(ns.getValueSchema(), sourceObject[key]);
              if (value != null || sparse) {
                newObject[key] = value;
              }
            }
          } else if (ns.isStructSchema()) {
            for (const [key, memberSchema] of ns.structIterator()) {
              const value = this.serialize(memberSchema, sourceObject[key]);
              if (value != null) {
                newObject[key] = value;
              }
            }
            const isUnion = ns.isUnionSchema();
            if (isUnion && Array.isArray(sourceObject.$unknown)) {
              const [k32, v] = sourceObject.$unknown;
              newObject[k32] = v;
            } else if (typeof sourceObject.__type === "string") {
              for (const k32 in sourceObject) {
                if (!(k32 in newObject)) {
                  newObject[k32] = this.serialize(15, sourceObject[k32]);
                }
              }
            }
          } else if (ns.isDocumentSchema()) {
            for (const key in sourceObject) {
              newObject[key] = this.serialize(ns.getValueSchema(), sourceObject[key]);
            }
          } else if (ns.isBigDecimalSchema()) {
            return sourceObject;
          }
          return newObject;
        }
        return source;
      }
      flush() {
        const buffer = cbor.serialize(this.value);
        this.value = void 0;
        return buffer;
      }
    };
    CborShapeDeserializer = class extends SerdeContext {
      static {
        __name(this, "CborShapeDeserializer");
      }
      read(schema, bytes) {
        const data3 = cbor.deserialize(bytes);
        return this.readValue(schema, data3);
      }
      readValue(_schema, value) {
        const ns = NormalizedSchema.of(_schema);
        if (ns.isTimestampSchema()) {
          if (typeof value === "number") {
            return _parseEpochTimestamp(value);
          }
          if (typeof value === "object") {
            if (value.tag === 1 && "value" in value) {
              return _parseEpochTimestamp(value.value);
            }
          }
        }
        if (ns.isBlobSchema()) {
          if (typeof value === "string") {
            return (this.serdeContext?.base64Decoder ?? import_util_base643.fromBase64)(value);
          }
          return value;
        }
        if (typeof value === "undefined" || typeof value === "boolean" || typeof value === "number" || typeof value === "string" || typeof value === "bigint" || typeof value === "symbol") {
          return value;
        } else if (typeof value === "object") {
          if (value === null) {
            return null;
          }
          if ("byteLength" in value) {
            return value;
          }
          if (value instanceof Date) {
            return value;
          }
          if (ns.isDocumentSchema()) {
            return value;
          }
          if (ns.isListSchema()) {
            const newArray = [];
            const memberSchema = ns.getValueSchema();
            for (const item of value) {
              const itemValue = this.readValue(memberSchema, item);
              newArray.push(itemValue);
            }
            return newArray;
          }
          const newObject = {};
          if (ns.isMapSchema()) {
            const targetSchema = ns.getValueSchema();
            for (const key in value) {
              const itemValue = this.readValue(targetSchema, value[key]);
              newObject[key] = itemValue;
            }
          } else if (ns.isStructSchema()) {
            const isUnion = ns.isUnionSchema();
            let keys;
            if (isUnion) {
              keys = /* @__PURE__ */ new Set();
              for (const k32 in value) {
                if (k32 !== "__type") {
                  keys.add(k32);
                }
              }
            }
            for (const [key, memberSchema] of ns.structIterator()) {
              if (isUnion) {
                keys.delete(key);
              }
              if (value[key] != null) {
                newObject[key] = this.readValue(memberSchema, value[key]);
              }
            }
            if (isUnion && keys?.size === 1) {
              let newObjectEmpty = true;
              for (const _ in newObject) {
                newObjectEmpty = false;
                break;
              }
              if (newObjectEmpty) {
                const k32 = keys.values().next().value;
                newObject.$unknown = [k32, value[k32]];
              }
            } else if (typeof value.__type === "string") {
              for (const k32 in value) {
                if (!(k32 in newObject)) {
                  newObject[k32] = value[k32];
                }
              }
            }
          } else if (value instanceof NumericValue) {
            return value;
          }
          return newObject;
        } else {
          return value;
        }
      }
    };
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/cbor/SmithyRpcV2CborProtocol.js
var import_util_middleware6, SmithyRpcV2CborProtocol;
var init_SmithyRpcV2CborProtocol = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/cbor/SmithyRpcV2CborProtocol.js"() {
    init_protocols();
    init_schema4();
    init_schema4();
    import_util_middleware6 = __toESM(require_dist_cjs6());
    init_CborCodec();
    init_parseCborBody();
    SmithyRpcV2CborProtocol = class extends RpcProtocol {
      static {
        __name(this, "SmithyRpcV2CborProtocol");
      }
      codec = new CborCodec();
      serializer = this.codec.createSerializer();
      deserializer = this.codec.createDeserializer();
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32 }) {
        super({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32 });
      }
      getShapeId() {
        return "smithy.protocols#rpcv2Cbor";
      }
      getPayloadCodec() {
        return this.codec;
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        Object.assign(request4.headers, {
          "content-type": this.getDefaultContentType(),
          "smithy-protocol": "rpc-v2-cbor",
          accept: this.getDefaultContentType()
        });
        if (deref(operationSchema.input) === "unit") {
          delete request4.body;
          delete request4.headers["content-type"];
        } else {
          if (!request4.body) {
            this.serializer.write(15, {});
            request4.body = this.serializer.flush();
          }
          try {
            request4.headers["content-length"] = String(request4.body.byteLength);
          } catch (e32) {
          }
        }
        const { service, operation: operation3 } = (0, import_util_middleware6.getSmithyContext)(context);
        const path47 = `/service/${service}/operation/${operation3}`;
        if (request4.path.endsWith("/")) {
          request4.path += path47.slice(1);
        } else {
          request4.path += path47;
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        return super.deserializeResponse(operationSchema, context, response);
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorName = loadSmithyRpcV2CborErrorCode(response, dataObject) ?? "Unknown";
        const errorMetadata = {
          $metadata: metadata,
          $fault: response.statusCode <= 500 ? "client" : "server"
        };
        let namespace = this.options.defaultNamespace;
        if (errorName.includes("#")) {
          [namespace] = errorName.split("#");
        }
        const registry = this.compositeErrorRegistry;
        const nsRegistry = TypeRegistry.for(namespace);
        registry.copyFrom(nsRegistry);
        let errorSchema;
        try {
          errorSchema = registry.getSchema(errorName);
        } catch (e32) {
          if (dataObject.Message) {
            dataObject.message = dataObject.Message;
          }
          const syntheticRegistry = TypeRegistry.for("smithy.ts.sdk.synthetic." + namespace);
          registry.copyFrom(syntheticRegistry);
          const baseExceptionSchema = registry.getBaseException();
          if (baseExceptionSchema) {
            const ErrorCtor2 = registry.getErrorCtor(baseExceptionSchema);
            throw Object.assign(new ErrorCtor2({ name: errorName }), errorMetadata, dataObject);
          }
          throw Object.assign(new Error(errorName), errorMetadata, dataObject);
        }
        const ns = NormalizedSchema.of(errorSchema);
        const ErrorCtor = registry.getErrorCtor(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "Unknown";
        const exception = new ErrorCtor(message2);
        const output = {};
        for (const [name, member7] of ns.structIterator()) {
          output[name] = this.deserializer.readValue(member7, dataObject[name]);
        }
        throw Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output);
      }
      getDefaultContentType() {
        return "application/cbor";
      }
    };
  }
});

// ../../node_modules/@smithy/core/dist-es/submodules/cbor/index.js
var init_cbor2 = __esm({
  "../../node_modules/@smithy/core/dist-es/submodules/cbor/index.js"() {
    init_parseCborBody();
    init_SmithyRpcV2CborProtocol();
    init_CborCodec();
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ProtocolLib.js
var import_smithy_client, ProtocolLib;
var init_ProtocolLib = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ProtocolLib.js"() {
    init_schema4();
    import_smithy_client = __toESM(require_dist_cjs34());
    ProtocolLib = class {
      static {
        __name(this, "ProtocolLib");
      }
      queryCompat;
      errorRegistry;
      constructor(queryCompat = false) {
        this.queryCompat = queryCompat;
      }
      resolveRestContentType(defaultContentType, inputSchema) {
        const members = inputSchema.getMemberSchemas();
        const httpPayloadMember = Object.values(members).find((m20) => {
          return !!m20.getMergedTraits().httpPayload;
        });
        if (httpPayloadMember) {
          const mediaType = httpPayloadMember.getMergedTraits().mediaType;
          if (mediaType) {
            return mediaType;
          } else if (httpPayloadMember.isStringSchema()) {
            return "text/plain";
          } else if (httpPayloadMember.isBlobSchema()) {
            return "application/octet-stream";
          } else {
            return defaultContentType;
          }
        } else if (!inputSchema.isUnitSchema()) {
          const hasBody = Object.values(members).find((m20) => {
            const { httpQuery, httpQueryParams, httpHeader, httpLabel, httpPrefixHeaders } = m20.getMergedTraits();
            const noPrefixHeaders = httpPrefixHeaders === void 0;
            return !httpQuery && !httpQueryParams && !httpHeader && !httpLabel && noPrefixHeaders;
          });
          if (hasBody) {
            return defaultContentType;
          }
        }
      }
      async getErrorSchemaOrThrowBaseException(errorIdentifier, defaultNamespace, response, dataObject, metadata, getErrorSchema) {
        let errorName = errorIdentifier;
        if (errorIdentifier.includes("#")) {
          [, errorName] = errorIdentifier.split("#");
        }
        const errorMetadata = {
          $metadata: metadata,
          $fault: response.statusCode < 500 ? "client" : "server"
        };
        if (!this.errorRegistry) {
          throw new Error("@aws-sdk/core/protocols - error handler not initialized.");
        }
        try {
          const errorSchema = getErrorSchema?.(this.errorRegistry, errorName) ?? this.errorRegistry.getSchema(errorIdentifier);
          return { errorSchema, errorMetadata };
        } catch (e32) {
          dataObject.message = dataObject.message ?? dataObject.Message ?? "UnknownError";
          const synthetic = this.errorRegistry;
          const baseExceptionSchema = synthetic.getBaseException();
          if (baseExceptionSchema) {
            const ErrorCtor = synthetic.getErrorCtor(baseExceptionSchema) ?? Error;
            throw this.decorateServiceException(Object.assign(new ErrorCtor({ name: errorName }), errorMetadata), dataObject);
          }
          const d32 = dataObject;
          const message2 = d32?.message ?? d32?.Message ?? d32?.Error?.Message ?? d32?.Error?.message;
          throw this.decorateServiceException(Object.assign(new Error(message2), {
            name: errorName
          }, errorMetadata), dataObject);
        }
      }
      compose(composite, errorIdentifier, defaultNamespace) {
        let namespace = defaultNamespace;
        if (errorIdentifier.includes("#")) {
          [namespace] = errorIdentifier.split("#");
        }
        const staticRegistry = TypeRegistry.for(namespace);
        const defaultSyntheticRegistry = TypeRegistry.for("smithy.ts.sdk.synthetic." + defaultNamespace);
        composite.copyFrom(staticRegistry);
        composite.copyFrom(defaultSyntheticRegistry);
        this.errorRegistry = composite;
      }
      decorateServiceException(exception, additions = {}) {
        if (this.queryCompat) {
          const msg = exception.Message ?? additions.Message;
          const error4 = (0, import_smithy_client.decorateServiceException)(exception, additions);
          if (msg) {
            error4.message = msg;
          }
          const errorObj = error4.Error ?? {};
          errorObj.Type = error4.Error?.Type;
          errorObj.Code = error4.Error?.Code;
          errorObj.Message = error4.Error?.message ?? error4.Error?.Message ?? msg;
          error4.Error = errorObj;
          const reqId = error4.$metadata.requestId;
          if (reqId) {
            error4.RequestId = reqId;
          }
          return error4;
        }
        return (0, import_smithy_client.decorateServiceException)(exception, additions);
      }
      setQueryCompatError(output, response) {
        const queryErrorHeader = response.headers?.["x-amzn-query-error"];
        if (output !== void 0 && queryErrorHeader != null) {
          const [Code, Type] = queryErrorHeader.split(";");
          const keys = Object.keys(output);
          const Error2 = {
            Code,
            Type
          };
          output.Code = Code;
          output.Type = Type;
          for (let i32 = 0; i32 < keys.length; i32++) {
            const k32 = keys[i32];
            Error2[k32 === "message" ? "Message" : k32] = output[k32];
          }
          delete Error2.__type;
          output.Error = Error2;
        }
      }
      queryCompatOutput(queryCompatErrorData, errorData) {
        if (queryCompatErrorData.Error) {
          errorData.Error = queryCompatErrorData.Error;
        }
        if (queryCompatErrorData.Type) {
          errorData.Type = queryCompatErrorData.Type;
        }
        if (queryCompatErrorData.Code) {
          errorData.Code = queryCompatErrorData.Code;
        }
      }
      findQueryCompatibleError(registry, errorName) {
        try {
          return registry.getSchema(errorName);
        } catch (e32) {
          return registry.find((schema) => NormalizedSchema.of(schema).getMergedTraits().awsQueryError?.[0] === errorName);
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/cbor/AwsSmithyRpcV2CborProtocol.js
var init_AwsSmithyRpcV2CborProtocol = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/cbor/AwsSmithyRpcV2CborProtocol.js"() {
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/coercing-serializers.js
var init_coercing_serializers = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/coercing-serializers.js"() {
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ConfigurableSerdeContext.js
var SerdeContextConfig;
var init_ConfigurableSerdeContext = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ConfigurableSerdeContext.js"() {
    SerdeContextConfig = class {
      static {
        __name(this, "SerdeContextConfig");
      }
      serdeContext;
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/UnionSerde.js
var UnionSerde;
var init_UnionSerde = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/UnionSerde.js"() {
    UnionSerde = class {
      static {
        __name(this, "UnionSerde");
      }
      from;
      to;
      keys;
      constructor(from, to) {
        this.from = from;
        this.to = to;
        const keys = Object.keys(this.from);
        const set = new Set(keys);
        set.delete("__type");
        this.keys = set;
      }
      mark(key) {
        this.keys.delete(key);
      }
      hasUnknown() {
        return this.keys.size === 1 && Object.keys(this.to).length === 0;
      }
      writeUnknown() {
        if (this.hasUnknown()) {
          const k32 = this.keys.values().next().value;
          const v = this.from[k32];
          this.to.$unknown = [k32, v];
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReviver.js
function jsonReviver(key, value, context) {
  if (context?.source) {
    const numericString = context.source;
    if (typeof value === "number") {
      if (value > Number.MAX_SAFE_INTEGER || value < Number.MIN_SAFE_INTEGER || numericString !== String(value)) {
        const isFractional = numericString.includes(".");
        if (isFractional) {
          return new NumericValue(numericString, "bigDecimal");
        } else {
          return BigInt(numericString);
        }
      }
    }
  }
  return value;
}
var init_jsonReviver = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReviver.js"() {
    init_serde();
    __name(jsonReviver, "jsonReviver");
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/common.js
var import_smithy_client2, import_util_utf86, collectBodyString;
var init_common2 = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/common.js"() {
    import_smithy_client2 = __toESM(require_dist_cjs34());
    import_util_utf86 = __toESM(require_dist_cjs9());
    collectBodyString = /* @__PURE__ */ __name((streamBody, context) => (0, import_smithy_client2.collectBody)(streamBody, context).then((body) => (context?.utf8Encoder ?? import_util_utf86.toUtf8)(body)), "collectBodyString");
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/parseJsonBody.js
var parseJsonBody, findKey, sanitizeErrorCode, loadRestJsonErrorCode;
var init_parseJsonBody = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/parseJsonBody.js"() {
    init_common2();
    parseJsonBody = /* @__PURE__ */ __name((streamBody, context) => collectBodyString(streamBody, context).then((encoded) => {
      if (encoded.length) {
        try {
          return JSON.parse(encoded);
        } catch (e32) {
          if (e32?.name === "SyntaxError") {
            Object.defineProperty(e32, "$responseBodyText", {
              value: encoded
            });
          }
          throw e32;
        }
      }
      return {};
    }), "parseJsonBody");
    findKey = /* @__PURE__ */ __name((object, key) => Object.keys(object).find((k32) => k32.toLowerCase() === key.toLowerCase()), "findKey");
    sanitizeErrorCode = /* @__PURE__ */ __name((rawValue) => {
      let cleanValue = rawValue;
      if (typeof cleanValue === "number") {
        cleanValue = cleanValue.toString();
      }
      if (cleanValue.indexOf(",") >= 0) {
        cleanValue = cleanValue.split(",")[0];
      }
      if (cleanValue.indexOf(":") >= 0) {
        cleanValue = cleanValue.split(":")[0];
      }
      if (cleanValue.indexOf("#") >= 0) {
        cleanValue = cleanValue.split("#")[1];
      }
      return cleanValue;
    }, "sanitizeErrorCode");
    loadRestJsonErrorCode = /* @__PURE__ */ __name((output, data3) => {
      const headerKey = findKey(output.headers, "x-amzn-errortype");
      if (headerKey !== void 0) {
        return sanitizeErrorCode(output.headers[headerKey]);
      }
      if (data3 && typeof data3 === "object") {
        const codeKey = findKey(data3, "code");
        if (codeKey && data3[codeKey] !== void 0) {
          return sanitizeErrorCode(data3[codeKey]);
        }
        if (data3["__type"] !== void 0) {
          return sanitizeErrorCode(data3["__type"]);
        }
      }
    }, "loadRestJsonErrorCode");
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeDeserializer.js
var import_util_base644, JsonShapeDeserializer;
var init_JsonShapeDeserializer = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeDeserializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_util_base644 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext();
    init_UnionSerde();
    init_jsonReviver();
    init_parseJsonBody();
    JsonShapeDeserializer = class extends SerdeContextConfig {
      static {
        __name(this, "JsonShapeDeserializer");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      async read(schema, data3) {
        return this._read(schema, typeof data3 === "string" ? JSON.parse(data3, jsonReviver) : await parseJsonBody(data3, this.serdeContext));
      }
      readObject(schema, data3) {
        return this._read(schema, data3);
      }
      _read(schema, value) {
        const isObject3 = value !== null && typeof value === "object";
        const ns = NormalizedSchema.of(schema);
        if (isObject3) {
          if (ns.isStructSchema()) {
            const record = value;
            const union = ns.isUnionSchema();
            const out = {};
            let nameMap = void 0;
            const { jsonName } = this.settings;
            if (jsonName) {
              nameMap = {};
            }
            let unionSerde;
            if (union) {
              unionSerde = new UnionSerde(record, out);
            }
            for (const [memberName, memberSchema] of ns.structIterator()) {
              let fromKey = memberName;
              if (jsonName) {
                fromKey = memberSchema.getMergedTraits().jsonName ?? fromKey;
                nameMap[fromKey] = memberName;
              }
              if (union) {
                unionSerde.mark(fromKey);
              }
              if (record[fromKey] != null) {
                out[memberName] = this._read(memberSchema, record[fromKey]);
              }
            }
            if (union) {
              unionSerde.writeUnknown();
            } else if (typeof record.__type === "string") {
              for (const k32 in record) {
                const v = record[k32];
                const t = jsonName ? nameMap[k32] ?? k32 : k32;
                if (!(t in out)) {
                  out[t] = v;
                }
              }
            }
            return out;
          }
          if (Array.isArray(value) && ns.isListSchema()) {
            const listMember = ns.getValueSchema();
            const out = [];
            for (const item of value) {
              out.push(this._read(listMember, item));
            }
            return out;
          }
          if (ns.isMapSchema()) {
            const mapMember = ns.getValueSchema();
            const out = {};
            for (const _k in value) {
              out[_k] = this._read(mapMember, value[_k]);
            }
            return out;
          }
        }
        if (ns.isBlobSchema() && typeof value === "string") {
          return (0, import_util_base644.fromBase64)(value);
        }
        const mediaType = ns.getMergedTraits().mediaType;
        if (ns.isStringSchema() && typeof value === "string" && mediaType) {
          const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
          if (isJson) {
            return LazyJsonString.from(value);
          }
          return value;
        }
        if (ns.isTimestampSchema() && value != null) {
          const format32 = determineTimestampFormat(ns, this.settings);
          switch (format32) {
            case 5:
              return parseRfc3339DateTimeWithOffset(value);
            case 6:
              return parseRfc7231DateTime(value);
            case 7:
              return parseEpochTimestamp(value);
            default:
              console.warn("Missing timestamp format, parsing value with Date constructor:", value);
              return new Date(value);
          }
        }
        if (ns.isBigIntegerSchema() && (typeof value === "number" || typeof value === "string")) {
          return BigInt(value);
        }
        if (ns.isBigDecimalSchema() && value != void 0) {
          if (value instanceof NumericValue) {
            return value;
          }
          const untyped = value;
          if (untyped.type === "bigDecimal" && "string" in untyped) {
            return new NumericValue(untyped.string, untyped.type);
          }
          return new NumericValue(String(value), "bigDecimal");
        }
        if (ns.isNumericSchema() && typeof value === "string") {
          switch (value) {
            case "Infinity":
              return Infinity;
            case "-Infinity":
              return -Infinity;
            case "NaN":
              return NaN;
          }
          return value;
        }
        if (ns.isDocumentSchema()) {
          if (isObject3) {
            const out = Array.isArray(value) ? [] : {};
            for (const k32 in value) {
              const v = value[k32];
              if (v instanceof NumericValue) {
                out[k32] = v;
              } else {
                out[k32] = this._read(ns, v);
              }
            }
            return out;
          } else {
            return structuredClone(value);
          }
        }
        return value;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReplacer.js
var NUMERIC_CONTROL_CHAR, JsonReplacer;
var init_jsonReplacer = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReplacer.js"() {
    init_serde();
    NUMERIC_CONTROL_CHAR = String.fromCharCode(925);
    JsonReplacer = class {
      static {
        __name(this, "JsonReplacer");
      }
      values = /* @__PURE__ */ new Map();
      counter = 0;
      stage = 0;
      createReplacer() {
        if (this.stage === 1) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer already created.");
        }
        if (this.stage === 2) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer exhausted.");
        }
        this.stage = 1;
        return (key, value) => {
          if (value instanceof NumericValue) {
            const v = `${NUMERIC_CONTROL_CHAR + "nv" + this.counter++}_` + value.string;
            this.values.set(`"${v}"`, value.string);
            return v;
          }
          if (typeof value === "bigint") {
            const s = value.toString();
            const v = `${NUMERIC_CONTROL_CHAR + "b" + this.counter++}_` + s;
            this.values.set(`"${v}"`, s);
            return v;
          }
          return value;
        };
      }
      replaceInJson(json) {
        if (this.stage === 0) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer not created yet.");
        }
        if (this.stage === 2) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer exhausted.");
        }
        this.stage = 2;
        if (this.counter === 0) {
          return json;
        }
        for (const [key, value] of this.values) {
          json = json.replace(key, value);
        }
        return json;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeSerializer.js
var import_util_base645, JsonShapeSerializer;
var init_JsonShapeSerializer = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeSerializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_util_base645 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext();
    init_jsonReplacer();
    JsonShapeSerializer = class extends SerdeContextConfig {
      static {
        __name(this, "JsonShapeSerializer");
      }
      settings;
      buffer;
      useReplacer = false;
      rootSchema;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value) {
        this.rootSchema = NormalizedSchema.of(schema);
        this.buffer = this._write(this.rootSchema, value);
      }
      flush() {
        const { rootSchema, useReplacer } = this;
        this.rootSchema = void 0;
        this.useReplacer = false;
        if (rootSchema?.isStructSchema() || rootSchema?.isDocumentSchema()) {
          if (!useReplacer) {
            return JSON.stringify(this.buffer);
          }
          const replacer = new JsonReplacer();
          return replacer.replaceInJson(JSON.stringify(this.buffer, replacer.createReplacer(), 0));
        }
        return this.buffer;
      }
      writeDiscriminatedDocument(schema, value) {
        this.write(schema, value);
        if (typeof this.buffer === "object") {
          this.buffer.__type = NormalizedSchema.of(schema).getName(true);
        }
      }
      _write(schema, value, container) {
        const isObject3 = value !== null && typeof value === "object";
        const ns = NormalizedSchema.of(schema);
        if (isObject3) {
          if (ns.isStructSchema()) {
            const record = value;
            const out = {};
            const { jsonName } = this.settings;
            let nameMap = void 0;
            if (jsonName) {
              nameMap = {};
            }
            let outCount = 0;
            for (const [memberName, memberSchema] of ns.structIterator()) {
              const serializableValue = this._write(memberSchema, record[memberName], ns);
              if (serializableValue !== void 0) {
                let targetKey = memberName;
                if (jsonName) {
                  targetKey = memberSchema.getMergedTraits().jsonName ?? memberName;
                  nameMap[memberName] = targetKey;
                }
                out[targetKey] = serializableValue;
                outCount++;
              }
            }
            if (ns.isUnionSchema() && outCount === 0) {
              const { $unknown } = record;
              if (Array.isArray($unknown)) {
                const [k32, v] = $unknown;
                out[k32] = this._write(15, v);
              }
            } else if (typeof record.__type === "string") {
              for (const k32 in record) {
                const v = record[k32];
                const targetKey = jsonName ? nameMap[k32] ?? k32 : k32;
                if (!(targetKey in out)) {
                  out[targetKey] = this._write(15, v);
                }
              }
            }
            return out;
          }
          if (Array.isArray(value) && ns.isListSchema()) {
            const listMember = ns.getValueSchema();
            const out = [];
            const sparse = !!ns.getMergedTraits().sparse;
            for (const item of value) {
              if (sparse || item != null) {
                out.push(this._write(listMember, item));
              }
            }
            return out;
          }
          if (ns.isMapSchema()) {
            const mapMember = ns.getValueSchema();
            const out = {};
            const sparse = !!ns.getMergedTraits().sparse;
            for (const _k in value) {
              const _v = value[_k];
              if (sparse || _v != null) {
                out[_k] = this._write(mapMember, _v);
              }
            }
            return out;
          }
          if (value instanceof Uint8Array && (ns.isBlobSchema() || ns.isDocumentSchema())) {
            if (ns === this.rootSchema) {
              return value;
            }
            return (this.serdeContext?.base64Encoder ?? import_util_base645.toBase64)(value);
          }
          if (value instanceof Date && (ns.isTimestampSchema() || ns.isDocumentSchema())) {
            const format32 = determineTimestampFormat(ns, this.settings);
            switch (format32) {
              case 5:
                return value.toISOString().replace(".000Z", "Z");
              case 6:
                return dateToUtcString(value);
              case 7:
                return value.getTime() / 1e3;
              default:
                console.warn("Missing timestamp format, using epoch seconds", value);
                return value.getTime() / 1e3;
            }
          }
          if (value instanceof NumericValue) {
            this.useReplacer = true;
          }
        }
        if (value === null && container?.isStructSchema()) {
          return void 0;
        }
        if (ns.isStringSchema()) {
          if (typeof value === "undefined" && ns.isIdempotencyToken()) {
            return (0, import_uuid.v4)();
          }
          const mediaType = ns.getMergedTraits().mediaType;
          if (value != null && mediaType) {
            const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
            if (isJson) {
              return LazyJsonString.from(value);
            }
          }
          return value;
        }
        if (typeof value === "number" && ns.isNumericSchema()) {
          if (Math.abs(value) === Infinity || isNaN(value)) {
            return String(value);
          }
          return value;
        }
        if (typeof value === "string" && ns.isBlobSchema()) {
          if (ns === this.rootSchema) {
            return value;
          }
          return (this.serdeContext?.base64Encoder ?? import_util_base645.toBase64)(value);
        }
        if (typeof value === "bigint") {
          this.useReplacer = true;
        }
        if (ns.isDocumentSchema()) {
          if (isObject3) {
            const out = Array.isArray(value) ? [] : {};
            for (const k32 in value) {
              const v = value[k32];
              if (v instanceof NumericValue) {
                this.useReplacer = true;
                out[k32] = v;
              } else {
                out[k32] = this._write(ns, v);
              }
            }
            return out;
          } else {
            return structuredClone(value);
          }
        }
        return value;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonCodec.js
var JsonCodec;
var init_JsonCodec = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonCodec.js"() {
    init_ConfigurableSerdeContext();
    init_JsonShapeDeserializer();
    init_JsonShapeSerializer();
    JsonCodec = class extends SerdeContextConfig {
      static {
        __name(this, "JsonCodec");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      createSerializer() {
        const serializer = new JsonShapeSerializer(this.settings);
        serializer.setSerdeContext(this.serdeContext);
        return serializer;
      }
      createDeserializer() {
        const deserializer = new JsonShapeDeserializer(this.settings);
        deserializer.setSerdeContext(this.serdeContext);
        return deserializer;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJsonRpcProtocol.js
var init_AwsJsonRpcProtocol = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJsonRpcProtocol.js"() {
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_0Protocol.js
var init_AwsJson1_0Protocol = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_0Protocol.js"() {
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_1Protocol.js
var init_AwsJson1_1Protocol = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_1Protocol.js"() {
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsRestJsonProtocol.js
var AwsRestJsonProtocol;
var init_AwsRestJsonProtocol = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsRestJsonProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib();
    init_JsonCodec();
    init_parseJsonBody();
    AwsRestJsonProtocol = class extends HttpBindingProtocol {
      static {
        __name(this, "AwsRestJsonProtocol");
      }
      serializer;
      deserializer;
      codec;
      mixin = new ProtocolLib();
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32 }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32
        });
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 7
          },
          httpBindings: true,
          jsonName: true
        };
        this.codec = new JsonCodec(settings);
        this.serializer = new HttpInterceptingShapeSerializer(this.codec.createSerializer(), settings);
        this.deserializer = new HttpInterceptingShapeDeserializer(this.codec.createDeserializer(), settings);
      }
      getShapeId() {
        return "aws.protocols#restJson1";
      }
      getPayloadCodec() {
        return this.codec;
      }
      setSerdeContext(serdeContext) {
        this.codec.setSerdeContext(serdeContext);
        super.setSerdeContext(serdeContext);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        const inputSchema = NormalizedSchema.of(operationSchema.input);
        if (!request4.headers["content-type"]) {
          const contentType = this.mixin.resolveRestContentType(this.getDefaultContentType(), inputSchema);
          if (contentType) {
            request4.headers["content-type"] = contentType;
          }
        }
        if (request4.body == null && request4.headers["content-type"] === this.getDefaultContentType()) {
          request4.body = "{}";
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        const output = await super.deserializeResponse(operationSchema, context, response);
        const outputSchema = NormalizedSchema.of(operationSchema.output);
        for (const [name, member7] of outputSchema.structIterator()) {
          if (member7.getMemberTraits().httpPayload && !(name in output)) {
            output[name] = null;
          }
        }
        return output;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = loadRestJsonErrorCode(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        await this.deserializeHttpMessage(errorSchema, context, response, dataObject);
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().jsonName ?? name;
          output[name] = errorDeserializer.readObject(member7, dataObject[target]);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      getDefaultContentType() {
        return "application/json";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/awsExpectUnion.js
var init_awsExpectUnion = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/awsExpectUnion.js"() {
  }
});

// ../../node_modules/@aws-sdk/xml-builder/node_modules/fast-xml-parser/lib/fxp.cjs
var require_fxp = __commonJS({
  "../../node_modules/@aws-sdk/xml-builder/node_modules/fast-xml-parser/lib/fxp.cjs"(exports2, module2) {
    (() => {
      "use strict";
      var t = { d: /* @__PURE__ */ __name((e33, n11) => {
        for (var i33 in n11) t.o(n11, i33) && !t.o(e33, i33) && Object.defineProperty(e33, i33, { enumerable: true, get: n11[i33] });
      }, "d"), o: /* @__PURE__ */ __name((t2, e33) => Object.prototype.hasOwnProperty.call(t2, e33), "o"), r: /* @__PURE__ */ __name((t2) => {
        "undefined" != typeof Symbol && Symbol.toStringTag && Object.defineProperty(t2, Symbol.toStringTag, { value: "Module" }), Object.defineProperty(t2, "__esModule", { value: true });
      }, "r") }, e32 = {};
      t.r(e32), t.d(e32, { XMLBuilder: /* @__PURE__ */ __name(() => Bt, "XMLBuilder"), XMLParser: /* @__PURE__ */ __name(() => Tt, "XMLParser"), XMLValidator: /* @__PURE__ */ __name(() => Ut, "XMLValidator") });
      const n10 = ":A-Za-z_\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD", i32 = new RegExp("^[" + n10 + "][" + n10 + "\\-.\\d\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$");
      function s(t2, e33) {
        const n11 = [];
        let i33 = e33.exec(t2);
        for (; i33; ) {
          const s2 = [];
          s2.startIndex = e33.lastIndex - i33[0].length;
          const r33 = i33.length;
          for (let t3 = 0; t3 < r33; t3++) s2.push(i33[t3]);
          n11.push(s2), i33 = e33.exec(t2);
        }
        return n11;
      }
      __name(s, "s");
      const r32 = /* @__PURE__ */ __name(function(t2) {
        return !(null == i32.exec(t2));
      }, "r"), o10 = ["hasOwnProperty", "toString", "valueOf", "__defineGetter__", "__defineSetter__", "__lookupGetter__", "__lookupSetter__"], a32 = ["__proto__", "constructor", "prototype"], h32 = { allowBooleanAttributes: false, unpairedTags: [] };
      function l20(t2, e33) {
        e33 = Object.assign({}, h32, e33);
        const n11 = [];
        let i33 = false, s2 = false;
        "\uFEFF" === t2[0] && (t2 = t2.substr(1));
        for (let r33 = 0; r33 < t2.length; r33++) if ("<" === t2[r33] && "?" === t2[r33 + 1]) {
          if (r33 += 2, r33 = p10(t2, r33), r33.err) return r33;
        } else {
          if ("<" !== t2[r33]) {
            if (u(t2[r33])) continue;
            return b32("InvalidChar", "char '" + t2[r33] + "' is not expected.", w(t2, r33));
          }
          {
            let o11 = r33;
            if (r33++, "!" === t2[r33]) {
              r33 = c32(t2, r33);
              continue;
            }
            {
              let a33 = false;
              "/" === t2[r33] && (a33 = true, r33++);
              let h33 = "";
              for (; r33 < t2.length && ">" !== t2[r33] && " " !== t2[r33] && "	" !== t2[r33] && "\n" !== t2[r33] && "\r" !== t2[r33]; r33++) h33 += t2[r33];
              if (h33 = h33.trim(), "/" === h33[h33.length - 1] && (h33 = h33.substring(0, h33.length - 1), r33--), !E(h33)) {
                let e34;
                return e34 = 0 === h33.trim().length ? "Invalid space after '<'." : "Tag '" + h33 + "' is an invalid name.", b32("InvalidTag", e34, w(t2, r33));
              }
              const l21 = g32(t2, r33);
              if (false === l21) return b32("InvalidAttr", "Attributes for '" + h33 + "' have open quote.", w(t2, r33));
              let d33 = l21.value;
              if (r33 = l21.index, "/" === d33[d33.length - 1]) {
                const n12 = r33 - d33.length;
                d33 = d33.substring(0, d33.length - 1);
                const s3 = x(d33, e33);
                if (true !== s3) return b32(s3.err.code, s3.err.msg, w(t2, n12 + s3.err.line));
                i33 = true;
              } else if (a33) {
                if (!l21.tagClosed) return b32("InvalidTag", "Closing tag '" + h33 + "' doesn't have proper closing.", w(t2, r33));
                if (d33.trim().length > 0) return b32("InvalidTag", "Closing tag '" + h33 + "' can't have attributes or invalid starting.", w(t2, o11));
                if (0 === n11.length) return b32("InvalidTag", "Closing tag '" + h33 + "' has not been opened.", w(t2, o11));
                {
                  const e34 = n11.pop();
                  if (h33 !== e34.tagName) {
                    let n12 = w(t2, e34.tagStartPos);
                    return b32("InvalidTag", "Expected closing tag '" + e34.tagName + "' (opened in line " + n12.line + ", col " + n12.col + ") instead of closing tag '" + h33 + "'.", w(t2, o11));
                  }
                  0 == n11.length && (s2 = true);
                }
              } else {
                const a34 = x(d33, e33);
                if (true !== a34) return b32(a34.err.code, a34.err.msg, w(t2, r33 - d33.length + a34.err.line));
                if (true === s2) return b32("InvalidXml", "Multiple possible root nodes found.", w(t2, r33));
                -1 !== e33.unpairedTags.indexOf(h33) || n11.push({ tagName: h33, tagStartPos: o11 }), i33 = true;
              }
              for (r33++; r33 < t2.length; r33++) if ("<" === t2[r33]) {
                if ("!" === t2[r33 + 1]) {
                  r33++, r33 = c32(t2, r33);
                  continue;
                }
                if ("?" !== t2[r33 + 1]) break;
                if (r33 = p10(t2, ++r33), r33.err) return r33;
              } else if ("&" === t2[r33]) {
                const e34 = N(t2, r33);
                if (-1 == e34) return b32("InvalidChar", "char '&' is not expected.", w(t2, r33));
                r33 = e34;
              } else if (true === s2 && !u(t2[r33])) return b32("InvalidXml", "Extra text at the end", w(t2, r33));
              "<" === t2[r33] && r33--;
            }
          }
        }
        return i33 ? 1 == n11.length ? b32("InvalidTag", "Unclosed tag '" + n11[0].tagName + "'.", w(t2, n11[0].tagStartPos)) : !(n11.length > 0) || b32("InvalidXml", "Invalid '" + JSON.stringify(n11.map((t3) => t3.tagName), null, 4).replace(/\r?\n/g, "") + "' found.", { line: 1, col: 1 }) : b32("InvalidXml", "Start tag expected.", 1);
      }
      __name(l20, "l");
      function u(t2) {
        return " " === t2 || "	" === t2 || "\n" === t2 || "\r" === t2;
      }
      __name(u, "u");
      function p10(t2, e33) {
        const n11 = e33;
        for (; e33 < t2.length; e33++) if ("?" == t2[e33] || " " == t2[e33]) {
          const i33 = t2.substr(n11, e33 - n11);
          if (e33 > 5 && "xml" === i33) return b32("InvalidXml", "XML declaration allowed only at the start of the document.", w(t2, e33));
          if ("?" == t2[e33] && ">" == t2[e33 + 1]) {
            e33++;
            break;
          }
          continue;
        }
        return e33;
      }
      __name(p10, "p");
      function c32(t2, e33) {
        if (t2.length > e33 + 5 && "-" === t2[e33 + 1] && "-" === t2[e33 + 2]) {
          for (e33 += 3; e33 < t2.length; e33++) if ("-" === t2[e33] && "-" === t2[e33 + 1] && ">" === t2[e33 + 2]) {
            e33 += 2;
            break;
          }
        } else if (t2.length > e33 + 8 && "D" === t2[e33 + 1] && "O" === t2[e33 + 2] && "C" === t2[e33 + 3] && "T" === t2[e33 + 4] && "Y" === t2[e33 + 5] && "P" === t2[e33 + 6] && "E" === t2[e33 + 7]) {
          let n11 = 1;
          for (e33 += 8; e33 < t2.length; e33++) if ("<" === t2[e33]) n11++;
          else if (">" === t2[e33] && (n11--, 0 === n11)) break;
        } else if (t2.length > e33 + 9 && "[" === t2[e33 + 1] && "C" === t2[e33 + 2] && "D" === t2[e33 + 3] && "A" === t2[e33 + 4] && "T" === t2[e33 + 5] && "A" === t2[e33 + 6] && "[" === t2[e33 + 7]) {
          for (e33 += 8; e33 < t2.length; e33++) if ("]" === t2[e33] && "]" === t2[e33 + 1] && ">" === t2[e33 + 2]) {
            e33 += 2;
            break;
          }
        }
        return e33;
      }
      __name(c32, "c");
      const d32 = '"', f32 = "'";
      function g32(t2, e33) {
        let n11 = "", i33 = "", s2 = false;
        for (; e33 < t2.length; e33++) {
          if (t2[e33] === d32 || t2[e33] === f32) "" === i33 ? i33 = t2[e33] : i33 !== t2[e33] || (i33 = "");
          else if (">" === t2[e33] && "" === i33) {
            s2 = true;
            break;
          }
          n11 += t2[e33];
        }
        return "" === i33 && { value: n11, index: e33, tagClosed: s2 };
      }
      __name(g32, "g");
      const m20 = new RegExp(`(\\s*)([^\\s=]+)(\\s*=)?(\\s*(['"])(([\\s\\S])*?)\\5)?`, "g");
      function x(t2, e33) {
        const n11 = s(t2, m20), i33 = {};
        for (let t3 = 0; t3 < n11.length; t3++) {
          if (0 === n11[t3][1].length) return b32("InvalidAttr", "Attribute '" + n11[t3][2] + "' has no space in starting.", v(n11[t3]));
          if (void 0 !== n11[t3][3] && void 0 === n11[t3][4]) return b32("InvalidAttr", "Attribute '" + n11[t3][2] + "' is without value.", v(n11[t3]));
          if (void 0 === n11[t3][3] && !e33.allowBooleanAttributes) return b32("InvalidAttr", "boolean attribute '" + n11[t3][2] + "' is not allowed.", v(n11[t3]));
          const s2 = n11[t3][2];
          if (!y(s2)) return b32("InvalidAttr", "Attribute '" + s2 + "' is an invalid name.", v(n11[t3]));
          if (Object.prototype.hasOwnProperty.call(i33, s2)) return b32("InvalidAttr", "Attribute '" + s2 + "' is repeated.", v(n11[t3]));
          i33[s2] = 1;
        }
        return true;
      }
      __name(x, "x");
      function N(t2, e33) {
        if (";" === t2[++e33]) return -1;
        if ("#" === t2[e33]) return (function(t3, e34) {
          let n12 = /\d/;
          for ("x" === t3[e34] && (e34++, n12 = /[\da-fA-F]/); e34 < t3.length; e34++) {
            if (";" === t3[e34]) return e34;
            if (!t3[e34].match(n12)) break;
          }
          return -1;
        })(t2, ++e33);
        let n11 = 0;
        for (; e33 < t2.length; e33++, n11++) if (!(t2[e33].match(/\w/) && n11 < 20)) {
          if (";" === t2[e33]) break;
          return -1;
        }
        return e33;
      }
      __name(N, "N");
      function b32(t2, e33, n11) {
        return { err: { code: t2, msg: e33, line: n11.line || n11, col: n11.col } };
      }
      __name(b32, "b");
      function y(t2) {
        return r32(t2);
      }
      __name(y, "y");
      function E(t2) {
        return r32(t2);
      }
      __name(E, "E");
      function w(t2, e33) {
        const n11 = t2.substring(0, e33).split(/\r?\n/);
        return { line: n11.length, col: n11[n11.length - 1].length + 1 };
      }
      __name(w, "w");
      function v(t2) {
        return t2.startIndex + t2[1].length;
      }
      __name(v, "v");
      const S = /* @__PURE__ */ __name((t2) => o10.includes(t2) ? "__" + t2 : t2, "S"), _ = { preserveOrder: false, attributeNamePrefix: "@_", attributesGroupName: false, textNodeName: "#text", ignoreAttributes: true, removeNSPrefix: false, allowBooleanAttributes: false, parseTagValue: true, parseAttributeValue: false, trimValues: true, cdataPropName: false, numberParseOptions: { hex: true, leadingZeros: true, eNotation: true }, tagValueProcessor: /* @__PURE__ */ __name(function(t2, e33) {
        return e33;
      }, "tagValueProcessor"), attributeValueProcessor: /* @__PURE__ */ __name(function(t2, e33) {
        return e33;
      }, "attributeValueProcessor"), stopNodes: [], alwaysCreateTextNode: false, isArray: /* @__PURE__ */ __name(() => false, "isArray"), commentPropName: false, unpairedTags: [], processEntities: true, htmlEntities: false, entityDecoder: null, ignoreDeclaration: false, ignorePiTags: false, transformTagName: false, transformAttributeName: false, updateTag: /* @__PURE__ */ __name(function(t2, e33, n11) {
        return t2;
      }, "updateTag"), captureMetaData: false, maxNestedTags: 100, strictReservedNames: true, jPath: true, onDangerousProperty: S };
      function A(t2, e33) {
        if ("string" != typeof t2) return;
        const n11 = t2.toLowerCase();
        if (o10.some((t3) => n11 === t3.toLowerCase())) throw new Error(`[SECURITY] Invalid ${e33}: "${t2}" is a reserved JavaScript keyword that could cause prototype pollution`);
        if (a32.some((t3) => n11 === t3.toLowerCase())) throw new Error(`[SECURITY] Invalid ${e33}: "${t2}" is a reserved JavaScript keyword that could cause prototype pollution`);
      }
      __name(A, "A");
      function T(t2, e33) {
        return "boolean" == typeof t2 ? { enabled: t2, maxEntitySize: 1e4, maxExpansionDepth: 1e4, maxTotalExpansions: 1 / 0, maxExpandedLength: 1e5, maxEntityCount: 1e3, allowedTags: null, tagFilter: null, appliesTo: "all" } : "object" == typeof t2 && null !== t2 ? { enabled: false !== t2.enabled, maxEntitySize: Math.max(1, t2.maxEntitySize ?? 1e4), maxExpansionDepth: Math.max(1, t2.maxExpansionDepth ?? 1e4), maxTotalExpansions: Math.max(1, t2.maxTotalExpansions ?? 1 / 0), maxExpandedLength: Math.max(1, t2.maxExpandedLength ?? 1e5), maxEntityCount: Math.max(1, t2.maxEntityCount ?? 1e3), allowedTags: t2.allowedTags ?? null, tagFilter: t2.tagFilter ?? null, appliesTo: t2.appliesTo ?? "all" } : T(true);
      }
      __name(T, "T");
      const C = /* @__PURE__ */ __name(function(t2) {
        const e33 = Object.assign({}, _, t2), n11 = [{ value: e33.attributeNamePrefix, name: "attributeNamePrefix" }, { value: e33.attributesGroupName, name: "attributesGroupName" }, { value: e33.textNodeName, name: "textNodeName" }, { value: e33.cdataPropName, name: "cdataPropName" }, { value: e33.commentPropName, name: "commentPropName" }];
        for (const { value: t3, name: e34 } of n11) t3 && A(t3, e34);
        return null === e33.onDangerousProperty && (e33.onDangerousProperty = S), e33.processEntities = T(e33.processEntities, e33.htmlEntities), e33.unpairedTagsSet = new Set(e33.unpairedTags), e33.stopNodes && Array.isArray(e33.stopNodes) && (e33.stopNodes = e33.stopNodes.map((t3) => "string" == typeof t3 && t3.startsWith("*.") ? ".." + t3.substring(2) : t3)), e33;
      }, "C");
      let P;
      P = "function" != typeof Symbol ? "@@xmlMetadata" : /* @__PURE__ */ Symbol("XML Node Metadata");
      class O {
        static {
          __name(this, "O");
        }
        constructor(t2) {
          this.tagname = t2, this.child = [], this[":@"] = /* @__PURE__ */ Object.create(null);
        }
        add(t2, e33) {
          "__proto__" === t2 && (t2 = "#__proto__"), this.child.push({ [t2]: e33 });
        }
        addChild(t2, e33) {
          "__proto__" === t2.tagname && (t2.tagname = "#__proto__"), t2[":@"] && Object.keys(t2[":@"]).length > 0 ? this.child.push({ [t2.tagname]: t2.child, ":@": t2[":@"] }) : this.child.push({ [t2.tagname]: t2.child }), void 0 !== e33 && (this.child[this.child.length - 1][P] = { startIndex: e33 });
        }
        static getMetaDataSymbol() {
          return P;
        }
      }
      class $ {
        static {
          __name(this, "$");
        }
        constructor(t2) {
          this.suppressValidationErr = !t2, this.options = t2;
        }
        readDocType(t2, e33) {
          const n11 = /* @__PURE__ */ Object.create(null);
          let i33 = 0;
          if ("O" !== t2[e33 + 3] || "C" !== t2[e33 + 4] || "T" !== t2[e33 + 5] || "Y" !== t2[e33 + 6] || "P" !== t2[e33 + 7] || "E" !== t2[e33 + 8]) throw new Error("Invalid Tag instead of DOCTYPE");
          {
            e33 += 9;
            let s2 = 1, r33 = false, o11 = false, a33 = "";
            for (; e33 < t2.length; e33++) if ("<" !== t2[e33] || o11) if (">" === t2[e33]) {
              if (o11 ? "-" === t2[e33 - 1] && "-" === t2[e33 - 2] && (o11 = false, s2--) : s2--, 0 === s2) break;
            } else "[" === t2[e33] ? r33 = true : a33 += t2[e33];
            else {
              if (r33 && D(t2, "!ENTITY", e33)) {
                let s3, r34;
                if (e33 += 7, [s3, r34, e33] = this.readEntityExp(t2, e33 + 1, this.suppressValidationErr), -1 === r34.indexOf("&")) {
                  if (false !== this.options.enabled && null != this.options.maxEntityCount && i33 >= this.options.maxEntityCount) throw new Error(`Entity count (${i33 + 1}) exceeds maximum allowed (${this.options.maxEntityCount})`);
                  n11[s3] = r34, i33++;
                }
              } else if (r33 && D(t2, "!ELEMENT", e33)) {
                e33 += 8;
                const { index: n12 } = this.readElementExp(t2, e33 + 1);
                e33 = n12;
              } else if (r33 && D(t2, "!ATTLIST", e33)) e33 += 8;
              else if (r33 && D(t2, "!NOTATION", e33)) {
                e33 += 9;
                const { index: n12 } = this.readNotationExp(t2, e33 + 1, this.suppressValidationErr);
                e33 = n12;
              } else {
                if (!D(t2, "!--", e33)) throw new Error("Invalid DOCTYPE");
                o11 = true;
              }
              s2++, a33 = "";
            }
            if (0 !== s2) throw new Error("Unclosed DOCTYPE");
          }
          return { entities: n11, i: e33 };
        }
        readEntityExp(t2, e33) {
          const n11 = e33 = I(t2, e33);
          for (; e33 < t2.length && !/\s/.test(t2[e33]) && '"' !== t2[e33] && "'" !== t2[e33]; ) e33++;
          let i33 = t2.substring(n11, e33);
          if (M(i33), e33 = I(t2, e33), !this.suppressValidationErr) {
            if ("SYSTEM" === t2.substring(e33, e33 + 6).toUpperCase()) throw new Error("External entities are not supported");
            if ("%" === t2[e33]) throw new Error("Parameter entities are not supported");
          }
          let s2 = "";
          if ([e33, s2] = this.readIdentifierVal(t2, e33, "entity"), false !== this.options.enabled && null != this.options.maxEntitySize && s2.length > this.options.maxEntitySize) throw new Error(`Entity "${i33}" size (${s2.length}) exceeds maximum allowed size (${this.options.maxEntitySize})`);
          return [i33, s2, --e33];
        }
        readNotationExp(t2, e33) {
          const n11 = e33 = I(t2, e33);
          for (; e33 < t2.length && !/\s/.test(t2[e33]); ) e33++;
          let i33 = t2.substring(n11, e33);
          !this.suppressValidationErr && M(i33), e33 = I(t2, e33);
          const s2 = t2.substring(e33, e33 + 6).toUpperCase();
          if (!this.suppressValidationErr && "SYSTEM" !== s2 && "PUBLIC" !== s2) throw new Error(`Expected SYSTEM or PUBLIC, found "${s2}"`);
          e33 += s2.length, e33 = I(t2, e33);
          let r33 = null, o11 = null;
          if ("PUBLIC" === s2) [e33, r33] = this.readIdentifierVal(t2, e33, "publicIdentifier"), '"' !== t2[e33 = I(t2, e33)] && "'" !== t2[e33] || ([e33, o11] = this.readIdentifierVal(t2, e33, "systemIdentifier"));
          else if ("SYSTEM" === s2 && ([e33, o11] = this.readIdentifierVal(t2, e33, "systemIdentifier"), !this.suppressValidationErr && !o11)) throw new Error("Missing mandatory system identifier for SYSTEM notation");
          return { notationName: i33, publicIdentifier: r33, systemIdentifier: o11, index: --e33 };
        }
        readIdentifierVal(t2, e33, n11) {
          let i33 = "";
          const s2 = t2[e33];
          if ('"' !== s2 && "'" !== s2) throw new Error(`Expected quoted string, found "${s2}"`);
          const r33 = ++e33;
          for (; e33 < t2.length && t2[e33] !== s2; ) e33++;
          if (i33 = t2.substring(r33, e33), t2[e33] !== s2) throw new Error(`Unterminated ${n11} value`);
          return [++e33, i33];
        }
        readElementExp(t2, e33) {
          const n11 = e33 = I(t2, e33);
          for (; e33 < t2.length && !/\s/.test(t2[e33]); ) e33++;
          let i33 = t2.substring(n11, e33);
          if (!this.suppressValidationErr && !r32(i33)) throw new Error(`Invalid element name: "${i33}"`);
          let s2 = "";
          if ("E" === t2[e33 = I(t2, e33)] && D(t2, "MPTY", e33)) e33 += 4;
          else if ("A" === t2[e33] && D(t2, "NY", e33)) e33 += 2;
          else if ("(" === t2[e33]) {
            const n12 = ++e33;
            for (; e33 < t2.length && ")" !== t2[e33]; ) e33++;
            if (s2 = t2.substring(n12, e33), ")" !== t2[e33]) throw new Error("Unterminated content model");
          } else if (!this.suppressValidationErr) throw new Error(`Invalid Element Expression, found "${t2[e33]}"`);
          return { elementName: i33, contentModel: s2.trim(), index: e33 };
        }
        readAttlistExp(t2, e33) {
          let n11 = e33 = I(t2, e33);
          for (; e33 < t2.length && !/\s/.test(t2[e33]); ) e33++;
          let i33 = t2.substring(n11, e33);
          for (M(i33), n11 = e33 = I(t2, e33); e33 < t2.length && !/\s/.test(t2[e33]); ) e33++;
          let s2 = t2.substring(n11, e33);
          if (!M(s2)) throw new Error(`Invalid attribute name: "${s2}"`);
          e33 = I(t2, e33);
          let r33 = "";
          if ("NOTATION" === t2.substring(e33, e33 + 8).toUpperCase()) {
            if (r33 = "NOTATION", "(" !== t2[e33 = I(t2, e33 += 8)]) throw new Error(`Expected '(', found "${t2[e33]}"`);
            e33++;
            let n12 = [];
            for (; e33 < t2.length && ")" !== t2[e33]; ) {
              const i34 = e33;
              for (; e33 < t2.length && "|" !== t2[e33] && ")" !== t2[e33]; ) e33++;
              let s3 = t2.substring(i34, e33);
              if (s3 = s3.trim(), !M(s3)) throw new Error(`Invalid notation name: "${s3}"`);
              n12.push(s3), "|" === t2[e33] && (e33++, e33 = I(t2, e33));
            }
            if (")" !== t2[e33]) throw new Error("Unterminated list of notations");
            e33++, r33 += " (" + n12.join("|") + ")";
          } else {
            const n12 = e33;
            for (; e33 < t2.length && !/\s/.test(t2[e33]); ) e33++;
            r33 += t2.substring(n12, e33);
            const i34 = ["CDATA", "ID", "IDREF", "IDREFS", "ENTITY", "ENTITIES", "NMTOKEN", "NMTOKENS"];
            if (!this.suppressValidationErr && !i34.includes(r33.toUpperCase())) throw new Error(`Invalid attribute type: "${r33}"`);
          }
          e33 = I(t2, e33);
          let o11 = "";
          return "#REQUIRED" === t2.substring(e33, e33 + 8).toUpperCase() ? (o11 = "#REQUIRED", e33 += 8) : "#IMPLIED" === t2.substring(e33, e33 + 7).toUpperCase() ? (o11 = "#IMPLIED", e33 += 7) : [e33, o11] = this.readIdentifierVal(t2, e33, "ATTLIST"), { elementName: i33, attributeName: s2, attributeType: r33, defaultValue: o11, index: e33 };
        }
      }
      const I = /* @__PURE__ */ __name((t2, e33) => {
        for (; e33 < t2.length && /\s/.test(t2[e33]); ) e33++;
        return e33;
      }, "I");
      function D(t2, e33, n11) {
        for (let i33 = 0; i33 < e33.length; i33++) if (e33[i33] !== t2[n11 + i33 + 1]) return false;
        return true;
      }
      __name(D, "D");
      function M(t2) {
        if (r32(t2)) return t2;
        throw new Error(`Invalid entity name ${t2}`);
      }
      __name(M, "M");
      const j32 = /^[-+]?0x[a-fA-F0-9]+$/, V = /^([\-\+])?(0*)([0-9]*(\.[0-9]*)?)$/, L = { hex: true, leadingZeros: true, decimalPoint: ".", eNotation: true, infinity: "original" };
      const k32 = /^([-+])?(0*)(\d*(\.\d*)?[eE][-\+]?\d+)$/;
      class F {
        static {
          __name(this, "F");
        }
        constructor(t2) {
          this._matcher = t2;
        }
        get separator() {
          return this._matcher.separator;
        }
        getCurrentTag() {
          const t2 = this._matcher.path;
          return t2.length > 0 ? t2[t2.length - 1].tag : void 0;
        }
        getCurrentNamespace() {
          const t2 = this._matcher.path;
          return t2.length > 0 ? t2[t2.length - 1].namespace : void 0;
        }
        getAttrValue(t2) {
          const e33 = this._matcher.path;
          if (0 !== e33.length) return e33[e33.length - 1].values?.[t2];
        }
        hasAttr(t2) {
          const e33 = this._matcher.path;
          if (0 === e33.length) return false;
          const n11 = e33[e33.length - 1];
          return void 0 !== n11.values && t2 in n11.values;
        }
        getPosition() {
          const t2 = this._matcher.path;
          return 0 === t2.length ? -1 : t2[t2.length - 1].position ?? 0;
        }
        getCounter() {
          const t2 = this._matcher.path;
          return 0 === t2.length ? -1 : t2[t2.length - 1].counter ?? 0;
        }
        getIndex() {
          return this.getPosition();
        }
        getDepth() {
          return this._matcher.path.length;
        }
        toString(t2, e33 = true) {
          return this._matcher.toString(t2, e33);
        }
        toArray() {
          return this._matcher.path.map((t2) => t2.tag);
        }
        matches(t2) {
          return this._matcher.matches(t2);
        }
        matchesAny(t2) {
          return t2.matchesAny(this._matcher);
        }
      }
      class R {
        static {
          __name(this, "R");
        }
        constructor(t2 = {}) {
          this.separator = t2.separator || ".", this.path = [], this.siblingStacks = [], this._pathStringCache = null, this._view = new F(this);
        }
        push(t2, e33 = null, n11 = null) {
          this._pathStringCache = null, this.path.length > 0 && (this.path[this.path.length - 1].values = void 0);
          const i33 = this.path.length;
          this.siblingStacks[i33] || (this.siblingStacks[i33] = /* @__PURE__ */ new Map());
          const s2 = this.siblingStacks[i33], r33 = n11 ? `${n11}:${t2}` : t2, o11 = s2.get(r33) || 0;
          let a33 = 0;
          for (const t3 of s2.values()) a33 += t3;
          s2.set(r33, o11 + 1);
          const h33 = { tag: t2, position: a33, counter: o11 };
          null != n11 && (h33.namespace = n11), null != e33 && (h33.values = e33), this.path.push(h33);
        }
        pop() {
          if (0 === this.path.length) return;
          this._pathStringCache = null;
          const t2 = this.path.pop();
          return this.siblingStacks.length > this.path.length + 1 && (this.siblingStacks.length = this.path.length + 1), t2;
        }
        updateCurrent(t2) {
          if (this.path.length > 0) {
            const e33 = this.path[this.path.length - 1];
            null != t2 && (e33.values = t2);
          }
        }
        getCurrentTag() {
          return this.path.length > 0 ? this.path[this.path.length - 1].tag : void 0;
        }
        getCurrentNamespace() {
          return this.path.length > 0 ? this.path[this.path.length - 1].namespace : void 0;
        }
        getAttrValue(t2) {
          if (0 !== this.path.length) return this.path[this.path.length - 1].values?.[t2];
        }
        hasAttr(t2) {
          if (0 === this.path.length) return false;
          const e33 = this.path[this.path.length - 1];
          return void 0 !== e33.values && t2 in e33.values;
        }
        getPosition() {
          return 0 === this.path.length ? -1 : this.path[this.path.length - 1].position ?? 0;
        }
        getCounter() {
          return 0 === this.path.length ? -1 : this.path[this.path.length - 1].counter ?? 0;
        }
        getIndex() {
          return this.getPosition();
        }
        getDepth() {
          return this.path.length;
        }
        toString(t2, e33 = true) {
          const n11 = t2 || this.separator;
          if (n11 === this.separator && true === e33) {
            if (null !== this._pathStringCache) return this._pathStringCache;
            const t3 = this.path.map((t4) => t4.namespace ? `${t4.namespace}:${t4.tag}` : t4.tag).join(n11);
            return this._pathStringCache = t3, t3;
          }
          return this.path.map((t3) => e33 && t3.namespace ? `${t3.namespace}:${t3.tag}` : t3.tag).join(n11);
        }
        toArray() {
          return this.path.map((t2) => t2.tag);
        }
        reset() {
          this._pathStringCache = null, this.path = [], this.siblingStacks = [];
        }
        matches(t2) {
          const e33 = t2.segments;
          return 0 !== e33.length && (t2.hasDeepWildcard() ? this._matchWithDeepWildcard(e33) : this._matchSimple(e33));
        }
        _matchSimple(t2) {
          if (this.path.length !== t2.length) return false;
          for (let e33 = 0; e33 < t2.length; e33++) if (!this._matchSegment(t2[e33], this.path[e33], e33 === this.path.length - 1)) return false;
          return true;
        }
        _matchWithDeepWildcard(t2) {
          let e33 = this.path.length - 1, n11 = t2.length - 1;
          for (; n11 >= 0 && e33 >= 0; ) {
            const i33 = t2[n11];
            if ("deep-wildcard" === i33.type) {
              if (n11--, n11 < 0) return true;
              const i34 = t2[n11];
              let s2 = false;
              for (let t3 = e33; t3 >= 0; t3--) if (this._matchSegment(i34, this.path[t3], t3 === this.path.length - 1)) {
                e33 = t3 - 1, n11--, s2 = true;
                break;
              }
              if (!s2) return false;
            } else {
              if (!this._matchSegment(i33, this.path[e33], e33 === this.path.length - 1)) return false;
              e33--, n11--;
            }
          }
          return n11 < 0;
        }
        _matchSegment(t2, e33, n11) {
          if ("*" !== t2.tag && t2.tag !== e33.tag) return false;
          if (void 0 !== t2.namespace && "*" !== t2.namespace && t2.namespace !== e33.namespace) return false;
          if (void 0 !== t2.attrName) {
            if (!n11) return false;
            if (!e33.values || !(t2.attrName in e33.values)) return false;
            if (void 0 !== t2.attrValue && String(e33.values[t2.attrName]) !== String(t2.attrValue)) return false;
          }
          if (void 0 !== t2.position) {
            if (!n11) return false;
            const i33 = e33.counter ?? 0;
            if ("first" === t2.position && 0 !== i33) return false;
            if ("odd" === t2.position && i33 % 2 != 1) return false;
            if ("even" === t2.position && i33 % 2 != 0) return false;
            if ("nth" === t2.position && i33 !== t2.positionValue) return false;
          }
          return true;
        }
        matchesAny(t2) {
          return t2.matchesAny(this);
        }
        snapshot() {
          return { path: this.path.map((t2) => ({ ...t2 })), siblingStacks: this.siblingStacks.map((t2) => new Map(t2)) };
        }
        restore(t2) {
          this._pathStringCache = null, this.path = t2.path.map((t3) => ({ ...t3 })), this.siblingStacks = t2.siblingStacks.map((t3) => new Map(t3));
        }
        readOnly() {
          return this._view;
        }
      }
      class G {
        static {
          __name(this, "G");
        }
        constructor(t2, e33 = {}, n11) {
          this.pattern = t2, this.separator = e33.separator || ".", this.segments = this._parse(t2), this.data = n11, this._hasDeepWildcard = this.segments.some((t3) => "deep-wildcard" === t3.type), this._hasAttributeCondition = this.segments.some((t3) => void 0 !== t3.attrName), this._hasPositionSelector = this.segments.some((t3) => void 0 !== t3.position);
        }
        _parse(t2) {
          const e33 = [];
          let n11 = 0, i33 = "";
          for (; n11 < t2.length; ) t2[n11] === this.separator ? n11 + 1 < t2.length && t2[n11 + 1] === this.separator ? (i33.trim() && (e33.push(this._parseSegment(i33.trim())), i33 = ""), e33.push({ type: "deep-wildcard" }), n11 += 2) : (i33.trim() && e33.push(this._parseSegment(i33.trim())), i33 = "", n11++) : (i33 += t2[n11], n11++);
          return i33.trim() && e33.push(this._parseSegment(i33.trim())), e33;
        }
        _parseSegment(t2) {
          const e33 = { type: "tag" };
          let n11 = null, i33 = t2;
          const s2 = t2.match(/^([^\[]+)(\[[^\]]*\])(.*)$/);
          if (s2 && (i33 = s2[1] + s2[3], s2[2])) {
            const t3 = s2[2].slice(1, -1);
            t3 && (n11 = t3);
          }
          let r33, o11, a33 = i33;
          if (i33.includes("::")) {
            const e34 = i33.indexOf("::");
            if (r33 = i33.substring(0, e34).trim(), a33 = i33.substring(e34 + 2).trim(), !r33) throw new Error(`Invalid namespace in pattern: ${t2}`);
          }
          let h33 = null;
          if (a33.includes(":")) {
            const t3 = a33.lastIndexOf(":"), e34 = a33.substring(0, t3).trim(), n12 = a33.substring(t3 + 1).trim();
            ["first", "last", "odd", "even"].includes(n12) || /^nth\(\d+\)$/.test(n12) ? (o11 = e34, h33 = n12) : o11 = a33;
          } else o11 = a33;
          if (!o11) throw new Error(`Invalid segment pattern: ${t2}`);
          if (e33.tag = o11, r33 && (e33.namespace = r33), n11) if (n11.includes("=")) {
            const t3 = n11.indexOf("=");
            e33.attrName = n11.substring(0, t3).trim(), e33.attrValue = n11.substring(t3 + 1).trim();
          } else e33.attrName = n11.trim();
          if (h33) {
            const t3 = h33.match(/^nth\((\d+)\)$/);
            t3 ? (e33.position = "nth", e33.positionValue = parseInt(t3[1], 10)) : e33.position = h33;
          }
          return e33;
        }
        get length() {
          return this.segments.length;
        }
        hasDeepWildcard() {
          return this._hasDeepWildcard;
        }
        hasAttributeCondition() {
          return this._hasAttributeCondition;
        }
        hasPositionSelector() {
          return this._hasPositionSelector;
        }
        toString() {
          return this.pattern;
        }
      }
      class B {
        static {
          __name(this, "B");
        }
        constructor() {
          this._byDepthAndTag = /* @__PURE__ */ new Map(), this._wildcardByDepth = /* @__PURE__ */ new Map(), this._deepWildcards = [], this._patterns = /* @__PURE__ */ new Set(), this._sealed = false;
        }
        add(t2) {
          if (this._sealed) throw new TypeError("ExpressionSet is sealed. Create a new ExpressionSet to add more expressions.");
          if (this._patterns.has(t2.pattern)) return this;
          if (this._patterns.add(t2.pattern), t2.hasDeepWildcard()) return this._deepWildcards.push(t2), this;
          const e33 = t2.length, n11 = t2.segments[t2.segments.length - 1], i33 = n11?.tag;
          if (i33 && "*" !== i33) {
            const n12 = `${e33}:${i33}`;
            this._byDepthAndTag.has(n12) || this._byDepthAndTag.set(n12, []), this._byDepthAndTag.get(n12).push(t2);
          } else this._wildcardByDepth.has(e33) || this._wildcardByDepth.set(e33, []), this._wildcardByDepth.get(e33).push(t2);
          return this;
        }
        addAll(t2) {
          for (const e33 of t2) this.add(e33);
          return this;
        }
        has(t2) {
          return this._patterns.has(t2.pattern);
        }
        get size() {
          return this._patterns.size;
        }
        seal() {
          return this._sealed = true, this;
        }
        get isSealed() {
          return this._sealed;
        }
        matchesAny(t2) {
          return null !== this.findMatch(t2);
        }
        findMatch(t2) {
          const e33 = t2.getDepth(), n11 = `${e33}:${t2.getCurrentTag()}`, i33 = this._byDepthAndTag.get(n11);
          if (i33) {
            for (let e34 = 0; e34 < i33.length; e34++) if (t2.matches(i33[e34])) return i33[e34];
          }
          const s2 = this._wildcardByDepth.get(e33);
          if (s2) {
            for (let e34 = 0; e34 < s2.length; e34++) if (t2.matches(s2[e34])) return s2[e34];
          }
          for (let e34 = 0; e34 < this._deepWildcards.length; e34++) if (t2.matches(this._deepWildcards[e34])) return this._deepWildcards[e34];
          return null;
        }
      }
      const U = { cent: "\xA2", pound: "\xA3", curren: "\xA4", yen: "\xA5", euro: "\u20AC", dollar: "$", euro: "\u20AC", fnof: "\u0192", inr: "\u20B9", af: "\u060B", birr: "\u1265\u122D", peso: "\u20B1", rub: "\u20BD", won: "\u20A9", yuan: "\xA5", cedil: "\xB8" }, W = { amp: "&", apos: "'", gt: ">", lt: "<", quot: '"' }, X = { nbsp: "\xA0", copy: "\xA9", reg: "\xAE", trade: "\u2122", mdash: "\u2014", ndash: "\u2013", hellip: "\u2026", laquo: "\xAB", raquo: "\xBB", lsquo: "\u2018", rsquo: "\u2019", ldquo: "\u201C", rdquo: "\u201D", bull: "\u2022", para: "\xB6", sect: "\xA7", deg: "\xB0", frac12: "\xBD", frac14: "\xBC", frac34: "\xBE" }, Y = new Set("!?\\\\/[]$%{}^&*()<>|+");
      function z(t2) {
        if ("#" === t2[0]) throw new Error(`[EntityReplacer] Invalid character '#' in entity name: "${t2}"`);
        for (const e33 of t2) if (Y.has(e33)) throw new Error(`[EntityReplacer] Invalid character '${e33}' in entity name: "${t2}"`);
        return t2;
      }
      __name(z, "z");
      function q10(...t2) {
        const e33 = /* @__PURE__ */ Object.create(null);
        for (const n11 of t2) if (n11) for (const t3 of Object.keys(n11)) {
          const i33 = n11[t3];
          if ("string" == typeof i33) e33[t3] = i33;
          else if (i33 && "object" == typeof i33 && void 0 !== i33.val) {
            const n12 = i33.val;
            "string" == typeof n12 && (e33[t3] = n12);
          }
        }
        return e33;
      }
      __name(q10, "q");
      const Z = "external", J = "base", K = "all", Q = Object.freeze({ allow: 0, leave: 1, remove: 2, throw: 3 }), H = /* @__PURE__ */ new Set([9, 10, 13]);
      class tt {
        static {
          __name(this, "tt");
        }
        constructor(t2 = {}) {
          var e33;
          this._limit = t2.limit || {}, this._maxTotalExpansions = this._limit.maxTotalExpansions || 0, this._maxExpandedLength = this._limit.maxExpandedLength || 0, this._postCheck = "function" == typeof t2.postCheck ? t2.postCheck : (t3) => t3, this._limitTiers = (e33 = this._limit.applyLimitsTo ?? Z) && e33 !== Z ? e33 === K ? /* @__PURE__ */ new Set([K]) : e33 === J ? /* @__PURE__ */ new Set([J]) : Array.isArray(e33) ? new Set(e33) : /* @__PURE__ */ new Set([Z]) : /* @__PURE__ */ new Set([Z]), this._numericAllowed = t2.numericAllowed ?? true, this._baseMap = q10(W, t2.namedEntities || null), this._externalMap = /* @__PURE__ */ Object.create(null), this._inputMap = /* @__PURE__ */ Object.create(null), this._totalExpansions = 0, this._expandedLength = 0, this._removeSet = new Set(t2.remove && Array.isArray(t2.remove) ? t2.remove : []), this._leaveSet = new Set(t2.leave && Array.isArray(t2.leave) ? t2.leave : []);
          const n11 = (function(t3) {
            if (!t3) return { xmlVersion: 1, onLevel: Q.allow, nullLevel: Q.remove };
            const e34 = 1.1 === t3.xmlVersion ? 1.1 : 1, n12 = Q[t3.onNCR] ?? Q.allow, i33 = Q[t3.nullNCR] ?? Q.remove;
            return { xmlVersion: e34, onLevel: n12, nullLevel: Math.max(i33, Q.remove) };
          })(t2.ncr);
          this._ncrXmlVersion = n11.xmlVersion, this._ncrOnLevel = n11.onLevel, this._ncrNullLevel = n11.nullLevel;
        }
        setExternalEntities(t2) {
          if (t2) for (const e33 of Object.keys(t2)) z(e33);
          this._externalMap = q10(t2);
        }
        addExternalEntity(t2, e33) {
          z(t2), "string" == typeof e33 && -1 === e33.indexOf("&") && (this._externalMap[t2] = e33);
        }
        addInputEntities(t2) {
          this._totalExpansions = 0, this._expandedLength = 0, this._inputMap = q10(t2);
        }
        reset() {
          return this._inputMap = /* @__PURE__ */ Object.create(null), this._totalExpansions = 0, this._expandedLength = 0, this;
        }
        setXmlVersion(t2) {
          this._ncrXmlVersion = 1.1 === t2 ? 1.1 : 1;
        }
        decode(t2) {
          if ("string" != typeof t2 || 0 === t2.length) return t2;
          const e33 = t2, n11 = [], i33 = t2.length;
          let s2 = 0, r33 = 0;
          const o11 = this._maxTotalExpansions > 0, a33 = this._maxExpandedLength > 0, h33 = o11 || a33;
          for (; r33 < i33; ) {
            if (38 !== t2.charCodeAt(r33)) {
              r33++;
              continue;
            }
            let e34 = r33 + 1;
            for (; e34 < i33 && 59 !== t2.charCodeAt(e34) && e34 - r33 <= 32; ) e34++;
            if (e34 >= i33 || 59 !== t2.charCodeAt(e34)) {
              r33++;
              continue;
            }
            const l22 = t2.slice(r33 + 1, e34);
            if (0 === l22.length) {
              r33++;
              continue;
            }
            let u2, p11;
            if (this._removeSet.has(l22)) u2 = "", void 0 === p11 && (p11 = Z);
            else {
              if (this._leaveSet.has(l22)) {
                r33++;
                continue;
              }
              if (35 === l22.charCodeAt(0)) {
                const t3 = this._resolveNCR(l22);
                if (void 0 === t3) {
                  r33++;
                  continue;
                }
                u2 = t3, p11 = J;
              } else {
                const t3 = this._resolveName(l22);
                u2 = t3?.value, p11 = t3?.tier;
              }
            }
            if (void 0 !== u2) {
              if (r33 > s2 && n11.push(t2.slice(s2, r33)), n11.push(u2), s2 = e34 + 1, r33 = s2, h33 && this._tierCounts(p11)) {
                if (o11 && (this._totalExpansions++, this._totalExpansions > this._maxTotalExpansions)) throw new Error(`[EntityReplacer] Entity expansion count limit exceeded: ${this._totalExpansions} > ${this._maxTotalExpansions}`);
                if (a33) {
                  const t3 = u2.length - (l22.length + 2);
                  if (t3 > 0 && (this._expandedLength += t3, this._expandedLength > this._maxExpandedLength)) throw new Error(`[EntityReplacer] Expanded content length limit exceeded: ${this._expandedLength} > ${this._maxExpandedLength}`);
                }
              }
            } else r33++;
          }
          s2 < i33 && n11.push(t2.slice(s2));
          const l21 = 0 === n11.length ? t2 : n11.join("");
          return this._postCheck(l21, e33);
        }
        _tierCounts(t2) {
          return !!this._limitTiers.has(K) || this._limitTiers.has(t2);
        }
        _resolveName(t2) {
          return t2 in this._inputMap ? { value: this._inputMap[t2], tier: Z } : t2 in this._externalMap ? { value: this._externalMap[t2], tier: Z } : t2 in this._baseMap ? { value: this._baseMap[t2], tier: J } : void 0;
        }
        _classifyNCR(t2) {
          return 0 === t2 ? this._ncrNullLevel : t2 >= 55296 && t2 <= 57343 || 1 === this._ncrXmlVersion && t2 >= 1 && t2 <= 31 && !H.has(t2) ? Q.remove : -1;
        }
        _applyNCRAction(t2, e33, n11) {
          switch (t2) {
            case Q.allow:
              return String.fromCodePoint(n11);
            case Q.remove:
              return "";
            case Q.leave:
              return;
            case Q.throw:
              throw new Error(`[EntityDecoder] Prohibited numeric character reference &${e33}; (U+${n11.toString(16).toUpperCase().padStart(4, "0")})`);
            default:
              return String.fromCodePoint(n11);
          }
        }
        _resolveNCR(t2) {
          const e33 = t2.charCodeAt(1);
          let n11;
          if (n11 = 120 === e33 || 88 === e33 ? parseInt(t2.slice(2), 16) : parseInt(t2.slice(1), 10), Number.isNaN(n11) || n11 < 0 || n11 > 1114111) return;
          const i33 = this._classifyNCR(n11);
          if (!this._numericAllowed && i33 < Q.remove) return;
          const s2 = -1 === i33 ? this._ncrOnLevel : Math.max(this._ncrOnLevel, i33);
          return this._applyNCRAction(s2, t2, n11);
        }
      }
      function et(t2, e33) {
        if (!t2) return {};
        const n11 = e33.attributesGroupName ? t2[e33.attributesGroupName] : t2;
        if (!n11) return {};
        const i33 = {};
        for (const t3 in n11) t3.startsWith(e33.attributeNamePrefix) ? i33[t3.substring(e33.attributeNamePrefix.length)] = n11[t3] : i33[t3] = n11[t3];
        return i33;
      }
      __name(et, "et");
      function nt(t2) {
        if (!t2 || "string" != typeof t2) return;
        const e33 = t2.indexOf(":");
        if (-1 !== e33 && e33 > 0) {
          const n11 = t2.substring(0, e33);
          if ("xmlns" !== n11) return n11;
        }
      }
      __name(nt, "nt");
      class it {
        static {
          __name(this, "it");
        }
        constructor(t2, e33) {
          var n11;
          this.options = t2, this.currentNode = null, this.tagsNodeStack = [], this.parseXml = ht, this.parseTextData = st, this.resolveNameSpace = rt, this.buildAttributesMap = at, this.isItStopNode = ct, this.replaceEntitiesValue = ut, this.readStopNodeData = mt, this.saveTextToParentTag = pt, this.addChild = lt, this.ignoreAttributesFn = "function" == typeof (n11 = this.options.ignoreAttributes) ? n11 : Array.isArray(n11) ? (t3) => {
            for (const e34 of n11) {
              if ("string" == typeof e34 && t3 === e34) return true;
              if (e34 instanceof RegExp && e34.test(t3)) return true;
            }
          } : () => false, this.entityExpansionCount = 0, this.currentExpandedLength = 0;
          let i33 = { ...W };
          this.options.entityDecoder ? this.entityDecoder = this.options.entityDecoder : ("object" == typeof this.options.htmlEntities ? i33 = this.options.htmlEntities : true === this.options.htmlEntities && (i33 = { ...X, ...U }), this.entityDecoder = new tt({ namedEntities: { ...i33, ...e33 }, numericAllowed: this.options.htmlEntities, limit: { maxTotalExpansions: this.options.processEntities.maxTotalExpansions, maxExpandedLength: this.options.processEntities.maxExpandedLength, applyLimitsTo: this.options.processEntities.appliesTo } })), this.matcher = new R(), this.readonlyMatcher = this.matcher.readOnly(), this.isCurrentNodeStopNode = false, this.stopNodeExpressionsSet = new B();
          const s2 = this.options.stopNodes;
          if (s2 && s2.length > 0) {
            for (let t3 = 0; t3 < s2.length; t3++) {
              const e34 = s2[t3];
              "string" == typeof e34 ? this.stopNodeExpressionsSet.add(new G(e34)) : e34 instanceof G && this.stopNodeExpressionsSet.add(e34);
            }
            this.stopNodeExpressionsSet.seal();
          }
        }
      }
      function st(t2, e33, n11, i33, s2, r33, o11) {
        const a33 = this.options;
        if (void 0 !== t2 && (a33.trimValues && !i33 && (t2 = t2.trim()), t2.length > 0)) {
          o11 || (t2 = this.replaceEntitiesValue(t2, e33, n11));
          const i34 = a33.jPath ? n11.toString() : n11, h33 = a33.tagValueProcessor(e33, t2, i34, s2, r33);
          return null == h33 ? t2 : typeof h33 != typeof t2 || h33 !== t2 ? h33 : a33.trimValues || t2.trim() === t2 ? xt(t2, a33.parseTagValue, a33.numberParseOptions) : t2;
        }
      }
      __name(st, "st");
      function rt(t2) {
        if (this.options.removeNSPrefix) {
          const e33 = t2.split(":"), n11 = "/" === t2.charAt(0) ? "/" : "";
          if ("xmlns" === e33[0]) return "";
          2 === e33.length && (t2 = n11 + e33[1]);
        }
        return t2;
      }
      __name(rt, "rt");
      const ot = new RegExp(`([^\\s=]+)\\s*(=\\s*(['"])([\\s\\S]*?)\\3)?`, "gm");
      function at(t2, e33, n11, i33 = false) {
        const r33 = this.options;
        if (true === i33 || true !== r33.ignoreAttributes && "string" == typeof t2) {
          const i34 = s(t2, ot), o11 = i34.length, a33 = {}, h33 = new Array(o11);
          let l21 = false;
          const u2 = {};
          for (let t3 = 0; t3 < o11; t3++) {
            const e34 = this.resolveNameSpace(i34[t3][1]), s2 = i34[t3][4];
            if (e34.length && void 0 !== s2) {
              let i35 = s2;
              r33.trimValues && (i35 = i35.trim()), i35 = this.replaceEntitiesValue(i35, n11, this.readonlyMatcher), h33[t3] = i35, u2[e34] = i35, l21 = true;
            }
          }
          l21 && "object" == typeof e33 && e33.updateCurrent && e33.updateCurrent(u2);
          const p11 = r33.jPath ? e33.toString() : this.readonlyMatcher;
          let c33 = false;
          for (let t3 = 0; t3 < o11; t3++) {
            const e34 = this.resolveNameSpace(i34[t3][1]);
            if (this.ignoreAttributesFn(e34, p11)) continue;
            let n12 = r33.attributeNamePrefix + e34;
            if (e34.length) if (r33.transformAttributeName && (n12 = r33.transformAttributeName(n12)), n12 = bt(n12, r33), void 0 !== i34[t3][4]) {
              const i35 = h33[t3], s2 = r33.attributeValueProcessor(e34, i35, p11);
              a33[n12] = null == s2 ? i35 : typeof s2 != typeof i35 || s2 !== i35 ? s2 : xt(i35, r33.parseAttributeValue, r33.numberParseOptions), c33 = true;
            } else r33.allowBooleanAttributes && (a33[n12] = true, c33 = true);
          }
          if (!c33) return;
          if (r33.attributesGroupName && !r33.preserveOrder) {
            const t3 = {};
            return t3[r33.attributesGroupName] = a33, t3;
          }
          return a33;
        }
      }
      __name(at, "at");
      const ht = /* @__PURE__ */ __name(function(t2) {
        t2 = t2.replace(/\r\n?/g, "\n");
        const e33 = new O("!xml");
        let n11 = e33, i33 = "";
        this.matcher.reset(), this.entityDecoder.reset(), this.entityExpansionCount = 0, this.currentExpandedLength = 0;
        const s2 = this.options, r33 = new $(s2.processEntities), o11 = t2.length;
        for (let a33 = 0; a33 < o11; a33++) if ("<" === t2[a33]) {
          const h33 = t2.charCodeAt(a33 + 1);
          if (47 === h33) {
            const e34 = dt(t2, ">", a33, "Closing Tag is not closed.");
            let r34 = t2.substring(a33 + 2, e34).trim();
            if (s2.removeNSPrefix) {
              const t3 = r34.indexOf(":");
              -1 !== t3 && (r34 = r34.substr(t3 + 1));
            }
            r34 = Nt(s2.transformTagName, r34, "", s2).tagName, n11 && (i33 = this.saveTextToParentTag(i33, n11, this.readonlyMatcher));
            const o12 = this.matcher.getCurrentTag();
            if (r34 && s2.unpairedTagsSet.has(r34)) throw new Error(`Unpaired tag can not be used as closing tag: </${r34}>`);
            o12 && s2.unpairedTagsSet.has(o12) && (this.matcher.pop(), this.tagsNodeStack.pop()), this.matcher.pop(), this.isCurrentNodeStopNode = false, n11 = this.tagsNodeStack.pop(), i33 = "", a33 = e34;
          } else if (63 === h33) {
            let e34 = gt(t2, a33, false, "?>");
            if (!e34) throw new Error("Pi Tag is not closed.");
            i33 = this.saveTextToParentTag(i33, n11, this.readonlyMatcher);
            const r34 = this.buildAttributesMap(e34.tagExp, this.matcher, e34.tagName, true);
            if (r34) {
              const t3 = r34[this.options.attributeNamePrefix + "version"];
              this.entityDecoder.setXmlVersion(Number(t3) || 1);
            }
            if (s2.ignoreDeclaration && "?xml" === e34.tagName || s2.ignorePiTags) ;
            else {
              const t3 = new O(e34.tagName);
              t3.add(s2.textNodeName, ""), e34.tagName !== e34.tagExp && e34.attrExpPresent && true !== s2.ignoreAttributes && (t3[":@"] = r34), this.addChild(n11, t3, this.readonlyMatcher, a33);
            }
            a33 = e34.closeIndex + 1;
          } else if (33 === h33 && 45 === t2.charCodeAt(a33 + 2) && 45 === t2.charCodeAt(a33 + 3)) {
            const e34 = dt(t2, "-->", a33 + 4, "Comment is not closed.");
            if (s2.commentPropName) {
              const r34 = t2.substring(a33 + 4, e34 - 2);
              i33 = this.saveTextToParentTag(i33, n11, this.readonlyMatcher), n11.add(s2.commentPropName, [{ [s2.textNodeName]: r34 }]);
            }
            a33 = e34;
          } else if (33 === h33 && 68 === t2.charCodeAt(a33 + 2)) {
            const e34 = r33.readDocType(t2, a33);
            this.entityDecoder.addInputEntities(e34.entities), a33 = e34.i;
          } else if (33 === h33 && 91 === t2.charCodeAt(a33 + 2)) {
            const e34 = dt(t2, "]]>", a33, "CDATA is not closed.") - 2, r34 = t2.substring(a33 + 9, e34);
            i33 = this.saveTextToParentTag(i33, n11, this.readonlyMatcher);
            let o12 = this.parseTextData(r34, n11.tagname, this.readonlyMatcher, true, false, true, true);
            null == o12 && (o12 = ""), s2.cdataPropName ? n11.add(s2.cdataPropName, [{ [s2.textNodeName]: r34 }]) : n11.add(s2.textNodeName, o12), a33 = e34 + 2;
          } else {
            let r34 = gt(t2, a33, s2.removeNSPrefix);
            if (!r34) {
              const e34 = t2.substring(Math.max(0, a33 - 50), Math.min(o11, a33 + 50));
              throw new Error(`readTagExp returned undefined at position ${a33}. Context: "${e34}"`);
            }
            let h34 = r34.tagName;
            const l21 = r34.rawTagName;
            let u2 = r34.tagExp, p11 = r34.attrExpPresent, c33 = r34.closeIndex;
            if ({ tagName: h34, tagExp: u2 } = Nt(s2.transformTagName, h34, u2, s2), s2.strictReservedNames && (h34 === s2.commentPropName || h34 === s2.cdataPropName || h34 === s2.textNodeName || h34 === s2.attributesGroupName)) throw new Error(`Invalid tag name: ${h34}`);
            n11 && i33 && "!xml" !== n11.tagname && (i33 = this.saveTextToParentTag(i33, n11, this.readonlyMatcher, false));
            const d33 = n11;
            d33 && s2.unpairedTagsSet.has(d33.tagname) && (n11 = this.tagsNodeStack.pop(), this.matcher.pop());
            let f33 = false;
            u2.length > 0 && u2.lastIndexOf("/") === u2.length - 1 && (f33 = true, "/" === h34[h34.length - 1] ? (h34 = h34.substr(0, h34.length - 1), u2 = h34) : u2 = u2.substr(0, u2.length - 1), p11 = h34 !== u2);
            let g33, m21 = null, x2 = {};
            g33 = nt(l21), h34 !== e33.tagname && this.matcher.push(h34, {}, g33), h34 !== u2 && p11 && (m21 = this.buildAttributesMap(u2, this.matcher, h34), m21 && (x2 = et(m21, s2))), h34 !== e33.tagname && (this.isCurrentNodeStopNode = this.isItStopNode());
            const N2 = a33;
            if (this.isCurrentNodeStopNode) {
              let e34 = "";
              if (f33) a33 = r34.closeIndex;
              else if (s2.unpairedTagsSet.has(h34)) a33 = r34.closeIndex;
              else {
                const n12 = this.readStopNodeData(t2, l21, c33 + 1);
                if (!n12) throw new Error(`Unexpected end of ${l21}`);
                a33 = n12.i, e34 = n12.tagContent;
              }
              const i34 = new O(h34);
              m21 && (i34[":@"] = m21), i34.add(s2.textNodeName, e34), this.matcher.pop(), this.isCurrentNodeStopNode = false, this.addChild(n11, i34, this.readonlyMatcher, N2);
            } else {
              if (f33) {
                ({ tagName: h34, tagExp: u2 } = Nt(s2.transformTagName, h34, u2, s2));
                const t3 = new O(h34);
                m21 && (t3[":@"] = m21), this.addChild(n11, t3, this.readonlyMatcher, N2), this.matcher.pop(), this.isCurrentNodeStopNode = false;
              } else {
                if (s2.unpairedTagsSet.has(h34)) {
                  const t3 = new O(h34);
                  m21 && (t3[":@"] = m21), this.addChild(n11, t3, this.readonlyMatcher, N2), this.matcher.pop(), this.isCurrentNodeStopNode = false, a33 = r34.closeIndex;
                  continue;
                }
                {
                  const t3 = new O(h34);
                  if (this.tagsNodeStack.length > s2.maxNestedTags) throw new Error("Maximum nested tags exceeded");
                  this.tagsNodeStack.push(n11), m21 && (t3[":@"] = m21), this.addChild(n11, t3, this.readonlyMatcher, N2), n11 = t3;
                }
              }
              i33 = "", a33 = c33;
            }
          }
        } else i33 += t2[a33];
        return e33.child;
      }, "ht");
      function lt(t2, e33, n11, i33) {
        this.options.captureMetaData || (i33 = void 0);
        const s2 = this.options.jPath ? n11.toString() : n11, r33 = this.options.updateTag(e33.tagname, s2, e33[":@"]);
        false === r33 || ("string" == typeof r33 ? (e33.tagname = r33, t2.addChild(e33, i33)) : t2.addChild(e33, i33));
      }
      __name(lt, "lt");
      function ut(t2, e33, n11) {
        const i33 = this.options.processEntities;
        if (!i33 || !i33.enabled) return t2;
        if (i33.allowedTags) {
          const s2 = this.options.jPath ? n11.toString() : n11;
          if (!(Array.isArray(i33.allowedTags) ? i33.allowedTags.includes(e33) : i33.allowedTags(e33, s2))) return t2;
        }
        if (i33.tagFilter) {
          const s2 = this.options.jPath ? n11.toString() : n11;
          if (!i33.tagFilter(e33, s2)) return t2;
        }
        return this.entityDecoder.decode(t2);
      }
      __name(ut, "ut");
      function pt(t2, e33, n11, i33) {
        return t2 && (void 0 === i33 && (i33 = 0 === e33.child.length), void 0 !== (t2 = this.parseTextData(t2, e33.tagname, n11, false, !!e33[":@"] && 0 !== Object.keys(e33[":@"]).length, i33)) && "" !== t2 && e33.add(this.options.textNodeName, t2), t2 = ""), t2;
      }
      __name(pt, "pt");
      function ct() {
        return 0 !== this.stopNodeExpressionsSet.size && this.matcher.matchesAny(this.stopNodeExpressionsSet);
      }
      __name(ct, "ct");
      function dt(t2, e33, n11, i33) {
        const s2 = t2.indexOf(e33, n11);
        if (-1 === s2) throw new Error(i33);
        return s2 + e33.length - 1;
      }
      __name(dt, "dt");
      function ft(t2, e33, n11, i33) {
        const s2 = t2.indexOf(e33, n11);
        if (-1 === s2) throw new Error(i33);
        return s2;
      }
      __name(ft, "ft");
      function gt(t2, e33, n11, i33 = ">") {
        const s2 = (function(t3, e34, n12 = ">") {
          let i34 = 0;
          const s3 = t3.length, r34 = n12.charCodeAt(0), o12 = n12.length > 1 ? n12.charCodeAt(1) : -1;
          let a34 = "", h34 = e34;
          for (let n13 = e34; n13 < s3; n13++) {
            const e35 = t3.charCodeAt(n13);
            if (i34) e35 === i34 && (i34 = 0);
            else if (34 === e35 || 39 === e35) i34 = e35;
            else if (e35 === r34) {
              if (-1 === o12) return a34 += t3.substring(h34, n13), { data: a34, index: n13 };
              if (t3.charCodeAt(n13 + 1) === o12) return a34 += t3.substring(h34, n13), { data: a34, index: n13 };
            } else 9 !== e35 || i34 || (a34 += t3.substring(h34, n13) + " ", h34 = n13 + 1);
          }
        })(t2, e33 + 1, i33);
        if (!s2) return;
        let r33 = s2.data;
        const o11 = s2.index, a33 = r33.search(/\s/);
        let h33 = r33, l21 = true;
        -1 !== a33 && (h33 = r33.substring(0, a33), r33 = r33.substring(a33 + 1).trimStart());
        const u2 = h33;
        if (n11) {
          const t3 = h33.indexOf(":");
          -1 !== t3 && (h33 = h33.substr(t3 + 1), l21 = h33 !== s2.data.substr(t3 + 1));
        }
        return { tagName: h33, tagExp: r33, closeIndex: o11, attrExpPresent: l21, rawTagName: u2 };
      }
      __name(gt, "gt");
      function mt(t2, e33, n11) {
        const i33 = n11;
        let s2 = 1;
        const r33 = t2.length;
        for (; n11 < r33; n11++) if ("<" === t2[n11]) {
          const r34 = t2.charCodeAt(n11 + 1);
          if (47 === r34) {
            const r35 = ft(t2, ">", n11, `${e33} is not closed`);
            if (t2.substring(n11 + 2, r35).trim() === e33 && (s2--, 0 === s2)) return { tagContent: t2.substring(i33, n11), i: r35 };
            n11 = r35;
          } else if (63 === r34) n11 = dt(t2, "?>", n11 + 1, "StopNode is not closed.");
          else if (33 === r34 && 45 === t2.charCodeAt(n11 + 2) && 45 === t2.charCodeAt(n11 + 3)) n11 = dt(t2, "-->", n11 + 3, "StopNode is not closed.");
          else if (33 === r34 && 91 === t2.charCodeAt(n11 + 2)) n11 = dt(t2, "]]>", n11, "StopNode is not closed.") - 2;
          else {
            const i34 = gt(t2, n11, ">");
            i34 && ((i34 && i34.tagName) === e33 && "/" !== i34.tagExp[i34.tagExp.length - 1] && s2++, n11 = i34.closeIndex);
          }
        }
      }
      __name(mt, "mt");
      function xt(t2, e33, n11) {
        if (e33 && "string" == typeof t2) {
          const e34 = t2.trim();
          return "true" === e34 || "false" !== e34 && (function(t3, e35 = {}) {
            if (e35 = Object.assign({}, L, e35), !t3 || "string" != typeof t3) return t3;
            let n12 = t3.trim();
            if (0 === n12.length) return t3;
            if (void 0 !== e35.skipLike && e35.skipLike.test(n12)) return t3;
            if ("0" === n12) return 0;
            if (e35.hex && j32.test(n12)) return (function(t4) {
              if (parseInt) return parseInt(t4, 16);
              if (Number.parseInt) return Number.parseInt(t4, 16);
              if (window && window.parseInt) return window.parseInt(t4, 16);
              throw new Error("parseInt, Number.parseInt, window.parseInt are not supported");
            })(n12);
            if (isFinite(n12)) {
              if (n12.includes("e") || n12.includes("E")) return (function(t4, e36, n13) {
                if (!n13.eNotation) return t4;
                const i34 = e36.match(k32);
                if (i34) {
                  let s2 = i34[1] || "";
                  const r33 = -1 === i34[3].indexOf("e") ? "E" : "e", o11 = i34[2], a33 = s2 ? t4[o11.length + 1] === r33 : t4[o11.length] === r33;
                  return o11.length > 1 && a33 ? t4 : (1 !== o11.length || !i34[3].startsWith(`.${r33}`) && i34[3][0] !== r33) && o11.length > 0 ? n13.leadingZeros && !a33 ? (e36 = (i34[1] || "") + i34[3], Number(e36)) : t4 : Number(e36);
                }
                return t4;
              })(t3, n12, e35);
              {
                const s2 = V.exec(n12);
                if (s2) {
                  const r33 = s2[1] || "", o11 = s2[2];
                  let a33 = (i33 = s2[3]) && -1 !== i33.indexOf(".") ? ("." === (i33 = i33.replace(/0+$/, "")) ? i33 = "0" : "." === i33[0] ? i33 = "0" + i33 : "." === i33[i33.length - 1] && (i33 = i33.substring(0, i33.length - 1)), i33) : i33;
                  const h33 = r33 ? "." === t3[o11.length + 1] : "." === t3[o11.length];
                  if (!e35.leadingZeros && (o11.length > 1 || 1 === o11.length && !h33)) return t3;
                  {
                    const i34 = Number(n12), s3 = String(i34);
                    if (0 === i34) return i34;
                    if (-1 !== s3.search(/[eE]/)) return e35.eNotation ? i34 : t3;
                    if (-1 !== n12.indexOf(".")) return "0" === s3 || s3 === a33 || s3 === `${r33}${a33}` ? i34 : t3;
                    let h34 = o11 ? a33 : n12;
                    return o11 ? h34 === s3 || r33 + h34 === s3 ? i34 : t3 : h34 === s3 || h34 === r33 + s3 ? i34 : t3;
                  }
                }
                return t3;
              }
            }
            var i33;
            return (function(t4, e36, n13) {
              const i34 = e36 === 1 / 0;
              switch (n13.infinity.toLowerCase()) {
                case "null":
                  return null;
                case "infinity":
                  return e36;
                case "string":
                  return i34 ? "Infinity" : "-Infinity";
                default:
                  return t4;
              }
            })(t3, Number(n12), e35);
          })(t2, n11);
        }
        return void 0 !== t2 ? t2 : "";
      }
      __name(xt, "xt");
      function Nt(t2, e33, n11, i33) {
        if (t2) {
          const i34 = t2(e33);
          n11 === e33 && (n11 = i34), e33 = i34;
        }
        return { tagName: e33 = bt(e33, i33), tagExp: n11 };
      }
      __name(Nt, "Nt");
      function bt(t2, e33) {
        if (a32.includes(t2)) throw new Error(`[SECURITY] Invalid name: "${t2}" is a reserved JavaScript keyword that could cause prototype pollution`);
        return o10.includes(t2) ? e33.onDangerousProperty(t2) : t2;
      }
      __name(bt, "bt");
      const yt = O.getMetaDataSymbol();
      function Et(t2, e33) {
        if (!t2 || "object" != typeof t2) return {};
        if (!e33) return t2;
        const n11 = {};
        for (const i33 in t2) i33.startsWith(e33) ? n11[i33.substring(e33.length)] = t2[i33] : n11[i33] = t2[i33];
        return n11;
      }
      __name(Et, "Et");
      function wt(t2, e33, n11, i33) {
        return vt(t2, e33, n11, i33);
      }
      __name(wt, "wt");
      function vt(t2, e33, n11, i33) {
        let s2;
        const r33 = {};
        for (let o11 = 0; o11 < t2.length; o11++) {
          const a33 = t2[o11], h33 = St(a33);
          if (void 0 !== h33 && h33 !== e33.textNodeName) {
            const t3 = Et(a33[":@"] || {}, e33.attributeNamePrefix);
            n11.push(h33, t3);
          }
          if (h33 === e33.textNodeName) void 0 === s2 ? s2 = a33[h33] : s2 += "" + a33[h33];
          else {
            if (void 0 === h33) continue;
            if (a33[h33]) {
              let t3 = vt(a33[h33], e33, n11, i33);
              const s3 = At(t3, e33);
              if (a33[":@"] ? _t(t3, a33[":@"], i33, e33) : 1 !== Object.keys(t3).length || void 0 === t3[e33.textNodeName] || e33.alwaysCreateTextNode ? 0 === Object.keys(t3).length && (e33.alwaysCreateTextNode ? t3[e33.textNodeName] = "" : t3 = "") : t3 = t3[e33.textNodeName], void 0 !== a33[yt] && "object" == typeof t3 && null !== t3 && (t3[yt] = a33[yt]), void 0 !== r33[h33] && Object.prototype.hasOwnProperty.call(r33, h33)) Array.isArray(r33[h33]) || (r33[h33] = [r33[h33]]), r33[h33].push(t3);
              else {
                const n12 = e33.jPath ? i33.toString() : i33;
                e33.isArray(h33, n12, s3) ? r33[h33] = [t3] : r33[h33] = t3;
              }
              void 0 !== h33 && h33 !== e33.textNodeName && n11.pop();
            }
          }
        }
        return "string" == typeof s2 ? s2.length > 0 && (r33[e33.textNodeName] = s2) : void 0 !== s2 && (r33[e33.textNodeName] = s2), r33;
      }
      __name(vt, "vt");
      function St(t2) {
        const e33 = Object.keys(t2);
        for (let t3 = 0; t3 < e33.length; t3++) {
          const n11 = e33[t3];
          if (":@" !== n11) return n11;
        }
      }
      __name(St, "St");
      function _t(t2, e33, n11, i33) {
        if (e33) {
          const s2 = Object.keys(e33), r33 = s2.length;
          for (let o11 = 0; o11 < r33; o11++) {
            const r34 = s2[o11], a33 = r34.startsWith(i33.attributeNamePrefix) ? r34.substring(i33.attributeNamePrefix.length) : r34, h33 = i33.jPath ? n11.toString() + "." + a33 : n11;
            i33.isArray(r34, h33, true, true) ? t2[r34] = [e33[r34]] : t2[r34] = e33[r34];
          }
        }
      }
      __name(_t, "_t");
      function At(t2, e33) {
        const { textNodeName: n11 } = e33, i33 = Object.keys(t2).length;
        return 0 === i33 || !(1 !== i33 || !t2[n11] && "boolean" != typeof t2[n11] && 0 !== t2[n11]);
      }
      __name(At, "At");
      class Tt {
        static {
          __name(this, "Tt");
        }
        constructor(t2) {
          this.externalEntities = {}, this.options = C(t2);
        }
        parse(t2, e33) {
          if ("string" != typeof t2 && t2.toString) t2 = t2.toString();
          else if ("string" != typeof t2) throw new Error("XML data is accepted in String or Bytes[] form.");
          if (e33) {
            true === e33 && (e33 = {});
            const n12 = l20(t2, e33);
            if (true !== n12) throw Error(`${n12.err.msg}:${n12.err.line}:${n12.err.col}`);
          }
          const n11 = new it(this.options, this.externalEntities), i33 = n11.parseXml(t2);
          return this.options.preserveOrder || void 0 === i33 ? i33 : wt(i33, this.options, n11.matcher, n11.readonlyMatcher);
        }
        addEntity(t2, e33) {
          if (-1 !== e33.indexOf("&")) throw new Error("Entity value can't have '&'");
          if (-1 !== t2.indexOf("&") || -1 !== t2.indexOf(";")) throw new Error("An entity must be set without '&' and ';'. Eg. use '#xD' for '&#xD;'");
          if ("&" === e33) throw new Error("An entity with value '&' is not permitted");
          this.externalEntities[t2] = e33;
        }
        static getMetaDataSymbol() {
          return O.getMetaDataSymbol();
        }
      }
      function Ct(t2, e33) {
        let n11 = "";
        e33.format && e33.indentBy.length > 0 && (n11 = "\n");
        const i33 = [];
        if (e33.stopNodes && Array.isArray(e33.stopNodes)) for (let t3 = 0; t3 < e33.stopNodes.length; t3++) {
          const n12 = e33.stopNodes[t3];
          "string" == typeof n12 ? i33.push(new G(n12)) : n12 instanceof G && i33.push(n12);
        }
        return Pt(t2, e33, n11, new R(), i33);
      }
      __name(Ct, "Ct");
      function Pt(t2, e33, n11, i33, s2) {
        let r33 = "", o11 = false;
        if (e33.maxNestedTags && i33.getDepth() > e33.maxNestedTags) throw new Error("Maximum nested tags exceeded");
        if (!Array.isArray(t2)) {
          if (null != t2) {
            let n12 = t2.toString();
            return n12 = Vt(n12, e33), n12;
          }
          return "";
        }
        for (let a33 = 0; a33 < t2.length; a33++) {
          const h33 = t2[a33], l21 = Dt(h33);
          if (void 0 === l21) continue;
          const u2 = Ot(h33[":@"], e33);
          i33.push(l21, u2);
          const p11 = jt(i33, s2);
          if (l21 === e33.textNodeName) {
            let t3 = h33[l21];
            p11 || (t3 = e33.tagValueProcessor(l21, t3), t3 = Vt(t3, e33)), o11 && (r33 += n11), r33 += t3, o11 = false, i33.pop();
            continue;
          }
          if (l21 === e33.cdataPropName) {
            o11 && (r33 += n11);
            const t3 = h33[l21][0][e33.textNodeName];
            r33 += `<![CDATA[${String(t3).replace(/\]\]>/g, "]]]]><![CDATA[>")}]]>`, o11 = false, i33.pop();
            continue;
          }
          if (l21 === e33.commentPropName) {
            const t3 = h33[l21][0][e33.textNodeName];
            r33 += n11 + `<!--${String(t3).replace(/--/g, "- -").replace(/-$/, "- ")}-->`, o11 = true, i33.pop();
            continue;
          }
          if ("?" === l21[0]) {
            const t3 = Mt(h33[":@"], e33, p11), s3 = "?xml" === l21 ? "" : n11;
            let a34 = h33[l21][0][e33.textNodeName];
            a34 = 0 !== a34.length ? " " + a34 : "", r33 += s3 + `<${l21}${a34}${t3}?>`, o11 = true, i33.pop();
            continue;
          }
          let c33 = n11;
          "" !== c33 && (c33 += e33.indentBy);
          const d33 = n11 + `<${l21}${Mt(h33[":@"], e33, p11)}`;
          let f33;
          f33 = p11 ? $t(h33[l21], e33) : Pt(h33[l21], e33, c33, i33, s2), -1 !== e33.unpairedTags.indexOf(l21) ? e33.suppressUnpairedNode ? r33 += d33 + ">" : r33 += d33 + "/>" : f33 && 0 !== f33.length || !e33.suppressEmptyNode ? f33 && f33.endsWith(">") ? r33 += d33 + `>${f33}${n11}</${l21}>` : (r33 += d33 + ">", f33 && "" !== n11 && (f33.includes("/>") || f33.includes("</")) ? r33 += n11 + e33.indentBy + f33 + n11 : r33 += f33, r33 += `</${l21}>`) : r33 += d33 + "/>", o11 = true, i33.pop();
        }
        return r33;
      }
      __name(Pt, "Pt");
      function Ot(t2, e33) {
        if (!t2 || e33.ignoreAttributes) return null;
        const n11 = {};
        let i33 = false;
        for (let s2 in t2) Object.prototype.hasOwnProperty.call(t2, s2) && (n11[s2.startsWith(e33.attributeNamePrefix) ? s2.substr(e33.attributeNamePrefix.length) : s2] = t2[s2], i33 = true);
        return i33 ? n11 : null;
      }
      __name(Ot, "Ot");
      function $t(t2, e33) {
        if (!Array.isArray(t2)) return null != t2 ? t2.toString() : "";
        let n11 = "";
        for (let i33 = 0; i33 < t2.length; i33++) {
          const s2 = t2[i33], r33 = Dt(s2);
          if (r33 === e33.textNodeName) n11 += s2[r33];
          else if (r33 === e33.cdataPropName) n11 += s2[r33][0][e33.textNodeName];
          else if (r33 === e33.commentPropName) n11 += s2[r33][0][e33.textNodeName];
          else {
            if (r33 && "?" === r33[0]) continue;
            if (r33) {
              const t3 = It(s2[":@"], e33), i34 = $t(s2[r33], e33);
              i34 && 0 !== i34.length ? n11 += `<${r33}${t3}>${i34}</${r33}>` : n11 += `<${r33}${t3}/>`;
            }
          }
        }
        return n11;
      }
      __name($t, "$t");
      function It(t2, e33) {
        let n11 = "";
        if (t2 && !e33.ignoreAttributes) for (let i33 in t2) {
          if (!Object.prototype.hasOwnProperty.call(t2, i33)) continue;
          let s2 = t2[i33];
          true === s2 && e33.suppressBooleanAttributes ? n11 += ` ${i33.substr(e33.attributeNamePrefix.length)}` : n11 += ` ${i33.substr(e33.attributeNamePrefix.length)}="${s2}"`;
        }
        return n11;
      }
      __name(It, "It");
      function Dt(t2) {
        const e33 = Object.keys(t2);
        for (let n11 = 0; n11 < e33.length; n11++) {
          const i33 = e33[n11];
          if (Object.prototype.hasOwnProperty.call(t2, i33) && ":@" !== i33) return i33;
        }
      }
      __name(Dt, "Dt");
      function Mt(t2, e33, n11) {
        let i33 = "";
        if (t2 && !e33.ignoreAttributes) for (let s2 in t2) {
          if (!Object.prototype.hasOwnProperty.call(t2, s2)) continue;
          let r33;
          n11 ? r33 = t2[s2] : (r33 = e33.attributeValueProcessor(s2, t2[s2]), r33 = Vt(r33, e33)), true === r33 && e33.suppressBooleanAttributes ? i33 += ` ${s2.substr(e33.attributeNamePrefix.length)}` : i33 += ` ${s2.substr(e33.attributeNamePrefix.length)}="${r33}"`;
        }
        return i33;
      }
      __name(Mt, "Mt");
      function jt(t2, e33) {
        if (!e33 || 0 === e33.length) return false;
        for (let n11 = 0; n11 < e33.length; n11++) if (t2.matches(e33[n11])) return true;
        return false;
      }
      __name(jt, "jt");
      function Vt(t2, e33) {
        if (t2 && t2.length > 0 && e33.processEntities) for (let n11 = 0; n11 < e33.entities.length; n11++) {
          const i33 = e33.entities[n11];
          t2 = t2.replace(i33.regex, i33.val);
        }
        return t2;
      }
      __name(Vt, "Vt");
      const Lt = { attributeNamePrefix: "@_", attributesGroupName: false, textNodeName: "#text", ignoreAttributes: true, cdataPropName: false, format: false, indentBy: "  ", suppressEmptyNode: false, suppressUnpairedNode: true, suppressBooleanAttributes: true, tagValueProcessor: /* @__PURE__ */ __name(function(t2, e33) {
        return e33;
      }, "tagValueProcessor"), attributeValueProcessor: /* @__PURE__ */ __name(function(t2, e33) {
        return e33;
      }, "attributeValueProcessor"), preserveOrder: false, commentPropName: false, unpairedTags: [], entities: [{ regex: new RegExp("&", "g"), val: "&amp;" }, { regex: new RegExp(">", "g"), val: "&gt;" }, { regex: new RegExp("<", "g"), val: "&lt;" }, { regex: new RegExp("'", "g"), val: "&apos;" }, { regex: new RegExp('"', "g"), val: "&quot;" }], processEntities: true, stopNodes: [], oneListGroup: false, maxNestedTags: 100, jPath: true };
      function kt(t2) {
        if (this.options = Object.assign({}, Lt, t2), this.options.stopNodes && Array.isArray(this.options.stopNodes) && (this.options.stopNodes = this.options.stopNodes.map((t3) => "string" == typeof t3 && t3.startsWith("*.") ? ".." + t3.substring(2) : t3)), this.stopNodeExpressions = [], this.options.stopNodes && Array.isArray(this.options.stopNodes)) for (let t3 = 0; t3 < this.options.stopNodes.length; t3++) {
          const e34 = this.options.stopNodes[t3];
          "string" == typeof e34 ? this.stopNodeExpressions.push(new G(e34)) : e34 instanceof G && this.stopNodeExpressions.push(e34);
        }
        var e33;
        true === this.options.ignoreAttributes || this.options.attributesGroupName ? this.isAttribute = function() {
          return false;
        } : (this.ignoreAttributesFn = "function" == typeof (e33 = this.options.ignoreAttributes) ? e33 : Array.isArray(e33) ? (t3) => {
          for (const n11 of e33) {
            if ("string" == typeof n11 && t3 === n11) return true;
            if (n11 instanceof RegExp && n11.test(t3)) return true;
          }
        } : () => false, this.attrPrefixLen = this.options.attributeNamePrefix.length, this.isAttribute = Gt), this.processTextOrObjNode = Ft, this.options.format ? (this.indentate = Rt, this.tagEndChar = ">\n", this.newLine = "\n") : (this.indentate = function() {
          return "";
        }, this.tagEndChar = ">", this.newLine = "");
      }
      __name(kt, "kt");
      function Ft(t2, e33, n11, i33) {
        const s2 = this.extractAttributes(t2);
        if (i33.push(e33, s2), this.checkStopNode(i33)) {
          const s3 = this.buildRawContent(t2), r34 = this.buildAttributesForStopNode(t2);
          return i33.pop(), this.buildObjectNode(s3, e33, r34, n11);
        }
        const r33 = this.j2x(t2, n11 + 1, i33);
        return i33.pop(), void 0 !== t2[this.options.textNodeName] && 1 === Object.keys(t2).length ? this.buildTextValNode(t2[this.options.textNodeName], e33, r33.attrStr, n11, i33) : this.buildObjectNode(r33.val, e33, r33.attrStr, n11);
      }
      __name(Ft, "Ft");
      function Rt(t2) {
        return this.options.indentBy.repeat(t2);
      }
      __name(Rt, "Rt");
      function Gt(t2) {
        return !(!t2.startsWith(this.options.attributeNamePrefix) || t2 === this.options.textNodeName) && t2.substr(this.attrPrefixLen);
      }
      __name(Gt, "Gt");
      kt.prototype.build = function(t2) {
        if (this.options.preserveOrder) return Ct(t2, this.options);
        {
          Array.isArray(t2) && this.options.arrayNodeName && this.options.arrayNodeName.length > 1 && (t2 = { [this.options.arrayNodeName]: t2 });
          const e33 = new R();
          return this.j2x(t2, 0, e33).val;
        }
      }, kt.prototype.j2x = function(t2, e33, n11) {
        let i33 = "", s2 = "";
        if (this.options.maxNestedTags && n11.getDepth() >= this.options.maxNestedTags) throw new Error("Maximum nested tags exceeded");
        const r33 = this.options.jPath ? n11.toString() : n11, o11 = this.checkStopNode(n11);
        for (let a33 in t2) if (Object.prototype.hasOwnProperty.call(t2, a33)) if (void 0 === t2[a33]) this.isAttribute(a33) && (s2 += "");
        else if (null === t2[a33]) this.isAttribute(a33) || a33 === this.options.cdataPropName ? s2 += "" : "?" === a33[0] ? s2 += this.indentate(e33) + "<" + a33 + "?" + this.tagEndChar : s2 += this.indentate(e33) + "<" + a33 + "/" + this.tagEndChar;
        else if (t2[a33] instanceof Date) s2 += this.buildTextValNode(t2[a33], a33, "", e33, n11);
        else if ("object" != typeof t2[a33]) {
          const h33 = this.isAttribute(a33);
          if (h33 && !this.ignoreAttributesFn(h33, r33)) i33 += this.buildAttrPairStr(h33, "" + t2[a33], o11);
          else if (!h33) if (a33 === this.options.textNodeName) {
            let e34 = this.options.tagValueProcessor(a33, "" + t2[a33]);
            s2 += this.replaceEntitiesValue(e34);
          } else {
            n11.push(a33);
            const i34 = this.checkStopNode(n11);
            if (n11.pop(), i34) {
              const n12 = "" + t2[a33];
              s2 += "" === n12 ? this.indentate(e33) + "<" + a33 + this.closeTag(a33) + this.tagEndChar : this.indentate(e33) + "<" + a33 + ">" + n12 + "</" + a33 + this.tagEndChar;
            } else s2 += this.buildTextValNode(t2[a33], a33, "", e33, n11);
          }
        } else if (Array.isArray(t2[a33])) {
          const i34 = t2[a33].length;
          let r34 = "", o12 = "";
          for (let h33 = 0; h33 < i34; h33++) {
            const i35 = t2[a33][h33];
            if (void 0 === i35) ;
            else if (null === i35) "?" === a33[0] ? s2 += this.indentate(e33) + "<" + a33 + "?" + this.tagEndChar : s2 += this.indentate(e33) + "<" + a33 + "/" + this.tagEndChar;
            else if ("object" == typeof i35) if (this.options.oneListGroup) {
              n11.push(a33);
              const t3 = this.j2x(i35, e33 + 1, n11);
              n11.pop(), r34 += t3.val, this.options.attributesGroupName && i35.hasOwnProperty(this.options.attributesGroupName) && (o12 += t3.attrStr);
            } else r34 += this.processTextOrObjNode(i35, a33, e33, n11);
            else if (this.options.oneListGroup) {
              let t3 = this.options.tagValueProcessor(a33, i35);
              t3 = this.replaceEntitiesValue(t3), r34 += t3;
            } else {
              n11.push(a33);
              const t3 = this.checkStopNode(n11);
              if (n11.pop(), t3) {
                const t4 = "" + i35;
                r34 += "" === t4 ? this.indentate(e33) + "<" + a33 + this.closeTag(a33) + this.tagEndChar : this.indentate(e33) + "<" + a33 + ">" + t4 + "</" + a33 + this.tagEndChar;
              } else r34 += this.buildTextValNode(i35, a33, "", e33, n11);
            }
          }
          this.options.oneListGroup && (r34 = this.buildObjectNode(r34, a33, o12, e33)), s2 += r34;
        } else if (this.options.attributesGroupName && a33 === this.options.attributesGroupName) {
          const e34 = Object.keys(t2[a33]), n12 = e34.length;
          for (let s3 = 0; s3 < n12; s3++) i33 += this.buildAttrPairStr(e34[s3], "" + t2[a33][e34[s3]], o11);
        } else s2 += this.processTextOrObjNode(t2[a33], a33, e33, n11);
        return { attrStr: i33, val: s2 };
      }, kt.prototype.buildAttrPairStr = function(t2, e33, n11) {
        return n11 || (e33 = this.options.attributeValueProcessor(t2, "" + e33), e33 = this.replaceEntitiesValue(e33)), this.options.suppressBooleanAttributes && "true" === e33 ? " " + t2 : " " + t2 + '="' + e33 + '"';
      }, kt.prototype.extractAttributes = function(t2) {
        if (!t2 || "object" != typeof t2) return null;
        const e33 = {};
        let n11 = false;
        if (this.options.attributesGroupName && t2[this.options.attributesGroupName]) {
          const i33 = t2[this.options.attributesGroupName];
          for (let t3 in i33) Object.prototype.hasOwnProperty.call(i33, t3) && (e33[t3.startsWith(this.options.attributeNamePrefix) ? t3.substring(this.options.attributeNamePrefix.length) : t3] = i33[t3], n11 = true);
        } else for (let i33 in t2) {
          if (!Object.prototype.hasOwnProperty.call(t2, i33)) continue;
          const s2 = this.isAttribute(i33);
          s2 && (e33[s2] = t2[i33], n11 = true);
        }
        return n11 ? e33 : null;
      }, kt.prototype.buildRawContent = function(t2) {
        if ("string" == typeof t2) return t2;
        if ("object" != typeof t2 || null === t2) return String(t2);
        if (void 0 !== t2[this.options.textNodeName]) return t2[this.options.textNodeName];
        let e33 = "";
        for (let n11 in t2) {
          if (!Object.prototype.hasOwnProperty.call(t2, n11)) continue;
          if (this.isAttribute(n11)) continue;
          if (this.options.attributesGroupName && n11 === this.options.attributesGroupName) continue;
          const i33 = t2[n11];
          if (n11 === this.options.textNodeName) e33 += i33;
          else if (Array.isArray(i33)) {
            for (let t3 of i33) if ("string" == typeof t3 || "number" == typeof t3) e33 += `<${n11}>${t3}</${n11}>`;
            else if ("object" == typeof t3 && null !== t3) {
              const i34 = this.buildRawContent(t3), s2 = this.buildAttributesForStopNode(t3);
              e33 += "" === i34 ? `<${n11}${s2}/>` : `<${n11}${s2}>${i34}</${n11}>`;
            }
          } else if ("object" == typeof i33 && null !== i33) {
            const t3 = this.buildRawContent(i33), s2 = this.buildAttributesForStopNode(i33);
            e33 += "" === t3 ? `<${n11}${s2}/>` : `<${n11}${s2}>${t3}</${n11}>`;
          } else e33 += `<${n11}>${i33}</${n11}>`;
        }
        return e33;
      }, kt.prototype.buildAttributesForStopNode = function(t2) {
        if (!t2 || "object" != typeof t2) return "";
        let e33 = "";
        if (this.options.attributesGroupName && t2[this.options.attributesGroupName]) {
          const n11 = t2[this.options.attributesGroupName];
          for (let t3 in n11) {
            if (!Object.prototype.hasOwnProperty.call(n11, t3)) continue;
            const i33 = t3.startsWith(this.options.attributeNamePrefix) ? t3.substring(this.options.attributeNamePrefix.length) : t3, s2 = n11[t3];
            true === s2 && this.options.suppressBooleanAttributes ? e33 += " " + i33 : e33 += " " + i33 + '="' + s2 + '"';
          }
        } else for (let n11 in t2) {
          if (!Object.prototype.hasOwnProperty.call(t2, n11)) continue;
          const i33 = this.isAttribute(n11);
          if (i33) {
            const s2 = t2[n11];
            true === s2 && this.options.suppressBooleanAttributes ? e33 += " " + i33 : e33 += " " + i33 + '="' + s2 + '"';
          }
        }
        return e33;
      }, kt.prototype.buildObjectNode = function(t2, e33, n11, i33) {
        if ("" === t2) return "?" === e33[0] ? this.indentate(i33) + "<" + e33 + n11 + "?" + this.tagEndChar : this.indentate(i33) + "<" + e33 + n11 + this.closeTag(e33) + this.tagEndChar;
        {
          let s2 = "</" + e33 + this.tagEndChar, r33 = "";
          return "?" === e33[0] && (r33 = "?", s2 = ""), !n11 && "" !== n11 || -1 !== t2.indexOf("<") ? false !== this.options.commentPropName && e33 === this.options.commentPropName && 0 === r33.length ? this.indentate(i33) + `<!--${t2}-->` + this.newLine : this.indentate(i33) + "<" + e33 + n11 + r33 + this.tagEndChar + t2 + this.indentate(i33) + s2 : this.indentate(i33) + "<" + e33 + n11 + r33 + ">" + t2 + s2;
        }
      }, kt.prototype.closeTag = function(t2) {
        let e33 = "";
        return -1 !== this.options.unpairedTags.indexOf(t2) ? this.options.suppressUnpairedNode || (e33 = "/") : e33 = this.options.suppressEmptyNode ? "/" : `></${t2}`, e33;
      }, kt.prototype.checkStopNode = function(t2) {
        if (!this.stopNodeExpressions || 0 === this.stopNodeExpressions.length) return false;
        for (let e33 = 0; e33 < this.stopNodeExpressions.length; e33++) if (t2.matches(this.stopNodeExpressions[e33])) return true;
        return false;
      }, kt.prototype.buildTextValNode = function(t2, e33, n11, i33, s2) {
        if (false !== this.options.cdataPropName && e33 === this.options.cdataPropName) {
          const e34 = String(t2).replace(/\]\]>/g, "]]]]><![CDATA[>");
          return this.indentate(i33) + `<![CDATA[${e34}]]>` + this.newLine;
        }
        if (false !== this.options.commentPropName && e33 === this.options.commentPropName) {
          const e34 = String(t2).replace(/--/g, "- -").replace(/-$/, "- ");
          return this.indentate(i33) + `<!--${e34}-->` + this.newLine;
        }
        if ("?" === e33[0]) return this.indentate(i33) + "<" + e33 + n11 + "?" + this.tagEndChar;
        {
          let s3 = this.options.tagValueProcessor(e33, t2);
          return s3 = this.replaceEntitiesValue(s3), "" === s3 ? this.indentate(i33) + "<" + e33 + n11 + this.closeTag(e33) + this.tagEndChar : this.indentate(i33) + "<" + e33 + n11 + ">" + s3 + "</" + e33 + this.tagEndChar;
        }
      }, kt.prototype.replaceEntitiesValue = function(t2) {
        if (t2 && t2.length > 0 && this.options.processEntities) for (let e33 = 0; e33 < this.options.entities.length; e33++) {
          const n11 = this.options.entities[e33];
          t2 = t2.replace(n11.regex, n11.val);
        }
        return t2;
      };
      const Bt = kt, Ut = { validate: l20 };
      module2.exports = e32;
    })();
  }
});

// ../../node_modules/@aws-sdk/xml-builder/dist-cjs/xml-external/nodable_entities.js
var require_nodable_entities = __commonJS({
  "../../node_modules/@aws-sdk/xml-builder/dist-cjs/xml-external/nodable_entities.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.EntityDecoderImpl = exports2.CURRENCY = exports2.COMMON_HTML = exports2.XML = void 0;
    exports2.XML = {
      amp: "&",
      apos: "'",
      gt: ">",
      lt: "<",
      quot: '"'
    };
    exports2.COMMON_HTML = {
      nbsp: "\xA0",
      copy: "\xA9",
      reg: "\xAE",
      trade: "\u2122",
      mdash: "\u2014",
      ndash: "\u2013",
      hellip: "\u2026",
      laquo: "\xAB",
      raquo: "\xBB",
      lsquo: "\u2018",
      rsquo: "\u2019",
      ldquo: "\u201C",
      rdquo: "\u201D",
      bull: "\u2022",
      para: "\xB6",
      sect: "\xA7",
      deg: "\xB0",
      frac12: "\xBD",
      frac14: "\xBC",
      frac34: "\xBE"
    };
    exports2.CURRENCY = {
      cent: "\xA2",
      pound: "\xA3",
      curren: "\xA4",
      yen: "\xA5",
      euro: "\u20AC",
      dollar: "$",
      fnof: "\u0192",
      inr: "\u20B9",
      af: "\u060B",
      birr: "\u1265\u122D",
      peso: "\u20B1",
      rub: "\u20BD",
      won: "\u20A9",
      yuan: "\xA5",
      cedil: "\xB8"
    };
    var SPECIAL_CHARS = new Set("!?\\/[]$%{}^&*()<>|+");
    function validateEntityName(name) {
      if (name[0] === "#") {
        throw new Error(`[EntityReplacer] Invalid character '#' in entity name: "${name}"`);
      }
      for (const ch of name) {
        if (SPECIAL_CHARS.has(ch)) {
          throw new Error(`[EntityReplacer] Invalid character '${ch}' in entity name: "${name}"`);
        }
      }
      return name;
    }
    __name(validateEntityName, "validateEntityName");
    function mergeEntityMaps(...maps) {
      const out = /* @__PURE__ */ Object.create(null);
      for (const map5 of maps) {
        if (!map5) {
          continue;
        }
        for (const key of Object.keys(map5)) {
          const raw = map5[key];
          if (typeof raw === "string") {
            out[key] = raw;
          } else if (raw && typeof raw === "object" && raw.val !== void 0) {
            const val = raw.val;
            if (typeof val === "string") {
              out[key] = val;
            }
          }
        }
      }
      return out;
    }
    __name(mergeEntityMaps, "mergeEntityMaps");
    var LIMIT_TIER_EXTERNAL = "external";
    var LIMIT_TIER_BASE = "base";
    var LIMIT_TIER_ALL = "all";
    function parseLimitTiers(raw) {
      if (!raw || raw === LIMIT_TIER_EXTERNAL) {
        return /* @__PURE__ */ new Set([LIMIT_TIER_EXTERNAL]);
      }
      if (raw === LIMIT_TIER_ALL) {
        return /* @__PURE__ */ new Set([LIMIT_TIER_ALL]);
      }
      if (raw === LIMIT_TIER_BASE) {
        return /* @__PURE__ */ new Set([LIMIT_TIER_BASE]);
      }
      if (Array.isArray(raw)) {
        return new Set(raw);
      }
      return /* @__PURE__ */ new Set([LIMIT_TIER_EXTERNAL]);
    }
    __name(parseLimitTiers, "parseLimitTiers");
    var NCR_LEVEL = Object.freeze({ allow: 0, leave: 1, remove: 2, throw: 3 });
    var XML10_ALLOWED_C0 = /* @__PURE__ */ new Set([9, 10, 13]);
    function parseNCRConfig(ncr) {
      if (!ncr) {
        return { xmlVersion: 1, onLevel: NCR_LEVEL.allow, nullLevel: NCR_LEVEL.remove };
      }
      const xmlVersion = ncr.xmlVersion === 1.1 ? 1.1 : 1;
      const onLevel = NCR_LEVEL[ncr.onNCR ?? "allow"] ?? NCR_LEVEL.allow;
      const nullLevel = NCR_LEVEL[ncr.nullNCR ?? "remove"] ?? NCR_LEVEL.remove;
      const clampedNull = Math.max(nullLevel, NCR_LEVEL.remove);
      return { xmlVersion, onLevel, nullLevel: clampedNull };
    }
    __name(parseNCRConfig, "parseNCRConfig");
    var EntityDecoderImpl = class EntityDecoderImpl {
      static {
        __name(this, "EntityDecoderImpl");
      }
      _limit;
      _maxTotalExpansions;
      _maxExpandedLength;
      _postCheck;
      _limitTiers;
      _numericAllowed;
      _baseMap;
      _externalMap;
      _inputMap;
      _totalExpansions;
      _expandedLength;
      _removeSet;
      _leaveSet;
      _ncrXmlVersion;
      _ncrOnLevel;
      _ncrNullLevel;
      constructor(options = {}) {
        this._limit = options.limit || {};
        this._maxTotalExpansions = this._limit.maxTotalExpansions || 0;
        this._maxExpandedLength = this._limit.maxExpandedLength || 0;
        this._postCheck = typeof options.postCheck === "function" ? options.postCheck : (r32) => r32;
        this._limitTiers = parseLimitTiers(this._limit.applyLimitsTo ?? LIMIT_TIER_EXTERNAL);
        this._numericAllowed = options.numericAllowed ?? true;
        this._baseMap = mergeEntityMaps(exports2.XML, options.namedEntities || null);
        this._externalMap = /* @__PURE__ */ Object.create(null);
        this._inputMap = /* @__PURE__ */ Object.create(null);
        this._totalExpansions = 0;
        this._expandedLength = 0;
        this._removeSet = new Set(options.remove && Array.isArray(options.remove) ? options.remove : []);
        this._leaveSet = new Set(options.leave && Array.isArray(options.leave) ? options.leave : []);
        const ncrCfg = parseNCRConfig(options.ncr);
        this._ncrXmlVersion = ncrCfg.xmlVersion;
        this._ncrOnLevel = ncrCfg.onLevel;
        this._ncrNullLevel = ncrCfg.nullLevel;
      }
      setExternalEntities(map5) {
        if (map5) {
          for (const key of Object.keys(map5)) {
            validateEntityName(key);
          }
        }
        this._externalMap = mergeEntityMaps(map5);
      }
      addExternalEntity(key, value) {
        validateEntityName(key);
        if (typeof value === "string" && value.indexOf("&") === -1) {
          this._externalMap[key] = value;
        }
      }
      addInputEntities(map5) {
        this._totalExpansions = 0;
        this._expandedLength = 0;
        this._inputMap = mergeEntityMaps(map5);
      }
      reset() {
        this._inputMap = /* @__PURE__ */ Object.create(null);
        this._totalExpansions = 0;
        this._expandedLength = 0;
        return this;
      }
      setXmlVersion(version) {
        this._ncrXmlVersion = version === "1.1" || version === 1.1 ? 1.1 : 1;
      }
      decode(str) {
        if (typeof str !== "string" || str.length === 0) {
          return str;
        }
        const original = str;
        const chunks2 = [];
        const len = str.length;
        let last = 0;
        let i32 = 0;
        const limitExpansions = this._maxTotalExpansions > 0;
        const limitLength = this._maxExpandedLength > 0;
        const checkLimits = limitExpansions || limitLength;
        while (i32 < len) {
          if (str.charCodeAt(i32) !== 38) {
            i32++;
            continue;
          }
          let j32 = i32 + 1;
          while (j32 < len && str.charCodeAt(j32) !== 59 && j32 - i32 <= 32) {
            j32++;
          }
          if (j32 >= len || str.charCodeAt(j32) !== 59) {
            i32++;
            continue;
          }
          const token = str.slice(i32 + 1, j32);
          if (token.length === 0) {
            i32++;
            continue;
          }
          let replacement;
          let tier;
          if (this._removeSet.has(token)) {
            replacement = "";
            if (tier === void 0) {
              tier = LIMIT_TIER_EXTERNAL;
            }
          } else if (this._leaveSet.has(token)) {
            i32++;
            continue;
          } else if (token.charCodeAt(0) === 35) {
            const ncrResult = this._resolveNCR(token);
            if (ncrResult === void 0) {
              i32++;
              continue;
            }
            replacement = ncrResult;
            tier = LIMIT_TIER_BASE;
          } else {
            const resolved = this._resolveName(token);
            replacement = resolved?.value;
            tier = resolved?.tier;
          }
          if (replacement === void 0) {
            i32++;
            continue;
          }
          if (i32 > last) {
            chunks2.push(str.slice(last, i32));
          }
          chunks2.push(replacement);
          last = j32 + 1;
          i32 = last;
          if (checkLimits && this._tierCounts(tier)) {
            if (limitExpansions) {
              this._totalExpansions++;
              if (this._totalExpansions > this._maxTotalExpansions) {
                throw new Error(`[EntityReplacer] Entity expansion count limit exceeded: ${this._totalExpansions} > ${this._maxTotalExpansions}`);
              }
            }
            if (limitLength) {
              const delta = replacement.length - (token.length + 2);
              if (delta > 0) {
                this._expandedLength += delta;
                if (this._expandedLength > this._maxExpandedLength) {
                  throw new Error(`[EntityReplacer] Expanded content length limit exceeded: ${this._expandedLength} > ${this._maxExpandedLength}`);
                }
              }
            }
          }
        }
        if (last < len) {
          chunks2.push(str.slice(last));
        }
        const result2 = chunks2.length === 0 ? str : chunks2.join("");
        return this._postCheck(result2, original);
      }
      _tierCounts(tier) {
        if (this._limitTiers.has(LIMIT_TIER_ALL)) {
          return true;
        }
        return this._limitTiers.has(tier);
      }
      _resolveName(name) {
        if (name in this._inputMap) {
          return { value: this._inputMap[name], tier: LIMIT_TIER_EXTERNAL };
        }
        if (name in this._externalMap) {
          return { value: this._externalMap[name], tier: LIMIT_TIER_EXTERNAL };
        }
        if (name in this._baseMap) {
          return { value: this._baseMap[name], tier: LIMIT_TIER_BASE };
        }
        return void 0;
      }
      _classifyNCR(cp) {
        if (cp === 0) {
          return this._ncrNullLevel;
        }
        if (cp >= 55296 && cp <= 57343) {
          return NCR_LEVEL.remove;
        }
        if (this._ncrXmlVersion === 1) {
          if (cp >= 1 && cp <= 31 && !XML10_ALLOWED_C0.has(cp)) {
            return NCR_LEVEL.remove;
          }
        }
        return -1;
      }
      _applyNCRAction(action, token, cp) {
        switch (action) {
          case NCR_LEVEL.allow:
            return String.fromCodePoint(cp);
          case NCR_LEVEL.remove:
            return "";
          case NCR_LEVEL.leave:
            return void 0;
          case NCR_LEVEL.throw:
            throw new Error(`[EntityDecoder] Prohibited numeric character reference &${token}; (U+${cp.toString(16).toUpperCase().padStart(4, "0")})`);
          default:
            return String.fromCodePoint(cp);
        }
      }
      _resolveNCR(token) {
        const second = token.charCodeAt(1);
        let cp;
        if (second === 120 || second === 88) {
          cp = parseInt(token.slice(2), 16);
        } else {
          cp = parseInt(token.slice(1), 10);
        }
        if (Number.isNaN(cp) || cp < 0 || cp > 1114111) {
          return void 0;
        }
        const minimum = this._classifyNCR(cp);
        if (!this._numericAllowed && minimum < NCR_LEVEL.remove) {
          return void 0;
        }
        const effective = minimum === -1 ? this._ncrOnLevel : Math.max(this._ncrOnLevel, minimum);
        return this._applyNCRAction(effective, token, cp);
      }
    };
    exports2.EntityDecoderImpl = EntityDecoderImpl;
  }
});

// ../../node_modules/@aws-sdk/xml-builder/dist-cjs/xml-parser.js
var require_xml_parser = __commonJS({
  "../../node_modules/@aws-sdk/xml-builder/dist-cjs/xml-parser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.parseXML = parseXML20;
    var fast_xml_parser_1 = require_fxp();
    var nodable_entities_1 = require_nodable_entities();
    var entityDecoder = new nodable_entities_1.EntityDecoderImpl({
      namedEntities: { ...nodable_entities_1.XML, ...nodable_entities_1.COMMON_HTML, ...nodable_entities_1.CURRENCY },
      numericAllowed: true,
      limit: {
        maxTotalExpansions: Infinity
      },
      ncr: {
        xmlVersion: 1.1
      }
    });
    var parser = new fast_xml_parser_1.XMLParser({
      attributeNamePrefix: "",
      processEntities: {
        enabled: true,
        maxTotalExpansions: Infinity
      },
      htmlEntities: true,
      entityDecoder: {
        setExternalEntities: /* @__PURE__ */ __name((entities) => {
          entityDecoder.setExternalEntities(entities);
        }, "setExternalEntities"),
        addInputEntities: /* @__PURE__ */ __name((entities) => {
          entityDecoder.addInputEntities(entities);
        }, "addInputEntities"),
        reset: /* @__PURE__ */ __name(() => {
          entityDecoder.reset();
        }, "reset"),
        decode: /* @__PURE__ */ __name((text) => {
          return entityDecoder.decode(text);
        }, "decode"),
        setXmlVersion: /* @__PURE__ */ __name((version) => void {}, "setXmlVersion")
      },
      ignoreAttributes: false,
      ignoreDeclaration: true,
      parseTagValue: false,
      trimValues: false,
      tagValueProcessor: /* @__PURE__ */ __name((_, val) => val.trim() === "" && val.includes("\n") ? "" : void 0, "tagValueProcessor"),
      maxNestedTags: Infinity
    });
    function parseXML20(xmlString) {
      return parser.parse(xmlString, true);
    }
    __name(parseXML20, "parseXML");
  }
});

// ../../node_modules/@aws-sdk/xml-builder/dist-cjs/index.js
var require_dist_cjs47 = __commonJS({
  "../../node_modules/@aws-sdk/xml-builder/dist-cjs/index.js"(exports2) {
    "use strict";
    var xmlParser = require_xml_parser();
    var ATTR_ESCAPE_RE = /[&<>"]/g;
    var ATTR_ESCAPE_MAP = {
      "&": "&amp;",
      "<": "&lt;",
      ">": "&gt;",
      '"': "&quot;"
    };
    function escapeAttribute(value) {
      return value.replace(ATTR_ESCAPE_RE, (ch) => ATTR_ESCAPE_MAP[ch]);
    }
    __name(escapeAttribute, "escapeAttribute");
    var ELEMENT_ESCAPE_RE = /[&"'<>\r\n\u0085\u2028]/g;
    var ELEMENT_ESCAPE_MAP = {
      "&": "&amp;",
      '"': "&quot;",
      "'": "&apos;",
      "<": "&lt;",
      ">": "&gt;",
      "\r": "&#x0D;",
      "\n": "&#x0A;",
      "\x85": "&#x85;",
      "\u2028": "&#x2028;"
    };
    function escapeElement(value) {
      return value.replace(ELEMENT_ESCAPE_RE, (ch) => ELEMENT_ESCAPE_MAP[ch]);
    }
    __name(escapeElement, "escapeElement");
    var XmlText10 = class {
      static {
        __name(this, "XmlText");
      }
      value;
      constructor(value) {
        this.value = value;
      }
      toString() {
        return escapeElement("" + this.value);
      }
    };
    var XmlNode10 = class _XmlNode {
      static {
        __name(this, "XmlNode");
      }
      name;
      children;
      attributes = {};
      static of(name, childText, withName) {
        const node = new _XmlNode(name);
        if (childText !== void 0) {
          node.addChildNode(new XmlText10(childText));
        }
        if (withName !== void 0) {
          node.withName(withName);
        }
        return node;
      }
      constructor(name, children = []) {
        this.name = name;
        this.children = children;
      }
      withName(name) {
        this.name = name;
        return this;
      }
      addAttribute(name, value) {
        this.attributes[name] = value;
        return this;
      }
      addChildNode(child) {
        this.children.push(child);
        return this;
      }
      removeAttribute(name) {
        delete this.attributes[name];
        return this;
      }
      n(name) {
        this.name = name;
        return this;
      }
      c(child) {
        this.children.push(child);
        return this;
      }
      a(name, value) {
        if (value != null) {
          this.attributes[name] = value;
        }
        return this;
      }
      cc(input, field, withName = field) {
        if (input[field] != null) {
          const node = _XmlNode.of(field, input[field]).withName(withName);
          this.c(node);
        }
      }
      l(input, listName, memberName, valueProvider) {
        if (input[listName] != null) {
          const nodes32 = valueProvider();
          nodes32.map((node) => {
            node.withName(memberName);
            this.c(node);
          });
        }
      }
      lc(input, listName, memberName, valueProvider) {
        if (input[listName] != null) {
          const nodes32 = valueProvider();
          const containerNode = new _XmlNode(memberName);
          nodes32.map((node) => {
            containerNode.c(node);
          });
          this.c(containerNode);
        }
      }
      toString() {
        const hasChildren = Boolean(this.children.length);
        let xmlText = `<${this.name}`;
        const attributes = this.attributes;
        for (const attributeName of Object.keys(attributes)) {
          const attribute = attributes[attributeName];
          if (attribute != null) {
            xmlText += ` ${attributeName}="${escapeAttribute("" + attribute)}"`;
          }
        }
        return xmlText += !hasChildren ? "/>" : `>${this.children.map((c32) => c32.toString()).join("")}</${this.name}>`;
      }
    };
    exports2.parseXML = xmlParser.parseXML;
    exports2.XmlNode = XmlNode10;
    exports2.XmlText = XmlText10;
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeDeserializer.js
var init_XmlShapeDeserializer = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeDeserializer.js"() {
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QueryShapeSerializer.js
var init_QueryShapeSerializer = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QueryShapeSerializer.js"() {
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsQueryProtocol.js
var init_AwsQueryProtocol = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsQueryProtocol.js"() {
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsEc2QueryProtocol.js
var init_AwsEc2QueryProtocol = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsEc2QueryProtocol.js"() {
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QuerySerializerSettings.js
var init_QuerySerializerSettings = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QuerySerializerSettings.js"() {
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/parseXmlBody.js
var init_parseXmlBody = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/parseXmlBody.js"() {
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeSerializer.js
var init_XmlShapeSerializer = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeSerializer.js"() {
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlCodec.js
var init_XmlCodec = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlCodec.js"() {
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/AwsRestXmlProtocol.js
var init_AwsRestXmlProtocol = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/AwsRestXmlProtocol.js"() {
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/index.js
var init_protocols3 = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/core/dist-es/submodules/protocols/index.js"() {
    init_AwsSmithyRpcV2CborProtocol();
    init_coercing_serializers();
    init_AwsJson1_0Protocol();
    init_AwsJson1_1Protocol();
    init_AwsJsonRpcProtocol();
    init_AwsRestJsonProtocol();
    init_JsonCodec();
    init_JsonShapeDeserializer();
    init_JsonShapeSerializer();
    init_awsExpectUnion();
    init_parseJsonBody();
    init_AwsEc2QueryProtocol();
    init_AwsQueryProtocol();
    init_QuerySerializerSettings();
    init_QueryShapeSerializer();
    init_AwsRestXmlProtocol();
    init_XmlCodec();
    init_XmlShapeDeserializer();
    init_XmlShapeSerializer();
    init_parseXmlBody();
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/endpoint/bdd.js
var import_util_endpoints, k, a, b, c, d, e, f, g, h, i, j, _data, root, r, nodes, bdd;
var init_bdd = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/endpoint/bdd.js"() {
    import_util_endpoints = __toESM(require_dist_cjs20());
    k = "ref";
    a = -1;
    b = true;
    c = "isSet";
    d = "PartitionResult";
    e = "booleanEquals";
    f = "getAttr";
    g = { [k]: "Endpoint" };
    h = { [k]: d };
    i = {};
    j = [{ [k]: "Region" }];
    _data = {
      conditions: [
        [c, [g]],
        [c, j],
        ["aws.partition", j, d],
        [e, [{ [k]: "UseFIPS" }, b]],
        [e, [{ [k]: "UseDualStack" }, b]],
        [e, [{ fn: f, argv: [h, "supportsDualStack"] }, b]],
        [e, [{ fn: f, argv: [h, "supportsFIPS"] }, b]],
        ["stringEquals", [{ fn: f, argv: [h, "name"] }, "aws-us-gov"]]
      ],
      results: [
        [a],
        [a, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [g, i],
        ["https://oidc-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", i],
        [a, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://oidc.{Region}.amazonaws.com", i],
        ["https://oidc-fips.{Region}.{PartitionResult#dnsSuffix}", i],
        [a, "FIPS is enabled but this partition does not support FIPS"],
        ["https://oidc.{Region}.{PartitionResult#dualStackDnsSuffix}", i],
        [a, "DualStack is enabled but this partition does not support DualStack"],
        ["https://oidc.{Region}.{PartitionResult#dnsSuffix}", i],
        [a, "Invalid Configuration: Missing Region"]
      ]
    };
    root = 2;
    r = 1e8;
    nodes = new Int32Array([
      -1,
      1,
      -1,
      0,
      13,
      3,
      1,
      4,
      r + 12,
      2,
      5,
      r + 12,
      3,
      8,
      6,
      4,
      7,
      r + 11,
      5,
      r + 9,
      r + 10,
      4,
      11,
      9,
      6,
      10,
      r + 8,
      7,
      r + 6,
      r + 7,
      5,
      12,
      r + 5,
      6,
      r + 4,
      r + 5,
      3,
      r + 1,
      14,
      4,
      r + 2,
      r + 3
    ]);
    bdd = import_util_endpoints.BinaryDecisionDiagram.from(nodes, root, _data.conditions, _data.results);
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/endpoint/endpointResolver.js
var import_util_endpoints2, import_util_endpoints3, cache, defaultEndpointResolver;
var init_endpointResolver = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/endpoint/endpointResolver.js"() {
    import_util_endpoints2 = __toESM(require_dist_cjs21());
    import_util_endpoints3 = __toESM(require_dist_cjs20());
    init_bdd();
    cache = new import_util_endpoints3.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    defaultEndpointResolver = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache.get(endpointParams, () => (0, import_util_endpoints3.decideEndpoint)(bdd, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    import_util_endpoints3.customEndpointFunctions.aws = import_util_endpoints2.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/models/SSOOIDCServiceException.js
var import_smithy_client3, SSOOIDCServiceException;
var init_SSOOIDCServiceException = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/models/SSOOIDCServiceException.js"() {
    import_smithy_client3 = __toESM(require_dist_cjs34());
    SSOOIDCServiceException = class _SSOOIDCServiceException extends import_smithy_client3.ServiceException {
      static {
        __name(this, "SSOOIDCServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _SSOOIDCServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/models/errors.js
var AccessDeniedException, AuthorizationPendingException, ExpiredTokenException, InternalServerException, InvalidClientException, InvalidGrantException, InvalidRequestException, InvalidScopeException, SlowDownException, UnauthorizedClientException, UnsupportedGrantTypeException;
var init_errors = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/models/errors.js"() {
    init_SSOOIDCServiceException();
    AccessDeniedException = class _AccessDeniedException extends SSOOIDCServiceException {
      static {
        __name(this, "AccessDeniedException");
      }
      name = "AccessDeniedException";
      $fault = "client";
      error;
      reason;
      error_description;
      constructor(opts) {
        super({
          name: "AccessDeniedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AccessDeniedException.prototype);
        this.error = opts.error;
        this.reason = opts.reason;
        this.error_description = opts.error_description;
      }
    };
    AuthorizationPendingException = class _AuthorizationPendingException extends SSOOIDCServiceException {
      static {
        __name(this, "AuthorizationPendingException");
      }
      name = "AuthorizationPendingException";
      $fault = "client";
      error;
      error_description;
      constructor(opts) {
        super({
          name: "AuthorizationPendingException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AuthorizationPendingException.prototype);
        this.error = opts.error;
        this.error_description = opts.error_description;
      }
    };
    ExpiredTokenException = class _ExpiredTokenException extends SSOOIDCServiceException {
      static {
        __name(this, "ExpiredTokenException");
      }
      name = "ExpiredTokenException";
      $fault = "client";
      error;
      error_description;
      constructor(opts) {
        super({
          name: "ExpiredTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ExpiredTokenException.prototype);
        this.error = opts.error;
        this.error_description = opts.error_description;
      }
    };
    InternalServerException = class _InternalServerException extends SSOOIDCServiceException {
      static {
        __name(this, "InternalServerException");
      }
      name = "InternalServerException";
      $fault = "server";
      error;
      error_description;
      constructor(opts) {
        super({
          name: "InternalServerException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _InternalServerException.prototype);
        this.error = opts.error;
        this.error_description = opts.error_description;
      }
    };
    InvalidClientException = class _InvalidClientException extends SSOOIDCServiceException {
      static {
        __name(this, "InvalidClientException");
      }
      name = "InvalidClientException";
      $fault = "client";
      error;
      error_description;
      constructor(opts) {
        super({
          name: "InvalidClientException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidClientException.prototype);
        this.error = opts.error;
        this.error_description = opts.error_description;
      }
    };
    InvalidGrantException = class _InvalidGrantException extends SSOOIDCServiceException {
      static {
        __name(this, "InvalidGrantException");
      }
      name = "InvalidGrantException";
      $fault = "client";
      error;
      error_description;
      constructor(opts) {
        super({
          name: "InvalidGrantException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidGrantException.prototype);
        this.error = opts.error;
        this.error_description = opts.error_description;
      }
    };
    InvalidRequestException = class _InvalidRequestException extends SSOOIDCServiceException {
      static {
        __name(this, "InvalidRequestException");
      }
      name = "InvalidRequestException";
      $fault = "client";
      error;
      reason;
      error_description;
      constructor(opts) {
        super({
          name: "InvalidRequestException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidRequestException.prototype);
        this.error = opts.error;
        this.reason = opts.reason;
        this.error_description = opts.error_description;
      }
    };
    InvalidScopeException = class _InvalidScopeException extends SSOOIDCServiceException {
      static {
        __name(this, "InvalidScopeException");
      }
      name = "InvalidScopeException";
      $fault = "client";
      error;
      error_description;
      constructor(opts) {
        super({
          name: "InvalidScopeException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidScopeException.prototype);
        this.error = opts.error;
        this.error_description = opts.error_description;
      }
    };
    SlowDownException = class _SlowDownException extends SSOOIDCServiceException {
      static {
        __name(this, "SlowDownException");
      }
      name = "SlowDownException";
      $fault = "client";
      error;
      error_description;
      constructor(opts) {
        super({
          name: "SlowDownException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _SlowDownException.prototype);
        this.error = opts.error;
        this.error_description = opts.error_description;
      }
    };
    UnauthorizedClientException = class _UnauthorizedClientException extends SSOOIDCServiceException {
      static {
        __name(this, "UnauthorizedClientException");
      }
      name = "UnauthorizedClientException";
      $fault = "client";
      error;
      error_description;
      constructor(opts) {
        super({
          name: "UnauthorizedClientException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnauthorizedClientException.prototype);
        this.error = opts.error;
        this.error_description = opts.error_description;
      }
    };
    UnsupportedGrantTypeException = class _UnsupportedGrantTypeException extends SSOOIDCServiceException {
      static {
        __name(this, "UnsupportedGrantTypeException");
      }
      name = "UnsupportedGrantTypeException";
      $fault = "client";
      error;
      error_description;
      constructor(opts) {
        super({
          name: "UnsupportedGrantTypeException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnsupportedGrantTypeException.prototype);
        this.error = opts.error;
        this.error_description = opts.error_description;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/schemas/schemas_0.js
var _ADE, _APE, _AT, _CS, _CT, _CTR, _CTRr, _CV, _ETE, _ICE, _IGE, _IRE, _ISE, _ISEn, _IT, _RT, _SDE, _UCE, _UGTE, _aT, _c, _cI, _cS, _cV, _co, _dC, _e, _eI, _ed, _gT, _h, _hE, _iT, _r, _rT, _rU, _s, _sc, _se, _tT, n0, _s_registry, SSOOIDCServiceException$, n0_registry, AccessDeniedException$, AuthorizationPendingException$, ExpiredTokenException$, InternalServerException$, InvalidClientException$, InvalidGrantException$, InvalidRequestException$, InvalidScopeException$, SlowDownException$, UnauthorizedClientException$, UnsupportedGrantTypeException$, errorTypeRegistries, AccessToken, ClientSecret, CodeVerifier, IdToken, RefreshToken, CreateTokenRequest$, CreateTokenResponse$, Scopes, CreateToken$;
var init_schemas_0 = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/schemas/schemas_0.js"() {
    init_schema4();
    init_errors();
    init_SSOOIDCServiceException();
    _ADE = "AccessDeniedException";
    _APE = "AuthorizationPendingException";
    _AT = "AccessToken";
    _CS = "ClientSecret";
    _CT = "CreateToken";
    _CTR = "CreateTokenRequest";
    _CTRr = "CreateTokenResponse";
    _CV = "CodeVerifier";
    _ETE = "ExpiredTokenException";
    _ICE = "InvalidClientException";
    _IGE = "InvalidGrantException";
    _IRE = "InvalidRequestException";
    _ISE = "InternalServerException";
    _ISEn = "InvalidScopeException";
    _IT = "IdToken";
    _RT = "RefreshToken";
    _SDE = "SlowDownException";
    _UCE = "UnauthorizedClientException";
    _UGTE = "UnsupportedGrantTypeException";
    _aT = "accessToken";
    _c = "client";
    _cI = "clientId";
    _cS = "clientSecret";
    _cV = "codeVerifier";
    _co = "code";
    _dC = "deviceCode";
    _e = "error";
    _eI = "expiresIn";
    _ed = "error_description";
    _gT = "grantType";
    _h = "http";
    _hE = "httpError";
    _iT = "idToken";
    _r = "reason";
    _rT = "refreshToken";
    _rU = "redirectUri";
    _s = "smithy.ts.sdk.synthetic.com.amazonaws.ssooidc";
    _sc = "scope";
    _se = "server";
    _tT = "tokenType";
    n0 = "com.amazonaws.ssooidc";
    _s_registry = TypeRegistry.for(_s);
    SSOOIDCServiceException$ = [-3, _s, "SSOOIDCServiceException", 0, [], []];
    _s_registry.registerError(SSOOIDCServiceException$, SSOOIDCServiceException);
    n0_registry = TypeRegistry.for(n0);
    AccessDeniedException$ = [
      -3,
      n0,
      _ADE,
      { [_e]: _c, [_hE]: 400 },
      [_e, _r, _ed],
      [0, 0, 0]
    ];
    n0_registry.registerError(AccessDeniedException$, AccessDeniedException);
    AuthorizationPendingException$ = [
      -3,
      n0,
      _APE,
      { [_e]: _c, [_hE]: 400 },
      [_e, _ed],
      [0, 0]
    ];
    n0_registry.registerError(AuthorizationPendingException$, AuthorizationPendingException);
    ExpiredTokenException$ = [-3, n0, _ETE, { [_e]: _c, [_hE]: 400 }, [_e, _ed], [0, 0]];
    n0_registry.registerError(ExpiredTokenException$, ExpiredTokenException);
    InternalServerException$ = [-3, n0, _ISE, { [_e]: _se, [_hE]: 500 }, [_e, _ed], [0, 0]];
    n0_registry.registerError(InternalServerException$, InternalServerException);
    InvalidClientException$ = [-3, n0, _ICE, { [_e]: _c, [_hE]: 401 }, [_e, _ed], [0, 0]];
    n0_registry.registerError(InvalidClientException$, InvalidClientException);
    InvalidGrantException$ = [-3, n0, _IGE, { [_e]: _c, [_hE]: 400 }, [_e, _ed], [0, 0]];
    n0_registry.registerError(InvalidGrantException$, InvalidGrantException);
    InvalidRequestException$ = [
      -3,
      n0,
      _IRE,
      { [_e]: _c, [_hE]: 400 },
      [_e, _r, _ed],
      [0, 0, 0]
    ];
    n0_registry.registerError(InvalidRequestException$, InvalidRequestException);
    InvalidScopeException$ = [-3, n0, _ISEn, { [_e]: _c, [_hE]: 400 }, [_e, _ed], [0, 0]];
    n0_registry.registerError(InvalidScopeException$, InvalidScopeException);
    SlowDownException$ = [-3, n0, _SDE, { [_e]: _c, [_hE]: 400 }, [_e, _ed], [0, 0]];
    n0_registry.registerError(SlowDownException$, SlowDownException);
    UnauthorizedClientException$ = [
      -3,
      n0,
      _UCE,
      { [_e]: _c, [_hE]: 400 },
      [_e, _ed],
      [0, 0]
    ];
    n0_registry.registerError(UnauthorizedClientException$, UnauthorizedClientException);
    UnsupportedGrantTypeException$ = [
      -3,
      n0,
      _UGTE,
      { [_e]: _c, [_hE]: 400 },
      [_e, _ed],
      [0, 0]
    ];
    n0_registry.registerError(UnsupportedGrantTypeException$, UnsupportedGrantTypeException);
    errorTypeRegistries = [_s_registry, n0_registry];
    AccessToken = [0, n0, _AT, 8, 0];
    ClientSecret = [0, n0, _CS, 8, 0];
    CodeVerifier = [0, n0, _CV, 8, 0];
    IdToken = [0, n0, _IT, 8, 0];
    RefreshToken = [0, n0, _RT, 8, 0];
    CreateTokenRequest$ = [
      3,
      n0,
      _CTR,
      0,
      [_cI, _cS, _gT, _dC, _co, _rT, _sc, _rU, _cV],
      [0, [() => ClientSecret, 0], 0, 0, 0, [() => RefreshToken, 0], 64 | 0, 0, [() => CodeVerifier, 0]],
      3
    ];
    CreateTokenResponse$ = [
      3,
      n0,
      _CTRr,
      0,
      [_aT, _tT, _eI, _rT, _iT],
      [[() => AccessToken, 0], 0, 1, [() => RefreshToken, 0], [() => IdToken, 0]]
    ];
    Scopes = 64 | 0;
    CreateToken$ = [
      9,
      n0,
      _CT,
      { [_h]: ["POST", "/token", 200] },
      () => CreateTokenRequest$,
      () => CreateTokenResponse$
    ];
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/runtimeConfig.shared.js
var import_smithy_client4, import_url_parser2, import_util_base646, import_util_utf87, getRuntimeConfig;
var init_runtimeConfig_shared = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/runtimeConfig.shared.js"() {
    init_httpAuthSchemes3();
    init_protocols3();
    init_dist_es();
    import_smithy_client4 = __toESM(require_dist_cjs34());
    import_url_parser2 = __toESM(require_dist_cjs18());
    import_util_base646 = __toESM(require_dist_cjs10());
    import_util_utf87 = __toESM(require_dist_cjs9());
    init_httpAuthSchemeProvider();
    init_endpointResolver();
    init_schemas_0();
    getRuntimeConfig = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2019-06-10",
        base64Decoder: config2?.base64Decoder ?? import_util_base646.fromBase64,
        base64Encoder: config2?.base64Encoder ?? import_util_base646.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSSOOIDCHttpAuthSchemeProvider,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer2()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        logger: config2?.logger ?? new import_smithy_client4.NoOpLogger(),
        protocol: config2?.protocol ?? AwsRestJsonProtocol,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.ssooidc",
          errorTypeRegistries,
          version: "2019-06-10",
          serviceTarget: "AWSSSOOIDCService"
        },
        serviceId: config2?.serviceId ?? "SSO OIDC",
        urlParser: config2?.urlParser ?? import_url_parser2.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? import_util_utf87.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? import_util_utf87.toUtf8
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/runtimeConfig.js
var import_util_user_agent_node, import_config_resolver, import_hash_node, import_middleware_retry, import_node_config_provider, import_node_http_handler, import_smithy_client5, import_util_body_length_node, import_util_defaults_mode_node, import_util_retry3, getRuntimeConfig2;
var init_runtimeConfig = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/runtimeConfig.js"() {
    init_package();
    init_client3();
    init_httpAuthSchemes3();
    import_util_user_agent_node = __toESM(require_dist_cjs43());
    import_config_resolver = __toESM(require_dist_cjs25());
    import_hash_node = __toESM(require_dist_cjs44());
    import_middleware_retry = __toESM(require_dist_cjs42());
    import_node_config_provider = __toESM(require_dist_cjs29());
    import_node_http_handler = __toESM(require_dist_cjs13());
    import_smithy_client5 = __toESM(require_dist_cjs34());
    import_util_body_length_node = __toESM(require_dist_cjs45());
    import_util_defaults_mode_node = __toESM(require_dist_cjs46());
    import_util_retry3 = __toESM(require_dist_cjs22());
    init_runtimeConfig_shared();
    getRuntimeConfig2 = /* @__PURE__ */ __name((config2) => {
      (0, import_smithy_client5.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, import_util_defaults_mode_node.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(import_smithy_client5.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig(config2);
      emitWarningIfUnsupportedVersion2(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, import_node_config_provider.loadConfig)(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS2, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? import_util_body_length_node.calculateBodyLength,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, import_util_user_agent_node.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_default.version }),
        maxAttempts: config2?.maxAttempts ?? (0, import_node_config_provider.loadConfig)(import_middleware_retry.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, import_node_config_provider.loadConfig)(import_config_resolver.NODE_REGION_CONFIG_OPTIONS, { ...import_config_resolver.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: import_node_http_handler.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, import_node_config_provider.loadConfig)({
          ...import_middleware_retry.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || import_util_retry3.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? import_hash_node.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? import_node_http_handler.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, import_node_config_provider.loadConfig)(import_config_resolver.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, import_node_config_provider.loadConfig)(import_config_resolver.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, import_node_config_provider.loadConfig)(import_util_user_agent_node.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/region-config-resolver/dist-cjs/regionConfig/stsRegionDefaultResolver.js
var require_stsRegionDefaultResolver = __commonJS({
  "../../node_modules/@aws-sdk/region-config-resolver/dist-cjs/regionConfig/stsRegionDefaultResolver.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.warning = void 0;
    exports2.stsRegionDefaultResolver = stsRegionDefaultResolver10;
    var config_resolver_1 = require_dist_cjs25();
    var node_config_provider_1 = require_dist_cjs29();
    function stsRegionDefaultResolver10(loaderConfig = {}) {
      return (0, node_config_provider_1.loadConfig)({
        ...config_resolver_1.NODE_REGION_CONFIG_OPTIONS,
        async default() {
          if (!exports2.warning.silence) {
            console.warn("@aws-sdk - WARN - default STS region of us-east-1 used. See @aws-sdk/credential-providers README and set a region explicitly.");
          }
          return "us-east-1";
        }
      }, { ...config_resolver_1.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig });
    }
    __name(stsRegionDefaultResolver10, "stsRegionDefaultResolver");
    exports2.warning = {
      silence: false
    };
  }
});

// ../../node_modules/@aws-sdk/region-config-resolver/dist-cjs/index.js
var require_dist_cjs48 = __commonJS({
  "../../node_modules/@aws-sdk/region-config-resolver/dist-cjs/index.js"(exports2) {
    "use strict";
    var stsRegionDefaultResolver10 = require_stsRegionDefaultResolver();
    var configResolver = require_dist_cjs25();
    var getAwsRegionExtensionConfiguration29 = /* @__PURE__ */ __name((runtimeConfig) => {
      return {
        setRegion(region) {
          runtimeConfig.region = region;
        },
        region() {
          return runtimeConfig.region;
        }
      };
    }, "getAwsRegionExtensionConfiguration");
    var resolveAwsRegionExtensionConfiguration29 = /* @__PURE__ */ __name((awsRegionExtensionConfiguration) => {
      return {
        region: awsRegionExtensionConfiguration.region()
      };
    }, "resolveAwsRegionExtensionConfiguration");
    exports2.NODE_REGION_CONFIG_FILE_OPTIONS = configResolver.NODE_REGION_CONFIG_FILE_OPTIONS;
    exports2.NODE_REGION_CONFIG_OPTIONS = configResolver.NODE_REGION_CONFIG_OPTIONS;
    exports2.REGION_ENV_NAME = configResolver.REGION_ENV_NAME;
    exports2.REGION_INI_NAME = configResolver.REGION_INI_NAME;
    exports2.resolveRegionConfig = configResolver.resolveRegionConfig;
    exports2.getAwsRegionExtensionConfiguration = getAwsRegionExtensionConfiguration29;
    exports2.resolveAwsRegionExtensionConfiguration = resolveAwsRegionExtensionConfiguration29;
    Object.prototype.hasOwnProperty.call(stsRegionDefaultResolver10, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: stsRegionDefaultResolver10["__proto__"]
    });
    Object.keys(stsRegionDefaultResolver10).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = stsRegionDefaultResolver10[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration, resolveHttpAuthRuntimeConfig;
var init_httpAuthExtensionConfiguration = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/runtimeExtensions.js
var import_region_config_resolver, import_protocol_http15, import_smithy_client6, resolveRuntimeExtensions;
var init_runtimeExtensions = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/runtimeExtensions.js"() {
    import_region_config_resolver = __toESM(require_dist_cjs48());
    import_protocol_http15 = __toESM(require_dist_cjs2());
    import_smithy_client6 = __toESM(require_dist_cjs34());
    init_httpAuthExtensionConfiguration();
    resolveRuntimeExtensions = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign((0, import_region_config_resolver.getAwsRegionExtensionConfiguration)(runtimeConfig), (0, import_smithy_client6.getDefaultExtensionConfiguration)(runtimeConfig), (0, import_protocol_http15.getHttpHandlerExtensionConfiguration)(runtimeConfig), getHttpAuthExtensionConfiguration(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, (0, import_region_config_resolver.resolveAwsRegionExtensionConfiguration)(extensionConfiguration), (0, import_smithy_client6.resolveDefaultRuntimeConfig)(extensionConfiguration), (0, import_protocol_http15.resolveHttpHandlerRuntimeConfig)(extensionConfiguration), resolveHttpAuthRuntimeConfig(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/SSOOIDCClient.js
var import_middleware_host_header, import_middleware_logger, import_middleware_recursion_detection, import_middleware_user_agent, import_config_resolver2, import_middleware_content_length, import_middleware_endpoint, import_middleware_retry2, import_smithy_client7, SSOOIDCClient;
var init_SSOOIDCClient = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/SSOOIDCClient.js"() {
    import_middleware_host_header = __toESM(require_dist_cjs3());
    import_middleware_logger = __toESM(require_dist_cjs4());
    import_middleware_recursion_detection = __toESM(require_dist_cjs5());
    import_middleware_user_agent = __toESM(require_dist_cjs41());
    import_config_resolver2 = __toESM(require_dist_cjs25());
    init_dist_es();
    init_schema4();
    import_middleware_content_length = __toESM(require_dist_cjs26());
    import_middleware_endpoint = __toESM(require_dist_cjs31());
    import_middleware_retry2 = __toESM(require_dist_cjs42());
    import_smithy_client7 = __toESM(require_dist_cjs34());
    init_httpAuthSchemeProvider();
    init_EndpointParameters();
    init_runtimeConfig();
    init_runtimeExtensions();
    SSOOIDCClient = class extends import_smithy_client7.Client {
      static {
        __name(this, "SSOOIDCClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig2(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters(_config_0);
        const _config_2 = (0, import_middleware_user_agent.resolveUserAgentConfig)(_config_1);
        const _config_3 = (0, import_middleware_retry2.resolveRetryConfig)(_config_2);
        const _config_4 = (0, import_config_resolver2.resolveRegionConfig)(_config_3);
        const _config_5 = (0, import_middleware_host_header.resolveHostHeaderConfig)(_config_4);
        const _config_6 = (0, import_middleware_endpoint.resolveEndpointConfig)(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig(_config_6);
        const _config_8 = resolveRuntimeExtensions(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin(this.config));
        this.middlewareStack.use((0, import_middleware_user_agent.getUserAgentPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_retry2.getRetryPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_content_length.getContentLengthPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_host_header.getHostHeaderPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_logger.getLoggerPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_recursion_detection.getRecursionDetectionPlugin)(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: defaultSSOOIDCHttpAuthSchemeParametersProvider,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/commands/CreateTokenCommand.js
var import_middleware_endpoint2, import_smithy_client8, CreateTokenCommand;
var init_CreateTokenCommand = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/commands/CreateTokenCommand.js"() {
    import_middleware_endpoint2 = __toESM(require_dist_cjs31());
    import_smithy_client8 = __toESM(require_dist_cjs34());
    init_EndpointParameters();
    init_schemas_0();
    CreateTokenCommand = class extends import_smithy_client8.Command.classBuilder().ep(commonParams).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint2.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSSOOIDCService", "CreateToken", {}).n("SSOOIDCClient", "CreateTokenCommand").sc(CreateToken$).build() {
      static {
        __name(this, "CreateTokenCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/SSOOIDC.js
var import_smithy_client9, commands, SSOOIDC;
var init_SSOOIDC = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/SSOOIDC.js"() {
    import_smithy_client9 = __toESM(require_dist_cjs34());
    init_CreateTokenCommand();
    init_SSOOIDCClient();
    commands = {
      CreateTokenCommand
    };
    SSOOIDC = class extends SSOOIDCClient {
      static {
        __name(this, "SSOOIDC");
      }
    };
    (0, import_smithy_client9.createAggregatedClient)(commands, SSOOIDC);
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/commands/index.js
var init_commands2 = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/commands/index.js"() {
    init_CreateTokenCommand();
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/models/enums.js
var AccessDeniedExceptionReason, InvalidRequestExceptionReason;
var init_enums = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/models/enums.js"() {
    AccessDeniedExceptionReason = {
      KMS_ACCESS_DENIED: "KMS_AccessDeniedException"
    };
    InvalidRequestExceptionReason = {
      KMS_DISABLED_KEY: "KMS_DisabledException",
      KMS_INVALID_KEY_USAGE: "KMS_InvalidKeyUsageException",
      KMS_INVALID_STATE: "KMS_InvalidStateException",
      KMS_KEY_NOT_FOUND: "KMS_NotFoundException"
    };
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/models/models_0.js
var init_models_0 = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/index.js
var sso_oidc_exports = {};
__export(sso_oidc_exports, {
  $Command: () => import_smithy_client8.Command,
  AccessDeniedException: () => AccessDeniedException,
  AccessDeniedException$: () => AccessDeniedException$,
  AccessDeniedExceptionReason: () => AccessDeniedExceptionReason,
  AuthorizationPendingException: () => AuthorizationPendingException,
  AuthorizationPendingException$: () => AuthorizationPendingException$,
  CreateToken$: () => CreateToken$,
  CreateTokenCommand: () => CreateTokenCommand,
  CreateTokenRequest$: () => CreateTokenRequest$,
  CreateTokenResponse$: () => CreateTokenResponse$,
  ExpiredTokenException: () => ExpiredTokenException,
  ExpiredTokenException$: () => ExpiredTokenException$,
  InternalServerException: () => InternalServerException,
  InternalServerException$: () => InternalServerException$,
  InvalidClientException: () => InvalidClientException,
  InvalidClientException$: () => InvalidClientException$,
  InvalidGrantException: () => InvalidGrantException,
  InvalidGrantException$: () => InvalidGrantException$,
  InvalidRequestException: () => InvalidRequestException,
  InvalidRequestException$: () => InvalidRequestException$,
  InvalidRequestExceptionReason: () => InvalidRequestExceptionReason,
  InvalidScopeException: () => InvalidScopeException,
  InvalidScopeException$: () => InvalidScopeException$,
  SSOOIDC: () => SSOOIDC,
  SSOOIDCClient: () => SSOOIDCClient,
  SSOOIDCServiceException: () => SSOOIDCServiceException,
  SSOOIDCServiceException$: () => SSOOIDCServiceException$,
  SlowDownException: () => SlowDownException,
  SlowDownException$: () => SlowDownException$,
  UnauthorizedClientException: () => UnauthorizedClientException,
  UnauthorizedClientException$: () => UnauthorizedClientException$,
  UnsupportedGrantTypeException: () => UnsupportedGrantTypeException,
  UnsupportedGrantTypeException$: () => UnsupportedGrantTypeException$,
  __Client: () => import_smithy_client7.Client,
  errorTypeRegistries: () => errorTypeRegistries
});
var init_sso_oidc = __esm({
  "../../node_modules/@aws-sdk/token-providers/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/index.js"() {
    init_SSOOIDCClient();
    init_SSOOIDC();
    init_commands2();
    init_schemas_0();
    init_enums();
    init_errors();
    init_models_0();
    init_SSOOIDCServiceException();
  }
});

// ../../node_modules/@aws-sdk/token-providers/dist-cjs/index.js
var require_dist_cjs49 = __commonJS({
  "../../node_modules/@aws-sdk/token-providers/dist-cjs/index.js"(exports2) {
    "use strict";
    var client = (init_client3(), __toCommonJS(client_exports2));
    var httpAuthSchemes = (init_httpAuthSchemes3(), __toCommonJS(httpAuthSchemes_exports2));
    var propertyProvider = require_dist_cjs27();
    var sharedIniFileLoader = require_dist_cjs28();
    var node_fs = require("node:fs");
    var fromEnvSigningName = /* @__PURE__ */ __name(({ logger: logger5, signingName } = {}) => async () => {
      logger5?.debug?.("@aws-sdk/token-providers - fromEnvSigningName");
      if (!signingName) {
        throw new propertyProvider.TokenProviderError("Please pass 'signingName' to compute environment variable key", { logger: logger5 });
      }
      const bearerTokenKey = httpAuthSchemes.getBearerTokenEnvKey(signingName);
      if (!(bearerTokenKey in process.env)) {
        throw new propertyProvider.TokenProviderError(`Token not present in '${bearerTokenKey}' environment variable`, { logger: logger5 });
      }
      const token = { token: process.env[bearerTokenKey] };
      client.setTokenFeature(token, "BEARER_SERVICE_ENV_VARS", "3");
      return token;
    }, "fromEnvSigningName");
    var EXPIRE_WINDOW_MS = 5 * 60 * 1e3;
    var REFRESH_MESSAGE = `To refresh this SSO session run 'aws sso login' with the corresponding profile.`;
    var getSsoOidcClient = /* @__PURE__ */ __name(async (ssoRegion, init = {}, callerClientConfig) => {
      const { SSOOIDCClient: SSOOIDCClient4 } = await Promise.resolve().then(() => (init_sso_oidc(), sso_oidc_exports));
      const coalesce3 = /* @__PURE__ */ __name((prop) => init.clientConfig?.[prop] ?? init.parentClientConfig?.[prop] ?? callerClientConfig?.[prop], "coalesce");
      const ssoOidcClient = new SSOOIDCClient4(Object.assign({}, init.clientConfig ?? {}, {
        region: ssoRegion ?? init.clientConfig?.region,
        logger: coalesce3("logger"),
        userAgentAppId: coalesce3("userAgentAppId")
      }));
      return ssoOidcClient;
    }, "getSsoOidcClient");
    var getNewSsoOidcToken = /* @__PURE__ */ __name(async (ssoToken, ssoRegion, init = {}, callerClientConfig) => {
      const { CreateTokenCommand: CreateTokenCommand4 } = await Promise.resolve().then(() => (init_sso_oidc(), sso_oidc_exports));
      const ssoOidcClient = await getSsoOidcClient(ssoRegion, init, callerClientConfig);
      return ssoOidcClient.send(new CreateTokenCommand4({
        clientId: ssoToken.clientId,
        clientSecret: ssoToken.clientSecret,
        refreshToken: ssoToken.refreshToken,
        grantType: "refresh_token"
      }));
    }, "getNewSsoOidcToken");
    var validateTokenExpiry = /* @__PURE__ */ __name((token) => {
      if (token.expiration && token.expiration.getTime() < Date.now()) {
        throw new propertyProvider.TokenProviderError(`Token is expired. ${REFRESH_MESSAGE}`, false);
      }
    }, "validateTokenExpiry");
    var validateTokenKey = /* @__PURE__ */ __name((key, value, forRefresh = false) => {
      if (typeof value === "undefined") {
        throw new propertyProvider.TokenProviderError(`Value not present for '${key}' in SSO Token${forRefresh ? ". Cannot refresh" : ""}. ${REFRESH_MESSAGE}`, false);
      }
    }, "validateTokenKey");
    var { writeFile: writeFile6 } = node_fs.promises;
    var writeSSOTokenToFile = /* @__PURE__ */ __name((id, ssoToken) => {
      const tokenFilepath = sharedIniFileLoader.getSSOTokenFilepath(id);
      const tokenString = JSON.stringify(ssoToken, null, 2);
      return writeFile6(tokenFilepath, tokenString);
    }, "writeSSOTokenToFile");
    var lastRefreshAttemptTime = /* @__PURE__ */ new Date(0);
    var fromSso = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/token-providers - fromSso");
      const profiles = await sharedIniFileLoader.parseKnownFiles(init);
      const profileName = sharedIniFileLoader.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      });
      const profile = profiles[profileName];
      if (!profile) {
        throw new propertyProvider.TokenProviderError(`Profile '${profileName}' could not be found in shared credentials file.`, false);
      } else if (!profile["sso_session"]) {
        throw new propertyProvider.TokenProviderError(`Profile '${profileName}' is missing required property 'sso_session'.`);
      }
      const ssoSessionName = profile["sso_session"];
      const ssoSessions = await sharedIniFileLoader.loadSsoSessionData(init);
      const ssoSession = ssoSessions[ssoSessionName];
      if (!ssoSession) {
        throw new propertyProvider.TokenProviderError(`Sso session '${ssoSessionName}' could not be found in shared credentials file.`, false);
      }
      for (const ssoSessionRequiredKey of ["sso_start_url", "sso_region"]) {
        if (!ssoSession[ssoSessionRequiredKey]) {
          throw new propertyProvider.TokenProviderError(`Sso session '${ssoSessionName}' is missing required property '${ssoSessionRequiredKey}'.`, false);
        }
      }
      ssoSession["sso_start_url"];
      const ssoRegion = ssoSession["sso_region"];
      let ssoToken;
      try {
        ssoToken = await sharedIniFileLoader.getSSOTokenFromFile(ssoSessionName);
      } catch (e32) {
        throw new propertyProvider.TokenProviderError(`The SSO session token associated with profile=${profileName} was not found or is invalid. ${REFRESH_MESSAGE}`, false);
      }
      validateTokenKey("accessToken", ssoToken.accessToken);
      validateTokenKey("expiresAt", ssoToken.expiresAt);
      const { accessToken, expiresAt } = ssoToken;
      const existingToken = { token: accessToken, expiration: new Date(expiresAt) };
      if (existingToken.expiration.getTime() - Date.now() > EXPIRE_WINDOW_MS) {
        return existingToken;
      }
      if (Date.now() - lastRefreshAttemptTime.getTime() < 30 * 1e3) {
        validateTokenExpiry(existingToken);
        return existingToken;
      }
      validateTokenKey("clientId", ssoToken.clientId, true);
      validateTokenKey("clientSecret", ssoToken.clientSecret, true);
      validateTokenKey("refreshToken", ssoToken.refreshToken, true);
      try {
        lastRefreshAttemptTime.setTime(Date.now());
        const newSsoOidcToken = await getNewSsoOidcToken(ssoToken, ssoRegion, init, callerClientConfig);
        validateTokenKey("accessToken", newSsoOidcToken.accessToken);
        validateTokenKey("expiresIn", newSsoOidcToken.expiresIn);
        const newTokenExpiration = new Date(Date.now() + newSsoOidcToken.expiresIn * 1e3);
        try {
          await writeSSOTokenToFile(ssoSessionName, {
            ...ssoToken,
            accessToken: newSsoOidcToken.accessToken,
            expiresAt: newTokenExpiration.toISOString(),
            refreshToken: newSsoOidcToken.refreshToken
          });
        } catch (error4) {
        }
        return {
          token: newSsoOidcToken.accessToken,
          expiration: newTokenExpiration
        };
      } catch (error4) {
        validateTokenExpiry(existingToken);
        return existingToken;
      }
    }, "fromSso");
    var fromStatic5 = /* @__PURE__ */ __name(({ token, logger: logger5 }) => async () => {
      logger5?.debug("@aws-sdk/token-providers - fromStatic");
      if (!token || !token.token) {
        throw new propertyProvider.TokenProviderError(`Please pass a valid token to fromStatic`, false);
      }
      return token;
    }, "fromStatic");
    var nodeProvider = /* @__PURE__ */ __name((init = {}) => propertyProvider.memoize(propertyProvider.chain(fromSso(init), async () => {
      throw new propertyProvider.TokenProviderError("Could not load token from any providers", false);
    }), (token) => token.expiration !== void 0 && token.expiration.getTime() - Date.now() < 3e5, (token) => token.expiration !== void 0), "nodeProvider");
    exports2.fromEnvSigningName = fromEnvSigningName;
    exports2.fromSso = fromSso;
    exports2.fromStatic = fromStatic5;
    exports2.nodeProvider = nodeProvider;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption2(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "awsssoportal",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption2(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var import_util_middleware7, defaultSSOHttpAuthSchemeParametersProvider, defaultSSOHttpAuthSchemeProvider, resolveHttpAuthSchemeConfig2;
var init_httpAuthSchemeProvider2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes2();
    import_util_middleware7 = __toESM(require_dist_cjs6());
    defaultSSOHttpAuthSchemeParametersProvider = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, import_util_middleware7.getSmithyContext)(context).operation,
        region: await (0, import_util_middleware7.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultSSOHttpAuthSchemeParametersProvider");
    __name(createAwsAuthSigv4HttpAuthOption2, "createAwsAuthSigv4HttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption2, "createSmithyApiNoAuthHttpAuthOption");
    defaultSSOHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "GetRoleCredentials": {
          options.push(createSmithyApiNoAuthHttpAuthOption2(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption2(authParameters));
        }
      }
      return options;
    }, "defaultSSOHttpAuthSchemeProvider");
    resolveHttpAuthSchemeConfig2 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveAwsSdkSigV4Config(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, import_util_middleware7.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/EndpointParameters.js
var resolveClientEndpointParameters2, commonParams2;
var init_EndpointParameters2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters2 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "awsssoportal"
      });
    }, "resolveClientEndpointParameters");
    commonParams2 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/package.json
var package_default2;
var init_package2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/package.json"() {
    package_default2 = {
      name: "@aws-sdk/nested-clients",
      version: "3.997.6",
      description: "Nested clients for AWS SDK packages.",
      main: "./dist-cjs/index.js",
      module: "./dist-es/index.js",
      types: "./dist-types/index.d.ts",
      scripts: {
        build: "yarn lint && concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline nested-clients",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        lint: "node ../../scripts/validation/submodules-linter.js --pkg nested-clients",
        test: "yarn g:vitest run",
        "test:watch": "yarn g:vitest watch"
      },
      engines: {
        node: ">=20.0.0"
      },
      sideEffects: false,
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      dependencies: {
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.8",
        "@aws-sdk/middleware-host-header": "^3.972.10",
        "@aws-sdk/middleware-logger": "^3.972.10",
        "@aws-sdk/middleware-recursion-detection": "^3.972.11",
        "@aws-sdk/middleware-user-agent": "^3.972.38",
        "@aws-sdk/region-config-resolver": "^3.972.13",
        "@aws-sdk/signature-v4-multi-region": "^3.996.25",
        "@aws-sdk/types": "^3.973.8",
        "@aws-sdk/util-endpoints": "^3.996.8",
        "@aws-sdk/util-user-agent-browser": "^3.972.10",
        "@aws-sdk/util-user-agent-node": "^3.973.24",
        "@smithy/config-resolver": "^4.4.17",
        "@smithy/core": "^3.23.17",
        "@smithy/fetch-http-handler": "^5.3.17",
        "@smithy/hash-node": "^4.2.14",
        "@smithy/invalid-dependency": "^4.2.14",
        "@smithy/middleware-content-length": "^4.2.14",
        "@smithy/middleware-endpoint": "^4.4.32",
        "@smithy/middleware-retry": "^4.5.7",
        "@smithy/middleware-serde": "^4.2.20",
        "@smithy/middleware-stack": "^4.2.14",
        "@smithy/node-config-provider": "^4.3.14",
        "@smithy/node-http-handler": "^4.6.1",
        "@smithy/protocol-http": "^5.3.14",
        "@smithy/smithy-client": "^4.12.13",
        "@smithy/types": "^4.14.1",
        "@smithy/url-parser": "^4.2.14",
        "@smithy/util-base64": "^4.3.2",
        "@smithy/util-body-length-browser": "^4.2.2",
        "@smithy/util-body-length-node": "^4.2.3",
        "@smithy/util-defaults-mode-browser": "^4.3.49",
        "@smithy/util-defaults-mode-node": "^4.2.54",
        "@smithy/util-endpoints": "^3.4.2",
        "@smithy/util-middleware": "^4.2.14",
        "@smithy/util-retry": "^4.3.6",
        "@smithy/util-utf8": "^4.2.2",
        tslib: "^2.6.2"
      },
      devDependencies: {
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "./cognito-identity.d.ts",
        "./cognito-identity.js",
        "./signin.d.ts",
        "./signin.js",
        "./sso-oidc.d.ts",
        "./sso-oidc.js",
        "./sso.d.ts",
        "./sso.js",
        "./sts.d.ts",
        "./sts.js",
        "dist-*/**"
      ],
      browser: {
        "./dist-es/submodules/cognito-identity/runtimeConfig": "./dist-es/submodules/cognito-identity/runtimeConfig.browser",
        "./dist-es/submodules/signin/runtimeConfig": "./dist-es/submodules/signin/runtimeConfig.browser",
        "./dist-es/submodules/sso-oidc/runtimeConfig": "./dist-es/submodules/sso-oidc/runtimeConfig.browser",
        "./dist-es/submodules/sso/runtimeConfig": "./dist-es/submodules/sso/runtimeConfig.browser",
        "./dist-es/submodules/sts/runtimeConfig": "./dist-es/submodules/sts/runtimeConfig.browser"
      },
      "react-native": {},
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/packages/nested-clients",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "packages/nested-clients"
      },
      exports: {
        "./package.json": "./package.json",
        "./sso-oidc": {
          types: "./dist-types/submodules/sso-oidc/index.d.ts",
          module: "./dist-es/submodules/sso-oidc/index.js",
          node: "./dist-cjs/submodules/sso-oidc/index.js",
          import: "./dist-es/submodules/sso-oidc/index.js",
          require: "./dist-cjs/submodules/sso-oidc/index.js"
        },
        "./sts": {
          types: "./dist-types/submodules/sts/index.d.ts",
          module: "./dist-es/submodules/sts/index.js",
          node: "./dist-cjs/submodules/sts/index.js",
          import: "./dist-es/submodules/sts/index.js",
          require: "./dist-cjs/submodules/sts/index.js"
        },
        "./signin": {
          types: "./dist-types/submodules/signin/index.d.ts",
          module: "./dist-es/submodules/signin/index.js",
          node: "./dist-cjs/submodules/signin/index.js",
          import: "./dist-es/submodules/signin/index.js",
          require: "./dist-cjs/submodules/signin/index.js"
        },
        "./cognito-identity": {
          types: "./dist-types/submodules/cognito-identity/index.d.ts",
          module: "./dist-es/submodules/cognito-identity/index.js",
          node: "./dist-cjs/submodules/cognito-identity/index.js",
          import: "./dist-es/submodules/cognito-identity/index.js",
          require: "./dist-cjs/submodules/cognito-identity/index.js"
        },
        "./sso": {
          types: "./dist-types/submodules/sso/index.d.ts",
          module: "./dist-es/submodules/sso/index.js",
          node: "./dist-cjs/submodules/sso/index.js",
          import: "./dist-es/submodules/sso/index.js",
          require: "./dist-cjs/submodules/sso/index.js"
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/util-user-agent-node/dist-cjs/index.js
var require_dist_cjs50 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/util-user-agent-node/dist-cjs/index.js"(exports2) {
    "use strict";
    var node_os = require("node:os");
    var node_process = require("node:process");
    var utilConfigProvider = require_dist_cjs24();
    var promises5 = require("node:fs/promises");
    var node_path = require("node:path");
    var middlewareUserAgent = require_dist_cjs23();
    var getRuntimeUserAgentPair2 = /* @__PURE__ */ __name(() => {
      const runtimesToCheck = ["deno", "bun", "llrt"];
      for (const runtime of runtimesToCheck) {
        if (node_process.versions[runtime]) {
          return [`md/${runtime}`, node_process.versions[runtime]];
        }
      }
      return ["md/nodejs", node_process.versions.node];
    }, "getRuntimeUserAgentPair");
    var getNodeModulesParentDirs2 = /* @__PURE__ */ __name((dirname14) => {
      const cwd = process.cwd();
      if (!dirname14) {
        return [cwd];
      }
      const normalizedPath = node_path.normalize(dirname14);
      const parts = normalizedPath.split(node_path.sep);
      const nodeModulesIndex = parts.indexOf("node_modules");
      const parentDir = nodeModulesIndex !== -1 ? parts.slice(0, nodeModulesIndex).join(node_path.sep) : normalizedPath;
      if (cwd === parentDir) {
        return [cwd];
      }
      return [parentDir, cwd];
    }, "getNodeModulesParentDirs");
    var SEMVER_REGEX2 = /^(0|[1-9]\d*)\.(0|[1-9]\d*)\.(0|[1-9]\d*)(?:-((?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*)(?:\.(?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*))*))?(?:\+[0-9a-zA-Z-]+(?:\.[0-9a-zA-Z-]+)*)?$/;
    var getSanitizedTypeScriptVersion2 = /* @__PURE__ */ __name((version = "") => {
      const match = version.match(SEMVER_REGEX2);
      if (!match) {
        return void 0;
      }
      const [major6, minor, patch, prerelease] = [match[1], match[2], match[3], match[4]];
      return prerelease ? `${major6}.${minor}.${patch}-${prerelease}` : `${major6}.${minor}.${patch}`;
    }, "getSanitizedTypeScriptVersion");
    var ALLOWED_PREFIXES2 = ["^", "~", ">=", "<=", ">", "<"];
    var ALLOWED_DIST_TAGS2 = ["latest", "beta", "dev", "rc", "insiders", "next"];
    var getSanitizedDevTypeScriptVersion2 = /* @__PURE__ */ __name((version = "") => {
      if (ALLOWED_DIST_TAGS2.includes(version)) {
        return version;
      }
      const prefix = ALLOWED_PREFIXES2.find((p10) => version.startsWith(p10)) ?? "";
      const sanitizedTypeScriptVersion = getSanitizedTypeScriptVersion2(version.slice(prefix.length));
      if (!sanitizedTypeScriptVersion) {
        return void 0;
      }
      return `${prefix}${sanitizedTypeScriptVersion}`;
    }, "getSanitizedDevTypeScriptVersion");
    var tscVersion2;
    var TS_PACKAGE_JSON2 = node_path.join("node_modules", "typescript", "package.json");
    var getTypeScriptUserAgentPair2 = /* @__PURE__ */ __name(async () => {
      if (tscVersion2 === null) {
        return void 0;
      } else if (typeof tscVersion2 === "string") {
        return ["md/tsc", tscVersion2];
      }
      let isTypeScriptDetectionDisabled = false;
      try {
        isTypeScriptDetectionDisabled = utilConfigProvider.booleanSelector(process.env, "AWS_SDK_JS_TYPESCRIPT_DETECTION_DISABLED", utilConfigProvider.SelectorType.ENV) || false;
      } catch {
      }
      if (isTypeScriptDetectionDisabled) {
        tscVersion2 = null;
        return void 0;
      }
      const dirname14 = typeof __dirname !== "undefined" ? __dirname : void 0;
      const nodeModulesParentDirs = getNodeModulesParentDirs2(dirname14);
      let versionFromApp;
      for (const nodeModulesParentDir of nodeModulesParentDirs) {
        try {
          const appPackageJsonPath = node_path.join(nodeModulesParentDir, "package.json");
          const packageJson = await promises5.readFile(appPackageJsonPath, "utf-8");
          const { dependencies, devDependencies } = JSON.parse(packageJson);
          const version = devDependencies?.typescript ?? dependencies?.typescript;
          if (typeof version !== "string") {
            continue;
          }
          versionFromApp = version;
          break;
        } catch {
        }
      }
      if (!versionFromApp) {
        tscVersion2 = null;
        return void 0;
      }
      let versionFromNodeModules;
      for (const nodeModulesParentDir of nodeModulesParentDirs) {
        try {
          const tsPackageJsonPath = node_path.join(nodeModulesParentDir, TS_PACKAGE_JSON2);
          const packageJson = await promises5.readFile(tsPackageJsonPath, "utf-8");
          const { version } = JSON.parse(packageJson);
          const sanitizedVersion2 = getSanitizedTypeScriptVersion2(version);
          if (typeof sanitizedVersion2 !== "string") {
            continue;
          }
          versionFromNodeModules = sanitizedVersion2;
          break;
        } catch {
        }
      }
      if (versionFromNodeModules) {
        tscVersion2 = versionFromNodeModules;
        return ["md/tsc", tscVersion2];
      }
      const sanitizedVersion = getSanitizedDevTypeScriptVersion2(versionFromApp);
      if (typeof sanitizedVersion !== "string") {
        tscVersion2 = null;
        return void 0;
      }
      tscVersion2 = `dev_${sanitizedVersion}`;
      return ["md/tsc", tscVersion2];
    }, "getTypeScriptUserAgentPair");
    var crtAvailability2 = {
      isCrtAvailable: false
    };
    var isCrtAvailable2 = /* @__PURE__ */ __name(() => {
      if (crtAvailability2.isCrtAvailable) {
        return ["md/crt-avail"];
      }
      return null;
    }, "isCrtAvailable");
    var createDefaultUserAgentProvider29 = /* @__PURE__ */ __name(({ serviceId, clientVersion }) => {
      const runtimeUserAgentPair = getRuntimeUserAgentPair2();
      return async (config2) => {
        const sections = [
          ["aws-sdk-js", clientVersion],
          ["ua", "2.1"],
          [`os/${node_os.platform()}`, node_os.release()],
          ["lang/js"],
          runtimeUserAgentPair
        ];
        const typescriptUserAgentPair = await getTypeScriptUserAgentPair2();
        if (typescriptUserAgentPair) {
          sections.push(typescriptUserAgentPair);
        }
        const crtAvailable = isCrtAvailable2();
        if (crtAvailable) {
          sections.push(crtAvailable);
        }
        if (serviceId) {
          sections.push([`api/${serviceId}`, clientVersion]);
        }
        if (node_process.env.AWS_EXECUTION_ENV) {
          sections.push([`exec-env/${node_process.env.AWS_EXECUTION_ENV}`]);
        }
        const appId = await config2?.userAgentAppId?.();
        const resolvedUserAgent = appId ? [...sections, [`app/${appId}`]] : [...sections];
        return resolvedUserAgent;
      };
    }, "createDefaultUserAgentProvider");
    var defaultUserAgent2 = createDefaultUserAgentProvider29;
    var UA_APP_ID_ENV_NAME2 = "AWS_SDK_UA_APP_ID";
    var UA_APP_ID_INI_NAME2 = "sdk_ua_app_id";
    var UA_APP_ID_INI_NAME_DEPRECATED2 = "sdk-ua-app-id";
    var NODE_APP_ID_CONFIG_OPTIONS29 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[UA_APP_ID_ENV_NAME2], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[UA_APP_ID_INI_NAME2] ?? profile[UA_APP_ID_INI_NAME_DEPRECATED2], "configFileSelector"),
      default: middlewareUserAgent.DEFAULT_UA_APP_ID
    };
    exports2.NODE_APP_ID_CONFIG_OPTIONS = NODE_APP_ID_CONFIG_OPTIONS29;
    exports2.UA_APP_ID_ENV_NAME = UA_APP_ID_ENV_NAME2;
    exports2.UA_APP_ID_INI_NAME = UA_APP_ID_INI_NAME2;
    exports2.createDefaultUserAgentProvider = createDefaultUserAgentProvider29;
    exports2.crtAvailability = crtAvailability2;
    exports2.defaultUserAgent = defaultUserAgent2;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ProtocolLib.js
var import_smithy_client10, ProtocolLib2;
var init_ProtocolLib2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ProtocolLib.js"() {
    init_schema4();
    import_smithy_client10 = __toESM(require_dist_cjs34());
    ProtocolLib2 = class {
      static {
        __name(this, "ProtocolLib");
      }
      queryCompat;
      errorRegistry;
      constructor(queryCompat = false) {
        this.queryCompat = queryCompat;
      }
      resolveRestContentType(defaultContentType, inputSchema) {
        const members = inputSchema.getMemberSchemas();
        const httpPayloadMember = Object.values(members).find((m20) => {
          return !!m20.getMergedTraits().httpPayload;
        });
        if (httpPayloadMember) {
          const mediaType = httpPayloadMember.getMergedTraits().mediaType;
          if (mediaType) {
            return mediaType;
          } else if (httpPayloadMember.isStringSchema()) {
            return "text/plain";
          } else if (httpPayloadMember.isBlobSchema()) {
            return "application/octet-stream";
          } else {
            return defaultContentType;
          }
        } else if (!inputSchema.isUnitSchema()) {
          const hasBody = Object.values(members).find((m20) => {
            const { httpQuery, httpQueryParams, httpHeader, httpLabel, httpPrefixHeaders } = m20.getMergedTraits();
            const noPrefixHeaders = httpPrefixHeaders === void 0;
            return !httpQuery && !httpQueryParams && !httpHeader && !httpLabel && noPrefixHeaders;
          });
          if (hasBody) {
            return defaultContentType;
          }
        }
      }
      async getErrorSchemaOrThrowBaseException(errorIdentifier, defaultNamespace, response, dataObject, metadata, getErrorSchema) {
        let errorName = errorIdentifier;
        if (errorIdentifier.includes("#")) {
          [, errorName] = errorIdentifier.split("#");
        }
        const errorMetadata = {
          $metadata: metadata,
          $fault: response.statusCode < 500 ? "client" : "server"
        };
        if (!this.errorRegistry) {
          throw new Error("@aws-sdk/core/protocols - error handler not initialized.");
        }
        try {
          const errorSchema = getErrorSchema?.(this.errorRegistry, errorName) ?? this.errorRegistry.getSchema(errorIdentifier);
          return { errorSchema, errorMetadata };
        } catch (e32) {
          dataObject.message = dataObject.message ?? dataObject.Message ?? "UnknownError";
          const synthetic = this.errorRegistry;
          const baseExceptionSchema = synthetic.getBaseException();
          if (baseExceptionSchema) {
            const ErrorCtor = synthetic.getErrorCtor(baseExceptionSchema) ?? Error;
            throw this.decorateServiceException(Object.assign(new ErrorCtor({ name: errorName }), errorMetadata), dataObject);
          }
          const d32 = dataObject;
          const message2 = d32?.message ?? d32?.Message ?? d32?.Error?.Message ?? d32?.Error?.message;
          throw this.decorateServiceException(Object.assign(new Error(message2), {
            name: errorName
          }, errorMetadata), dataObject);
        }
      }
      compose(composite, errorIdentifier, defaultNamespace) {
        let namespace = defaultNamespace;
        if (errorIdentifier.includes("#")) {
          [namespace] = errorIdentifier.split("#");
        }
        const staticRegistry = TypeRegistry.for(namespace);
        const defaultSyntheticRegistry = TypeRegistry.for("smithy.ts.sdk.synthetic." + defaultNamespace);
        composite.copyFrom(staticRegistry);
        composite.copyFrom(defaultSyntheticRegistry);
        this.errorRegistry = composite;
      }
      decorateServiceException(exception, additions = {}) {
        if (this.queryCompat) {
          const msg = exception.Message ?? additions.Message;
          const error4 = (0, import_smithy_client10.decorateServiceException)(exception, additions);
          if (msg) {
            error4.message = msg;
          }
          const errorObj = error4.Error ?? {};
          errorObj.Type = error4.Error?.Type;
          errorObj.Code = error4.Error?.Code;
          errorObj.Message = error4.Error?.message ?? error4.Error?.Message ?? msg;
          error4.Error = errorObj;
          const reqId = error4.$metadata.requestId;
          if (reqId) {
            error4.RequestId = reqId;
          }
          return error4;
        }
        return (0, import_smithy_client10.decorateServiceException)(exception, additions);
      }
      setQueryCompatError(output, response) {
        const queryErrorHeader = response.headers?.["x-amzn-query-error"];
        if (output !== void 0 && queryErrorHeader != null) {
          const [Code, Type] = queryErrorHeader.split(";");
          const keys = Object.keys(output);
          const Error2 = {
            Code,
            Type
          };
          output.Code = Code;
          output.Type = Type;
          for (let i32 = 0; i32 < keys.length; i32++) {
            const k32 = keys[i32];
            Error2[k32 === "message" ? "Message" : k32] = output[k32];
          }
          delete Error2.__type;
          output.Error = Error2;
        }
      }
      queryCompatOutput(queryCompatErrorData, errorData) {
        if (queryCompatErrorData.Error) {
          errorData.Error = queryCompatErrorData.Error;
        }
        if (queryCompatErrorData.Type) {
          errorData.Type = queryCompatErrorData.Type;
        }
        if (queryCompatErrorData.Code) {
          errorData.Code = queryCompatErrorData.Code;
        }
      }
      findQueryCompatibleError(registry, errorName) {
        try {
          return registry.getSchema(errorName);
        } catch (e32) {
          return registry.find((schema) => NormalizedSchema.of(schema).getMergedTraits().awsQueryError?.[0] === errorName);
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/cbor/AwsSmithyRpcV2CborProtocol.js
var AwsSmithyRpcV2CborProtocol;
var init_AwsSmithyRpcV2CborProtocol2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/cbor/AwsSmithyRpcV2CborProtocol.js"() {
    init_cbor2();
    init_schema4();
    init_ProtocolLib2();
    AwsSmithyRpcV2CborProtocol = class extends SmithyRpcV2CborProtocol {
      static {
        __name(this, "AwsSmithyRpcV2CborProtocol");
      }
      awsQueryCompatible;
      mixin;
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, awsQueryCompatible }) {
        super({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32 });
        this.awsQueryCompatible = !!awsQueryCompatible;
        this.mixin = new ProtocolLib2(this.awsQueryCompatible);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        if (this.awsQueryCompatible) {
          request4.headers["x-amzn-query-mode"] = "true";
        }
        return request4;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        if (this.awsQueryCompatible) {
          this.mixin.setQueryCompatError(dataObject, response);
        }
        const errorName = (() => {
          const compatHeader = response.headers["x-amzn-query-error"];
          if (compatHeader && this.awsQueryCompatible) {
            return compatHeader.split(";")[0];
          }
          return loadSmithyRpcV2CborErrorCode(response, dataObject) ?? "Unknown";
        })();
        this.mixin.compose(this.compositeErrorRegistry, errorName, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorName, this.options.defaultNamespace, response, dataObject, metadata, this.awsQueryCompatible ? this.mixin.findQueryCompatibleError : void 0);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        const output = {};
        for (const [name, member7] of ns.structIterator()) {
          if (dataObject[name] != null) {
            output[name] = this.deserializer.readValue(member7, dataObject[name]);
          }
        }
        if (this.awsQueryCompatible) {
          this.mixin.queryCompatOutput(dataObject, output);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/coercing-serializers.js
var _toStr, _toBool, _toNum;
var init_coercing_serializers2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/coercing-serializers.js"() {
    _toStr = /* @__PURE__ */ __name((val) => {
      if (val == null) {
        return val;
      }
      if (typeof val === "number" || typeof val === "bigint") {
        const warning2 = new Error(`Received number ${val} where a string was expected.`);
        warning2.name = "Warning";
        console.warn(warning2);
        return String(val);
      }
      if (typeof val === "boolean") {
        const warning2 = new Error(`Received boolean ${val} where a string was expected.`);
        warning2.name = "Warning";
        console.warn(warning2);
        return String(val);
      }
      return val;
    }, "_toStr");
    _toBool = /* @__PURE__ */ __name((val) => {
      if (val == null) {
        return val;
      }
      if (typeof val === "number") {
      }
      if (typeof val === "string") {
        const lowercase = val.toLowerCase();
        if (val !== "" && lowercase !== "false" && lowercase !== "true") {
          const warning2 = new Error(`Received string "${val}" where a boolean was expected.`);
          warning2.name = "Warning";
          console.warn(warning2);
        }
        return val !== "" && lowercase !== "false";
      }
      return val;
    }, "_toBool");
    _toNum = /* @__PURE__ */ __name((val) => {
      if (val == null) {
        return val;
      }
      if (typeof val === "boolean") {
      }
      if (typeof val === "string") {
        const num = Number(val);
        if (num.toString() !== val) {
          const warning2 = new Error(`Received string "${val}" where a number was expected.`);
          warning2.name = "Warning";
          console.warn(warning2);
          return val;
        }
        return num;
      }
      return val;
    }, "_toNum");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ConfigurableSerdeContext.js
var SerdeContextConfig2;
var init_ConfigurableSerdeContext2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ConfigurableSerdeContext.js"() {
    SerdeContextConfig2 = class {
      static {
        __name(this, "SerdeContextConfig");
      }
      serdeContext;
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/UnionSerde.js
var UnionSerde2;
var init_UnionSerde2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/UnionSerde.js"() {
    UnionSerde2 = class {
      static {
        __name(this, "UnionSerde");
      }
      from;
      to;
      keys;
      constructor(from, to) {
        this.from = from;
        this.to = to;
        const keys = Object.keys(this.from);
        const set = new Set(keys);
        set.delete("__type");
        this.keys = set;
      }
      mark(key) {
        this.keys.delete(key);
      }
      hasUnknown() {
        return this.keys.size === 1 && Object.keys(this.to).length === 0;
      }
      writeUnknown() {
        if (this.hasUnknown()) {
          const k32 = this.keys.values().next().value;
          const v = this.from[k32];
          this.to.$unknown = [k32, v];
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReviver.js
function jsonReviver2(key, value, context) {
  if (context?.source) {
    const numericString = context.source;
    if (typeof value === "number") {
      if (value > Number.MAX_SAFE_INTEGER || value < Number.MIN_SAFE_INTEGER || numericString !== String(value)) {
        const isFractional = numericString.includes(".");
        if (isFractional) {
          return new NumericValue(numericString, "bigDecimal");
        } else {
          return BigInt(numericString);
        }
      }
    }
  }
  return value;
}
var init_jsonReviver2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReviver.js"() {
    init_serde();
    __name(jsonReviver2, "jsonReviver");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/common.js
var import_smithy_client11, import_util_utf88, collectBodyString2;
var init_common3 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/common.js"() {
    import_smithy_client11 = __toESM(require_dist_cjs34());
    import_util_utf88 = __toESM(require_dist_cjs9());
    collectBodyString2 = /* @__PURE__ */ __name((streamBody, context) => (0, import_smithy_client11.collectBody)(streamBody, context).then((body) => (context?.utf8Encoder ?? import_util_utf88.toUtf8)(body)), "collectBodyString");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/parseJsonBody.js
var parseJsonBody2, parseJsonErrorBody, findKey2, sanitizeErrorCode2, loadRestJsonErrorCode2;
var init_parseJsonBody2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/parseJsonBody.js"() {
    init_common3();
    parseJsonBody2 = /* @__PURE__ */ __name((streamBody, context) => collectBodyString2(streamBody, context).then((encoded) => {
      if (encoded.length) {
        try {
          return JSON.parse(encoded);
        } catch (e32) {
          if (e32?.name === "SyntaxError") {
            Object.defineProperty(e32, "$responseBodyText", {
              value: encoded
            });
          }
          throw e32;
        }
      }
      return {};
    }), "parseJsonBody");
    parseJsonErrorBody = /* @__PURE__ */ __name(async (errorBody, context) => {
      const value = await parseJsonBody2(errorBody, context);
      value.message = value.message ?? value.Message;
      return value;
    }, "parseJsonErrorBody");
    findKey2 = /* @__PURE__ */ __name((object, key) => Object.keys(object).find((k32) => k32.toLowerCase() === key.toLowerCase()), "findKey");
    sanitizeErrorCode2 = /* @__PURE__ */ __name((rawValue) => {
      let cleanValue = rawValue;
      if (typeof cleanValue === "number") {
        cleanValue = cleanValue.toString();
      }
      if (cleanValue.indexOf(",") >= 0) {
        cleanValue = cleanValue.split(",")[0];
      }
      if (cleanValue.indexOf(":") >= 0) {
        cleanValue = cleanValue.split(":")[0];
      }
      if (cleanValue.indexOf("#") >= 0) {
        cleanValue = cleanValue.split("#")[1];
      }
      return cleanValue;
    }, "sanitizeErrorCode");
    loadRestJsonErrorCode2 = /* @__PURE__ */ __name((output, data3) => {
      const headerKey = findKey2(output.headers, "x-amzn-errortype");
      if (headerKey !== void 0) {
        return sanitizeErrorCode2(output.headers[headerKey]);
      }
      if (data3 && typeof data3 === "object") {
        const codeKey = findKey2(data3, "code");
        if (codeKey && data3[codeKey] !== void 0) {
          return sanitizeErrorCode2(data3[codeKey]);
        }
        if (data3["__type"] !== void 0) {
          return sanitizeErrorCode2(data3["__type"]);
        }
      }
    }, "loadRestJsonErrorCode");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeDeserializer.js
var import_util_base647, JsonShapeDeserializer2;
var init_JsonShapeDeserializer2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeDeserializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_util_base647 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext2();
    init_UnionSerde2();
    init_jsonReviver2();
    init_parseJsonBody2();
    JsonShapeDeserializer2 = class extends SerdeContextConfig2 {
      static {
        __name(this, "JsonShapeDeserializer");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      async read(schema, data3) {
        return this._read(schema, typeof data3 === "string" ? JSON.parse(data3, jsonReviver2) : await parseJsonBody2(data3, this.serdeContext));
      }
      readObject(schema, data3) {
        return this._read(schema, data3);
      }
      _read(schema, value) {
        const isObject3 = value !== null && typeof value === "object";
        const ns = NormalizedSchema.of(schema);
        if (isObject3) {
          if (ns.isStructSchema()) {
            const record = value;
            const union = ns.isUnionSchema();
            const out = {};
            let nameMap = void 0;
            const { jsonName } = this.settings;
            if (jsonName) {
              nameMap = {};
            }
            let unionSerde;
            if (union) {
              unionSerde = new UnionSerde2(record, out);
            }
            for (const [memberName, memberSchema] of ns.structIterator()) {
              let fromKey = memberName;
              if (jsonName) {
                fromKey = memberSchema.getMergedTraits().jsonName ?? fromKey;
                nameMap[fromKey] = memberName;
              }
              if (union) {
                unionSerde.mark(fromKey);
              }
              if (record[fromKey] != null) {
                out[memberName] = this._read(memberSchema, record[fromKey]);
              }
            }
            if (union) {
              unionSerde.writeUnknown();
            } else if (typeof record.__type === "string") {
              for (const k32 in record) {
                const v = record[k32];
                const t = jsonName ? nameMap[k32] ?? k32 : k32;
                if (!(t in out)) {
                  out[t] = v;
                }
              }
            }
            return out;
          }
          if (Array.isArray(value) && ns.isListSchema()) {
            const listMember = ns.getValueSchema();
            const out = [];
            for (const item of value) {
              out.push(this._read(listMember, item));
            }
            return out;
          }
          if (ns.isMapSchema()) {
            const mapMember = ns.getValueSchema();
            const out = {};
            for (const _k in value) {
              out[_k] = this._read(mapMember, value[_k]);
            }
            return out;
          }
        }
        if (ns.isBlobSchema() && typeof value === "string") {
          return (0, import_util_base647.fromBase64)(value);
        }
        const mediaType = ns.getMergedTraits().mediaType;
        if (ns.isStringSchema() && typeof value === "string" && mediaType) {
          const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
          if (isJson) {
            return LazyJsonString.from(value);
          }
          return value;
        }
        if (ns.isTimestampSchema() && value != null) {
          const format32 = determineTimestampFormat(ns, this.settings);
          switch (format32) {
            case 5:
              return parseRfc3339DateTimeWithOffset(value);
            case 6:
              return parseRfc7231DateTime(value);
            case 7:
              return parseEpochTimestamp(value);
            default:
              console.warn("Missing timestamp format, parsing value with Date constructor:", value);
              return new Date(value);
          }
        }
        if (ns.isBigIntegerSchema() && (typeof value === "number" || typeof value === "string")) {
          return BigInt(value);
        }
        if (ns.isBigDecimalSchema() && value != void 0) {
          if (value instanceof NumericValue) {
            return value;
          }
          const untyped = value;
          if (untyped.type === "bigDecimal" && "string" in untyped) {
            return new NumericValue(untyped.string, untyped.type);
          }
          return new NumericValue(String(value), "bigDecimal");
        }
        if (ns.isNumericSchema() && typeof value === "string") {
          switch (value) {
            case "Infinity":
              return Infinity;
            case "-Infinity":
              return -Infinity;
            case "NaN":
              return NaN;
          }
          return value;
        }
        if (ns.isDocumentSchema()) {
          if (isObject3) {
            const out = Array.isArray(value) ? [] : {};
            for (const k32 in value) {
              const v = value[k32];
              if (v instanceof NumericValue) {
                out[k32] = v;
              } else {
                out[k32] = this._read(ns, v);
              }
            }
            return out;
          } else {
            return structuredClone(value);
          }
        }
        return value;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReplacer.js
var NUMERIC_CONTROL_CHAR2, JsonReplacer2;
var init_jsonReplacer2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReplacer.js"() {
    init_serde();
    NUMERIC_CONTROL_CHAR2 = String.fromCharCode(925);
    JsonReplacer2 = class {
      static {
        __name(this, "JsonReplacer");
      }
      values = /* @__PURE__ */ new Map();
      counter = 0;
      stage = 0;
      createReplacer() {
        if (this.stage === 1) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer already created.");
        }
        if (this.stage === 2) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer exhausted.");
        }
        this.stage = 1;
        return (key, value) => {
          if (value instanceof NumericValue) {
            const v = `${NUMERIC_CONTROL_CHAR2 + "nv" + this.counter++}_` + value.string;
            this.values.set(`"${v}"`, value.string);
            return v;
          }
          if (typeof value === "bigint") {
            const s = value.toString();
            const v = `${NUMERIC_CONTROL_CHAR2 + "b" + this.counter++}_` + s;
            this.values.set(`"${v}"`, s);
            return v;
          }
          return value;
        };
      }
      replaceInJson(json) {
        if (this.stage === 0) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer not created yet.");
        }
        if (this.stage === 2) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer exhausted.");
        }
        this.stage = 2;
        if (this.counter === 0) {
          return json;
        }
        for (const [key, value] of this.values) {
          json = json.replace(key, value);
        }
        return json;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeSerializer.js
var import_util_base648, JsonShapeSerializer2;
var init_JsonShapeSerializer2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeSerializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_util_base648 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext2();
    init_jsonReplacer2();
    JsonShapeSerializer2 = class extends SerdeContextConfig2 {
      static {
        __name(this, "JsonShapeSerializer");
      }
      settings;
      buffer;
      useReplacer = false;
      rootSchema;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value) {
        this.rootSchema = NormalizedSchema.of(schema);
        this.buffer = this._write(this.rootSchema, value);
      }
      flush() {
        const { rootSchema, useReplacer } = this;
        this.rootSchema = void 0;
        this.useReplacer = false;
        if (rootSchema?.isStructSchema() || rootSchema?.isDocumentSchema()) {
          if (!useReplacer) {
            return JSON.stringify(this.buffer);
          }
          const replacer = new JsonReplacer2();
          return replacer.replaceInJson(JSON.stringify(this.buffer, replacer.createReplacer(), 0));
        }
        return this.buffer;
      }
      writeDiscriminatedDocument(schema, value) {
        this.write(schema, value);
        if (typeof this.buffer === "object") {
          this.buffer.__type = NormalizedSchema.of(schema).getName(true);
        }
      }
      _write(schema, value, container) {
        const isObject3 = value !== null && typeof value === "object";
        const ns = NormalizedSchema.of(schema);
        if (isObject3) {
          if (ns.isStructSchema()) {
            const record = value;
            const out = {};
            const { jsonName } = this.settings;
            let nameMap = void 0;
            if (jsonName) {
              nameMap = {};
            }
            let outCount = 0;
            for (const [memberName, memberSchema] of ns.structIterator()) {
              const serializableValue = this._write(memberSchema, record[memberName], ns);
              if (serializableValue !== void 0) {
                let targetKey = memberName;
                if (jsonName) {
                  targetKey = memberSchema.getMergedTraits().jsonName ?? memberName;
                  nameMap[memberName] = targetKey;
                }
                out[targetKey] = serializableValue;
                outCount++;
              }
            }
            if (ns.isUnionSchema() && outCount === 0) {
              const { $unknown } = record;
              if (Array.isArray($unknown)) {
                const [k32, v] = $unknown;
                out[k32] = this._write(15, v);
              }
            } else if (typeof record.__type === "string") {
              for (const k32 in record) {
                const v = record[k32];
                const targetKey = jsonName ? nameMap[k32] ?? k32 : k32;
                if (!(targetKey in out)) {
                  out[targetKey] = this._write(15, v);
                }
              }
            }
            return out;
          }
          if (Array.isArray(value) && ns.isListSchema()) {
            const listMember = ns.getValueSchema();
            const out = [];
            const sparse = !!ns.getMergedTraits().sparse;
            for (const item of value) {
              if (sparse || item != null) {
                out.push(this._write(listMember, item));
              }
            }
            return out;
          }
          if (ns.isMapSchema()) {
            const mapMember = ns.getValueSchema();
            const out = {};
            const sparse = !!ns.getMergedTraits().sparse;
            for (const _k in value) {
              const _v = value[_k];
              if (sparse || _v != null) {
                out[_k] = this._write(mapMember, _v);
              }
            }
            return out;
          }
          if (value instanceof Uint8Array && (ns.isBlobSchema() || ns.isDocumentSchema())) {
            if (ns === this.rootSchema) {
              return value;
            }
            return (this.serdeContext?.base64Encoder ?? import_util_base648.toBase64)(value);
          }
          if (value instanceof Date && (ns.isTimestampSchema() || ns.isDocumentSchema())) {
            const format32 = determineTimestampFormat(ns, this.settings);
            switch (format32) {
              case 5:
                return value.toISOString().replace(".000Z", "Z");
              case 6:
                return dateToUtcString(value);
              case 7:
                return value.getTime() / 1e3;
              default:
                console.warn("Missing timestamp format, using epoch seconds", value);
                return value.getTime() / 1e3;
            }
          }
          if (value instanceof NumericValue) {
            this.useReplacer = true;
          }
        }
        if (value === null && container?.isStructSchema()) {
          return void 0;
        }
        if (ns.isStringSchema()) {
          if (typeof value === "undefined" && ns.isIdempotencyToken()) {
            return (0, import_uuid.v4)();
          }
          const mediaType = ns.getMergedTraits().mediaType;
          if (value != null && mediaType) {
            const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
            if (isJson) {
              return LazyJsonString.from(value);
            }
          }
          return value;
        }
        if (typeof value === "number" && ns.isNumericSchema()) {
          if (Math.abs(value) === Infinity || isNaN(value)) {
            return String(value);
          }
          return value;
        }
        if (typeof value === "string" && ns.isBlobSchema()) {
          if (ns === this.rootSchema) {
            return value;
          }
          return (this.serdeContext?.base64Encoder ?? import_util_base648.toBase64)(value);
        }
        if (typeof value === "bigint") {
          this.useReplacer = true;
        }
        if (ns.isDocumentSchema()) {
          if (isObject3) {
            const out = Array.isArray(value) ? [] : {};
            for (const k32 in value) {
              const v = value[k32];
              if (v instanceof NumericValue) {
                this.useReplacer = true;
                out[k32] = v;
              } else {
                out[k32] = this._write(ns, v);
              }
            }
            return out;
          } else {
            return structuredClone(value);
          }
        }
        return value;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonCodec.js
var JsonCodec2;
var init_JsonCodec2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonCodec.js"() {
    init_ConfigurableSerdeContext2();
    init_JsonShapeDeserializer2();
    init_JsonShapeSerializer2();
    JsonCodec2 = class extends SerdeContextConfig2 {
      static {
        __name(this, "JsonCodec");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      createSerializer() {
        const serializer = new JsonShapeSerializer2(this.settings);
        serializer.setSerdeContext(this.serdeContext);
        return serializer;
      }
      createDeserializer() {
        const deserializer = new JsonShapeDeserializer2(this.settings);
        deserializer.setSerdeContext(this.serdeContext);
        return deserializer;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJsonRpcProtocol.js
var AwsJsonRpcProtocol;
var init_AwsJsonRpcProtocol2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJsonRpcProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib2();
    init_JsonCodec2();
    init_parseJsonBody2();
    AwsJsonRpcProtocol = class extends RpcProtocol {
      static {
        __name(this, "AwsJsonRpcProtocol");
      }
      serializer;
      deserializer;
      serviceTarget;
      codec;
      mixin;
      awsQueryCompatible;
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, serviceTarget, awsQueryCompatible, jsonCodec }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32
        });
        this.serviceTarget = serviceTarget;
        this.codec = jsonCodec ?? new JsonCodec2({
          timestampFormat: {
            useTrait: true,
            default: 7
          },
          jsonName: false
        });
        this.serializer = this.codec.createSerializer();
        this.deserializer = this.codec.createDeserializer();
        this.awsQueryCompatible = !!awsQueryCompatible;
        this.mixin = new ProtocolLib2(this.awsQueryCompatible);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        if (!request4.path.endsWith("/")) {
          request4.path += "/";
        }
        request4.headers["content-type"] = `application/x-amz-json-${this.getJsonRpcVersion()}`;
        request4.headers["x-amz-target"] = `${this.serviceTarget}.${operationSchema.name}`;
        if (this.awsQueryCompatible) {
          request4.headers["x-amzn-query-mode"] = "true";
        }
        if (deref(operationSchema.input) === "unit" || !request4.body) {
          request4.body = "{}";
        }
        return request4;
      }
      getPayloadCodec() {
        return this.codec;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        if (this.awsQueryCompatible) {
          this.mixin.setQueryCompatError(dataObject, response);
        }
        const errorIdentifier = loadRestJsonErrorCode2(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata, this.awsQueryCompatible ? this.mixin.findQueryCompatibleError : void 0);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          if (dataObject[name] != null) {
            output[name] = errorDeserializer.readObject(member7, dataObject[name]);
          }
        }
        if (this.awsQueryCompatible) {
          this.mixin.queryCompatOutput(dataObject, output);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_0Protocol.js
var AwsJson1_0Protocol;
var init_AwsJson1_0Protocol2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_0Protocol.js"() {
    init_AwsJsonRpcProtocol2();
    AwsJson1_0Protocol = class extends AwsJsonRpcProtocol {
      static {
        __name(this, "AwsJson1_0Protocol");
      }
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, serviceTarget, awsQueryCompatible, jsonCodec }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32,
          serviceTarget,
          awsQueryCompatible,
          jsonCodec
        });
      }
      getShapeId() {
        return "aws.protocols#awsJson1_0";
      }
      getJsonRpcVersion() {
        return "1.0";
      }
      getDefaultContentType() {
        return "application/x-amz-json-1.0";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_1Protocol.js
var AwsJson1_1Protocol;
var init_AwsJson1_1Protocol2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_1Protocol.js"() {
    init_AwsJsonRpcProtocol2();
    AwsJson1_1Protocol = class extends AwsJsonRpcProtocol {
      static {
        __name(this, "AwsJson1_1Protocol");
      }
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, serviceTarget, awsQueryCompatible, jsonCodec }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32,
          serviceTarget,
          awsQueryCompatible,
          jsonCodec
        });
      }
      getShapeId() {
        return "aws.protocols#awsJson1_1";
      }
      getJsonRpcVersion() {
        return "1.1";
      }
      getDefaultContentType() {
        return "application/x-amz-json-1.1";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsRestJsonProtocol.js
var AwsRestJsonProtocol2;
var init_AwsRestJsonProtocol2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsRestJsonProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib2();
    init_JsonCodec2();
    init_parseJsonBody2();
    AwsRestJsonProtocol2 = class extends HttpBindingProtocol {
      static {
        __name(this, "AwsRestJsonProtocol");
      }
      serializer;
      deserializer;
      codec;
      mixin = new ProtocolLib2();
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32 }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32
        });
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 7
          },
          httpBindings: true,
          jsonName: true
        };
        this.codec = new JsonCodec2(settings);
        this.serializer = new HttpInterceptingShapeSerializer(this.codec.createSerializer(), settings);
        this.deserializer = new HttpInterceptingShapeDeserializer(this.codec.createDeserializer(), settings);
      }
      getShapeId() {
        return "aws.protocols#restJson1";
      }
      getPayloadCodec() {
        return this.codec;
      }
      setSerdeContext(serdeContext) {
        this.codec.setSerdeContext(serdeContext);
        super.setSerdeContext(serdeContext);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        const inputSchema = NormalizedSchema.of(operationSchema.input);
        if (!request4.headers["content-type"]) {
          const contentType = this.mixin.resolveRestContentType(this.getDefaultContentType(), inputSchema);
          if (contentType) {
            request4.headers["content-type"] = contentType;
          }
        }
        if (request4.body == null && request4.headers["content-type"] === this.getDefaultContentType()) {
          request4.body = "{}";
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        const output = await super.deserializeResponse(operationSchema, context, response);
        const outputSchema = NormalizedSchema.of(operationSchema.output);
        for (const [name, member7] of outputSchema.structIterator()) {
          if (member7.getMemberTraits().httpPayload && !(name in output)) {
            output[name] = null;
          }
        }
        return output;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = loadRestJsonErrorCode2(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        await this.deserializeHttpMessage(errorSchema, context, response, dataObject);
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().jsonName ?? name;
          output[name] = errorDeserializer.readObject(member7, dataObject[target]);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      getDefaultContentType() {
        return "application/json";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/awsExpectUnion.js
var import_smithy_client12, awsExpectUnion;
var init_awsExpectUnion2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/awsExpectUnion.js"() {
    import_smithy_client12 = __toESM(require_dist_cjs34());
    awsExpectUnion = /* @__PURE__ */ __name((value) => {
      if (value == null) {
        return void 0;
      }
      if (typeof value === "object" && "__type" in value) {
        delete value.__type;
      }
      return (0, import_smithy_client12.expectUnion)(value);
    }, "awsExpectUnion");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeDeserializer.js
var import_xml_builder, import_smithy_client13, import_util_utf89, XmlShapeDeserializer;
var init_XmlShapeDeserializer2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeDeserializer.js"() {
    import_xml_builder = __toESM(require_dist_cjs47());
    init_protocols();
    init_schema4();
    import_smithy_client13 = __toESM(require_dist_cjs34());
    import_util_utf89 = __toESM(require_dist_cjs9());
    init_ConfigurableSerdeContext2();
    init_UnionSerde2();
    XmlShapeDeserializer = class extends SerdeContextConfig2 {
      static {
        __name(this, "XmlShapeDeserializer");
      }
      settings;
      stringDeserializer;
      constructor(settings) {
        super();
        this.settings = settings;
        this.stringDeserializer = new FromStringShapeDeserializer(settings);
      }
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
        this.stringDeserializer.setSerdeContext(serdeContext);
      }
      read(schema, bytes, key) {
        const ns = NormalizedSchema.of(schema);
        const memberSchemas = ns.getMemberSchemas();
        const isEventPayload = ns.isStructSchema() && ns.isMemberSchema() && !!Object.values(memberSchemas).find((memberNs) => {
          return !!memberNs.getMemberTraits().eventPayload;
        });
        if (isEventPayload) {
          const output = {};
          const memberName = Object.keys(memberSchemas)[0];
          const eventMemberSchema = memberSchemas[memberName];
          if (eventMemberSchema.isBlobSchema()) {
            output[memberName] = bytes;
          } else {
            output[memberName] = this.read(memberSchemas[memberName], bytes);
          }
          return output;
        }
        const xmlString = (this.serdeContext?.utf8Encoder ?? import_util_utf89.toUtf8)(bytes);
        const parsedObject = this.parseXml(xmlString);
        return this.readSchema(schema, key ? parsedObject[key] : parsedObject);
      }
      readSchema(_schema, value) {
        const ns = NormalizedSchema.of(_schema);
        if (ns.isUnitSchema()) {
          return;
        }
        const traits = ns.getMergedTraits();
        if (ns.isListSchema() && !Array.isArray(value)) {
          return this.readSchema(ns, [value]);
        }
        if (value == null) {
          return value;
        }
        if (typeof value === "object") {
          const flat = !!traits.xmlFlattened;
          if (ns.isListSchema()) {
            const listValue = ns.getValueSchema();
            const buffer2 = [];
            const sourceKey = listValue.getMergedTraits().xmlName ?? "member";
            const source = flat ? value : (value[0] ?? value)[sourceKey];
            if (source == null) {
              return buffer2;
            }
            const sourceArray = Array.isArray(source) ? source : [source];
            for (const v of sourceArray) {
              buffer2.push(this.readSchema(listValue, v));
            }
            return buffer2;
          }
          const buffer = {};
          if (ns.isMapSchema()) {
            const keyNs = ns.getKeySchema();
            const memberNs = ns.getValueSchema();
            let entries;
            if (flat) {
              entries = Array.isArray(value) ? value : [value];
            } else {
              entries = Array.isArray(value.entry) ? value.entry : [value.entry];
            }
            const keyProperty = keyNs.getMergedTraits().xmlName ?? "key";
            const valueProperty = memberNs.getMergedTraits().xmlName ?? "value";
            for (const entry of entries) {
              const key = entry[keyProperty];
              const value2 = entry[valueProperty];
              buffer[key] = this.readSchema(memberNs, value2);
            }
            return buffer;
          }
          if (ns.isStructSchema()) {
            const union = ns.isUnionSchema();
            let unionSerde;
            if (union) {
              unionSerde = new UnionSerde2(value, buffer);
            }
            for (const [memberName, memberSchema] of ns.structIterator()) {
              const memberTraits = memberSchema.getMergedTraits();
              const xmlObjectKey = !memberTraits.httpPayload ? memberSchema.getMemberTraits().xmlName ?? memberName : memberTraits.xmlName ?? memberSchema.getName();
              if (union) {
                unionSerde.mark(xmlObjectKey);
              }
              if (value[xmlObjectKey] != null) {
                buffer[memberName] = this.readSchema(memberSchema, value[xmlObjectKey]);
              }
            }
            if (union) {
              unionSerde.writeUnknown();
            }
            return buffer;
          }
          if (ns.isDocumentSchema()) {
            return value;
          }
          throw new Error(`@aws-sdk/core/protocols - xml deserializer unhandled schema type for ${ns.getName(true)}`);
        }
        if (ns.isListSchema()) {
          return [];
        }
        if (ns.isMapSchema() || ns.isStructSchema()) {
          return {};
        }
        return this.stringDeserializer.read(ns, value);
      }
      parseXml(xml) {
        if (xml.length) {
          let parsedObj;
          try {
            parsedObj = (0, import_xml_builder.parseXML)(xml);
          } catch (e32) {
            if (e32 && typeof e32 === "object") {
              Object.defineProperty(e32, "$responseBodyText", {
                value: xml
              });
            }
            throw e32;
          }
          const textNodeName = "#text";
          const key = Object.keys(parsedObj)[0];
          const parsedObjToReturn = parsedObj[key];
          if (parsedObjToReturn[textNodeName]) {
            parsedObjToReturn[key] = parsedObjToReturn[textNodeName];
            delete parsedObjToReturn[textNodeName];
          }
          return (0, import_smithy_client13.getValueFromTextNode)(parsedObjToReturn);
        }
        return {};
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QueryShapeSerializer.js
var import_smithy_client14, import_util_base649, QueryShapeSerializer;
var init_QueryShapeSerializer2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QueryShapeSerializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_smithy_client14 = __toESM(require_dist_cjs34());
    import_util_base649 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext2();
    QueryShapeSerializer = class extends SerdeContextConfig2 {
      static {
        __name(this, "QueryShapeSerializer");
      }
      settings;
      buffer;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value, prefix = "") {
        if (this.buffer === void 0) {
          this.buffer = "";
        }
        const ns = NormalizedSchema.of(schema);
        if (prefix && !prefix.endsWith(".")) {
          prefix += ".";
        }
        if (ns.isBlobSchema()) {
          if (typeof value === "string" || value instanceof Uint8Array) {
            this.writeKey(prefix);
            this.writeValue((this.serdeContext?.base64Encoder ?? import_util_base649.toBase64)(value));
          }
        } else if (ns.isBooleanSchema() || ns.isNumericSchema() || ns.isStringSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(String(value));
          } else if (ns.isIdempotencyToken()) {
            this.writeKey(prefix);
            this.writeValue((0, import_uuid.v4)());
          }
        } else if (ns.isBigIntegerSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(String(value));
          }
        } else if (ns.isBigDecimalSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(value instanceof NumericValue ? value.string : String(value));
          }
        } else if (ns.isTimestampSchema()) {
          if (value instanceof Date) {
            this.writeKey(prefix);
            const format32 = determineTimestampFormat(ns, this.settings);
            switch (format32) {
              case 5:
                this.writeValue(value.toISOString().replace(".000Z", "Z"));
                break;
              case 6:
                this.writeValue((0, import_smithy_client14.dateToUtcString)(value));
                break;
              case 7:
                this.writeValue(String(value.getTime() / 1e3));
                break;
            }
          }
        } else if (ns.isDocumentSchema()) {
          if (Array.isArray(value)) {
            this.write(64 | 15, value, prefix);
          } else if (value instanceof Date) {
            this.write(4, value, prefix);
          } else if (value instanceof Uint8Array) {
            this.write(21, value, prefix);
          } else if (value && typeof value === "object") {
            this.write(128 | 15, value, prefix);
          } else {
            this.writeKey(prefix);
            this.writeValue(String(value));
          }
        } else if (ns.isListSchema()) {
          if (Array.isArray(value)) {
            if (value.length === 0) {
              if (this.settings.serializeEmptyLists) {
                this.writeKey(prefix);
                this.writeValue("");
              }
            } else {
              const member7 = ns.getValueSchema();
              const flat = this.settings.flattenLists || ns.getMergedTraits().xmlFlattened;
              let i32 = 1;
              for (const item of value) {
                if (item == null) {
                  continue;
                }
                const traits = member7.getMergedTraits();
                const suffix = this.getKey("member", traits.xmlName, traits.ec2QueryName);
                const key = flat ? `${prefix}${i32}` : `${prefix}${suffix}.${i32}`;
                this.write(member7, item, key);
                ++i32;
              }
            }
          }
        } else if (ns.isMapSchema()) {
          if (value && typeof value === "object") {
            const keySchema = ns.getKeySchema();
            const memberSchema = ns.getValueSchema();
            const flat = ns.getMergedTraits().xmlFlattened;
            let i32 = 1;
            for (const k32 in value) {
              const v = value[k32];
              if (v == null) {
                continue;
              }
              const keyTraits = keySchema.getMergedTraits();
              const keySuffix = this.getKey("key", keyTraits.xmlName, keyTraits.ec2QueryName);
              const key = flat ? `${prefix}${i32}.${keySuffix}` : `${prefix}entry.${i32}.${keySuffix}`;
              const valTraits = memberSchema.getMergedTraits();
              const valueSuffix = this.getKey("value", valTraits.xmlName, valTraits.ec2QueryName);
              const valueKey = flat ? `${prefix}${i32}.${valueSuffix}` : `${prefix}entry.${i32}.${valueSuffix}`;
              this.write(keySchema, k32, key);
              this.write(memberSchema, v, valueKey);
              ++i32;
            }
          }
        } else if (ns.isStructSchema()) {
          if (value && typeof value === "object") {
            let didWriteMember = false;
            for (const [memberName, member7] of ns.structIterator()) {
              if (value[memberName] == null && !member7.isIdempotencyToken()) {
                continue;
              }
              const traits = member7.getMergedTraits();
              const suffix = this.getKey(memberName, traits.xmlName, traits.ec2QueryName, "struct");
              const key = `${prefix}${suffix}`;
              this.write(member7, value[memberName], key);
              didWriteMember = true;
            }
            if (!didWriteMember && ns.isUnionSchema()) {
              const { $unknown } = value;
              if (Array.isArray($unknown)) {
                const [k32, v] = $unknown;
                const key = `${prefix}${k32}`;
                this.write(15, v, key);
              }
            }
          }
        } else if (ns.isUnitSchema()) {
        } else {
          throw new Error(`@aws-sdk/core/protocols - QuerySerializer unrecognized schema type ${ns.getName(true)}`);
        }
      }
      flush() {
        if (this.buffer === void 0) {
          throw new Error("@aws-sdk/core/protocols - QuerySerializer cannot flush with nothing written to buffer.");
        }
        const str = this.buffer;
        delete this.buffer;
        return str;
      }
      getKey(memberName, xmlName, ec2QueryName, keySource) {
        const { ec2, capitalizeKeys } = this.settings;
        if (ec2 && ec2QueryName) {
          return ec2QueryName;
        }
        const key = xmlName ?? memberName;
        if (capitalizeKeys && keySource === "struct") {
          return key[0].toUpperCase() + key.slice(1);
        }
        return key;
      }
      writeKey(key) {
        if (key.endsWith(".")) {
          key = key.slice(0, key.length - 1);
        }
        this.buffer += `&${extendedEncodeURIComponent(key)}=`;
      }
      writeValue(value) {
        this.buffer += extendedEncodeURIComponent(value);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsQueryProtocol.js
var AwsQueryProtocol;
var init_AwsQueryProtocol2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsQueryProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib2();
    init_XmlShapeDeserializer2();
    init_QueryShapeSerializer2();
    AwsQueryProtocol = class extends RpcProtocol {
      static {
        __name(this, "AwsQueryProtocol");
      }
      options;
      serializer;
      deserializer;
      mixin = new ProtocolLib2();
      constructor(options) {
        super({
          defaultNamespace: options.defaultNamespace,
          errorTypeRegistries: options.errorTypeRegistries
        });
        this.options = options;
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 5
          },
          httpBindings: false,
          xmlNamespace: options.xmlNamespace,
          serviceNamespace: options.defaultNamespace,
          serializeEmptyLists: true
        };
        this.serializer = new QueryShapeSerializer(settings);
        this.deserializer = new XmlShapeDeserializer(settings);
      }
      getShapeId() {
        return "aws.protocols#awsQuery";
      }
      setSerdeContext(serdeContext) {
        this.serializer.setSerdeContext(serdeContext);
        this.deserializer.setSerdeContext(serdeContext);
      }
      getPayloadCodec() {
        throw new Error("AWSQuery protocol has no payload codec.");
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        if (!request4.path.endsWith("/")) {
          request4.path += "/";
        }
        request4.headers["content-type"] = "application/x-www-form-urlencoded";
        if (deref(operationSchema.input) === "unit" || !request4.body) {
          request4.body = "";
        }
        const action = operationSchema.name.split("#")[1] ?? operationSchema.name;
        request4.body = `Action=${action}&Version=${this.options.version}` + request4.body;
        if (request4.body.endsWith("&")) {
          request4.body = request4.body.slice(-1);
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        const deserializer = this.deserializer;
        const ns = NormalizedSchema.of(operationSchema.output);
        const dataObject = {};
        if (response.statusCode >= 300) {
          const bytes2 = await collectBody(response.body, context);
          if (bytes2.byteLength > 0) {
            Object.assign(dataObject, await deserializer.read(15, bytes2));
          }
          await this.handleError(operationSchema, context, response, dataObject, this.deserializeMetadata(response));
        }
        for (const header in response.headers) {
          const value = response.headers[header];
          delete response.headers[header];
          response.headers[header.toLowerCase()] = value;
        }
        const shortName = operationSchema.name.split("#")[1] ?? operationSchema.name;
        const awsQueryResultKey = ns.isStructSchema() && this.useNestedResult() ? shortName + "Result" : void 0;
        const bytes = await collectBody(response.body, context);
        if (bytes.byteLength > 0) {
          Object.assign(dataObject, await deserializer.read(ns, bytes, awsQueryResultKey));
        }
        dataObject.$metadata = this.deserializeMetadata(response);
        return dataObject;
      }
      useNestedResult() {
        return true;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = this.loadQueryErrorCode(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const errorData = this.loadQueryError(dataObject) ?? {};
        const message2 = this.loadQueryErrorMessage(dataObject);
        errorData.message = message2;
        errorData.Error = {
          Type: errorData.Type,
          Code: errorData.Code,
          Message: message2
        };
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, errorData, metadata, this.mixin.findQueryCompatibleError);
        const ns = NormalizedSchema.of(errorSchema);
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        const output = {
          Type: errorData.Error.Type,
          Code: errorData.Error.Code,
          Error: errorData.Error
        };
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().xmlName ?? name;
          const value = errorData[target] ?? dataObject[target];
          output[name] = this.deserializer.readSchema(member7, value);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      loadQueryErrorCode(output, data3) {
        const code = (data3.Errors?.[0]?.Error ?? data3.Errors?.Error ?? data3.Error)?.Code;
        if (code !== void 0) {
          return code;
        }
        if (output.statusCode == 404) {
          return "NotFound";
        }
      }
      loadQueryError(data3) {
        return data3.Errors?.[0]?.Error ?? data3.Errors?.Error ?? data3.Error;
      }
      loadQueryErrorMessage(data3) {
        const errorData = this.loadQueryError(data3);
        return errorData?.message ?? errorData?.Message ?? data3.message ?? data3.Message ?? "Unknown";
      }
      getDefaultContentType() {
        return "application/x-www-form-urlencoded";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsEc2QueryProtocol.js
var AwsEc2QueryProtocol;
var init_AwsEc2QueryProtocol2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsEc2QueryProtocol.js"() {
    init_AwsQueryProtocol2();
    AwsEc2QueryProtocol = class extends AwsQueryProtocol {
      static {
        __name(this, "AwsEc2QueryProtocol");
      }
      options;
      constructor(options) {
        super(options);
        this.options = options;
        const ec2Settings = {
          capitalizeKeys: true,
          flattenLists: true,
          serializeEmptyLists: false,
          ec2: true
        };
        Object.assign(this.serializer.settings, ec2Settings);
      }
      getShapeId() {
        return "aws.protocols#ec2Query";
      }
      useNestedResult() {
        return false;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QuerySerializerSettings.js
var init_QuerySerializerSettings2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QuerySerializerSettings.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/parseXmlBody.js
var import_xml_builder2, import_smithy_client15, parseXmlBody, parseXmlErrorBody, loadRestXmlErrorCode;
var init_parseXmlBody2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/parseXmlBody.js"() {
    import_xml_builder2 = __toESM(require_dist_cjs47());
    import_smithy_client15 = __toESM(require_dist_cjs34());
    init_common3();
    parseXmlBody = /* @__PURE__ */ __name((streamBody, context) => collectBodyString2(streamBody, context).then((encoded) => {
      if (encoded.length) {
        let parsedObj;
        try {
          parsedObj = (0, import_xml_builder2.parseXML)(encoded);
        } catch (e32) {
          if (e32 && typeof e32 === "object") {
            Object.defineProperty(e32, "$responseBodyText", {
              value: encoded
            });
          }
          throw e32;
        }
        const textNodeName = "#text";
        const key = Object.keys(parsedObj)[0];
        const parsedObjToReturn = parsedObj[key];
        if (parsedObjToReturn[textNodeName]) {
          parsedObjToReturn[key] = parsedObjToReturn[textNodeName];
          delete parsedObjToReturn[textNodeName];
        }
        return (0, import_smithy_client15.getValueFromTextNode)(parsedObjToReturn);
      }
      return {};
    }), "parseXmlBody");
    parseXmlErrorBody = /* @__PURE__ */ __name(async (errorBody, context) => {
      const value = await parseXmlBody(errorBody, context);
      if (value.Error) {
        value.Error.message = value.Error.message ?? value.Error.Message;
      }
      return value;
    }, "parseXmlErrorBody");
    loadRestXmlErrorCode = /* @__PURE__ */ __name((output, data3) => {
      if (data3?.Error?.Code !== void 0) {
        return data3.Error.Code;
      }
      if (data3?.Code !== void 0) {
        return data3.Code;
      }
      if (output.statusCode == 404) {
        return "NotFound";
      }
    }, "loadRestXmlErrorCode");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeSerializer.js
var import_xml_builder3, import_smithy_client16, import_util_base6410, XmlShapeSerializer;
var init_XmlShapeSerializer2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeSerializer.js"() {
    import_xml_builder3 = __toESM(require_dist_cjs47());
    init_protocols();
    init_schema4();
    init_serde();
    import_smithy_client16 = __toESM(require_dist_cjs34());
    import_util_base6410 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext2();
    XmlShapeSerializer = class extends SerdeContextConfig2 {
      static {
        __name(this, "XmlShapeSerializer");
      }
      settings;
      stringBuffer;
      byteBuffer;
      buffer;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value) {
        const ns = NormalizedSchema.of(schema);
        if (ns.isStringSchema() && typeof value === "string") {
          this.stringBuffer = value;
        } else if (ns.isBlobSchema()) {
          this.byteBuffer = "byteLength" in value ? value : (this.serdeContext?.base64Decoder ?? import_util_base6410.fromBase64)(value);
        } else {
          this.buffer = this.writeStruct(ns, value, void 0);
          const traits = ns.getMergedTraits();
          if (traits.httpPayload && !traits.xmlName) {
            this.buffer.withName(ns.getName());
          }
        }
      }
      flush() {
        if (this.byteBuffer !== void 0) {
          const bytes = this.byteBuffer;
          delete this.byteBuffer;
          return bytes;
        }
        if (this.stringBuffer !== void 0) {
          const str = this.stringBuffer;
          delete this.stringBuffer;
          return str;
        }
        const buffer = this.buffer;
        if (this.settings.xmlNamespace) {
          if (!buffer?.attributes?.["xmlns"]) {
            buffer.addAttribute("xmlns", this.settings.xmlNamespace);
          }
        }
        delete this.buffer;
        return buffer.toString();
      }
      writeStruct(ns, value, parentXmlns) {
        const traits = ns.getMergedTraits();
        const name = ns.isMemberSchema() && !traits.httpPayload ? ns.getMemberTraits().xmlName ?? ns.getMemberName() : traits.xmlName ?? ns.getName();
        if (!name || !ns.isStructSchema()) {
          throw new Error(`@aws-sdk/core/protocols - xml serializer, cannot write struct with empty name or non-struct, schema=${ns.getName(true)}.`);
        }
        const structXmlNode = import_xml_builder3.XmlNode.of(name);
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(ns, parentXmlns);
        for (const [memberName, memberSchema] of ns.structIterator()) {
          const val = value[memberName];
          if (val != null || memberSchema.isIdempotencyToken()) {
            if (memberSchema.getMergedTraits().xmlAttribute) {
              structXmlNode.addAttribute(memberSchema.getMergedTraits().xmlName ?? memberName, this.writeSimple(memberSchema, val));
              continue;
            }
            if (memberSchema.isListSchema()) {
              this.writeList(memberSchema, val, structXmlNode, xmlns);
            } else if (memberSchema.isMapSchema()) {
              this.writeMap(memberSchema, val, structXmlNode, xmlns);
            } else if (memberSchema.isStructSchema()) {
              structXmlNode.addChildNode(this.writeStruct(memberSchema, val, xmlns));
            } else {
              const memberNode = import_xml_builder3.XmlNode.of(memberSchema.getMergedTraits().xmlName ?? memberSchema.getMemberName());
              this.writeSimpleInto(memberSchema, val, memberNode, xmlns);
              structXmlNode.addChildNode(memberNode);
            }
          }
        }
        const { $unknown } = value;
        if ($unknown && ns.isUnionSchema() && Array.isArray($unknown) && Object.keys(value).length === 1) {
          const [k32, v] = $unknown;
          const node = import_xml_builder3.XmlNode.of(k32);
          if (typeof v !== "string") {
            if (value instanceof import_xml_builder3.XmlNode || value instanceof import_xml_builder3.XmlText) {
              structXmlNode.addChildNode(value);
            } else {
              throw new Error(`@aws-sdk - $unknown union member in XML requires value of type string, @aws-sdk/xml-builder::XmlNode or XmlText.`);
            }
          }
          this.writeSimpleInto(0, v, node, xmlns);
          structXmlNode.addChildNode(node);
        }
        if (xmlns) {
          structXmlNode.addAttribute(xmlnsAttr, xmlns);
        }
        return structXmlNode;
      }
      writeList(listMember, array, container, parentXmlns) {
        if (!listMember.isMemberSchema()) {
          throw new Error(`@aws-sdk/core/protocols - xml serializer, cannot write non-member list: ${listMember.getName(true)}`);
        }
        const listTraits = listMember.getMergedTraits();
        const listValueSchema = listMember.getValueSchema();
        const listValueTraits = listValueSchema.getMergedTraits();
        const sparse = !!listValueTraits.sparse;
        const flat = !!listTraits.xmlFlattened;
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(listMember, parentXmlns);
        const writeItem = /* @__PURE__ */ __name((container2, value) => {
          if (listValueSchema.isListSchema()) {
            this.writeList(listValueSchema, Array.isArray(value) ? value : [value], container2, xmlns);
          } else if (listValueSchema.isMapSchema()) {
            this.writeMap(listValueSchema, value, container2, xmlns);
          } else if (listValueSchema.isStructSchema()) {
            const struct3 = this.writeStruct(listValueSchema, value, xmlns);
            container2.addChildNode(struct3.withName(flat ? listTraits.xmlName ?? listMember.getMemberName() : listValueTraits.xmlName ?? "member"));
          } else {
            const listItemNode = import_xml_builder3.XmlNode.of(flat ? listTraits.xmlName ?? listMember.getMemberName() : listValueTraits.xmlName ?? "member");
            this.writeSimpleInto(listValueSchema, value, listItemNode, xmlns);
            container2.addChildNode(listItemNode);
          }
        }, "writeItem");
        if (flat) {
          for (const value of array) {
            if (sparse || value != null) {
              writeItem(container, value);
            }
          }
        } else {
          const listNode = import_xml_builder3.XmlNode.of(listTraits.xmlName ?? listMember.getMemberName());
          if (xmlns) {
            listNode.addAttribute(xmlnsAttr, xmlns);
          }
          for (const value of array) {
            if (sparse || value != null) {
              writeItem(listNode, value);
            }
          }
          container.addChildNode(listNode);
        }
      }
      writeMap(mapMember, map5, container, parentXmlns, containerIsMap = false) {
        if (!mapMember.isMemberSchema()) {
          throw new Error(`@aws-sdk/core/protocols - xml serializer, cannot write non-member map: ${mapMember.getName(true)}`);
        }
        const mapTraits = mapMember.getMergedTraits();
        const mapKeySchema = mapMember.getKeySchema();
        const mapKeyTraits = mapKeySchema.getMergedTraits();
        const keyTag = mapKeyTraits.xmlName ?? "key";
        const mapValueSchema = mapMember.getValueSchema();
        const mapValueTraits = mapValueSchema.getMergedTraits();
        const valueTag = mapValueTraits.xmlName ?? "value";
        const sparse = !!mapValueTraits.sparse;
        const flat = !!mapTraits.xmlFlattened;
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(mapMember, parentXmlns);
        const addKeyValue = /* @__PURE__ */ __name((entry, key, val) => {
          const keyNode = import_xml_builder3.XmlNode.of(keyTag, key);
          const [keyXmlnsAttr, keyXmlns] = this.getXmlnsAttribute(mapKeySchema, xmlns);
          if (keyXmlns) {
            keyNode.addAttribute(keyXmlnsAttr, keyXmlns);
          }
          entry.addChildNode(keyNode);
          let valueNode = import_xml_builder3.XmlNode.of(valueTag);
          if (mapValueSchema.isListSchema()) {
            this.writeList(mapValueSchema, val, valueNode, xmlns);
          } else if (mapValueSchema.isMapSchema()) {
            this.writeMap(mapValueSchema, val, valueNode, xmlns, true);
          } else if (mapValueSchema.isStructSchema()) {
            valueNode = this.writeStruct(mapValueSchema, val, xmlns);
          } else {
            this.writeSimpleInto(mapValueSchema, val, valueNode, xmlns);
          }
          entry.addChildNode(valueNode);
        }, "addKeyValue");
        if (flat) {
          for (const key in map5) {
            const val = map5[key];
            if (sparse || val != null) {
              const entry = import_xml_builder3.XmlNode.of(mapTraits.xmlName ?? mapMember.getMemberName());
              addKeyValue(entry, key, val);
              container.addChildNode(entry);
            }
          }
        } else {
          let mapNode;
          if (!containerIsMap) {
            mapNode = import_xml_builder3.XmlNode.of(mapTraits.xmlName ?? mapMember.getMemberName());
            if (xmlns) {
              mapNode.addAttribute(xmlnsAttr, xmlns);
            }
            container.addChildNode(mapNode);
          }
          for (const key in map5) {
            const val = map5[key];
            if (sparse || val != null) {
              const entry = import_xml_builder3.XmlNode.of("entry");
              addKeyValue(entry, key, val);
              (containerIsMap ? container : mapNode).addChildNode(entry);
            }
          }
        }
      }
      writeSimple(_schema, value) {
        if (null === value) {
          throw new Error("@aws-sdk/core/protocols - (XML serializer) cannot write null value.");
        }
        const ns = NormalizedSchema.of(_schema);
        let nodeContents = null;
        if (value && typeof value === "object") {
          if (ns.isBlobSchema()) {
            nodeContents = (this.serdeContext?.base64Encoder ?? import_util_base6410.toBase64)(value);
          } else if (ns.isTimestampSchema() && value instanceof Date) {
            const format32 = determineTimestampFormat(ns, this.settings);
            switch (format32) {
              case 5:
                nodeContents = value.toISOString().replace(".000Z", "Z");
                break;
              case 6:
                nodeContents = (0, import_smithy_client16.dateToUtcString)(value);
                break;
              case 7:
                nodeContents = String(value.getTime() / 1e3);
                break;
              default:
                console.warn("Missing timestamp format, using http date", value);
                nodeContents = (0, import_smithy_client16.dateToUtcString)(value);
                break;
            }
          } else if (ns.isBigDecimalSchema() && value) {
            if (value instanceof NumericValue) {
              return value.string;
            }
            return String(value);
          } else if (ns.isMapSchema() || ns.isListSchema()) {
            throw new Error("@aws-sdk/core/protocols - xml serializer, cannot call _write() on List/Map schema, call writeList or writeMap() instead.");
          } else {
            throw new Error(`@aws-sdk/core/protocols - xml serializer, unhandled schema type for object value and schema: ${ns.getName(true)}`);
          }
        }
        if (ns.isBooleanSchema() || ns.isNumericSchema() || ns.isBigIntegerSchema() || ns.isBigDecimalSchema()) {
          nodeContents = String(value);
        }
        if (ns.isStringSchema()) {
          if (value === void 0 && ns.isIdempotencyToken()) {
            nodeContents = (0, import_uuid.v4)();
          } else {
            nodeContents = String(value);
          }
        }
        if (nodeContents === null) {
          throw new Error(`Unhandled schema-value pair ${ns.getName(true)}=${value}`);
        }
        return nodeContents;
      }
      writeSimpleInto(_schema, value, into, parentXmlns) {
        const nodeContents = this.writeSimple(_schema, value);
        const ns = NormalizedSchema.of(_schema);
        const content = new import_xml_builder3.XmlText(nodeContents);
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(ns, parentXmlns);
        if (xmlns) {
          into.addAttribute(xmlnsAttr, xmlns);
        }
        into.addChildNode(content);
      }
      getXmlnsAttribute(ns, parentXmlns) {
        const traits = ns.getMergedTraits();
        const [prefix, xmlns] = traits.xmlNamespace ?? [];
        if (xmlns && xmlns !== parentXmlns) {
          return [prefix ? `xmlns:${prefix}` : "xmlns", xmlns];
        }
        return [void 0, void 0];
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlCodec.js
var XmlCodec;
var init_XmlCodec2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlCodec.js"() {
    init_ConfigurableSerdeContext2();
    init_XmlShapeDeserializer2();
    init_XmlShapeSerializer2();
    XmlCodec = class extends SerdeContextConfig2 {
      static {
        __name(this, "XmlCodec");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      createSerializer() {
        const serializer = new XmlShapeSerializer(this.settings);
        serializer.setSerdeContext(this.serdeContext);
        return serializer;
      }
      createDeserializer() {
        const deserializer = new XmlShapeDeserializer(this.settings);
        deserializer.setSerdeContext(this.serdeContext);
        return deserializer;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/AwsRestXmlProtocol.js
var AwsRestXmlProtocol;
var init_AwsRestXmlProtocol2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/AwsRestXmlProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib2();
    init_parseXmlBody2();
    init_XmlCodec2();
    AwsRestXmlProtocol = class extends HttpBindingProtocol {
      static {
        __name(this, "AwsRestXmlProtocol");
      }
      codec;
      serializer;
      deserializer;
      mixin = new ProtocolLib2();
      constructor(options) {
        super(options);
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 5
          },
          httpBindings: true,
          xmlNamespace: options.xmlNamespace,
          serviceNamespace: options.defaultNamespace
        };
        this.codec = new XmlCodec(settings);
        this.serializer = new HttpInterceptingShapeSerializer(this.codec.createSerializer(), settings);
        this.deserializer = new HttpInterceptingShapeDeserializer(this.codec.createDeserializer(), settings);
      }
      getPayloadCodec() {
        return this.codec;
      }
      getShapeId() {
        return "aws.protocols#restXml";
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        const inputSchema = NormalizedSchema.of(operationSchema.input);
        if (!request4.headers["content-type"]) {
          const contentType = this.mixin.resolveRestContentType(this.getDefaultContentType(), inputSchema);
          if (contentType) {
            request4.headers["content-type"] = contentType;
          }
        }
        if (typeof request4.body === "string" && request4.headers["content-type"] === this.getDefaultContentType() && !request4.body.startsWith("<?xml ") && !this.hasUnstructuredPayloadBinding(inputSchema)) {
          request4.body = '<?xml version="1.0" encoding="UTF-8"?>' + request4.body;
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        return super.deserializeResponse(operationSchema, context, response);
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = loadRestXmlErrorCode(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        if (dataObject.Error && typeof dataObject.Error === "object") {
          for (const key of Object.keys(dataObject.Error)) {
            dataObject[key] = dataObject.Error[key];
            if (key.toLowerCase() === "message") {
              dataObject.message = dataObject.Error[key];
            }
          }
        }
        if (dataObject.RequestId && !metadata.requestId) {
          metadata.requestId = dataObject.RequestId;
        }
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.Error?.message ?? dataObject.Error?.Message ?? dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        await this.deserializeHttpMessage(errorSchema, context, response, dataObject);
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().xmlName ?? name;
          const value = dataObject.Error?.[target] ?? dataObject[target];
          output[name] = errorDeserializer.readSchema(member7, value);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      getDefaultContentType() {
        return "application/xml";
      }
      hasUnstructuredPayloadBinding(ns) {
        for (const [, member7] of ns.structIterator()) {
          if (member7.getMergedTraits().httpPayload) {
            return !(member7.isStructSchema() || member7.isMapSchema() || member7.isListSchema());
          }
        }
        return false;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/index.js
var protocols_exports2 = {};
__export(protocols_exports2, {
  AwsEc2QueryProtocol: () => AwsEc2QueryProtocol,
  AwsJson1_0Protocol: () => AwsJson1_0Protocol,
  AwsJson1_1Protocol: () => AwsJson1_1Protocol,
  AwsJsonRpcProtocol: () => AwsJsonRpcProtocol,
  AwsQueryProtocol: () => AwsQueryProtocol,
  AwsRestJsonProtocol: () => AwsRestJsonProtocol2,
  AwsRestXmlProtocol: () => AwsRestXmlProtocol,
  AwsSmithyRpcV2CborProtocol: () => AwsSmithyRpcV2CborProtocol,
  JsonCodec: () => JsonCodec2,
  JsonShapeDeserializer: () => JsonShapeDeserializer2,
  JsonShapeSerializer: () => JsonShapeSerializer2,
  QueryShapeSerializer: () => QueryShapeSerializer,
  XmlCodec: () => XmlCodec,
  XmlShapeDeserializer: () => XmlShapeDeserializer,
  XmlShapeSerializer: () => XmlShapeSerializer,
  _toBool: () => _toBool,
  _toNum: () => _toNum,
  _toStr: () => _toStr,
  awsExpectUnion: () => awsExpectUnion,
  loadRestJsonErrorCode: () => loadRestJsonErrorCode2,
  loadRestXmlErrorCode: () => loadRestXmlErrorCode,
  parseJsonBody: () => parseJsonBody2,
  parseJsonErrorBody: () => parseJsonErrorBody,
  parseXmlBody: () => parseXmlBody,
  parseXmlErrorBody: () => parseXmlErrorBody
});
var init_protocols4 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/core/dist-es/submodules/protocols/index.js"() {
    init_AwsSmithyRpcV2CborProtocol2();
    init_coercing_serializers2();
    init_AwsJson1_0Protocol2();
    init_AwsJson1_1Protocol2();
    init_AwsJsonRpcProtocol2();
    init_AwsRestJsonProtocol2();
    init_JsonCodec2();
    init_JsonShapeDeserializer2();
    init_JsonShapeSerializer2();
    init_awsExpectUnion2();
    init_parseJsonBody2();
    init_AwsEc2QueryProtocol2();
    init_AwsQueryProtocol2();
    init_QuerySerializerSettings2();
    init_QueryShapeSerializer2();
    init_AwsRestXmlProtocol2();
    init_XmlCodec2();
    init_XmlShapeDeserializer2();
    init_XmlShapeSerializer2();
    init_parseXmlBody2();
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/bdd.js
var import_util_endpoints4, k2, a2, b2, c2, d2, e2, f2, g2, h2, i2, j2, _data2, root2, r2, nodes2, bdd2;
var init_bdd2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/bdd.js"() {
    import_util_endpoints4 = __toESM(require_dist_cjs20());
    k2 = "ref";
    a2 = -1;
    b2 = true;
    c2 = "isSet";
    d2 = "PartitionResult";
    e2 = "booleanEquals";
    f2 = "getAttr";
    g2 = { [k2]: "Endpoint" };
    h2 = { [k2]: d2 };
    i2 = {};
    j2 = [{ [k2]: "Region" }];
    _data2 = {
      conditions: [
        [c2, [g2]],
        [c2, j2],
        ["aws.partition", j2, d2],
        [e2, [{ [k2]: "UseFIPS" }, b2]],
        [e2, [{ [k2]: "UseDualStack" }, b2]],
        [e2, [{ fn: f2, argv: [h2, "supportsDualStack"] }, b2]],
        [e2, [{ fn: f2, argv: [h2, "supportsFIPS"] }, b2]],
        ["stringEquals", [{ fn: f2, argv: [h2, "name"] }, "aws-us-gov"]]
      ],
      results: [
        [a2],
        [a2, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a2, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [g2, i2],
        ["https://portal.sso-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", i2],
        [a2, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://portal.sso.{Region}.amazonaws.com", i2],
        ["https://portal.sso-fips.{Region}.{PartitionResult#dnsSuffix}", i2],
        [a2, "FIPS is enabled but this partition does not support FIPS"],
        ["https://portal.sso.{Region}.{PartitionResult#dualStackDnsSuffix}", i2],
        [a2, "DualStack is enabled but this partition does not support DualStack"],
        ["https://portal.sso.{Region}.{PartitionResult#dnsSuffix}", i2],
        [a2, "Invalid Configuration: Missing Region"]
      ]
    };
    root2 = 2;
    r2 = 1e8;
    nodes2 = new Int32Array([
      -1,
      1,
      -1,
      0,
      13,
      3,
      1,
      4,
      r2 + 12,
      2,
      5,
      r2 + 12,
      3,
      8,
      6,
      4,
      7,
      r2 + 11,
      5,
      r2 + 9,
      r2 + 10,
      4,
      11,
      9,
      6,
      10,
      r2 + 8,
      7,
      r2 + 6,
      r2 + 7,
      5,
      12,
      r2 + 5,
      6,
      r2 + 4,
      r2 + 5,
      3,
      r2 + 1,
      14,
      4,
      r2 + 2,
      r2 + 3
    ]);
    bdd2 = import_util_endpoints4.BinaryDecisionDiagram.from(nodes2, root2, _data2.conditions, _data2.results);
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/endpointResolver.js
var import_util_endpoints5, import_util_endpoints6, cache2, defaultEndpointResolver2;
var init_endpointResolver2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/endpointResolver.js"() {
    import_util_endpoints5 = __toESM(require_dist_cjs21());
    import_util_endpoints6 = __toESM(require_dist_cjs20());
    init_bdd2();
    cache2 = new import_util_endpoints6.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    defaultEndpointResolver2 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache2.get(endpointParams, () => (0, import_util_endpoints6.decideEndpoint)(bdd2, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    import_util_endpoints6.customEndpointFunctions.aws = import_util_endpoints5.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/SSOServiceException.js
var import_smithy_client17, SSOServiceException;
var init_SSOServiceException = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/SSOServiceException.js"() {
    import_smithy_client17 = __toESM(require_dist_cjs34());
    SSOServiceException = class _SSOServiceException extends import_smithy_client17.ServiceException {
      static {
        __name(this, "SSOServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _SSOServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/errors.js
var InvalidRequestException2, ResourceNotFoundException, TooManyRequestsException, UnauthorizedException;
var init_errors2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/errors.js"() {
    init_SSOServiceException();
    InvalidRequestException2 = class _InvalidRequestException extends SSOServiceException {
      static {
        __name(this, "InvalidRequestException");
      }
      name = "InvalidRequestException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidRequestException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidRequestException.prototype);
      }
    };
    ResourceNotFoundException = class _ResourceNotFoundException extends SSOServiceException {
      static {
        __name(this, "ResourceNotFoundException");
      }
      name = "ResourceNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ResourceNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceNotFoundException.prototype);
      }
    };
    TooManyRequestsException = class _TooManyRequestsException extends SSOServiceException {
      static {
        __name(this, "TooManyRequestsException");
      }
      name = "TooManyRequestsException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TooManyRequestsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyRequestsException.prototype);
      }
    };
    UnauthorizedException = class _UnauthorizedException extends SSOServiceException {
      static {
        __name(this, "UnauthorizedException");
      }
      name = "UnauthorizedException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "UnauthorizedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnauthorizedException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/schemas/schemas_0.js
var _ATT, _GRC, _GRCR, _GRCRe, _IRE2, _RC, _RNFE, _SAKT, _STT, _TMRE, _UE, _aI, _aKI, _aT2, _ai, _c2, _e2, _ex, _h2, _hE2, _hH, _hQ, _m, _rC, _rN, _rn, _s2, _sAK, _sT, _xasbt, n02, _s_registry2, SSOServiceException$, n0_registry2, InvalidRequestException$2, ResourceNotFoundException$, TooManyRequestsException$, UnauthorizedException$, errorTypeRegistries2, AccessTokenType, SecretAccessKeyType, SessionTokenType, GetRoleCredentialsRequest$, GetRoleCredentialsResponse$, RoleCredentials$, GetRoleCredentials$;
var init_schemas_02 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/schemas/schemas_0.js"() {
    init_schema4();
    init_errors2();
    init_SSOServiceException();
    _ATT = "AccessTokenType";
    _GRC = "GetRoleCredentials";
    _GRCR = "GetRoleCredentialsRequest";
    _GRCRe = "GetRoleCredentialsResponse";
    _IRE2 = "InvalidRequestException";
    _RC = "RoleCredentials";
    _RNFE = "ResourceNotFoundException";
    _SAKT = "SecretAccessKeyType";
    _STT = "SessionTokenType";
    _TMRE = "TooManyRequestsException";
    _UE = "UnauthorizedException";
    _aI = "accountId";
    _aKI = "accessKeyId";
    _aT2 = "accessToken";
    _ai = "account_id";
    _c2 = "client";
    _e2 = "error";
    _ex = "expiration";
    _h2 = "http";
    _hE2 = "httpError";
    _hH = "httpHeader";
    _hQ = "httpQuery";
    _m = "message";
    _rC = "roleCredentials";
    _rN = "roleName";
    _rn = "role_name";
    _s2 = "smithy.ts.sdk.synthetic.com.amazonaws.sso";
    _sAK = "secretAccessKey";
    _sT = "sessionToken";
    _xasbt = "x-amz-sso_bearer_token";
    n02 = "com.amazonaws.sso";
    _s_registry2 = TypeRegistry.for(_s2);
    SSOServiceException$ = [-3, _s2, "SSOServiceException", 0, [], []];
    _s_registry2.registerError(SSOServiceException$, SSOServiceException);
    n0_registry2 = TypeRegistry.for(n02);
    InvalidRequestException$2 = [-3, n02, _IRE2, { [_e2]: _c2, [_hE2]: 400 }, [_m], [0]];
    n0_registry2.registerError(InvalidRequestException$2, InvalidRequestException2);
    ResourceNotFoundException$ = [-3, n02, _RNFE, { [_e2]: _c2, [_hE2]: 404 }, [_m], [0]];
    n0_registry2.registerError(ResourceNotFoundException$, ResourceNotFoundException);
    TooManyRequestsException$ = [-3, n02, _TMRE, { [_e2]: _c2, [_hE2]: 429 }, [_m], [0]];
    n0_registry2.registerError(TooManyRequestsException$, TooManyRequestsException);
    UnauthorizedException$ = [-3, n02, _UE, { [_e2]: _c2, [_hE2]: 401 }, [_m], [0]];
    n0_registry2.registerError(UnauthorizedException$, UnauthorizedException);
    errorTypeRegistries2 = [_s_registry2, n0_registry2];
    AccessTokenType = [0, n02, _ATT, 8, 0];
    SecretAccessKeyType = [0, n02, _SAKT, 8, 0];
    SessionTokenType = [0, n02, _STT, 8, 0];
    GetRoleCredentialsRequest$ = [
      3,
      n02,
      _GRCR,
      0,
      [_rN, _aI, _aT2],
      [
        [0, { [_hQ]: _rn }],
        [0, { [_hQ]: _ai }],
        [() => AccessTokenType, { [_hH]: _xasbt }]
      ],
      3
    ];
    GetRoleCredentialsResponse$ = [
      3,
      n02,
      _GRCRe,
      0,
      [_rC],
      [[() => RoleCredentials$, 0]]
    ];
    RoleCredentials$ = [
      3,
      n02,
      _RC,
      0,
      [_aKI, _sAK, _sT, _ex],
      [0, [() => SecretAccessKeyType, 0], [() => SessionTokenType, 0], 1]
    ];
    GetRoleCredentials$ = [
      9,
      n02,
      _GRC,
      { [_h2]: ["GET", "/federation/credentials", 200] },
      () => GetRoleCredentialsRequest$,
      () => GetRoleCredentialsResponse$
    ];
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.shared.js
var import_smithy_client18, import_url_parser3, import_util_base6411, import_util_utf810, getRuntimeConfig3;
var init_runtimeConfig_shared2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.shared.js"() {
    init_httpAuthSchemes2();
    init_protocols4();
    init_dist_es();
    import_smithy_client18 = __toESM(require_dist_cjs34());
    import_url_parser3 = __toESM(require_dist_cjs18());
    import_util_base6411 = __toESM(require_dist_cjs10());
    import_util_utf810 = __toESM(require_dist_cjs9());
    init_httpAuthSchemeProvider2();
    init_endpointResolver2();
    init_schemas_02();
    getRuntimeConfig3 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2019-06-10",
        base64Decoder: config2?.base64Decoder ?? import_util_base6411.fromBase64,
        base64Encoder: config2?.base64Encoder ?? import_util_base6411.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver2,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSSOHttpAuthSchemeProvider,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        logger: config2?.logger ?? new import_smithy_client18.NoOpLogger(),
        protocol: config2?.protocol ?? AwsRestJsonProtocol2,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.sso",
          errorTypeRegistries: errorTypeRegistries2,
          version: "2019-06-10",
          serviceTarget: "SWBPortalService"
        },
        serviceId: config2?.serviceId ?? "SSO",
        urlParser: config2?.urlParser ?? import_url_parser3.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? import_util_utf810.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? import_util_utf810.toUtf8
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.js
var import_util_user_agent_node2, import_config_resolver3, import_hash_node2, import_middleware_retry3, import_node_config_provider2, import_node_http_handler2, import_smithy_client19, import_util_body_length_node2, import_util_defaults_mode_node2, import_util_retry4, getRuntimeConfig4;
var init_runtimeConfig2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.js"() {
    init_package2();
    init_client2();
    init_httpAuthSchemes2();
    import_util_user_agent_node2 = __toESM(require_dist_cjs50());
    import_config_resolver3 = __toESM(require_dist_cjs25());
    import_hash_node2 = __toESM(require_dist_cjs44());
    import_middleware_retry3 = __toESM(require_dist_cjs35());
    import_node_config_provider2 = __toESM(require_dist_cjs29());
    import_node_http_handler2 = __toESM(require_dist_cjs13());
    import_smithy_client19 = __toESM(require_dist_cjs34());
    import_util_body_length_node2 = __toESM(require_dist_cjs45());
    import_util_defaults_mode_node2 = __toESM(require_dist_cjs46());
    import_util_retry4 = __toESM(require_dist_cjs22());
    init_runtimeConfig_shared2();
    getRuntimeConfig4 = /* @__PURE__ */ __name((config2) => {
      (0, import_smithy_client19.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, import_util_defaults_mode_node2.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(import_smithy_client19.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig3(config2);
      emitWarningIfUnsupportedVersion(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, import_node_config_provider2.loadConfig)(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? import_util_body_length_node2.calculateBodyLength,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, import_util_user_agent_node2.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_default2.version }),
        maxAttempts: config2?.maxAttempts ?? (0, import_node_config_provider2.loadConfig)(import_middleware_retry3.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, import_node_config_provider2.loadConfig)(import_config_resolver3.NODE_REGION_CONFIG_OPTIONS, { ...import_config_resolver3.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: import_node_http_handler2.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, import_node_config_provider2.loadConfig)({
          ...import_middleware_retry3.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || import_util_retry4.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? import_hash_node2.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? import_node_http_handler2.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, import_node_config_provider2.loadConfig)(import_config_resolver3.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, import_node_config_provider2.loadConfig)(import_config_resolver3.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, import_node_config_provider2.loadConfig)(import_util_user_agent_node2.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration2, resolveHttpAuthRuntimeConfig2;
var init_httpAuthExtensionConfiguration2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration2 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig2 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeExtensions.js
var import_region_config_resolver2, import_protocol_http16, import_smithy_client20, resolveRuntimeExtensions2;
var init_runtimeExtensions2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeExtensions.js"() {
    import_region_config_resolver2 = __toESM(require_dist_cjs48());
    import_protocol_http16 = __toESM(require_dist_cjs2());
    import_smithy_client20 = __toESM(require_dist_cjs34());
    init_httpAuthExtensionConfiguration2();
    resolveRuntimeExtensions2 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign((0, import_region_config_resolver2.getAwsRegionExtensionConfiguration)(runtimeConfig), (0, import_smithy_client20.getDefaultExtensionConfiguration)(runtimeConfig), (0, import_protocol_http16.getHttpHandlerExtensionConfiguration)(runtimeConfig), getHttpAuthExtensionConfiguration2(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, (0, import_region_config_resolver2.resolveAwsRegionExtensionConfiguration)(extensionConfiguration), (0, import_smithy_client20.resolveDefaultRuntimeConfig)(extensionConfiguration), (0, import_protocol_http16.resolveHttpHandlerRuntimeConfig)(extensionConfiguration), resolveHttpAuthRuntimeConfig2(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSOClient.js
var import_middleware_host_header2, import_middleware_logger2, import_middleware_recursion_detection2, import_middleware_user_agent2, import_config_resolver4, import_middleware_content_length2, import_middleware_endpoint3, import_middleware_retry4, import_smithy_client21, SSOClient;
var init_SSOClient = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSOClient.js"() {
    import_middleware_host_header2 = __toESM(require_dist_cjs3());
    import_middleware_logger2 = __toESM(require_dist_cjs4());
    import_middleware_recursion_detection2 = __toESM(require_dist_cjs5());
    import_middleware_user_agent2 = __toESM(require_dist_cjs23());
    import_config_resolver4 = __toESM(require_dist_cjs25());
    init_dist_es();
    init_schema4();
    import_middleware_content_length2 = __toESM(require_dist_cjs26());
    import_middleware_endpoint3 = __toESM(require_dist_cjs31());
    import_middleware_retry4 = __toESM(require_dist_cjs35());
    import_smithy_client21 = __toESM(require_dist_cjs34());
    init_httpAuthSchemeProvider2();
    init_EndpointParameters2();
    init_runtimeConfig2();
    init_runtimeExtensions2();
    SSOClient = class extends import_smithy_client21.Client {
      static {
        __name(this, "SSOClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig4(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters2(_config_0);
        const _config_2 = (0, import_middleware_user_agent2.resolveUserAgentConfig)(_config_1);
        const _config_3 = (0, import_middleware_retry4.resolveRetryConfig)(_config_2);
        const _config_4 = (0, import_config_resolver4.resolveRegionConfig)(_config_3);
        const _config_5 = (0, import_middleware_host_header2.resolveHostHeaderConfig)(_config_4);
        const _config_6 = (0, import_middleware_endpoint3.resolveEndpointConfig)(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig2(_config_6);
        const _config_8 = resolveRuntimeExtensions2(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin(this.config));
        this.middlewareStack.use((0, import_middleware_user_agent2.getUserAgentPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_retry4.getRetryPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_content_length2.getContentLengthPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_host_header2.getHostHeaderPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_logger2.getLoggerPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_recursion_detection2.getRecursionDetectionPlugin)(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: defaultSSOHttpAuthSchemeParametersProvider,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/GetRoleCredentialsCommand.js
var import_middleware_endpoint4, import_smithy_client22, GetRoleCredentialsCommand;
var init_GetRoleCredentialsCommand = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/GetRoleCredentialsCommand.js"() {
    import_middleware_endpoint4 = __toESM(require_dist_cjs31());
    import_smithy_client22 = __toESM(require_dist_cjs34());
    init_EndpointParameters2();
    init_schemas_02();
    GetRoleCredentialsCommand = class extends import_smithy_client22.Command.classBuilder().ep(commonParams2).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint4.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("SWBPortalService", "GetRoleCredentials", {}).n("SSOClient", "GetRoleCredentialsCommand").sc(GetRoleCredentials$).build() {
      static {
        __name(this, "GetRoleCredentialsCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSO.js
var import_smithy_client23, commands2, SSO;
var init_SSO = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSO.js"() {
    import_smithy_client23 = __toESM(require_dist_cjs34());
    init_GetRoleCredentialsCommand();
    init_SSOClient();
    commands2 = {
      GetRoleCredentialsCommand
    };
    SSO = class extends SSOClient {
      static {
        __name(this, "SSO");
      }
    };
    (0, import_smithy_client23.createAggregatedClient)(commands2, SSO);
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/index.js
var init_commands3 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/index.js"() {
    init_GetRoleCredentialsCommand();
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/models_0.js
var init_models_02 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/index.js
var sso_exports = {};
__export(sso_exports, {
  $Command: () => import_smithy_client22.Command,
  GetRoleCredentials$: () => GetRoleCredentials$,
  GetRoleCredentialsCommand: () => GetRoleCredentialsCommand,
  GetRoleCredentialsRequest$: () => GetRoleCredentialsRequest$,
  GetRoleCredentialsResponse$: () => GetRoleCredentialsResponse$,
  InvalidRequestException: () => InvalidRequestException2,
  InvalidRequestException$: () => InvalidRequestException$2,
  ResourceNotFoundException: () => ResourceNotFoundException,
  ResourceNotFoundException$: () => ResourceNotFoundException$,
  RoleCredentials$: () => RoleCredentials$,
  SSO: () => SSO,
  SSOClient: () => SSOClient,
  SSOServiceException: () => SSOServiceException,
  SSOServiceException$: () => SSOServiceException$,
  TooManyRequestsException: () => TooManyRequestsException,
  TooManyRequestsException$: () => TooManyRequestsException$,
  UnauthorizedException: () => UnauthorizedException,
  UnauthorizedException$: () => UnauthorizedException$,
  __Client: () => import_smithy_client21.Client,
  errorTypeRegistries: () => errorTypeRegistries2
});
var init_sso = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/index.js"() {
    init_SSOClient();
    init_SSO();
    init_commands3();
    init_schemas_02();
    init_errors2();
    init_models_02();
    init_SSOServiceException();
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/loadSso-BKDNrsal.js
var require_loadSso_BKDNrsal = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/loadSso-BKDNrsal.js"(exports2) {
    "use strict";
    var sso = (init_sso(), __toCommonJS(sso_exports));
    exports2.GetRoleCredentialsCommand = sso.GetRoleCredentialsCommand;
    exports2.SSOClient = sso.SSOClient;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/index.js
var require_dist_cjs51 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/index.js"(exports2) {
    "use strict";
    var propertyProvider = require_dist_cjs27();
    var sharedIniFileLoader = require_dist_cjs28();
    var client = (init_client2(), __toCommonJS(client_exports));
    var tokenProviders = require_dist_cjs49();
    var isSsoProfile = /* @__PURE__ */ __name((arg) => arg && (typeof arg.sso_start_url === "string" || typeof arg.sso_account_id === "string" || typeof arg.sso_session === "string" || typeof arg.sso_region === "string" || typeof arg.sso_role_name === "string"), "isSsoProfile");
    var SHOULD_FAIL_CREDENTIAL_CHAIN = false;
    var resolveSSOCredentials = /* @__PURE__ */ __name(async ({ ssoStartUrl, ssoSession, ssoAccountId, ssoRegion, ssoRoleName, ssoClient, clientConfig, parentClientConfig, callerClientConfig, profile, filepath, configFilepath, ignoreCache, logger: logger5 }) => {
      let token;
      const refreshMessage = `To refresh this SSO session run aws sso login with the corresponding profile.`;
      if (ssoSession) {
        try {
          const _token = await tokenProviders.fromSso({
            profile,
            filepath,
            configFilepath,
            ignoreCache
          })();
          token = {
            accessToken: _token.token,
            expiresAt: new Date(_token.expiration).toISOString()
          };
        } catch (e32) {
          throw new propertyProvider.CredentialsProviderError(e32.message, {
            tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
            logger: logger5
          });
        }
      } else {
        try {
          token = await sharedIniFileLoader.getSSOTokenFromFile(ssoStartUrl);
        } catch (e32) {
          throw new propertyProvider.CredentialsProviderError(`The SSO session associated with this profile is invalid. ${refreshMessage}`, {
            tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
            logger: logger5
          });
        }
      }
      if (new Date(token.expiresAt).getTime() - Date.now() <= 0) {
        throw new propertyProvider.CredentialsProviderError(`The SSO session associated with this profile has expired. ${refreshMessage}`, {
          tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
          logger: logger5
        });
      }
      const { accessToken } = token;
      const { SSOClient: SSOClient10, GetRoleCredentialsCommand: GetRoleCredentialsCommand10 } = await Promise.resolve().then(function() {
        return require_loadSso_BKDNrsal();
      });
      const sso = ssoClient || new SSOClient10(Object.assign({}, clientConfig ?? {}, {
        logger: clientConfig?.logger ?? callerClientConfig?.logger ?? parentClientConfig?.logger,
        region: clientConfig?.region ?? ssoRegion,
        userAgentAppId: clientConfig?.userAgentAppId ?? callerClientConfig?.userAgentAppId ?? parentClientConfig?.userAgentAppId
      }));
      let ssoResp;
      try {
        ssoResp = await sso.send(new GetRoleCredentialsCommand10({
          accountId: ssoAccountId,
          roleName: ssoRoleName,
          accessToken
        }));
      } catch (e32) {
        throw new propertyProvider.CredentialsProviderError(e32, {
          tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
          logger: logger5
        });
      }
      const { roleCredentials: { accessKeyId, secretAccessKey, sessionToken, expiration, credentialScope, accountId } = {} } = ssoResp;
      if (!accessKeyId || !secretAccessKey || !sessionToken || !expiration) {
        throw new propertyProvider.CredentialsProviderError("SSO returns an invalid temporary credential.", {
          tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
          logger: logger5
        });
      }
      const credentials = {
        accessKeyId,
        secretAccessKey,
        sessionToken,
        expiration: new Date(expiration),
        ...credentialScope && { credentialScope },
        ...accountId && { accountId }
      };
      if (ssoSession) {
        client.setCredentialFeature(credentials, "CREDENTIALS_SSO", "s");
      } else {
        client.setCredentialFeature(credentials, "CREDENTIALS_SSO_LEGACY", "u");
      }
      return credentials;
    }, "resolveSSOCredentials");
    var validateSsoProfile = /* @__PURE__ */ __name((profile, logger5) => {
      const { sso_start_url, sso_account_id, sso_region, sso_role_name } = profile;
      if (!sso_start_url || !sso_account_id || !sso_region || !sso_role_name) {
        throw new propertyProvider.CredentialsProviderError(`Profile is configured with invalid SSO credentials. Required parameters "sso_account_id", "sso_region", "sso_role_name", "sso_start_url". Got ${Object.keys(profile).join(", ")}
Reference: https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-sso.html`, { tryNextLink: false, logger: logger5 });
      }
      return profile;
    }, "validateSsoProfile");
    var fromSSO = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/credential-provider-sso - fromSSO");
      const { ssoStartUrl, ssoAccountId, ssoRegion, ssoRoleName, ssoSession } = init;
      const { ssoClient } = init;
      const profileName = sharedIniFileLoader.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      });
      if (!ssoStartUrl && !ssoAccountId && !ssoRegion && !ssoRoleName && !ssoSession) {
        const profiles = await sharedIniFileLoader.parseKnownFiles(init);
        const profile = profiles[profileName];
        if (!profile) {
          throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} was not found.`, { logger: init.logger });
        }
        if (!isSsoProfile(profile)) {
          throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} is not configured with SSO credentials.`, {
            logger: init.logger
          });
        }
        if (profile?.sso_session) {
          const ssoSessions = await sharedIniFileLoader.loadSsoSessionData(init);
          const session = ssoSessions[profile.sso_session];
          const conflictMsg = ` configurations in profile ${profileName} and sso-session ${profile.sso_session}`;
          if (ssoRegion && ssoRegion !== session.sso_region) {
            throw new propertyProvider.CredentialsProviderError(`Conflicting SSO region` + conflictMsg, {
              tryNextLink: false,
              logger: init.logger
            });
          }
          if (ssoStartUrl && ssoStartUrl !== session.sso_start_url) {
            throw new propertyProvider.CredentialsProviderError(`Conflicting SSO start_url` + conflictMsg, {
              tryNextLink: false,
              logger: init.logger
            });
          }
          profile.sso_region = session.sso_region;
          profile.sso_start_url = session.sso_start_url;
        }
        const { sso_start_url, sso_account_id, sso_region, sso_role_name, sso_session } = validateSsoProfile(profile, init.logger);
        return resolveSSOCredentials({
          ssoStartUrl: sso_start_url,
          ssoSession: sso_session,
          ssoAccountId: sso_account_id,
          ssoRegion: sso_region,
          ssoRoleName: sso_role_name,
          ssoClient,
          clientConfig: init.clientConfig,
          parentClientConfig: init.parentClientConfig,
          callerClientConfig: init.callerClientConfig,
          profile: profileName,
          filepath: init.filepath,
          configFilepath: init.configFilepath,
          ignoreCache: init.ignoreCache,
          logger: init.logger
        });
      } else if (!ssoStartUrl || !ssoAccountId || !ssoRegion || !ssoRoleName) {
        throw new propertyProvider.CredentialsProviderError('Incomplete configuration. The fromSSO() argument hash must include "ssoStartUrl", "ssoAccountId", "ssoRegion", "ssoRoleName"', { tryNextLink: false, logger: init.logger });
      } else {
        return resolveSSOCredentials({
          ssoStartUrl,
          ssoSession,
          ssoAccountId,
          ssoRegion,
          ssoRoleName,
          ssoClient,
          clientConfig: init.clientConfig,
          parentClientConfig: init.parentClientConfig,
          callerClientConfig: init.callerClientConfig,
          profile: profileName,
          filepath: init.filepath,
          configFilepath: init.configFilepath,
          ignoreCache: init.ignoreCache,
          logger: init.logger
        });
      }
    }, "fromSSO");
    exports2.fromSSO = fromSSO;
    exports2.isSsoProfile = isSsoProfile;
    exports2.validateSsoProfile = validateSsoProfile;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption3(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "signin",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption3(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var import_util_middleware8, defaultSigninHttpAuthSchemeParametersProvider, defaultSigninHttpAuthSchemeProvider, resolveHttpAuthSchemeConfig3;
var init_httpAuthSchemeProvider3 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes2();
    import_util_middleware8 = __toESM(require_dist_cjs6());
    defaultSigninHttpAuthSchemeParametersProvider = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, import_util_middleware8.getSmithyContext)(context).operation,
        region: await (0, import_util_middleware8.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultSigninHttpAuthSchemeParametersProvider");
    __name(createAwsAuthSigv4HttpAuthOption3, "createAwsAuthSigv4HttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption3, "createSmithyApiNoAuthHttpAuthOption");
    defaultSigninHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "CreateOAuth2Token": {
          options.push(createSmithyApiNoAuthHttpAuthOption3(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption3(authParameters));
        }
      }
      return options;
    }, "defaultSigninHttpAuthSchemeProvider");
    resolveHttpAuthSchemeConfig3 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveAwsSdkSigV4Config(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, import_util_middleware8.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/EndpointParameters.js
var resolveClientEndpointParameters3, commonParams3;
var init_EndpointParameters3 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters3 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "signin"
      });
    }, "resolveClientEndpointParameters");
    commonParams3 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/bdd.js
var import_util_endpoints7, m, a3, b3, c3, d3, e3, f3, g3, h3, i3, j3, k3, l, _data3, root3, r3, nodes3, bdd3;
var init_bdd3 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/bdd.js"() {
    import_util_endpoints7 = __toESM(require_dist_cjs20());
    m = "ref";
    a3 = -1;
    b3 = true;
    c3 = "isSet";
    d3 = "PartitionResult";
    e3 = "booleanEquals";
    f3 = "getAttr";
    g3 = "stringEquals";
    h3 = { [m]: "Endpoint" };
    i3 = { [m]: d3 };
    j3 = { fn: f3, argv: [i3, "name"] };
    k3 = {};
    l = [{ [m]: "Region" }];
    _data3 = {
      conditions: [
        [c3, [h3]],
        [c3, l],
        ["aws.partition", l, d3],
        [e3, [{ [m]: "UseFIPS" }, b3]],
        [e3, [{ [m]: "UseDualStack" }, b3]],
        [e3, [{ fn: f3, argv: [i3, "supportsDualStack"] }, b3]],
        [e3, [{ fn: f3, argv: [i3, "supportsFIPS"] }, b3]],
        [g3, [j3, "aws"]],
        [g3, [j3, "aws-cn"]],
        [g3, [j3, "aws-us-gov"]]
      ],
      results: [
        [a3],
        [a3, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a3, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [h3, k3],
        ["https://{Region}.signin.aws.amazon.com", k3],
        ["https://{Region}.signin.amazonaws.cn", k3],
        ["https://{Region}.signin.amazonaws-us-gov.com", k3],
        ["https://signin-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", k3],
        [a3, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://signin-fips.{Region}.{PartitionResult#dnsSuffix}", k3],
        [a3, "FIPS is enabled but this partition does not support FIPS"],
        ["https://signin.{Region}.{PartitionResult#dualStackDnsSuffix}", k3],
        [a3, "DualStack is enabled but this partition does not support DualStack"],
        ["https://signin.{Region}.{PartitionResult#dnsSuffix}", k3],
        [a3, "Invalid Configuration: Missing Region"]
      ]
    };
    root3 = 2;
    r3 = 1e8;
    nodes3 = new Int32Array([
      -1,
      1,
      -1,
      0,
      15,
      3,
      1,
      4,
      r3 + 14,
      2,
      5,
      r3 + 14,
      3,
      11,
      6,
      4,
      10,
      7,
      7,
      r3 + 4,
      8,
      8,
      r3 + 5,
      9,
      9,
      r3 + 6,
      r3 + 13,
      5,
      r3 + 11,
      r3 + 12,
      4,
      13,
      12,
      6,
      r3 + 9,
      r3 + 10,
      5,
      14,
      r3 + 8,
      6,
      r3 + 7,
      r3 + 8,
      3,
      r3 + 1,
      16,
      4,
      r3 + 2,
      r3 + 3
    ]);
    bdd3 = import_util_endpoints7.BinaryDecisionDiagram.from(nodes3, root3, _data3.conditions, _data3.results);
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/endpointResolver.js
var import_util_endpoints8, import_util_endpoints9, cache3, defaultEndpointResolver3;
var init_endpointResolver3 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/endpointResolver.js"() {
    import_util_endpoints8 = __toESM(require_dist_cjs21());
    import_util_endpoints9 = __toESM(require_dist_cjs20());
    init_bdd3();
    cache3 = new import_util_endpoints9.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    defaultEndpointResolver3 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache3.get(endpointParams, () => (0, import_util_endpoints9.decideEndpoint)(bdd3, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    import_util_endpoints9.customEndpointFunctions.aws = import_util_endpoints8.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/SigninServiceException.js
var import_smithy_client24, SigninServiceException;
var init_SigninServiceException = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/SigninServiceException.js"() {
    import_smithy_client24 = __toESM(require_dist_cjs34());
    SigninServiceException = class _SigninServiceException extends import_smithy_client24.ServiceException {
      static {
        __name(this, "SigninServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _SigninServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/errors.js
var AccessDeniedException2, InternalServerException2, TooManyRequestsError, ValidationException;
var init_errors3 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/errors.js"() {
    init_SigninServiceException();
    AccessDeniedException2 = class _AccessDeniedException extends SigninServiceException {
      static {
        __name(this, "AccessDeniedException");
      }
      name = "AccessDeniedException";
      $fault = "client";
      error;
      constructor(opts) {
        super({
          name: "AccessDeniedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AccessDeniedException.prototype);
        this.error = opts.error;
      }
    };
    InternalServerException2 = class _InternalServerException extends SigninServiceException {
      static {
        __name(this, "InternalServerException");
      }
      name = "InternalServerException";
      $fault = "server";
      error;
      constructor(opts) {
        super({
          name: "InternalServerException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _InternalServerException.prototype);
        this.error = opts.error;
      }
    };
    TooManyRequestsError = class _TooManyRequestsError extends SigninServiceException {
      static {
        __name(this, "TooManyRequestsError");
      }
      name = "TooManyRequestsError";
      $fault = "client";
      error;
      constructor(opts) {
        super({
          name: "TooManyRequestsError",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyRequestsError.prototype);
        this.error = opts.error;
      }
    };
    ValidationException = class _ValidationException extends SigninServiceException {
      static {
        __name(this, "ValidationException");
      }
      name = "ValidationException";
      $fault = "client";
      error;
      constructor(opts) {
        super({
          name: "ValidationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ValidationException.prototype);
        this.error = opts.error;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/schemas/schemas_0.js
var _ADE2, _AT2, _COAT, _COATR, _COATRB, _COATRBr, _COATRr, _ISE2, _RT2, _TMRE2, _VE, _aKI2, _aT3, _c3, _cI2, _cV2, _co2, _e3, _eI2, _gT2, _h3, _hE3, _iT2, _jN, _m2, _rT2, _rU2, _s3, _sAK2, _sT2, _se2, _tI, _tO, _tT2, n03, _s_registry3, SigninServiceException$, n0_registry3, AccessDeniedException$2, InternalServerException$2, TooManyRequestsError$, ValidationException$, errorTypeRegistries3, RefreshToken2, AccessToken$, CreateOAuth2TokenRequest$, CreateOAuth2TokenRequestBody$, CreateOAuth2TokenResponse$, CreateOAuth2TokenResponseBody$, CreateOAuth2Token$;
var init_schemas_03 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/schemas/schemas_0.js"() {
    init_schema4();
    init_errors3();
    init_SigninServiceException();
    _ADE2 = "AccessDeniedException";
    _AT2 = "AccessToken";
    _COAT = "CreateOAuth2Token";
    _COATR = "CreateOAuth2TokenRequest";
    _COATRB = "CreateOAuth2TokenRequestBody";
    _COATRBr = "CreateOAuth2TokenResponseBody";
    _COATRr = "CreateOAuth2TokenResponse";
    _ISE2 = "InternalServerException";
    _RT2 = "RefreshToken";
    _TMRE2 = "TooManyRequestsError";
    _VE = "ValidationException";
    _aKI2 = "accessKeyId";
    _aT3 = "accessToken";
    _c3 = "client";
    _cI2 = "clientId";
    _cV2 = "codeVerifier";
    _co2 = "code";
    _e3 = "error";
    _eI2 = "expiresIn";
    _gT2 = "grantType";
    _h3 = "http";
    _hE3 = "httpError";
    _iT2 = "idToken";
    _jN = "jsonName";
    _m2 = "message";
    _rT2 = "refreshToken";
    _rU2 = "redirectUri";
    _s3 = "smithy.ts.sdk.synthetic.com.amazonaws.signin";
    _sAK2 = "secretAccessKey";
    _sT2 = "sessionToken";
    _se2 = "server";
    _tI = "tokenInput";
    _tO = "tokenOutput";
    _tT2 = "tokenType";
    n03 = "com.amazonaws.signin";
    _s_registry3 = TypeRegistry.for(_s3);
    SigninServiceException$ = [-3, _s3, "SigninServiceException", 0, [], []];
    _s_registry3.registerError(SigninServiceException$, SigninServiceException);
    n0_registry3 = TypeRegistry.for(n03);
    AccessDeniedException$2 = [-3, n03, _ADE2, { [_e3]: _c3 }, [_e3, _m2], [0, 0], 2];
    n0_registry3.registerError(AccessDeniedException$2, AccessDeniedException2);
    InternalServerException$2 = [-3, n03, _ISE2, { [_e3]: _se2, [_hE3]: 500 }, [_e3, _m2], [0, 0], 2];
    n0_registry3.registerError(InternalServerException$2, InternalServerException2);
    TooManyRequestsError$ = [-3, n03, _TMRE2, { [_e3]: _c3, [_hE3]: 429 }, [_e3, _m2], [0, 0], 2];
    n0_registry3.registerError(TooManyRequestsError$, TooManyRequestsError);
    ValidationException$ = [-3, n03, _VE, { [_e3]: _c3, [_hE3]: 400 }, [_e3, _m2], [0, 0], 2];
    n0_registry3.registerError(ValidationException$, ValidationException);
    errorTypeRegistries3 = [_s_registry3, n0_registry3];
    RefreshToken2 = [0, n03, _RT2, 8, 0];
    AccessToken$ = [
      3,
      n03,
      _AT2,
      8,
      [_aKI2, _sAK2, _sT2],
      [
        [0, { [_jN]: _aKI2 }],
        [0, { [_jN]: _sAK2 }],
        [0, { [_jN]: _sT2 }]
      ],
      3
    ];
    CreateOAuth2TokenRequest$ = [
      3,
      n03,
      _COATR,
      0,
      [_tI],
      [[() => CreateOAuth2TokenRequestBody$, 16]],
      1
    ];
    CreateOAuth2TokenRequestBody$ = [
      3,
      n03,
      _COATRB,
      0,
      [_cI2, _gT2, _co2, _rU2, _cV2, _rT2],
      [
        [0, { [_jN]: _cI2 }],
        [0, { [_jN]: _gT2 }],
        0,
        [0, { [_jN]: _rU2 }],
        [0, { [_jN]: _cV2 }],
        [() => RefreshToken2, { [_jN]: _rT2 }]
      ],
      2
    ];
    CreateOAuth2TokenResponse$ = [
      3,
      n03,
      _COATRr,
      0,
      [_tO],
      [[() => CreateOAuth2TokenResponseBody$, 16]],
      1
    ];
    CreateOAuth2TokenResponseBody$ = [
      3,
      n03,
      _COATRBr,
      0,
      [_aT3, _tT2, _eI2, _rT2, _iT2],
      [
        [() => AccessToken$, { [_jN]: _aT3 }],
        [0, { [_jN]: _tT2 }],
        [1, { [_jN]: _eI2 }],
        [() => RefreshToken2, { [_jN]: _rT2 }],
        [0, { [_jN]: _iT2 }]
      ],
      4
    ];
    CreateOAuth2Token$ = [
      9,
      n03,
      _COAT,
      { [_h3]: ["POST", "/v1/token", 200] },
      () => CreateOAuth2TokenRequest$,
      () => CreateOAuth2TokenResponse$
    ];
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.shared.js
var import_smithy_client25, import_url_parser4, import_util_base6412, import_util_utf811, getRuntimeConfig5;
var init_runtimeConfig_shared3 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.shared.js"() {
    init_httpAuthSchemes2();
    init_protocols4();
    init_dist_es();
    import_smithy_client25 = __toESM(require_dist_cjs34());
    import_url_parser4 = __toESM(require_dist_cjs18());
    import_util_base6412 = __toESM(require_dist_cjs10());
    import_util_utf811 = __toESM(require_dist_cjs9());
    init_httpAuthSchemeProvider3();
    init_endpointResolver3();
    init_schemas_03();
    getRuntimeConfig5 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2023-01-01",
        base64Decoder: config2?.base64Decoder ?? import_util_base6412.fromBase64,
        base64Encoder: config2?.base64Encoder ?? import_util_base6412.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver3,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSigninHttpAuthSchemeProvider,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        logger: config2?.logger ?? new import_smithy_client25.NoOpLogger(),
        protocol: config2?.protocol ?? AwsRestJsonProtocol2,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.signin",
          errorTypeRegistries: errorTypeRegistries3,
          version: "2023-01-01",
          serviceTarget: "Signin"
        },
        serviceId: config2?.serviceId ?? "Signin",
        urlParser: config2?.urlParser ?? import_url_parser4.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? import_util_utf811.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? import_util_utf811.toUtf8
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.js
var import_util_user_agent_node3, import_config_resolver5, import_hash_node3, import_middleware_retry5, import_node_config_provider3, import_node_http_handler3, import_smithy_client26, import_util_body_length_node3, import_util_defaults_mode_node3, import_util_retry5, getRuntimeConfig6;
var init_runtimeConfig3 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.js"() {
    init_package2();
    init_client2();
    init_httpAuthSchemes2();
    import_util_user_agent_node3 = __toESM(require_dist_cjs50());
    import_config_resolver5 = __toESM(require_dist_cjs25());
    import_hash_node3 = __toESM(require_dist_cjs44());
    import_middleware_retry5 = __toESM(require_dist_cjs35());
    import_node_config_provider3 = __toESM(require_dist_cjs29());
    import_node_http_handler3 = __toESM(require_dist_cjs13());
    import_smithy_client26 = __toESM(require_dist_cjs34());
    import_util_body_length_node3 = __toESM(require_dist_cjs45());
    import_util_defaults_mode_node3 = __toESM(require_dist_cjs46());
    import_util_retry5 = __toESM(require_dist_cjs22());
    init_runtimeConfig_shared3();
    getRuntimeConfig6 = /* @__PURE__ */ __name((config2) => {
      (0, import_smithy_client26.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, import_util_defaults_mode_node3.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(import_smithy_client26.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig5(config2);
      emitWarningIfUnsupportedVersion(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, import_node_config_provider3.loadConfig)(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? import_util_body_length_node3.calculateBodyLength,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, import_util_user_agent_node3.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_default2.version }),
        maxAttempts: config2?.maxAttempts ?? (0, import_node_config_provider3.loadConfig)(import_middleware_retry5.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, import_node_config_provider3.loadConfig)(import_config_resolver5.NODE_REGION_CONFIG_OPTIONS, { ...import_config_resolver5.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: import_node_http_handler3.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, import_node_config_provider3.loadConfig)({
          ...import_middleware_retry5.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || import_util_retry5.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? import_hash_node3.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? import_node_http_handler3.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, import_node_config_provider3.loadConfig)(import_config_resolver5.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, import_node_config_provider3.loadConfig)(import_config_resolver5.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, import_node_config_provider3.loadConfig)(import_util_user_agent_node3.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration3, resolveHttpAuthRuntimeConfig3;
var init_httpAuthExtensionConfiguration3 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration3 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig3 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeExtensions.js
var import_region_config_resolver3, import_protocol_http17, import_smithy_client27, resolveRuntimeExtensions3;
var init_runtimeExtensions3 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeExtensions.js"() {
    import_region_config_resolver3 = __toESM(require_dist_cjs48());
    import_protocol_http17 = __toESM(require_dist_cjs2());
    import_smithy_client27 = __toESM(require_dist_cjs34());
    init_httpAuthExtensionConfiguration3();
    resolveRuntimeExtensions3 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign((0, import_region_config_resolver3.getAwsRegionExtensionConfiguration)(runtimeConfig), (0, import_smithy_client27.getDefaultExtensionConfiguration)(runtimeConfig), (0, import_protocol_http17.getHttpHandlerExtensionConfiguration)(runtimeConfig), getHttpAuthExtensionConfiguration3(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, (0, import_region_config_resolver3.resolveAwsRegionExtensionConfiguration)(extensionConfiguration), (0, import_smithy_client27.resolveDefaultRuntimeConfig)(extensionConfiguration), (0, import_protocol_http17.resolveHttpHandlerRuntimeConfig)(extensionConfiguration), resolveHttpAuthRuntimeConfig3(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/SigninClient.js
var import_middleware_host_header3, import_middleware_logger3, import_middleware_recursion_detection3, import_middleware_user_agent3, import_config_resolver6, import_middleware_content_length3, import_middleware_endpoint5, import_middleware_retry6, import_smithy_client28, SigninClient;
var init_SigninClient = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/SigninClient.js"() {
    import_middleware_host_header3 = __toESM(require_dist_cjs3());
    import_middleware_logger3 = __toESM(require_dist_cjs4());
    import_middleware_recursion_detection3 = __toESM(require_dist_cjs5());
    import_middleware_user_agent3 = __toESM(require_dist_cjs23());
    import_config_resolver6 = __toESM(require_dist_cjs25());
    init_dist_es();
    init_schema4();
    import_middleware_content_length3 = __toESM(require_dist_cjs26());
    import_middleware_endpoint5 = __toESM(require_dist_cjs31());
    import_middleware_retry6 = __toESM(require_dist_cjs35());
    import_smithy_client28 = __toESM(require_dist_cjs34());
    init_httpAuthSchemeProvider3();
    init_EndpointParameters3();
    init_runtimeConfig3();
    init_runtimeExtensions3();
    SigninClient = class extends import_smithy_client28.Client {
      static {
        __name(this, "SigninClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig6(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters3(_config_0);
        const _config_2 = (0, import_middleware_user_agent3.resolveUserAgentConfig)(_config_1);
        const _config_3 = (0, import_middleware_retry6.resolveRetryConfig)(_config_2);
        const _config_4 = (0, import_config_resolver6.resolveRegionConfig)(_config_3);
        const _config_5 = (0, import_middleware_host_header3.resolveHostHeaderConfig)(_config_4);
        const _config_6 = (0, import_middleware_endpoint5.resolveEndpointConfig)(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig3(_config_6);
        const _config_8 = resolveRuntimeExtensions3(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin(this.config));
        this.middlewareStack.use((0, import_middleware_user_agent3.getUserAgentPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_retry6.getRetryPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_content_length3.getContentLengthPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_host_header3.getHostHeaderPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_logger3.getLoggerPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_recursion_detection3.getRecursionDetectionPlugin)(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: defaultSigninHttpAuthSchemeParametersProvider,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/CreateOAuth2TokenCommand.js
var import_middleware_endpoint6, import_smithy_client29, CreateOAuth2TokenCommand;
var init_CreateOAuth2TokenCommand = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/CreateOAuth2TokenCommand.js"() {
    import_middleware_endpoint6 = __toESM(require_dist_cjs31());
    import_smithy_client29 = __toESM(require_dist_cjs34());
    init_EndpointParameters3();
    init_schemas_03();
    CreateOAuth2TokenCommand = class extends import_smithy_client29.Command.classBuilder().ep(commonParams3).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint6.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("Signin", "CreateOAuth2Token", {}).n("SigninClient", "CreateOAuth2TokenCommand").sc(CreateOAuth2Token$).build() {
      static {
        __name(this, "CreateOAuth2TokenCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/Signin.js
var import_smithy_client30, commands3, Signin;
var init_Signin = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/Signin.js"() {
    import_smithy_client30 = __toESM(require_dist_cjs34());
    init_CreateOAuth2TokenCommand();
    init_SigninClient();
    commands3 = {
      CreateOAuth2TokenCommand
    };
    Signin = class extends SigninClient {
      static {
        __name(this, "Signin");
      }
    };
    (0, import_smithy_client30.createAggregatedClient)(commands3, Signin);
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/index.js
var init_commands4 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/index.js"() {
    init_CreateOAuth2TokenCommand();
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/enums.js
var OAuth2ErrorCode;
var init_enums2 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/enums.js"() {
    OAuth2ErrorCode = {
      AUTHCODE_EXPIRED: "AUTHCODE_EXPIRED",
      INSUFFICIENT_PERMISSIONS: "INSUFFICIENT_PERMISSIONS",
      INVALID_REQUEST: "INVALID_REQUEST",
      SERVER_ERROR: "server_error",
      TOKEN_EXPIRED: "TOKEN_EXPIRED",
      USER_CREDENTIALS_CHANGED: "USER_CREDENTIALS_CHANGED"
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/models_0.js
var init_models_03 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/index.js
var signin_exports = {};
__export(signin_exports, {
  $Command: () => import_smithy_client29.Command,
  AccessDeniedException: () => AccessDeniedException2,
  AccessDeniedException$: () => AccessDeniedException$2,
  AccessToken$: () => AccessToken$,
  CreateOAuth2Token$: () => CreateOAuth2Token$,
  CreateOAuth2TokenCommand: () => CreateOAuth2TokenCommand,
  CreateOAuth2TokenRequest$: () => CreateOAuth2TokenRequest$,
  CreateOAuth2TokenRequestBody$: () => CreateOAuth2TokenRequestBody$,
  CreateOAuth2TokenResponse$: () => CreateOAuth2TokenResponse$,
  CreateOAuth2TokenResponseBody$: () => CreateOAuth2TokenResponseBody$,
  InternalServerException: () => InternalServerException2,
  InternalServerException$: () => InternalServerException$2,
  OAuth2ErrorCode: () => OAuth2ErrorCode,
  Signin: () => Signin,
  SigninClient: () => SigninClient,
  SigninServiceException: () => SigninServiceException,
  SigninServiceException$: () => SigninServiceException$,
  TooManyRequestsError: () => TooManyRequestsError,
  TooManyRequestsError$: () => TooManyRequestsError$,
  ValidationException: () => ValidationException,
  ValidationException$: () => ValidationException$,
  __Client: () => import_smithy_client28.Client,
  errorTypeRegistries: () => errorTypeRegistries3
});
var init_signin = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/index.js"() {
    init_SigninClient();
    init_Signin();
    init_commands4();
    init_schemas_03();
    init_enums2();
    init_errors3();
    init_models_03();
    init_SigninServiceException();
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-login/dist-cjs/index.js
var require_dist_cjs52 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-login/dist-cjs/index.js"(exports2) {
    "use strict";
    var client = (init_client2(), __toCommonJS(client_exports));
    var propertyProvider = require_dist_cjs27();
    var sharedIniFileLoader = require_dist_cjs28();
    var protocolHttp = require_dist_cjs2();
    var node_crypto = require("node:crypto");
    var node_fs = require("node:fs");
    var node_os = require("node:os");
    var node_path = require("node:path");
    var LoginCredentialsFetcher = class _LoginCredentialsFetcher {
      static {
        __name(this, "LoginCredentialsFetcher");
      }
      profileData;
      init;
      callerClientConfig;
      static REFRESH_THRESHOLD = 5 * 60 * 1e3;
      constructor(profileData, init, callerClientConfig) {
        this.profileData = profileData;
        this.init = init;
        this.callerClientConfig = callerClientConfig;
      }
      async loadCredentials() {
        const token = await this.loadToken();
        if (!token) {
          throw new propertyProvider.CredentialsProviderError(`Failed to load a token for session ${this.loginSession}, please re-authenticate using aws login`, { tryNextLink: false, logger: this.logger });
        }
        const accessToken = token.accessToken;
        const now = Date.now();
        const expiryTime = new Date(accessToken.expiresAt).getTime();
        const timeUntilExpiry = expiryTime - now;
        if (timeUntilExpiry <= _LoginCredentialsFetcher.REFRESH_THRESHOLD) {
          return this.refresh(token);
        }
        return {
          accessKeyId: accessToken.accessKeyId,
          secretAccessKey: accessToken.secretAccessKey,
          sessionToken: accessToken.sessionToken,
          accountId: accessToken.accountId,
          expiration: new Date(accessToken.expiresAt)
        };
      }
      get logger() {
        return this.init?.logger;
      }
      get loginSession() {
        return this.profileData.login_session;
      }
      async refresh(token) {
        const { SigninClient: SigninClient10, CreateOAuth2TokenCommand: CreateOAuth2TokenCommand10 } = await Promise.resolve().then(() => (init_signin(), signin_exports));
        const { logger: logger5, userAgentAppId } = this.callerClientConfig ?? {};
        const isH210 = /* @__PURE__ */ __name((requestHandler2) => {
          return requestHandler2?.metadata?.handlerProtocol === "h2";
        }, "isH2");
        const requestHandler = isH210(this.callerClientConfig?.requestHandler) ? void 0 : this.callerClientConfig?.requestHandler;
        const region = this.profileData.region ?? await this.callerClientConfig?.region?.() ?? process.env.AWS_REGION;
        const client2 = new SigninClient10({
          credentials: {
            accessKeyId: "",
            secretAccessKey: ""
          },
          region,
          requestHandler,
          logger: logger5,
          userAgentAppId,
          ...this.init?.clientConfig
        });
        this.createDPoPInterceptor(client2.middlewareStack);
        const commandInput = {
          tokenInput: {
            clientId: token.clientId,
            refreshToken: token.refreshToken,
            grantType: "refresh_token"
          }
        };
        try {
          const response = await client2.send(new CreateOAuth2TokenCommand10(commandInput));
          const { accessKeyId, secretAccessKey, sessionToken } = response.tokenOutput?.accessToken ?? {};
          const { refreshToken, expiresIn } = response.tokenOutput ?? {};
          if (!accessKeyId || !secretAccessKey || !sessionToken || !refreshToken) {
            throw new propertyProvider.CredentialsProviderError("Token refresh response missing required fields", {
              logger: this.logger,
              tryNextLink: false
            });
          }
          const expiresInMs = (expiresIn ?? 900) * 1e3;
          const expiration = new Date(Date.now() + expiresInMs);
          const updatedToken = {
            ...token,
            accessToken: {
              ...token.accessToken,
              accessKeyId,
              secretAccessKey,
              sessionToken,
              expiresAt: expiration.toISOString()
            },
            refreshToken
          };
          await this.saveToken(updatedToken);
          const newAccessToken = updatedToken.accessToken;
          return {
            accessKeyId: newAccessToken.accessKeyId,
            secretAccessKey: newAccessToken.secretAccessKey,
            sessionToken: newAccessToken.sessionToken,
            accountId: newAccessToken.accountId,
            expiration
          };
        } catch (error4) {
          if (error4.name === "AccessDeniedException") {
            const errorType = error4.error;
            let message2;
            switch (errorType) {
              case "TOKEN_EXPIRED":
                message2 = "Your session has expired. Please reauthenticate.";
                break;
              case "USER_CREDENTIALS_CHANGED":
                message2 = "Unable to refresh credentials because of a change in your password. Please reauthenticate with your new password.";
                break;
              case "INSUFFICIENT_PERMISSIONS":
                message2 = "Unable to refresh credentials due to insufficient permissions. You may be missing permission for the 'CreateOAuth2Token' action.";
                break;
              default:
                message2 = `Failed to refresh token: ${String(error4)}. Please re-authenticate using \`aws login\``;
            }
            throw new propertyProvider.CredentialsProviderError(message2, { logger: this.logger, tryNextLink: false });
          }
          throw new propertyProvider.CredentialsProviderError(`Failed to refresh token: ${String(error4)}. Please re-authenticate using aws login`, { logger: this.logger });
        }
      }
      async loadToken() {
        const tokenFilePath = this.getTokenFilePath();
        try {
          let tokenData;
          try {
            tokenData = await sharedIniFileLoader.readFile(tokenFilePath, { ignoreCache: this.init?.ignoreCache });
          } catch {
            tokenData = await node_fs.promises.readFile(tokenFilePath, "utf8");
          }
          const token = JSON.parse(tokenData);
          const missingFields = ["accessToken", "clientId", "refreshToken", "dpopKey"].filter((k32) => !token[k32]);
          if (!token.accessToken?.accountId) {
            missingFields.push("accountId");
          }
          if (missingFields.length > 0) {
            throw new propertyProvider.CredentialsProviderError(`Token validation failed, missing fields: ${missingFields.join(", ")}`, {
              logger: this.logger,
              tryNextLink: false
            });
          }
          return token;
        } catch (error4) {
          throw new propertyProvider.CredentialsProviderError(`Failed to load token from ${tokenFilePath}: ${String(error4)}`, {
            logger: this.logger,
            tryNextLink: false
          });
        }
      }
      async saveToken(token) {
        const tokenFilePath = this.getTokenFilePath();
        const directory = node_path.dirname(tokenFilePath);
        try {
          await node_fs.promises.mkdir(directory, { recursive: true });
        } catch (error4) {
        }
        await node_fs.promises.writeFile(tokenFilePath, JSON.stringify(token, null, 2), "utf8");
      }
      getTokenFilePath() {
        const directory = process.env.AWS_LOGIN_CACHE_DIRECTORY ?? node_path.join(node_os.homedir(), ".aws", "login", "cache");
        const loginSessionBytes = Buffer.from(this.loginSession, "utf8");
        const loginSessionSha256 = node_crypto.createHash("sha256").update(loginSessionBytes).digest("hex");
        return node_path.join(directory, `${loginSessionSha256}.json`);
      }
      derToRawSignature(derSignature) {
        let offset = 2;
        if (derSignature[offset] !== 2) {
          throw new Error("Invalid DER signature");
        }
        offset++;
        const rLength = derSignature[offset++];
        let r32 = derSignature.subarray(offset, offset + rLength);
        offset += rLength;
        if (derSignature[offset] !== 2) {
          throw new Error("Invalid DER signature");
        }
        offset++;
        const sLength = derSignature[offset++];
        let s = derSignature.subarray(offset, offset + sLength);
        r32 = r32[0] === 0 ? r32.subarray(1) : r32;
        s = s[0] === 0 ? s.subarray(1) : s;
        const rPadded = Buffer.concat([Buffer.alloc(32 - r32.length), r32]);
        const sPadded = Buffer.concat([Buffer.alloc(32 - s.length), s]);
        return Buffer.concat([rPadded, sPadded]);
      }
      createDPoPInterceptor(middlewareStack) {
        middlewareStack.add((next) => async (args) => {
          if (protocolHttp.HttpRequest.isInstance(args.request)) {
            const request4 = args.request;
            const actualEndpoint = `${request4.protocol}//${request4.hostname}${request4.port ? `:${request4.port}` : ""}${request4.path}`;
            const dpop = await this.generateDpop(request4.method, actualEndpoint);
            request4.headers = {
              ...request4.headers,
              DPoP: dpop
            };
          }
          return next(args);
        }, {
          step: "finalizeRequest",
          name: "dpopInterceptor",
          override: true
        });
      }
      async generateDpop(method = "POST", endpoint) {
        const token = await this.loadToken();
        try {
          const privateKey = node_crypto.createPrivateKey({
            key: token.dpopKey,
            format: "pem",
            type: "sec1"
          });
          const publicKey = node_crypto.createPublicKey(privateKey);
          const publicDer = publicKey.export({ format: "der", type: "spki" });
          let pointStart = -1;
          for (let i32 = 0; i32 < publicDer.length; i32++) {
            if (publicDer[i32] === 4) {
              pointStart = i32;
              break;
            }
          }
          const x = publicDer.slice(pointStart + 1, pointStart + 33);
          const y = publicDer.slice(pointStart + 33, pointStart + 65);
          const header = {
            alg: "ES256",
            typ: "dpop+jwt",
            jwk: {
              kty: "EC",
              crv: "P-256",
              x: x.toString("base64url"),
              y: y.toString("base64url")
            }
          };
          const payload3 = {
            jti: crypto.randomUUID(),
            htm: method,
            htu: endpoint,
            iat: Math.floor(Date.now() / 1e3)
          };
          const headerB64 = Buffer.from(JSON.stringify(header)).toString("base64url");
          const payloadB64 = Buffer.from(JSON.stringify(payload3)).toString("base64url");
          const message2 = `${headerB64}.${payloadB64}`;
          const asn1Signature = node_crypto.sign("sha256", Buffer.from(message2), privateKey);
          const rawSignature = this.derToRawSignature(asn1Signature);
          const signatureB64 = rawSignature.toString("base64url");
          return `${message2}.${signatureB64}`;
        } catch (error4) {
          throw new propertyProvider.CredentialsProviderError(`Failed to generate Dpop proof: ${error4 instanceof Error ? error4.message : String(error4)}`, { logger: this.logger, tryNextLink: false });
        }
      }
    };
    var fromLoginCredentials = /* @__PURE__ */ __name((init) => async ({ callerClientConfig } = {}) => {
      init?.logger?.debug?.("@aws-sdk/credential-providers - fromLoginCredentials");
      const profiles = await sharedIniFileLoader.parseKnownFiles(init || {});
      const profileName = sharedIniFileLoader.getProfileName({
        profile: init?.profile ?? callerClientConfig?.profile
      });
      const profile = profiles[profileName];
      if (!profile?.login_session) {
        throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} does not contain login_session.`, {
          tryNextLink: true,
          logger: init?.logger
        });
      }
      const fetcher = new LoginCredentialsFetcher(profile, init, callerClientConfig);
      const credentials = await fetcher.loadCredentials();
      return client.setCredentialFeature(credentials, "CREDENTIALS_LOGIN", "AD");
    }, "fromLoginCredentials");
    exports2.fromLoginCredentials = fromLoginCredentials;
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/dist-cjs/toStream.js
var require_toStream = __commonJS({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/dist-cjs/toStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.toStream = toStream;
    var node_stream_1 = require("node:stream");
    function toStream(bytes) {
      return node_stream_1.Readable.from(Buffer.from(bytes));
    }
    __name(toStream, "toStream");
  }
});

// ../../node_modules/@aws-sdk/util-arn-parser/dist-cjs/index.js
var require_dist_cjs53 = __commonJS({
  "../../node_modules/@aws-sdk/util-arn-parser/dist-cjs/index.js"(exports2) {
    "use strict";
    var validate = /* @__PURE__ */ __name((str) => typeof str === "string" && str.indexOf("arn:") === 0 && str.split(":").length >= 6, "validate");
    var parse2 = /* @__PURE__ */ __name((arn) => {
      const segments = arn.split(":");
      if (segments.length < 6 || segments[0] !== "arn")
        throw new Error("Malformed ARN");
      const [, partition4, service, region, accountId, ...resource] = segments;
      return {
        partition: partition4,
        service,
        region,
        accountId,
        resource: resource.join(":")
      };
    }, "parse");
    var build = /* @__PURE__ */ __name((arnObject) => {
      const { partition: partition4 = "aws", service, region, accountId, resource } = arnObject;
      if ([service, region, accountId, resource].some((segment) => typeof segment !== "string")) {
        throw new Error("Input ARN object is invalid");
      }
      return `arn:${partition4}:${service}:${region}:${accountId}:${resource}`;
    }, "build");
    exports2.build = build;
    exports2.parse = parse2;
    exports2.validate = validate;
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ProtocolLib.js
var import_smithy_client31, ProtocolLib3;
var init_ProtocolLib3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ProtocolLib.js"() {
    init_schema4();
    import_smithy_client31 = __toESM(require_dist_cjs34());
    ProtocolLib3 = class {
      static {
        __name(this, "ProtocolLib");
      }
      queryCompat;
      errorRegistry;
      constructor(queryCompat = false) {
        this.queryCompat = queryCompat;
      }
      resolveRestContentType(defaultContentType, inputSchema) {
        const members = inputSchema.getMemberSchemas();
        const httpPayloadMember = Object.values(members).find((m20) => {
          return !!m20.getMergedTraits().httpPayload;
        });
        if (httpPayloadMember) {
          const mediaType = httpPayloadMember.getMergedTraits().mediaType;
          if (mediaType) {
            return mediaType;
          } else if (httpPayloadMember.isStringSchema()) {
            return "text/plain";
          } else if (httpPayloadMember.isBlobSchema()) {
            return "application/octet-stream";
          } else {
            return defaultContentType;
          }
        } else if (!inputSchema.isUnitSchema()) {
          const hasBody = Object.values(members).find((m20) => {
            const { httpQuery, httpQueryParams, httpHeader, httpLabel, httpPrefixHeaders } = m20.getMergedTraits();
            const noPrefixHeaders = httpPrefixHeaders === void 0;
            return !httpQuery && !httpQueryParams && !httpHeader && !httpLabel && noPrefixHeaders;
          });
          if (hasBody) {
            return defaultContentType;
          }
        }
      }
      async getErrorSchemaOrThrowBaseException(errorIdentifier, defaultNamespace, response, dataObject, metadata, getErrorSchema) {
        let errorName = errorIdentifier;
        if (errorIdentifier.includes("#")) {
          [, errorName] = errorIdentifier.split("#");
        }
        const errorMetadata = {
          $metadata: metadata,
          $fault: response.statusCode < 500 ? "client" : "server"
        };
        if (!this.errorRegistry) {
          throw new Error("@aws-sdk/core/protocols - error handler not initialized.");
        }
        try {
          const errorSchema = getErrorSchema?.(this.errorRegistry, errorName) ?? this.errorRegistry.getSchema(errorIdentifier);
          return { errorSchema, errorMetadata };
        } catch (e32) {
          dataObject.message = dataObject.message ?? dataObject.Message ?? "UnknownError";
          const synthetic = this.errorRegistry;
          const baseExceptionSchema = synthetic.getBaseException();
          if (baseExceptionSchema) {
            const ErrorCtor = synthetic.getErrorCtor(baseExceptionSchema) ?? Error;
            throw this.decorateServiceException(Object.assign(new ErrorCtor({ name: errorName }), errorMetadata), dataObject);
          }
          const d32 = dataObject;
          const message2 = d32?.message ?? d32?.Message ?? d32?.Error?.Message ?? d32?.Error?.message;
          throw this.decorateServiceException(Object.assign(new Error(message2), {
            name: errorName
          }, errorMetadata), dataObject);
        }
      }
      compose(composite, errorIdentifier, defaultNamespace) {
        let namespace = defaultNamespace;
        if (errorIdentifier.includes("#")) {
          [namespace] = errorIdentifier.split("#");
        }
        const staticRegistry = TypeRegistry.for(namespace);
        const defaultSyntheticRegistry = TypeRegistry.for("smithy.ts.sdk.synthetic." + defaultNamespace);
        composite.copyFrom(staticRegistry);
        composite.copyFrom(defaultSyntheticRegistry);
        this.errorRegistry = composite;
      }
      decorateServiceException(exception, additions = {}) {
        if (this.queryCompat) {
          const msg = exception.Message ?? additions.Message;
          const error4 = (0, import_smithy_client31.decorateServiceException)(exception, additions);
          if (msg) {
            error4.message = msg;
          }
          const errorObj = error4.Error ?? {};
          errorObj.Type = error4.Error?.Type;
          errorObj.Code = error4.Error?.Code;
          errorObj.Message = error4.Error?.message ?? error4.Error?.Message ?? msg;
          error4.Error = errorObj;
          const reqId = error4.$metadata.requestId;
          if (reqId) {
            error4.RequestId = reqId;
          }
          return error4;
        }
        return (0, import_smithy_client31.decorateServiceException)(exception, additions);
      }
      setQueryCompatError(output, response) {
        const queryErrorHeader = response.headers?.["x-amzn-query-error"];
        if (output !== void 0 && queryErrorHeader != null) {
          const [Code, Type] = queryErrorHeader.split(";");
          const keys = Object.keys(output);
          const Error2 = {
            Code,
            Type
          };
          output.Code = Code;
          output.Type = Type;
          for (let i32 = 0; i32 < keys.length; i32++) {
            const k32 = keys[i32];
            Error2[k32 === "message" ? "Message" : k32] = output[k32];
          }
          delete Error2.__type;
          output.Error = Error2;
        }
      }
      queryCompatOutput(queryCompatErrorData, errorData) {
        if (queryCompatErrorData.Error) {
          errorData.Error = queryCompatErrorData.Error;
        }
        if (queryCompatErrorData.Type) {
          errorData.Type = queryCompatErrorData.Type;
        }
        if (queryCompatErrorData.Code) {
          errorData.Code = queryCompatErrorData.Code;
        }
      }
      findQueryCompatibleError(registry, errorName) {
        try {
          return registry.getSchema(errorName);
        } catch (e32) {
          return registry.find((schema) => NormalizedSchema.of(schema).getMergedTraits().awsQueryError?.[0] === errorName);
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/cbor/AwsSmithyRpcV2CborProtocol.js
var AwsSmithyRpcV2CborProtocol2;
var init_AwsSmithyRpcV2CborProtocol3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/cbor/AwsSmithyRpcV2CborProtocol.js"() {
    init_cbor2();
    init_schema4();
    init_ProtocolLib3();
    AwsSmithyRpcV2CborProtocol2 = class extends SmithyRpcV2CborProtocol {
      static {
        __name(this, "AwsSmithyRpcV2CborProtocol");
      }
      awsQueryCompatible;
      mixin;
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, awsQueryCompatible }) {
        super({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32 });
        this.awsQueryCompatible = !!awsQueryCompatible;
        this.mixin = new ProtocolLib3(this.awsQueryCompatible);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        if (this.awsQueryCompatible) {
          request4.headers["x-amzn-query-mode"] = "true";
        }
        return request4;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        if (this.awsQueryCompatible) {
          this.mixin.setQueryCompatError(dataObject, response);
        }
        const errorName = (() => {
          const compatHeader = response.headers["x-amzn-query-error"];
          if (compatHeader && this.awsQueryCompatible) {
            return compatHeader.split(";")[0];
          }
          return loadSmithyRpcV2CborErrorCode(response, dataObject) ?? "Unknown";
        })();
        this.mixin.compose(this.compositeErrorRegistry, errorName, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorName, this.options.defaultNamespace, response, dataObject, metadata, this.awsQueryCompatible ? this.mixin.findQueryCompatibleError : void 0);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        const output = {};
        for (const [name, member7] of ns.structIterator()) {
          if (dataObject[name] != null) {
            output[name] = this.deserializer.readValue(member7, dataObject[name]);
          }
        }
        if (this.awsQueryCompatible) {
          this.mixin.queryCompatOutput(dataObject, output);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/coercing-serializers.js
var _toStr2, _toBool2, _toNum2;
var init_coercing_serializers3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/coercing-serializers.js"() {
    _toStr2 = /* @__PURE__ */ __name((val) => {
      if (val == null) {
        return val;
      }
      if (typeof val === "number" || typeof val === "bigint") {
        const warning2 = new Error(`Received number ${val} where a string was expected.`);
        warning2.name = "Warning";
        console.warn(warning2);
        return String(val);
      }
      if (typeof val === "boolean") {
        const warning2 = new Error(`Received boolean ${val} where a string was expected.`);
        warning2.name = "Warning";
        console.warn(warning2);
        return String(val);
      }
      return val;
    }, "_toStr");
    _toBool2 = /* @__PURE__ */ __name((val) => {
      if (val == null) {
        return val;
      }
      if (typeof val === "number") {
      }
      if (typeof val === "string") {
        const lowercase = val.toLowerCase();
        if (val !== "" && lowercase !== "false" && lowercase !== "true") {
          const warning2 = new Error(`Received string "${val}" where a boolean was expected.`);
          warning2.name = "Warning";
          console.warn(warning2);
        }
        return val !== "" && lowercase !== "false";
      }
      return val;
    }, "_toBool");
    _toNum2 = /* @__PURE__ */ __name((val) => {
      if (val == null) {
        return val;
      }
      if (typeof val === "boolean") {
      }
      if (typeof val === "string") {
        const num = Number(val);
        if (num.toString() !== val) {
          const warning2 = new Error(`Received string "${val}" where a number was expected.`);
          warning2.name = "Warning";
          console.warn(warning2);
          return val;
        }
        return num;
      }
      return val;
    }, "_toNum");
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ConfigurableSerdeContext.js
var SerdeContextConfig3;
var init_ConfigurableSerdeContext3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ConfigurableSerdeContext.js"() {
    SerdeContextConfig3 = class {
      static {
        __name(this, "SerdeContextConfig");
      }
      serdeContext;
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/UnionSerde.js
var UnionSerde3;
var init_UnionSerde3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/UnionSerde.js"() {
    UnionSerde3 = class {
      static {
        __name(this, "UnionSerde");
      }
      from;
      to;
      keys;
      constructor(from, to) {
        this.from = from;
        this.to = to;
        const keys = Object.keys(this.from);
        const set = new Set(keys);
        set.delete("__type");
        this.keys = set;
      }
      mark(key) {
        this.keys.delete(key);
      }
      hasUnknown() {
        return this.keys.size === 1 && Object.keys(this.to).length === 0;
      }
      writeUnknown() {
        if (this.hasUnknown()) {
          const k32 = this.keys.values().next().value;
          const v = this.from[k32];
          this.to.$unknown = [k32, v];
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReviver.js
function jsonReviver3(key, value, context) {
  if (context?.source) {
    const numericString = context.source;
    if (typeof value === "number") {
      if (value > Number.MAX_SAFE_INTEGER || value < Number.MIN_SAFE_INTEGER || numericString !== String(value)) {
        const isFractional = numericString.includes(".");
        if (isFractional) {
          return new NumericValue(numericString, "bigDecimal");
        } else {
          return BigInt(numericString);
        }
      }
    }
  }
  return value;
}
var init_jsonReviver3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReviver.js"() {
    init_serde();
    __name(jsonReviver3, "jsonReviver");
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/common.js
var import_smithy_client32, import_util_utf812, collectBodyString3;
var init_common4 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/common.js"() {
    import_smithy_client32 = __toESM(require_dist_cjs34());
    import_util_utf812 = __toESM(require_dist_cjs9());
    collectBodyString3 = /* @__PURE__ */ __name((streamBody, context) => (0, import_smithy_client32.collectBody)(streamBody, context).then((body) => (context?.utf8Encoder ?? import_util_utf812.toUtf8)(body)), "collectBodyString");
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/parseJsonBody.js
var parseJsonBody3, parseJsonErrorBody2, findKey3, sanitizeErrorCode3, loadRestJsonErrorCode3;
var init_parseJsonBody3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/parseJsonBody.js"() {
    init_common4();
    parseJsonBody3 = /* @__PURE__ */ __name((streamBody, context) => collectBodyString3(streamBody, context).then((encoded) => {
      if (encoded.length) {
        try {
          return JSON.parse(encoded);
        } catch (e32) {
          if (e32?.name === "SyntaxError") {
            Object.defineProperty(e32, "$responseBodyText", {
              value: encoded
            });
          }
          throw e32;
        }
      }
      return {};
    }), "parseJsonBody");
    parseJsonErrorBody2 = /* @__PURE__ */ __name(async (errorBody, context) => {
      const value = await parseJsonBody3(errorBody, context);
      value.message = value.message ?? value.Message;
      return value;
    }, "parseJsonErrorBody");
    findKey3 = /* @__PURE__ */ __name((object, key) => Object.keys(object).find((k32) => k32.toLowerCase() === key.toLowerCase()), "findKey");
    sanitizeErrorCode3 = /* @__PURE__ */ __name((rawValue) => {
      let cleanValue = rawValue;
      if (typeof cleanValue === "number") {
        cleanValue = cleanValue.toString();
      }
      if (cleanValue.indexOf(",") >= 0) {
        cleanValue = cleanValue.split(",")[0];
      }
      if (cleanValue.indexOf(":") >= 0) {
        cleanValue = cleanValue.split(":")[0];
      }
      if (cleanValue.indexOf("#") >= 0) {
        cleanValue = cleanValue.split("#")[1];
      }
      return cleanValue;
    }, "sanitizeErrorCode");
    loadRestJsonErrorCode3 = /* @__PURE__ */ __name((output, data3) => {
      const headerKey = findKey3(output.headers, "x-amzn-errortype");
      if (headerKey !== void 0) {
        return sanitizeErrorCode3(output.headers[headerKey]);
      }
      if (data3 && typeof data3 === "object") {
        const codeKey = findKey3(data3, "code");
        if (codeKey && data3[codeKey] !== void 0) {
          return sanitizeErrorCode3(data3[codeKey]);
        }
        if (data3["__type"] !== void 0) {
          return sanitizeErrorCode3(data3["__type"]);
        }
      }
    }, "loadRestJsonErrorCode");
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeDeserializer.js
var import_util_base6413, JsonShapeDeserializer3;
var init_JsonShapeDeserializer3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeDeserializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_util_base6413 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext3();
    init_UnionSerde3();
    init_jsonReviver3();
    init_parseJsonBody3();
    JsonShapeDeserializer3 = class extends SerdeContextConfig3 {
      static {
        __name(this, "JsonShapeDeserializer");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      async read(schema, data3) {
        return this._read(schema, typeof data3 === "string" ? JSON.parse(data3, jsonReviver3) : await parseJsonBody3(data3, this.serdeContext));
      }
      readObject(schema, data3) {
        return this._read(schema, data3);
      }
      _read(schema, value) {
        const isObject3 = value !== null && typeof value === "object";
        const ns = NormalizedSchema.of(schema);
        if (isObject3) {
          if (ns.isStructSchema()) {
            const record = value;
            const union = ns.isUnionSchema();
            const out = {};
            let nameMap = void 0;
            const { jsonName } = this.settings;
            if (jsonName) {
              nameMap = {};
            }
            let unionSerde;
            if (union) {
              unionSerde = new UnionSerde3(record, out);
            }
            for (const [memberName, memberSchema] of ns.structIterator()) {
              let fromKey = memberName;
              if (jsonName) {
                fromKey = memberSchema.getMergedTraits().jsonName ?? fromKey;
                nameMap[fromKey] = memberName;
              }
              if (union) {
                unionSerde.mark(fromKey);
              }
              if (record[fromKey] != null) {
                out[memberName] = this._read(memberSchema, record[fromKey]);
              }
            }
            if (union) {
              unionSerde.writeUnknown();
            } else if (typeof record.__type === "string") {
              for (const k32 in record) {
                const v = record[k32];
                const t = jsonName ? nameMap[k32] ?? k32 : k32;
                if (!(t in out)) {
                  out[t] = v;
                }
              }
            }
            return out;
          }
          if (Array.isArray(value) && ns.isListSchema()) {
            const listMember = ns.getValueSchema();
            const out = [];
            for (const item of value) {
              out.push(this._read(listMember, item));
            }
            return out;
          }
          if (ns.isMapSchema()) {
            const mapMember = ns.getValueSchema();
            const out = {};
            for (const _k in value) {
              out[_k] = this._read(mapMember, value[_k]);
            }
            return out;
          }
        }
        if (ns.isBlobSchema() && typeof value === "string") {
          return (0, import_util_base6413.fromBase64)(value);
        }
        const mediaType = ns.getMergedTraits().mediaType;
        if (ns.isStringSchema() && typeof value === "string" && mediaType) {
          const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
          if (isJson) {
            return LazyJsonString.from(value);
          }
          return value;
        }
        if (ns.isTimestampSchema() && value != null) {
          const format32 = determineTimestampFormat(ns, this.settings);
          switch (format32) {
            case 5:
              return parseRfc3339DateTimeWithOffset(value);
            case 6:
              return parseRfc7231DateTime(value);
            case 7:
              return parseEpochTimestamp(value);
            default:
              console.warn("Missing timestamp format, parsing value with Date constructor:", value);
              return new Date(value);
          }
        }
        if (ns.isBigIntegerSchema() && (typeof value === "number" || typeof value === "string")) {
          return BigInt(value);
        }
        if (ns.isBigDecimalSchema() && value != void 0) {
          if (value instanceof NumericValue) {
            return value;
          }
          const untyped = value;
          if (untyped.type === "bigDecimal" && "string" in untyped) {
            return new NumericValue(untyped.string, untyped.type);
          }
          return new NumericValue(String(value), "bigDecimal");
        }
        if (ns.isNumericSchema() && typeof value === "string") {
          switch (value) {
            case "Infinity":
              return Infinity;
            case "-Infinity":
              return -Infinity;
            case "NaN":
              return NaN;
          }
          return value;
        }
        if (ns.isDocumentSchema()) {
          if (isObject3) {
            const out = Array.isArray(value) ? [] : {};
            for (const k32 in value) {
              const v = value[k32];
              if (v instanceof NumericValue) {
                out[k32] = v;
              } else {
                out[k32] = this._read(ns, v);
              }
            }
            return out;
          } else {
            return structuredClone(value);
          }
        }
        return value;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReplacer.js
var NUMERIC_CONTROL_CHAR3, JsonReplacer3;
var init_jsonReplacer3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReplacer.js"() {
    init_serde();
    NUMERIC_CONTROL_CHAR3 = String.fromCharCode(925);
    JsonReplacer3 = class {
      static {
        __name(this, "JsonReplacer");
      }
      values = /* @__PURE__ */ new Map();
      counter = 0;
      stage = 0;
      createReplacer() {
        if (this.stage === 1) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer already created.");
        }
        if (this.stage === 2) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer exhausted.");
        }
        this.stage = 1;
        return (key, value) => {
          if (value instanceof NumericValue) {
            const v = `${NUMERIC_CONTROL_CHAR3 + "nv" + this.counter++}_` + value.string;
            this.values.set(`"${v}"`, value.string);
            return v;
          }
          if (typeof value === "bigint") {
            const s = value.toString();
            const v = `${NUMERIC_CONTROL_CHAR3 + "b" + this.counter++}_` + s;
            this.values.set(`"${v}"`, s);
            return v;
          }
          return value;
        };
      }
      replaceInJson(json) {
        if (this.stage === 0) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer not created yet.");
        }
        if (this.stage === 2) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer exhausted.");
        }
        this.stage = 2;
        if (this.counter === 0) {
          return json;
        }
        for (const [key, value] of this.values) {
          json = json.replace(key, value);
        }
        return json;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeSerializer.js
var import_util_base6414, JsonShapeSerializer3;
var init_JsonShapeSerializer3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeSerializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_util_base6414 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext3();
    init_jsonReplacer3();
    JsonShapeSerializer3 = class extends SerdeContextConfig3 {
      static {
        __name(this, "JsonShapeSerializer");
      }
      settings;
      buffer;
      useReplacer = false;
      rootSchema;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value) {
        this.rootSchema = NormalizedSchema.of(schema);
        this.buffer = this._write(this.rootSchema, value);
      }
      flush() {
        const { rootSchema, useReplacer } = this;
        this.rootSchema = void 0;
        this.useReplacer = false;
        if (rootSchema?.isStructSchema() || rootSchema?.isDocumentSchema()) {
          if (!useReplacer) {
            return JSON.stringify(this.buffer);
          }
          const replacer = new JsonReplacer3();
          return replacer.replaceInJson(JSON.stringify(this.buffer, replacer.createReplacer(), 0));
        }
        return this.buffer;
      }
      writeDiscriminatedDocument(schema, value) {
        this.write(schema, value);
        if (typeof this.buffer === "object") {
          this.buffer.__type = NormalizedSchema.of(schema).getName(true);
        }
      }
      _write(schema, value, container) {
        const isObject3 = value !== null && typeof value === "object";
        const ns = NormalizedSchema.of(schema);
        if (isObject3) {
          if (ns.isStructSchema()) {
            const record = value;
            const out = {};
            const { jsonName } = this.settings;
            let nameMap = void 0;
            if (jsonName) {
              nameMap = {};
            }
            let outCount = 0;
            for (const [memberName, memberSchema] of ns.structIterator()) {
              const serializableValue = this._write(memberSchema, record[memberName], ns);
              if (serializableValue !== void 0) {
                let targetKey = memberName;
                if (jsonName) {
                  targetKey = memberSchema.getMergedTraits().jsonName ?? memberName;
                  nameMap[memberName] = targetKey;
                }
                out[targetKey] = serializableValue;
                outCount++;
              }
            }
            if (ns.isUnionSchema() && outCount === 0) {
              const { $unknown } = record;
              if (Array.isArray($unknown)) {
                const [k32, v] = $unknown;
                out[k32] = this._write(15, v);
              }
            } else if (typeof record.__type === "string") {
              for (const k32 in record) {
                const v = record[k32];
                const targetKey = jsonName ? nameMap[k32] ?? k32 : k32;
                if (!(targetKey in out)) {
                  out[targetKey] = this._write(15, v);
                }
              }
            }
            return out;
          }
          if (Array.isArray(value) && ns.isListSchema()) {
            const listMember = ns.getValueSchema();
            const out = [];
            const sparse = !!ns.getMergedTraits().sparse;
            for (const item of value) {
              if (sparse || item != null) {
                out.push(this._write(listMember, item));
              }
            }
            return out;
          }
          if (ns.isMapSchema()) {
            const mapMember = ns.getValueSchema();
            const out = {};
            const sparse = !!ns.getMergedTraits().sparse;
            for (const _k in value) {
              const _v = value[_k];
              if (sparse || _v != null) {
                out[_k] = this._write(mapMember, _v);
              }
            }
            return out;
          }
          if (value instanceof Uint8Array && (ns.isBlobSchema() || ns.isDocumentSchema())) {
            if (ns === this.rootSchema) {
              return value;
            }
            return (this.serdeContext?.base64Encoder ?? import_util_base6414.toBase64)(value);
          }
          if (value instanceof Date && (ns.isTimestampSchema() || ns.isDocumentSchema())) {
            const format32 = determineTimestampFormat(ns, this.settings);
            switch (format32) {
              case 5:
                return value.toISOString().replace(".000Z", "Z");
              case 6:
                return dateToUtcString(value);
              case 7:
                return value.getTime() / 1e3;
              default:
                console.warn("Missing timestamp format, using epoch seconds", value);
                return value.getTime() / 1e3;
            }
          }
          if (value instanceof NumericValue) {
            this.useReplacer = true;
          }
        }
        if (value === null && container?.isStructSchema()) {
          return void 0;
        }
        if (ns.isStringSchema()) {
          if (typeof value === "undefined" && ns.isIdempotencyToken()) {
            return (0, import_uuid.v4)();
          }
          const mediaType = ns.getMergedTraits().mediaType;
          if (value != null && mediaType) {
            const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
            if (isJson) {
              return LazyJsonString.from(value);
            }
          }
          return value;
        }
        if (typeof value === "number" && ns.isNumericSchema()) {
          if (Math.abs(value) === Infinity || isNaN(value)) {
            return String(value);
          }
          return value;
        }
        if (typeof value === "string" && ns.isBlobSchema()) {
          if (ns === this.rootSchema) {
            return value;
          }
          return (this.serdeContext?.base64Encoder ?? import_util_base6414.toBase64)(value);
        }
        if (typeof value === "bigint") {
          this.useReplacer = true;
        }
        if (ns.isDocumentSchema()) {
          if (isObject3) {
            const out = Array.isArray(value) ? [] : {};
            for (const k32 in value) {
              const v = value[k32];
              if (v instanceof NumericValue) {
                this.useReplacer = true;
                out[k32] = v;
              } else {
                out[k32] = this._write(ns, v);
              }
            }
            return out;
          } else {
            return structuredClone(value);
          }
        }
        return value;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonCodec.js
var JsonCodec3;
var init_JsonCodec3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonCodec.js"() {
    init_ConfigurableSerdeContext3();
    init_JsonShapeDeserializer3();
    init_JsonShapeSerializer3();
    JsonCodec3 = class extends SerdeContextConfig3 {
      static {
        __name(this, "JsonCodec");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      createSerializer() {
        const serializer = new JsonShapeSerializer3(this.settings);
        serializer.setSerdeContext(this.serdeContext);
        return serializer;
      }
      createDeserializer() {
        const deserializer = new JsonShapeDeserializer3(this.settings);
        deserializer.setSerdeContext(this.serdeContext);
        return deserializer;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJsonRpcProtocol.js
var AwsJsonRpcProtocol2;
var init_AwsJsonRpcProtocol3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJsonRpcProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib3();
    init_JsonCodec3();
    init_parseJsonBody3();
    AwsJsonRpcProtocol2 = class extends RpcProtocol {
      static {
        __name(this, "AwsJsonRpcProtocol");
      }
      serializer;
      deserializer;
      serviceTarget;
      codec;
      mixin;
      awsQueryCompatible;
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, serviceTarget, awsQueryCompatible, jsonCodec }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32
        });
        this.serviceTarget = serviceTarget;
        this.codec = jsonCodec ?? new JsonCodec3({
          timestampFormat: {
            useTrait: true,
            default: 7
          },
          jsonName: false
        });
        this.serializer = this.codec.createSerializer();
        this.deserializer = this.codec.createDeserializer();
        this.awsQueryCompatible = !!awsQueryCompatible;
        this.mixin = new ProtocolLib3(this.awsQueryCompatible);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        if (!request4.path.endsWith("/")) {
          request4.path += "/";
        }
        request4.headers["content-type"] = `application/x-amz-json-${this.getJsonRpcVersion()}`;
        request4.headers["x-amz-target"] = `${this.serviceTarget}.${operationSchema.name}`;
        if (this.awsQueryCompatible) {
          request4.headers["x-amzn-query-mode"] = "true";
        }
        if (deref(operationSchema.input) === "unit" || !request4.body) {
          request4.body = "{}";
        }
        return request4;
      }
      getPayloadCodec() {
        return this.codec;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        if (this.awsQueryCompatible) {
          this.mixin.setQueryCompatError(dataObject, response);
        }
        const errorIdentifier = loadRestJsonErrorCode3(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata, this.awsQueryCompatible ? this.mixin.findQueryCompatibleError : void 0);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          if (dataObject[name] != null) {
            output[name] = errorDeserializer.readObject(member7, dataObject[name]);
          }
        }
        if (this.awsQueryCompatible) {
          this.mixin.queryCompatOutput(dataObject, output);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_0Protocol.js
var AwsJson1_0Protocol2;
var init_AwsJson1_0Protocol3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_0Protocol.js"() {
    init_AwsJsonRpcProtocol3();
    AwsJson1_0Protocol2 = class extends AwsJsonRpcProtocol2 {
      static {
        __name(this, "AwsJson1_0Protocol");
      }
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, serviceTarget, awsQueryCompatible, jsonCodec }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32,
          serviceTarget,
          awsQueryCompatible,
          jsonCodec
        });
      }
      getShapeId() {
        return "aws.protocols#awsJson1_0";
      }
      getJsonRpcVersion() {
        return "1.0";
      }
      getDefaultContentType() {
        return "application/x-amz-json-1.0";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_1Protocol.js
var AwsJson1_1Protocol2;
var init_AwsJson1_1Protocol3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_1Protocol.js"() {
    init_AwsJsonRpcProtocol3();
    AwsJson1_1Protocol2 = class extends AwsJsonRpcProtocol2 {
      static {
        __name(this, "AwsJson1_1Protocol");
      }
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, serviceTarget, awsQueryCompatible, jsonCodec }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32,
          serviceTarget,
          awsQueryCompatible,
          jsonCodec
        });
      }
      getShapeId() {
        return "aws.protocols#awsJson1_1";
      }
      getJsonRpcVersion() {
        return "1.1";
      }
      getDefaultContentType() {
        return "application/x-amz-json-1.1";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsRestJsonProtocol.js
var AwsRestJsonProtocol3;
var init_AwsRestJsonProtocol3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsRestJsonProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib3();
    init_JsonCodec3();
    init_parseJsonBody3();
    AwsRestJsonProtocol3 = class extends HttpBindingProtocol {
      static {
        __name(this, "AwsRestJsonProtocol");
      }
      serializer;
      deserializer;
      codec;
      mixin = new ProtocolLib3();
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32 }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32
        });
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 7
          },
          httpBindings: true,
          jsonName: true
        };
        this.codec = new JsonCodec3(settings);
        this.serializer = new HttpInterceptingShapeSerializer(this.codec.createSerializer(), settings);
        this.deserializer = new HttpInterceptingShapeDeserializer(this.codec.createDeserializer(), settings);
      }
      getShapeId() {
        return "aws.protocols#restJson1";
      }
      getPayloadCodec() {
        return this.codec;
      }
      setSerdeContext(serdeContext) {
        this.codec.setSerdeContext(serdeContext);
        super.setSerdeContext(serdeContext);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        const inputSchema = NormalizedSchema.of(operationSchema.input);
        if (!request4.headers["content-type"]) {
          const contentType = this.mixin.resolveRestContentType(this.getDefaultContentType(), inputSchema);
          if (contentType) {
            request4.headers["content-type"] = contentType;
          }
        }
        if (request4.body == null && request4.headers["content-type"] === this.getDefaultContentType()) {
          request4.body = "{}";
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        const output = await super.deserializeResponse(operationSchema, context, response);
        const outputSchema = NormalizedSchema.of(operationSchema.output);
        for (const [name, member7] of outputSchema.structIterator()) {
          if (member7.getMemberTraits().httpPayload && !(name in output)) {
            output[name] = null;
          }
        }
        return output;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = loadRestJsonErrorCode3(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        await this.deserializeHttpMessage(errorSchema, context, response, dataObject);
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().jsonName ?? name;
          output[name] = errorDeserializer.readObject(member7, dataObject[target]);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      getDefaultContentType() {
        return "application/json";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/awsExpectUnion.js
var import_smithy_client33, awsExpectUnion2;
var init_awsExpectUnion3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/awsExpectUnion.js"() {
    import_smithy_client33 = __toESM(require_dist_cjs34());
    awsExpectUnion2 = /* @__PURE__ */ __name((value) => {
      if (value == null) {
        return void 0;
      }
      if (typeof value === "object" && "__type" in value) {
        delete value.__type;
      }
      return (0, import_smithy_client33.expectUnion)(value);
    }, "awsExpectUnion");
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeDeserializer.js
var import_xml_builder4, import_smithy_client34, import_util_utf813, XmlShapeDeserializer2;
var init_XmlShapeDeserializer3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeDeserializer.js"() {
    import_xml_builder4 = __toESM(require_dist_cjs47());
    init_protocols();
    init_schema4();
    import_smithy_client34 = __toESM(require_dist_cjs34());
    import_util_utf813 = __toESM(require_dist_cjs9());
    init_ConfigurableSerdeContext3();
    init_UnionSerde3();
    XmlShapeDeserializer2 = class extends SerdeContextConfig3 {
      static {
        __name(this, "XmlShapeDeserializer");
      }
      settings;
      stringDeserializer;
      constructor(settings) {
        super();
        this.settings = settings;
        this.stringDeserializer = new FromStringShapeDeserializer(settings);
      }
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
        this.stringDeserializer.setSerdeContext(serdeContext);
      }
      read(schema, bytes, key) {
        const ns = NormalizedSchema.of(schema);
        const memberSchemas = ns.getMemberSchemas();
        const isEventPayload = ns.isStructSchema() && ns.isMemberSchema() && !!Object.values(memberSchemas).find((memberNs) => {
          return !!memberNs.getMemberTraits().eventPayload;
        });
        if (isEventPayload) {
          const output = {};
          const memberName = Object.keys(memberSchemas)[0];
          const eventMemberSchema = memberSchemas[memberName];
          if (eventMemberSchema.isBlobSchema()) {
            output[memberName] = bytes;
          } else {
            output[memberName] = this.read(memberSchemas[memberName], bytes);
          }
          return output;
        }
        const xmlString = (this.serdeContext?.utf8Encoder ?? import_util_utf813.toUtf8)(bytes);
        const parsedObject = this.parseXml(xmlString);
        return this.readSchema(schema, key ? parsedObject[key] : parsedObject);
      }
      readSchema(_schema, value) {
        const ns = NormalizedSchema.of(_schema);
        if (ns.isUnitSchema()) {
          return;
        }
        const traits = ns.getMergedTraits();
        if (ns.isListSchema() && !Array.isArray(value)) {
          return this.readSchema(ns, [value]);
        }
        if (value == null) {
          return value;
        }
        if (typeof value === "object") {
          const flat = !!traits.xmlFlattened;
          if (ns.isListSchema()) {
            const listValue = ns.getValueSchema();
            const buffer2 = [];
            const sourceKey = listValue.getMergedTraits().xmlName ?? "member";
            const source = flat ? value : (value[0] ?? value)[sourceKey];
            if (source == null) {
              return buffer2;
            }
            const sourceArray = Array.isArray(source) ? source : [source];
            for (const v of sourceArray) {
              buffer2.push(this.readSchema(listValue, v));
            }
            return buffer2;
          }
          const buffer = {};
          if (ns.isMapSchema()) {
            const keyNs = ns.getKeySchema();
            const memberNs = ns.getValueSchema();
            let entries;
            if (flat) {
              entries = Array.isArray(value) ? value : [value];
            } else {
              entries = Array.isArray(value.entry) ? value.entry : [value.entry];
            }
            const keyProperty = keyNs.getMergedTraits().xmlName ?? "key";
            const valueProperty = memberNs.getMergedTraits().xmlName ?? "value";
            for (const entry of entries) {
              const key = entry[keyProperty];
              const value2 = entry[valueProperty];
              buffer[key] = this.readSchema(memberNs, value2);
            }
            return buffer;
          }
          if (ns.isStructSchema()) {
            const union = ns.isUnionSchema();
            let unionSerde;
            if (union) {
              unionSerde = new UnionSerde3(value, buffer);
            }
            for (const [memberName, memberSchema] of ns.structIterator()) {
              const memberTraits = memberSchema.getMergedTraits();
              const xmlObjectKey = !memberTraits.httpPayload ? memberSchema.getMemberTraits().xmlName ?? memberName : memberTraits.xmlName ?? memberSchema.getName();
              if (union) {
                unionSerde.mark(xmlObjectKey);
              }
              if (value[xmlObjectKey] != null) {
                buffer[memberName] = this.readSchema(memberSchema, value[xmlObjectKey]);
              }
            }
            if (union) {
              unionSerde.writeUnknown();
            }
            return buffer;
          }
          if (ns.isDocumentSchema()) {
            return value;
          }
          throw new Error(`@aws-sdk/core/protocols - xml deserializer unhandled schema type for ${ns.getName(true)}`);
        }
        if (ns.isListSchema()) {
          return [];
        }
        if (ns.isMapSchema() || ns.isStructSchema()) {
          return {};
        }
        return this.stringDeserializer.read(ns, value);
      }
      parseXml(xml) {
        if (xml.length) {
          let parsedObj;
          try {
            parsedObj = (0, import_xml_builder4.parseXML)(xml);
          } catch (e32) {
            if (e32 && typeof e32 === "object") {
              Object.defineProperty(e32, "$responseBodyText", {
                value: xml
              });
            }
            throw e32;
          }
          const textNodeName = "#text";
          const key = Object.keys(parsedObj)[0];
          const parsedObjToReturn = parsedObj[key];
          if (parsedObjToReturn[textNodeName]) {
            parsedObjToReturn[key] = parsedObjToReturn[textNodeName];
            delete parsedObjToReturn[textNodeName];
          }
          return (0, import_smithy_client34.getValueFromTextNode)(parsedObjToReturn);
        }
        return {};
      }
    };
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QueryShapeSerializer.js
var import_smithy_client35, import_util_base6415, QueryShapeSerializer2;
var init_QueryShapeSerializer3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QueryShapeSerializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_smithy_client35 = __toESM(require_dist_cjs34());
    import_util_base6415 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext3();
    QueryShapeSerializer2 = class extends SerdeContextConfig3 {
      static {
        __name(this, "QueryShapeSerializer");
      }
      settings;
      buffer;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value, prefix = "") {
        if (this.buffer === void 0) {
          this.buffer = "";
        }
        const ns = NormalizedSchema.of(schema);
        if (prefix && !prefix.endsWith(".")) {
          prefix += ".";
        }
        if (ns.isBlobSchema()) {
          if (typeof value === "string" || value instanceof Uint8Array) {
            this.writeKey(prefix);
            this.writeValue((this.serdeContext?.base64Encoder ?? import_util_base6415.toBase64)(value));
          }
        } else if (ns.isBooleanSchema() || ns.isNumericSchema() || ns.isStringSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(String(value));
          } else if (ns.isIdempotencyToken()) {
            this.writeKey(prefix);
            this.writeValue((0, import_uuid.v4)());
          }
        } else if (ns.isBigIntegerSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(String(value));
          }
        } else if (ns.isBigDecimalSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(value instanceof NumericValue ? value.string : String(value));
          }
        } else if (ns.isTimestampSchema()) {
          if (value instanceof Date) {
            this.writeKey(prefix);
            const format32 = determineTimestampFormat(ns, this.settings);
            switch (format32) {
              case 5:
                this.writeValue(value.toISOString().replace(".000Z", "Z"));
                break;
              case 6:
                this.writeValue((0, import_smithy_client35.dateToUtcString)(value));
                break;
              case 7:
                this.writeValue(String(value.getTime() / 1e3));
                break;
            }
          }
        } else if (ns.isDocumentSchema()) {
          if (Array.isArray(value)) {
            this.write(64 | 15, value, prefix);
          } else if (value instanceof Date) {
            this.write(4, value, prefix);
          } else if (value instanceof Uint8Array) {
            this.write(21, value, prefix);
          } else if (value && typeof value === "object") {
            this.write(128 | 15, value, prefix);
          } else {
            this.writeKey(prefix);
            this.writeValue(String(value));
          }
        } else if (ns.isListSchema()) {
          if (Array.isArray(value)) {
            if (value.length === 0) {
              if (this.settings.serializeEmptyLists) {
                this.writeKey(prefix);
                this.writeValue("");
              }
            } else {
              const member7 = ns.getValueSchema();
              const flat = this.settings.flattenLists || ns.getMergedTraits().xmlFlattened;
              let i32 = 1;
              for (const item of value) {
                if (item == null) {
                  continue;
                }
                const traits = member7.getMergedTraits();
                const suffix = this.getKey("member", traits.xmlName, traits.ec2QueryName);
                const key = flat ? `${prefix}${i32}` : `${prefix}${suffix}.${i32}`;
                this.write(member7, item, key);
                ++i32;
              }
            }
          }
        } else if (ns.isMapSchema()) {
          if (value && typeof value === "object") {
            const keySchema = ns.getKeySchema();
            const memberSchema = ns.getValueSchema();
            const flat = ns.getMergedTraits().xmlFlattened;
            let i32 = 1;
            for (const k32 in value) {
              const v = value[k32];
              if (v == null) {
                continue;
              }
              const keyTraits = keySchema.getMergedTraits();
              const keySuffix = this.getKey("key", keyTraits.xmlName, keyTraits.ec2QueryName);
              const key = flat ? `${prefix}${i32}.${keySuffix}` : `${prefix}entry.${i32}.${keySuffix}`;
              const valTraits = memberSchema.getMergedTraits();
              const valueSuffix = this.getKey("value", valTraits.xmlName, valTraits.ec2QueryName);
              const valueKey = flat ? `${prefix}${i32}.${valueSuffix}` : `${prefix}entry.${i32}.${valueSuffix}`;
              this.write(keySchema, k32, key);
              this.write(memberSchema, v, valueKey);
              ++i32;
            }
          }
        } else if (ns.isStructSchema()) {
          if (value && typeof value === "object") {
            let didWriteMember = false;
            for (const [memberName, member7] of ns.structIterator()) {
              if (value[memberName] == null && !member7.isIdempotencyToken()) {
                continue;
              }
              const traits = member7.getMergedTraits();
              const suffix = this.getKey(memberName, traits.xmlName, traits.ec2QueryName, "struct");
              const key = `${prefix}${suffix}`;
              this.write(member7, value[memberName], key);
              didWriteMember = true;
            }
            if (!didWriteMember && ns.isUnionSchema()) {
              const { $unknown } = value;
              if (Array.isArray($unknown)) {
                const [k32, v] = $unknown;
                const key = `${prefix}${k32}`;
                this.write(15, v, key);
              }
            }
          }
        } else if (ns.isUnitSchema()) {
        } else {
          throw new Error(`@aws-sdk/core/protocols - QuerySerializer unrecognized schema type ${ns.getName(true)}`);
        }
      }
      flush() {
        if (this.buffer === void 0) {
          throw new Error("@aws-sdk/core/protocols - QuerySerializer cannot flush with nothing written to buffer.");
        }
        const str = this.buffer;
        delete this.buffer;
        return str;
      }
      getKey(memberName, xmlName, ec2QueryName, keySource) {
        const { ec2, capitalizeKeys } = this.settings;
        if (ec2 && ec2QueryName) {
          return ec2QueryName;
        }
        const key = xmlName ?? memberName;
        if (capitalizeKeys && keySource === "struct") {
          return key[0].toUpperCase() + key.slice(1);
        }
        return key;
      }
      writeKey(key) {
        if (key.endsWith(".")) {
          key = key.slice(0, key.length - 1);
        }
        this.buffer += `&${extendedEncodeURIComponent(key)}=`;
      }
      writeValue(value) {
        this.buffer += extendedEncodeURIComponent(value);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsQueryProtocol.js
var AwsQueryProtocol2;
var init_AwsQueryProtocol3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsQueryProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib3();
    init_XmlShapeDeserializer3();
    init_QueryShapeSerializer3();
    AwsQueryProtocol2 = class extends RpcProtocol {
      static {
        __name(this, "AwsQueryProtocol");
      }
      options;
      serializer;
      deserializer;
      mixin = new ProtocolLib3();
      constructor(options) {
        super({
          defaultNamespace: options.defaultNamespace,
          errorTypeRegistries: options.errorTypeRegistries
        });
        this.options = options;
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 5
          },
          httpBindings: false,
          xmlNamespace: options.xmlNamespace,
          serviceNamespace: options.defaultNamespace,
          serializeEmptyLists: true
        };
        this.serializer = new QueryShapeSerializer2(settings);
        this.deserializer = new XmlShapeDeserializer2(settings);
      }
      getShapeId() {
        return "aws.protocols#awsQuery";
      }
      setSerdeContext(serdeContext) {
        this.serializer.setSerdeContext(serdeContext);
        this.deserializer.setSerdeContext(serdeContext);
      }
      getPayloadCodec() {
        throw new Error("AWSQuery protocol has no payload codec.");
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        if (!request4.path.endsWith("/")) {
          request4.path += "/";
        }
        request4.headers["content-type"] = "application/x-www-form-urlencoded";
        if (deref(operationSchema.input) === "unit" || !request4.body) {
          request4.body = "";
        }
        const action = operationSchema.name.split("#")[1] ?? operationSchema.name;
        request4.body = `Action=${action}&Version=${this.options.version}` + request4.body;
        if (request4.body.endsWith("&")) {
          request4.body = request4.body.slice(-1);
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        const deserializer = this.deserializer;
        const ns = NormalizedSchema.of(operationSchema.output);
        const dataObject = {};
        if (response.statusCode >= 300) {
          const bytes2 = await collectBody(response.body, context);
          if (bytes2.byteLength > 0) {
            Object.assign(dataObject, await deserializer.read(15, bytes2));
          }
          await this.handleError(operationSchema, context, response, dataObject, this.deserializeMetadata(response));
        }
        for (const header in response.headers) {
          const value = response.headers[header];
          delete response.headers[header];
          response.headers[header.toLowerCase()] = value;
        }
        const shortName = operationSchema.name.split("#")[1] ?? operationSchema.name;
        const awsQueryResultKey = ns.isStructSchema() && this.useNestedResult() ? shortName + "Result" : void 0;
        const bytes = await collectBody(response.body, context);
        if (bytes.byteLength > 0) {
          Object.assign(dataObject, await deserializer.read(ns, bytes, awsQueryResultKey));
        }
        dataObject.$metadata = this.deserializeMetadata(response);
        return dataObject;
      }
      useNestedResult() {
        return true;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = this.loadQueryErrorCode(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const errorData = this.loadQueryError(dataObject) ?? {};
        const message2 = this.loadQueryErrorMessage(dataObject);
        errorData.message = message2;
        errorData.Error = {
          Type: errorData.Type,
          Code: errorData.Code,
          Message: message2
        };
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, errorData, metadata, this.mixin.findQueryCompatibleError);
        const ns = NormalizedSchema.of(errorSchema);
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        const output = {
          Type: errorData.Error.Type,
          Code: errorData.Error.Code,
          Error: errorData.Error
        };
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().xmlName ?? name;
          const value = errorData[target] ?? dataObject[target];
          output[name] = this.deserializer.readSchema(member7, value);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      loadQueryErrorCode(output, data3) {
        const code = (data3.Errors?.[0]?.Error ?? data3.Errors?.Error ?? data3.Error)?.Code;
        if (code !== void 0) {
          return code;
        }
        if (output.statusCode == 404) {
          return "NotFound";
        }
      }
      loadQueryError(data3) {
        return data3.Errors?.[0]?.Error ?? data3.Errors?.Error ?? data3.Error;
      }
      loadQueryErrorMessage(data3) {
        const errorData = this.loadQueryError(data3);
        return errorData?.message ?? errorData?.Message ?? data3.message ?? data3.Message ?? "Unknown";
      }
      getDefaultContentType() {
        return "application/x-www-form-urlencoded";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsEc2QueryProtocol.js
var AwsEc2QueryProtocol2;
var init_AwsEc2QueryProtocol3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsEc2QueryProtocol.js"() {
    init_AwsQueryProtocol3();
    AwsEc2QueryProtocol2 = class extends AwsQueryProtocol2 {
      static {
        __name(this, "AwsEc2QueryProtocol");
      }
      options;
      constructor(options) {
        super(options);
        this.options = options;
        const ec2Settings = {
          capitalizeKeys: true,
          flattenLists: true,
          serializeEmptyLists: false,
          ec2: true
        };
        Object.assign(this.serializer.settings, ec2Settings);
      }
      getShapeId() {
        return "aws.protocols#ec2Query";
      }
      useNestedResult() {
        return false;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QuerySerializerSettings.js
var init_QuerySerializerSettings3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QuerySerializerSettings.js"() {
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/parseXmlBody.js
var import_xml_builder5, import_smithy_client36, parseXmlBody2, parseXmlErrorBody2, loadRestXmlErrorCode2;
var init_parseXmlBody3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/parseXmlBody.js"() {
    import_xml_builder5 = __toESM(require_dist_cjs47());
    import_smithy_client36 = __toESM(require_dist_cjs34());
    init_common4();
    parseXmlBody2 = /* @__PURE__ */ __name((streamBody, context) => collectBodyString3(streamBody, context).then((encoded) => {
      if (encoded.length) {
        let parsedObj;
        try {
          parsedObj = (0, import_xml_builder5.parseXML)(encoded);
        } catch (e32) {
          if (e32 && typeof e32 === "object") {
            Object.defineProperty(e32, "$responseBodyText", {
              value: encoded
            });
          }
          throw e32;
        }
        const textNodeName = "#text";
        const key = Object.keys(parsedObj)[0];
        const parsedObjToReturn = parsedObj[key];
        if (parsedObjToReturn[textNodeName]) {
          parsedObjToReturn[key] = parsedObjToReturn[textNodeName];
          delete parsedObjToReturn[textNodeName];
        }
        return (0, import_smithy_client36.getValueFromTextNode)(parsedObjToReturn);
      }
      return {};
    }), "parseXmlBody");
    parseXmlErrorBody2 = /* @__PURE__ */ __name(async (errorBody, context) => {
      const value = await parseXmlBody2(errorBody, context);
      if (value.Error) {
        value.Error.message = value.Error.message ?? value.Error.Message;
      }
      return value;
    }, "parseXmlErrorBody");
    loadRestXmlErrorCode2 = /* @__PURE__ */ __name((output, data3) => {
      if (data3?.Error?.Code !== void 0) {
        return data3.Error.Code;
      }
      if (data3?.Code !== void 0) {
        return data3.Code;
      }
      if (output.statusCode == 404) {
        return "NotFound";
      }
    }, "loadRestXmlErrorCode");
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeSerializer.js
var import_xml_builder6, import_smithy_client37, import_util_base6416, XmlShapeSerializer2;
var init_XmlShapeSerializer3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeSerializer.js"() {
    import_xml_builder6 = __toESM(require_dist_cjs47());
    init_protocols();
    init_schema4();
    init_serde();
    import_smithy_client37 = __toESM(require_dist_cjs34());
    import_util_base6416 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext3();
    XmlShapeSerializer2 = class extends SerdeContextConfig3 {
      static {
        __name(this, "XmlShapeSerializer");
      }
      settings;
      stringBuffer;
      byteBuffer;
      buffer;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value) {
        const ns = NormalizedSchema.of(schema);
        if (ns.isStringSchema() && typeof value === "string") {
          this.stringBuffer = value;
        } else if (ns.isBlobSchema()) {
          this.byteBuffer = "byteLength" in value ? value : (this.serdeContext?.base64Decoder ?? import_util_base6416.fromBase64)(value);
        } else {
          this.buffer = this.writeStruct(ns, value, void 0);
          const traits = ns.getMergedTraits();
          if (traits.httpPayload && !traits.xmlName) {
            this.buffer.withName(ns.getName());
          }
        }
      }
      flush() {
        if (this.byteBuffer !== void 0) {
          const bytes = this.byteBuffer;
          delete this.byteBuffer;
          return bytes;
        }
        if (this.stringBuffer !== void 0) {
          const str = this.stringBuffer;
          delete this.stringBuffer;
          return str;
        }
        const buffer = this.buffer;
        if (this.settings.xmlNamespace) {
          if (!buffer?.attributes?.["xmlns"]) {
            buffer.addAttribute("xmlns", this.settings.xmlNamespace);
          }
        }
        delete this.buffer;
        return buffer.toString();
      }
      writeStruct(ns, value, parentXmlns) {
        const traits = ns.getMergedTraits();
        const name = ns.isMemberSchema() && !traits.httpPayload ? ns.getMemberTraits().xmlName ?? ns.getMemberName() : traits.xmlName ?? ns.getName();
        if (!name || !ns.isStructSchema()) {
          throw new Error(`@aws-sdk/core/protocols - xml serializer, cannot write struct with empty name or non-struct, schema=${ns.getName(true)}.`);
        }
        const structXmlNode = import_xml_builder6.XmlNode.of(name);
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(ns, parentXmlns);
        for (const [memberName, memberSchema] of ns.structIterator()) {
          const val = value[memberName];
          if (val != null || memberSchema.isIdempotencyToken()) {
            if (memberSchema.getMergedTraits().xmlAttribute) {
              structXmlNode.addAttribute(memberSchema.getMergedTraits().xmlName ?? memberName, this.writeSimple(memberSchema, val));
              continue;
            }
            if (memberSchema.isListSchema()) {
              this.writeList(memberSchema, val, structXmlNode, xmlns);
            } else if (memberSchema.isMapSchema()) {
              this.writeMap(memberSchema, val, structXmlNode, xmlns);
            } else if (memberSchema.isStructSchema()) {
              structXmlNode.addChildNode(this.writeStruct(memberSchema, val, xmlns));
            } else {
              const memberNode = import_xml_builder6.XmlNode.of(memberSchema.getMergedTraits().xmlName ?? memberSchema.getMemberName());
              this.writeSimpleInto(memberSchema, val, memberNode, xmlns);
              structXmlNode.addChildNode(memberNode);
            }
          }
        }
        const { $unknown } = value;
        if ($unknown && ns.isUnionSchema() && Array.isArray($unknown) && Object.keys(value).length === 1) {
          const [k32, v] = $unknown;
          const node = import_xml_builder6.XmlNode.of(k32);
          if (typeof v !== "string") {
            if (value instanceof import_xml_builder6.XmlNode || value instanceof import_xml_builder6.XmlText) {
              structXmlNode.addChildNode(value);
            } else {
              throw new Error(`@aws-sdk - $unknown union member in XML requires value of type string, @aws-sdk/xml-builder::XmlNode or XmlText.`);
            }
          }
          this.writeSimpleInto(0, v, node, xmlns);
          structXmlNode.addChildNode(node);
        }
        if (xmlns) {
          structXmlNode.addAttribute(xmlnsAttr, xmlns);
        }
        return structXmlNode;
      }
      writeList(listMember, array, container, parentXmlns) {
        if (!listMember.isMemberSchema()) {
          throw new Error(`@aws-sdk/core/protocols - xml serializer, cannot write non-member list: ${listMember.getName(true)}`);
        }
        const listTraits = listMember.getMergedTraits();
        const listValueSchema = listMember.getValueSchema();
        const listValueTraits = listValueSchema.getMergedTraits();
        const sparse = !!listValueTraits.sparse;
        const flat = !!listTraits.xmlFlattened;
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(listMember, parentXmlns);
        const writeItem = /* @__PURE__ */ __name((container2, value) => {
          if (listValueSchema.isListSchema()) {
            this.writeList(listValueSchema, Array.isArray(value) ? value : [value], container2, xmlns);
          } else if (listValueSchema.isMapSchema()) {
            this.writeMap(listValueSchema, value, container2, xmlns);
          } else if (listValueSchema.isStructSchema()) {
            const struct3 = this.writeStruct(listValueSchema, value, xmlns);
            container2.addChildNode(struct3.withName(flat ? listTraits.xmlName ?? listMember.getMemberName() : listValueTraits.xmlName ?? "member"));
          } else {
            const listItemNode = import_xml_builder6.XmlNode.of(flat ? listTraits.xmlName ?? listMember.getMemberName() : listValueTraits.xmlName ?? "member");
            this.writeSimpleInto(listValueSchema, value, listItemNode, xmlns);
            container2.addChildNode(listItemNode);
          }
        }, "writeItem");
        if (flat) {
          for (const value of array) {
            if (sparse || value != null) {
              writeItem(container, value);
            }
          }
        } else {
          const listNode = import_xml_builder6.XmlNode.of(listTraits.xmlName ?? listMember.getMemberName());
          if (xmlns) {
            listNode.addAttribute(xmlnsAttr, xmlns);
          }
          for (const value of array) {
            if (sparse || value != null) {
              writeItem(listNode, value);
            }
          }
          container.addChildNode(listNode);
        }
      }
      writeMap(mapMember, map5, container, parentXmlns, containerIsMap = false) {
        if (!mapMember.isMemberSchema()) {
          throw new Error(`@aws-sdk/core/protocols - xml serializer, cannot write non-member map: ${mapMember.getName(true)}`);
        }
        const mapTraits = mapMember.getMergedTraits();
        const mapKeySchema = mapMember.getKeySchema();
        const mapKeyTraits = mapKeySchema.getMergedTraits();
        const keyTag = mapKeyTraits.xmlName ?? "key";
        const mapValueSchema = mapMember.getValueSchema();
        const mapValueTraits = mapValueSchema.getMergedTraits();
        const valueTag = mapValueTraits.xmlName ?? "value";
        const sparse = !!mapValueTraits.sparse;
        const flat = !!mapTraits.xmlFlattened;
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(mapMember, parentXmlns);
        const addKeyValue = /* @__PURE__ */ __name((entry, key, val) => {
          const keyNode = import_xml_builder6.XmlNode.of(keyTag, key);
          const [keyXmlnsAttr, keyXmlns] = this.getXmlnsAttribute(mapKeySchema, xmlns);
          if (keyXmlns) {
            keyNode.addAttribute(keyXmlnsAttr, keyXmlns);
          }
          entry.addChildNode(keyNode);
          let valueNode = import_xml_builder6.XmlNode.of(valueTag);
          if (mapValueSchema.isListSchema()) {
            this.writeList(mapValueSchema, val, valueNode, xmlns);
          } else if (mapValueSchema.isMapSchema()) {
            this.writeMap(mapValueSchema, val, valueNode, xmlns, true);
          } else if (mapValueSchema.isStructSchema()) {
            valueNode = this.writeStruct(mapValueSchema, val, xmlns);
          } else {
            this.writeSimpleInto(mapValueSchema, val, valueNode, xmlns);
          }
          entry.addChildNode(valueNode);
        }, "addKeyValue");
        if (flat) {
          for (const key in map5) {
            const val = map5[key];
            if (sparse || val != null) {
              const entry = import_xml_builder6.XmlNode.of(mapTraits.xmlName ?? mapMember.getMemberName());
              addKeyValue(entry, key, val);
              container.addChildNode(entry);
            }
          }
        } else {
          let mapNode;
          if (!containerIsMap) {
            mapNode = import_xml_builder6.XmlNode.of(mapTraits.xmlName ?? mapMember.getMemberName());
            if (xmlns) {
              mapNode.addAttribute(xmlnsAttr, xmlns);
            }
            container.addChildNode(mapNode);
          }
          for (const key in map5) {
            const val = map5[key];
            if (sparse || val != null) {
              const entry = import_xml_builder6.XmlNode.of("entry");
              addKeyValue(entry, key, val);
              (containerIsMap ? container : mapNode).addChildNode(entry);
            }
          }
        }
      }
      writeSimple(_schema, value) {
        if (null === value) {
          throw new Error("@aws-sdk/core/protocols - (XML serializer) cannot write null value.");
        }
        const ns = NormalizedSchema.of(_schema);
        let nodeContents = null;
        if (value && typeof value === "object") {
          if (ns.isBlobSchema()) {
            nodeContents = (this.serdeContext?.base64Encoder ?? import_util_base6416.toBase64)(value);
          } else if (ns.isTimestampSchema() && value instanceof Date) {
            const format32 = determineTimestampFormat(ns, this.settings);
            switch (format32) {
              case 5:
                nodeContents = value.toISOString().replace(".000Z", "Z");
                break;
              case 6:
                nodeContents = (0, import_smithy_client37.dateToUtcString)(value);
                break;
              case 7:
                nodeContents = String(value.getTime() / 1e3);
                break;
              default:
                console.warn("Missing timestamp format, using http date", value);
                nodeContents = (0, import_smithy_client37.dateToUtcString)(value);
                break;
            }
          } else if (ns.isBigDecimalSchema() && value) {
            if (value instanceof NumericValue) {
              return value.string;
            }
            return String(value);
          } else if (ns.isMapSchema() || ns.isListSchema()) {
            throw new Error("@aws-sdk/core/protocols - xml serializer, cannot call _write() on List/Map schema, call writeList or writeMap() instead.");
          } else {
            throw new Error(`@aws-sdk/core/protocols - xml serializer, unhandled schema type for object value and schema: ${ns.getName(true)}`);
          }
        }
        if (ns.isBooleanSchema() || ns.isNumericSchema() || ns.isBigIntegerSchema() || ns.isBigDecimalSchema()) {
          nodeContents = String(value);
        }
        if (ns.isStringSchema()) {
          if (value === void 0 && ns.isIdempotencyToken()) {
            nodeContents = (0, import_uuid.v4)();
          } else {
            nodeContents = String(value);
          }
        }
        if (nodeContents === null) {
          throw new Error(`Unhandled schema-value pair ${ns.getName(true)}=${value}`);
        }
        return nodeContents;
      }
      writeSimpleInto(_schema, value, into, parentXmlns) {
        const nodeContents = this.writeSimple(_schema, value);
        const ns = NormalizedSchema.of(_schema);
        const content = new import_xml_builder6.XmlText(nodeContents);
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(ns, parentXmlns);
        if (xmlns) {
          into.addAttribute(xmlnsAttr, xmlns);
        }
        into.addChildNode(content);
      }
      getXmlnsAttribute(ns, parentXmlns) {
        const traits = ns.getMergedTraits();
        const [prefix, xmlns] = traits.xmlNamespace ?? [];
        if (xmlns && xmlns !== parentXmlns) {
          return [prefix ? `xmlns:${prefix}` : "xmlns", xmlns];
        }
        return [void 0, void 0];
      }
    };
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlCodec.js
var XmlCodec2;
var init_XmlCodec3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlCodec.js"() {
    init_ConfigurableSerdeContext3();
    init_XmlShapeDeserializer3();
    init_XmlShapeSerializer3();
    XmlCodec2 = class extends SerdeContextConfig3 {
      static {
        __name(this, "XmlCodec");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      createSerializer() {
        const serializer = new XmlShapeSerializer2(this.settings);
        serializer.setSerdeContext(this.serdeContext);
        return serializer;
      }
      createDeserializer() {
        const deserializer = new XmlShapeDeserializer2(this.settings);
        deserializer.setSerdeContext(this.serdeContext);
        return deserializer;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/AwsRestXmlProtocol.js
var AwsRestXmlProtocol2;
var init_AwsRestXmlProtocol3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/AwsRestXmlProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib3();
    init_parseXmlBody3();
    init_XmlCodec3();
    AwsRestXmlProtocol2 = class extends HttpBindingProtocol {
      static {
        __name(this, "AwsRestXmlProtocol");
      }
      codec;
      serializer;
      deserializer;
      mixin = new ProtocolLib3();
      constructor(options) {
        super(options);
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 5
          },
          httpBindings: true,
          xmlNamespace: options.xmlNamespace,
          serviceNamespace: options.defaultNamespace
        };
        this.codec = new XmlCodec2(settings);
        this.serializer = new HttpInterceptingShapeSerializer(this.codec.createSerializer(), settings);
        this.deserializer = new HttpInterceptingShapeDeserializer(this.codec.createDeserializer(), settings);
      }
      getPayloadCodec() {
        return this.codec;
      }
      getShapeId() {
        return "aws.protocols#restXml";
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        const inputSchema = NormalizedSchema.of(operationSchema.input);
        if (!request4.headers["content-type"]) {
          const contentType = this.mixin.resolveRestContentType(this.getDefaultContentType(), inputSchema);
          if (contentType) {
            request4.headers["content-type"] = contentType;
          }
        }
        if (typeof request4.body === "string" && request4.headers["content-type"] === this.getDefaultContentType() && !request4.body.startsWith("<?xml ") && !this.hasUnstructuredPayloadBinding(inputSchema)) {
          request4.body = '<?xml version="1.0" encoding="UTF-8"?>' + request4.body;
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        return super.deserializeResponse(operationSchema, context, response);
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = loadRestXmlErrorCode2(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        if (dataObject.Error && typeof dataObject.Error === "object") {
          for (const key of Object.keys(dataObject.Error)) {
            dataObject[key] = dataObject.Error[key];
            if (key.toLowerCase() === "message") {
              dataObject.message = dataObject.Error[key];
            }
          }
        }
        if (dataObject.RequestId && !metadata.requestId) {
          metadata.requestId = dataObject.RequestId;
        }
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.Error?.message ?? dataObject.Error?.Message ?? dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        await this.deserializeHttpMessage(errorSchema, context, response, dataObject);
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().xmlName ?? name;
          const value = dataObject.Error?.[target] ?? dataObject[target];
          output[name] = errorDeserializer.readSchema(member7, value);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      getDefaultContentType() {
        return "application/xml";
      }
      hasUnstructuredPayloadBinding(ns) {
        for (const [, member7] of ns.structIterator()) {
          if (member7.getMergedTraits().httpPayload) {
            return !(member7.isStructSchema() || member7.isMapSchema() || member7.isListSchema());
          }
        }
        return false;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/index.js
var protocols_exports3 = {};
__export(protocols_exports3, {
  AwsEc2QueryProtocol: () => AwsEc2QueryProtocol2,
  AwsJson1_0Protocol: () => AwsJson1_0Protocol2,
  AwsJson1_1Protocol: () => AwsJson1_1Protocol2,
  AwsJsonRpcProtocol: () => AwsJsonRpcProtocol2,
  AwsQueryProtocol: () => AwsQueryProtocol2,
  AwsRestJsonProtocol: () => AwsRestJsonProtocol3,
  AwsRestXmlProtocol: () => AwsRestXmlProtocol2,
  AwsSmithyRpcV2CborProtocol: () => AwsSmithyRpcV2CborProtocol2,
  JsonCodec: () => JsonCodec3,
  JsonShapeDeserializer: () => JsonShapeDeserializer3,
  JsonShapeSerializer: () => JsonShapeSerializer3,
  QueryShapeSerializer: () => QueryShapeSerializer2,
  XmlCodec: () => XmlCodec2,
  XmlShapeDeserializer: () => XmlShapeDeserializer2,
  XmlShapeSerializer: () => XmlShapeSerializer2,
  _toBool: () => _toBool2,
  _toNum: () => _toNum2,
  _toStr: () => _toStr2,
  awsExpectUnion: () => awsExpectUnion2,
  loadRestJsonErrorCode: () => loadRestJsonErrorCode3,
  loadRestXmlErrorCode: () => loadRestXmlErrorCode2,
  parseJsonBody: () => parseJsonBody3,
  parseJsonErrorBody: () => parseJsonErrorBody2,
  parseXmlBody: () => parseXmlBody2,
  parseXmlErrorBody: () => parseXmlErrorBody2
});
var init_protocols5 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/index.js"() {
    init_AwsSmithyRpcV2CborProtocol3();
    init_coercing_serializers3();
    init_AwsJson1_0Protocol3();
    init_AwsJson1_1Protocol3();
    init_AwsJsonRpcProtocol3();
    init_AwsRestJsonProtocol3();
    init_JsonCodec3();
    init_JsonShapeDeserializer3();
    init_JsonShapeSerializer3();
    init_awsExpectUnion3();
    init_parseJsonBody3();
    init_AwsEc2QueryProtocol3();
    init_AwsQueryProtocol3();
    init_QuerySerializerSettings3();
    init_QueryShapeSerializer3();
    init_AwsRestXmlProtocol3();
    init_XmlCodec3();
    init_XmlShapeDeserializer3();
    init_XmlShapeSerializer3();
    init_parseXmlBody3();
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/client/emitWarningIfUnsupportedVersion.js
var state3, emitWarningIfUnsupportedVersion6;
var init_emitWarningIfUnsupportedVersion3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/client/emitWarningIfUnsupportedVersion.js"() {
    state3 = {
      warningEmitted: false
    };
    emitWarningIfUnsupportedVersion6 = /* @__PURE__ */ __name((version) => {
      if (version && !state3.warningEmitted) {
        if (process.env.AWS_SDK_JS_NODE_VERSION_SUPPORT_WARNING_DISABLED === "true") {
          state3.warningEmitted = true;
          return;
        }
        const userMajorVersion = parseInt(version.substring(1, version.indexOf(".")));
        const vv = 22;
        if (userMajorVersion < vv) {
          state3.warningEmitted = true;
          process.emitWarning(`NodeVersionSupportWarning: The AWS SDK for JavaScript (v3)
versions published after the first week of January 2027
will require node >=${vv}. You are running node ${version}.

To continue receiving updates to AWS services, bug fixes,
and security updates please upgrade to node >=${vv}.

More information can be found at: https://a.co/c895JFp`);
        }
      }
    }, "emitWarningIfUnsupportedVersion");
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/client/longPollMiddleware.js
var longPollMiddleware3, longPollMiddlewareOptions3, getLongPollPlugin3;
var init_longPollMiddleware3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/client/longPollMiddleware.js"() {
    longPollMiddleware3 = /* @__PURE__ */ __name(() => (next, context) => async (args) => {
      context.__retryLongPoll = true;
      return next(args);
    }, "longPollMiddleware");
    longPollMiddlewareOptions3 = {
      name: "longPollMiddleware",
      tags: ["RETRY"],
      step: "initialize",
      override: true
    };
    getLongPollPlugin3 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(longPollMiddleware3(), longPollMiddlewareOptions3);
      }, "applyToStack")
    }), "getLongPollPlugin");
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/client/setCredentialFeature.js
function setCredentialFeature3(credentials, feature, value) {
  if (!credentials.$source) {
    credentials.$source = {};
  }
  credentials.$source[feature] = value;
  return credentials;
}
var init_setCredentialFeature3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/client/setCredentialFeature.js"() {
    __name(setCredentialFeature3, "setCredentialFeature");
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/client/setFeature.js
function setFeature4(context, feature, value) {
  if (!context.__aws_sdk_context) {
    context.__aws_sdk_context = {
      features: {}
    };
  } else if (!context.__aws_sdk_context.features) {
    context.__aws_sdk_context.features = {};
  }
  context.__aws_sdk_context.features[feature] = value;
}
var import_util_retry6;
var init_setFeature4 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/client/setFeature.js"() {
    import_util_retry6 = __toESM(require_dist_cjs22());
    import_util_retry6.Retry.v2026 ||= typeof process === "object" && process.env?.AWS_NEW_RETRIES_2026 === "true";
    __name(setFeature4, "setFeature");
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/client/setTokenFeature.js
function setTokenFeature3(token, feature, value) {
  if (!token.$source) {
    token.$source = {};
  }
  token.$source[feature] = value;
  return token;
}
var init_setTokenFeature3 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/client/setTokenFeature.js"() {
    __name(setTokenFeature3, "setTokenFeature");
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/client/index.js
var client_exports3 = {};
__export(client_exports3, {
  emitWarningIfUnsupportedVersion: () => emitWarningIfUnsupportedVersion6,
  getLongPollPlugin: () => getLongPollPlugin3,
  setCredentialFeature: () => setCredentialFeature3,
  setFeature: () => setFeature4,
  setTokenFeature: () => setTokenFeature3,
  state: () => state3
});
var init_client4 = __esm({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/node_modules/@aws-sdk/core/dist-es/submodules/client/index.js"() {
    init_emitWarningIfUnsupportedVersion3();
    init_longPollMiddleware3();
    init_setCredentialFeature3();
    init_setFeature4();
    init_setTokenFeature3();
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-s3/dist-cjs/index.js
var require_dist_cjs54 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-sdk-s3/dist-cjs/index.js"(exports2) {
    "use strict";
    var protocolHttp = require_dist_cjs2();
    var smithyClient = require_dist_cjs34();
    var toStream = require_toStream();
    var utilArnParser = require_dist_cjs53();
    var protocols = (init_protocols5(), __toCommonJS(protocols_exports3));
    var schema = (init_schema4(), __toCommonJS(schema_exports));
    var signatureV4 = require_dist_cjs36();
    var utilConfigProvider = require_dist_cjs24();
    var client = (init_client4(), __toCommonJS(client_exports3));
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var utilMiddleware = require_dist_cjs6();
    var CONTENT_LENGTH_HEADER6 = "content-length";
    var DECODED_CONTENT_LENGTH_HEADER = "x-amz-decoded-content-length";
    function checkContentLengthHeader() {
      return (next, context) => async (args) => {
        const { request: request4 } = args;
        if (protocolHttp.HttpRequest.isInstance(request4)) {
          if (!(CONTENT_LENGTH_HEADER6 in request4.headers) && !(DECODED_CONTENT_LENGTH_HEADER in request4.headers)) {
            const message2 = `Are you using a Stream of unknown length as the Body of a PutObject request? Consider using Upload instead from @aws-sdk/lib-storage.`;
            if (typeof context?.logger?.warn === "function" && !(context.logger instanceof smithyClient.NoOpLogger)) {
              context.logger.warn(message2);
            } else {
              console.warn(message2);
            }
          }
        }
        return next({ ...args });
      };
    }
    __name(checkContentLengthHeader, "checkContentLengthHeader");
    var checkContentLengthHeaderMiddlewareOptions = {
      step: "finalizeRequest",
      tags: ["CHECK_CONTENT_LENGTH_HEADER"],
      name: "getCheckContentLengthHeaderPlugin",
      override: true
    };
    var getCheckContentLengthHeaderPlugin = /* @__PURE__ */ __name((unused) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(checkContentLengthHeader(), checkContentLengthHeaderMiddlewareOptions);
      }, "applyToStack")
    }), "getCheckContentLengthHeaderPlugin");
    var regionRedirectEndpointMiddleware = /* @__PURE__ */ __name((config2) => {
      return (next, context) => async (args) => {
        const originalRegion = await config2.region();
        const regionProviderRef = config2.region;
        let unlock = /* @__PURE__ */ __name(() => {
        }, "unlock");
        if (context.__s3RegionRedirect) {
          Object.defineProperty(config2, "region", {
            writable: false,
            value: /* @__PURE__ */ __name(async () => {
              return context.__s3RegionRedirect;
            }, "value")
          });
          unlock = /* @__PURE__ */ __name(() => Object.defineProperty(config2, "region", {
            writable: true,
            value: regionProviderRef
          }), "unlock");
        }
        try {
          const result2 = await next(args);
          if (context.__s3RegionRedirect) {
            unlock();
            const region = await config2.region();
            if (originalRegion !== region) {
              throw new Error("Region was not restored following S3 region redirect.");
            }
          }
          return result2;
        } catch (e32) {
          unlock();
          throw e32;
        }
      };
    }, "regionRedirectEndpointMiddleware");
    var regionRedirectEndpointMiddlewareOptions = {
      tags: ["REGION_REDIRECT", "S3"],
      name: "regionRedirectEndpointMiddleware",
      override: true,
      relation: "before",
      toMiddleware: "endpointV2Middleware"
    };
    function regionRedirectMiddleware(clientConfig) {
      return (next, context) => async (args) => {
        try {
          return await next(args);
        } catch (err) {
          if (clientConfig.followRegionRedirects) {
            const statusCode = err?.$metadata?.httpStatusCode;
            const isHeadBucket = context.commandName === "HeadBucketCommand";
            const bucketRegionHeader = err?.$response?.headers?.["x-amz-bucket-region"];
            if (bucketRegionHeader) {
              if (statusCode === 301 || statusCode === 400 && (err?.name === "IllegalLocationConstraintException" || isHeadBucket)) {
                try {
                  const actualRegion = bucketRegionHeader;
                  context.logger?.debug(`Redirecting from ${await clientConfig.region()} to ${actualRegion}`);
                  context.__s3RegionRedirect = actualRegion;
                } catch (e32) {
                  throw new Error("Region redirect failed: " + e32);
                }
                return next(args);
              }
            }
          }
          throw err;
        }
      };
    }
    __name(regionRedirectMiddleware, "regionRedirectMiddleware");
    var regionRedirectMiddlewareOptions = {
      step: "initialize",
      tags: ["REGION_REDIRECT", "S3"],
      name: "regionRedirectMiddleware",
      override: true
    };
    var getRegionRedirectMiddlewarePlugin = /* @__PURE__ */ __name((clientConfig) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(regionRedirectMiddleware(clientConfig), regionRedirectMiddlewareOptions);
        clientStack.addRelativeTo(regionRedirectEndpointMiddleware(clientConfig), regionRedirectEndpointMiddlewareOptions);
      }, "applyToStack")
    }), "getRegionRedirectMiddlewarePlugin");
    var s3ExpiresMiddleware = /* @__PURE__ */ __name((config2) => {
      return (next, context) => async (args) => {
        const result2 = await next(args);
        const { response } = result2;
        if (protocolHttp.HttpResponse.isInstance(response)) {
          if (response.headers.expires) {
            response.headers.expiresstring = response.headers.expires;
            try {
              smithyClient.parseRfc7231DateTime(response.headers.expires);
            } catch (e32) {
              context.logger?.warn(`AWS SDK Warning for ${context.clientName}::${context.commandName} response parsing (${response.headers.expires}): ${e32}`);
              delete response.headers.expires;
            }
          }
        }
        return result2;
      };
    }, "s3ExpiresMiddleware");
    var s3ExpiresMiddlewareOptions = {
      tags: ["S3"],
      name: "s3ExpiresMiddleware",
      override: true,
      relation: "after",
      toMiddleware: "deserializerMiddleware"
    };
    var getS3ExpiresMiddlewarePlugin = /* @__PURE__ */ __name((clientConfig) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.addRelativeTo(s3ExpiresMiddleware(), s3ExpiresMiddlewareOptions);
      }, "applyToStack")
    }), "getS3ExpiresMiddlewarePlugin");
    var S3ExpressIdentityCache = class _S3ExpressIdentityCache {
      static {
        __name(this, "S3ExpressIdentityCache");
      }
      data;
      lastPurgeTime = Date.now();
      static EXPIRED_CREDENTIAL_PURGE_INTERVAL_MS = 3e4;
      constructor(data3 = {}) {
        this.data = data3;
      }
      get(key) {
        const entry = this.data[key];
        if (!entry) {
          return;
        }
        return entry;
      }
      set(key, entry) {
        this.data[key] = entry;
        return entry;
      }
      delete(key) {
        delete this.data[key];
      }
      async purgeExpired() {
        const now = Date.now();
        if (this.lastPurgeTime + _S3ExpressIdentityCache.EXPIRED_CREDENTIAL_PURGE_INTERVAL_MS > now) {
          return;
        }
        for (const key in this.data) {
          const entry = this.data[key];
          if (!entry.isRefreshing) {
            const credential = await entry.identity;
            if (credential.expiration) {
              if (credential.expiration.getTime() < now) {
                delete this.data[key];
              }
            }
          }
        }
      }
    };
    var S3ExpressIdentityCacheEntry = class {
      static {
        __name(this, "S3ExpressIdentityCacheEntry");
      }
      _identity;
      isRefreshing;
      accessed;
      constructor(_identity, isRefreshing = false, accessed = Date.now()) {
        this._identity = _identity;
        this.isRefreshing = isRefreshing;
        this.accessed = accessed;
      }
      get identity() {
        this.accessed = Date.now();
        return this._identity;
      }
    };
    var S3ExpressIdentityProviderImpl = class _S3ExpressIdentityProviderImpl {
      static {
        __name(this, "S3ExpressIdentityProviderImpl");
      }
      createSessionFn;
      cache;
      static REFRESH_WINDOW_MS = 6e4;
      constructor(createSessionFn, cache32 = new S3ExpressIdentityCache()) {
        this.createSessionFn = createSessionFn;
        this.cache = cache32;
      }
      async getS3ExpressIdentity(awsIdentity, identityProperties) {
        const key = identityProperties.Bucket;
        const { cache: cache32 } = this;
        const entry = cache32.get(key);
        if (entry) {
          return entry.identity.then((identity) => {
            const isExpired = (identity.expiration?.getTime() ?? 0) < Date.now();
            if (isExpired) {
              return cache32.set(key, new S3ExpressIdentityCacheEntry(this.getIdentity(key))).identity;
            }
            const isExpiringSoon = (identity.expiration?.getTime() ?? 0) < Date.now() + _S3ExpressIdentityProviderImpl.REFRESH_WINDOW_MS;
            if (isExpiringSoon && !entry.isRefreshing) {
              entry.isRefreshing = true;
              this.getIdentity(key).then((id) => {
                cache32.set(key, new S3ExpressIdentityCacheEntry(Promise.resolve(id)));
              });
            }
            return identity;
          });
        }
        return cache32.set(key, new S3ExpressIdentityCacheEntry(this.getIdentity(key))).identity;
      }
      async getIdentity(key) {
        await this.cache.purgeExpired().catch((error4) => {
          console.warn("Error while clearing expired entries in S3ExpressIdentityCache: \n" + error4);
        });
        const session = await this.createSessionFn(key);
        if (!session.Credentials?.AccessKeyId || !session.Credentials?.SecretAccessKey) {
          throw new Error("s3#createSession response credential missing AccessKeyId or SecretAccessKey.");
        }
        const identity = {
          accessKeyId: session.Credentials.AccessKeyId,
          secretAccessKey: session.Credentials.SecretAccessKey,
          sessionToken: session.Credentials.SessionToken,
          expiration: session.Credentials.Expiration ? new Date(session.Credentials.Expiration) : void 0
        };
        return identity;
      }
    };
    var S3_EXPRESS_BUCKET_TYPE = "Directory";
    var S3_EXPRESS_BACKEND = "S3Express";
    var S3_EXPRESS_AUTH_SCHEME = "sigv4-s3express";
    var SESSION_TOKEN_QUERY_PARAM = "X-Amz-S3session-Token";
    var SESSION_TOKEN_HEADER = SESSION_TOKEN_QUERY_PARAM.toLowerCase();
    var NODE_DISABLE_S3_EXPRESS_SESSION_AUTH_ENV_NAME = "AWS_S3_DISABLE_EXPRESS_SESSION_AUTH";
    var NODE_DISABLE_S3_EXPRESS_SESSION_AUTH_INI_NAME = "s3_disable_express_session_auth";
    var NODE_DISABLE_S3_EXPRESS_SESSION_AUTH_OPTIONS = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => utilConfigProvider.booleanSelector(env3, NODE_DISABLE_S3_EXPRESS_SESSION_AUTH_ENV_NAME, utilConfigProvider.SelectorType.ENV), "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => utilConfigProvider.booleanSelector(profile, NODE_DISABLE_S3_EXPRESS_SESSION_AUTH_INI_NAME, utilConfigProvider.SelectorType.CONFIG), "configFileSelector"),
      default: false
    };
    var SignatureV4S3Express = class extends signatureV4.SignatureV4 {
      static {
        __name(this, "SignatureV4S3Express");
      }
      async signWithCredentials(requestToSign, credentials, options) {
        const credentialsWithoutSessionToken = getCredentialsWithoutSessionToken(credentials);
        requestToSign.headers[SESSION_TOKEN_HEADER] = credentials.sessionToken;
        const privateAccess = this;
        setSingleOverride(privateAccess, credentialsWithoutSessionToken);
        return privateAccess.signRequest(requestToSign, options ?? {});
      }
      async presignWithCredentials(requestToSign, credentials, options) {
        const credentialsWithoutSessionToken = getCredentialsWithoutSessionToken(credentials);
        delete requestToSign.headers[SESSION_TOKEN_HEADER];
        requestToSign.headers[SESSION_TOKEN_QUERY_PARAM] = credentials.sessionToken;
        requestToSign.query = requestToSign.query ?? {};
        requestToSign.query[SESSION_TOKEN_QUERY_PARAM] = credentials.sessionToken;
        const privateAccess = this;
        setSingleOverride(privateAccess, credentialsWithoutSessionToken);
        return this.presign(requestToSign, options);
      }
    };
    function getCredentialsWithoutSessionToken(credentials) {
      const credentialsWithoutSessionToken = {
        accessKeyId: credentials.accessKeyId,
        secretAccessKey: credentials.secretAccessKey,
        expiration: credentials.expiration
      };
      return credentialsWithoutSessionToken;
    }
    __name(getCredentialsWithoutSessionToken, "getCredentialsWithoutSessionToken");
    function setSingleOverride(privateAccess, credentialsWithoutSessionToken) {
      const id = setTimeout(() => {
        throw new Error("SignatureV4S3Express credential override was created but not called.");
      }, 10);
      const currentCredentialProvider = privateAccess.credentialProvider;
      const overrideCredentialsProviderOnce = /* @__PURE__ */ __name(() => {
        clearTimeout(id);
        privateAccess.credentialProvider = currentCredentialProvider;
        return Promise.resolve(credentialsWithoutSessionToken);
      }, "overrideCredentialsProviderOnce");
      privateAccess.credentialProvider = overrideCredentialsProviderOnce;
    }
    __name(setSingleOverride, "setSingleOverride");
    var s3ExpressMiddleware = /* @__PURE__ */ __name((options) => {
      return (next, context) => async (args) => {
        if (context.endpointV2) {
          const endpoint = context.endpointV2;
          const isS3ExpressAuth = endpoint.properties?.authSchemes?.[0]?.name === S3_EXPRESS_AUTH_SCHEME;
          const isS3ExpressBucket = endpoint.properties?.backend === S3_EXPRESS_BACKEND || endpoint.properties?.bucketType === S3_EXPRESS_BUCKET_TYPE;
          if (isS3ExpressBucket) {
            client.setFeature(context, "S3_EXPRESS_BUCKET", "J");
            context.isS3ExpressBucket = true;
          }
          if (isS3ExpressAuth) {
            const requestBucket = args.input.Bucket;
            if (requestBucket) {
              const s3ExpressIdentity = await options.s3ExpressIdentityProvider.getS3ExpressIdentity(await options.credentials(), {
                Bucket: requestBucket
              });
              context.s3ExpressIdentity = s3ExpressIdentity;
              if (protocolHttp.HttpRequest.isInstance(args.request) && s3ExpressIdentity.sessionToken) {
                args.request.headers[SESSION_TOKEN_HEADER] = s3ExpressIdentity.sessionToken;
              }
            }
          }
        }
        return next(args);
      };
    }, "s3ExpressMiddleware");
    var s3ExpressMiddlewareOptions = {
      name: "s3ExpressMiddleware",
      step: "build",
      tags: ["S3", "S3_EXPRESS"],
      override: true
    };
    var getS3ExpressPlugin = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(s3ExpressMiddleware(options), s3ExpressMiddlewareOptions);
      }, "applyToStack")
    }), "getS3ExpressPlugin");
    var signS3Express = /* @__PURE__ */ __name(async (s3ExpressIdentity, signingOptions, request4, sigV4MultiRegionSigner) => {
      const signedRequest = await sigV4MultiRegionSigner.signWithCredentials(request4, s3ExpressIdentity, {});
      if (signedRequest.headers["X-Amz-Security-Token"] || signedRequest.headers["x-amz-security-token"]) {
        throw new Error("X-Amz-Security-Token must not be set for s3-express requests.");
      }
      return signedRequest;
    }, "signS3Express");
    var defaultErrorHandler3 = /* @__PURE__ */ __name((signingProperties) => (error4) => {
      throw error4;
    }, "defaultErrorHandler");
    var defaultSuccessHandler3 = /* @__PURE__ */ __name((httpResponse, signingProperties) => {
    }, "defaultSuccessHandler");
    var s3ExpressHttpSigningMiddlewareOptions = core.httpSigningMiddlewareOptions;
    var s3ExpressHttpSigningMiddleware = /* @__PURE__ */ __name((config2) => (next, context) => async (args) => {
      if (!protocolHttp.HttpRequest.isInstance(args.request)) {
        return next(args);
      }
      const smithyContext = utilMiddleware.getSmithyContext(context);
      const scheme = smithyContext.selectedHttpAuthScheme;
      if (!scheme) {
        throw new Error(`No HttpAuthScheme was selected: unable to sign request`);
      }
      const { httpAuthOption: { signingProperties = {} }, identity, signer } = scheme;
      let request4;
      if (context.s3ExpressIdentity) {
        request4 = await signS3Express(context.s3ExpressIdentity, signingProperties, args.request, await config2.signer());
      } else {
        request4 = await signer.sign(args.request, identity, signingProperties);
      }
      const output = await next({
        ...args,
        request: request4
      }).catch((signer.errorHandler || defaultErrorHandler3)(signingProperties));
      (signer.successHandler || defaultSuccessHandler3)(output.response, signingProperties);
      return output;
    }, "s3ExpressHttpSigningMiddleware");
    var getS3ExpressHttpSigningPlugin = /* @__PURE__ */ __name((config2) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.addRelativeTo(s3ExpressHttpSigningMiddleware(config2), core.httpSigningMiddlewareOptions);
      }, "applyToStack")
    }), "getS3ExpressHttpSigningPlugin");
    var resolveS3Config = /* @__PURE__ */ __name((input, { session }) => {
      const [s3ClientProvider, CreateSessionCommandCtor] = session;
      const { forcePathStyle, useAccelerateEndpoint, disableMultiregionAccessPoints, followRegionRedirects, s3ExpressIdentityProvider, bucketEndpoint, expectContinueHeader } = input;
      return Object.assign(input, {
        forcePathStyle: forcePathStyle ?? false,
        useAccelerateEndpoint: useAccelerateEndpoint ?? false,
        disableMultiregionAccessPoints: disableMultiregionAccessPoints ?? false,
        followRegionRedirects: followRegionRedirects ?? false,
        s3ExpressIdentityProvider: s3ExpressIdentityProvider ?? new S3ExpressIdentityProviderImpl(async (key) => s3ClientProvider().send(new CreateSessionCommandCtor({
          Bucket: key
        }))),
        bucketEndpoint: bucketEndpoint ?? false,
        expectContinueHeader: expectContinueHeader ?? 2097152
      });
    }, "resolveS3Config");
    var THROW_IF_EMPTY_BODY = {
      CopyObjectCommand: true,
      UploadPartCopyCommand: true,
      CompleteMultipartUploadCommand: true
    };
    var throw200ExceptionsMiddleware = /* @__PURE__ */ __name((config2) => (next, context) => async (args) => {
      const result2 = await next(args);
      const { response } = result2;
      if (!protocolHttp.HttpResponse.isInstance(response)) {
        return result2;
      }
      const { statusCode, body } = response;
      if (statusCode < 200 || statusCode >= 300) {
        return result2;
      }
      const bodyBytes = await collectBody17(body, config2);
      response.body = toStream.toStream(bodyBytes);
      if (bodyBytes.length === 0 && THROW_IF_EMPTY_BODY[context.commandName]) {
        const err = new Error("S3 aborted request");
        err.$metadata = {
          httpStatusCode: 503
        };
        err.name = "InternalError";
        throw err;
      }
      const bodyStringTail = config2.utf8Encoder(bodyBytes.subarray(bodyBytes.length - 16));
      if (bodyStringTail && bodyStringTail.endsWith("</Error>")) {
        response.statusCode = 503;
      }
      return result2;
    }, "throw200ExceptionsMiddleware");
    var collectBody17 = /* @__PURE__ */ __name((streamBody = new Uint8Array(), context) => {
      if (streamBody instanceof Uint8Array) {
        return Promise.resolve(streamBody);
      }
      return context.streamCollector(streamBody) || Promise.resolve(new Uint8Array());
    }, "collectBody");
    var throw200ExceptionsMiddlewareOptions = {
      relation: "after",
      toMiddleware: "deserializerMiddleware",
      tags: ["THROW_200_EXCEPTIONS", "S3"],
      name: "throw200ExceptionsMiddleware",
      override: true
    };
    var getThrow200ExceptionsPlugin = /* @__PURE__ */ __name((config2) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.addRelativeTo(throw200ExceptionsMiddleware(config2), throw200ExceptionsMiddlewareOptions);
      }, "applyToStack")
    }), "getThrow200ExceptionsPlugin");
    function bucketEndpointMiddleware(options) {
      return (next, context) => async (args) => {
        if (options.bucketEndpoint) {
          const endpoint = context.endpointV2;
          if (endpoint) {
            const bucket = args.input.Bucket;
            if (typeof bucket === "string") {
              try {
                const bucketEndpointUrl = new URL(bucket);
                context.endpointV2 = {
                  ...endpoint,
                  url: bucketEndpointUrl
                };
              } catch (e32) {
                const warning2 = `@aws-sdk/middleware-sdk-s3: bucketEndpoint=true was set but Bucket=${bucket} could not be parsed as URL.`;
                if (context.logger?.constructor?.name === "NoOpLogger") {
                  console.warn(warning2);
                } else {
                  context.logger?.warn?.(warning2);
                }
                throw e32;
              }
            }
          }
        }
        return next(args);
      };
    }
    __name(bucketEndpointMiddleware, "bucketEndpointMiddleware");
    var bucketEndpointMiddlewareOptions = {
      name: "bucketEndpointMiddleware",
      override: true,
      relation: "after",
      toMiddleware: "endpointV2Middleware"
    };
    function validateBucketNameMiddleware({ bucketEndpoint }) {
      return (next) => async (args) => {
        const { input: { Bucket } } = args;
        if (!bucketEndpoint && typeof Bucket === "string" && !utilArnParser.validate(Bucket) && Bucket.indexOf("/") >= 0) {
          const err = new Error(`Bucket name shouldn't contain '/', received '${Bucket}'`);
          err.name = "InvalidBucketName";
          throw err;
        }
        return next({ ...args });
      };
    }
    __name(validateBucketNameMiddleware, "validateBucketNameMiddleware");
    var validateBucketNameMiddlewareOptions = {
      step: "initialize",
      tags: ["VALIDATE_BUCKET_NAME"],
      name: "validateBucketNameMiddleware",
      override: true
    };
    var getValidateBucketNamePlugin = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(validateBucketNameMiddleware(options), validateBucketNameMiddlewareOptions);
        clientStack.addRelativeTo(bucketEndpointMiddleware(options), bucketEndpointMiddlewareOptions);
      }, "applyToStack")
    }), "getValidateBucketNamePlugin");
    var S3RestXmlProtocol = class extends protocols.AwsRestXmlProtocol {
      static {
        __name(this, "S3RestXmlProtocol");
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        const ns = schema.NormalizedSchema.of(operationSchema.input);
        const staticStructureSchema = ns.getSchema();
        let bucketMemberIndex = 0;
        const requiredMemberCount = staticStructureSchema[6] ?? 0;
        if (input && typeof input === "object") {
          for (const [memberName, memberNs] of ns.structIterator()) {
            if (++bucketMemberIndex > requiredMemberCount) {
              break;
            }
            if (memberName === "Bucket") {
              if (!input.Bucket && memberNs.getMergedTraits().httpLabel) {
                throw new Error(`No value provided for input HTTP label: Bucket.`);
              }
              break;
            }
          }
        }
        return request4;
      }
    };
    exports2.NODE_DISABLE_S3_EXPRESS_SESSION_AUTH_OPTIONS = NODE_DISABLE_S3_EXPRESS_SESSION_AUTH_OPTIONS;
    exports2.S3ExpressIdentityCache = S3ExpressIdentityCache;
    exports2.S3ExpressIdentityCacheEntry = S3ExpressIdentityCacheEntry;
    exports2.S3ExpressIdentityProviderImpl = S3ExpressIdentityProviderImpl;
    exports2.S3RestXmlProtocol = S3RestXmlProtocol;
    exports2.SignatureV4S3Express = SignatureV4S3Express;
    exports2.checkContentLengthHeader = checkContentLengthHeader;
    exports2.checkContentLengthHeaderMiddlewareOptions = checkContentLengthHeaderMiddlewareOptions;
    exports2.getCheckContentLengthHeaderPlugin = getCheckContentLengthHeaderPlugin;
    exports2.getRegionRedirectMiddlewarePlugin = getRegionRedirectMiddlewarePlugin;
    exports2.getS3ExpiresMiddlewarePlugin = getS3ExpiresMiddlewarePlugin;
    exports2.getS3ExpressHttpSigningPlugin = getS3ExpressHttpSigningPlugin;
    exports2.getS3ExpressPlugin = getS3ExpressPlugin;
    exports2.getThrow200ExceptionsPlugin = getThrow200ExceptionsPlugin;
    exports2.getValidateBucketNamePlugin = getValidateBucketNamePlugin;
    exports2.regionRedirectEndpointMiddleware = regionRedirectEndpointMiddleware;
    exports2.regionRedirectEndpointMiddlewareOptions = regionRedirectEndpointMiddlewareOptions;
    exports2.regionRedirectMiddleware = regionRedirectMiddleware;
    exports2.regionRedirectMiddlewareOptions = regionRedirectMiddlewareOptions;
    exports2.resolveS3Config = resolveS3Config;
    exports2.s3ExpiresMiddleware = s3ExpiresMiddleware;
    exports2.s3ExpiresMiddlewareOptions = s3ExpiresMiddlewareOptions;
    exports2.s3ExpressHttpSigningMiddleware = s3ExpressHttpSigningMiddleware;
    exports2.s3ExpressHttpSigningMiddlewareOptions = s3ExpressHttpSigningMiddlewareOptions;
    exports2.s3ExpressMiddleware = s3ExpressMiddleware;
    exports2.s3ExpressMiddlewareOptions = s3ExpressMiddlewareOptions;
    exports2.throw200ExceptionsMiddleware = throw200ExceptionsMiddleware;
    exports2.throw200ExceptionsMiddlewareOptions = throw200ExceptionsMiddlewareOptions;
    exports2.validateBucketNameMiddleware = validateBucketNameMiddleware;
    exports2.validateBucketNameMiddlewareOptions = validateBucketNameMiddlewareOptions;
  }
});

// ../../node_modules/@aws-sdk/signature-v4-multi-region/dist-cjs/index.js
var require_dist_cjs55 = __commonJS({
  "../../node_modules/@aws-sdk/signature-v4-multi-region/dist-cjs/index.js"(exports2) {
    "use strict";
    var middlewareSdkS3 = require_dist_cjs54();
    var signatureV4 = require_dist_cjs36();
    var signatureV4CrtContainer = {
      CrtSignerV4: null
    };
    var SignatureV4MultiRegion19 = class {
      static {
        __name(this, "SignatureV4MultiRegion");
      }
      sigv4aSigner;
      sigv4Signer;
      signerOptions;
      static sigv4aDependency() {
        if (typeof signatureV4CrtContainer.CrtSignerV4 === "function") {
          return "crt";
        } else if (typeof signatureV4.signatureV4aContainer.SignatureV4a === "function") {
          return "js";
        }
        return "none";
      }
      constructor(options) {
        this.sigv4Signer = new middlewareSdkS3.SignatureV4S3Express(options);
        this.signerOptions = options;
      }
      async sign(requestToSign, options = {}) {
        if (options.signingRegion === "*") {
          return this.getSigv4aSigner().sign(requestToSign, options);
        }
        return this.sigv4Signer.sign(requestToSign, options);
      }
      async signWithCredentials(requestToSign, credentials, options = {}) {
        if (options.signingRegion === "*") {
          const signer = this.getSigv4aSigner();
          const CrtSignerV4 = signatureV4CrtContainer.CrtSignerV4;
          if (CrtSignerV4 && signer instanceof CrtSignerV4) {
            return signer.signWithCredentials(requestToSign, credentials, options);
          } else {
            throw new Error(`signWithCredentials with signingRegion '*' is only supported when using the CRT dependency @aws-sdk/signature-v4-crt. Please check whether you have installed the "@aws-sdk/signature-v4-crt" package explicitly. You must also register the package by calling [require("@aws-sdk/signature-v4-crt");] or an ESM equivalent such as [import "@aws-sdk/signature-v4-crt";]. For more information please go to https://github.com/aws/aws-sdk-js-v3#functionality-requiring-aws-common-runtime-crt`);
          }
        }
        return this.sigv4Signer.signWithCredentials(requestToSign, credentials, options);
      }
      async presign(originalRequest, options = {}) {
        if (options.signingRegion === "*") {
          const signer = this.getSigv4aSigner();
          const CrtSignerV4 = signatureV4CrtContainer.CrtSignerV4;
          if (CrtSignerV4 && signer instanceof CrtSignerV4) {
            return signer.presign(originalRequest, options);
          } else {
            throw new Error(`presign with signingRegion '*' is only supported when using the CRT dependency @aws-sdk/signature-v4-crt. Please check whether you have installed the "@aws-sdk/signature-v4-crt" package explicitly. You must also register the package by calling [require("@aws-sdk/signature-v4-crt");] or an ESM equivalent such as [import "@aws-sdk/signature-v4-crt";]. For more information please go to https://github.com/aws/aws-sdk-js-v3#functionality-requiring-aws-common-runtime-crt`);
          }
        }
        return this.sigv4Signer.presign(originalRequest, options);
      }
      async presignWithCredentials(originalRequest, credentials, options = {}) {
        if (options.signingRegion === "*") {
          throw new Error("Method presignWithCredentials is not supported for [signingRegion=*].");
        }
        return this.sigv4Signer.presignWithCredentials(originalRequest, credentials, options);
      }
      getSigv4aSigner() {
        if (!this.sigv4aSigner) {
          const CrtSignerV4 = signatureV4CrtContainer.CrtSignerV4;
          const JsSigV4aSigner = signatureV4.signatureV4aContainer.SignatureV4a;
          if (this.signerOptions.runtime === "node") {
            if (!CrtSignerV4 && !JsSigV4aSigner) {
              throw new Error("Neither CRT nor JS SigV4a implementation is available. Please load either @aws-sdk/signature-v4-crt or @aws-sdk/signature-v4a. For more information please go to https://github.com/aws/aws-sdk-js-v3#functionality-requiring-aws-common-runtime-crt");
            }
            if (CrtSignerV4 && typeof CrtSignerV4 === "function") {
              this.sigv4aSigner = new CrtSignerV4({
                ...this.signerOptions,
                signingAlgorithm: 1
              });
            } else if (JsSigV4aSigner && typeof JsSigV4aSigner === "function") {
              this.sigv4aSigner = new JsSigV4aSigner({
                ...this.signerOptions
              });
            } else {
              throw new Error("Available SigV4a implementation is not a valid constructor. Please ensure you've properly imported @aws-sdk/signature-v4-crt or @aws-sdk/signature-v4a.For more information please go to https://github.com/aws/aws-sdk-js-v3#functionality-requiring-aws-common-runtime-crt");
            }
          } else {
            if (!JsSigV4aSigner || typeof JsSigV4aSigner !== "function") {
              throw new Error("JS SigV4a implementation is not available or not a valid constructor. Please check whether you have installed the @aws-sdk/signature-v4a package explicitly. The CRT implementation is not available for browsers. You must also register the package by calling [require('@aws-sdk/signature-v4a');] or an ESM equivalent such as [import '@aws-sdk/signature-v4a';]. For more information please go to https://github.com/aws/aws-sdk-js-v3#using-javascript-non-crt-implementation-of-sigv4a");
            }
            this.sigv4aSigner = new JsSigV4aSigner({
              ...this.signerOptions
            });
          }
        }
        return this.sigv4aSigner;
      }
    };
    exports2.SignatureV4MultiRegion = SignatureV4MultiRegion19;
    exports2.signatureV4CrtContainer = signatureV4CrtContainer;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/bdd.js
var import_util_endpoints10, q, a4, b4, c4, d4, e4, f4, g4, h4, i4, j4, k4, l2, m2, n, o, p, _data4, root4, r4, nodes4, bdd4;
var init_bdd4 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/bdd.js"() {
    import_util_endpoints10 = __toESM(require_dist_cjs20());
    q = "ref";
    a4 = -1;
    b4 = true;
    c4 = "isSet";
    d4 = "PartitionResult";
    e4 = "booleanEquals";
    f4 = "stringEquals";
    g4 = "getAttr";
    h4 = "us-east-1";
    i4 = "sigv4";
    j4 = "sts";
    k4 = "https://sts.{Region}.{PartitionResult#dnsSuffix}";
    l2 = { [q]: "Endpoint" };
    m2 = { [q]: "Region" };
    n = { [q]: d4 };
    o = {};
    p = [m2];
    _data4 = {
      conditions: [
        [c4, [l2]],
        [c4, p],
        ["aws.partition", p, d4],
        [e4, [{ [q]: "UseFIPS" }, b4]],
        [e4, [{ [q]: "UseDualStack" }, b4]],
        [f4, [m2, "aws-global"]],
        [e4, [{ [q]: "UseGlobalEndpoint" }, b4]],
        [f4, [m2, "eu-central-1"]],
        [e4, [{ fn: g4, argv: [n, "supportsDualStack"] }, b4]],
        [e4, [{ fn: g4, argv: [n, "supportsFIPS"] }, b4]],
        [f4, [m2, "ap-south-1"]],
        [f4, [m2, "eu-north-1"]],
        [f4, [m2, "eu-west-1"]],
        [f4, [m2, "eu-west-2"]],
        [f4, [m2, "eu-west-3"]],
        [f4, [m2, "sa-east-1"]],
        [f4, [m2, h4]],
        [f4, [m2, "us-east-2"]],
        [f4, [m2, "us-west-2"]],
        [f4, [m2, "us-west-1"]],
        [f4, [m2, "ca-central-1"]],
        [f4, [m2, "ap-southeast-1"]],
        [f4, [m2, "ap-northeast-1"]],
        [f4, [m2, "ap-southeast-2"]],
        [f4, [{ fn: g4, argv: [n, "name"] }, "aws-us-gov"]]
      ],
      results: [
        [a4],
        ["https://sts.amazonaws.com", { authSchemes: [{ name: i4, signingName: j4, signingRegion: h4 }] }],
        [k4, { authSchemes: [{ name: i4, signingName: j4, signingRegion: "{Region}" }] }],
        [a4, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a4, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [l2, o],
        ["https://sts-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", o],
        [a4, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://sts.{Region}.amazonaws.com", o],
        ["https://sts-fips.{Region}.{PartitionResult#dnsSuffix}", o],
        [a4, "FIPS is enabled but this partition does not support FIPS"],
        ["https://sts.{Region}.{PartitionResult#dualStackDnsSuffix}", o],
        [a4, "DualStack is enabled but this partition does not support DualStack"],
        [k4, o],
        [a4, "Invalid Configuration: Missing Region"]
      ]
    };
    root4 = 2;
    r4 = 1e8;
    nodes4 = new Int32Array([
      -1,
      1,
      -1,
      0,
      30,
      3,
      1,
      4,
      r4 + 14,
      2,
      5,
      r4 + 14,
      3,
      25,
      6,
      4,
      24,
      7,
      5,
      r4 + 1,
      8,
      6,
      9,
      r4 + 13,
      7,
      r4 + 1,
      10,
      10,
      r4 + 1,
      11,
      11,
      r4 + 1,
      12,
      12,
      r4 + 1,
      13,
      13,
      r4 + 1,
      14,
      14,
      r4 + 1,
      15,
      15,
      r4 + 1,
      16,
      16,
      r4 + 1,
      17,
      17,
      r4 + 1,
      18,
      18,
      r4 + 1,
      19,
      19,
      r4 + 1,
      20,
      20,
      r4 + 1,
      21,
      21,
      r4 + 1,
      22,
      22,
      r4 + 1,
      23,
      23,
      r4 + 1,
      r4 + 2,
      8,
      r4 + 11,
      r4 + 12,
      4,
      28,
      26,
      9,
      27,
      r4 + 10,
      24,
      r4 + 8,
      r4 + 9,
      8,
      29,
      r4 + 7,
      9,
      r4 + 6,
      r4 + 7,
      3,
      r4 + 3,
      31,
      4,
      r4 + 4,
      r4 + 5
    ]);
    bdd4 = import_util_endpoints10.BinaryDecisionDiagram.from(nodes4, root4, _data4.conditions, _data4.results);
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/endpointResolver.js
var import_util_endpoints11, import_util_endpoints12, cache4, defaultEndpointResolver4;
var init_endpointResolver4 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/endpointResolver.js"() {
    import_util_endpoints11 = __toESM(require_dist_cjs21());
    import_util_endpoints12 = __toESM(require_dist_cjs20());
    init_bdd4();
    cache4 = new import_util_endpoints12.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS", "UseGlobalEndpoint"]
    });
    defaultEndpointResolver4 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache4.get(endpointParams, () => (0, import_util_endpoints12.decideEndpoint)(bdd4, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    import_util_endpoints12.customEndpointFunctions.aws = import_util_endpoints11.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption4(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "sts",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createAwsAuthSigv4aHttpAuthOption(authParameters) {
  return {
    schemeId: "aws.auth#sigv4a",
    signingProperties: {
      name: "sts",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption4(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var import_signature_v4_multi_region, import_middleware_endpoint7, import_util_middleware9, createEndpointRuleSetHttpAuthSchemeParametersProvider, _defaultSTSHttpAuthSchemeParametersProvider, defaultSTSHttpAuthSchemeParametersProvider, createEndpointRuleSetHttpAuthSchemeProvider, _defaultSTSHttpAuthSchemeProvider, defaultSTSHttpAuthSchemeProvider, resolveStsAuthConfig, resolveHttpAuthSchemeConfig4;
var init_httpAuthSchemeProvider4 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes2();
    import_signature_v4_multi_region = __toESM(require_dist_cjs55());
    import_middleware_endpoint7 = __toESM(require_dist_cjs31());
    import_util_middleware9 = __toESM(require_dist_cjs6());
    init_endpointResolver4();
    init_STSClient();
    createEndpointRuleSetHttpAuthSchemeParametersProvider = /* @__PURE__ */ __name((defaultHttpAuthSchemeParametersProvider) => async (config2, context, input) => {
      if (!input) {
        throw new Error("Could not find `input` for `defaultEndpointRuleSetHttpAuthSchemeParametersProvider`");
      }
      const defaultParameters = await defaultHttpAuthSchemeParametersProvider(config2, context, input);
      const instructionsFn = (0, import_util_middleware9.getSmithyContext)(context)?.commandInstance?.constructor?.getEndpointParameterInstructions;
      if (!instructionsFn) {
        throw new Error(`getEndpointParameterInstructions() is not defined on '${context.commandName}'`);
      }
      const endpointParameters = await (0, import_middleware_endpoint7.resolveParams)(input, { getEndpointParameterInstructions: instructionsFn }, config2);
      return Object.assign(defaultParameters, endpointParameters);
    }, "createEndpointRuleSetHttpAuthSchemeParametersProvider");
    _defaultSTSHttpAuthSchemeParametersProvider = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, import_util_middleware9.getSmithyContext)(context).operation,
        region: await (0, import_util_middleware9.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "_defaultSTSHttpAuthSchemeParametersProvider");
    defaultSTSHttpAuthSchemeParametersProvider = createEndpointRuleSetHttpAuthSchemeParametersProvider(_defaultSTSHttpAuthSchemeParametersProvider);
    __name(createAwsAuthSigv4HttpAuthOption4, "createAwsAuthSigv4HttpAuthOption");
    __name(createAwsAuthSigv4aHttpAuthOption, "createAwsAuthSigv4aHttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption4, "createSmithyApiNoAuthHttpAuthOption");
    createEndpointRuleSetHttpAuthSchemeProvider = /* @__PURE__ */ __name((defaultEndpointResolver32, defaultHttpAuthSchemeResolver, createHttpAuthOptionFunctions) => {
      const endpointRuleSetHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
        const endpoint = defaultEndpointResolver32(authParameters);
        const authSchemes = endpoint.properties?.authSchemes;
        if (!authSchemes) {
          return defaultHttpAuthSchemeResolver(authParameters);
        }
        const options = [];
        for (const scheme of authSchemes) {
          const { name: resolvedName, properties = {}, ...rest } = scheme;
          const name = resolvedName.toLowerCase();
          if (resolvedName !== name) {
            console.warn(`HttpAuthScheme has been normalized with lowercasing: '${resolvedName}' to '${name}'`);
          }
          let schemeId;
          if (name === "sigv4a") {
            schemeId = "aws.auth#sigv4a";
            const sigv4Present = authSchemes.find((s) => {
              const name2 = s.name.toLowerCase();
              return name2 !== "sigv4a" && name2.startsWith("sigv4");
            });
            if (import_signature_v4_multi_region.SignatureV4MultiRegion.sigv4aDependency() === "none" && sigv4Present) {
              continue;
            }
          } else if (name.startsWith("sigv4")) {
            schemeId = "aws.auth#sigv4";
          } else {
            throw new Error(`Unknown HttpAuthScheme found in '@smithy.rules#endpointRuleSet': '${name}'`);
          }
          const createOption = createHttpAuthOptionFunctions[schemeId];
          if (!createOption) {
            throw new Error(`Could not find HttpAuthOption create function for '${schemeId}'`);
          }
          const option = createOption(authParameters);
          option.schemeId = schemeId;
          option.signingProperties = { ...option.signingProperties || {}, ...rest, ...properties };
          options.push(option);
        }
        return options;
      }, "endpointRuleSetHttpAuthSchemeProvider");
      return endpointRuleSetHttpAuthSchemeProvider;
    }, "createEndpointRuleSetHttpAuthSchemeProvider");
    _defaultSTSHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "AssumeRoleWithWebIdentity": {
          options.push(createSmithyApiNoAuthHttpAuthOption4(authParameters));
          options.push(createAwsAuthSigv4aHttpAuthOption(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption4(authParameters));
          options.push(createAwsAuthSigv4aHttpAuthOption(authParameters));
        }
      }
      return options;
    }, "_defaultSTSHttpAuthSchemeProvider");
    defaultSTSHttpAuthSchemeProvider = createEndpointRuleSetHttpAuthSchemeProvider(defaultEndpointResolver4, _defaultSTSHttpAuthSchemeProvider, {
      "aws.auth#sigv4": createAwsAuthSigv4HttpAuthOption4,
      "aws.auth#sigv4a": createAwsAuthSigv4aHttpAuthOption,
      "smithy.api#noAuth": createSmithyApiNoAuthHttpAuthOption4
    });
    resolveStsAuthConfig = /* @__PURE__ */ __name((input) => Object.assign(input, {
      stsClientCtor: STSClient
    }), "resolveStsAuthConfig");
    resolveHttpAuthSchemeConfig4 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveStsAuthConfig(config2);
      const config_1 = resolveAwsSdkSigV4Config(config_0);
      const config_2 = resolveAwsSdkSigV4AConfig(config_1);
      return Object.assign(config_2, {
        authSchemePreference: (0, import_util_middleware9.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/EndpointParameters.js
var resolveClientEndpointParameters4, commonParams4;
var init_EndpointParameters4 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters4 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        useGlobalEndpoint: options.useGlobalEndpoint ?? false,
        defaultSigningName: "sts"
      });
    }, "resolveClientEndpointParameters");
    commonParams4 = {
      UseGlobalEndpoint: { type: "builtInParams", name: "useGlobalEndpoint" },
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/STSServiceException.js
var import_smithy_client38, STSServiceException;
var init_STSServiceException = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/STSServiceException.js"() {
    import_smithy_client38 = __toESM(require_dist_cjs34());
    STSServiceException = class _STSServiceException extends import_smithy_client38.ServiceException {
      static {
        __name(this, "STSServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _STSServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/errors.js
var ExpiredTokenException2, MalformedPolicyDocumentException, PackedPolicyTooLargeException, RegionDisabledException, IDPRejectedClaimException, InvalidIdentityTokenException, IDPCommunicationErrorException;
var init_errors4 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/errors.js"() {
    init_STSServiceException();
    ExpiredTokenException2 = class _ExpiredTokenException extends STSServiceException {
      static {
        __name(this, "ExpiredTokenException");
      }
      name = "ExpiredTokenException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ExpiredTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ExpiredTokenException.prototype);
      }
    };
    MalformedPolicyDocumentException = class _MalformedPolicyDocumentException extends STSServiceException {
      static {
        __name(this, "MalformedPolicyDocumentException");
      }
      name = "MalformedPolicyDocumentException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "MalformedPolicyDocumentException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _MalformedPolicyDocumentException.prototype);
      }
    };
    PackedPolicyTooLargeException = class _PackedPolicyTooLargeException extends STSServiceException {
      static {
        __name(this, "PackedPolicyTooLargeException");
      }
      name = "PackedPolicyTooLargeException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "PackedPolicyTooLargeException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _PackedPolicyTooLargeException.prototype);
      }
    };
    RegionDisabledException = class _RegionDisabledException extends STSServiceException {
      static {
        __name(this, "RegionDisabledException");
      }
      name = "RegionDisabledException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "RegionDisabledException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _RegionDisabledException.prototype);
      }
    };
    IDPRejectedClaimException = class _IDPRejectedClaimException extends STSServiceException {
      static {
        __name(this, "IDPRejectedClaimException");
      }
      name = "IDPRejectedClaimException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "IDPRejectedClaimException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _IDPRejectedClaimException.prototype);
      }
    };
    InvalidIdentityTokenException = class _InvalidIdentityTokenException extends STSServiceException {
      static {
        __name(this, "InvalidIdentityTokenException");
      }
      name = "InvalidIdentityTokenException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidIdentityTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidIdentityTokenException.prototype);
      }
    };
    IDPCommunicationErrorException = class _IDPCommunicationErrorException extends STSServiceException {
      static {
        __name(this, "IDPCommunicationErrorException");
      }
      name = "IDPCommunicationErrorException";
      $fault = "client";
      $retryable = {};
      constructor(opts) {
        super({
          name: "IDPCommunicationErrorException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _IDPCommunicationErrorException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/schemas/schemas_0.js
var _A, _AKI, _AR, _ARI, _ARR, _ARRs, _ARU, _ARWWI, _ARWWIR, _ARWWIRs, _Au, _C, _CA, _DS, _E, _EI, _ETE2, _IDPCEE, _IDPRCE, _IITE, _K, _MPDE, _P, _PA, _PAr, _PC, _PCLT, _PCr, _PDT, _PI, _PPS, _PPTLE, _Pr, _RA, _RDE, _RSN, _SAK, _SFWIT, _SI, _SN, _ST, _T, _TC, _TTK, _Ta, _V, _WIT, _a, _aKST, _aQE, _c4, _cTT, _e4, _hE4, _m3, _pDLT, _s4, _tLT, n04, _s_registry4, STSServiceException$, n0_registry4, ExpiredTokenException$2, IDPCommunicationErrorException$, IDPRejectedClaimException$, InvalidIdentityTokenException$, MalformedPolicyDocumentException$, PackedPolicyTooLargeException$, RegionDisabledException$, errorTypeRegistries4, accessKeySecretType, clientTokenType, AssumedRoleUser$, AssumeRoleRequest$, AssumeRoleResponse$, AssumeRoleWithWebIdentityRequest$, AssumeRoleWithWebIdentityResponse$, Credentials$, PolicyDescriptorType$, ProvidedContext$, Tag$, policyDescriptorListType, ProvidedContextsListType, tagKeyListType, tagListType, AssumeRole$, AssumeRoleWithWebIdentity$;
var init_schemas_04 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/schemas/schemas_0.js"() {
    init_schema4();
    init_errors4();
    init_STSServiceException();
    _A = "Arn";
    _AKI = "AccessKeyId";
    _AR = "AssumeRole";
    _ARI = "AssumedRoleId";
    _ARR = "AssumeRoleRequest";
    _ARRs = "AssumeRoleResponse";
    _ARU = "AssumedRoleUser";
    _ARWWI = "AssumeRoleWithWebIdentity";
    _ARWWIR = "AssumeRoleWithWebIdentityRequest";
    _ARWWIRs = "AssumeRoleWithWebIdentityResponse";
    _Au = "Audience";
    _C = "Credentials";
    _CA = "ContextAssertion";
    _DS = "DurationSeconds";
    _E = "Expiration";
    _EI = "ExternalId";
    _ETE2 = "ExpiredTokenException";
    _IDPCEE = "IDPCommunicationErrorException";
    _IDPRCE = "IDPRejectedClaimException";
    _IITE = "InvalidIdentityTokenException";
    _K = "Key";
    _MPDE = "MalformedPolicyDocumentException";
    _P = "Policy";
    _PA = "PolicyArns";
    _PAr = "ProviderArn";
    _PC = "ProvidedContexts";
    _PCLT = "ProvidedContextsListType";
    _PCr = "ProvidedContext";
    _PDT = "PolicyDescriptorType";
    _PI = "ProviderId";
    _PPS = "PackedPolicySize";
    _PPTLE = "PackedPolicyTooLargeException";
    _Pr = "Provider";
    _RA = "RoleArn";
    _RDE = "RegionDisabledException";
    _RSN = "RoleSessionName";
    _SAK = "SecretAccessKey";
    _SFWIT = "SubjectFromWebIdentityToken";
    _SI = "SourceIdentity";
    _SN = "SerialNumber";
    _ST = "SessionToken";
    _T = "Tags";
    _TC = "TokenCode";
    _TTK = "TransitiveTagKeys";
    _Ta = "Tag";
    _V = "Value";
    _WIT = "WebIdentityToken";
    _a = "arn";
    _aKST = "accessKeySecretType";
    _aQE = "awsQueryError";
    _c4 = "client";
    _cTT = "clientTokenType";
    _e4 = "error";
    _hE4 = "httpError";
    _m3 = "message";
    _pDLT = "policyDescriptorListType";
    _s4 = "smithy.ts.sdk.synthetic.com.amazonaws.sts";
    _tLT = "tagListType";
    n04 = "com.amazonaws.sts";
    _s_registry4 = TypeRegistry.for(_s4);
    STSServiceException$ = [-3, _s4, "STSServiceException", 0, [], []];
    _s_registry4.registerError(STSServiceException$, STSServiceException);
    n0_registry4 = TypeRegistry.for(n04);
    ExpiredTokenException$2 = [
      -3,
      n04,
      _ETE2,
      { [_aQE]: [`ExpiredTokenException`, 400], [_e4]: _c4, [_hE4]: 400 },
      [_m3],
      [0]
    ];
    n0_registry4.registerError(ExpiredTokenException$2, ExpiredTokenException2);
    IDPCommunicationErrorException$ = [
      -3,
      n04,
      _IDPCEE,
      { [_aQE]: [`IDPCommunicationError`, 400], [_e4]: _c4, [_hE4]: 400 },
      [_m3],
      [0]
    ];
    n0_registry4.registerError(IDPCommunicationErrorException$, IDPCommunicationErrorException);
    IDPRejectedClaimException$ = [
      -3,
      n04,
      _IDPRCE,
      { [_aQE]: [`IDPRejectedClaim`, 403], [_e4]: _c4, [_hE4]: 403 },
      [_m3],
      [0]
    ];
    n0_registry4.registerError(IDPRejectedClaimException$, IDPRejectedClaimException);
    InvalidIdentityTokenException$ = [
      -3,
      n04,
      _IITE,
      { [_aQE]: [`InvalidIdentityToken`, 400], [_e4]: _c4, [_hE4]: 400 },
      [_m3],
      [0]
    ];
    n0_registry4.registerError(InvalidIdentityTokenException$, InvalidIdentityTokenException);
    MalformedPolicyDocumentException$ = [
      -3,
      n04,
      _MPDE,
      { [_aQE]: [`MalformedPolicyDocument`, 400], [_e4]: _c4, [_hE4]: 400 },
      [_m3],
      [0]
    ];
    n0_registry4.registerError(MalformedPolicyDocumentException$, MalformedPolicyDocumentException);
    PackedPolicyTooLargeException$ = [
      -3,
      n04,
      _PPTLE,
      { [_aQE]: [`PackedPolicyTooLarge`, 400], [_e4]: _c4, [_hE4]: 400 },
      [_m3],
      [0]
    ];
    n0_registry4.registerError(PackedPolicyTooLargeException$, PackedPolicyTooLargeException);
    RegionDisabledException$ = [
      -3,
      n04,
      _RDE,
      { [_aQE]: [`RegionDisabledException`, 403], [_e4]: _c4, [_hE4]: 403 },
      [_m3],
      [0]
    ];
    n0_registry4.registerError(RegionDisabledException$, RegionDisabledException);
    errorTypeRegistries4 = [_s_registry4, n0_registry4];
    accessKeySecretType = [0, n04, _aKST, 8, 0];
    clientTokenType = [0, n04, _cTT, 8, 0];
    AssumedRoleUser$ = [3, n04, _ARU, 0, [_ARI, _A], [0, 0], 2];
    AssumeRoleRequest$ = [
      3,
      n04,
      _ARR,
      0,
      [_RA, _RSN, _PA, _P, _DS, _T, _TTK, _EI, _SN, _TC, _SI, _PC],
      [0, 0, () => policyDescriptorListType, 0, 1, () => tagListType, 64 | 0, 0, 0, 0, 0, () => ProvidedContextsListType],
      2
    ];
    AssumeRoleResponse$ = [
      3,
      n04,
      _ARRs,
      0,
      [_C, _ARU, _PPS, _SI],
      [[() => Credentials$, 0], () => AssumedRoleUser$, 1, 0]
    ];
    AssumeRoleWithWebIdentityRequest$ = [
      3,
      n04,
      _ARWWIR,
      0,
      [_RA, _RSN, _WIT, _PI, _PA, _P, _DS],
      [0, 0, [() => clientTokenType, 0], 0, () => policyDescriptorListType, 0, 1],
      3
    ];
    AssumeRoleWithWebIdentityResponse$ = [
      3,
      n04,
      _ARWWIRs,
      0,
      [_C, _SFWIT, _ARU, _PPS, _Pr, _Au, _SI],
      [[() => Credentials$, 0], 0, () => AssumedRoleUser$, 1, 0, 0, 0]
    ];
    Credentials$ = [
      3,
      n04,
      _C,
      0,
      [_AKI, _SAK, _ST, _E],
      [0, [() => accessKeySecretType, 0], 0, 4],
      4
    ];
    PolicyDescriptorType$ = [3, n04, _PDT, 0, [_a], [0]];
    ProvidedContext$ = [3, n04, _PCr, 0, [_PAr, _CA], [0, 0]];
    Tag$ = [3, n04, _Ta, 0, [_K, _V], [0, 0], 2];
    policyDescriptorListType = [1, n04, _pDLT, 0, () => PolicyDescriptorType$];
    ProvidedContextsListType = [1, n04, _PCLT, 0, () => ProvidedContext$];
    tagKeyListType = 64 | 0;
    tagListType = [1, n04, _tLT, 0, () => Tag$];
    AssumeRole$ = [9, n04, _AR, 0, () => AssumeRoleRequest$, () => AssumeRoleResponse$];
    AssumeRoleWithWebIdentity$ = [
      9,
      n04,
      _ARWWI,
      0,
      () => AssumeRoleWithWebIdentityRequest$,
      () => AssumeRoleWithWebIdentityResponse$
    ];
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.shared.js
var import_signature_v4_multi_region2, import_smithy_client39, import_url_parser5, import_util_base6417, import_util_utf814, getRuntimeConfig7;
var init_runtimeConfig_shared4 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.shared.js"() {
    init_httpAuthSchemes2();
    init_protocols4();
    import_signature_v4_multi_region2 = __toESM(require_dist_cjs55());
    init_dist_es();
    import_smithy_client39 = __toESM(require_dist_cjs34());
    import_url_parser5 = __toESM(require_dist_cjs18());
    import_util_base6417 = __toESM(require_dist_cjs10());
    import_util_utf814 = __toESM(require_dist_cjs9());
    init_httpAuthSchemeProvider4();
    init_endpointResolver4();
    init_schemas_04();
    getRuntimeConfig7 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2011-06-15",
        base64Decoder: config2?.base64Decoder ?? import_util_base6417.fromBase64,
        base64Encoder: config2?.base64Encoder ?? import_util_base6417.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver4,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSTSHttpAuthSchemeProvider,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer()
          },
          {
            schemeId: "aws.auth#sigv4a",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4a"), "identityProvider"),
            signer: new AwsSdkSigV4ASigner()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        logger: config2?.logger ?? new import_smithy_client39.NoOpLogger(),
        protocol: config2?.protocol ?? AwsQueryProtocol,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.sts",
          errorTypeRegistries: errorTypeRegistries4,
          xmlNamespace: "https://sts.amazonaws.com/doc/2011-06-15/",
          version: "2011-06-15",
          serviceTarget: "AWSSecurityTokenServiceV20110615"
        },
        serviceId: config2?.serviceId ?? "STS",
        signerConstructor: config2?.signerConstructor ?? import_signature_v4_multi_region2.SignatureV4MultiRegion,
        urlParser: config2?.urlParser ?? import_url_parser5.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? import_util_utf814.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? import_util_utf814.toUtf8
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.js
var import_util_user_agent_node4, import_config_resolver7, import_hash_node4, import_middleware_retry7, import_node_config_provider4, import_node_http_handler4, import_smithy_client40, import_util_body_length_node4, import_util_defaults_mode_node4, import_util_retry7, getRuntimeConfig8;
var init_runtimeConfig4 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.js"() {
    init_package2();
    init_client2();
    init_httpAuthSchemes2();
    import_util_user_agent_node4 = __toESM(require_dist_cjs50());
    import_config_resolver7 = __toESM(require_dist_cjs25());
    init_dist_es();
    import_hash_node4 = __toESM(require_dist_cjs44());
    import_middleware_retry7 = __toESM(require_dist_cjs35());
    import_node_config_provider4 = __toESM(require_dist_cjs29());
    import_node_http_handler4 = __toESM(require_dist_cjs13());
    import_smithy_client40 = __toESM(require_dist_cjs34());
    import_util_body_length_node4 = __toESM(require_dist_cjs45());
    import_util_defaults_mode_node4 = __toESM(require_dist_cjs46());
    import_util_retry7 = __toESM(require_dist_cjs22());
    init_runtimeConfig_shared4();
    getRuntimeConfig8 = /* @__PURE__ */ __name((config2) => {
      (0, import_smithy_client40.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, import_util_defaults_mode_node4.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(import_smithy_client40.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig7(config2);
      emitWarningIfUnsupportedVersion(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, import_node_config_provider4.loadConfig)(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? import_util_body_length_node4.calculateBodyLength,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, import_util_user_agent_node4.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_default2.version }),
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4") || (async (idProps) => await config2.credentialDefaultProvider(idProps?.__config || {})()), "identityProvider"),
            signer: new AwsSdkSigV4Signer()
          },
          {
            schemeId: "aws.auth#sigv4a",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4a"), "identityProvider"),
            signer: new AwsSdkSigV4ASigner()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        maxAttempts: config2?.maxAttempts ?? (0, import_node_config_provider4.loadConfig)(import_middleware_retry7.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, import_node_config_provider4.loadConfig)(import_config_resolver7.NODE_REGION_CONFIG_OPTIONS, { ...import_config_resolver7.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: import_node_http_handler4.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, import_node_config_provider4.loadConfig)({
          ...import_middleware_retry7.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || import_util_retry7.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? import_hash_node4.Hash.bind(null, "sha256"),
        sigv4aSigningRegionSet: config2?.sigv4aSigningRegionSet ?? (0, import_node_config_provider4.loadConfig)(NODE_SIGV4A_CONFIG_OPTIONS, loaderConfig),
        streamCollector: config2?.streamCollector ?? import_node_http_handler4.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, import_node_config_provider4.loadConfig)(import_config_resolver7.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, import_node_config_provider4.loadConfig)(import_config_resolver7.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, import_node_config_provider4.loadConfig)(import_util_user_agent_node4.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration4, resolveHttpAuthRuntimeConfig4;
var init_httpAuthExtensionConfiguration4 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration4 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig4 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeExtensions.js
var import_region_config_resolver4, import_protocol_http18, import_smithy_client41, resolveRuntimeExtensions4;
var init_runtimeExtensions4 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeExtensions.js"() {
    import_region_config_resolver4 = __toESM(require_dist_cjs48());
    import_protocol_http18 = __toESM(require_dist_cjs2());
    import_smithy_client41 = __toESM(require_dist_cjs34());
    init_httpAuthExtensionConfiguration4();
    resolveRuntimeExtensions4 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign((0, import_region_config_resolver4.getAwsRegionExtensionConfiguration)(runtimeConfig), (0, import_smithy_client41.getDefaultExtensionConfiguration)(runtimeConfig), (0, import_protocol_http18.getHttpHandlerExtensionConfiguration)(runtimeConfig), getHttpAuthExtensionConfiguration4(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, (0, import_region_config_resolver4.resolveAwsRegionExtensionConfiguration)(extensionConfiguration), (0, import_smithy_client41.resolveDefaultRuntimeConfig)(extensionConfiguration), (0, import_protocol_http18.resolveHttpHandlerRuntimeConfig)(extensionConfiguration), resolveHttpAuthRuntimeConfig4(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STSClient.js
var import_middleware_host_header4, import_middleware_logger4, import_middleware_recursion_detection4, import_middleware_user_agent4, import_config_resolver8, import_middleware_content_length4, import_middleware_endpoint8, import_middleware_retry8, import_smithy_client42, STSClient;
var init_STSClient = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STSClient.js"() {
    import_middleware_host_header4 = __toESM(require_dist_cjs3());
    import_middleware_logger4 = __toESM(require_dist_cjs4());
    import_middleware_recursion_detection4 = __toESM(require_dist_cjs5());
    import_middleware_user_agent4 = __toESM(require_dist_cjs23());
    import_config_resolver8 = __toESM(require_dist_cjs25());
    init_dist_es();
    init_schema4();
    import_middleware_content_length4 = __toESM(require_dist_cjs26());
    import_middleware_endpoint8 = __toESM(require_dist_cjs31());
    import_middleware_retry8 = __toESM(require_dist_cjs35());
    import_smithy_client42 = __toESM(require_dist_cjs34());
    init_httpAuthSchemeProvider4();
    init_EndpointParameters4();
    init_runtimeConfig4();
    init_runtimeExtensions4();
    STSClient = class extends import_smithy_client42.Client {
      static {
        __name(this, "STSClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig8(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters4(_config_0);
        const _config_2 = (0, import_middleware_user_agent4.resolveUserAgentConfig)(_config_1);
        const _config_3 = (0, import_middleware_retry8.resolveRetryConfig)(_config_2);
        const _config_4 = (0, import_config_resolver8.resolveRegionConfig)(_config_3);
        const _config_5 = (0, import_middleware_host_header4.resolveHostHeaderConfig)(_config_4);
        const _config_6 = (0, import_middleware_endpoint8.resolveEndpointConfig)(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig4(_config_6);
        const _config_8 = resolveRuntimeExtensions4(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin(this.config));
        this.middlewareStack.use((0, import_middleware_user_agent4.getUserAgentPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_retry8.getRetryPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_content_length4.getContentLengthPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_host_header4.getHostHeaderPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_logger4.getLoggerPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_recursion_detection4.getRecursionDetectionPlugin)(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: defaultSTSHttpAuthSchemeParametersProvider,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials,
            "aws.auth#sigv4a": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleCommand.js
var import_middleware_endpoint9, import_smithy_client43, AssumeRoleCommand;
var init_AssumeRoleCommand = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleCommand.js"() {
    import_middleware_endpoint9 = __toESM(require_dist_cjs31());
    import_smithy_client43 = __toESM(require_dist_cjs34());
    init_EndpointParameters4();
    init_schemas_04();
    AssumeRoleCommand = class extends import_smithy_client43.Command.classBuilder().ep(commonParams4).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint9.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "AssumeRole", {}).n("STSClient", "AssumeRoleCommand").sc(AssumeRole$).build() {
      static {
        __name(this, "AssumeRoleCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleWithWebIdentityCommand.js
var import_middleware_endpoint10, import_smithy_client44, AssumeRoleWithWebIdentityCommand;
var init_AssumeRoleWithWebIdentityCommand = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleWithWebIdentityCommand.js"() {
    import_middleware_endpoint10 = __toESM(require_dist_cjs31());
    import_smithy_client44 = __toESM(require_dist_cjs34());
    init_EndpointParameters4();
    init_schemas_04();
    AssumeRoleWithWebIdentityCommand = class extends import_smithy_client44.Command.classBuilder().ep(commonParams4).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint10.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "AssumeRoleWithWebIdentity", {}).n("STSClient", "AssumeRoleWithWebIdentityCommand").sc(AssumeRoleWithWebIdentity$).build() {
      static {
        __name(this, "AssumeRoleWithWebIdentityCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STS.js
var import_smithy_client45, commands4, STS;
var init_STS = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STS.js"() {
    import_smithy_client45 = __toESM(require_dist_cjs34());
    init_AssumeRoleCommand();
    init_AssumeRoleWithWebIdentityCommand();
    init_STSClient();
    commands4 = {
      AssumeRoleCommand,
      AssumeRoleWithWebIdentityCommand
    };
    STS = class extends STSClient {
      static {
        __name(this, "STS");
      }
    };
    (0, import_smithy_client45.createAggregatedClient)(commands4, STS);
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/index.js
var init_commands5 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/index.js"() {
    init_AssumeRoleCommand();
    init_AssumeRoleWithWebIdentityCommand();
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/models_0.js
var init_models_04 = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultStsRoleAssumers.js
var import_region_config_resolver5, getAccountIdFromAssumedRoleUser, resolveRegion, getDefaultRoleAssumer, getDefaultRoleAssumerWithWebIdentity, isH2;
var init_defaultStsRoleAssumers = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultStsRoleAssumers.js"() {
    init_client2();
    import_region_config_resolver5 = __toESM(require_dist_cjs48());
    init_AssumeRoleCommand();
    init_AssumeRoleWithWebIdentityCommand();
    getAccountIdFromAssumedRoleUser = /* @__PURE__ */ __name((assumedRoleUser) => {
      if (typeof assumedRoleUser?.Arn === "string") {
        const arnComponents = assumedRoleUser.Arn.split(":");
        if (arnComponents.length > 4 && arnComponents[4] !== "") {
          return arnComponents[4];
        }
      }
      return void 0;
    }, "getAccountIdFromAssumedRoleUser");
    resolveRegion = /* @__PURE__ */ __name(async (_region, _parentRegion, credentialProviderLogger, loaderConfig = {}) => {
      const region = typeof _region === "function" ? await _region() : _region;
      const parentRegion = typeof _parentRegion === "function" ? await _parentRegion() : _parentRegion;
      let stsDefaultRegion = "";
      const resolvedRegion = region ?? parentRegion ?? (stsDefaultRegion = await (0, import_region_config_resolver5.stsRegionDefaultResolver)(loaderConfig)());
      credentialProviderLogger?.debug?.("@aws-sdk/client-sts::resolveRegion", "accepting first of:", `${region} (credential provider clientConfig)`, `${parentRegion} (contextual client)`, `${stsDefaultRegion} (STS default: AWS_REGION, profile region, or us-east-1)`);
      return resolvedRegion;
    }, "resolveRegion");
    getDefaultRoleAssumer = /* @__PURE__ */ __name((stsOptions, STSClient12) => {
      let stsClient;
      let closureSourceCreds;
      return async (sourceCreds, params) => {
        closureSourceCreds = sourceCreds;
        if (!stsClient) {
          const { logger: logger5 = stsOptions?.parentClientConfig?.logger, profile = stsOptions?.parentClientConfig?.profile, region, requestHandler = stsOptions?.parentClientConfig?.requestHandler, credentialProviderLogger, userAgentAppId = stsOptions?.parentClientConfig?.userAgentAppId } = stsOptions;
          const resolvedRegion = await resolveRegion(region, stsOptions?.parentClientConfig?.region, credentialProviderLogger, {
            logger: logger5,
            profile
          });
          const isCompatibleRequestHandler = !isH2(requestHandler);
          stsClient = new STSClient12({
            ...stsOptions,
            userAgentAppId,
            profile,
            credentialDefaultProvider: /* @__PURE__ */ __name(() => async () => closureSourceCreds, "credentialDefaultProvider"),
            region: resolvedRegion,
            requestHandler: isCompatibleRequestHandler ? requestHandler : void 0,
            logger: logger5
          });
        }
        const { Credentials, AssumedRoleUser } = await stsClient.send(new AssumeRoleCommand(params));
        if (!Credentials || !Credentials.AccessKeyId || !Credentials.SecretAccessKey) {
          throw new Error(`Invalid response from STS.assumeRole call with role ${params.RoleArn}`);
        }
        const accountId = getAccountIdFromAssumedRoleUser(AssumedRoleUser);
        const credentials = {
          accessKeyId: Credentials.AccessKeyId,
          secretAccessKey: Credentials.SecretAccessKey,
          sessionToken: Credentials.SessionToken,
          expiration: Credentials.Expiration,
          ...Credentials.CredentialScope && { credentialScope: Credentials.CredentialScope },
          ...accountId && { accountId }
        };
        setCredentialFeature(credentials, "CREDENTIALS_STS_ASSUME_ROLE", "i");
        return credentials;
      };
    }, "getDefaultRoleAssumer");
    getDefaultRoleAssumerWithWebIdentity = /* @__PURE__ */ __name((stsOptions, STSClient12) => {
      let stsClient;
      return async (params) => {
        if (!stsClient) {
          const { logger: logger5 = stsOptions?.parentClientConfig?.logger, profile = stsOptions?.parentClientConfig?.profile, region, requestHandler = stsOptions?.parentClientConfig?.requestHandler, credentialProviderLogger, userAgentAppId = stsOptions?.parentClientConfig?.userAgentAppId } = stsOptions;
          const resolvedRegion = await resolveRegion(region, stsOptions?.parentClientConfig?.region, credentialProviderLogger, {
            logger: logger5,
            profile
          });
          const isCompatibleRequestHandler = !isH2(requestHandler);
          stsClient = new STSClient12({
            ...stsOptions,
            userAgentAppId,
            profile,
            region: resolvedRegion,
            requestHandler: isCompatibleRequestHandler ? requestHandler : void 0,
            logger: logger5
          });
        }
        const { Credentials, AssumedRoleUser } = await stsClient.send(new AssumeRoleWithWebIdentityCommand(params));
        if (!Credentials || !Credentials.AccessKeyId || !Credentials.SecretAccessKey) {
          throw new Error(`Invalid response from STS.assumeRoleWithWebIdentity call with role ${params.RoleArn}`);
        }
        const accountId = getAccountIdFromAssumedRoleUser(AssumedRoleUser);
        const credentials = {
          accessKeyId: Credentials.AccessKeyId,
          secretAccessKey: Credentials.SecretAccessKey,
          sessionToken: Credentials.SessionToken,
          expiration: Credentials.Expiration,
          ...Credentials.CredentialScope && { credentialScope: Credentials.CredentialScope },
          ...accountId && { accountId }
        };
        if (accountId) {
          setCredentialFeature(credentials, "RESOLVED_ACCOUNT_ID", "T");
        }
        setCredentialFeature(credentials, "CREDENTIALS_STS_ASSUME_ROLE_WEB_ID", "k");
        return credentials;
      };
    }, "getDefaultRoleAssumerWithWebIdentity");
    isH2 = /* @__PURE__ */ __name((requestHandler) => {
      return requestHandler?.metadata?.handlerProtocol === "h2";
    }, "isH2");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultRoleAssumers.js
var getCustomizableStsClientCtor, getDefaultRoleAssumer2, getDefaultRoleAssumerWithWebIdentity2, decorateDefaultCredentialProvider;
var init_defaultRoleAssumers = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultRoleAssumers.js"() {
    init_defaultStsRoleAssumers();
    init_STSClient();
    getCustomizableStsClientCtor = /* @__PURE__ */ __name((baseCtor, customizations) => {
      if (!customizations)
        return baseCtor;
      else
        return class CustomizableSTSClient extends baseCtor {
          static {
            __name(this, "CustomizableSTSClient");
          }
          constructor(config2) {
            super(config2);
            for (const customization of customizations) {
              this.middlewareStack.use(customization);
            }
          }
        };
    }, "getCustomizableStsClientCtor");
    getDefaultRoleAssumer2 = /* @__PURE__ */ __name((stsOptions = {}, stsPlugins) => getDefaultRoleAssumer(stsOptions, getCustomizableStsClientCtor(STSClient, stsPlugins)), "getDefaultRoleAssumer");
    getDefaultRoleAssumerWithWebIdentity2 = /* @__PURE__ */ __name((stsOptions = {}, stsPlugins) => getDefaultRoleAssumerWithWebIdentity(stsOptions, getCustomizableStsClientCtor(STSClient, stsPlugins)), "getDefaultRoleAssumerWithWebIdentity");
    decorateDefaultCredentialProvider = /* @__PURE__ */ __name((provider) => (input) => provider({
      roleAssumer: getDefaultRoleAssumer2(input),
      roleAssumerWithWebIdentity: getDefaultRoleAssumerWithWebIdentity2(input),
      ...input
    }), "decorateDefaultCredentialProvider");
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/index.js
var sts_exports = {};
__export(sts_exports, {
  AssumeRole$: () => AssumeRole$,
  AssumeRoleCommand: () => AssumeRoleCommand,
  AssumeRoleRequest$: () => AssumeRoleRequest$,
  AssumeRoleResponse$: () => AssumeRoleResponse$,
  AssumeRoleWithWebIdentity$: () => AssumeRoleWithWebIdentity$,
  AssumeRoleWithWebIdentityCommand: () => AssumeRoleWithWebIdentityCommand,
  AssumeRoleWithWebIdentityRequest$: () => AssumeRoleWithWebIdentityRequest$,
  AssumeRoleWithWebIdentityResponse$: () => AssumeRoleWithWebIdentityResponse$,
  AssumedRoleUser$: () => AssumedRoleUser$,
  Credentials$: () => Credentials$,
  ExpiredTokenException: () => ExpiredTokenException2,
  ExpiredTokenException$: () => ExpiredTokenException$2,
  IDPCommunicationErrorException: () => IDPCommunicationErrorException,
  IDPCommunicationErrorException$: () => IDPCommunicationErrorException$,
  IDPRejectedClaimException: () => IDPRejectedClaimException,
  IDPRejectedClaimException$: () => IDPRejectedClaimException$,
  InvalidIdentityTokenException: () => InvalidIdentityTokenException,
  InvalidIdentityTokenException$: () => InvalidIdentityTokenException$,
  MalformedPolicyDocumentException: () => MalformedPolicyDocumentException,
  MalformedPolicyDocumentException$: () => MalformedPolicyDocumentException$,
  PackedPolicyTooLargeException: () => PackedPolicyTooLargeException,
  PackedPolicyTooLargeException$: () => PackedPolicyTooLargeException$,
  PolicyDescriptorType$: () => PolicyDescriptorType$,
  ProvidedContext$: () => ProvidedContext$,
  RegionDisabledException: () => RegionDisabledException,
  RegionDisabledException$: () => RegionDisabledException$,
  STS: () => STS,
  STSClient: () => STSClient,
  STSServiceException: () => STSServiceException,
  STSServiceException$: () => STSServiceException$,
  Tag$: () => Tag$,
  __Client: () => import_smithy_client42.Client,
  decorateDefaultCredentialProvider: () => decorateDefaultCredentialProvider,
  errorTypeRegistries: () => errorTypeRegistries4,
  getDefaultRoleAssumer: () => getDefaultRoleAssumer2,
  getDefaultRoleAssumerWithWebIdentity: () => getDefaultRoleAssumerWithWebIdentity2
});
var init_sts = __esm({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/index.js"() {
    init_STSClient();
    init_STS();
    init_commands5();
    init_schemas_04();
    init_errors4();
    init_models_04();
    init_defaultRoleAssumers();
    init_STSServiceException();
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-process/dist-cjs/index.js
var require_dist_cjs56 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-process/dist-cjs/index.js"(exports2) {
    "use strict";
    var sharedIniFileLoader = require_dist_cjs28();
    var propertyProvider = require_dist_cjs27();
    var node_child_process = require("node:child_process");
    var node_util = require("node:util");
    var client = (init_client2(), __toCommonJS(client_exports));
    var getValidatedProcessCredentials = /* @__PURE__ */ __name((profileName, data3, profiles) => {
      if (data3.Version !== 1) {
        throw Error(`Profile ${profileName} credential_process did not return Version 1.`);
      }
      if (data3.AccessKeyId === void 0 || data3.SecretAccessKey === void 0) {
        throw Error(`Profile ${profileName} credential_process returned invalid credentials.`);
      }
      if (data3.Expiration) {
        const currentTime = /* @__PURE__ */ new Date();
        const expireTime = new Date(data3.Expiration);
        if (expireTime < currentTime) {
          throw Error(`Profile ${profileName} credential_process returned expired credentials.`);
        }
      }
      let accountId = data3.AccountId;
      if (!accountId && profiles?.[profileName]?.aws_account_id) {
        accountId = profiles[profileName].aws_account_id;
      }
      const credentials = {
        accessKeyId: data3.AccessKeyId,
        secretAccessKey: data3.SecretAccessKey,
        ...data3.SessionToken && { sessionToken: data3.SessionToken },
        ...data3.Expiration && { expiration: new Date(data3.Expiration) },
        ...data3.CredentialScope && { credentialScope: data3.CredentialScope },
        ...accountId && { accountId }
      };
      client.setCredentialFeature(credentials, "CREDENTIALS_PROCESS", "w");
      return credentials;
    }, "getValidatedProcessCredentials");
    var resolveProcessCredentials = /* @__PURE__ */ __name(async (profileName, profiles, logger5) => {
      const profile = profiles[profileName];
      if (profiles[profileName]) {
        const credentialProcess = profile["credential_process"];
        if (credentialProcess !== void 0) {
          const execPromise = node_util.promisify(sharedIniFileLoader.externalDataInterceptor?.getTokenRecord?.().exec ?? node_child_process.exec);
          try {
            const { stdout } = await execPromise(credentialProcess);
            let data3;
            try {
              data3 = JSON.parse(stdout.trim());
            } catch {
              throw Error(`Profile ${profileName} credential_process returned invalid JSON.`);
            }
            return getValidatedProcessCredentials(profileName, data3, profiles);
          } catch (error4) {
            throw new propertyProvider.CredentialsProviderError(error4.message, { logger: logger5 });
          }
        } else {
          throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} did not contain credential_process.`, { logger: logger5 });
        }
      } else {
        throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} could not be found in shared credentials file.`, {
          logger: logger5
        });
      }
    }, "resolveProcessCredentials");
    var fromProcess = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/credential-provider-process - fromProcess");
      const profiles = await sharedIniFileLoader.parseKnownFiles(init);
      return resolveProcessCredentials(sharedIniFileLoader.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      }), profiles, init.logger);
    }, "fromProcess");
    exports2.fromProcess = fromProcess;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromWebToken.js
var require_fromWebToken = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromWebToken.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __setModuleDefault2 = exports2 && exports2.__setModuleDefault || (Object.create ? (function(o10, v) {
      Object.defineProperty(o10, "default", { enumerable: true, value: v });
    }) : function(o10, v) {
      o10["default"] = v;
    });
    var __importStar2 = exports2 && exports2.__importStar || /* @__PURE__ */ (function() {
      var ownKeys2 = /* @__PURE__ */ __name(function(o10) {
        ownKeys2 = Object.getOwnPropertyNames || function(o11) {
          var ar = [];
          for (var k32 in o11) if (Object.prototype.hasOwnProperty.call(o11, k32)) ar[ar.length] = k32;
          return ar;
        };
        return ownKeys2(o10);
      }, "ownKeys");
      return function(mod) {
        if (mod && mod.__esModule) return mod;
        var result2 = {};
        if (mod != null) {
          for (var k32 = ownKeys2(mod), i32 = 0; i32 < k32.length; i32++) if (k32[i32] !== "default") __createBinding3(result2, mod, k32[i32]);
        }
        __setModuleDefault2(result2, mod);
        return result2;
      };
    })();
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromWebToken = void 0;
    var fromWebToken = /* @__PURE__ */ __name((init) => async (awsIdentityProperties) => {
      init.logger?.debug("@aws-sdk/credential-provider-web-identity - fromWebToken");
      const { roleArn, roleSessionName, webIdentityToken, providerId, policyArns, policy, durationSeconds } = init;
      let { roleAssumerWithWebIdentity } = init;
      if (!roleAssumerWithWebIdentity) {
        const { getDefaultRoleAssumerWithWebIdentity: getDefaultRoleAssumerWithWebIdentity19 } = await Promise.resolve().then(() => __importStar2((init_sts(), __toCommonJS(sts_exports))));
        roleAssumerWithWebIdentity = getDefaultRoleAssumerWithWebIdentity19({
          ...init.clientConfig,
          credentialProviderLogger: init.logger,
          parentClientConfig: {
            ...awsIdentityProperties?.callerClientConfig,
            ...init.parentClientConfig
          }
        }, init.clientPlugins);
      }
      return roleAssumerWithWebIdentity({
        RoleArn: roleArn,
        RoleSessionName: roleSessionName ?? `aws-sdk-js-session-${Date.now()}`,
        WebIdentityToken: webIdentityToken,
        ProviderId: providerId,
        PolicyArns: policyArns,
        Policy: policy,
        DurationSeconds: durationSeconds
      });
    }, "fromWebToken");
    exports2.fromWebToken = fromWebToken;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromTokenFile.js
var require_fromTokenFile = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromTokenFile.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromTokenFile = void 0;
    var client_1 = (init_client2(), __toCommonJS(client_exports));
    var property_provider_1 = require_dist_cjs27();
    var shared_ini_file_loader_1 = require_dist_cjs28();
    var node_fs_1 = require("node:fs");
    var fromWebToken_1 = require_fromWebToken();
    var ENV_TOKEN_FILE = "AWS_WEB_IDENTITY_TOKEN_FILE";
    var ENV_ROLE_ARN = "AWS_ROLE_ARN";
    var ENV_ROLE_SESSION_NAME = "AWS_ROLE_SESSION_NAME";
    var fromTokenFile = /* @__PURE__ */ __name((init = {}) => async (awsIdentityProperties) => {
      init.logger?.debug("@aws-sdk/credential-provider-web-identity - fromTokenFile");
      const webIdentityTokenFile = init?.webIdentityTokenFile ?? process.env[ENV_TOKEN_FILE];
      const roleArn = init?.roleArn ?? process.env[ENV_ROLE_ARN];
      const roleSessionName = init?.roleSessionName ?? process.env[ENV_ROLE_SESSION_NAME];
      if (!webIdentityTokenFile || !roleArn) {
        throw new property_provider_1.CredentialsProviderError("Web identity configuration not specified", {
          logger: init.logger
        });
      }
      const credentials = await (0, fromWebToken_1.fromWebToken)({
        ...init,
        webIdentityToken: shared_ini_file_loader_1.externalDataInterceptor?.getTokenRecord?.()[webIdentityTokenFile] ?? (0, node_fs_1.readFileSync)(webIdentityTokenFile, { encoding: "ascii" }),
        roleArn,
        roleSessionName
      })(awsIdentityProperties);
      if (webIdentityTokenFile === process.env[ENV_TOKEN_FILE]) {
        (0, client_1.setCredentialFeature)(credentials, "CREDENTIALS_ENV_VARS_STS_WEB_ID_TOKEN", "h");
      }
      return credentials;
    }, "fromTokenFile");
    exports2.fromTokenFile = fromTokenFile;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/index.js
var require_dist_cjs57 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/index.js"(exports2) {
    "use strict";
    var fromTokenFile = require_fromTokenFile();
    var fromWebToken = require_fromWebToken();
    Object.prototype.hasOwnProperty.call(fromTokenFile, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: fromTokenFile["__proto__"]
    });
    Object.keys(fromTokenFile).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = fromTokenFile[k32];
    });
    Object.prototype.hasOwnProperty.call(fromWebToken, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: fromWebToken["__proto__"]
    });
    Object.keys(fromWebToken).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = fromWebToken[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-ini/dist-cjs/index.js
var require_dist_cjs58 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-ini/dist-cjs/index.js"(exports2) {
    "use strict";
    var sharedIniFileLoader = require_dist_cjs28();
    var propertyProvider = require_dist_cjs27();
    var client = (init_client2(), __toCommonJS(client_exports));
    var credentialProviderLogin = require_dist_cjs52();
    var resolveCredentialSource = /* @__PURE__ */ __name((credentialSource, profileName, logger5) => {
      const sourceProvidersMap = {
        EcsContainer: /* @__PURE__ */ __name(async (options) => {
          const { fromHttp } = await Promise.resolve().then(() => __toESM(require_dist_cjs40()));
          const { fromContainerMetadata } = await Promise.resolve().then(() => __toESM(require_dist_cjs38()));
          logger5?.debug("@aws-sdk/credential-provider-ini - credential_source is EcsContainer");
          return async () => propertyProvider.chain(fromHttp(options ?? {}), fromContainerMetadata(options))().then(setNamedProvider);
        }, "EcsContainer"),
        Ec2InstanceMetadata: /* @__PURE__ */ __name(async (options) => {
          logger5?.debug("@aws-sdk/credential-provider-ini - credential_source is Ec2InstanceMetadata");
          const { fromInstanceMetadata } = await Promise.resolve().then(() => __toESM(require_dist_cjs38()));
          return async () => fromInstanceMetadata(options)().then(setNamedProvider);
        }, "Ec2InstanceMetadata"),
        Environment: /* @__PURE__ */ __name(async (options) => {
          logger5?.debug("@aws-sdk/credential-provider-ini - credential_source is Environment");
          const { fromEnv: fromEnv6 } = await Promise.resolve().then(() => __toESM(require_dist_cjs37()));
          return async () => fromEnv6(options)().then(setNamedProvider);
        }, "Environment")
      };
      if (credentialSource in sourceProvidersMap) {
        return sourceProvidersMap[credentialSource];
      } else {
        throw new propertyProvider.CredentialsProviderError(`Unsupported credential source in profile ${profileName}. Got ${credentialSource}, expected EcsContainer or Ec2InstanceMetadata or Environment.`, { logger: logger5 });
      }
    }, "resolveCredentialSource");
    var setNamedProvider = /* @__PURE__ */ __name((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_NAMED_PROVIDER", "p"), "setNamedProvider");
    var isAssumeRoleProfile = /* @__PURE__ */ __name((arg, { profile = "default", logger: logger5 } = {}) => {
      return Boolean(arg) && typeof arg === "object" && typeof arg.role_arn === "string" && ["undefined", "string"].indexOf(typeof arg.role_session_name) > -1 && ["undefined", "string"].indexOf(typeof arg.external_id) > -1 && ["undefined", "string"].indexOf(typeof arg.mfa_serial) > -1 && (isAssumeRoleWithSourceProfile(arg, { profile, logger: logger5 }) || isCredentialSourceProfile(arg, { profile, logger: logger5 }));
    }, "isAssumeRoleProfile");
    var isAssumeRoleWithSourceProfile = /* @__PURE__ */ __name((arg, { profile, logger: logger5 }) => {
      const withSourceProfile = typeof arg.source_profile === "string" && typeof arg.credential_source === "undefined";
      if (withSourceProfile) {
        logger5?.debug?.(`    ${profile} isAssumeRoleWithSourceProfile source_profile=${arg.source_profile}`);
      }
      return withSourceProfile;
    }, "isAssumeRoleWithSourceProfile");
    var isCredentialSourceProfile = /* @__PURE__ */ __name((arg, { profile, logger: logger5 }) => {
      const withProviderProfile = typeof arg.credential_source === "string" && typeof arg.source_profile === "undefined";
      if (withProviderProfile) {
        logger5?.debug?.(`    ${profile} isCredentialSourceProfile credential_source=${arg.credential_source}`);
      }
      return withProviderProfile;
    }, "isCredentialSourceProfile");
    var resolveAssumeRoleCredentials = /* @__PURE__ */ __name(async (profileName, profiles, options, callerClientConfig, visitedProfiles = {}, resolveProfileData2) => {
      options.logger?.debug("@aws-sdk/credential-provider-ini - resolveAssumeRoleCredentials (STS)");
      const profileData = profiles[profileName];
      const { source_profile, region } = profileData;
      if (!options.roleAssumer) {
        const { getDefaultRoleAssumer: getDefaultRoleAssumer19 } = await Promise.resolve().then(() => (init_sts(), sts_exports));
        options.roleAssumer = getDefaultRoleAssumer19({
          ...options.clientConfig,
          credentialProviderLogger: options.logger,
          parentClientConfig: {
            ...callerClientConfig,
            ...options?.parentClientConfig,
            region: region ?? options?.parentClientConfig?.region ?? callerClientConfig?.region
          }
        }, options.clientPlugins);
      }
      if (source_profile && source_profile in visitedProfiles) {
        throw new propertyProvider.CredentialsProviderError(`Detected a cycle attempting to resolve credentials for profile ${sharedIniFileLoader.getProfileName(options)}. Profiles visited: ` + Object.keys(visitedProfiles).join(", "), { logger: options.logger });
      }
      options.logger?.debug(`@aws-sdk/credential-provider-ini - finding credential resolver using ${source_profile ? `source_profile=[${source_profile}]` : `profile=[${profileName}]`}`);
      const sourceCredsProvider = source_profile ? resolveProfileData2(source_profile, profiles, options, callerClientConfig, {
        ...visitedProfiles,
        [source_profile]: true
      }, isCredentialSourceWithoutRoleArn(profiles[source_profile] ?? {})) : (await resolveCredentialSource(profileData.credential_source, profileName, options.logger)(options))();
      if (isCredentialSourceWithoutRoleArn(profileData)) {
        return sourceCredsProvider.then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SOURCE_PROFILE", "o"));
      } else {
        const params = {
          RoleArn: profileData.role_arn,
          RoleSessionName: profileData.role_session_name || `aws-sdk-js-${Date.now()}`,
          ExternalId: profileData.external_id,
          DurationSeconds: parseInt(profileData.duration_seconds || "3600", 10)
        };
        const { mfa_serial } = profileData;
        if (mfa_serial) {
          if (!options.mfaCodeProvider) {
            throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} requires multi-factor authentication, but no MFA code callback was provided.`, { logger: options.logger, tryNextLink: false });
          }
          params.SerialNumber = mfa_serial;
          params.TokenCode = await options.mfaCodeProvider(mfa_serial);
        }
        const sourceCreds = await sourceCredsProvider;
        return options.roleAssumer(sourceCreds, params).then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SOURCE_PROFILE", "o"));
      }
    }, "resolveAssumeRoleCredentials");
    var isCredentialSourceWithoutRoleArn = /* @__PURE__ */ __name((section) => {
      return !section.role_arn && !!section.credential_source;
    }, "isCredentialSourceWithoutRoleArn");
    var isLoginProfile = /* @__PURE__ */ __name((data3) => {
      return Boolean(data3 && data3.login_session);
    }, "isLoginProfile");
    var resolveLoginCredentials = /* @__PURE__ */ __name(async (profileName, options, callerClientConfig) => {
      const credentials = await credentialProviderLogin.fromLoginCredentials({
        ...options,
        profile: profileName
      })({ callerClientConfig });
      return client.setCredentialFeature(credentials, "CREDENTIALS_PROFILE_LOGIN", "AC");
    }, "resolveLoginCredentials");
    var isProcessProfile = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.credential_process === "string", "isProcessProfile");
    var resolveProcessCredentials = /* @__PURE__ */ __name(async (options, profile) => Promise.resolve().then(() => __toESM(require_dist_cjs56())).then(({ fromProcess }) => fromProcess({
      ...options,
      profile
    })().then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_PROCESS", "v"))), "resolveProcessCredentials");
    var resolveSsoCredentials = /* @__PURE__ */ __name(async (profile, profileData, options = {}, callerClientConfig) => {
      const { fromSSO } = await Promise.resolve().then(() => __toESM(require_dist_cjs51()));
      return fromSSO({
        profile,
        logger: options.logger,
        parentClientConfig: options.parentClientConfig,
        clientConfig: options.clientConfig
      })({
        callerClientConfig
      }).then((creds) => {
        if (profileData.sso_session) {
          return client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SSO", "r");
        } else {
          return client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SSO_LEGACY", "t");
        }
      });
    }, "resolveSsoCredentials");
    var isSsoProfile = /* @__PURE__ */ __name((arg) => arg && (typeof arg.sso_start_url === "string" || typeof arg.sso_account_id === "string" || typeof arg.sso_session === "string" || typeof arg.sso_region === "string" || typeof arg.sso_role_name === "string"), "isSsoProfile");
    var isStaticCredsProfile = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.aws_access_key_id === "string" && typeof arg.aws_secret_access_key === "string" && ["undefined", "string"].indexOf(typeof arg.aws_session_token) > -1 && ["undefined", "string"].indexOf(typeof arg.aws_account_id) > -1, "isStaticCredsProfile");
    var resolveStaticCredentials = /* @__PURE__ */ __name(async (profile, options) => {
      options?.logger?.debug("@aws-sdk/credential-provider-ini - resolveStaticCredentials");
      const credentials = {
        accessKeyId: profile.aws_access_key_id,
        secretAccessKey: profile.aws_secret_access_key,
        sessionToken: profile.aws_session_token,
        ...profile.aws_credential_scope && { credentialScope: profile.aws_credential_scope },
        ...profile.aws_account_id && { accountId: profile.aws_account_id }
      };
      return client.setCredentialFeature(credentials, "CREDENTIALS_PROFILE", "n");
    }, "resolveStaticCredentials");
    var isWebIdentityProfile = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.web_identity_token_file === "string" && typeof arg.role_arn === "string" && ["undefined", "string"].indexOf(typeof arg.role_session_name) > -1, "isWebIdentityProfile");
    var resolveWebIdentityCredentials = /* @__PURE__ */ __name(async (profile, options, callerClientConfig) => Promise.resolve().then(() => __toESM(require_dist_cjs57())).then(({ fromTokenFile }) => fromTokenFile({
      webIdentityTokenFile: profile.web_identity_token_file,
      roleArn: profile.role_arn,
      roleSessionName: profile.role_session_name,
      roleAssumerWithWebIdentity: options.roleAssumerWithWebIdentity,
      logger: options.logger,
      parentClientConfig: options.parentClientConfig
    })({
      callerClientConfig
    }).then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_STS_WEB_ID_TOKEN", "q"))), "resolveWebIdentityCredentials");
    var resolveProfileData = /* @__PURE__ */ __name(async (profileName, profiles, options, callerClientConfig, visitedProfiles = {}, isAssumeRoleRecursiveCall = false) => {
      const data3 = profiles[profileName];
      if (Object.keys(visitedProfiles).length > 0 && isStaticCredsProfile(data3)) {
        return resolveStaticCredentials(data3, options);
      }
      if (isAssumeRoleRecursiveCall || isAssumeRoleProfile(data3, { profile: profileName, logger: options.logger })) {
        return resolveAssumeRoleCredentials(profileName, profiles, options, callerClientConfig, visitedProfiles, resolveProfileData);
      }
      if (isStaticCredsProfile(data3)) {
        return resolveStaticCredentials(data3, options);
      }
      if (isWebIdentityProfile(data3)) {
        return resolveWebIdentityCredentials(data3, options, callerClientConfig);
      }
      if (isProcessProfile(data3)) {
        return resolveProcessCredentials(options, profileName);
      }
      if (isSsoProfile(data3)) {
        return await resolveSsoCredentials(profileName, data3, options, callerClientConfig);
      }
      if (isLoginProfile(data3)) {
        return resolveLoginCredentials(profileName, options, callerClientConfig);
      }
      throw new propertyProvider.CredentialsProviderError(`Could not resolve credentials using profile: [${profileName}] in configuration/credentials file(s).`, { logger: options.logger });
    }, "resolveProfileData");
    var fromIni2 = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/credential-provider-ini - fromIni");
      const profiles = await sharedIniFileLoader.parseKnownFiles(init);
      return resolveProfileData(sharedIniFileLoader.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      }), profiles, init, callerClientConfig);
    }, "fromIni");
    exports2.fromIni = fromIni2;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-node/dist-cjs/index.js
var require_dist_cjs59 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@aws-sdk/credential-provider-node/dist-cjs/index.js"(exports2) {
    "use strict";
    var credentialProviderEnv = require_dist_cjs37();
    var propertyProvider = require_dist_cjs27();
    var sharedIniFileLoader = require_dist_cjs28();
    var ENV_IMDS_DISABLED3 = "AWS_EC2_METADATA_DISABLED";
    var remoteProvider = /* @__PURE__ */ __name(async (init) => {
      const { ENV_CMDS_FULL_URI, ENV_CMDS_RELATIVE_URI, fromContainerMetadata, fromInstanceMetadata } = await Promise.resolve().then(() => __toESM(require_dist_cjs38()));
      if (process.env[ENV_CMDS_RELATIVE_URI] || process.env[ENV_CMDS_FULL_URI]) {
        init.logger?.debug("@aws-sdk/credential-provider-node - remoteProvider::fromHttp/fromContainerMetadata");
        const { fromHttp } = await Promise.resolve().then(() => __toESM(require_dist_cjs40()));
        return propertyProvider.chain(fromHttp(init), fromContainerMetadata(init));
      }
      if (process.env[ENV_IMDS_DISABLED3] && process.env[ENV_IMDS_DISABLED3] !== "false") {
        return async () => {
          throw new propertyProvider.CredentialsProviderError("EC2 Instance Metadata Service access disabled", { logger: init.logger });
        };
      }
      init.logger?.debug("@aws-sdk/credential-provider-node - remoteProvider::fromInstanceMetadata");
      return fromInstanceMetadata(init);
    }, "remoteProvider");
    function memoizeChain(providers, treatAsExpired) {
      const chain5 = internalCreateChain(providers);
      let activeLock;
      let passiveLock;
      let credentials;
      const provider = /* @__PURE__ */ __name(async (options) => {
        if (options?.forceRefresh) {
          return await chain5(options);
        }
        if (credentials?.expiration) {
          if (credentials?.expiration?.getTime() < Date.now()) {
            credentials = void 0;
          }
        }
        if (activeLock) {
          await activeLock;
        } else if (!credentials || treatAsExpired?.(credentials)) {
          if (credentials) {
            if (!passiveLock) {
              passiveLock = chain5(options).then((c32) => {
                credentials = c32;
              }).finally(() => {
                passiveLock = void 0;
              });
            }
          } else {
            activeLock = chain5(options).then((c32) => {
              credentials = c32;
            }).finally(() => {
              activeLock = void 0;
            });
            return provider(options);
          }
        }
        return credentials;
      }, "provider");
      return provider;
    }
    __name(memoizeChain, "memoizeChain");
    var internalCreateChain = /* @__PURE__ */ __name((providers) => async (awsIdentityProperties) => {
      let lastProviderError;
      for (const provider of providers) {
        try {
          return await provider(awsIdentityProperties);
        } catch (err) {
          lastProviderError = err;
          if (err?.tryNextLink) {
            continue;
          }
          throw err;
        }
      }
      throw lastProviderError;
    }, "internalCreateChain");
    var multipleCredentialSourceWarningEmitted = false;
    var defaultProvider = /* @__PURE__ */ __name((init = {}) => memoizeChain([
      async () => {
        const profile = init.profile ?? process.env[sharedIniFileLoader.ENV_PROFILE];
        if (profile) {
          const envStaticCredentialsAreSet = process.env[credentialProviderEnv.ENV_KEY] && process.env[credentialProviderEnv.ENV_SECRET];
          if (envStaticCredentialsAreSet) {
            if (!multipleCredentialSourceWarningEmitted) {
              const warnFn = init.logger?.warn && init.logger?.constructor?.name !== "NoOpLogger" ? init.logger.warn.bind(init.logger) : console.warn;
              warnFn(`@aws-sdk/credential-provider-node - defaultProvider::fromEnv WARNING:
    Multiple credential sources detected: 
    Both AWS_PROFILE and the pair AWS_ACCESS_KEY_ID/AWS_SECRET_ACCESS_KEY static credentials are set.
    This SDK will proceed with the AWS_PROFILE value.
    
    However, a future version may change this behavior to prefer the ENV static credentials.
    Please ensure that your environment only sets either the AWS_PROFILE or the
    AWS_ACCESS_KEY_ID/AWS_SECRET_ACCESS_KEY pair.
`);
              multipleCredentialSourceWarningEmitted = true;
            }
          }
          throw new propertyProvider.CredentialsProviderError("AWS_PROFILE is set, skipping fromEnv provider.", {
            logger: init.logger,
            tryNextLink: true
          });
        }
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromEnv");
        return credentialProviderEnv.fromEnv(init)();
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromSSO");
        const { ssoStartUrl, ssoAccountId, ssoRegion, ssoRoleName, ssoSession } = init;
        if (!ssoStartUrl && !ssoAccountId && !ssoRegion && !ssoRoleName && !ssoSession) {
          throw new propertyProvider.CredentialsProviderError("Skipping SSO provider in default chain (inputs do not include SSO fields).", { logger: init.logger });
        }
        const { fromSSO } = await Promise.resolve().then(() => __toESM(require_dist_cjs51()));
        return fromSSO(init)(awsIdentityProperties);
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromIni");
        const { fromIni: fromIni2 } = await Promise.resolve().then(() => __toESM(require_dist_cjs58()));
        return fromIni2(init)(awsIdentityProperties);
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromProcess");
        const { fromProcess } = await Promise.resolve().then(() => __toESM(require_dist_cjs56()));
        return fromProcess(init)(awsIdentityProperties);
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromTokenFile");
        const { fromTokenFile } = await Promise.resolve().then(() => __toESM(require_dist_cjs57()));
        return fromTokenFile(init)(awsIdentityProperties);
      },
      async () => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::remoteProvider");
        return (await remoteProvider(init))();
      },
      async () => {
        throw new propertyProvider.CredentialsProviderError("Could not load credentials from any providers", {
          tryNextLink: false,
          logger: init.logger
        });
      }
    ], credentialsTreatedAsExpired), "defaultProvider");
    var credentialsWillNeedRefresh = /* @__PURE__ */ __name((credentials) => credentials?.expiration !== void 0, "credentialsWillNeedRefresh");
    var credentialsTreatedAsExpired = /* @__PURE__ */ __name((credentials) => credentials?.expiration !== void 0 && credentials.expiration.getTime() - Date.now() < 3e5, "credentialsTreatedAsExpired");
    exports2.credentialsTreatedAsExpired = credentialsTreatedAsExpired;
    exports2.credentialsWillNeedRefresh = credentialsWillNeedRefresh;
    exports2.defaultProvider = defaultProvider;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/dist-cjs/endpoint/bdd.js
var require_bdd = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/dist-cjs/endpoint/bdd.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.bdd = void 0;
    var util_endpoints_1 = require_dist_cjs20();
    var m20 = "ref";
    var a32 = -1;
    var b32 = true;
    var c32 = "isSet";
    var d32 = "PartitionResult";
    var e32 = "stringEquals";
    var f32 = "booleanEquals";
    var g32 = "getAttr";
    var h32 = { [m20]: "Endpoint" };
    var i32 = { "fn": g32, "argv": [{ [m20]: d32 }, "name"] };
    var j32 = { [m20]: d32 };
    var k32 = {};
    var l20 = [{ [m20]: "Region" }];
    var _data32 = {
      conditions: [
        [c32, [h32]],
        [c32, l20],
        ["aws.partition", l20, d32],
        [e32, [i32, "aws-eusc"]],
        [e32, [i32, "aws-iso-f"]],
        [e32, [i32, "aws-iso-e"]],
        [e32, [i32, "aws-iso-b"]],
        [e32, [i32, "aws-iso"]],
        [e32, [i32, "aws-cn"]],
        [e32, [i32, "aws-us-gov"]],
        [e32, [i32, "aws"]],
        [f32, [{ [m20]: "UseFIPS" }, b32]],
        [f32, [{ fn: g32, argv: [j32, "supportsFIPS"] }, b32]],
        [f32, [{ [m20]: "UseDualStack" }, b32]],
        [f32, [{ fn: g32, argv: [j32, "supportsDualStack"] }, b32]]
      ],
      results: [
        [a32],
        [a32, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a32, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [h32, k32],
        ["https://api.ecr.{Region}.{PartitionResult#dnsSuffix}", k32],
        ["https://ecr.{Region}.{PartitionResult#dualStackDnsSuffix}", k32],
        ["https://api.ecr-fips.{Region}.{PartitionResult#dnsSuffix}", k32],
        ["https://ecr-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", k32],
        ["https://api.ecr-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", k32],
        [a32, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        [a32, "FIPS is enabled but this partition does not support FIPS"],
        ["https://api.ecr.{Region}.{PartitionResult#dualStackDnsSuffix}", k32],
        [a32, "DualStack is enabled but this partition does not support DualStack"],
        [a32, "Invalid Configuration: Missing Region"]
      ]
    };
    var root32 = 2;
    var r32 = 1e8;
    var nodes32 = new Int32Array([
      -1,
      1,
      -1,
      0,
      23,
      3,
      1,
      4,
      r32 + 13,
      2,
      5,
      r32 + 13,
      3,
      20,
      6,
      4,
      20,
      7,
      5,
      20,
      8,
      6,
      20,
      9,
      7,
      20,
      10,
      8,
      20,
      11,
      9,
      20,
      12,
      10,
      20,
      13,
      11,
      16,
      14,
      13,
      15,
      r32 + 4,
      14,
      r32 + 11,
      r32 + 12,
      12,
      18,
      17,
      13,
      r32 + 9,
      r32 + 10,
      13,
      19,
      r32 + 6,
      14,
      r32 + 8,
      r32 + 9,
      11,
      22,
      21,
      13,
      r32 + 5,
      r32 + 4,
      13,
      r32 + 7,
      r32 + 6,
      11,
      r32 + 1,
      24,
      13,
      r32 + 2,
      r32 + 3
    ]);
    exports2.bdd = util_endpoints_1.BinaryDecisionDiagram.from(nodes32, root32, _data32.conditions, _data32.results);
  }
});

// ../../node_modules/@aws-sdk/client-ecr/dist-cjs/endpoint/endpointResolver.js
var require_endpointResolver = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/dist-cjs/endpoint/endpointResolver.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.defaultEndpointResolver = void 0;
    var util_endpoints_1 = require_dist_cjs21();
    var util_endpoints_2 = require_dist_cjs20();
    var bdd_1 = require_bdd();
    var cache32 = new util_endpoints_2.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    var defaultEndpointResolver32 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache32.get(endpointParams, () => (0, util_endpoints_2.decideEndpoint)(bdd_1.bdd, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    exports2.defaultEndpointResolver = defaultEndpointResolver32;
    util_endpoints_2.customEndpointFunctions.aws = util_endpoints_1.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/dist-cjs/models/ECRServiceException.js
var require_ECRServiceException = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/dist-cjs/models/ECRServiceException.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ECRServiceException = exports2.__ServiceException = void 0;
    var smithy_client_1 = require_dist_cjs34();
    Object.defineProperty(exports2, "__ServiceException", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return smithy_client_1.ServiceException;
    }, "get") });
    var ECRServiceException = class _ECRServiceException extends smithy_client_1.ServiceException {
      static {
        __name(this, "ECRServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _ECRServiceException.prototype);
      }
    };
    exports2.ECRServiceException = ECRServiceException;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/dist-cjs/models/errors.js
var require_errors = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/dist-cjs/models/errors.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.InvalidLayerPartException = exports2.ImageStorageClassUpdateNotSupportedException = exports2.LifecyclePolicyPreviewInProgressException = exports2.UnsupportedImageTypeException = exports2.ImageArchivedException = exports2.ExclusionAlreadyExistsException = exports2.BlockedByOrganizationPolicyException = exports2.ReferencedImagesNotFoundException = exports2.ImageTagAlreadyExistsException = exports2.ImageDigestDoesNotMatchException = exports2.ImageAlreadyExistsException = exports2.UnableToListUpstreamImageReferrersException = exports2.LifecyclePolicyPreviewNotFoundException = exports2.UnableToGetUpstreamLayerException = exports2.LayersNotFoundException = exports2.LayerInaccessibleException = exports2.ScanNotFoundException = exports2.ImageNotFoundException = exports2.ExclusionNotFoundException = exports2.SigningConfigurationNotFoundException = exports2.RepositoryPolicyNotFoundException = exports2.TemplateNotFoundException = exports2.RepositoryNotEmptyException = exports2.RegistryPolicyNotFoundException = exports2.PullThroughCacheRuleNotFoundException = exports2.LifecyclePolicyNotFoundException = exports2.TemplateAlreadyExistsException = exports2.TooManyTagsException = exports2.RepositoryAlreadyExistsException = exports2.InvalidTagParameterException = exports2.UnsupportedUpstreamRegistryException = exports2.UnableToDecryptSecretValueException = exports2.UnableToAccessSecretException = exports2.SecretNotFoundException = exports2.PullThroughCacheRuleAlreadyExistsException = exports2.UploadNotFoundException = exports2.LayerPartTooSmallException = exports2.LayerAlreadyExistsException = exports2.KmsException = exports2.InvalidLayerException = exports2.EmptyUploadException = exports2.ValidationException = exports2.UnableToGetUpstreamImageException = exports2.LimitExceededException = exports2.ServerException = exports2.RepositoryNotFoundException = exports2.InvalidParameterException = void 0;
    var ECRServiceException_1 = require_ECRServiceException();
    var InvalidParameterException2 = class _InvalidParameterException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "InvalidParameterException");
      }
      name = "InvalidParameterException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidParameterException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidParameterException.prototype);
      }
    };
    exports2.InvalidParameterException = InvalidParameterException2;
    var RepositoryNotFoundException = class _RepositoryNotFoundException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "RepositoryNotFoundException");
      }
      name = "RepositoryNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "RepositoryNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _RepositoryNotFoundException.prototype);
      }
    };
    exports2.RepositoryNotFoundException = RepositoryNotFoundException;
    var ServerException = class _ServerException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "ServerException");
      }
      name = "ServerException";
      $fault = "server";
      constructor(opts) {
        super({
          name: "ServerException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _ServerException.prototype);
      }
    };
    exports2.ServerException = ServerException;
    var LimitExceededException2 = class _LimitExceededException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "LimitExceededException");
      }
      name = "LimitExceededException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "LimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _LimitExceededException.prototype);
      }
    };
    exports2.LimitExceededException = LimitExceededException2;
    var UnableToGetUpstreamImageException = class _UnableToGetUpstreamImageException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "UnableToGetUpstreamImageException");
      }
      name = "UnableToGetUpstreamImageException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "UnableToGetUpstreamImageException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnableToGetUpstreamImageException.prototype);
      }
    };
    exports2.UnableToGetUpstreamImageException = UnableToGetUpstreamImageException;
    var ValidationException10 = class _ValidationException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "ValidationException");
      }
      name = "ValidationException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ValidationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ValidationException.prototype);
      }
    };
    exports2.ValidationException = ValidationException10;
    var EmptyUploadException = class _EmptyUploadException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "EmptyUploadException");
      }
      name = "EmptyUploadException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "EmptyUploadException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _EmptyUploadException.prototype);
      }
    };
    exports2.EmptyUploadException = EmptyUploadException;
    var InvalidLayerException = class _InvalidLayerException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "InvalidLayerException");
      }
      name = "InvalidLayerException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidLayerException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidLayerException.prototype);
      }
    };
    exports2.InvalidLayerException = InvalidLayerException;
    var KmsException = class _KmsException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "KmsException");
      }
      name = "KmsException";
      $fault = "client";
      kmsError;
      constructor(opts) {
        super({
          name: "KmsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _KmsException.prototype);
        this.kmsError = opts.kmsError;
      }
    };
    exports2.KmsException = KmsException;
    var LayerAlreadyExistsException = class _LayerAlreadyExistsException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "LayerAlreadyExistsException");
      }
      name = "LayerAlreadyExistsException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "LayerAlreadyExistsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _LayerAlreadyExistsException.prototype);
      }
    };
    exports2.LayerAlreadyExistsException = LayerAlreadyExistsException;
    var LayerPartTooSmallException = class _LayerPartTooSmallException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "LayerPartTooSmallException");
      }
      name = "LayerPartTooSmallException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "LayerPartTooSmallException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _LayerPartTooSmallException.prototype);
      }
    };
    exports2.LayerPartTooSmallException = LayerPartTooSmallException;
    var UploadNotFoundException = class _UploadNotFoundException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "UploadNotFoundException");
      }
      name = "UploadNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "UploadNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UploadNotFoundException.prototype);
      }
    };
    exports2.UploadNotFoundException = UploadNotFoundException;
    var PullThroughCacheRuleAlreadyExistsException = class _PullThroughCacheRuleAlreadyExistsException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "PullThroughCacheRuleAlreadyExistsException");
      }
      name = "PullThroughCacheRuleAlreadyExistsException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "PullThroughCacheRuleAlreadyExistsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _PullThroughCacheRuleAlreadyExistsException.prototype);
      }
    };
    exports2.PullThroughCacheRuleAlreadyExistsException = PullThroughCacheRuleAlreadyExistsException;
    var SecretNotFoundException = class _SecretNotFoundException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "SecretNotFoundException");
      }
      name = "SecretNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "SecretNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _SecretNotFoundException.prototype);
      }
    };
    exports2.SecretNotFoundException = SecretNotFoundException;
    var UnableToAccessSecretException = class _UnableToAccessSecretException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "UnableToAccessSecretException");
      }
      name = "UnableToAccessSecretException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "UnableToAccessSecretException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnableToAccessSecretException.prototype);
      }
    };
    exports2.UnableToAccessSecretException = UnableToAccessSecretException;
    var UnableToDecryptSecretValueException = class _UnableToDecryptSecretValueException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "UnableToDecryptSecretValueException");
      }
      name = "UnableToDecryptSecretValueException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "UnableToDecryptSecretValueException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnableToDecryptSecretValueException.prototype);
      }
    };
    exports2.UnableToDecryptSecretValueException = UnableToDecryptSecretValueException;
    var UnsupportedUpstreamRegistryException = class _UnsupportedUpstreamRegistryException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "UnsupportedUpstreamRegistryException");
      }
      name = "UnsupportedUpstreamRegistryException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "UnsupportedUpstreamRegistryException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnsupportedUpstreamRegistryException.prototype);
      }
    };
    exports2.UnsupportedUpstreamRegistryException = UnsupportedUpstreamRegistryException;
    var InvalidTagParameterException = class _InvalidTagParameterException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "InvalidTagParameterException");
      }
      name = "InvalidTagParameterException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidTagParameterException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidTagParameterException.prototype);
      }
    };
    exports2.InvalidTagParameterException = InvalidTagParameterException;
    var RepositoryAlreadyExistsException = class _RepositoryAlreadyExistsException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "RepositoryAlreadyExistsException");
      }
      name = "RepositoryAlreadyExistsException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "RepositoryAlreadyExistsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _RepositoryAlreadyExistsException.prototype);
      }
    };
    exports2.RepositoryAlreadyExistsException = RepositoryAlreadyExistsException;
    var TooManyTagsException = class _TooManyTagsException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "TooManyTagsException");
      }
      name = "TooManyTagsException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TooManyTagsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyTagsException.prototype);
      }
    };
    exports2.TooManyTagsException = TooManyTagsException;
    var TemplateAlreadyExistsException = class _TemplateAlreadyExistsException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "TemplateAlreadyExistsException");
      }
      name = "TemplateAlreadyExistsException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TemplateAlreadyExistsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TemplateAlreadyExistsException.prototype);
      }
    };
    exports2.TemplateAlreadyExistsException = TemplateAlreadyExistsException;
    var LifecyclePolicyNotFoundException = class _LifecyclePolicyNotFoundException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "LifecyclePolicyNotFoundException");
      }
      name = "LifecyclePolicyNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "LifecyclePolicyNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _LifecyclePolicyNotFoundException.prototype);
      }
    };
    exports2.LifecyclePolicyNotFoundException = LifecyclePolicyNotFoundException;
    var PullThroughCacheRuleNotFoundException = class _PullThroughCacheRuleNotFoundException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "PullThroughCacheRuleNotFoundException");
      }
      name = "PullThroughCacheRuleNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "PullThroughCacheRuleNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _PullThroughCacheRuleNotFoundException.prototype);
      }
    };
    exports2.PullThroughCacheRuleNotFoundException = PullThroughCacheRuleNotFoundException;
    var RegistryPolicyNotFoundException = class _RegistryPolicyNotFoundException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "RegistryPolicyNotFoundException");
      }
      name = "RegistryPolicyNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "RegistryPolicyNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _RegistryPolicyNotFoundException.prototype);
      }
    };
    exports2.RegistryPolicyNotFoundException = RegistryPolicyNotFoundException;
    var RepositoryNotEmptyException = class _RepositoryNotEmptyException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "RepositoryNotEmptyException");
      }
      name = "RepositoryNotEmptyException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "RepositoryNotEmptyException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _RepositoryNotEmptyException.prototype);
      }
    };
    exports2.RepositoryNotEmptyException = RepositoryNotEmptyException;
    var TemplateNotFoundException = class _TemplateNotFoundException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "TemplateNotFoundException");
      }
      name = "TemplateNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TemplateNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TemplateNotFoundException.prototype);
      }
    };
    exports2.TemplateNotFoundException = TemplateNotFoundException;
    var RepositoryPolicyNotFoundException = class _RepositoryPolicyNotFoundException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "RepositoryPolicyNotFoundException");
      }
      name = "RepositoryPolicyNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "RepositoryPolicyNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _RepositoryPolicyNotFoundException.prototype);
      }
    };
    exports2.RepositoryPolicyNotFoundException = RepositoryPolicyNotFoundException;
    var SigningConfigurationNotFoundException = class _SigningConfigurationNotFoundException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "SigningConfigurationNotFoundException");
      }
      name = "SigningConfigurationNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "SigningConfigurationNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _SigningConfigurationNotFoundException.prototype);
      }
    };
    exports2.SigningConfigurationNotFoundException = SigningConfigurationNotFoundException;
    var ExclusionNotFoundException = class _ExclusionNotFoundException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "ExclusionNotFoundException");
      }
      name = "ExclusionNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ExclusionNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ExclusionNotFoundException.prototype);
      }
    };
    exports2.ExclusionNotFoundException = ExclusionNotFoundException;
    var ImageNotFoundException = class _ImageNotFoundException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "ImageNotFoundException");
      }
      name = "ImageNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ImageNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ImageNotFoundException.prototype);
      }
    };
    exports2.ImageNotFoundException = ImageNotFoundException;
    var ScanNotFoundException = class _ScanNotFoundException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "ScanNotFoundException");
      }
      name = "ScanNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ScanNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ScanNotFoundException.prototype);
      }
    };
    exports2.ScanNotFoundException = ScanNotFoundException;
    var LayerInaccessibleException = class _LayerInaccessibleException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "LayerInaccessibleException");
      }
      name = "LayerInaccessibleException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "LayerInaccessibleException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _LayerInaccessibleException.prototype);
      }
    };
    exports2.LayerInaccessibleException = LayerInaccessibleException;
    var LayersNotFoundException = class _LayersNotFoundException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "LayersNotFoundException");
      }
      name = "LayersNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "LayersNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _LayersNotFoundException.prototype);
      }
    };
    exports2.LayersNotFoundException = LayersNotFoundException;
    var UnableToGetUpstreamLayerException = class _UnableToGetUpstreamLayerException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "UnableToGetUpstreamLayerException");
      }
      name = "UnableToGetUpstreamLayerException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "UnableToGetUpstreamLayerException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnableToGetUpstreamLayerException.prototype);
      }
    };
    exports2.UnableToGetUpstreamLayerException = UnableToGetUpstreamLayerException;
    var LifecyclePolicyPreviewNotFoundException = class _LifecyclePolicyPreviewNotFoundException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "LifecyclePolicyPreviewNotFoundException");
      }
      name = "LifecyclePolicyPreviewNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "LifecyclePolicyPreviewNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _LifecyclePolicyPreviewNotFoundException.prototype);
      }
    };
    exports2.LifecyclePolicyPreviewNotFoundException = LifecyclePolicyPreviewNotFoundException;
    var UnableToListUpstreamImageReferrersException = class _UnableToListUpstreamImageReferrersException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "UnableToListUpstreamImageReferrersException");
      }
      name = "UnableToListUpstreamImageReferrersException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "UnableToListUpstreamImageReferrersException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnableToListUpstreamImageReferrersException.prototype);
      }
    };
    exports2.UnableToListUpstreamImageReferrersException = UnableToListUpstreamImageReferrersException;
    var ImageAlreadyExistsException = class _ImageAlreadyExistsException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "ImageAlreadyExistsException");
      }
      name = "ImageAlreadyExistsException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ImageAlreadyExistsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ImageAlreadyExistsException.prototype);
      }
    };
    exports2.ImageAlreadyExistsException = ImageAlreadyExistsException;
    var ImageDigestDoesNotMatchException = class _ImageDigestDoesNotMatchException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "ImageDigestDoesNotMatchException");
      }
      name = "ImageDigestDoesNotMatchException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ImageDigestDoesNotMatchException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ImageDigestDoesNotMatchException.prototype);
      }
    };
    exports2.ImageDigestDoesNotMatchException = ImageDigestDoesNotMatchException;
    var ImageTagAlreadyExistsException = class _ImageTagAlreadyExistsException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "ImageTagAlreadyExistsException");
      }
      name = "ImageTagAlreadyExistsException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ImageTagAlreadyExistsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ImageTagAlreadyExistsException.prototype);
      }
    };
    exports2.ImageTagAlreadyExistsException = ImageTagAlreadyExistsException;
    var ReferencedImagesNotFoundException = class _ReferencedImagesNotFoundException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "ReferencedImagesNotFoundException");
      }
      name = "ReferencedImagesNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ReferencedImagesNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ReferencedImagesNotFoundException.prototype);
      }
    };
    exports2.ReferencedImagesNotFoundException = ReferencedImagesNotFoundException;
    var BlockedByOrganizationPolicyException = class _BlockedByOrganizationPolicyException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "BlockedByOrganizationPolicyException");
      }
      name = "BlockedByOrganizationPolicyException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "BlockedByOrganizationPolicyException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _BlockedByOrganizationPolicyException.prototype);
      }
    };
    exports2.BlockedByOrganizationPolicyException = BlockedByOrganizationPolicyException;
    var ExclusionAlreadyExistsException = class _ExclusionAlreadyExistsException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "ExclusionAlreadyExistsException");
      }
      name = "ExclusionAlreadyExistsException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ExclusionAlreadyExistsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ExclusionAlreadyExistsException.prototype);
      }
    };
    exports2.ExclusionAlreadyExistsException = ExclusionAlreadyExistsException;
    var ImageArchivedException = class _ImageArchivedException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "ImageArchivedException");
      }
      name = "ImageArchivedException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ImageArchivedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ImageArchivedException.prototype);
      }
    };
    exports2.ImageArchivedException = ImageArchivedException;
    var UnsupportedImageTypeException = class _UnsupportedImageTypeException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "UnsupportedImageTypeException");
      }
      name = "UnsupportedImageTypeException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "UnsupportedImageTypeException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnsupportedImageTypeException.prototype);
      }
    };
    exports2.UnsupportedImageTypeException = UnsupportedImageTypeException;
    var LifecyclePolicyPreviewInProgressException = class _LifecyclePolicyPreviewInProgressException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "LifecyclePolicyPreviewInProgressException");
      }
      name = "LifecyclePolicyPreviewInProgressException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "LifecyclePolicyPreviewInProgressException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _LifecyclePolicyPreviewInProgressException.prototype);
      }
    };
    exports2.LifecyclePolicyPreviewInProgressException = LifecyclePolicyPreviewInProgressException;
    var ImageStorageClassUpdateNotSupportedException = class _ImageStorageClassUpdateNotSupportedException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "ImageStorageClassUpdateNotSupportedException");
      }
      name = "ImageStorageClassUpdateNotSupportedException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ImageStorageClassUpdateNotSupportedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ImageStorageClassUpdateNotSupportedException.prototype);
      }
    };
    exports2.ImageStorageClassUpdateNotSupportedException = ImageStorageClassUpdateNotSupportedException;
    var InvalidLayerPartException = class _InvalidLayerPartException extends ECRServiceException_1.ECRServiceException {
      static {
        __name(this, "InvalidLayerPartException");
      }
      name = "InvalidLayerPartException";
      $fault = "client";
      registryId;
      repositoryName;
      uploadId;
      lastValidByteReceived;
      constructor(opts) {
        super({
          name: "InvalidLayerPartException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidLayerPartException.prototype);
        this.registryId = opts.registryId;
        this.repositoryName = opts.repositoryName;
        this.uploadId = opts.uploadId;
        this.lastValidByteReceived = opts.lastValidByteReceived;
      }
    };
    exports2.InvalidLayerPartException = InvalidLayerPartException;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/dist-cjs/schemas/schemas_0.js
var require_schemas_0 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/dist-cjs/schemas/schemas_0.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.Attribute$ = exports2.errorTypeRegistries = exports2.ValidationException$ = exports2.UploadNotFoundException$ = exports2.UnsupportedUpstreamRegistryException$ = exports2.UnsupportedImageTypeException$ = exports2.UnableToListUpstreamImageReferrersException$ = exports2.UnableToGetUpstreamLayerException$ = exports2.UnableToGetUpstreamImageException$ = exports2.UnableToDecryptSecretValueException$ = exports2.UnableToAccessSecretException$ = exports2.TooManyTagsException$ = exports2.TemplateNotFoundException$ = exports2.TemplateAlreadyExistsException$ = exports2.SigningConfigurationNotFoundException$ = exports2.ServerException$ = exports2.SecretNotFoundException$ = exports2.ScanNotFoundException$ = exports2.RepositoryPolicyNotFoundException$ = exports2.RepositoryNotFoundException$ = exports2.RepositoryNotEmptyException$ = exports2.RepositoryAlreadyExistsException$ = exports2.RegistryPolicyNotFoundException$ = exports2.ReferencedImagesNotFoundException$ = exports2.PullThroughCacheRuleNotFoundException$ = exports2.PullThroughCacheRuleAlreadyExistsException$ = exports2.LimitExceededException$ = exports2.LifecyclePolicyPreviewNotFoundException$ = exports2.LifecyclePolicyPreviewInProgressException$ = exports2.LifecyclePolicyNotFoundException$ = exports2.LayersNotFoundException$ = exports2.LayerPartTooSmallException$ = exports2.LayerInaccessibleException$ = exports2.LayerAlreadyExistsException$ = exports2.KmsException$ = exports2.InvalidTagParameterException$ = exports2.InvalidParameterException$ = exports2.InvalidLayerPartException$ = exports2.InvalidLayerException$ = exports2.ImageTagAlreadyExistsException$ = exports2.ImageStorageClassUpdateNotSupportedException$ = exports2.ImageNotFoundException$ = exports2.ImageDigestDoesNotMatchException$ = exports2.ImageArchivedException$ = exports2.ImageAlreadyExistsException$ = exports2.ExclusionNotFoundException$ = exports2.ExclusionAlreadyExistsException$ = exports2.EmptyUploadException$ = exports2.BlockedByOrganizationPolicyException$ = exports2.ECRServiceException$ = void 0;
    exports2.DescribeRegistryResponse$ = exports2.DescribeRegistryRequest$ = exports2.DescribePullThroughCacheRulesResponse$ = exports2.DescribePullThroughCacheRulesRequest$ = exports2.DescribeImagesResponse$ = exports2.DescribeImagesRequest$ = exports2.DescribeImageSigningStatusResponse$ = exports2.DescribeImageSigningStatusRequest$ = exports2.DescribeImagesFilter$ = exports2.DescribeImageScanFindingsResponse$ = exports2.DescribeImageScanFindingsRequest$ = exports2.DescribeImageReplicationStatusResponse$ = exports2.DescribeImageReplicationStatusRequest$ = exports2.DeregisterPullTimeUpdateExclusionResponse$ = exports2.DeregisterPullTimeUpdateExclusionRequest$ = exports2.DeleteSigningConfigurationResponse$ = exports2.DeleteSigningConfigurationRequest$ = exports2.DeleteRepositoryResponse$ = exports2.DeleteRepositoryRequest$ = exports2.DeleteRepositoryPolicyResponse$ = exports2.DeleteRepositoryPolicyRequest$ = exports2.DeleteRepositoryCreationTemplateResponse$ = exports2.DeleteRepositoryCreationTemplateRequest$ = exports2.DeleteRegistryPolicyResponse$ = exports2.DeleteRegistryPolicyRequest$ = exports2.DeletePullThroughCacheRuleResponse$ = exports2.DeletePullThroughCacheRuleRequest$ = exports2.DeleteLifecyclePolicyResponse$ = exports2.DeleteLifecyclePolicyRequest$ = exports2.CvssScoreDetails$ = exports2.CvssScoreAdjustment$ = exports2.CvssScore$ = exports2.CreateRepositoryResponse$ = exports2.CreateRepositoryRequest$ = exports2.CreateRepositoryCreationTemplateResponse$ = exports2.CreateRepositoryCreationTemplateRequest$ = exports2.CreatePullThroughCacheRuleResponse$ = exports2.CreatePullThroughCacheRuleRequest$ = exports2.CompleteLayerUploadResponse$ = exports2.CompleteLayerUploadRequest$ = exports2.BatchGetRepositoryScanningConfigurationResponse$ = exports2.BatchGetRepositoryScanningConfigurationRequest$ = exports2.BatchGetImageResponse$ = exports2.BatchGetImageRequest$ = exports2.BatchDeleteImageResponse$ = exports2.BatchDeleteImageRequest$ = exports2.BatchCheckLayerAvailabilityResponse$ = exports2.BatchCheckLayerAvailabilityRequest$ = exports2.AwsEcrContainerImageDetails$ = exports2.AuthorizationData$ = void 0;
    exports2.ListImagesFilter$ = exports2.ListImageReferrersResponse$ = exports2.ListImageReferrersRequest$ = exports2.ListImageReferrersFilter$ = exports2.LifecyclePolicyRuleAction$ = exports2.LifecyclePolicyPreviewSummary$ = exports2.LifecyclePolicyPreviewResult$ = exports2.LifecyclePolicyPreviewFilter$ = exports2.LayerFailure$ = exports2.Layer$ = exports2.InitiateLayerUploadResponse$ = exports2.InitiateLayerUploadRequest$ = exports2.ImageTagMutabilityExclusionFilter$ = exports2.ImageSigningStatus$ = exports2.ImageScanStatus$ = exports2.ImageScanningConfiguration$ = exports2.ImageScanFindingsSummary$ = exports2.ImageScanFindings$ = exports2.ImageScanFinding$ = exports2.ImageReplicationStatus$ = exports2.ImageReferrer$ = exports2.ImageIdentifier$ = exports2.ImageFailure$ = exports2.ImageDetail$ = exports2.Image$ = exports2.GetSigningConfigurationResponse$ = exports2.GetSigningConfigurationRequest$ = exports2.GetRepositoryPolicyResponse$ = exports2.GetRepositoryPolicyRequest$ = exports2.GetRegistryScanningConfigurationResponse$ = exports2.GetRegistryScanningConfigurationRequest$ = exports2.GetRegistryPolicyResponse$ = exports2.GetRegistryPolicyRequest$ = exports2.GetLifecyclePolicyResponse$ = exports2.GetLifecyclePolicyRequest$ = exports2.GetLifecyclePolicyPreviewResponse$ = exports2.GetLifecyclePolicyPreviewRequest$ = exports2.GetDownloadUrlForLayerResponse$ = exports2.GetDownloadUrlForLayerRequest$ = exports2.GetAuthorizationTokenResponse$ = exports2.GetAuthorizationTokenRequest$ = exports2.GetAccountSettingResponse$ = exports2.GetAccountSettingRequest$ = exports2.EnhancedImageScanFinding$ = exports2.EncryptionConfigurationForRepositoryCreationTemplate$ = exports2.EncryptionConfiguration$ = exports2.DescribeRepositoryCreationTemplatesResponse$ = exports2.DescribeRepositoryCreationTemplatesRequest$ = exports2.DescribeRepositoriesResponse$ = exports2.DescribeRepositoriesRequest$ = void 0;
    exports2.StartImageScanRequest$ = exports2.SigningRule$ = exports2.SigningRepositoryFilter$ = exports2.SigningConfiguration$ = exports2.SetRepositoryPolicyResponse$ = exports2.SetRepositoryPolicyRequest$ = exports2.ScoreDetails$ = exports2.ScanningRepositoryFilter$ = exports2.ResourceDetails$ = exports2.Resource$ = exports2.RepositoryScanningConfigurationFailure$ = exports2.RepositoryScanningConfiguration$ = exports2.RepositoryFilter$ = exports2.RepositoryCreationTemplate$ = exports2.Repository$ = exports2.ReplicationRule$ = exports2.ReplicationDestination$ = exports2.ReplicationConfiguration$ = exports2.Remediation$ = exports2.RegistryScanningRule$ = exports2.RegistryScanningConfiguration$ = exports2.RegisterPullTimeUpdateExclusionResponse$ = exports2.RegisterPullTimeUpdateExclusionRequest$ = exports2.Recommendation$ = exports2.PutSigningConfigurationResponse$ = exports2.PutSigningConfigurationRequest$ = exports2.PutReplicationConfigurationResponse$ = exports2.PutReplicationConfigurationRequest$ = exports2.PutRegistryScanningConfigurationResponse$ = exports2.PutRegistryScanningConfigurationRequest$ = exports2.PutRegistryPolicyResponse$ = exports2.PutRegistryPolicyRequest$ = exports2.PutLifecyclePolicyResponse$ = exports2.PutLifecyclePolicyRequest$ = exports2.PutImageTagMutabilityResponse$ = exports2.PutImageTagMutabilityRequest$ = exports2.PutImageScanningConfigurationResponse$ = exports2.PutImageScanningConfigurationRequest$ = exports2.PutImageResponse$ = exports2.PutImageRequest$ = exports2.PutAccountSettingResponse$ = exports2.PutAccountSettingRequest$ = exports2.PullThroughCacheRule$ = exports2.PackageVulnerabilityDetails$ = exports2.ListTagsForResourceResponse$ = exports2.ListTagsForResourceRequest$ = exports2.ListPullTimeUpdateExclusionsResponse$ = exports2.ListPullTimeUpdateExclusionsRequest$ = exports2.ListImagesResponse$ = exports2.ListImagesRequest$ = void 0;
    exports2.GetLifecyclePolicyPreview$ = exports2.GetLifecyclePolicy$ = exports2.GetDownloadUrlForLayer$ = exports2.GetAuthorizationToken$ = exports2.GetAccountSetting$ = exports2.DescribeRepositoryCreationTemplates$ = exports2.DescribeRepositories$ = exports2.DescribeRegistry$ = exports2.DescribePullThroughCacheRules$ = exports2.DescribeImageSigningStatus$ = exports2.DescribeImageScanFindings$ = exports2.DescribeImages$ = exports2.DescribeImageReplicationStatus$ = exports2.DeregisterPullTimeUpdateExclusion$ = exports2.DeleteSigningConfiguration$ = exports2.DeleteRepositoryPolicy$ = exports2.DeleteRepositoryCreationTemplate$ = exports2.DeleteRepository$ = exports2.DeleteRegistryPolicy$ = exports2.DeletePullThroughCacheRule$ = exports2.DeleteLifecyclePolicy$ = exports2.CreateRepositoryCreationTemplate$ = exports2.CreateRepository$ = exports2.CreatePullThroughCacheRule$ = exports2.CompleteLayerUpload$ = exports2.BatchGetRepositoryScanningConfiguration$ = exports2.BatchGetImage$ = exports2.BatchDeleteImage$ = exports2.BatchCheckLayerAvailability$ = exports2.VulnerablePackage$ = exports2.ValidatePullThroughCacheRuleResponse$ = exports2.ValidatePullThroughCacheRuleRequest$ = exports2.UploadLayerPartResponse$ = exports2.UploadLayerPartRequest$ = exports2.UpdateRepositoryCreationTemplateResponse$ = exports2.UpdateRepositoryCreationTemplateRequest$ = exports2.UpdatePullThroughCacheRuleResponse$ = exports2.UpdatePullThroughCacheRuleRequest$ = exports2.UpdateImageStorageClassResponse$ = exports2.UpdateImageStorageClassRequest$ = exports2.UntagResourceResponse$ = exports2.UntagResourceRequest$ = exports2.TransitioningImageTotalCount$ = exports2.TagResourceResponse$ = exports2.TagResourceRequest$ = exports2.Tag$ = exports2.SubjectIdentifier$ = exports2.StartLifecyclePolicyPreviewResponse$ = exports2.StartLifecyclePolicyPreviewRequest$ = exports2.StartImageScanResponse$ = void 0;
    exports2.ValidatePullThroughCacheRule$ = exports2.UploadLayerPart$ = exports2.UpdateRepositoryCreationTemplate$ = exports2.UpdatePullThroughCacheRule$ = exports2.UpdateImageStorageClass$ = exports2.UntagResource$ = exports2.TagResource$ = exports2.StartLifecyclePolicyPreview$ = exports2.StartImageScan$ = exports2.SetRepositoryPolicy$ = exports2.RegisterPullTimeUpdateExclusion$ = exports2.PutSigningConfiguration$ = exports2.PutReplicationConfiguration$ = exports2.PutRegistryScanningConfiguration$ = exports2.PutRegistryPolicy$ = exports2.PutLifecyclePolicy$ = exports2.PutImageTagMutability$ = exports2.PutImageScanningConfiguration$ = exports2.PutImage$ = exports2.PutAccountSetting$ = exports2.ListTagsForResource$ = exports2.ListPullTimeUpdateExclusions$ = exports2.ListImages$ = exports2.ListImageReferrers$ = exports2.InitiateLayerUpload$ = exports2.GetSigningConfiguration$ = exports2.GetRepositoryPolicy$ = exports2.GetRegistryScanningConfiguration$ = exports2.GetRegistryPolicy$ = void 0;
    var _A10 = "Attribute";
    var _AD = "AuthorizationData";
    var _ADL = "AuthorizationDataList";
    var _AECID = "AwsEcrContainerImageDetails";
    var _AL = "AttributeList";
    var _BBOPE = "BlockedByOrganizationPolicyException";
    var _BCLA = "BatchCheckLayerAvailability";
    var _BCLAR = "BatchCheckLayerAvailabilityRequest";
    var _BCLARa = "BatchCheckLayerAvailabilityResponse";
    var _BDI = "BatchDeleteImage";
    var _BDIR = "BatchDeleteImageRequest";
    var _BDIRa = "BatchDeleteImageResponse";
    var _BGI = "BatchGetImage";
    var _BGIR = "BatchGetImageRequest";
    var _BGIRa = "BatchGetImageResponse";
    var _BGRSC = "BatchGetRepositoryScanningConfiguration";
    var _BGRSCR = "BatchGetRepositoryScanningConfigurationRequest";
    var _BGRSCRa = "BatchGetRepositoryScanningConfigurationResponse";
    var _CLU = "CompleteLayerUpload";
    var _CLUR = "CompleteLayerUploadRequest";
    var _CLURo = "CompleteLayerUploadResponse";
    var _CPTCR = "CreatePullThroughCacheRule";
    var _CPTCRR = "CreatePullThroughCacheRuleRequest";
    var _CPTCRRr = "CreatePullThroughCacheRuleResponse";
    var _CR = "CreateRepository";
    var _CRCT = "CreateRepositoryCreationTemplate";
    var _CRCTR = "CreateRepositoryCreationTemplateRequest";
    var _CRCTRr = "CreateRepositoryCreationTemplateResponse";
    var _CRR = "CreateRepositoryRequest";
    var _CRRr = "CreateRepositoryResponse";
    var _CS4 = "CvssScore";
    var _CSA = "CvssScoreAdjustment";
    var _CSAL = "CvssScoreAdjustmentList";
    var _CSD = "CvssScoreDetails";
    var _CSL = "CvssScoreList";
    var _DI = "DescribeImages";
    var _DIF = "DescribeImagesFilter";
    var _DIR = "DescribeImagesRequest";
    var _DIRS = "DescribeImageReplicationStatus";
    var _DIRSR = "DescribeImageReplicationStatusRequest";
    var _DIRSRe = "DescribeImageReplicationStatusResponse";
    var _DIRe = "DescribeImagesResponse";
    var _DISF = "DescribeImageScanFindings";
    var _DISFR = "DescribeImageScanFindingsRequest";
    var _DISFRe = "DescribeImageScanFindingsResponse";
    var _DISS = "DescribeImageSigningStatus";
    var _DISSR = "DescribeImageSigningStatusRequest";
    var _DISSRe = "DescribeImageSigningStatusResponse";
    var _DLP = "DeleteLifecyclePolicy";
    var _DLPR = "DeleteLifecyclePolicyRequest";
    var _DLPRe = "DeleteLifecyclePolicyResponse";
    var _DPTCR = "DeletePullThroughCacheRule";
    var _DPTCRR = "DeletePullThroughCacheRuleRequest";
    var _DPTCRRe = "DeletePullThroughCacheRuleResponse";
    var _DPTCRRes = "DescribePullThroughCacheRulesRequest";
    var _DPTCRResc = "DescribePullThroughCacheRulesResponse";
    var _DPTCRe = "DescribePullThroughCacheRules";
    var _DPTUE = "DeregisterPullTimeUpdateExclusion";
    var _DPTUER = "DeregisterPullTimeUpdateExclusionRequest";
    var _DPTUERe = "DeregisterPullTimeUpdateExclusionResponse";
    var _DR = "DeleteRepository";
    var _DRCT = "DeleteRepositoryCreationTemplate";
    var _DRCTR = "DeleteRepositoryCreationTemplateRequest";
    var _DRCTRe = "DeleteRepositoryCreationTemplateResponse";
    var _DRCTRes = "DescribeRepositoryCreationTemplatesRequest";
    var _DRCTResc = "DescribeRepositoryCreationTemplatesResponse";
    var _DRCTe = "DescribeRepositoryCreationTemplates";
    var _DRP = "DeleteRegistryPolicy";
    var _DRPR = "DeleteRegistryPolicyRequest";
    var _DRPRe = "DeleteRegistryPolicyResponse";
    var _DRPRel = "DeleteRepositoryPolicyRequest";
    var _DRPRele = "DeleteRepositoryPolicyResponse";
    var _DRPe = "DeleteRepositoryPolicy";
    var _DRR = "DeleteRepositoryRequest";
    var _DRRe = "DeleteRepositoryResponse";
    var _DRRes = "DescribeRegistryRequest";
    var _DRResc = "DescribeRegistryResponse";
    var _DRRescr = "DescribeRepositoriesRequest";
    var _DRRescri = "DescribeRepositoriesResponse";
    var _DRe = "DescribeRegistry";
    var _DRes = "DescribeRepositories";
    var _DSC = "DeleteSigningConfiguration";
    var _DSCR = "DeleteSigningConfigurationRequest";
    var _DSCRe = "DeleteSigningConfigurationResponse";
    var _EAEE = "ExclusionAlreadyExistsException";
    var _EC = "EncryptionConfiguration";
    var _ECFRCT = "EncryptionConfigurationForRepositoryCreationTemplate";
    var _EISF = "EnhancedImageScanFinding";
    var _EISFL = "EnhancedImageScanFindingList";
    var _ENFE = "ExclusionNotFoundException";
    var _EUE = "EmptyUploadException";
    var _GAS = "GetAccountSetting";
    var _GASR = "GetAccountSettingRequest";
    var _GASRe = "GetAccountSettingResponse";
    var _GAT = "GetAuthorizationToken";
    var _GATR = "GetAuthorizationTokenRequest";
    var _GATRe = "GetAuthorizationTokenResponse";
    var _GDUFL = "GetDownloadUrlForLayer";
    var _GDUFLR = "GetDownloadUrlForLayerRequest";
    var _GDUFLRe = "GetDownloadUrlForLayerResponse";
    var _GLP = "GetLifecyclePolicy";
    var _GLPP = "GetLifecyclePolicyPreview";
    var _GLPPR = "GetLifecyclePolicyPreviewRequest";
    var _GLPPRe = "GetLifecyclePolicyPreviewResponse";
    var _GLPR = "GetLifecyclePolicyRequest";
    var _GLPRe = "GetLifecyclePolicyResponse";
    var _GRP = "GetRegistryPolicy";
    var _GRPR = "GetRegistryPolicyRequest";
    var _GRPRe = "GetRegistryPolicyResponse";
    var _GRPRet = "GetRepositoryPolicyRequest";
    var _GRPRete = "GetRepositoryPolicyResponse";
    var _GRPe = "GetRepositoryPolicy";
    var _GRSC = "GetRegistryScanningConfiguration";
    var _GRSCR = "GetRegistryScanningConfigurationRequest";
    var _GRSCRe = "GetRegistryScanningConfigurationResponse";
    var _GSC = "GetSigningConfiguration";
    var _GSCR = "GetSigningConfigurationRequest";
    var _GSCRe = "GetSigningConfigurationResponse";
    var _I = "Image";
    var _IAE = "ImageArchivedException";
    var _IAEE = "ImageAlreadyExistsException";
    var _ID = "ImageDetail";
    var _IDDNME = "ImageDigestDoesNotMatchException";
    var _IDL = "ImageDetailList";
    var _IF = "ImageFailure";
    var _IFL = "ImageFailureList";
    var _II2 = "ImageIdentifier";
    var _IIL = "ImageIdentifierList";
    var _IL = "ImageList";
    var _ILE = "InvalidLayerException";
    var _ILPE = "InvalidLayerPartException";
    var _ILU = "InitiateLayerUpload";
    var _ILUR = "InitiateLayerUploadRequest";
    var _ILURn = "InitiateLayerUploadResponse";
    var _INFE = "ImageNotFoundException";
    var _IPE2 = "InvalidParameterException";
    var _IR = "ImageReferrer";
    var _IRL = "ImageReferrerList";
    var _IRS = "ImageReplicationStatus";
    var _IRSL = "ImageReplicationStatusList";
    var _ISC = "ImageScanningConfiguration";
    var _ISCUNSE = "ImageStorageClassUpdateNotSupportedException";
    var _ISF = "ImageScanFinding";
    var _ISFL = "ImageScanFindingList";
    var _ISFS = "ImageScanFindingsSummary";
    var _ISFm = "ImageScanFindings";
    var _ISS = "ImageScanStatus";
    var _ISSL = "ImageSigningStatusList";
    var _ISSm = "ImageSigningStatus";
    var _ITAEE = "ImageTagAlreadyExistsException";
    var _ITMEF = "ImageTagMutabilityExclusionFilter";
    var _ITMEFm = "ImageTagMutabilityExclusionFilters";
    var _ITPE = "InvalidTagParameterException";
    var _K10 = "Key";
    var _KE = "KmsException";
    var _L2 = "Layer";
    var _LAEE = "LayerAlreadyExistsException";
    var _LEE2 = "LimitExceededException";
    var _LF = "LayerFailure";
    var _LFL = "LayerFailureList";
    var _LI = "ListImages";
    var _LIE = "LayerInaccessibleException";
    var _LIF = "ListImagesFilter";
    var _LIR = "ListImagesRequest";
    var _LIRF = "ListImageReferrersFilter";
    var _LIRR = "ListImageReferrersRequest";
    var _LIRRi = "ListImageReferrersResponse";
    var _LIRi = "ListImagesResponse";
    var _LIRis = "ListImageReferrers";
    var _LL = "LayerList";
    var _LNFE = "LayersNotFoundException";
    var _LPNFE = "LifecyclePolicyNotFoundException";
    var _LPPF = "LifecyclePolicyPreviewFilter";
    var _LPPIPE = "LifecyclePolicyPreviewInProgressException";
    var _LPPNFE = "LifecyclePolicyPreviewNotFoundException";
    var _LPPR = "LifecyclePolicyPreviewResult";
    var _LPPRL = "LifecyclePolicyPreviewResultList";
    var _LPPS = "LifecyclePolicyPreviewSummary";
    var _LPRA = "LifecyclePolicyRuleAction";
    var _LPTSE = "LayerPartTooSmallException";
    var _LPTUE = "ListPullTimeUpdateExclusions";
    var _LPTUER = "ListPullTimeUpdateExclusionsRequest";
    var _LPTUERi = "ListPullTimeUpdateExclusionsResponse";
    var _LTFR = "ListTagsForResource";
    var _LTFRR = "ListTagsForResourceRequest";
    var _LTFRRi = "ListTagsForResourceResponse";
    var _PAS = "PutAccountSetting";
    var _PASR = "PutAccountSettingRequest";
    var _PASRu = "PutAccountSettingResponse";
    var _PI10 = "PutImage";
    var _PIR = "PutImageRequest";
    var _PIRu = "PutImageResponse";
    var _PISC = "PutImageScanningConfiguration";
    var _PISCR = "PutImageScanningConfigurationRequest";
    var _PISCRu = "PutImageScanningConfigurationResponse";
    var _PITM = "PutImageTagMutability";
    var _PITMR = "PutImageTagMutabilityRequest";
    var _PITMRu = "PutImageTagMutabilityResponse";
    var _PLP = "PutLifecyclePolicy";
    var _PLPR = "PutLifecyclePolicyRequest";
    var _PLPRu = "PutLifecyclePolicyResponse";
    var _PRC = "PutReplicationConfiguration";
    var _PRCR = "PutReplicationConfigurationRequest";
    var _PRCRu = "PutReplicationConfigurationResponse";
    var _PRP = "PutRegistryPolicy";
    var _PRPR = "PutRegistryPolicyRequest";
    var _PRPRu = "PutRegistryPolicyResponse";
    var _PRSC = "PutRegistryScanningConfiguration";
    var _PRSCR = "PutRegistryScanningConfigurationRequest";
    var _PRSCRu = "PutRegistryScanningConfigurationResponse";
    var _PSC = "PutSigningConfiguration";
    var _PSCR = "PutSigningConfigurationRequest";
    var _PSCRu = "PutSigningConfigurationResponse";
    var _PTCR = "PullThroughCacheRule";
    var _PTCRAEE = "PullThroughCacheRuleAlreadyExistsException";
    var _PTCRL = "PullThroughCacheRuleList";
    var _PTCRNFE = "PullThroughCacheRuleNotFoundException";
    var _PVD = "PackageVulnerabilityDetails";
    var _R = "Recommendation";
    var _RAEE = "RepositoryAlreadyExistsException";
    var _RC10 = "ReplicationConfiguration";
    var _RCT = "RepositoryCreationTemplate";
    var _RCTL = "RepositoryCreationTemplateList";
    var _RD = "ReplicationDestination";
    var _RDL = "ReplicationDestinationList";
    var _RDe = "ResourceDetails";
    var _RF = "RepositoryFilter";
    var _RFL = "RepositoryFilterList";
    var _RINFE = "ReferencedImagesNotFoundException";
    var _RL = "RepositoryList";
    var _RLe = "ResourceList";
    var _RNEE = "RepositoryNotEmptyException";
    var _RNFE11 = "RepositoryNotFoundException";
    var _RPNFE = "RegistryPolicyNotFoundException";
    var _RPNFEe = "RepositoryPolicyNotFoundException";
    var _RPTUE = "RegisterPullTimeUpdateExclusion";
    var _RPTUER = "RegisterPullTimeUpdateExclusionRequest";
    var _RPTUERe = "RegisterPullTimeUpdateExclusionResponse";
    var _RR = "ReplicationRule";
    var _RRL = "ReplicationRuleList";
    var _RSC = "RegistryScanningConfiguration";
    var _RSCF = "RepositoryScanningConfigurationFailure";
    var _RSCFL = "RepositoryScanningConfigurationFailureList";
    var _RSCL = "RepositoryScanningConfigurationList";
    var _RSCe = "RepositoryScanningConfiguration";
    var _RSR = "RegistryScanningRule";
    var _RSRL = "RegistryScanningRuleList";
    var _Re = "Remediation";
    var _Rep = "Repository";
    var _Res = "Resource";
    var _SC = "SigningConfiguration";
    var _SCNFE = "SigningConfigurationNotFoundException";
    var _SD = "ScoreDetails";
    var _SE = "ServerException";
    var _SI10 = "SubjectIdentifier";
    var _SIS = "StartImageScan";
    var _SISR = "StartImageScanRequest";
    var _SISRt = "StartImageScanResponse";
    var _SLPP = "StartLifecyclePolicyPreview";
    var _SLPPR = "StartLifecyclePolicyPreviewRequest";
    var _SLPPRt = "StartLifecyclePolicyPreviewResponse";
    var _SNFE = "ScanNotFoundException";
    var _SNFEe = "SecretNotFoundException";
    var _SR = "SigningRule";
    var _SRF = "ScanningRepositoryFilter";
    var _SRFL = "ScanningRepositoryFilterList";
    var _SRFLi = "SigningRepositoryFilterList";
    var _SRFi = "SigningRepositoryFilter";
    var _SRL = "SigningRuleList";
    var _SRP = "SetRepositoryPolicy";
    var _SRPR = "SetRepositoryPolicyRequest";
    var _SRPRe = "SetRepositoryPolicyResponse";
    var _T10 = "Tag";
    var _TAEE = "TemplateAlreadyExistsException";
    var _TITC = "TransitioningImageTotalCount";
    var _TITCr = "TransitioningImageTotalCounts";
    var _TL = "TagList";
    var _TMTE = "TooManyTagsException";
    var _TNFE = "TemplateNotFoundException";
    var _TR = "TagResource";
    var _TRR = "TagResourceRequest";
    var _TRRa = "TagResourceResponse";
    var _UISC = "UpdateImageStorageClass";
    var _UISCR = "UpdateImageStorageClassRequest";
    var _UISCRp = "UpdateImageStorageClassResponse";
    var _UITE = "UnsupportedImageTypeException";
    var _ULP = "UploadLayerPart";
    var _ULPR = "UploadLayerPartRequest";
    var _ULPRp = "UploadLayerPartResponse";
    var _UNFE = "UploadNotFoundException";
    var _UPTCR = "UpdatePullThroughCacheRule";
    var _UPTCRR = "UpdatePullThroughCacheRuleRequest";
    var _UPTCRRp = "UpdatePullThroughCacheRuleResponse";
    var _UR = "UntagResource";
    var _URCT = "UpdateRepositoryCreationTemplate";
    var _URCTR = "UpdateRepositoryCreationTemplateRequest";
    var _URCTRp = "UpdateRepositoryCreationTemplateResponse";
    var _URR = "UntagResourceRequest";
    var _URRn = "UntagResourceResponse";
    var _UTASE = "UnableToAccessSecretException";
    var _UTDSVE = "UnableToDecryptSecretValueException";
    var _UTGUIE = "UnableToGetUpstreamImageException";
    var _UTGULE = "UnableToGetUpstreamLayerException";
    var _UTLUIRE = "UnableToListUpstreamImageReferrersException";
    var _UURE = "UnsupportedUpstreamRegistryException";
    var _V10 = "Value";
    var _VE10 = "ValidationException";
    var _VP = "VulnerablePackage";
    var _VPL = "VulnerablePackagesList";
    var _VPTCR = "ValidatePullThroughCacheRule";
    var _VPTCRR = "ValidatePullThroughCacheRuleRequest";
    var _VPTCRRa = "ValidatePullThroughCacheRuleResponse";
    var _a10 = "architecture";
    var _aAI = "awsAccountId";
    var _aD = "authorizationData";
    var _aECI = "awsEcrContainerImage";
    var _aF = "appliedFor";
    var _aMT = "acceptedMediaTypes";
    var _aMTr = "artifactMediaType";
    var _aRP = "appliedRulePriority";
    var _aS = "artifactStatus";
    var _aSF = "appliedScanFilters";
    var _aT22 = "authorizationToken";
    var _aTr = "artifactType";
    var _aTrt = "artifactTypes";
    var _ac = "action";
    var _ad = "adjustments";
    var _an = "annotations";
    var _ar = "arch";
    var _at = "attributes";
    var _au = "author";
    var _bS = "baseScore";
    var _c32 = "client";
    var _cA = "credentialArn";
    var _cAr = "createdAt";
    var _cRA = "customRoleArn";
    var _cv = "cvss";
    var _d = "description";
    var _dU = "downloadUrl";
    var _de = "destinations";
    var _det = "details";
    var _di = "digest";
    var _e32 = "error";
    var _eA = "expiresAt";
    var _eAx = "exploitAvailable";
    var _eC = "encryptionConfiguration";
    var _eF = "enhancedFindings";
    var _eITC = "expiringImageTotalCount";
    var _eRP = "ecrRepositoryPrefix";
    var _eRPc = "ecrRepositoryPrefixes";
    var _eT = "encryptionType";
    var _ep = "epoch";
    var _f = "failures";
    var _fA = "findingArn";
    var _fAi = "fixAvailable";
    var _fC = "failureCode";
    var _fIV = "fixedInVersion";
    var _fOA = "firstObservedAt";
    var _fP = "filePath";
    var _fR = "failureReason";
    var _fSC = "findingSeverityCounts";
    var _fT = "filterType";
    var _fa = "failure";
    var _fi = "filter";
    var _fin = "findings";
    var _fo = "force";
    var _hE32 = "httpError";
    var _i = "images";
    var _iD = "imageDetails";
    var _iDm = "imageDigest";
    var _iH = "imageHash";
    var _iI = "imageIds";
    var _iIm = "imageId";
    var _iM = "imageManifest";
    var _iMMT = "imageManifestMediaType";
    var _iPA = "imagePushedAt";
    var _iS = "imageStatus";
    var _iSC = "imageScanningConfiguration";
    var _iSCA = "imageScanCompletedAt";
    var _iSF = "imageScanFindings";
    var _iSFS = "imageScanFindingsSummary";
    var _iSIB = "imageSizeInBytes";
    var _iSS = "imageScanStatus";
    var _iT13 = "imageTags";
    var _iTC = "imageTotalCount";
    var _iTM = "imageTagMutability";
    var _iTMEF = "imageTagMutabilityExclusionFilters";
    var _iTm = "imageTag";
    var _iUC = "inUseCount";
    var _iV = "isValid";
    var _id = "id";
    var _im = "image";
    var _k = "key";
    var _kE = "kmsError";
    var _kK = "kmsKey";
    var _l = "layers";
    var _lA = "layerAvailability";
    var _lAA = "lastArchivedAt";
    var _lAAa = "lastActivatedAt";
    var _lBR = "lastByteReceived";
    var _lD = "layerDigests";
    var _lDa = "layerDigest";
    var _lEA = "lastEvaluatedAt";
    var _lIUA = "lastInUseAt";
    var _lOA = "lastObservedAt";
    var _lP = "lifecyclePolicy";
    var _lPB = "layerPartBlob";
    var _lPT = "lifecyclePolicyText";
    var _lRPT = "lastRecordedPullTime";
    var _lS = "layerSize";
    var _lVBR = "lastValidByteReceived";
    var _m29 = "message";
    var _mR = "maxResults";
    var _mT = "mediaType";
    var _me = "metric";
    var _n = "name";
    var _nT = "nextToken";
    var _p = "platform";
    var _pA = "pushedAt";
    var _pAr = "principalArn";
    var _pE = "proxyEndpoint";
    var _pFB = "partFirstByte";
    var _pLB = "partLastByte";
    var _pM = "packageManager";
    var _pR = "previewResults";
    var _pS = "partSize";
    var _pT = "policyText";
    var _pTCR = "pullThroughCacheRules";
    var _pTUE = "pullTimeUpdateExclusions";
    var _pVD = "packageVulnerabilityDetails";
    var _pr = "prefix";
    var _pre = "prefixes";
    var _r4 = "registry";
    var _rA = "resourceArn";
    var _rAe = "repositoryArn";
    var _rC10 = "replicationConfiguration";
    var _rCT = "repositoryCreationTemplate";
    var _rCTe = "repositoryCreationTemplates";
    var _rF = "repositoryFilters";
    var _rI = "registryId";
    var _rIe = "registryIds";
    var _rN10 = "repositoryName";
    var _rNe = "repositoryNames";
    var _rP = "repositoryPolicy";
    var _rS = "replicationStatuses";
    var _rSC = "registryScanningConfiguration";
    var _rT13 = "resourceTags";
    var _rU13 = "referenceUrls";
    var _rUe = "repositoryUri";
    var _rV = "relatedVulnerabilities";
    var _re = "repository";
    var _rea = "reason";
    var _rec = "recommendation";
    var _ref = "referrers";
    var _reg = "region";
    var _rel = "release";
    var _rem = "remediation";
    var _rep = "repositories";
    var _res = "resources";
    var _ru = "rules";
    var _s32 = "smithy.ts.sdk.synthetic.com.amazonaws.ecr";
    var _sC = "scanningConfigurations";
    var _sCc = "scanningConfiguration";
    var _sCi = "signingConfiguration";
    var _sCt = "storageClass";
    var _sD = "scoreDetails";
    var _sF = "scanFrequency";
    var _sI = "subjectId";
    var _sLH = "sourceLayerHash";
    var _sMD = "subjectManifestDigest";
    var _sOP = "scanOnPush";
    var _sPA = "signingProfileArn";
    var _sS = "scoreSource";
    var _sSi = "signingStatuses";
    var _sT19 = "scanType";
    var _sU = "sourceUrl";
    var _sV = "scoringVector";
    var _sc4 = "score";
    var _se14 = "server";
    var _sev = "severity";
    var _si = "size";
    var _so = "source";
    var _st = "status";
    var _su = "summary";
    var _t = "tags";
    var _tITC = "transitioningImageTotalCounts";
    var _tK = "tagKeys";
    var _tS = "tagStatus";
    var _tSC = "targetStorageClass";
    var _te = "text";
    var _ti = "title";
    var _ty = "type";
    var _u = "uri";
    var _uA = "updatedAt";
    var _uI = "uploadId";
    var _uR = "upstreamRegistry";
    var _uRP = "upstreamRepositoryPrefix";
    var _uRU = "upstreamRegistryUrl";
    var _ur = "url";
    var _v = "value";
    var _vCA = "vendorCreatedAt";
    var _vI = "vulnerabilityId";
    var _vP = "vulnerablePackages";
    var _vS = "vendorSeverity";
    var _vSUA = "vulnerabilitySourceUpdatedAt";
    var _vUA = "vendorUpdatedAt";
    var _ve = "version";
    var n032 = "com.amazonaws.ecr";
    var schema_1 = (init_schema4(), __toCommonJS(schema_exports));
    var ECRServiceException_1 = require_ECRServiceException();
    var errors_1 = require_errors();
    var _s_registry32 = schema_1.TypeRegistry.for(_s32);
    exports2.ECRServiceException$ = [-3, _s32, "ECRServiceException", 0, [], []];
    _s_registry32.registerError(exports2.ECRServiceException$, ECRServiceException_1.ECRServiceException);
    var n0_registry32 = schema_1.TypeRegistry.for(n032);
    exports2.BlockedByOrganizationPolicyException$ = [
      -3,
      n032,
      _BBOPE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.BlockedByOrganizationPolicyException$, errors_1.BlockedByOrganizationPolicyException);
    exports2.EmptyUploadException$ = [
      -3,
      n032,
      _EUE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.EmptyUploadException$, errors_1.EmptyUploadException);
    exports2.ExclusionAlreadyExistsException$ = [
      -3,
      n032,
      _EAEE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ExclusionAlreadyExistsException$, errors_1.ExclusionAlreadyExistsException);
    exports2.ExclusionNotFoundException$ = [
      -3,
      n032,
      _ENFE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ExclusionNotFoundException$, errors_1.ExclusionNotFoundException);
    exports2.ImageAlreadyExistsException$ = [
      -3,
      n032,
      _IAEE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ImageAlreadyExistsException$, errors_1.ImageAlreadyExistsException);
    exports2.ImageArchivedException$ = [
      -3,
      n032,
      _IAE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ImageArchivedException$, errors_1.ImageArchivedException);
    exports2.ImageDigestDoesNotMatchException$ = [
      -3,
      n032,
      _IDDNME,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ImageDigestDoesNotMatchException$, errors_1.ImageDigestDoesNotMatchException);
    exports2.ImageNotFoundException$ = [
      -3,
      n032,
      _INFE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ImageNotFoundException$, errors_1.ImageNotFoundException);
    exports2.ImageStorageClassUpdateNotSupportedException$ = [
      -3,
      n032,
      _ISCUNSE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ImageStorageClassUpdateNotSupportedException$, errors_1.ImageStorageClassUpdateNotSupportedException);
    exports2.ImageTagAlreadyExistsException$ = [
      -3,
      n032,
      _ITAEE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ImageTagAlreadyExistsException$, errors_1.ImageTagAlreadyExistsException);
    exports2.InvalidLayerException$ = [
      -3,
      n032,
      _ILE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidLayerException$, errors_1.InvalidLayerException);
    exports2.InvalidLayerPartException$ = [
      -3,
      n032,
      _ILPE,
      { [_e32]: _c32 },
      [_rI, _rN10, _uI, _lVBR, _m29],
      [0, 0, 0, 1, 0]
    ];
    n0_registry32.registerError(exports2.InvalidLayerPartException$, errors_1.InvalidLayerPartException);
    exports2.InvalidParameterException$ = [
      -3,
      n032,
      _IPE2,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidParameterException$, errors_1.InvalidParameterException);
    exports2.InvalidTagParameterException$ = [
      -3,
      n032,
      _ITPE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidTagParameterException$, errors_1.InvalidTagParameterException);
    exports2.KmsException$ = [
      -3,
      n032,
      _KE,
      { [_e32]: _c32 },
      [_m29, _kE],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.KmsException$, errors_1.KmsException);
    exports2.LayerAlreadyExistsException$ = [
      -3,
      n032,
      _LAEE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.LayerAlreadyExistsException$, errors_1.LayerAlreadyExistsException);
    exports2.LayerInaccessibleException$ = [
      -3,
      n032,
      _LIE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.LayerInaccessibleException$, errors_1.LayerInaccessibleException);
    exports2.LayerPartTooSmallException$ = [
      -3,
      n032,
      _LPTSE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.LayerPartTooSmallException$, errors_1.LayerPartTooSmallException);
    exports2.LayersNotFoundException$ = [
      -3,
      n032,
      _LNFE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.LayersNotFoundException$, errors_1.LayersNotFoundException);
    exports2.LifecyclePolicyNotFoundException$ = [
      -3,
      n032,
      _LPNFE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.LifecyclePolicyNotFoundException$, errors_1.LifecyclePolicyNotFoundException);
    exports2.LifecyclePolicyPreviewInProgressException$ = [
      -3,
      n032,
      _LPPIPE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.LifecyclePolicyPreviewInProgressException$, errors_1.LifecyclePolicyPreviewInProgressException);
    exports2.LifecyclePolicyPreviewNotFoundException$ = [
      -3,
      n032,
      _LPPNFE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.LifecyclePolicyPreviewNotFoundException$, errors_1.LifecyclePolicyPreviewNotFoundException);
    exports2.LimitExceededException$ = [
      -3,
      n032,
      _LEE2,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.LimitExceededException$, errors_1.LimitExceededException);
    exports2.PullThroughCacheRuleAlreadyExistsException$ = [
      -3,
      n032,
      _PTCRAEE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.PullThroughCacheRuleAlreadyExistsException$, errors_1.PullThroughCacheRuleAlreadyExistsException);
    exports2.PullThroughCacheRuleNotFoundException$ = [
      -3,
      n032,
      _PTCRNFE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.PullThroughCacheRuleNotFoundException$, errors_1.PullThroughCacheRuleNotFoundException);
    exports2.ReferencedImagesNotFoundException$ = [
      -3,
      n032,
      _RINFE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ReferencedImagesNotFoundException$, errors_1.ReferencedImagesNotFoundException);
    exports2.RegistryPolicyNotFoundException$ = [
      -3,
      n032,
      _RPNFE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.RegistryPolicyNotFoundException$, errors_1.RegistryPolicyNotFoundException);
    exports2.RepositoryAlreadyExistsException$ = [
      -3,
      n032,
      _RAEE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.RepositoryAlreadyExistsException$, errors_1.RepositoryAlreadyExistsException);
    exports2.RepositoryNotEmptyException$ = [
      -3,
      n032,
      _RNEE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.RepositoryNotEmptyException$, errors_1.RepositoryNotEmptyException);
    exports2.RepositoryNotFoundException$ = [
      -3,
      n032,
      _RNFE11,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.RepositoryNotFoundException$, errors_1.RepositoryNotFoundException);
    exports2.RepositoryPolicyNotFoundException$ = [
      -3,
      n032,
      _RPNFEe,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.RepositoryPolicyNotFoundException$, errors_1.RepositoryPolicyNotFoundException);
    exports2.ScanNotFoundException$ = [
      -3,
      n032,
      _SNFE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ScanNotFoundException$, errors_1.ScanNotFoundException);
    exports2.SecretNotFoundException$ = [
      -3,
      n032,
      _SNFEe,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.SecretNotFoundException$, errors_1.SecretNotFoundException);
    exports2.ServerException$ = [
      -3,
      n032,
      _SE,
      { [_e32]: _se14 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ServerException$, errors_1.ServerException);
    exports2.SigningConfigurationNotFoundException$ = [
      -3,
      n032,
      _SCNFE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.SigningConfigurationNotFoundException$, errors_1.SigningConfigurationNotFoundException);
    exports2.TemplateAlreadyExistsException$ = [
      -3,
      n032,
      _TAEE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.TemplateAlreadyExistsException$, errors_1.TemplateAlreadyExistsException);
    exports2.TemplateNotFoundException$ = [
      -3,
      n032,
      _TNFE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.TemplateNotFoundException$, errors_1.TemplateNotFoundException);
    exports2.TooManyTagsException$ = [
      -3,
      n032,
      _TMTE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.TooManyTagsException$, errors_1.TooManyTagsException);
    exports2.UnableToAccessSecretException$ = [
      -3,
      n032,
      _UTASE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.UnableToAccessSecretException$, errors_1.UnableToAccessSecretException);
    exports2.UnableToDecryptSecretValueException$ = [
      -3,
      n032,
      _UTDSVE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.UnableToDecryptSecretValueException$, errors_1.UnableToDecryptSecretValueException);
    exports2.UnableToGetUpstreamImageException$ = [
      -3,
      n032,
      _UTGUIE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.UnableToGetUpstreamImageException$, errors_1.UnableToGetUpstreamImageException);
    exports2.UnableToGetUpstreamLayerException$ = [
      -3,
      n032,
      _UTGULE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.UnableToGetUpstreamLayerException$, errors_1.UnableToGetUpstreamLayerException);
    exports2.UnableToListUpstreamImageReferrersException$ = [
      -3,
      n032,
      _UTLUIRE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.UnableToListUpstreamImageReferrersException$, errors_1.UnableToListUpstreamImageReferrersException);
    exports2.UnsupportedImageTypeException$ = [
      -3,
      n032,
      _UITE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.UnsupportedImageTypeException$, errors_1.UnsupportedImageTypeException);
    exports2.UnsupportedUpstreamRegistryException$ = [
      -3,
      n032,
      _UURE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.UnsupportedUpstreamRegistryException$, errors_1.UnsupportedUpstreamRegistryException);
    exports2.UploadNotFoundException$ = [
      -3,
      n032,
      _UNFE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.UploadNotFoundException$, errors_1.UploadNotFoundException);
    exports2.ValidationException$ = [
      -3,
      n032,
      _VE10,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ValidationException$, errors_1.ValidationException);
    exports2.errorTypeRegistries = [
      _s_registry32,
      n0_registry32
    ];
    exports2.Attribute$ = [
      3,
      n032,
      _A10,
      0,
      [_k, _v],
      [0, 0],
      1
    ];
    exports2.AuthorizationData$ = [
      3,
      n032,
      _AD,
      0,
      [_aT22, _eA, _pE],
      [0, 4, 0]
    ];
    exports2.AwsEcrContainerImageDetails$ = [
      3,
      n032,
      _AECID,
      0,
      [_a10, _au, _iH, _iT13, _p, _pA, _lIUA, _iUC, _r4, _rN10],
      [0, 0, 0, 64 | 0, 0, 4, 4, 1, 0, 0]
    ];
    exports2.BatchCheckLayerAvailabilityRequest$ = [
      3,
      n032,
      _BCLAR,
      0,
      [_rN10, _lD, _rI],
      [0, 64 | 0, 0],
      2
    ];
    exports2.BatchCheckLayerAvailabilityResponse$ = [
      3,
      n032,
      _BCLARa,
      0,
      [_l, _f],
      [() => LayerList, () => LayerFailureList]
    ];
    exports2.BatchDeleteImageRequest$ = [
      3,
      n032,
      _BDIR,
      0,
      [_rN10, _iI, _rI],
      [0, () => ImageIdentifierList, 0],
      2
    ];
    exports2.BatchDeleteImageResponse$ = [
      3,
      n032,
      _BDIRa,
      0,
      [_iI, _f],
      [() => ImageIdentifierList, () => ImageFailureList]
    ];
    exports2.BatchGetImageRequest$ = [
      3,
      n032,
      _BGIR,
      0,
      [_rN10, _iI, _rI, _aMT],
      [0, () => ImageIdentifierList, 0, 64 | 0],
      2
    ];
    exports2.BatchGetImageResponse$ = [
      3,
      n032,
      _BGIRa,
      0,
      [_i, _f],
      [() => ImageList, () => ImageFailureList]
    ];
    exports2.BatchGetRepositoryScanningConfigurationRequest$ = [
      3,
      n032,
      _BGRSCR,
      0,
      [_rNe],
      [64 | 0],
      1
    ];
    exports2.BatchGetRepositoryScanningConfigurationResponse$ = [
      3,
      n032,
      _BGRSCRa,
      0,
      [_sC, _f],
      [() => RepositoryScanningConfigurationList, () => RepositoryScanningConfigurationFailureList]
    ];
    exports2.CompleteLayerUploadRequest$ = [
      3,
      n032,
      _CLUR,
      0,
      [_rN10, _uI, _lD, _rI],
      [0, 0, 64 | 0, 0],
      3
    ];
    exports2.CompleteLayerUploadResponse$ = [
      3,
      n032,
      _CLURo,
      0,
      [_rI, _rN10, _uI, _lDa],
      [0, 0, 0, 0]
    ];
    exports2.CreatePullThroughCacheRuleRequest$ = [
      3,
      n032,
      _CPTCRR,
      0,
      [_eRP, _uRU, _rI, _uR, _cA, _cRA, _uRP],
      [0, 0, 0, 0, 0, 0, 0],
      2
    ];
    exports2.CreatePullThroughCacheRuleResponse$ = [
      3,
      n032,
      _CPTCRRr,
      0,
      [_eRP, _uRU, _cAr, _rI, _uR, _cA, _cRA, _uRP],
      [0, 0, 4, 0, 0, 0, 0, 0]
    ];
    exports2.CreateRepositoryCreationTemplateRequest$ = [
      3,
      n032,
      _CRCTR,
      0,
      [_pr, _aF, _d, _eC, _rT13, _iTM, _iTMEF, _rP, _lP, _cRA],
      [0, 64 | 0, 0, () => exports2.EncryptionConfigurationForRepositoryCreationTemplate$, () => TagList, 0, () => ImageTagMutabilityExclusionFilters, 0, 0, 0],
      2
    ];
    exports2.CreateRepositoryCreationTemplateResponse$ = [
      3,
      n032,
      _CRCTRr,
      0,
      [_rI, _rCT],
      [0, () => exports2.RepositoryCreationTemplate$]
    ];
    exports2.CreateRepositoryRequest$ = [
      3,
      n032,
      _CRR,
      0,
      [_rN10, _rI, _t, _iTM, _iTMEF, _iSC, _eC],
      [0, 0, () => TagList, 0, () => ImageTagMutabilityExclusionFilters, () => exports2.ImageScanningConfiguration$, () => exports2.EncryptionConfiguration$],
      1
    ];
    exports2.CreateRepositoryResponse$ = [
      3,
      n032,
      _CRRr,
      0,
      [_re],
      [() => exports2.Repository$]
    ];
    exports2.CvssScore$ = [
      3,
      n032,
      _CS4,
      0,
      [_bS, _sV, _so, _ve],
      [1, 0, 0, 0]
    ];
    exports2.CvssScoreAdjustment$ = [
      3,
      n032,
      _CSA,
      0,
      [_me, _rea],
      [0, 0]
    ];
    exports2.CvssScoreDetails$ = [
      3,
      n032,
      _CSD,
      0,
      [_ad, _sc4, _sS, _sV, _ve],
      [() => CvssScoreAdjustmentList, 1, 0, 0, 0]
    ];
    exports2.DeleteLifecyclePolicyRequest$ = [
      3,
      n032,
      _DLPR,
      0,
      [_rN10, _rI],
      [0, 0],
      1
    ];
    exports2.DeleteLifecyclePolicyResponse$ = [
      3,
      n032,
      _DLPRe,
      0,
      [_rI, _rN10, _lPT, _lEA],
      [0, 0, 0, 4]
    ];
    exports2.DeletePullThroughCacheRuleRequest$ = [
      3,
      n032,
      _DPTCRR,
      0,
      [_eRP, _rI],
      [0, 0],
      1
    ];
    exports2.DeletePullThroughCacheRuleResponse$ = [
      3,
      n032,
      _DPTCRRe,
      0,
      [_eRP, _uRU, _cAr, _rI, _cA, _cRA, _uRP],
      [0, 0, 4, 0, 0, 0, 0]
    ];
    exports2.DeleteRegistryPolicyRequest$ = [
      3,
      n032,
      _DRPR,
      0,
      [],
      []
    ];
    exports2.DeleteRegistryPolicyResponse$ = [
      3,
      n032,
      _DRPRe,
      0,
      [_rI, _pT],
      [0, 0]
    ];
    exports2.DeleteRepositoryCreationTemplateRequest$ = [
      3,
      n032,
      _DRCTR,
      0,
      [_pr],
      [0],
      1
    ];
    exports2.DeleteRepositoryCreationTemplateResponse$ = [
      3,
      n032,
      _DRCTRe,
      0,
      [_rI, _rCT],
      [0, () => exports2.RepositoryCreationTemplate$]
    ];
    exports2.DeleteRepositoryPolicyRequest$ = [
      3,
      n032,
      _DRPRel,
      0,
      [_rN10, _rI],
      [0, 0],
      1
    ];
    exports2.DeleteRepositoryPolicyResponse$ = [
      3,
      n032,
      _DRPRele,
      0,
      [_rI, _rN10, _pT],
      [0, 0, 0]
    ];
    exports2.DeleteRepositoryRequest$ = [
      3,
      n032,
      _DRR,
      0,
      [_rN10, _rI, _fo],
      [0, 0, 2],
      1
    ];
    exports2.DeleteRepositoryResponse$ = [
      3,
      n032,
      _DRRe,
      0,
      [_re],
      [() => exports2.Repository$]
    ];
    exports2.DeleteSigningConfigurationRequest$ = [
      3,
      n032,
      _DSCR,
      0,
      [],
      []
    ];
    exports2.DeleteSigningConfigurationResponse$ = [
      3,
      n032,
      _DSCRe,
      0,
      [_rI, _sCi],
      [0, () => exports2.SigningConfiguration$]
    ];
    exports2.DeregisterPullTimeUpdateExclusionRequest$ = [
      3,
      n032,
      _DPTUER,
      0,
      [_pAr],
      [0],
      1
    ];
    exports2.DeregisterPullTimeUpdateExclusionResponse$ = [
      3,
      n032,
      _DPTUERe,
      0,
      [_pAr],
      [0]
    ];
    exports2.DescribeImageReplicationStatusRequest$ = [
      3,
      n032,
      _DIRSR,
      0,
      [_rN10, _iIm, _rI],
      [0, () => exports2.ImageIdentifier$, 0],
      2
    ];
    exports2.DescribeImageReplicationStatusResponse$ = [
      3,
      n032,
      _DIRSRe,
      0,
      [_rN10, _iIm, _rS],
      [0, () => exports2.ImageIdentifier$, () => ImageReplicationStatusList]
    ];
    exports2.DescribeImageScanFindingsRequest$ = [
      3,
      n032,
      _DISFR,
      0,
      [_rN10, _iIm, _rI, _nT, _mR],
      [0, () => exports2.ImageIdentifier$, 0, 0, 1],
      2
    ];
    exports2.DescribeImageScanFindingsResponse$ = [
      3,
      n032,
      _DISFRe,
      0,
      [_rI, _rN10, _iIm, _iSS, _iSF, _nT],
      [0, 0, () => exports2.ImageIdentifier$, () => exports2.ImageScanStatus$, () => exports2.ImageScanFindings$, 0]
    ];
    exports2.DescribeImagesFilter$ = [
      3,
      n032,
      _DIF,
      0,
      [_tS, _iS],
      [0, 0]
    ];
    exports2.DescribeImageSigningStatusRequest$ = [
      3,
      n032,
      _DISSR,
      0,
      [_rN10, _iIm, _rI],
      [0, () => exports2.ImageIdentifier$, 0],
      2
    ];
    exports2.DescribeImageSigningStatusResponse$ = [
      3,
      n032,
      _DISSRe,
      0,
      [_rN10, _iIm, _rI, _sSi],
      [0, () => exports2.ImageIdentifier$, 0, () => ImageSigningStatusList]
    ];
    exports2.DescribeImagesRequest$ = [
      3,
      n032,
      _DIR,
      0,
      [_rN10, _rI, _iI, _nT, _mR, _fi],
      [0, 0, () => ImageIdentifierList, 0, 1, () => exports2.DescribeImagesFilter$],
      1
    ];
    exports2.DescribeImagesResponse$ = [
      3,
      n032,
      _DIRe,
      0,
      [_iD, _nT],
      [() => ImageDetailList, 0]
    ];
    exports2.DescribePullThroughCacheRulesRequest$ = [
      3,
      n032,
      _DPTCRRes,
      0,
      [_rI, _eRPc, _nT, _mR],
      [0, 64 | 0, 0, 1]
    ];
    exports2.DescribePullThroughCacheRulesResponse$ = [
      3,
      n032,
      _DPTCRResc,
      0,
      [_pTCR, _nT],
      [() => PullThroughCacheRuleList, 0]
    ];
    exports2.DescribeRegistryRequest$ = [
      3,
      n032,
      _DRRes,
      0,
      [],
      []
    ];
    exports2.DescribeRegistryResponse$ = [
      3,
      n032,
      _DRResc,
      0,
      [_rI, _rC10],
      [0, () => exports2.ReplicationConfiguration$]
    ];
    exports2.DescribeRepositoriesRequest$ = [
      3,
      n032,
      _DRRescr,
      0,
      [_rI, _rNe, _nT, _mR],
      [0, 64 | 0, 0, 1]
    ];
    exports2.DescribeRepositoriesResponse$ = [
      3,
      n032,
      _DRRescri,
      0,
      [_rep, _nT],
      [() => RepositoryList, 0]
    ];
    exports2.DescribeRepositoryCreationTemplatesRequest$ = [
      3,
      n032,
      _DRCTRes,
      0,
      [_pre, _nT, _mR],
      [64 | 0, 0, 1]
    ];
    exports2.DescribeRepositoryCreationTemplatesResponse$ = [
      3,
      n032,
      _DRCTResc,
      0,
      [_rI, _rCTe, _nT],
      [0, () => RepositoryCreationTemplateList, 0]
    ];
    exports2.EncryptionConfiguration$ = [
      3,
      n032,
      _EC,
      0,
      [_eT, _kK],
      [0, 0],
      1
    ];
    exports2.EncryptionConfigurationForRepositoryCreationTemplate$ = [
      3,
      n032,
      _ECFRCT,
      0,
      [_eT, _kK],
      [0, 0],
      1
    ];
    exports2.EnhancedImageScanFinding$ = [
      3,
      n032,
      _EISF,
      0,
      [_aAI, _d, _fA, _fOA, _lOA, _pVD, _rem, _res, _sc4, _sD, _sev, _st, _ti, _ty, _uA, _fAi, _eAx],
      [0, 0, 0, 4, 4, () => exports2.PackageVulnerabilityDetails$, () => exports2.Remediation$, () => ResourceList, 1, () => exports2.ScoreDetails$, 0, 0, 0, 0, 4, 0, 0]
    ];
    exports2.GetAccountSettingRequest$ = [
      3,
      n032,
      _GASR,
      0,
      [_n],
      [0],
      1
    ];
    exports2.GetAccountSettingResponse$ = [
      3,
      n032,
      _GASRe,
      0,
      [_n, _v],
      [0, 0]
    ];
    exports2.GetAuthorizationTokenRequest$ = [
      3,
      n032,
      _GATR,
      0,
      [_rIe],
      [64 | 0]
    ];
    exports2.GetAuthorizationTokenResponse$ = [
      3,
      n032,
      _GATRe,
      0,
      [_aD],
      [() => AuthorizationDataList]
    ];
    exports2.GetDownloadUrlForLayerRequest$ = [
      3,
      n032,
      _GDUFLR,
      0,
      [_rN10, _lDa, _rI],
      [0, 0, 0],
      2
    ];
    exports2.GetDownloadUrlForLayerResponse$ = [
      3,
      n032,
      _GDUFLRe,
      0,
      [_dU, _lDa],
      [0, 0]
    ];
    exports2.GetLifecyclePolicyPreviewRequest$ = [
      3,
      n032,
      _GLPPR,
      0,
      [_rN10, _rI, _iI, _nT, _mR, _fi],
      [0, 0, () => ImageIdentifierList, 0, 1, () => exports2.LifecyclePolicyPreviewFilter$],
      1
    ];
    exports2.GetLifecyclePolicyPreviewResponse$ = [
      3,
      n032,
      _GLPPRe,
      0,
      [_rI, _rN10, _lPT, _st, _nT, _pR, _su],
      [0, 0, 0, 0, 0, () => LifecyclePolicyPreviewResultList, () => exports2.LifecyclePolicyPreviewSummary$]
    ];
    exports2.GetLifecyclePolicyRequest$ = [
      3,
      n032,
      _GLPR,
      0,
      [_rN10, _rI],
      [0, 0],
      1
    ];
    exports2.GetLifecyclePolicyResponse$ = [
      3,
      n032,
      _GLPRe,
      0,
      [_rI, _rN10, _lPT, _lEA],
      [0, 0, 0, 4]
    ];
    exports2.GetRegistryPolicyRequest$ = [
      3,
      n032,
      _GRPR,
      0,
      [],
      []
    ];
    exports2.GetRegistryPolicyResponse$ = [
      3,
      n032,
      _GRPRe,
      0,
      [_rI, _pT],
      [0, 0]
    ];
    exports2.GetRegistryScanningConfigurationRequest$ = [
      3,
      n032,
      _GRSCR,
      0,
      [],
      []
    ];
    exports2.GetRegistryScanningConfigurationResponse$ = [
      3,
      n032,
      _GRSCRe,
      0,
      [_rI, _sCc],
      [0, () => exports2.RegistryScanningConfiguration$]
    ];
    exports2.GetRepositoryPolicyRequest$ = [
      3,
      n032,
      _GRPRet,
      0,
      [_rN10, _rI],
      [0, 0],
      1
    ];
    exports2.GetRepositoryPolicyResponse$ = [
      3,
      n032,
      _GRPRete,
      0,
      [_rI, _rN10, _pT],
      [0, 0, 0]
    ];
    exports2.GetSigningConfigurationRequest$ = [
      3,
      n032,
      _GSCR,
      0,
      [],
      []
    ];
    exports2.GetSigningConfigurationResponse$ = [
      3,
      n032,
      _GSCRe,
      0,
      [_rI, _sCi],
      [0, () => exports2.SigningConfiguration$]
    ];
    exports2.Image$ = [
      3,
      n032,
      _I,
      0,
      [_rI, _rN10, _iIm, _iM, _iMMT],
      [0, 0, () => exports2.ImageIdentifier$, 0, 0]
    ];
    exports2.ImageDetail$ = [
      3,
      n032,
      _ID,
      0,
      [_rI, _rN10, _iDm, _iT13, _iSIB, _iPA, _iSS, _iSFS, _iMMT, _aMTr, _lRPT, _sMD, _iS, _lAA, _lAAa],
      [0, 0, 0, 64 | 0, 1, 4, () => exports2.ImageScanStatus$, () => exports2.ImageScanFindingsSummary$, 0, 0, 4, 0, 0, 4, 4]
    ];
    exports2.ImageFailure$ = [
      3,
      n032,
      _IF,
      0,
      [_iIm, _fC, _fR],
      [() => exports2.ImageIdentifier$, 0, 0]
    ];
    exports2.ImageIdentifier$ = [
      3,
      n032,
      _II2,
      0,
      [_iDm, _iTm],
      [0, 0]
    ];
    exports2.ImageReferrer$ = [
      3,
      n032,
      _IR,
      0,
      [_di, _mT, _si, _aTr, _an, _aS],
      [0, 0, 1, 0, 128 | 0, 0],
      3
    ];
    exports2.ImageReplicationStatus$ = [
      3,
      n032,
      _IRS,
      0,
      [_reg, _rI, _st, _fC],
      [0, 0, 0, 0]
    ];
    exports2.ImageScanFinding$ = [
      3,
      n032,
      _ISF,
      0,
      [_n, _d, _u, _sev, _at],
      [0, 0, 0, 0, () => AttributeList]
    ];
    exports2.ImageScanFindings$ = [
      3,
      n032,
      _ISFm,
      0,
      [_iSCA, _vSUA, _fSC, _fin, _eF],
      [4, 4, 128 | 1, () => ImageScanFindingList, () => EnhancedImageScanFindingList]
    ];
    exports2.ImageScanFindingsSummary$ = [
      3,
      n032,
      _ISFS,
      0,
      [_iSCA, _vSUA, _fSC],
      [4, 4, 128 | 1]
    ];
    exports2.ImageScanningConfiguration$ = [
      3,
      n032,
      _ISC,
      0,
      [_sOP],
      [2]
    ];
    exports2.ImageScanStatus$ = [
      3,
      n032,
      _ISS,
      0,
      [_st, _d],
      [0, 0]
    ];
    exports2.ImageSigningStatus$ = [
      3,
      n032,
      _ISSm,
      0,
      [_sPA, _fC, _fR, _st],
      [0, 0, 0, 0]
    ];
    exports2.ImageTagMutabilityExclusionFilter$ = [
      3,
      n032,
      _ITMEF,
      0,
      [_fT, _fi],
      [0, 0],
      2
    ];
    exports2.InitiateLayerUploadRequest$ = [
      3,
      n032,
      _ILUR,
      0,
      [_rN10, _rI],
      [0, 0],
      1
    ];
    exports2.InitiateLayerUploadResponse$ = [
      3,
      n032,
      _ILURn,
      0,
      [_uI, _pS],
      [0, 1]
    ];
    exports2.Layer$ = [
      3,
      n032,
      _L2,
      0,
      [_lDa, _lA, _lS, _mT],
      [0, 0, 1, 0]
    ];
    exports2.LayerFailure$ = [
      3,
      n032,
      _LF,
      0,
      [_lDa, _fC, _fR],
      [0, 0, 0]
    ];
    exports2.LifecyclePolicyPreviewFilter$ = [
      3,
      n032,
      _LPPF,
      0,
      [_tS],
      [0]
    ];
    exports2.LifecyclePolicyPreviewResult$ = [
      3,
      n032,
      _LPPR,
      0,
      [_iT13, _iDm, _iPA, _ac, _aRP, _sCt],
      [64 | 0, 0, 4, () => exports2.LifecyclePolicyRuleAction$, 1, 0]
    ];
    exports2.LifecyclePolicyPreviewSummary$ = [
      3,
      n032,
      _LPPS,
      0,
      [_eITC, _tITC],
      [1, () => TransitioningImageTotalCounts]
    ];
    exports2.LifecyclePolicyRuleAction$ = [
      3,
      n032,
      _LPRA,
      0,
      [_ty, _tSC],
      [0, 0]
    ];
    exports2.ListImageReferrersFilter$ = [
      3,
      n032,
      _LIRF,
      0,
      [_aTrt, _aS],
      [64 | 0, 0]
    ];
    exports2.ListImageReferrersRequest$ = [
      3,
      n032,
      _LIRR,
      0,
      [_rN10, _sI, _rI, _fi, _nT, _mR],
      [0, () => exports2.SubjectIdentifier$, 0, () => exports2.ListImageReferrersFilter$, 0, 1],
      2
    ];
    exports2.ListImageReferrersResponse$ = [
      3,
      n032,
      _LIRRi,
      0,
      [_ref, _nT],
      [() => ImageReferrerList, 0]
    ];
    exports2.ListImagesFilter$ = [
      3,
      n032,
      _LIF,
      0,
      [_tS, _iS],
      [0, 0]
    ];
    exports2.ListImagesRequest$ = [
      3,
      n032,
      _LIR,
      0,
      [_rN10, _rI, _nT, _mR, _fi],
      [0, 0, 0, 1, () => exports2.ListImagesFilter$],
      1
    ];
    exports2.ListImagesResponse$ = [
      3,
      n032,
      _LIRi,
      0,
      [_iI, _nT],
      [() => ImageIdentifierList, 0]
    ];
    exports2.ListPullTimeUpdateExclusionsRequest$ = [
      3,
      n032,
      _LPTUER,
      0,
      [_mR, _nT],
      [1, 0]
    ];
    exports2.ListPullTimeUpdateExclusionsResponse$ = [
      3,
      n032,
      _LPTUERi,
      0,
      [_pTUE, _nT],
      [64 | 0, 0]
    ];
    exports2.ListTagsForResourceRequest$ = [
      3,
      n032,
      _LTFRR,
      0,
      [_rA],
      [0],
      1
    ];
    exports2.ListTagsForResourceResponse$ = [
      3,
      n032,
      _LTFRRi,
      0,
      [_t],
      [() => TagList]
    ];
    exports2.PackageVulnerabilityDetails$ = [
      3,
      n032,
      _PVD,
      0,
      [_cv, _rU13, _rV, _so, _sU, _vCA, _vS, _vUA, _vI, _vP],
      [() => CvssScoreList, 64 | 0, 64 | 0, 0, 0, 4, 0, 4, 0, () => VulnerablePackagesList]
    ];
    exports2.PullThroughCacheRule$ = [
      3,
      n032,
      _PTCR,
      0,
      [_eRP, _uRU, _cAr, _rI, _cA, _cRA, _uRP, _uR, _uA],
      [0, 0, 4, 0, 0, 0, 0, 0, 4]
    ];
    exports2.PutAccountSettingRequest$ = [
      3,
      n032,
      _PASR,
      0,
      [_n, _v],
      [0, 0],
      2
    ];
    exports2.PutAccountSettingResponse$ = [
      3,
      n032,
      _PASRu,
      0,
      [_n, _v],
      [0, 0]
    ];
    exports2.PutImageRequest$ = [
      3,
      n032,
      _PIR,
      0,
      [_rN10, _iM, _rI, _iMMT, _iTm, _iDm],
      [0, 0, 0, 0, 0, 0],
      2
    ];
    exports2.PutImageResponse$ = [
      3,
      n032,
      _PIRu,
      0,
      [_im],
      [() => exports2.Image$]
    ];
    exports2.PutImageScanningConfigurationRequest$ = [
      3,
      n032,
      _PISCR,
      0,
      [_rN10, _iSC, _rI],
      [0, () => exports2.ImageScanningConfiguration$, 0],
      2
    ];
    exports2.PutImageScanningConfigurationResponse$ = [
      3,
      n032,
      _PISCRu,
      0,
      [_rI, _rN10, _iSC],
      [0, 0, () => exports2.ImageScanningConfiguration$]
    ];
    exports2.PutImageTagMutabilityRequest$ = [
      3,
      n032,
      _PITMR,
      0,
      [_rN10, _iTM, _rI, _iTMEF],
      [0, 0, 0, () => ImageTagMutabilityExclusionFilters],
      2
    ];
    exports2.PutImageTagMutabilityResponse$ = [
      3,
      n032,
      _PITMRu,
      0,
      [_rI, _rN10, _iTM, _iTMEF],
      [0, 0, 0, () => ImageTagMutabilityExclusionFilters]
    ];
    exports2.PutLifecyclePolicyRequest$ = [
      3,
      n032,
      _PLPR,
      0,
      [_rN10, _lPT, _rI],
      [0, 0, 0],
      2
    ];
    exports2.PutLifecyclePolicyResponse$ = [
      3,
      n032,
      _PLPRu,
      0,
      [_rI, _rN10, _lPT],
      [0, 0, 0]
    ];
    exports2.PutRegistryPolicyRequest$ = [
      3,
      n032,
      _PRPR,
      0,
      [_pT],
      [0],
      1
    ];
    exports2.PutRegistryPolicyResponse$ = [
      3,
      n032,
      _PRPRu,
      0,
      [_rI, _pT],
      [0, 0]
    ];
    exports2.PutRegistryScanningConfigurationRequest$ = [
      3,
      n032,
      _PRSCR,
      0,
      [_sT19, _ru],
      [0, () => RegistryScanningRuleList]
    ];
    exports2.PutRegistryScanningConfigurationResponse$ = [
      3,
      n032,
      _PRSCRu,
      0,
      [_rSC],
      [() => exports2.RegistryScanningConfiguration$]
    ];
    exports2.PutReplicationConfigurationRequest$ = [
      3,
      n032,
      _PRCR,
      0,
      [_rC10],
      [() => exports2.ReplicationConfiguration$],
      1
    ];
    exports2.PutReplicationConfigurationResponse$ = [
      3,
      n032,
      _PRCRu,
      0,
      [_rC10],
      [() => exports2.ReplicationConfiguration$]
    ];
    exports2.PutSigningConfigurationRequest$ = [
      3,
      n032,
      _PSCR,
      0,
      [_sCi],
      [() => exports2.SigningConfiguration$],
      1
    ];
    exports2.PutSigningConfigurationResponse$ = [
      3,
      n032,
      _PSCRu,
      0,
      [_sCi],
      [() => exports2.SigningConfiguration$]
    ];
    exports2.Recommendation$ = [
      3,
      n032,
      _R,
      0,
      [_ur, _te],
      [0, 0]
    ];
    exports2.RegisterPullTimeUpdateExclusionRequest$ = [
      3,
      n032,
      _RPTUER,
      0,
      [_pAr],
      [0],
      1
    ];
    exports2.RegisterPullTimeUpdateExclusionResponse$ = [
      3,
      n032,
      _RPTUERe,
      0,
      [_pAr, _cAr],
      [0, 4]
    ];
    exports2.RegistryScanningConfiguration$ = [
      3,
      n032,
      _RSC,
      0,
      [_sT19, _ru],
      [0, () => RegistryScanningRuleList]
    ];
    exports2.RegistryScanningRule$ = [
      3,
      n032,
      _RSR,
      0,
      [_sF, _rF],
      [0, () => ScanningRepositoryFilterList],
      2
    ];
    exports2.Remediation$ = [
      3,
      n032,
      _Re,
      0,
      [_rec],
      [() => exports2.Recommendation$]
    ];
    exports2.ReplicationConfiguration$ = [
      3,
      n032,
      _RC10,
      0,
      [_ru],
      [() => ReplicationRuleList],
      1
    ];
    exports2.ReplicationDestination$ = [
      3,
      n032,
      _RD,
      0,
      [_reg, _rI],
      [0, 0],
      2
    ];
    exports2.ReplicationRule$ = [
      3,
      n032,
      _RR,
      0,
      [_de, _rF],
      [() => ReplicationDestinationList, () => RepositoryFilterList],
      1
    ];
    exports2.Repository$ = [
      3,
      n032,
      _Rep,
      0,
      [_rAe, _rI, _rN10, _rUe, _cAr, _iTM, _iTMEF, _iSC, _eC],
      [0, 0, 0, 0, 4, 0, () => ImageTagMutabilityExclusionFilters, () => exports2.ImageScanningConfiguration$, () => exports2.EncryptionConfiguration$]
    ];
    exports2.RepositoryCreationTemplate$ = [
      3,
      n032,
      _RCT,
      0,
      [_pr, _d, _eC, _rT13, _iTM, _iTMEF, _rP, _lP, _aF, _cRA, _cAr, _uA],
      [0, 0, () => exports2.EncryptionConfigurationForRepositoryCreationTemplate$, () => TagList, 0, () => ImageTagMutabilityExclusionFilters, 0, 0, 64 | 0, 0, 4, 4]
    ];
    exports2.RepositoryFilter$ = [
      3,
      n032,
      _RF,
      0,
      [_fi, _fT],
      [0, 0],
      2
    ];
    exports2.RepositoryScanningConfiguration$ = [
      3,
      n032,
      _RSCe,
      0,
      [_rAe, _rN10, _sOP, _sF, _aSF],
      [0, 0, 2, 0, () => ScanningRepositoryFilterList]
    ];
    exports2.RepositoryScanningConfigurationFailure$ = [
      3,
      n032,
      _RSCF,
      0,
      [_rN10, _fC, _fR],
      [0, 0, 0]
    ];
    exports2.Resource$ = [
      3,
      n032,
      _Res,
      0,
      [_det, _id, _t, _ty],
      [() => exports2.ResourceDetails$, 0, 128 | 0, 0]
    ];
    exports2.ResourceDetails$ = [
      3,
      n032,
      _RDe,
      0,
      [_aECI],
      [() => exports2.AwsEcrContainerImageDetails$]
    ];
    exports2.ScanningRepositoryFilter$ = [
      3,
      n032,
      _SRF,
      0,
      [_fi, _fT],
      [0, 0],
      2
    ];
    exports2.ScoreDetails$ = [
      3,
      n032,
      _SD,
      0,
      [_cv],
      [() => exports2.CvssScoreDetails$]
    ];
    exports2.SetRepositoryPolicyRequest$ = [
      3,
      n032,
      _SRPR,
      0,
      [_rN10, _pT, _rI, _fo],
      [0, 0, 0, 2],
      2
    ];
    exports2.SetRepositoryPolicyResponse$ = [
      3,
      n032,
      _SRPRe,
      0,
      [_rI, _rN10, _pT],
      [0, 0, 0]
    ];
    exports2.SigningConfiguration$ = [
      3,
      n032,
      _SC,
      0,
      [_ru],
      [() => SigningRuleList],
      1
    ];
    exports2.SigningRepositoryFilter$ = [
      3,
      n032,
      _SRFi,
      0,
      [_fi, _fT],
      [0, 0],
      2
    ];
    exports2.SigningRule$ = [
      3,
      n032,
      _SR,
      0,
      [_sPA, _rF],
      [0, () => SigningRepositoryFilterList],
      1
    ];
    exports2.StartImageScanRequest$ = [
      3,
      n032,
      _SISR,
      0,
      [_rN10, _iIm, _rI],
      [0, () => exports2.ImageIdentifier$, 0],
      2
    ];
    exports2.StartImageScanResponse$ = [
      3,
      n032,
      _SISRt,
      0,
      [_rI, _rN10, _iIm, _iSS],
      [0, 0, () => exports2.ImageIdentifier$, () => exports2.ImageScanStatus$]
    ];
    exports2.StartLifecyclePolicyPreviewRequest$ = [
      3,
      n032,
      _SLPPR,
      0,
      [_rN10, _rI, _lPT],
      [0, 0, 0],
      1
    ];
    exports2.StartLifecyclePolicyPreviewResponse$ = [
      3,
      n032,
      _SLPPRt,
      0,
      [_rI, _rN10, _lPT, _st],
      [0, 0, 0, 0]
    ];
    exports2.SubjectIdentifier$ = [
      3,
      n032,
      _SI10,
      0,
      [_iDm],
      [0],
      1
    ];
    exports2.Tag$ = [
      3,
      n032,
      _T10,
      0,
      [_K10, _V10],
      [0, 0],
      2
    ];
    exports2.TagResourceRequest$ = [
      3,
      n032,
      _TRR,
      0,
      [_rA, _t],
      [0, () => TagList],
      2
    ];
    exports2.TagResourceResponse$ = [
      3,
      n032,
      _TRRa,
      0,
      [],
      []
    ];
    exports2.TransitioningImageTotalCount$ = [
      3,
      n032,
      _TITC,
      0,
      [_tSC, _iTC],
      [0, 1]
    ];
    exports2.UntagResourceRequest$ = [
      3,
      n032,
      _URR,
      0,
      [_rA, _tK],
      [0, 64 | 0],
      2
    ];
    exports2.UntagResourceResponse$ = [
      3,
      n032,
      _URRn,
      0,
      [],
      []
    ];
    exports2.UpdateImageStorageClassRequest$ = [
      3,
      n032,
      _UISCR,
      0,
      [_rN10, _iIm, _tSC, _rI],
      [0, () => exports2.ImageIdentifier$, 0, 0],
      3
    ];
    exports2.UpdateImageStorageClassResponse$ = [
      3,
      n032,
      _UISCRp,
      0,
      [_rI, _rN10, _iIm, _iS],
      [0, 0, () => exports2.ImageIdentifier$, 0]
    ];
    exports2.UpdatePullThroughCacheRuleRequest$ = [
      3,
      n032,
      _UPTCRR,
      0,
      [_eRP, _rI, _cA, _cRA],
      [0, 0, 0, 0],
      1
    ];
    exports2.UpdatePullThroughCacheRuleResponse$ = [
      3,
      n032,
      _UPTCRRp,
      0,
      [_eRP, _rI, _uA, _cA, _cRA, _uRP],
      [0, 0, 4, 0, 0, 0]
    ];
    exports2.UpdateRepositoryCreationTemplateRequest$ = [
      3,
      n032,
      _URCTR,
      0,
      [_pr, _d, _eC, _rT13, _iTM, _iTMEF, _rP, _lP, _aF, _cRA],
      [0, 0, () => exports2.EncryptionConfigurationForRepositoryCreationTemplate$, () => TagList, 0, () => ImageTagMutabilityExclusionFilters, 0, 0, 64 | 0, 0],
      1
    ];
    exports2.UpdateRepositoryCreationTemplateResponse$ = [
      3,
      n032,
      _URCTRp,
      0,
      [_rI, _rCT],
      [0, () => exports2.RepositoryCreationTemplate$]
    ];
    exports2.UploadLayerPartRequest$ = [
      3,
      n032,
      _ULPR,
      0,
      [_rN10, _uI, _pFB, _pLB, _lPB, _rI],
      [0, 0, 1, 1, 21, 0],
      5
    ];
    exports2.UploadLayerPartResponse$ = [
      3,
      n032,
      _ULPRp,
      0,
      [_rI, _rN10, _uI, _lBR],
      [0, 0, 0, 1]
    ];
    exports2.ValidatePullThroughCacheRuleRequest$ = [
      3,
      n032,
      _VPTCRR,
      0,
      [_eRP, _rI],
      [0, 0],
      1
    ];
    exports2.ValidatePullThroughCacheRuleResponse$ = [
      3,
      n032,
      _VPTCRRa,
      0,
      [_eRP, _rI, _uRU, _cA, _cRA, _uRP, _iV, _fa],
      [0, 0, 0, 0, 0, 0, 2, 0]
    ];
    exports2.VulnerablePackage$ = [
      3,
      n032,
      _VP,
      0,
      [_ar, _ep, _fP, _n, _pM, _rel, _sLH, _ve, _fIV],
      [0, 1, 0, 0, 0, 0, 0, 0, 0]
    ];
    var ArtifactTypeList = 64 | 0;
    var AttributeList = [
      1,
      n032,
      _AL,
      0,
      () => exports2.Attribute$
    ];
    var AuthorizationDataList = [
      1,
      n032,
      _ADL,
      0,
      () => exports2.AuthorizationData$
    ];
    var BatchedOperationLayerDigestList = 64 | 0;
    var CvssScoreAdjustmentList = [
      1,
      n032,
      _CSAL,
      0,
      () => exports2.CvssScoreAdjustment$
    ];
    var CvssScoreList = [
      1,
      n032,
      _CSL,
      0,
      () => exports2.CvssScore$
    ];
    var EnhancedImageScanFindingList = [
      1,
      n032,
      _EISFL,
      0,
      () => exports2.EnhancedImageScanFinding$
    ];
    var GetAuthorizationTokenRegistryIdList = 64 | 0;
    var ImageDetailList = [
      1,
      n032,
      _IDL,
      0,
      () => exports2.ImageDetail$
    ];
    var ImageFailureList = [
      1,
      n032,
      _IFL,
      0,
      () => exports2.ImageFailure$
    ];
    var ImageIdentifierList = [
      1,
      n032,
      _IIL,
      0,
      () => exports2.ImageIdentifier$
    ];
    var ImageList = [
      1,
      n032,
      _IL,
      0,
      () => exports2.Image$
    ];
    var ImageReferrerList = [
      1,
      n032,
      _IRL,
      0,
      () => exports2.ImageReferrer$
    ];
    var ImageReplicationStatusList = [
      1,
      n032,
      _IRSL,
      0,
      () => exports2.ImageReplicationStatus$
    ];
    var ImageScanFindingList = [
      1,
      n032,
      _ISFL,
      0,
      () => exports2.ImageScanFinding$
    ];
    var ImageSigningStatusList = [
      1,
      n032,
      _ISSL,
      0,
      () => exports2.ImageSigningStatus$
    ];
    var ImageTagList = 64 | 0;
    var ImageTagMutabilityExclusionFilters = [
      1,
      n032,
      _ITMEFm,
      0,
      () => exports2.ImageTagMutabilityExclusionFilter$
    ];
    var ImageTagsList = 64 | 0;
    var LayerDigestList = 64 | 0;
    var LayerFailureList = [
      1,
      n032,
      _LFL,
      0,
      () => exports2.LayerFailure$
    ];
    var LayerList = [
      1,
      n032,
      _LL,
      0,
      () => exports2.Layer$
    ];
    var LifecyclePolicyPreviewResultList = [
      1,
      n032,
      _LPPRL,
      0,
      () => exports2.LifecyclePolicyPreviewResult$
    ];
    var MediaTypeList = 64 | 0;
    var PrefixList = 64 | 0;
    var PullThroughCacheRuleList = [
      1,
      n032,
      _PTCRL,
      0,
      () => exports2.PullThroughCacheRule$
    ];
    var PullThroughCacheRuleRepositoryPrefixList = 64 | 0;
    var PullTimeUpdateExclusionList = 64 | 0;
    var RCTAppliedForList = 64 | 0;
    var ReferenceUrlsList = 64 | 0;
    var RegistryScanningRuleList = [
      1,
      n032,
      _RSRL,
      0,
      () => exports2.RegistryScanningRule$
    ];
    var RelatedVulnerabilitiesList = 64 | 0;
    var ReplicationDestinationList = [
      1,
      n032,
      _RDL,
      0,
      () => exports2.ReplicationDestination$
    ];
    var ReplicationRuleList = [
      1,
      n032,
      _RRL,
      0,
      () => exports2.ReplicationRule$
    ];
    var RepositoryCreationTemplateList = [
      1,
      n032,
      _RCTL,
      0,
      () => exports2.RepositoryCreationTemplate$
    ];
    var RepositoryFilterList = [
      1,
      n032,
      _RFL,
      0,
      () => exports2.RepositoryFilter$
    ];
    var RepositoryList = [
      1,
      n032,
      _RL,
      0,
      () => exports2.Repository$
    ];
    var RepositoryNameList = 64 | 0;
    var RepositoryScanningConfigurationFailureList = [
      1,
      n032,
      _RSCFL,
      0,
      () => exports2.RepositoryScanningConfigurationFailure$
    ];
    var RepositoryScanningConfigurationList = [
      1,
      n032,
      _RSCL,
      0,
      () => exports2.RepositoryScanningConfiguration$
    ];
    var ResourceList = [
      1,
      n032,
      _RLe,
      0,
      () => exports2.Resource$
    ];
    var ScanningConfigurationRepositoryNameList = 64 | 0;
    var ScanningRepositoryFilterList = [
      1,
      n032,
      _SRFL,
      0,
      () => exports2.ScanningRepositoryFilter$
    ];
    var SigningRepositoryFilterList = [
      1,
      n032,
      _SRFLi,
      0,
      () => exports2.SigningRepositoryFilter$
    ];
    var SigningRuleList = [
      1,
      n032,
      _SRL,
      0,
      () => exports2.SigningRule$
    ];
    var TagKeyList = 64 | 0;
    var TagList = [
      1,
      n032,
      _TL,
      0,
      () => exports2.Tag$
    ];
    var TransitioningImageTotalCounts = [
      1,
      n032,
      _TITCr,
      0,
      () => exports2.TransitioningImageTotalCount$
    ];
    var VulnerablePackagesList = [
      1,
      n032,
      _VPL,
      0,
      () => exports2.VulnerablePackage$
    ];
    var Annotations = 128 | 0;
    var FindingSeverityCounts = 128 | 1;
    var Tags = 128 | 0;
    exports2.BatchCheckLayerAvailability$ = [
      9,
      n032,
      _BCLA,
      0,
      () => exports2.BatchCheckLayerAvailabilityRequest$,
      () => exports2.BatchCheckLayerAvailabilityResponse$
    ];
    exports2.BatchDeleteImage$ = [
      9,
      n032,
      _BDI,
      0,
      () => exports2.BatchDeleteImageRequest$,
      () => exports2.BatchDeleteImageResponse$
    ];
    exports2.BatchGetImage$ = [
      9,
      n032,
      _BGI,
      0,
      () => exports2.BatchGetImageRequest$,
      () => exports2.BatchGetImageResponse$
    ];
    exports2.BatchGetRepositoryScanningConfiguration$ = [
      9,
      n032,
      _BGRSC,
      0,
      () => exports2.BatchGetRepositoryScanningConfigurationRequest$,
      () => exports2.BatchGetRepositoryScanningConfigurationResponse$
    ];
    exports2.CompleteLayerUpload$ = [
      9,
      n032,
      _CLU,
      0,
      () => exports2.CompleteLayerUploadRequest$,
      () => exports2.CompleteLayerUploadResponse$
    ];
    exports2.CreatePullThroughCacheRule$ = [
      9,
      n032,
      _CPTCR,
      0,
      () => exports2.CreatePullThroughCacheRuleRequest$,
      () => exports2.CreatePullThroughCacheRuleResponse$
    ];
    exports2.CreateRepository$ = [
      9,
      n032,
      _CR,
      0,
      () => exports2.CreateRepositoryRequest$,
      () => exports2.CreateRepositoryResponse$
    ];
    exports2.CreateRepositoryCreationTemplate$ = [
      9,
      n032,
      _CRCT,
      0,
      () => exports2.CreateRepositoryCreationTemplateRequest$,
      () => exports2.CreateRepositoryCreationTemplateResponse$
    ];
    exports2.DeleteLifecyclePolicy$ = [
      9,
      n032,
      _DLP,
      0,
      () => exports2.DeleteLifecyclePolicyRequest$,
      () => exports2.DeleteLifecyclePolicyResponse$
    ];
    exports2.DeletePullThroughCacheRule$ = [
      9,
      n032,
      _DPTCR,
      0,
      () => exports2.DeletePullThroughCacheRuleRequest$,
      () => exports2.DeletePullThroughCacheRuleResponse$
    ];
    exports2.DeleteRegistryPolicy$ = [
      9,
      n032,
      _DRP,
      0,
      () => exports2.DeleteRegistryPolicyRequest$,
      () => exports2.DeleteRegistryPolicyResponse$
    ];
    exports2.DeleteRepository$ = [
      9,
      n032,
      _DR,
      0,
      () => exports2.DeleteRepositoryRequest$,
      () => exports2.DeleteRepositoryResponse$
    ];
    exports2.DeleteRepositoryCreationTemplate$ = [
      9,
      n032,
      _DRCT,
      0,
      () => exports2.DeleteRepositoryCreationTemplateRequest$,
      () => exports2.DeleteRepositoryCreationTemplateResponse$
    ];
    exports2.DeleteRepositoryPolicy$ = [
      9,
      n032,
      _DRPe,
      0,
      () => exports2.DeleteRepositoryPolicyRequest$,
      () => exports2.DeleteRepositoryPolicyResponse$
    ];
    exports2.DeleteSigningConfiguration$ = [
      9,
      n032,
      _DSC,
      0,
      () => exports2.DeleteSigningConfigurationRequest$,
      () => exports2.DeleteSigningConfigurationResponse$
    ];
    exports2.DeregisterPullTimeUpdateExclusion$ = [
      9,
      n032,
      _DPTUE,
      0,
      () => exports2.DeregisterPullTimeUpdateExclusionRequest$,
      () => exports2.DeregisterPullTimeUpdateExclusionResponse$
    ];
    exports2.DescribeImageReplicationStatus$ = [
      9,
      n032,
      _DIRS,
      0,
      () => exports2.DescribeImageReplicationStatusRequest$,
      () => exports2.DescribeImageReplicationStatusResponse$
    ];
    exports2.DescribeImages$ = [
      9,
      n032,
      _DI,
      0,
      () => exports2.DescribeImagesRequest$,
      () => exports2.DescribeImagesResponse$
    ];
    exports2.DescribeImageScanFindings$ = [
      9,
      n032,
      _DISF,
      0,
      () => exports2.DescribeImageScanFindingsRequest$,
      () => exports2.DescribeImageScanFindingsResponse$
    ];
    exports2.DescribeImageSigningStatus$ = [
      9,
      n032,
      _DISS,
      0,
      () => exports2.DescribeImageSigningStatusRequest$,
      () => exports2.DescribeImageSigningStatusResponse$
    ];
    exports2.DescribePullThroughCacheRules$ = [
      9,
      n032,
      _DPTCRe,
      0,
      () => exports2.DescribePullThroughCacheRulesRequest$,
      () => exports2.DescribePullThroughCacheRulesResponse$
    ];
    exports2.DescribeRegistry$ = [
      9,
      n032,
      _DRe,
      0,
      () => exports2.DescribeRegistryRequest$,
      () => exports2.DescribeRegistryResponse$
    ];
    exports2.DescribeRepositories$ = [
      9,
      n032,
      _DRes,
      0,
      () => exports2.DescribeRepositoriesRequest$,
      () => exports2.DescribeRepositoriesResponse$
    ];
    exports2.DescribeRepositoryCreationTemplates$ = [
      9,
      n032,
      _DRCTe,
      0,
      () => exports2.DescribeRepositoryCreationTemplatesRequest$,
      () => exports2.DescribeRepositoryCreationTemplatesResponse$
    ];
    exports2.GetAccountSetting$ = [
      9,
      n032,
      _GAS,
      0,
      () => exports2.GetAccountSettingRequest$,
      () => exports2.GetAccountSettingResponse$
    ];
    exports2.GetAuthorizationToken$ = [
      9,
      n032,
      _GAT,
      0,
      () => exports2.GetAuthorizationTokenRequest$,
      () => exports2.GetAuthorizationTokenResponse$
    ];
    exports2.GetDownloadUrlForLayer$ = [
      9,
      n032,
      _GDUFL,
      0,
      () => exports2.GetDownloadUrlForLayerRequest$,
      () => exports2.GetDownloadUrlForLayerResponse$
    ];
    exports2.GetLifecyclePolicy$ = [
      9,
      n032,
      _GLP,
      0,
      () => exports2.GetLifecyclePolicyRequest$,
      () => exports2.GetLifecyclePolicyResponse$
    ];
    exports2.GetLifecyclePolicyPreview$ = [
      9,
      n032,
      _GLPP,
      0,
      () => exports2.GetLifecyclePolicyPreviewRequest$,
      () => exports2.GetLifecyclePolicyPreviewResponse$
    ];
    exports2.GetRegistryPolicy$ = [
      9,
      n032,
      _GRP,
      0,
      () => exports2.GetRegistryPolicyRequest$,
      () => exports2.GetRegistryPolicyResponse$
    ];
    exports2.GetRegistryScanningConfiguration$ = [
      9,
      n032,
      _GRSC,
      0,
      () => exports2.GetRegistryScanningConfigurationRequest$,
      () => exports2.GetRegistryScanningConfigurationResponse$
    ];
    exports2.GetRepositoryPolicy$ = [
      9,
      n032,
      _GRPe,
      0,
      () => exports2.GetRepositoryPolicyRequest$,
      () => exports2.GetRepositoryPolicyResponse$
    ];
    exports2.GetSigningConfiguration$ = [
      9,
      n032,
      _GSC,
      0,
      () => exports2.GetSigningConfigurationRequest$,
      () => exports2.GetSigningConfigurationResponse$
    ];
    exports2.InitiateLayerUpload$ = [
      9,
      n032,
      _ILU,
      0,
      () => exports2.InitiateLayerUploadRequest$,
      () => exports2.InitiateLayerUploadResponse$
    ];
    exports2.ListImageReferrers$ = [
      9,
      n032,
      _LIRis,
      0,
      () => exports2.ListImageReferrersRequest$,
      () => exports2.ListImageReferrersResponse$
    ];
    exports2.ListImages$ = [
      9,
      n032,
      _LI,
      0,
      () => exports2.ListImagesRequest$,
      () => exports2.ListImagesResponse$
    ];
    exports2.ListPullTimeUpdateExclusions$ = [
      9,
      n032,
      _LPTUE,
      0,
      () => exports2.ListPullTimeUpdateExclusionsRequest$,
      () => exports2.ListPullTimeUpdateExclusionsResponse$
    ];
    exports2.ListTagsForResource$ = [
      9,
      n032,
      _LTFR,
      0,
      () => exports2.ListTagsForResourceRequest$,
      () => exports2.ListTagsForResourceResponse$
    ];
    exports2.PutAccountSetting$ = [
      9,
      n032,
      _PAS,
      0,
      () => exports2.PutAccountSettingRequest$,
      () => exports2.PutAccountSettingResponse$
    ];
    exports2.PutImage$ = [
      9,
      n032,
      _PI10,
      0,
      () => exports2.PutImageRequest$,
      () => exports2.PutImageResponse$
    ];
    exports2.PutImageScanningConfiguration$ = [
      9,
      n032,
      _PISC,
      0,
      () => exports2.PutImageScanningConfigurationRequest$,
      () => exports2.PutImageScanningConfigurationResponse$
    ];
    exports2.PutImageTagMutability$ = [
      9,
      n032,
      _PITM,
      0,
      () => exports2.PutImageTagMutabilityRequest$,
      () => exports2.PutImageTagMutabilityResponse$
    ];
    exports2.PutLifecyclePolicy$ = [
      9,
      n032,
      _PLP,
      0,
      () => exports2.PutLifecyclePolicyRequest$,
      () => exports2.PutLifecyclePolicyResponse$
    ];
    exports2.PutRegistryPolicy$ = [
      9,
      n032,
      _PRP,
      0,
      () => exports2.PutRegistryPolicyRequest$,
      () => exports2.PutRegistryPolicyResponse$
    ];
    exports2.PutRegistryScanningConfiguration$ = [
      9,
      n032,
      _PRSC,
      0,
      () => exports2.PutRegistryScanningConfigurationRequest$,
      () => exports2.PutRegistryScanningConfigurationResponse$
    ];
    exports2.PutReplicationConfiguration$ = [
      9,
      n032,
      _PRC,
      0,
      () => exports2.PutReplicationConfigurationRequest$,
      () => exports2.PutReplicationConfigurationResponse$
    ];
    exports2.PutSigningConfiguration$ = [
      9,
      n032,
      _PSC,
      0,
      () => exports2.PutSigningConfigurationRequest$,
      () => exports2.PutSigningConfigurationResponse$
    ];
    exports2.RegisterPullTimeUpdateExclusion$ = [
      9,
      n032,
      _RPTUE,
      0,
      () => exports2.RegisterPullTimeUpdateExclusionRequest$,
      () => exports2.RegisterPullTimeUpdateExclusionResponse$
    ];
    exports2.SetRepositoryPolicy$ = [
      9,
      n032,
      _SRP,
      0,
      () => exports2.SetRepositoryPolicyRequest$,
      () => exports2.SetRepositoryPolicyResponse$
    ];
    exports2.StartImageScan$ = [
      9,
      n032,
      _SIS,
      0,
      () => exports2.StartImageScanRequest$,
      () => exports2.StartImageScanResponse$
    ];
    exports2.StartLifecyclePolicyPreview$ = [
      9,
      n032,
      _SLPP,
      0,
      () => exports2.StartLifecyclePolicyPreviewRequest$,
      () => exports2.StartLifecyclePolicyPreviewResponse$
    ];
    exports2.TagResource$ = [
      9,
      n032,
      _TR,
      0,
      () => exports2.TagResourceRequest$,
      () => exports2.TagResourceResponse$
    ];
    exports2.UntagResource$ = [
      9,
      n032,
      _UR,
      0,
      () => exports2.UntagResourceRequest$,
      () => exports2.UntagResourceResponse$
    ];
    exports2.UpdateImageStorageClass$ = [
      9,
      n032,
      _UISC,
      0,
      () => exports2.UpdateImageStorageClassRequest$,
      () => exports2.UpdateImageStorageClassResponse$
    ];
    exports2.UpdatePullThroughCacheRule$ = [
      9,
      n032,
      _UPTCR,
      0,
      () => exports2.UpdatePullThroughCacheRuleRequest$,
      () => exports2.UpdatePullThroughCacheRuleResponse$
    ];
    exports2.UpdateRepositoryCreationTemplate$ = [
      9,
      n032,
      _URCT,
      0,
      () => exports2.UpdateRepositoryCreationTemplateRequest$,
      () => exports2.UpdateRepositoryCreationTemplateResponse$
    ];
    exports2.UploadLayerPart$ = [
      9,
      n032,
      _ULP,
      0,
      () => exports2.UploadLayerPartRequest$,
      () => exports2.UploadLayerPartResponse$
    ];
    exports2.ValidatePullThroughCacheRule$ = [
      9,
      n032,
      _VPTCR,
      0,
      () => exports2.ValidatePullThroughCacheRuleRequest$,
      () => exports2.ValidatePullThroughCacheRuleResponse$
    ];
  }
});

// ../../node_modules/@aws-sdk/client-ecr/dist-cjs/runtimeConfig.shared.js
var require_runtimeConfig_shared = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/dist-cjs/runtimeConfig.shared.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes2(), __toCommonJS(httpAuthSchemes_exports));
    var protocols_1 = (init_protocols4(), __toCommonJS(protocols_exports2));
    var smithy_client_1 = require_dist_cjs34();
    var url_parser_1 = require_dist_cjs18();
    var util_base64_1 = require_dist_cjs10();
    var util_utf8_1 = require_dist_cjs9();
    var httpAuthSchemeProvider_1 = require_httpAuthSchemeProvider();
    var endpointResolver_1 = require_endpointResolver();
    var schemas_0_1 = require_schemas_0();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2015-09-21",
        base64Decoder: config2?.base64Decoder ?? util_base64_1.fromBase64,
        base64Encoder: config2?.base64Encoder ?? util_base64_1.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? endpointResolver_1.defaultEndpointResolver,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? httpAuthSchemeProvider_1.defaultECRHttpAuthSchemeProvider,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new httpAuthSchemes_1.AwsSdkSigV4Signer()
          }
        ],
        logger: config2?.logger ?? new smithy_client_1.NoOpLogger(),
        protocol: config2?.protocol ?? protocols_1.AwsJson1_1Protocol,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.ecr",
          errorTypeRegistries: schemas_0_1.errorTypeRegistries,
          xmlNamespace: "http://ecr.amazonaws.com/doc/2015-09-21/",
          version: "2015-09-21",
          serviceTarget: "AmazonEC2ContainerRegistry_V20150921"
        },
        serviceId: config2?.serviceId ?? "ECR",
        urlParser: config2?.urlParser ?? url_parser_1.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? util_utf8_1.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? util_utf8_1.toUtf8
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/dist-cjs/runtimeConfig.js
var require_runtimeConfig = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/dist-cjs/runtimeConfig.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var package_json_1 = tslib_1.__importDefault(require_package());
    var client_1 = (init_client2(), __toCommonJS(client_exports));
    var httpAuthSchemes_1 = (init_httpAuthSchemes2(), __toCommonJS(httpAuthSchemes_exports));
    var credential_provider_node_1 = require_dist_cjs59();
    var util_user_agent_node_1 = require_dist_cjs50();
    var config_resolver_1 = require_dist_cjs25();
    var hash_node_1 = require_dist_cjs44();
    var middleware_retry_1 = require_dist_cjs35();
    var node_config_provider_1 = require_dist_cjs29();
    var node_http_handler_1 = require_dist_cjs13();
    var smithy_client_1 = require_dist_cjs34();
    var util_body_length_node_1 = require_dist_cjs45();
    var util_defaults_mode_node_1 = require_dist_cjs46();
    var util_retry_1 = require_dist_cjs22();
    var runtimeConfig_shared_1 = require_runtimeConfig_shared();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      (0, smithy_client_1.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, util_defaults_mode_node_1.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(smithy_client_1.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = (0, runtimeConfig_shared_1.getRuntimeConfig)(config2);
      (0, client_1.emitWarningIfUnsupportedVersion)(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, node_config_provider_1.loadConfig)(httpAuthSchemes_1.NODE_AUTH_SCHEME_PREFERENCE_OPTIONS, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? util_body_length_node_1.calculateBodyLength,
        credentialDefaultProvider: config2?.credentialDefaultProvider ?? credential_provider_node_1.defaultProvider,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, util_user_agent_node_1.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_json_1.default.version }),
        maxAttempts: config2?.maxAttempts ?? (0, node_config_provider_1.loadConfig)(middleware_retry_1.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_REGION_CONFIG_OPTIONS, { ...config_resolver_1.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: node_http_handler_1.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, node_config_provider_1.loadConfig)({
          ...middleware_retry_1.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || util_retry_1.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? hash_node_1.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? node_http_handler_1.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, node_config_provider_1.loadConfig)(util_user_agent_node_1.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-waiter/dist-cjs/index.js
var require_dist_cjs60 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/node_modules/@smithy/util-waiter/dist-cjs/index.js"(exports2) {
    "use strict";
    var getCircularReplacer3 = /* @__PURE__ */ __name(() => {
      const seen = /* @__PURE__ */ new WeakSet();
      return (key, value) => {
        if (typeof value === "object" && value !== null) {
          if (seen.has(value)) {
            return "[Circular]";
          }
          seen.add(value);
        }
        return value;
      };
    }, "getCircularReplacer");
    var sleep4 = /* @__PURE__ */ __name((seconds) => {
      return new Promise((resolve13) => setTimeout(resolve13, seconds * 1e3));
    }, "sleep");
    var waiterServiceDefaults3 = {
      minDelay: 2,
      maxDelay: 120
    };
    exports2.WaiterState = void 0;
    (function(WaiterState3) {
      WaiterState3["ABORTED"] = "ABORTED";
      WaiterState3["FAILURE"] = "FAILURE";
      WaiterState3["SUCCESS"] = "SUCCESS";
      WaiterState3["RETRY"] = "RETRY";
      WaiterState3["TIMEOUT"] = "TIMEOUT";
    })(exports2.WaiterState || (exports2.WaiterState = {}));
    var checkExceptions3 = /* @__PURE__ */ __name((result2) => {
      if (result2.state === exports2.WaiterState.ABORTED) {
        const abortError = new Error(`${JSON.stringify({
          ...result2,
          reason: "Request was aborted"
        }, getCircularReplacer3())}`);
        abortError.name = "AbortError";
        throw abortError;
      } else if (result2.state === exports2.WaiterState.TIMEOUT) {
        const timeoutError = new Error(`${JSON.stringify({
          ...result2,
          reason: "Waiter has timed out"
        }, getCircularReplacer3())}`);
        timeoutError.name = "TimeoutError";
        throw timeoutError;
      } else if (result2.state !== exports2.WaiterState.SUCCESS) {
        throw new Error(`${JSON.stringify(result2, getCircularReplacer3())}`);
      }
      return result2;
    }, "checkExceptions");
    var runPolling3 = /* @__PURE__ */ __name(async ({ minDelay, maxDelay, maxWaitTime, abortController, client, abortSignal }, input, acceptorChecks) => {
      const observedResponses = {};
      const [minDelayMs, maxDelayMs] = [minDelay * 1e3, maxDelay * 1e3];
      let currentAttempt = 0;
      const waitUntil = Date.now() + maxWaitTime * 1e3;
      const warn403Time = Date.now() + 6e4;
      let didWarn403 = false;
      while (true) {
        if (currentAttempt > 0) {
          const delayMs = exponentialBackoffWithJitter3(minDelayMs, maxDelayMs, currentAttempt, waitUntil);
          if (abortController?.signal?.aborted || abortSignal?.aborted) {
            const message2 = "AbortController signal aborted.";
            observedResponses[message2] |= 0;
            observedResponses[message2] += 1;
            return { state: exports2.WaiterState.ABORTED, observedResponses };
          }
          if (Date.now() + delayMs > waitUntil) {
            return { state: exports2.WaiterState.TIMEOUT, observedResponses };
          }
          await sleep4(delayMs / 1e3);
        }
        const { state: state13, reason } = await acceptorChecks(client, input);
        if (reason) {
          const message2 = createMessageFromResponse3(reason);
          observedResponses[message2] |= 0;
          observedResponses[message2] += 1;
        }
        if (state13 !== exports2.WaiterState.RETRY) {
          return { state: state13, reason, final: reason, observedResponses };
        }
        currentAttempt += 1;
        if (!didWarn403 && Date.now() >= warn403Time) {
          checkWarn4033(observedResponses, client);
          didWarn403 = true;
        }
      }
    }, "runPolling");
    var checkWarn4033 = /* @__PURE__ */ __name((observedResponses = {}, client) => {
      const orderedErrors = Object.keys(observedResponses);
      let count403 = 0;
      for (const response of orderedErrors) {
        const n10 = observedResponses[response] | 0;
        if (response.startsWith("403:")) {
          count403 += n10;
        }
      }
      const clientLogger = client?.config?.logger;
      const warningLogger = typeof clientLogger?.warn === "function" && !clientLogger.constructor?.name?.includes?.("NoOpLogger") ? clientLogger : console;
      if (count403 >= 3 || orderedErrors[orderedErrors.length - 1].startsWith("403:")) {
        warningLogger.warn(`@smithy/util-waiter WARN - 403 status code encountered during waiter polling.`);
      }
    }, "checkWarn403");
    var createMessageFromResponse3 = /* @__PURE__ */ __name((reason) => {
      const status = reason?.$response?.statusCode ?? reason?.$metadata?.httpStatusCode;
      if (reason?.$responseBodyText) {
        return `${status ? status + ": " : ""}Deserialization error for body: ${reason.$responseBodyText}`;
      }
      if (status) {
        if (reason?.$response || reason?.message) {
          return `${status ?? "Unknown"}: ${reason?.message}`;
        }
        return `${status}: OK`;
      }
      return String(reason?.message ?? JSON.stringify(reason, getCircularReplacer3()) ?? "Unknown");
    }, "createMessageFromResponse");
    var exponentialBackoffWithJitter3 = /* @__PURE__ */ __name((minDelayMs, maxDelayMs, attempt, waitUntil) => {
      const attemptCountCeiling = Math.log(maxDelayMs / minDelayMs) / Math.log(2) + 1;
      if (attempt > attemptCountCeiling) {
        return maxDelayMs;
      }
      const delay = minDelayMs * 2 ** (attempt - 1);
      const capped = Math.min(delay, maxDelayMs);
      const waitFor2 = randomInRange3(minDelayMs, capped);
      if (Date.now() + waitFor2 > waitUntil) {
        const timeRemaining = waitUntil - Date.now();
        return Math.max(0, timeRemaining - 500);
      }
      return waitFor2;
    }, "exponentialBackoffWithJitter");
    var randomInRange3 = /* @__PURE__ */ __name((min, max) => min + Math.random() * (max - min), "randomInRange");
    var validateWaiterOptions3 = /* @__PURE__ */ __name((options) => {
      if (options.maxWaitTime <= 0) {
        throw new Error(`WaiterConfiguration.maxWaitTime must be greater than 0`);
      } else if (options.minDelay <= 0) {
        throw new Error(`WaiterConfiguration.minDelay must be greater than 0`);
      } else if (options.maxDelay <= 0) {
        throw new Error(`WaiterConfiguration.maxDelay must be greater than 0`);
      } else if (options.maxWaitTime <= options.minDelay) {
        throw new Error(`WaiterConfiguration.maxWaitTime [${options.maxWaitTime}] must be greater than WaiterConfiguration.minDelay [${options.minDelay}] for this waiter`);
      } else if (options.maxDelay < options.minDelay) {
        throw new Error(`WaiterConfiguration.maxDelay [${options.maxDelay}] must be greater than WaiterConfiguration.minDelay [${options.minDelay}] for this waiter`);
      }
    }, "validateWaiterOptions");
    var abortTimeout3 = /* @__PURE__ */ __name((abortSignal) => {
      let onAbort;
      const promise = new Promise((resolve13) => {
        onAbort = /* @__PURE__ */ __name(() => resolve13({ state: exports2.WaiterState.ABORTED }), "onAbort");
        if (typeof abortSignal.addEventListener === "function") {
          abortSignal.addEventListener("abort", onAbort);
        } else {
          abortSignal.onabort = onAbort;
        }
      });
      return {
        clearListener() {
          if (typeof abortSignal.removeEventListener === "function") {
            abortSignal.removeEventListener("abort", onAbort);
          }
        },
        aborted: promise
      };
    }, "abortTimeout");
    var createWaiter3 = /* @__PURE__ */ __name(async (options, input, acceptorChecks) => {
      const params = {
        ...waiterServiceDefaults3,
        ...options
      };
      validateWaiterOptions3(params);
      const exitConditions = [runPolling3(params, input, acceptorChecks)];
      const finalize = [];
      if (options.abortSignal) {
        const { aborted, clearListener } = abortTimeout3(options.abortSignal);
        finalize.push(clearListener);
        exitConditions.push(aborted);
      }
      if (options.abortController?.signal) {
        const { aborted, clearListener } = abortTimeout3(options.abortController.signal);
        finalize.push(clearListener);
        exitConditions.push(aborted);
      }
      return Promise.race(exitConditions).then((result2) => {
        for (const fn of finalize) {
          fn();
        }
        return result2;
      });
    }, "createWaiter");
    exports2.checkExceptions = checkExceptions3;
    exports2.createWaiter = createWaiter3;
    exports2.waiterServiceDefaults = waiterServiceDefaults3;
  }
});

// ../../node_modules/@aws-sdk/client-ecr/dist-cjs/index.js
var require_dist_cjs61 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecr/dist-cjs/index.js"(exports2) {
    "use strict";
    var middlewareHostHeader = require_dist_cjs3();
    var middlewareLogger = require_dist_cjs4();
    var middlewareRecursionDetection = require_dist_cjs5();
    var middlewareUserAgent = require_dist_cjs23();
    var configResolver = require_dist_cjs25();
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var schema = (init_schema4(), __toCommonJS(schema_exports));
    var middlewareContentLength = require_dist_cjs26();
    var middlewareEndpoint = require_dist_cjs31();
    var middlewareRetry = require_dist_cjs35();
    var smithyClient = require_dist_cjs34();
    var httpAuthSchemeProvider = require_httpAuthSchemeProvider();
    var runtimeConfig = require_runtimeConfig();
    var regionConfigResolver = require_dist_cjs48();
    var protocolHttp = require_dist_cjs2();
    var schemas_0 = require_schemas_0();
    var utilWaiter = require_dist_cjs60();
    var errors = require_errors();
    var ECRServiceException = require_ECRServiceException();
    var resolveClientEndpointParameters32 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "ecr"
      });
    }, "resolveClientEndpointParameters");
    var commonParams32 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
    var getHttpAuthExtensionConfiguration32 = /* @__PURE__ */ __name((runtimeConfig2) => {
      const _httpAuthSchemes = runtimeConfig2.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig2.httpAuthSchemeProvider;
      let _credentials = runtimeConfig2.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider2) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider2;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    var resolveHttpAuthRuntimeConfig32 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
    var resolveRuntimeExtensions32 = /* @__PURE__ */ __name((runtimeConfig2, extensions) => {
      const extensionConfiguration = Object.assign(regionConfigResolver.getAwsRegionExtensionConfiguration(runtimeConfig2), smithyClient.getDefaultExtensionConfiguration(runtimeConfig2), protocolHttp.getHttpHandlerExtensionConfiguration(runtimeConfig2), getHttpAuthExtensionConfiguration32(runtimeConfig2));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig2, regionConfigResolver.resolveAwsRegionExtensionConfiguration(extensionConfiguration), smithyClient.resolveDefaultRuntimeConfig(extensionConfiguration), protocolHttp.resolveHttpHandlerRuntimeConfig(extensionConfiguration), resolveHttpAuthRuntimeConfig32(extensionConfiguration));
    }, "resolveRuntimeExtensions");
    var ECRClient3 = class extends smithyClient.Client {
      static {
        __name(this, "ECRClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = runtimeConfig.getRuntimeConfig(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters32(_config_0);
        const _config_2 = middlewareUserAgent.resolveUserAgentConfig(_config_1);
        const _config_3 = middlewareRetry.resolveRetryConfig(_config_2);
        const _config_4 = configResolver.resolveRegionConfig(_config_3);
        const _config_5 = middlewareHostHeader.resolveHostHeaderConfig(_config_4);
        const _config_6 = middlewareEndpoint.resolveEndpointConfig(_config_5);
        const _config_7 = httpAuthSchemeProvider.resolveHttpAuthSchemeConfig(_config_6);
        const _config_8 = resolveRuntimeExtensions32(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(schema.getSchemaSerdePlugin(this.config));
        this.middlewareStack.use(middlewareUserAgent.getUserAgentPlugin(this.config));
        this.middlewareStack.use(middlewareRetry.getRetryPlugin(this.config));
        this.middlewareStack.use(middlewareContentLength.getContentLengthPlugin(this.config));
        this.middlewareStack.use(middlewareHostHeader.getHostHeaderPlugin(this.config));
        this.middlewareStack.use(middlewareLogger.getLoggerPlugin(this.config));
        this.middlewareStack.use(middlewareRecursionDetection.getRecursionDetectionPlugin(this.config));
        this.middlewareStack.use(core.getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: httpAuthSchemeProvider.defaultECRHttpAuthSchemeParametersProvider,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new core.DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(core.getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
    var BatchCheckLayerAvailabilityCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "BatchCheckLayerAvailability", {}).n("ECRClient", "BatchCheckLayerAvailabilityCommand").sc(schemas_0.BatchCheckLayerAvailability$).build() {
      static {
        __name(this, "BatchCheckLayerAvailabilityCommand");
      }
    };
    var BatchDeleteImageCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "BatchDeleteImage", {}).n("ECRClient", "BatchDeleteImageCommand").sc(schemas_0.BatchDeleteImage$).build() {
      static {
        __name(this, "BatchDeleteImageCommand");
      }
    };
    var BatchGetImageCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "BatchGetImage", {}).n("ECRClient", "BatchGetImageCommand").sc(schemas_0.BatchGetImage$).build() {
      static {
        __name(this, "BatchGetImageCommand");
      }
    };
    var BatchGetRepositoryScanningConfigurationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "BatchGetRepositoryScanningConfiguration", {}).n("ECRClient", "BatchGetRepositoryScanningConfigurationCommand").sc(schemas_0.BatchGetRepositoryScanningConfiguration$).build() {
      static {
        __name(this, "BatchGetRepositoryScanningConfigurationCommand");
      }
    };
    var CompleteLayerUploadCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "CompleteLayerUpload", {}).n("ECRClient", "CompleteLayerUploadCommand").sc(schemas_0.CompleteLayerUpload$).build() {
      static {
        __name(this, "CompleteLayerUploadCommand");
      }
    };
    var CreatePullThroughCacheRuleCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "CreatePullThroughCacheRule", {}).n("ECRClient", "CreatePullThroughCacheRuleCommand").sc(schemas_0.CreatePullThroughCacheRule$).build() {
      static {
        __name(this, "CreatePullThroughCacheRuleCommand");
      }
    };
    var CreateRepositoryCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "CreateRepository", {}).n("ECRClient", "CreateRepositoryCommand").sc(schemas_0.CreateRepository$).build() {
      static {
        __name(this, "CreateRepositoryCommand");
      }
    };
    var CreateRepositoryCreationTemplateCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "CreateRepositoryCreationTemplate", {}).n("ECRClient", "CreateRepositoryCreationTemplateCommand").sc(schemas_0.CreateRepositoryCreationTemplate$).build() {
      static {
        __name(this, "CreateRepositoryCreationTemplateCommand");
      }
    };
    var DeleteLifecyclePolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "DeleteLifecyclePolicy", {}).n("ECRClient", "DeleteLifecyclePolicyCommand").sc(schemas_0.DeleteLifecyclePolicy$).build() {
      static {
        __name(this, "DeleteLifecyclePolicyCommand");
      }
    };
    var DeletePullThroughCacheRuleCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "DeletePullThroughCacheRule", {}).n("ECRClient", "DeletePullThroughCacheRuleCommand").sc(schemas_0.DeletePullThroughCacheRule$).build() {
      static {
        __name(this, "DeletePullThroughCacheRuleCommand");
      }
    };
    var DeleteRegistryPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "DeleteRegistryPolicy", {}).n("ECRClient", "DeleteRegistryPolicyCommand").sc(schemas_0.DeleteRegistryPolicy$).build() {
      static {
        __name(this, "DeleteRegistryPolicyCommand");
      }
    };
    var DeleteRepositoryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "DeleteRepository", {}).n("ECRClient", "DeleteRepositoryCommand").sc(schemas_0.DeleteRepository$).build() {
      static {
        __name(this, "DeleteRepositoryCommand");
      }
    };
    var DeleteRepositoryCreationTemplateCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "DeleteRepositoryCreationTemplate", {}).n("ECRClient", "DeleteRepositoryCreationTemplateCommand").sc(schemas_0.DeleteRepositoryCreationTemplate$).build() {
      static {
        __name(this, "DeleteRepositoryCreationTemplateCommand");
      }
    };
    var DeleteRepositoryPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "DeleteRepositoryPolicy", {}).n("ECRClient", "DeleteRepositoryPolicyCommand").sc(schemas_0.DeleteRepositoryPolicy$).build() {
      static {
        __name(this, "DeleteRepositoryPolicyCommand");
      }
    };
    var DeleteSigningConfigurationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "DeleteSigningConfiguration", {}).n("ECRClient", "DeleteSigningConfigurationCommand").sc(schemas_0.DeleteSigningConfiguration$).build() {
      static {
        __name(this, "DeleteSigningConfigurationCommand");
      }
    };
    var DeregisterPullTimeUpdateExclusionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "DeregisterPullTimeUpdateExclusion", {}).n("ECRClient", "DeregisterPullTimeUpdateExclusionCommand").sc(schemas_0.DeregisterPullTimeUpdateExclusion$).build() {
      static {
        __name(this, "DeregisterPullTimeUpdateExclusionCommand");
      }
    };
    var DescribeImageReplicationStatusCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "DescribeImageReplicationStatus", {}).n("ECRClient", "DescribeImageReplicationStatusCommand").sc(schemas_0.DescribeImageReplicationStatus$).build() {
      static {
        __name(this, "DescribeImageReplicationStatusCommand");
      }
    };
    var DescribeImageScanFindingsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "DescribeImageScanFindings", {}).n("ECRClient", "DescribeImageScanFindingsCommand").sc(schemas_0.DescribeImageScanFindings$).build() {
      static {
        __name(this, "DescribeImageScanFindingsCommand");
      }
    };
    var DescribeImagesCommand3 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "DescribeImages", {}).n("ECRClient", "DescribeImagesCommand").sc(schemas_0.DescribeImages$).build() {
      static {
        __name(this, "DescribeImagesCommand");
      }
    };
    var DescribeImageSigningStatusCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "DescribeImageSigningStatus", {}).n("ECRClient", "DescribeImageSigningStatusCommand").sc(schemas_0.DescribeImageSigningStatus$).build() {
      static {
        __name(this, "DescribeImageSigningStatusCommand");
      }
    };
    var DescribePullThroughCacheRulesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "DescribePullThroughCacheRules", {}).n("ECRClient", "DescribePullThroughCacheRulesCommand").sc(schemas_0.DescribePullThroughCacheRules$).build() {
      static {
        __name(this, "DescribePullThroughCacheRulesCommand");
      }
    };
    var DescribeRegistryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "DescribeRegistry", {}).n("ECRClient", "DescribeRegistryCommand").sc(schemas_0.DescribeRegistry$).build() {
      static {
        __name(this, "DescribeRegistryCommand");
      }
    };
    var DescribeRepositoriesCommand3 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "DescribeRepositories", {}).n("ECRClient", "DescribeRepositoriesCommand").sc(schemas_0.DescribeRepositories$).build() {
      static {
        __name(this, "DescribeRepositoriesCommand");
      }
    };
    var DescribeRepositoryCreationTemplatesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "DescribeRepositoryCreationTemplates", {}).n("ECRClient", "DescribeRepositoryCreationTemplatesCommand").sc(schemas_0.DescribeRepositoryCreationTemplates$).build() {
      static {
        __name(this, "DescribeRepositoryCreationTemplatesCommand");
      }
    };
    var GetAccountSettingCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "GetAccountSetting", {}).n("ECRClient", "GetAccountSettingCommand").sc(schemas_0.GetAccountSetting$).build() {
      static {
        __name(this, "GetAccountSettingCommand");
      }
    };
    var GetAuthorizationTokenCommand3 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "GetAuthorizationToken", {}).n("ECRClient", "GetAuthorizationTokenCommand").sc(schemas_0.GetAuthorizationToken$).build() {
      static {
        __name(this, "GetAuthorizationTokenCommand");
      }
    };
    var GetDownloadUrlForLayerCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "GetDownloadUrlForLayer", {}).n("ECRClient", "GetDownloadUrlForLayerCommand").sc(schemas_0.GetDownloadUrlForLayer$).build() {
      static {
        __name(this, "GetDownloadUrlForLayerCommand");
      }
    };
    var GetLifecyclePolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "GetLifecyclePolicy", {}).n("ECRClient", "GetLifecyclePolicyCommand").sc(schemas_0.GetLifecyclePolicy$).build() {
      static {
        __name(this, "GetLifecyclePolicyCommand");
      }
    };
    var GetLifecyclePolicyPreviewCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "GetLifecyclePolicyPreview", {}).n("ECRClient", "GetLifecyclePolicyPreviewCommand").sc(schemas_0.GetLifecyclePolicyPreview$).build() {
      static {
        __name(this, "GetLifecyclePolicyPreviewCommand");
      }
    };
    var GetRegistryPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "GetRegistryPolicy", {}).n("ECRClient", "GetRegistryPolicyCommand").sc(schemas_0.GetRegistryPolicy$).build() {
      static {
        __name(this, "GetRegistryPolicyCommand");
      }
    };
    var GetRegistryScanningConfigurationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "GetRegistryScanningConfiguration", {}).n("ECRClient", "GetRegistryScanningConfigurationCommand").sc(schemas_0.GetRegistryScanningConfiguration$).build() {
      static {
        __name(this, "GetRegistryScanningConfigurationCommand");
      }
    };
    var GetRepositoryPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "GetRepositoryPolicy", {}).n("ECRClient", "GetRepositoryPolicyCommand").sc(schemas_0.GetRepositoryPolicy$).build() {
      static {
        __name(this, "GetRepositoryPolicyCommand");
      }
    };
    var GetSigningConfigurationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "GetSigningConfiguration", {}).n("ECRClient", "GetSigningConfigurationCommand").sc(schemas_0.GetSigningConfiguration$).build() {
      static {
        __name(this, "GetSigningConfigurationCommand");
      }
    };
    var InitiateLayerUploadCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "InitiateLayerUpload", {}).n("ECRClient", "InitiateLayerUploadCommand").sc(schemas_0.InitiateLayerUpload$).build() {
      static {
        __name(this, "InitiateLayerUploadCommand");
      }
    };
    var ListImageReferrersCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "ListImageReferrers", {}).n("ECRClient", "ListImageReferrersCommand").sc(schemas_0.ListImageReferrers$).build() {
      static {
        __name(this, "ListImageReferrersCommand");
      }
    };
    var ListImagesCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "ListImages", {}).n("ECRClient", "ListImagesCommand").sc(schemas_0.ListImages$).build() {
      static {
        __name(this, "ListImagesCommand");
      }
    };
    var ListPullTimeUpdateExclusionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "ListPullTimeUpdateExclusions", {}).n("ECRClient", "ListPullTimeUpdateExclusionsCommand").sc(schemas_0.ListPullTimeUpdateExclusions$).build() {
      static {
        __name(this, "ListPullTimeUpdateExclusionsCommand");
      }
    };
    var ListTagsForResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "ListTagsForResource", {}).n("ECRClient", "ListTagsForResourceCommand").sc(schemas_0.ListTagsForResource$).build() {
      static {
        __name(this, "ListTagsForResourceCommand");
      }
    };
    var PutAccountSettingCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "PutAccountSetting", {}).n("ECRClient", "PutAccountSettingCommand").sc(schemas_0.PutAccountSetting$).build() {
      static {
        __name(this, "PutAccountSettingCommand");
      }
    };
    var PutImageCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "PutImage", {}).n("ECRClient", "PutImageCommand").sc(schemas_0.PutImage$).build() {
      static {
        __name(this, "PutImageCommand");
      }
    };
    var PutImageScanningConfigurationCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "PutImageScanningConfiguration", {}).n("ECRClient", "PutImageScanningConfigurationCommand").sc(schemas_0.PutImageScanningConfiguration$).build() {
      static {
        __name(this, "PutImageScanningConfigurationCommand");
      }
    };
    var PutImageTagMutabilityCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "PutImageTagMutability", {}).n("ECRClient", "PutImageTagMutabilityCommand").sc(schemas_0.PutImageTagMutability$).build() {
      static {
        __name(this, "PutImageTagMutabilityCommand");
      }
    };
    var PutLifecyclePolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "PutLifecyclePolicy", {}).n("ECRClient", "PutLifecyclePolicyCommand").sc(schemas_0.PutLifecyclePolicy$).build() {
      static {
        __name(this, "PutLifecyclePolicyCommand");
      }
    };
    var PutRegistryPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "PutRegistryPolicy", {}).n("ECRClient", "PutRegistryPolicyCommand").sc(schemas_0.PutRegistryPolicy$).build() {
      static {
        __name(this, "PutRegistryPolicyCommand");
      }
    };
    var PutRegistryScanningConfigurationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "PutRegistryScanningConfiguration", {}).n("ECRClient", "PutRegistryScanningConfigurationCommand").sc(schemas_0.PutRegistryScanningConfiguration$).build() {
      static {
        __name(this, "PutRegistryScanningConfigurationCommand");
      }
    };
    var PutReplicationConfigurationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "PutReplicationConfiguration", {}).n("ECRClient", "PutReplicationConfigurationCommand").sc(schemas_0.PutReplicationConfiguration$).build() {
      static {
        __name(this, "PutReplicationConfigurationCommand");
      }
    };
    var PutSigningConfigurationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "PutSigningConfiguration", {}).n("ECRClient", "PutSigningConfigurationCommand").sc(schemas_0.PutSigningConfiguration$).build() {
      static {
        __name(this, "PutSigningConfigurationCommand");
      }
    };
    var RegisterPullTimeUpdateExclusionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "RegisterPullTimeUpdateExclusion", {}).n("ECRClient", "RegisterPullTimeUpdateExclusionCommand").sc(schemas_0.RegisterPullTimeUpdateExclusion$).build() {
      static {
        __name(this, "RegisterPullTimeUpdateExclusionCommand");
      }
    };
    var SetRepositoryPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "SetRepositoryPolicy", {}).n("ECRClient", "SetRepositoryPolicyCommand").sc(schemas_0.SetRepositoryPolicy$).build() {
      static {
        __name(this, "SetRepositoryPolicyCommand");
      }
    };
    var StartImageScanCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "StartImageScan", {}).n("ECRClient", "StartImageScanCommand").sc(schemas_0.StartImageScan$).build() {
      static {
        __name(this, "StartImageScanCommand");
      }
    };
    var StartLifecyclePolicyPreviewCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "StartLifecyclePolicyPreview", {}).n("ECRClient", "StartLifecyclePolicyPreviewCommand").sc(schemas_0.StartLifecyclePolicyPreview$).build() {
      static {
        __name(this, "StartLifecyclePolicyPreviewCommand");
      }
    };
    var TagResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "TagResource", {}).n("ECRClient", "TagResourceCommand").sc(schemas_0.TagResource$).build() {
      static {
        __name(this, "TagResourceCommand");
      }
    };
    var UntagResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "UntagResource", {}).n("ECRClient", "UntagResourceCommand").sc(schemas_0.UntagResource$).build() {
      static {
        __name(this, "UntagResourceCommand");
      }
    };
    var UpdateImageStorageClassCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "UpdateImageStorageClass", {}).n("ECRClient", "UpdateImageStorageClassCommand").sc(schemas_0.UpdateImageStorageClass$).build() {
      static {
        __name(this, "UpdateImageStorageClassCommand");
      }
    };
    var UpdatePullThroughCacheRuleCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "UpdatePullThroughCacheRule", {}).n("ECRClient", "UpdatePullThroughCacheRuleCommand").sc(schemas_0.UpdatePullThroughCacheRule$).build() {
      static {
        __name(this, "UpdatePullThroughCacheRuleCommand");
      }
    };
    var UpdateRepositoryCreationTemplateCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "UpdateRepositoryCreationTemplate", {}).n("ECRClient", "UpdateRepositoryCreationTemplateCommand").sc(schemas_0.UpdateRepositoryCreationTemplate$).build() {
      static {
        __name(this, "UpdateRepositoryCreationTemplateCommand");
      }
    };
    var UploadLayerPartCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "UploadLayerPart", {}).n("ECRClient", "UploadLayerPartCommand").sc(schemas_0.UploadLayerPart$).build() {
      static {
        __name(this, "UploadLayerPartCommand");
      }
    };
    var ValidatePullThroughCacheRuleCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerRegistry_V20150921", "ValidatePullThroughCacheRule", {}).n("ECRClient", "ValidatePullThroughCacheRuleCommand").sc(schemas_0.ValidatePullThroughCacheRule$).build() {
      static {
        __name(this, "ValidatePullThroughCacheRuleCommand");
      }
    };
    var paginateDescribeImageScanFindings = core.createPaginator(ECRClient3, DescribeImageScanFindingsCommand, "nextToken", "nextToken", "maxResults");
    var paginateDescribeImages = core.createPaginator(ECRClient3, DescribeImagesCommand3, "nextToken", "nextToken", "maxResults");
    var paginateDescribePullThroughCacheRules = core.createPaginator(ECRClient3, DescribePullThroughCacheRulesCommand, "nextToken", "nextToken", "maxResults");
    var paginateDescribeRepositories = core.createPaginator(ECRClient3, DescribeRepositoriesCommand3, "nextToken", "nextToken", "maxResults");
    var paginateDescribeRepositoryCreationTemplates = core.createPaginator(ECRClient3, DescribeRepositoryCreationTemplatesCommand, "nextToken", "nextToken", "maxResults");
    var paginateGetLifecyclePolicyPreview = core.createPaginator(ECRClient3, GetLifecyclePolicyPreviewCommand, "nextToken", "nextToken", "maxResults");
    var paginateListImages = core.createPaginator(ECRClient3, ListImagesCommand2, "nextToken", "nextToken", "maxResults");
    var checkState$1 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeImageScanFindingsCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.imageScanStatus.status;
          }, "returnComparator");
          if (returnComparator() === "COMPLETE") {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.imageScanStatus.status;
          }, "returnComparator");
          if (returnComparator() === "FAILED") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$1");
    var waitForImageScanComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$1);
    }, "waitForImageScanComplete");
    var waitUntilImageScanComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$1);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilImageScanComplete");
    var checkState = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new GetLifecyclePolicyPreviewCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.status;
          }, "returnComparator");
          if (returnComparator() === "COMPLETE") {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.status;
          }, "returnComparator");
          if (returnComparator() === "FAILED") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState");
    var waitForLifecyclePolicyPreviewComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState);
    }, "waitForLifecyclePolicyPreviewComplete");
    var waitUntilLifecyclePolicyPreviewComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilLifecyclePolicyPreviewComplete");
    var commands32 = {
      BatchCheckLayerAvailabilityCommand,
      BatchDeleteImageCommand: BatchDeleteImageCommand2,
      BatchGetImageCommand: BatchGetImageCommand2,
      BatchGetRepositoryScanningConfigurationCommand,
      CompleteLayerUploadCommand,
      CreatePullThroughCacheRuleCommand,
      CreateRepositoryCommand: CreateRepositoryCommand2,
      CreateRepositoryCreationTemplateCommand,
      DeleteLifecyclePolicyCommand,
      DeletePullThroughCacheRuleCommand,
      DeleteRegistryPolicyCommand,
      DeleteRepositoryCommand,
      DeleteRepositoryCreationTemplateCommand,
      DeleteRepositoryPolicyCommand,
      DeleteSigningConfigurationCommand,
      DeregisterPullTimeUpdateExclusionCommand,
      DescribeImageReplicationStatusCommand,
      DescribeImagesCommand: DescribeImagesCommand3,
      DescribeImageScanFindingsCommand,
      DescribeImageSigningStatusCommand,
      DescribePullThroughCacheRulesCommand,
      DescribeRegistryCommand,
      DescribeRepositoriesCommand: DescribeRepositoriesCommand3,
      DescribeRepositoryCreationTemplatesCommand,
      GetAccountSettingCommand,
      GetAuthorizationTokenCommand: GetAuthorizationTokenCommand3,
      GetDownloadUrlForLayerCommand,
      GetLifecyclePolicyCommand,
      GetLifecyclePolicyPreviewCommand,
      GetRegistryPolicyCommand,
      GetRegistryScanningConfigurationCommand,
      GetRepositoryPolicyCommand,
      GetSigningConfigurationCommand,
      InitiateLayerUploadCommand,
      ListImageReferrersCommand,
      ListImagesCommand: ListImagesCommand2,
      ListPullTimeUpdateExclusionsCommand,
      ListTagsForResourceCommand,
      PutAccountSettingCommand,
      PutImageCommand: PutImageCommand2,
      PutImageScanningConfigurationCommand: PutImageScanningConfigurationCommand2,
      PutImageTagMutabilityCommand,
      PutLifecyclePolicyCommand,
      PutRegistryPolicyCommand,
      PutRegistryScanningConfigurationCommand,
      PutReplicationConfigurationCommand,
      PutSigningConfigurationCommand,
      RegisterPullTimeUpdateExclusionCommand,
      SetRepositoryPolicyCommand,
      StartImageScanCommand,
      StartLifecyclePolicyPreviewCommand,
      TagResourceCommand,
      UntagResourceCommand,
      UpdateImageStorageClassCommand,
      UpdatePullThroughCacheRuleCommand,
      UpdateRepositoryCreationTemplateCommand,
      UploadLayerPartCommand,
      ValidatePullThroughCacheRuleCommand
    };
    var paginators = {
      paginateDescribeImages,
      paginateDescribeImageScanFindings,
      paginateDescribePullThroughCacheRules,
      paginateDescribeRepositories,
      paginateDescribeRepositoryCreationTemplates,
      paginateGetLifecyclePolicyPreview,
      paginateListImages
    };
    var waiters = {
      waitUntilImageScanComplete,
      waitUntilLifecyclePolicyPreviewComplete
    };
    var ECR = class extends ECRClient3 {
      static {
        __name(this, "ECR");
      }
    };
    smithyClient.createAggregatedClient(commands32, ECR, { paginators, waiters });
    var LayerFailureCode = {
      InvalidLayerDigest: "InvalidLayerDigest",
      MissingLayerDigest: "MissingLayerDigest"
    };
    var LayerAvailability = {
      ARCHIVED: "ARCHIVED",
      AVAILABLE: "AVAILABLE",
      UNAVAILABLE: "UNAVAILABLE"
    };
    var ImageFailureCode = {
      ImageInaccessible: "ImageInaccessible",
      ImageNotFound: "ImageNotFound",
      ImageReferencedByManifestList: "ImageReferencedByManifestList",
      ImageTagDoesNotMatchDigest: "ImageTagDoesNotMatchDigest",
      InvalidImageDigest: "InvalidImageDigest",
      InvalidImageTag: "InvalidImageTag",
      KmsError: "KmsError",
      MissingDigestAndTag: "MissingDigestAndTag",
      UpstreamAccessDenied: "UpstreamAccessDenied",
      UpstreamTooManyRequests: "UpstreamTooManyRequests",
      UpstreamUnavailable: "UpstreamUnavailable"
    };
    var ScanningConfigurationFailureCode = {
      REPOSITORY_NOT_FOUND: "REPOSITORY_NOT_FOUND"
    };
    var ScanningRepositoryFilterType = {
      WILDCARD: "WILDCARD"
    };
    var ScanFrequency = {
      CONTINUOUS_SCAN: "CONTINUOUS_SCAN",
      MANUAL: "MANUAL",
      SCAN_ON_PUSH: "SCAN_ON_PUSH"
    };
    var UpstreamRegistry = {
      AzureContainerRegistry: "azure-container-registry",
      Chainguard: "chainguard",
      DockerHub: "docker-hub",
      Ecr: "ecr",
      EcrPublic: "ecr-public",
      GitHubContainerRegistry: "github-container-registry",
      GitLabContainerRegistry: "gitlab-container-registry",
      K8s: "k8s",
      Quay: "quay"
    };
    var EncryptionType = {
      AES256: "AES256",
      KMS: "KMS",
      KMS_DSSE: "KMS_DSSE"
    };
    var ImageTagMutability = {
      IMMUTABLE: "IMMUTABLE",
      IMMUTABLE_WITH_EXCLUSION: "IMMUTABLE_WITH_EXCLUSION",
      MUTABLE: "MUTABLE",
      MUTABLE_WITH_EXCLUSION: "MUTABLE_WITH_EXCLUSION"
    };
    var ImageTagMutabilityExclusionFilterType = {
      WILDCARD: "WILDCARD"
    };
    var RCTAppliedFor = {
      CREATE_ON_PUSH: "CREATE_ON_PUSH",
      PULL_THROUGH_CACHE: "PULL_THROUGH_CACHE",
      REPLICATION: "REPLICATION"
    };
    var SigningRepositoryFilterType = {
      WILDCARD_MATCH: "WILDCARD_MATCH"
    };
    var ReplicationStatus = {
      COMPLETE: "COMPLETE",
      FAILED: "FAILED",
      IN_PROGRESS: "IN_PROGRESS"
    };
    var ImageStatusFilter = {
      ACTIVATING: "ACTIVATING",
      ACTIVE: "ACTIVE",
      ANY: "ANY",
      ARCHIVED: "ARCHIVED"
    };
    var TagStatus = {
      ANY: "ANY",
      TAGGED: "TAGGED",
      UNTAGGED: "UNTAGGED"
    };
    var FindingSeverity = {
      CRITICAL: "CRITICAL",
      HIGH: "HIGH",
      INFORMATIONAL: "INFORMATIONAL",
      LOW: "LOW",
      MEDIUM: "MEDIUM",
      UNDEFINED: "UNDEFINED"
    };
    var ScanStatus = {
      ACTIVE: "ACTIVE",
      COMPLETE: "COMPLETE",
      FAILED: "FAILED",
      FINDINGS_UNAVAILABLE: "FINDINGS_UNAVAILABLE",
      IMAGE_ARCHIVED: "IMAGE_ARCHIVED",
      IN_PROGRESS: "IN_PROGRESS",
      LIMIT_EXCEEDED: "LIMIT_EXCEEDED",
      PENDING: "PENDING",
      SCAN_ELIGIBILITY_EXPIRED: "SCAN_ELIGIBILITY_EXPIRED",
      UNSUPPORTED_IMAGE: "UNSUPPORTED_IMAGE"
    };
    var ImageStatus = {
      ACTIVATING: "ACTIVATING",
      ACTIVE: "ACTIVE",
      ARCHIVED: "ARCHIVED"
    };
    var SigningStatus = {
      COMPLETE: "COMPLETE",
      FAILED: "FAILED",
      IN_PROGRESS: "IN_PROGRESS"
    };
    var RepositoryFilterType = {
      PREFIX_MATCH: "PREFIX_MATCH"
    };
    var LifecyclePolicyTargetStorageClass = {
      ARCHIVE: "ARCHIVE"
    };
    var ImageActionType = {
      EXPIRE: "EXPIRE",
      TRANSITION: "TRANSITION"
    };
    var LifecyclePolicyStorageClass = {
      ARCHIVE: "ARCHIVE",
      STANDARD: "STANDARD"
    };
    var LifecyclePolicyPreviewStatus = {
      COMPLETE: "COMPLETE",
      EXPIRED: "EXPIRED",
      FAILED: "FAILED",
      IN_PROGRESS: "IN_PROGRESS"
    };
    var ScanType = {
      BASIC: "BASIC",
      ENHANCED: "ENHANCED"
    };
    var ArtifactStatusFilter = {
      ACTIVATING: "ACTIVATING",
      ACTIVE: "ACTIVE",
      ANY: "ANY",
      ARCHIVED: "ARCHIVED"
    };
    var ArtifactStatus = {
      ACTIVATING: "ACTIVATING",
      ACTIVE: "ACTIVE",
      ARCHIVED: "ARCHIVED"
    };
    var TargetStorageClass = {
      ARCHIVE: "ARCHIVE",
      STANDARD: "STANDARD"
    };
    exports2.$Command = smithyClient.Command;
    exports2.__Client = smithyClient.Client;
    exports2.ECRServiceException = ECRServiceException.ECRServiceException;
    exports2.ArtifactStatus = ArtifactStatus;
    exports2.ArtifactStatusFilter = ArtifactStatusFilter;
    exports2.BatchCheckLayerAvailabilityCommand = BatchCheckLayerAvailabilityCommand;
    exports2.BatchDeleteImageCommand = BatchDeleteImageCommand2;
    exports2.BatchGetImageCommand = BatchGetImageCommand2;
    exports2.BatchGetRepositoryScanningConfigurationCommand = BatchGetRepositoryScanningConfigurationCommand;
    exports2.CompleteLayerUploadCommand = CompleteLayerUploadCommand;
    exports2.CreatePullThroughCacheRuleCommand = CreatePullThroughCacheRuleCommand;
    exports2.CreateRepositoryCommand = CreateRepositoryCommand2;
    exports2.CreateRepositoryCreationTemplateCommand = CreateRepositoryCreationTemplateCommand;
    exports2.DeleteLifecyclePolicyCommand = DeleteLifecyclePolicyCommand;
    exports2.DeletePullThroughCacheRuleCommand = DeletePullThroughCacheRuleCommand;
    exports2.DeleteRegistryPolicyCommand = DeleteRegistryPolicyCommand;
    exports2.DeleteRepositoryCommand = DeleteRepositoryCommand;
    exports2.DeleteRepositoryCreationTemplateCommand = DeleteRepositoryCreationTemplateCommand;
    exports2.DeleteRepositoryPolicyCommand = DeleteRepositoryPolicyCommand;
    exports2.DeleteSigningConfigurationCommand = DeleteSigningConfigurationCommand;
    exports2.DeregisterPullTimeUpdateExclusionCommand = DeregisterPullTimeUpdateExclusionCommand;
    exports2.DescribeImageReplicationStatusCommand = DescribeImageReplicationStatusCommand;
    exports2.DescribeImageScanFindingsCommand = DescribeImageScanFindingsCommand;
    exports2.DescribeImageSigningStatusCommand = DescribeImageSigningStatusCommand;
    exports2.DescribeImagesCommand = DescribeImagesCommand3;
    exports2.DescribePullThroughCacheRulesCommand = DescribePullThroughCacheRulesCommand;
    exports2.DescribeRegistryCommand = DescribeRegistryCommand;
    exports2.DescribeRepositoriesCommand = DescribeRepositoriesCommand3;
    exports2.DescribeRepositoryCreationTemplatesCommand = DescribeRepositoryCreationTemplatesCommand;
    exports2.ECR = ECR;
    exports2.ECRClient = ECRClient3;
    exports2.EncryptionType = EncryptionType;
    exports2.FindingSeverity = FindingSeverity;
    exports2.GetAccountSettingCommand = GetAccountSettingCommand;
    exports2.GetAuthorizationTokenCommand = GetAuthorizationTokenCommand3;
    exports2.GetDownloadUrlForLayerCommand = GetDownloadUrlForLayerCommand;
    exports2.GetLifecyclePolicyCommand = GetLifecyclePolicyCommand;
    exports2.GetLifecyclePolicyPreviewCommand = GetLifecyclePolicyPreviewCommand;
    exports2.GetRegistryPolicyCommand = GetRegistryPolicyCommand;
    exports2.GetRegistryScanningConfigurationCommand = GetRegistryScanningConfigurationCommand;
    exports2.GetRepositoryPolicyCommand = GetRepositoryPolicyCommand;
    exports2.GetSigningConfigurationCommand = GetSigningConfigurationCommand;
    exports2.ImageActionType = ImageActionType;
    exports2.ImageFailureCode = ImageFailureCode;
    exports2.ImageStatus = ImageStatus;
    exports2.ImageStatusFilter = ImageStatusFilter;
    exports2.ImageTagMutability = ImageTagMutability;
    exports2.ImageTagMutabilityExclusionFilterType = ImageTagMutabilityExclusionFilterType;
    exports2.InitiateLayerUploadCommand = InitiateLayerUploadCommand;
    exports2.LayerAvailability = LayerAvailability;
    exports2.LayerFailureCode = LayerFailureCode;
    exports2.LifecyclePolicyPreviewStatus = LifecyclePolicyPreviewStatus;
    exports2.LifecyclePolicyStorageClass = LifecyclePolicyStorageClass;
    exports2.LifecyclePolicyTargetStorageClass = LifecyclePolicyTargetStorageClass;
    exports2.ListImageReferrersCommand = ListImageReferrersCommand;
    exports2.ListImagesCommand = ListImagesCommand2;
    exports2.ListPullTimeUpdateExclusionsCommand = ListPullTimeUpdateExclusionsCommand;
    exports2.ListTagsForResourceCommand = ListTagsForResourceCommand;
    exports2.PutAccountSettingCommand = PutAccountSettingCommand;
    exports2.PutImageCommand = PutImageCommand2;
    exports2.PutImageScanningConfigurationCommand = PutImageScanningConfigurationCommand2;
    exports2.PutImageTagMutabilityCommand = PutImageTagMutabilityCommand;
    exports2.PutLifecyclePolicyCommand = PutLifecyclePolicyCommand;
    exports2.PutRegistryPolicyCommand = PutRegistryPolicyCommand;
    exports2.PutRegistryScanningConfigurationCommand = PutRegistryScanningConfigurationCommand;
    exports2.PutReplicationConfigurationCommand = PutReplicationConfigurationCommand;
    exports2.PutSigningConfigurationCommand = PutSigningConfigurationCommand;
    exports2.RCTAppliedFor = RCTAppliedFor;
    exports2.RegisterPullTimeUpdateExclusionCommand = RegisterPullTimeUpdateExclusionCommand;
    exports2.ReplicationStatus = ReplicationStatus;
    exports2.RepositoryFilterType = RepositoryFilterType;
    exports2.ScanFrequency = ScanFrequency;
    exports2.ScanStatus = ScanStatus;
    exports2.ScanType = ScanType;
    exports2.ScanningConfigurationFailureCode = ScanningConfigurationFailureCode;
    exports2.ScanningRepositoryFilterType = ScanningRepositoryFilterType;
    exports2.SetRepositoryPolicyCommand = SetRepositoryPolicyCommand;
    exports2.SigningRepositoryFilterType = SigningRepositoryFilterType;
    exports2.SigningStatus = SigningStatus;
    exports2.StartImageScanCommand = StartImageScanCommand;
    exports2.StartLifecyclePolicyPreviewCommand = StartLifecyclePolicyPreviewCommand;
    exports2.TagResourceCommand = TagResourceCommand;
    exports2.TagStatus = TagStatus;
    exports2.TargetStorageClass = TargetStorageClass;
    exports2.UntagResourceCommand = UntagResourceCommand;
    exports2.UpdateImageStorageClassCommand = UpdateImageStorageClassCommand;
    exports2.UpdatePullThroughCacheRuleCommand = UpdatePullThroughCacheRuleCommand;
    exports2.UpdateRepositoryCreationTemplateCommand = UpdateRepositoryCreationTemplateCommand;
    exports2.UploadLayerPartCommand = UploadLayerPartCommand;
    exports2.UpstreamRegistry = UpstreamRegistry;
    exports2.ValidatePullThroughCacheRuleCommand = ValidatePullThroughCacheRuleCommand;
    exports2.paginateDescribeImageScanFindings = paginateDescribeImageScanFindings;
    exports2.paginateDescribeImages = paginateDescribeImages;
    exports2.paginateDescribePullThroughCacheRules = paginateDescribePullThroughCacheRules;
    exports2.paginateDescribeRepositories = paginateDescribeRepositories;
    exports2.paginateDescribeRepositoryCreationTemplates = paginateDescribeRepositoryCreationTemplates;
    exports2.paginateGetLifecyclePolicyPreview = paginateGetLifecyclePolicyPreview;
    exports2.paginateListImages = paginateListImages;
    exports2.waitForImageScanComplete = waitForImageScanComplete;
    exports2.waitForLifecyclePolicyPreviewComplete = waitForLifecyclePolicyPreviewComplete;
    exports2.waitUntilImageScanComplete = waitUntilImageScanComplete;
    exports2.waitUntilLifecyclePolicyPreviewComplete = waitUntilLifecyclePolicyPreviewComplete;
    Object.prototype.hasOwnProperty.call(schemas_0, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: schemas_0["__proto__"]
    });
    Object.keys(schemas_0).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = schemas_0[k32];
    });
    Object.prototype.hasOwnProperty.call(errors, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: errors["__proto__"]
    });
    Object.keys(errors).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = errors[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/middleware-expect-continue/dist-cjs/index.js
var require_dist_cjs62 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-expect-continue/dist-cjs/index.js"(exports2) {
    "use strict";
    var protocolHttp = require_dist_cjs2();
    function addExpectContinueMiddleware(options) {
      return (next) => async (args) => {
        const { request: request4 } = args;
        if (options.expectContinueHeader !== false && protocolHttp.HttpRequest.isInstance(request4) && request4.body && options.runtime === "node" && options.requestHandler?.constructor?.name !== "FetchHttpHandler") {
          let sendHeader = true;
          if (typeof options.expectContinueHeader === "number") {
            try {
              const bodyLength = Number(request4.headers?.["content-length"]) ?? options.bodyLengthChecker?.(request4.body) ?? Infinity;
              sendHeader = bodyLength >= options.expectContinueHeader;
            } catch (e32) {
            }
          } else {
            sendHeader = !!options.expectContinueHeader;
          }
          if (sendHeader) {
            request4.headers.Expect = "100-continue";
          }
        }
        return next({
          ...args,
          request: request4
        });
      };
    }
    __name(addExpectContinueMiddleware, "addExpectContinueMiddleware");
    var addExpectContinueMiddlewareOptions = {
      step: "build",
      tags: ["SET_EXPECT_HEADER", "EXPECT_HEADER"],
      name: "addExpectContinueMiddleware",
      override: true
    };
    var getAddExpectContinuePlugin = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(addExpectContinueMiddleware(options), addExpectContinueMiddlewareOptions);
      }, "applyToStack")
    }), "getAddExpectContinuePlugin");
    exports2.addExpectContinueMiddleware = addExpectContinueMiddleware;
    exports2.addExpectContinueMiddlewareOptions = addExpectContinueMiddlewareOptions;
    exports2.getAddExpectContinuePlugin = getAddExpectContinuePlugin;
  }
});

// ../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@aws-sdk/core/dist-es/submodules/client/emitWarningIfUnsupportedVersion.js
var state4, emitWarningIfUnsupportedVersion8;
var init_emitWarningIfUnsupportedVersion4 = __esm({
  "../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@aws-sdk/core/dist-es/submodules/client/emitWarningIfUnsupportedVersion.js"() {
    state4 = {
      warningEmitted: false
    };
    emitWarningIfUnsupportedVersion8 = /* @__PURE__ */ __name((version) => {
      if (version && !state4.warningEmitted) {
        if (process.env.AWS_SDK_JS_NODE_VERSION_SUPPORT_WARNING_DISABLED === "true") {
          state4.warningEmitted = true;
          return;
        }
        const userMajorVersion = parseInt(version.substring(1, version.indexOf(".")));
        const vv = 22;
        if (userMajorVersion < vv) {
          state4.warningEmitted = true;
          process.emitWarning(`NodeVersionSupportWarning: The AWS SDK for JavaScript (v3)
versions published after the first week of January 2027
will require node >=${vv}. You are running node ${version}.

To continue receiving updates to AWS services, bug fixes,
and security updates please upgrade to node >=${vv}.

More information can be found at: https://a.co/c895JFp`);
        }
      }
    }, "emitWarningIfUnsupportedVersion");
  }
});

// ../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@aws-sdk/core/dist-es/submodules/client/longPollMiddleware.js
var longPollMiddleware4, longPollMiddlewareOptions4, getLongPollPlugin4;
var init_longPollMiddleware4 = __esm({
  "../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@aws-sdk/core/dist-es/submodules/client/longPollMiddleware.js"() {
    longPollMiddleware4 = /* @__PURE__ */ __name(() => (next, context) => async (args) => {
      context.__retryLongPoll = true;
      return next(args);
    }, "longPollMiddleware");
    longPollMiddlewareOptions4 = {
      name: "longPollMiddleware",
      tags: ["RETRY"],
      step: "initialize",
      override: true
    };
    getLongPollPlugin4 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(longPollMiddleware4(), longPollMiddlewareOptions4);
      }, "applyToStack")
    }), "getLongPollPlugin");
  }
});

// ../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@aws-sdk/core/dist-es/submodules/client/setCredentialFeature.js
function setCredentialFeature4(credentials, feature, value) {
  if (!credentials.$source) {
    credentials.$source = {};
  }
  credentials.$source[feature] = value;
  return credentials;
}
var init_setCredentialFeature4 = __esm({
  "../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@aws-sdk/core/dist-es/submodules/client/setCredentialFeature.js"() {
    __name(setCredentialFeature4, "setCredentialFeature");
  }
});

// ../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@aws-sdk/core/dist-es/submodules/client/setFeature.js
function setFeature5(context, feature, value) {
  if (!context.__aws_sdk_context) {
    context.__aws_sdk_context = {
      features: {}
    };
  } else if (!context.__aws_sdk_context.features) {
    context.__aws_sdk_context.features = {};
  }
  context.__aws_sdk_context.features[feature] = value;
}
var import_util_retry8;
var init_setFeature5 = __esm({
  "../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@aws-sdk/core/dist-es/submodules/client/setFeature.js"() {
    import_util_retry8 = __toESM(require_dist_cjs22());
    import_util_retry8.Retry.v2026 ||= typeof process === "object" && process.env?.AWS_NEW_RETRIES_2026 === "true";
    __name(setFeature5, "setFeature");
  }
});

// ../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@aws-sdk/core/dist-es/submodules/client/setTokenFeature.js
function setTokenFeature4(token, feature, value) {
  if (!token.$source) {
    token.$source = {};
  }
  token.$source[feature] = value;
  return token;
}
var init_setTokenFeature4 = __esm({
  "../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@aws-sdk/core/dist-es/submodules/client/setTokenFeature.js"() {
    __name(setTokenFeature4, "setTokenFeature");
  }
});

// ../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@aws-sdk/core/dist-es/submodules/client/index.js
var client_exports4 = {};
__export(client_exports4, {
  emitWarningIfUnsupportedVersion: () => emitWarningIfUnsupportedVersion8,
  getLongPollPlugin: () => getLongPollPlugin4,
  setCredentialFeature: () => setCredentialFeature4,
  setFeature: () => setFeature5,
  setTokenFeature: () => setTokenFeature4,
  state: () => state4
});
var init_client5 = __esm({
  "../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@aws-sdk/core/dist-es/submodules/client/index.js"() {
    init_emitWarningIfUnsupportedVersion4();
    init_longPollMiddleware4();
    init_setCredentialFeature4();
    init_setFeature5();
    init_setTokenFeature4();
  }
});

// ../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.js
var require_ChecksumStream3 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ChecksumStream = void 0;
    var util_base64_1 = require_dist_cjs10();
    var stream_1 = require("stream");
    var ChecksumStream5 = class extends stream_1.Duplex {
      static {
        __name(this, "ChecksumStream");
      }
      expectedChecksum;
      checksumSourceLocation;
      checksum;
      source;
      base64Encoder;
      pendingCallback = null;
      constructor({ expectedChecksum, checksum, source, checksumSourceLocation, base64Encoder }) {
        super();
        if (typeof source.pipe === "function") {
          this.source = source;
        } else {
          throw new Error(`@smithy/util-stream: unsupported source type ${source?.constructor?.name ?? source} in ChecksumStream.`);
        }
        this.base64Encoder = base64Encoder ?? util_base64_1.toBase64;
        this.expectedChecksum = expectedChecksum;
        this.checksum = checksum;
        this.checksumSourceLocation = checksumSourceLocation;
        this.source.pipe(this);
      }
      _read(size) {
        if (this.pendingCallback) {
          const callback = this.pendingCallback;
          this.pendingCallback = null;
          callback();
        }
      }
      _write(chunk, encoding, callback) {
        try {
          this.checksum.update(chunk);
          const canPushMore = this.push(chunk);
          if (!canPushMore) {
            this.pendingCallback = callback;
            return;
          }
        } catch (e32) {
          return callback(e32);
        }
        return callback();
      }
      async _final(callback) {
        try {
          const digest = await this.checksum.digest();
          const received = this.base64Encoder(digest);
          if (this.expectedChecksum !== received) {
            return callback(new Error(`Checksum mismatch: expected "${this.expectedChecksum}" but received "${received}" in response header "${this.checksumSourceLocation}".`));
          }
        } catch (e32) {
          return callback(e32);
        }
        this.push(null);
        return callback();
      }
    };
    exports2.ChecksumStream = ChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/stream-type-check.js
var require_stream_type_check3 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/stream-type-check.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isBlob = exports2.isReadableStream = void 0;
    var isReadableStream6 = /* @__PURE__ */ __name((stream) => typeof ReadableStream === "function" && (stream?.constructor?.name === ReadableStream.name || stream instanceof ReadableStream), "isReadableStream");
    exports2.isReadableStream = isReadableStream6;
    var isBlob3 = /* @__PURE__ */ __name((blob) => {
      return typeof Blob === "function" && (blob?.constructor?.name === Blob.name || blob instanceof Blob);
    }, "isBlob");
    exports2.isBlob = isBlob3;
  }
});

// ../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.browser.js
var require_ChecksumStream_browser3 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ChecksumStream = void 0;
    var ReadableStreamRef3 = typeof ReadableStream === "function" ? ReadableStream : function() {
    };
    var ChecksumStream5 = class extends ReadableStreamRef3 {
      static {
        __name(this, "ChecksumStream");
      }
    };
    exports2.ChecksumStream = ChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.browser.js
var require_createChecksumStream_browser3 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createChecksumStream = void 0;
    var util_base64_1 = require_dist_cjs10();
    var stream_type_check_1 = require_stream_type_check3();
    var ChecksumStream_browser_1 = require_ChecksumStream_browser3();
    var createChecksumStream5 = /* @__PURE__ */ __name(({ expectedChecksum, checksum, source, checksumSourceLocation, base64Encoder }) => {
      if (!(0, stream_type_check_1.isReadableStream)(source)) {
        throw new Error(`@smithy/util-stream: unsupported source type ${source?.constructor?.name ?? source} in ChecksumStream.`);
      }
      const encoder = base64Encoder ?? util_base64_1.toBase64;
      if (typeof TransformStream !== "function") {
        throw new Error("@smithy/util-stream: unable to instantiate ChecksumStream because API unavailable: ReadableStream/TransformStream.");
      }
      const transform = new TransformStream({
        start() {
        },
        async transform(chunk, controller) {
          checksum.update(chunk);
          controller.enqueue(chunk);
        },
        async flush(controller) {
          const digest = await checksum.digest();
          const received = encoder(digest);
          if (expectedChecksum !== received) {
            const error4 = new Error(`Checksum mismatch: expected "${expectedChecksum}" but received "${received}" in response header "${checksumSourceLocation}".`);
            controller.error(error4);
          } else {
            controller.terminate();
          }
        }
      });
      source.pipeThrough(transform);
      const readable = transform.readable;
      Object.setPrototypeOf(readable, ChecksumStream_browser_1.ChecksumStream.prototype);
      return readable;
    }, "createChecksumStream");
    exports2.createChecksumStream = createChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.js
var require_createChecksumStream3 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createChecksumStream = createChecksumStream5;
    var stream_type_check_1 = require_stream_type_check3();
    var ChecksumStream_1 = require_ChecksumStream3();
    var createChecksumStream_browser_1 = require_createChecksumStream_browser3();
    function createChecksumStream5(init) {
      if (typeof ReadableStream === "function" && (0, stream_type_check_1.isReadableStream)(init.source)) {
        return (0, createChecksumStream_browser_1.createChecksumStream)(init);
      }
      return new ChecksumStream_1.ChecksumStream(init);
    }
    __name(createChecksumStream5, "createChecksumStream");
  }
});

// ../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/ByteArrayCollector.js
var require_ByteArrayCollector3 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/ByteArrayCollector.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ByteArrayCollector = void 0;
    var ByteArrayCollector3 = class {
      static {
        __name(this, "ByteArrayCollector");
      }
      allocByteArray;
      byteLength = 0;
      byteArrays = [];
      constructor(allocByteArray) {
        this.allocByteArray = allocByteArray;
      }
      push(byteArray) {
        this.byteArrays.push(byteArray);
        this.byteLength += byteArray.byteLength;
      }
      flush() {
        if (this.byteArrays.length === 1) {
          const bytes = this.byteArrays[0];
          this.reset();
          return bytes;
        }
        const aggregation = this.allocByteArray(this.byteLength);
        let cursor3 = 0;
        for (let i32 = 0; i32 < this.byteArrays.length; ++i32) {
          const bytes = this.byteArrays[i32];
          aggregation.set(bytes, cursor3);
          cursor3 += bytes.byteLength;
        }
        this.reset();
        return aggregation;
      }
      reset() {
        this.byteArrays = [];
        this.byteLength = 0;
      }
    };
    exports2.ByteArrayCollector = ByteArrayCollector3;
  }
});

// ../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadableStream.js
var require_createBufferedReadableStream3 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadableStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createBufferedReadable = void 0;
    exports2.createBufferedReadableStream = createBufferedReadableStream3;
    exports2.merge = merge3;
    exports2.flush = flush3;
    exports2.sizeOf = sizeOf3;
    exports2.modeOf = modeOf3;
    var ByteArrayCollector_1 = require_ByteArrayCollector3();
    function createBufferedReadableStream3(upstream, size, logger5) {
      const reader = upstream.getReader();
      let streamBufferingLoggedWarning = false;
      let bytesSeen = 0;
      const buffers = ["", new ByteArrayCollector_1.ByteArrayCollector((size2) => new Uint8Array(size2))];
      let mode = -1;
      const pull = /* @__PURE__ */ __name(async (controller) => {
        const { value, done } = await reader.read();
        const chunk = value;
        if (done) {
          if (mode !== -1) {
            const remainder = flush3(buffers, mode);
            if (sizeOf3(remainder) > 0) {
              controller.enqueue(remainder);
            }
          }
          controller.close();
        } else {
          const chunkMode = modeOf3(chunk, false);
          if (mode !== chunkMode) {
            if (mode >= 0) {
              controller.enqueue(flush3(buffers, mode));
            }
            mode = chunkMode;
          }
          if (mode === -1) {
            controller.enqueue(chunk);
            return;
          }
          const chunkSize = sizeOf3(chunk);
          bytesSeen += chunkSize;
          const bufferSize = sizeOf3(buffers[mode]);
          if (chunkSize >= size && bufferSize === 0) {
            controller.enqueue(chunk);
          } else {
            const newSize = merge3(buffers, mode, chunk);
            if (!streamBufferingLoggedWarning && bytesSeen > size * 2) {
              streamBufferingLoggedWarning = true;
              logger5?.warn(`@smithy/util-stream - stream chunk size ${chunkSize} is below threshold of ${size}, automatically buffering.`);
            }
            if (newSize >= size) {
              controller.enqueue(flush3(buffers, mode));
            } else {
              await pull(controller);
            }
          }
        }
      }, "pull");
      return new ReadableStream({
        pull
      });
    }
    __name(createBufferedReadableStream3, "createBufferedReadableStream");
    exports2.createBufferedReadable = createBufferedReadableStream3;
    function merge3(buffers, mode, chunk) {
      switch (mode) {
        case 0:
          buffers[0] += chunk;
          return sizeOf3(buffers[0]);
        case 1:
        case 2:
          buffers[mode].push(chunk);
          return sizeOf3(buffers[mode]);
      }
    }
    __name(merge3, "merge");
    function flush3(buffers, mode) {
      switch (mode) {
        case 0:
          const s = buffers[0];
          buffers[0] = "";
          return s;
        case 1:
        case 2:
          return buffers[mode].flush();
      }
      throw new Error(`@smithy/util-stream - invalid index ${mode} given to flush()`);
    }
    __name(flush3, "flush");
    function sizeOf3(chunk) {
      return chunk?.byteLength ?? chunk?.length ?? 0;
    }
    __name(sizeOf3, "sizeOf");
    function modeOf3(chunk, allowBuffer = true) {
      if (allowBuffer && typeof Buffer !== "undefined" && chunk instanceof Buffer) {
        return 2;
      }
      if (chunk instanceof Uint8Array) {
        return 1;
      }
      if (typeof chunk === "string") {
        return 0;
      }
      return -1;
    }
    __name(modeOf3, "modeOf");
  }
});

// ../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadable.js
var require_createBufferedReadable3 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadable.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createBufferedReadable = createBufferedReadable3;
    var node_stream_1 = require("node:stream");
    var ByteArrayCollector_1 = require_ByteArrayCollector3();
    var createBufferedReadableStream_1 = require_createBufferedReadableStream3();
    var stream_type_check_1 = require_stream_type_check3();
    function createBufferedReadable3(upstream, size, logger5) {
      if ((0, stream_type_check_1.isReadableStream)(upstream)) {
        return (0, createBufferedReadableStream_1.createBufferedReadableStream)(upstream, size, logger5);
      }
      const downstream = new node_stream_1.Readable({ read() {
      } });
      let streamBufferingLoggedWarning = false;
      let bytesSeen = 0;
      const buffers = [
        "",
        new ByteArrayCollector_1.ByteArrayCollector((size2) => new Uint8Array(size2)),
        new ByteArrayCollector_1.ByteArrayCollector((size2) => Buffer.from(new Uint8Array(size2)))
      ];
      let mode = -1;
      upstream.on("data", (chunk) => {
        const chunkMode = (0, createBufferedReadableStream_1.modeOf)(chunk, true);
        if (mode !== chunkMode) {
          if (mode >= 0) {
            downstream.push((0, createBufferedReadableStream_1.flush)(buffers, mode));
          }
          mode = chunkMode;
        }
        if (mode === -1) {
          downstream.push(chunk);
          return;
        }
        const chunkSize = (0, createBufferedReadableStream_1.sizeOf)(chunk);
        bytesSeen += chunkSize;
        const bufferSize = (0, createBufferedReadableStream_1.sizeOf)(buffers[mode]);
        if (chunkSize >= size && bufferSize === 0) {
          downstream.push(chunk);
        } else {
          const newSize = (0, createBufferedReadableStream_1.merge)(buffers, mode, chunk);
          if (!streamBufferingLoggedWarning && bytesSeen > size * 2) {
            streamBufferingLoggedWarning = true;
            logger5?.warn(`@smithy/util-stream - stream chunk size ${chunkSize} is below threshold of ${size}, automatically buffering.`);
          }
          if (newSize >= size) {
            downstream.push((0, createBufferedReadableStream_1.flush)(buffers, mode));
          }
        }
      });
      upstream.on("end", () => {
        if (mode !== -1) {
          const remainder = (0, createBufferedReadableStream_1.flush)(buffers, mode);
          if ((0, createBufferedReadableStream_1.sizeOf)(remainder) > 0) {
            downstream.push(remainder);
          }
        }
        downstream.push(null);
      });
      return downstream;
    }
    __name(createBufferedReadable3, "createBufferedReadable");
  }
});

// ../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.browser.js
var require_getAwsChunkedEncodingStream_browser3 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getAwsChunkedEncodingStream = void 0;
    var getAwsChunkedEncodingStream5 = /* @__PURE__ */ __name((readableStream, options) => {
      const { base64Encoder, bodyLengthChecker, checksumAlgorithmFn, checksumLocationName, streamHasher } = options;
      const checksumRequired = base64Encoder !== void 0 && bodyLengthChecker !== void 0 && checksumAlgorithmFn !== void 0 && checksumLocationName !== void 0 && streamHasher !== void 0;
      const digest = checksumRequired ? streamHasher(checksumAlgorithmFn, readableStream) : void 0;
      const reader = readableStream.getReader();
      return new ReadableStream({
        async pull(controller) {
          const { value, done } = await reader.read();
          if (done) {
            controller.enqueue(`0\r
`);
            if (checksumRequired) {
              const checksum = base64Encoder(await digest);
              controller.enqueue(`${checksumLocationName}:${checksum}\r
`);
              controller.enqueue(`\r
`);
            }
            controller.close();
          } else {
            controller.enqueue(`${(bodyLengthChecker(value) || 0).toString(16)}\r
${value}\r
`);
          }
        }
      });
    }, "getAwsChunkedEncodingStream");
    exports2.getAwsChunkedEncodingStream = getAwsChunkedEncodingStream5;
  }
});

// ../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.js
var require_getAwsChunkedEncodingStream3 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getAwsChunkedEncodingStream = getAwsChunkedEncodingStream5;
    var node_stream_1 = require("node:stream");
    var getAwsChunkedEncodingStream_browser_1 = require_getAwsChunkedEncodingStream_browser3();
    var stream_type_check_1 = require_stream_type_check3();
    function getAwsChunkedEncodingStream5(stream, options) {
      const readable = stream;
      const readableStream = stream;
      if ((0, stream_type_check_1.isReadableStream)(readableStream)) {
        return (0, getAwsChunkedEncodingStream_browser_1.getAwsChunkedEncodingStream)(readableStream, options);
      }
      const { base64Encoder, bodyLengthChecker, checksumAlgorithmFn, checksumLocationName, streamHasher } = options;
      const checksumRequired = base64Encoder !== void 0 && checksumAlgorithmFn !== void 0 && checksumLocationName !== void 0 && streamHasher !== void 0;
      const digest = checksumRequired ? streamHasher(checksumAlgorithmFn, readable) : void 0;
      const awsChunkedEncodingStream = new node_stream_1.Readable({
        read: /* @__PURE__ */ __name(() => {
        }, "read")
      });
      readable.on("data", (data3) => {
        const length = bodyLengthChecker(data3) || 0;
        if (length === 0) {
          return;
        }
        awsChunkedEncodingStream.push(`${length.toString(16)}\r
`);
        awsChunkedEncodingStream.push(data3);
        awsChunkedEncodingStream.push("\r\n");
      });
      readable.on("end", async () => {
        awsChunkedEncodingStream.push(`0\r
`);
        if (checksumRequired) {
          const checksum = base64Encoder(await digest);
          awsChunkedEncodingStream.push(`${checksumLocationName}:${checksum}\r
`);
          awsChunkedEncodingStream.push(`\r
`);
        }
        awsChunkedEncodingStream.push(null);
      });
      return awsChunkedEncodingStream;
    }
    __name(getAwsChunkedEncodingStream5, "getAwsChunkedEncodingStream");
  }
});

// ../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/headStream.browser.js
var require_headStream_browser3 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/headStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.headStream = headStream5;
    async function headStream5(stream, bytes) {
      let byteLengthCounter = 0;
      const chunks2 = [];
      const reader = stream.getReader();
      let isDone = false;
      while (!isDone) {
        const { done, value } = await reader.read();
        if (value) {
          chunks2.push(value);
          byteLengthCounter += value?.byteLength ?? 0;
        }
        if (byteLengthCounter >= bytes) {
          break;
        }
        isDone = done;
      }
      reader.releaseLock();
      const collected = new Uint8Array(Math.min(bytes, byteLengthCounter));
      let offset = 0;
      for (const chunk of chunks2) {
        if (chunk.byteLength > collected.byteLength - offset) {
          collected.set(chunk.subarray(0, collected.byteLength - offset), offset);
          break;
        } else {
          collected.set(chunk, offset);
        }
        offset += chunk.length;
      }
      return collected;
    }
    __name(headStream5, "headStream");
  }
});

// ../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/headStream.js
var require_headStream3 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/headStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.headStream = void 0;
    var stream_1 = require("stream");
    var headStream_browser_1 = require_headStream_browser3();
    var stream_type_check_1 = require_stream_type_check3();
    var headStream5 = /* @__PURE__ */ __name((stream, bytes) => {
      if ((0, stream_type_check_1.isReadableStream)(stream)) {
        return (0, headStream_browser_1.headStream)(stream, bytes);
      }
      return new Promise((resolve13, reject) => {
        const collector = new Collector8();
        collector.limit = bytes;
        stream.pipe(collector);
        stream.on("error", (err) => {
          collector.end();
          reject(err);
        });
        collector.on("error", reject);
        collector.on("finish", function() {
          const bytes2 = new Uint8Array(Buffer.concat(this.buffers));
          resolve13(bytes2);
        });
      });
    }, "headStream");
    exports2.headStream = headStream5;
    var Collector8 = class extends stream_1.Writable {
      static {
        __name(this, "Collector");
      }
      buffers = [];
      limit = Infinity;
      bytesBuffered = 0;
      _write(chunk, encoding, callback) {
        this.buffers.push(chunk);
        this.bytesBuffered += chunk.byteLength ?? 0;
        if (this.bytesBuffered >= this.limit) {
          const excess = this.bytesBuffered - this.limit;
          const tailBuffer = this.buffers[this.buffers.length - 1];
          this.buffers[this.buffers.length - 1] = tailBuffer.subarray(0, tailBuffer.byteLength - excess);
          this.emit("finish");
        }
        callback();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.browser.js
var require_sdk_stream_mixin_browser3 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.sdkStreamMixin = void 0;
    var fetch_http_handler_1 = require_dist_cjs14();
    var util_base64_1 = require_dist_cjs10();
    var util_hex_encoding_1 = require_dist_cjs15();
    var util_utf8_1 = require_dist_cjs9();
    var stream_type_check_1 = require_stream_type_check3();
    var ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11 = "The stream has already been transformed.";
    var sdkStreamMixin12 = /* @__PURE__ */ __name((stream) => {
      if (!isBlobInstance6(stream) && !(0, stream_type_check_1.isReadableStream)(stream)) {
        const name = stream?.__proto__?.constructor?.name || stream;
        throw new Error(`Unexpected stream implementation, expect Blob or ReadableStream, got ${name}`);
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
        }
        transformed = true;
        return await (0, fetch_http_handler_1.streamCollector)(stream);
      }, "transformToByteArray");
      const blobToWebStream = /* @__PURE__ */ __name((blob) => {
        if (typeof blob.stream !== "function") {
          throw new Error("Cannot transform payload Blob to web stream. Please make sure the Blob.stream() is polyfilled.\nIf you are using React Native, this API is not yet supported, see: https://react-native.canny.io/feature-requests/p/fetch-streaming-body");
        }
        return blob.stream();
      }, "blobToWebStream");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === "base64") {
            return (0, util_base64_1.toBase64)(buf);
          } else if (encoding === "hex") {
            return (0, util_hex_encoding_1.toHex)(buf);
          } else if (encoding === void 0 || encoding === "utf8" || encoding === "utf-8") {
            return (0, util_utf8_1.toUtf8)(buf);
          } else if (typeof TextDecoder === "function") {
            return new TextDecoder(encoding).decode(buf);
          } else {
            throw new Error("TextDecoder is not available, please make sure polyfill is provided.");
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
          }
          transformed = true;
          if (isBlobInstance6(stream)) {
            return blobToWebStream(stream);
          } else if ((0, stream_type_check_1.isReadableStream)(stream)) {
            return stream;
          } else {
            throw new Error(`Cannot transform payload to web stream, got ${stream}`);
          }
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
    exports2.sdkStreamMixin = sdkStreamMixin12;
    var isBlobInstance6 = /* @__PURE__ */ __name((stream) => typeof Blob === "function" && stream instanceof Blob, "isBlobInstance");
  }
});

// ../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.js
var require_sdk_stream_mixin3 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.sdkStreamMixin = void 0;
    var node_http_handler_1 = require_dist_cjs13();
    var util_buffer_from_1 = require_dist_cjs8();
    var stream_1 = require("stream");
    var sdk_stream_mixin_browser_1 = require_sdk_stream_mixin_browser3();
    var ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11 = "The stream has already been transformed.";
    var sdkStreamMixin12 = /* @__PURE__ */ __name((stream) => {
      if (!(stream instanceof stream_1.Readable)) {
        try {
          return (0, sdk_stream_mixin_browser_1.sdkStreamMixin)(stream);
        } catch (e32) {
          const name = stream?.__proto__?.constructor?.name || stream;
          throw new Error(`Unexpected stream implementation, expect Stream.Readable instance, got ${name}`);
        }
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
        }
        transformed = true;
        return await (0, node_http_handler_1.streamCollector)(stream);
      }, "transformToByteArray");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === void 0 || Buffer.isEncoding(encoding)) {
            return (0, util_buffer_from_1.fromArrayBuffer)(buf.buffer, buf.byteOffset, buf.byteLength).toString(encoding);
          } else {
            const decoder = new TextDecoder(encoding);
            return decoder.decode(buf);
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
          }
          if (stream.readableFlowing !== null) {
            throw new Error("The stream has been consumed by other callbacks.");
          }
          if (typeof stream_1.Readable.toWeb !== "function") {
            throw new Error("Readable.toWeb() is not supported. Please ensure a polyfill is available.");
          }
          transformed = true;
          return stream_1.Readable.toWeb(stream);
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
    exports2.sdkStreamMixin = sdkStreamMixin12;
  }
});

// ../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/splitStream.browser.js
var require_splitStream_browser3 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/splitStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.splitStream = splitStream5;
    async function splitStream5(stream) {
      if (typeof stream.stream === "function") {
        stream = stream.stream();
      }
      const readableStream = stream;
      return readableStream.tee();
    }
    __name(splitStream5, "splitStream");
  }
});

// ../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/splitStream.js
var require_splitStream3 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/splitStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.splitStream = splitStream5;
    var stream_1 = require("stream");
    var splitStream_browser_1 = require_splitStream_browser3();
    var stream_type_check_1 = require_stream_type_check3();
    async function splitStream5(stream) {
      if ((0, stream_type_check_1.isReadableStream)(stream) || (0, stream_type_check_1.isBlob)(stream)) {
        return (0, splitStream_browser_1.splitStream)(stream);
      }
      const stream1 = new stream_1.PassThrough();
      const stream2 = new stream_1.PassThrough();
      stream.pipe(stream1);
      stream.pipe(stream2);
      return [stream1, stream2];
    }
    __name(splitStream5, "splitStream");
  }
});

// ../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/index.js
var require_dist_cjs63 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-flexible-checksums/node_modules/@smithy/util-stream/dist-cjs/index.js"(exports2) {
    "use strict";
    var utilBase64 = require_dist_cjs10();
    var utilUtf8 = require_dist_cjs9();
    var ChecksumStream5 = require_ChecksumStream3();
    var createChecksumStream5 = require_createChecksumStream3();
    var createBufferedReadable3 = require_createBufferedReadable3();
    var getAwsChunkedEncodingStream5 = require_getAwsChunkedEncodingStream3();
    var headStream5 = require_headStream3();
    var sdkStreamMixin12 = require_sdk_stream_mixin3();
    var splitStream5 = require_splitStream3();
    var streamTypeCheck = require_stream_type_check3();
    var Uint8ArrayBlobAdapter8 = class _Uint8ArrayBlobAdapter extends Uint8Array {
      static {
        __name(this, "Uint8ArrayBlobAdapter");
      }
      static fromString(source, encoding = "utf-8") {
        if (typeof source === "string") {
          if (encoding === "base64") {
            return _Uint8ArrayBlobAdapter.mutate(utilBase64.fromBase64(source));
          }
          return _Uint8ArrayBlobAdapter.mutate(utilUtf8.fromUtf8(source));
        }
        throw new Error(`Unsupported conversion from ${typeof source} to Uint8ArrayBlobAdapter.`);
      }
      static mutate(source) {
        Object.setPrototypeOf(source, _Uint8ArrayBlobAdapter.prototype);
        return source;
      }
      transformToString(encoding = "utf-8") {
        if (encoding === "base64") {
          return utilBase64.toBase64(this);
        }
        return utilUtf8.toUtf8(this);
      }
    };
    exports2.isBlob = streamTypeCheck.isBlob;
    exports2.isReadableStream = streamTypeCheck.isReadableStream;
    exports2.Uint8ArrayBlobAdapter = Uint8ArrayBlobAdapter8;
    Object.prototype.hasOwnProperty.call(ChecksumStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: ChecksumStream5["__proto__"]
    });
    Object.keys(ChecksumStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = ChecksumStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(createChecksumStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: createChecksumStream5["__proto__"]
    });
    Object.keys(createChecksumStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = createChecksumStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(createBufferedReadable3, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: createBufferedReadable3["__proto__"]
    });
    Object.keys(createBufferedReadable3).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = createBufferedReadable3[k32];
    });
    Object.prototype.hasOwnProperty.call(getAwsChunkedEncodingStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: getAwsChunkedEncodingStream5["__proto__"]
    });
    Object.keys(getAwsChunkedEncodingStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = getAwsChunkedEncodingStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(headStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: headStream5["__proto__"]
    });
    Object.keys(headStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = headStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(sdkStreamMixin12, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: sdkStreamMixin12["__proto__"]
    });
    Object.keys(sdkStreamMixin12).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = sdkStreamMixin12[k32];
    });
    Object.prototype.hasOwnProperty.call(splitStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: splitStream5["__proto__"]
    });
    Object.keys(splitStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = splitStream5[k32];
    });
  }
});

// ../../node_modules/@aws-crypto/util/node_modules/@smithy/is-array-buffer/dist-cjs/index.js
var require_dist_cjs64 = __commonJS({
  "../../node_modules/@aws-crypto/util/node_modules/@smithy/is-array-buffer/dist-cjs/index.js"(exports2, module2) {
    var __defProp2 = Object.defineProperty;
    var __getOwnPropDesc2 = Object.getOwnPropertyDescriptor;
    var __getOwnPropNames2 = Object.getOwnPropertyNames;
    var __hasOwnProp2 = Object.prototype.hasOwnProperty;
    var __name2 = /* @__PURE__ */ __name((target, value) => __defProp2(target, "name", { value, configurable: true }), "__name");
    var __export2 = /* @__PURE__ */ __name((target, all) => {
      for (var name in all)
        __defProp2(target, name, { get: all[name], enumerable: true });
    }, "__export");
    var __copyProps2 = /* @__PURE__ */ __name((to, from, except, desc) => {
      if (from && typeof from === "object" || typeof from === "function") {
        for (let key of __getOwnPropNames2(from))
          if (!__hasOwnProp2.call(to, key) && key !== except)
            __defProp2(to, key, { get: /* @__PURE__ */ __name(() => from[key], "get"), enumerable: !(desc = __getOwnPropDesc2(from, key)) || desc.enumerable });
      }
      return to;
    }, "__copyProps");
    var __toCommonJS2 = /* @__PURE__ */ __name((mod) => __copyProps2(__defProp2({}, "__esModule", { value: true }), mod), "__toCommonJS");
    var src_exports = {};
    __export2(src_exports, {
      isArrayBuffer: /* @__PURE__ */ __name(() => isArrayBuffer7, "isArrayBuffer")
    });
    module2.exports = __toCommonJS2(src_exports);
    var isArrayBuffer7 = /* @__PURE__ */ __name2((arg) => typeof ArrayBuffer === "function" && arg instanceof ArrayBuffer || Object.prototype.toString.call(arg) === "[object ArrayBuffer]", "isArrayBuffer");
  }
});

// ../../node_modules/@aws-crypto/util/node_modules/@smithy/util-buffer-from/dist-cjs/index.js
var require_dist_cjs65 = __commonJS({
  "../../node_modules/@aws-crypto/util/node_modules/@smithy/util-buffer-from/dist-cjs/index.js"(exports2, module2) {
    var __defProp2 = Object.defineProperty;
    var __getOwnPropDesc2 = Object.getOwnPropertyDescriptor;
    var __getOwnPropNames2 = Object.getOwnPropertyNames;
    var __hasOwnProp2 = Object.prototype.hasOwnProperty;
    var __name2 = /* @__PURE__ */ __name((target, value) => __defProp2(target, "name", { value, configurable: true }), "__name");
    var __export2 = /* @__PURE__ */ __name((target, all) => {
      for (var name in all)
        __defProp2(target, name, { get: all[name], enumerable: true });
    }, "__export");
    var __copyProps2 = /* @__PURE__ */ __name((to, from, except, desc) => {
      if (from && typeof from === "object" || typeof from === "function") {
        for (let key of __getOwnPropNames2(from))
          if (!__hasOwnProp2.call(to, key) && key !== except)
            __defProp2(to, key, { get: /* @__PURE__ */ __name(() => from[key], "get"), enumerable: !(desc = __getOwnPropDesc2(from, key)) || desc.enumerable });
      }
      return to;
    }, "__copyProps");
    var __toCommonJS2 = /* @__PURE__ */ __name((mod) => __copyProps2(__defProp2({}, "__esModule", { value: true }), mod), "__toCommonJS");
    var src_exports = {};
    __export2(src_exports, {
      fromArrayBuffer: /* @__PURE__ */ __name(() => fromArrayBuffer7, "fromArrayBuffer"),
      fromString: /* @__PURE__ */ __name(() => fromString7, "fromString")
    });
    module2.exports = __toCommonJS2(src_exports);
    var import_is_array_buffer9 = require_dist_cjs64();
    var import_buffer = require("buffer");
    var fromArrayBuffer7 = /* @__PURE__ */ __name2((input, offset = 0, length = input.byteLength - offset) => {
      if (!(0, import_is_array_buffer9.isArrayBuffer)(input)) {
        throw new TypeError(`The "input" argument must be ArrayBuffer. Received type ${typeof input} (${input})`);
      }
      return import_buffer.Buffer.from(input, offset, length);
    }, "fromArrayBuffer");
    var fromString7 = /* @__PURE__ */ __name2((input, encoding) => {
      if (typeof input !== "string") {
        throw new TypeError(`The "input" argument must be of type string. Received type ${typeof input} (${input})`);
      }
      return encoding ? import_buffer.Buffer.from(input, encoding) : import_buffer.Buffer.from(input);
    }, "fromString");
  }
});

// ../../node_modules/@aws-crypto/util/node_modules/@smithy/util-utf8/dist-cjs/index.js
var require_dist_cjs66 = __commonJS({
  "../../node_modules/@aws-crypto/util/node_modules/@smithy/util-utf8/dist-cjs/index.js"(exports2, module2) {
    var __defProp2 = Object.defineProperty;
    var __getOwnPropDesc2 = Object.getOwnPropertyDescriptor;
    var __getOwnPropNames2 = Object.getOwnPropertyNames;
    var __hasOwnProp2 = Object.prototype.hasOwnProperty;
    var __name2 = /* @__PURE__ */ __name((target, value) => __defProp2(target, "name", { value, configurable: true }), "__name");
    var __export2 = /* @__PURE__ */ __name((target, all) => {
      for (var name in all)
        __defProp2(target, name, { get: all[name], enumerable: true });
    }, "__export");
    var __copyProps2 = /* @__PURE__ */ __name((to, from, except, desc) => {
      if (from && typeof from === "object" || typeof from === "function") {
        for (let key of __getOwnPropNames2(from))
          if (!__hasOwnProp2.call(to, key) && key !== except)
            __defProp2(to, key, { get: /* @__PURE__ */ __name(() => from[key], "get"), enumerable: !(desc = __getOwnPropDesc2(from, key)) || desc.enumerable });
      }
      return to;
    }, "__copyProps");
    var __toCommonJS2 = /* @__PURE__ */ __name((mod) => __copyProps2(__defProp2({}, "__esModule", { value: true }), mod), "__toCommonJS");
    var src_exports = {};
    __export2(src_exports, {
      fromUtf8: /* @__PURE__ */ __name(() => fromUtf842, "fromUtf8"),
      toUint8Array: /* @__PURE__ */ __name(() => toUint8Array5, "toUint8Array"),
      toUtf8: /* @__PURE__ */ __name(() => toUtf862, "toUtf8")
    });
    module2.exports = __toCommonJS2(src_exports);
    var import_util_buffer_from = require_dist_cjs65();
    var fromUtf842 = /* @__PURE__ */ __name2((input) => {
      const buf = (0, import_util_buffer_from.fromString)(input, "utf8");
      return new Uint8Array(buf.buffer, buf.byteOffset, buf.byteLength / Uint8Array.BYTES_PER_ELEMENT);
    }, "fromUtf8");
    var toUint8Array5 = /* @__PURE__ */ __name2((data3) => {
      if (typeof data3 === "string") {
        return fromUtf842(data3);
      }
      if (ArrayBuffer.isView(data3)) {
        return new Uint8Array(data3.buffer, data3.byteOffset, data3.byteLength / Uint8Array.BYTES_PER_ELEMENT);
      }
      return new Uint8Array(data3);
    }, "toUint8Array");
    var toUtf862 = /* @__PURE__ */ __name2((input) => {
      if (typeof input === "string") {
        return input;
      }
      if (typeof input !== "object" || typeof input.byteOffset !== "number" || typeof input.byteLength !== "number") {
        throw new Error("@smithy/util-utf8: toUtf8 encoder function only accepts string | Uint8Array.");
      }
      return (0, import_util_buffer_from.fromArrayBuffer)(input.buffer, input.byteOffset, input.byteLength).toString("utf8");
    }, "toUtf8");
  }
});

// ../../node_modules/@aws-crypto/util/build/main/convertToBuffer.js
var require_convertToBuffer = __commonJS({
  "../../node_modules/@aws-crypto/util/build/main/convertToBuffer.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.convertToBuffer = void 0;
    var util_utf8_1 = require_dist_cjs66();
    var fromUtf842 = typeof Buffer !== "undefined" && Buffer.from ? function(input) {
      return Buffer.from(input, "utf8");
    } : util_utf8_1.fromUtf8;
    function convertToBuffer(data3) {
      if (data3 instanceof Uint8Array)
        return data3;
      if (typeof data3 === "string") {
        return fromUtf842(data3);
      }
      if (ArrayBuffer.isView(data3)) {
        return new Uint8Array(data3.buffer, data3.byteOffset, data3.byteLength / Uint8Array.BYTES_PER_ELEMENT);
      }
      return new Uint8Array(data3);
    }
    __name(convertToBuffer, "convertToBuffer");
    exports2.convertToBuffer = convertToBuffer;
  }
});

// ../../node_modules/@aws-crypto/util/build/main/isEmptyData.js
var require_isEmptyData = __commonJS({
  "../../node_modules/@aws-crypto/util/build/main/isEmptyData.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isEmptyData = void 0;
    function isEmptyData(data3) {
      if (typeof data3 === "string") {
        return data3.length === 0;
      }
      return data3.byteLength === 0;
    }
    __name(isEmptyData, "isEmptyData");
    exports2.isEmptyData = isEmptyData;
  }
});

// ../../node_modules/@aws-crypto/util/build/main/numToUint8.js
var require_numToUint8 = __commonJS({
  "../../node_modules/@aws-crypto/util/build/main/numToUint8.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.numToUint8 = void 0;
    function numToUint8(num) {
      return new Uint8Array([
        (num & 4278190080) >> 24,
        (num & 16711680) >> 16,
        (num & 65280) >> 8,
        num & 255
      ]);
    }
    __name(numToUint8, "numToUint8");
    exports2.numToUint8 = numToUint8;
  }
});

// ../../node_modules/@aws-crypto/util/build/main/uint32ArrayFrom.js
var require_uint32ArrayFrom = __commonJS({
  "../../node_modules/@aws-crypto/util/build/main/uint32ArrayFrom.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.uint32ArrayFrom = void 0;
    function uint32ArrayFrom(a_lookUpTable) {
      if (!Uint32Array.from) {
        var return_array = new Uint32Array(a_lookUpTable.length);
        var a_index = 0;
        while (a_index < a_lookUpTable.length) {
          return_array[a_index] = a_lookUpTable[a_index];
          a_index += 1;
        }
        return return_array;
      }
      return Uint32Array.from(a_lookUpTable);
    }
    __name(uint32ArrayFrom, "uint32ArrayFrom");
    exports2.uint32ArrayFrom = uint32ArrayFrom;
  }
});

// ../../node_modules/@aws-crypto/util/build/main/index.js
var require_main = __commonJS({
  "../../node_modules/@aws-crypto/util/build/main/index.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.uint32ArrayFrom = exports2.numToUint8 = exports2.isEmptyData = exports2.convertToBuffer = void 0;
    var convertToBuffer_1 = require_convertToBuffer();
    Object.defineProperty(exports2, "convertToBuffer", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return convertToBuffer_1.convertToBuffer;
    }, "get") });
    var isEmptyData_1 = require_isEmptyData();
    Object.defineProperty(exports2, "isEmptyData", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return isEmptyData_1.isEmptyData;
    }, "get") });
    var numToUint8_1 = require_numToUint8();
    Object.defineProperty(exports2, "numToUint8", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return numToUint8_1.numToUint8;
    }, "get") });
    var uint32ArrayFrom_1 = require_uint32ArrayFrom();
    Object.defineProperty(exports2, "uint32ArrayFrom", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return uint32ArrayFrom_1.uint32ArrayFrom;
    }, "get") });
  }
});

// ../../node_modules/@aws-crypto/crc32c/build/main/aws_crc32c.js
var require_aws_crc32c = __commonJS({
  "../../node_modules/@aws-crypto/crc32c/build/main/aws_crc32c.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.AwsCrc32c = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var util_1 = require_main();
    var index_1 = require_main2();
    var AwsCrc32c = (
      /** @class */
      (function() {
        function AwsCrc32c2() {
          this.crc32c = new index_1.Crc32c();
        }
        __name(AwsCrc32c2, "AwsCrc32c");
        AwsCrc32c2.prototype.update = function(toHash) {
          if ((0, util_1.isEmptyData)(toHash))
            return;
          this.crc32c.update((0, util_1.convertToBuffer)(toHash));
        };
        AwsCrc32c2.prototype.digest = function() {
          return tslib_1.__awaiter(this, void 0, void 0, function() {
            return tslib_1.__generator(this, function(_a10) {
              return [2, (0, util_1.numToUint8)(this.crc32c.digest())];
            });
          });
        };
        AwsCrc32c2.prototype.reset = function() {
          this.crc32c = new index_1.Crc32c();
        };
        return AwsCrc32c2;
      })()
    );
    exports2.AwsCrc32c = AwsCrc32c;
  }
});

// ../../node_modules/@aws-crypto/crc32c/build/main/index.js
var require_main2 = __commonJS({
  "../../node_modules/@aws-crypto/crc32c/build/main/index.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.AwsCrc32c = exports2.Crc32c = exports2.crc32c = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var util_1 = require_main();
    function crc32c(data3) {
      return new Crc32c().update(data3).digest();
    }
    __name(crc32c, "crc32c");
    exports2.crc32c = crc32c;
    var Crc32c = (
      /** @class */
      (function() {
        function Crc32c2() {
          this.checksum = 4294967295;
        }
        __name(Crc32c2, "Crc32c");
        Crc32c2.prototype.update = function(data3) {
          var e_1, _a10;
          try {
            for (var data_1 = tslib_1.__values(data3), data_1_1 = data_1.next(); !data_1_1.done; data_1_1 = data_1.next()) {
              var byte = data_1_1.value;
              this.checksum = this.checksum >>> 8 ^ lookupTable[(this.checksum ^ byte) & 255];
            }
          } catch (e_1_1) {
            e_1 = { error: e_1_1 };
          } finally {
            try {
              if (data_1_1 && !data_1_1.done && (_a10 = data_1.return)) _a10.call(data_1);
            } finally {
              if (e_1) throw e_1.error;
            }
          }
          return this;
        };
        Crc32c2.prototype.digest = function() {
          return (this.checksum ^ 4294967295) >>> 0;
        };
        return Crc32c2;
      })()
    );
    exports2.Crc32c = Crc32c;
    var a_lookupTable = [
      0,
      4067132163,
      3778769143,
      324072436,
      3348797215,
      904991772,
      648144872,
      3570033899,
      2329499855,
      2024987596,
      1809983544,
      2575936315,
      1296289744,
      3207089363,
      2893594407,
      1578318884,
      274646895,
      3795141740,
      4049975192,
      51262619,
      3619967088,
      632279923,
      922689671,
      3298075524,
      2592579488,
      1760304291,
      2075979607,
      2312596564,
      1562183871,
      2943781820,
      3156637768,
      1313733451,
      549293790,
      3537243613,
      3246849577,
      871202090,
      3878099393,
      357341890,
      102525238,
      4101499445,
      2858735121,
      1477399826,
      1264559846,
      3107202533,
      1845379342,
      2677391885,
      2361733625,
      2125378298,
      820201905,
      3263744690,
      3520608582,
      598981189,
      4151959214,
      85089709,
      373468761,
      3827903834,
      3124367742,
      1213305469,
      1526817161,
      2842354314,
      2107672161,
      2412447074,
      2627466902,
      1861252501,
      1098587580,
      3004210879,
      2688576843,
      1378610760,
      2262928035,
      1955203488,
      1742404180,
      2511436119,
      3416409459,
      969524848,
      714683780,
      3639785095,
      205050476,
      4266873199,
      3976438427,
      526918040,
      1361435347,
      2739821008,
      2954799652,
      1114974503,
      2529119692,
      1691668175,
      2005155131,
      2247081528,
      3690758684,
      697762079,
      986182379,
      3366744552,
      476452099,
      3993867776,
      4250756596,
      255256311,
      1640403810,
      2477592673,
      2164122517,
      1922457750,
      2791048317,
      1412925310,
      1197962378,
      3037525897,
      3944729517,
      427051182,
      170179418,
      4165941337,
      746937522,
      3740196785,
      3451792453,
      1070968646,
      1905808397,
      2213795598,
      2426610938,
      1657317369,
      3053634322,
      1147748369,
      1463399397,
      2773627110,
      4215344322,
      153784257,
      444234805,
      3893493558,
      1021025245,
      3467647198,
      3722505002,
      797665321,
      2197175160,
      1889384571,
      1674398607,
      2443626636,
      1164749927,
      3070701412,
      2757221520,
      1446797203,
      137323447,
      4198817972,
      3910406976,
      461344835,
      3484808360,
      1037989803,
      781091935,
      3705997148,
      2460548119,
      1623424788,
      1939049696,
      2180517859,
      1429367560,
      2807687179,
      3020495871,
      1180866812,
      410100952,
      3927582683,
      4182430767,
      186734380,
      3756733383,
      763408580,
      1053836080,
      3434856499,
      2722870694,
      1344288421,
      1131464017,
      2971354706,
      1708204729,
      2545590714,
      2229949006,
      1988219213,
      680717673,
      3673779818,
      3383336350,
      1002577565,
      4010310262,
      493091189,
      238226049,
      4233660802,
      2987750089,
      1082061258,
      1395524158,
      2705686845,
      1972364758,
      2279892693,
      2494862625,
      1725896226,
      952904198,
      3399985413,
      3656866545,
      731699698,
      4283874585,
      222117402,
      510512622,
      3959836397,
      3280807620,
      837199303,
      582374963,
      3504198960,
      68661723,
      4135334616,
      3844915500,
      390545967,
      1230274059,
      3141532936,
      2825850620,
      1510247935,
      2395924756,
      2091215383,
      1878366691,
      2644384480,
      3553878443,
      565732008,
      854102364,
      3229815391,
      340358836,
      3861050807,
      4117890627,
      119113024,
      1493875044,
      2875275879,
      3090270611,
      1247431312,
      2660249211,
      1828433272,
      2141937292,
      2378227087,
      3811616794,
      291187481,
      34330861,
      4032846830,
      615137029,
      3603020806,
      3314634738,
      939183345,
      1776939221,
      2609017814,
      2295496738,
      2058945313,
      2926798794,
      1545135305,
      1330124605,
      3173225534,
      4084100981,
      17165430,
      307568514,
      3762199681,
      888469610,
      3332340585,
      3587147933,
      665062302,
      2042050490,
      2346497209,
      2559330125,
      1793573966,
      3190661285,
      1279665062,
      1595330642,
      2910671697
    ];
    var lookupTable = (0, util_1.uint32ArrayFrom)(a_lookupTable);
    var aws_crc32c_1 = require_aws_crc32c();
    Object.defineProperty(exports2, "AwsCrc32c", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return aws_crc32c_1.AwsCrc32c;
    }, "get") });
  }
});

// ../../node_modules/@aws-sdk/crc64-nvme/dist-cjs/index.js
var require_dist_cjs67 = __commonJS({
  "../../node_modules/@aws-sdk/crc64-nvme/dist-cjs/index.js"(exports2) {
    "use strict";
    var generateCRC64NVMETable = /* @__PURE__ */ __name(() => {
      const sliceLength = 8;
      const tables = new Array(sliceLength);
      for (let slice = 0; slice < sliceLength; slice++) {
        const table3 = new Array(512);
        for (let i32 = 0; i32 < 256; i32++) {
          let crc = BigInt(i32);
          for (let j32 = 0; j32 < 8 * (slice + 1); j32++) {
            if (crc & 1n) {
              crc = crc >> 1n ^ 0x9a6c9329ac4bc9b5n;
            } else {
              crc = crc >> 1n;
            }
          }
          table3[i32 * 2] = Number(crc >> 32n & 0xffffffffn);
          table3[i32 * 2 + 1] = Number(crc & 0xffffffffn);
        }
        tables[slice] = new Uint32Array(table3);
      }
      return tables;
    }, "generateCRC64NVMETable");
    var CRC64_NVME_REVERSED_TABLE;
    var t0;
    var t1;
    var t2;
    var t3;
    var t4;
    var t5;
    var t6;
    var t7;
    var ensureTablesInitialized = /* @__PURE__ */ __name(() => {
      if (!CRC64_NVME_REVERSED_TABLE) {
        CRC64_NVME_REVERSED_TABLE = generateCRC64NVMETable();
        [t0, t1, t2, t3, t4, t5, t6, t7] = CRC64_NVME_REVERSED_TABLE;
      }
    }, "ensureTablesInitialized");
    var Crc64Nvme = class {
      static {
        __name(this, "Crc64Nvme");
      }
      c1 = 0;
      c2 = 0;
      constructor() {
        ensureTablesInitialized();
        this.reset();
      }
      update(data3) {
        const len = data3.length;
        let i32 = 0;
        let crc1 = this.c1;
        let crc2 = this.c2;
        while (i32 + 8 <= len) {
          const idx0 = ((crc2 ^ data3[i32++]) & 255) << 1;
          const idx1 = ((crc2 >>> 8 ^ data3[i32++]) & 255) << 1;
          const idx2 = ((crc2 >>> 16 ^ data3[i32++]) & 255) << 1;
          const idx3 = ((crc2 >>> 24 ^ data3[i32++]) & 255) << 1;
          const idx4 = ((crc1 ^ data3[i32++]) & 255) << 1;
          const idx5 = ((crc1 >>> 8 ^ data3[i32++]) & 255) << 1;
          const idx6 = ((crc1 >>> 16 ^ data3[i32++]) & 255) << 1;
          const idx7 = ((crc1 >>> 24 ^ data3[i32++]) & 255) << 1;
          crc1 = t7[idx0] ^ t6[idx1] ^ t5[idx2] ^ t4[idx3] ^ t3[idx4] ^ t2[idx5] ^ t1[idx6] ^ t0[idx7];
          crc2 = t7[idx0 + 1] ^ t6[idx1 + 1] ^ t5[idx2 + 1] ^ t4[idx3 + 1] ^ t3[idx4 + 1] ^ t2[idx5 + 1] ^ t1[idx6 + 1] ^ t0[idx7 + 1];
        }
        while (i32 < len) {
          const idx = ((crc2 ^ data3[i32]) & 255) << 1;
          crc2 = (crc2 >>> 8 | (crc1 & 255) << 24) >>> 0;
          crc1 = crc1 >>> 8 ^ t0[idx];
          crc2 ^= t0[idx + 1];
          i32++;
        }
        this.c1 = crc1;
        this.c2 = crc2;
      }
      async digest() {
        const c1 = this.c1 ^ 4294967295;
        const c210 = this.c2 ^ 4294967295;
        return new Uint8Array([
          c1 >>> 24,
          c1 >>> 16 & 255,
          c1 >>> 8 & 255,
          c1 & 255,
          c210 >>> 24,
          c210 >>> 16 & 255,
          c210 >>> 8 & 255,
          c210 & 255
        ]);
      }
      reset() {
        this.c1 = 4294967295;
        this.c2 = 4294967295;
      }
    };
    var crc64NvmeCrtContainer = {
      CrtCrc64Nvme: null
    };
    exports2.Crc64Nvme = Crc64Nvme;
    exports2.crc64NvmeCrtContainer = crc64NvmeCrtContainer;
  }
});

// ../../node_modules/@aws-crypto/crc32/build/main/aws_crc32.js
var require_aws_crc32 = __commonJS({
  "../../node_modules/@aws-crypto/crc32/build/main/aws_crc32.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.AwsCrc32 = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var util_1 = require_main();
    var index_1 = require_main3();
    var AwsCrc32 = (
      /** @class */
      (function() {
        function AwsCrc322() {
          this.crc32 = new index_1.Crc32();
        }
        __name(AwsCrc322, "AwsCrc32");
        AwsCrc322.prototype.update = function(toHash) {
          if ((0, util_1.isEmptyData)(toHash))
            return;
          this.crc32.update((0, util_1.convertToBuffer)(toHash));
        };
        AwsCrc322.prototype.digest = function() {
          return tslib_1.__awaiter(this, void 0, void 0, function() {
            return tslib_1.__generator(this, function(_a10) {
              return [2, (0, util_1.numToUint8)(this.crc32.digest())];
            });
          });
        };
        AwsCrc322.prototype.reset = function() {
          this.crc32 = new index_1.Crc32();
        };
        return AwsCrc322;
      })()
    );
    exports2.AwsCrc32 = AwsCrc32;
  }
});

// ../../node_modules/@aws-crypto/crc32/build/main/index.js
var require_main3 = __commonJS({
  "../../node_modules/@aws-crypto/crc32/build/main/index.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.AwsCrc32 = exports2.Crc32 = exports2.crc32 = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var util_1 = require_main();
    function crc32(data3) {
      return new Crc3211().update(data3).digest();
    }
    __name(crc32, "crc32");
    exports2.crc32 = crc32;
    var Crc3211 = (
      /** @class */
      (function() {
        function Crc3212() {
          this.checksum = 4294967295;
        }
        __name(Crc3212, "Crc32");
        Crc3212.prototype.update = function(data3) {
          var e_1, _a10;
          try {
            for (var data_1 = tslib_1.__values(data3), data_1_1 = data_1.next(); !data_1_1.done; data_1_1 = data_1.next()) {
              var byte = data_1_1.value;
              this.checksum = this.checksum >>> 8 ^ lookupTable[(this.checksum ^ byte) & 255];
            }
          } catch (e_1_1) {
            e_1 = { error: e_1_1 };
          } finally {
            try {
              if (data_1_1 && !data_1_1.done && (_a10 = data_1.return)) _a10.call(data_1);
            } finally {
              if (e_1) throw e_1.error;
            }
          }
          return this;
        };
        Crc3212.prototype.digest = function() {
          return (this.checksum ^ 4294967295) >>> 0;
        };
        return Crc3212;
      })()
    );
    exports2.Crc32 = Crc3211;
    var a_lookUpTable = [
      0,
      1996959894,
      3993919788,
      2567524794,
      124634137,
      1886057615,
      3915621685,
      2657392035,
      249268274,
      2044508324,
      3772115230,
      2547177864,
      162941995,
      2125561021,
      3887607047,
      2428444049,
      498536548,
      1789927666,
      4089016648,
      2227061214,
      450548861,
      1843258603,
      4107580753,
      2211677639,
      325883990,
      1684777152,
      4251122042,
      2321926636,
      335633487,
      1661365465,
      4195302755,
      2366115317,
      997073096,
      1281953886,
      3579855332,
      2724688242,
      1006888145,
      1258607687,
      3524101629,
      2768942443,
      901097722,
      1119000684,
      3686517206,
      2898065728,
      853044451,
      1172266101,
      3705015759,
      2882616665,
      651767980,
      1373503546,
      3369554304,
      3218104598,
      565507253,
      1454621731,
      3485111705,
      3099436303,
      671266974,
      1594198024,
      3322730930,
      2970347812,
      795835527,
      1483230225,
      3244367275,
      3060149565,
      1994146192,
      31158534,
      2563907772,
      4023717930,
      1907459465,
      112637215,
      2680153253,
      3904427059,
      2013776290,
      251722036,
      2517215374,
      3775830040,
      2137656763,
      141376813,
      2439277719,
      3865271297,
      1802195444,
      476864866,
      2238001368,
      4066508878,
      1812370925,
      453092731,
      2181625025,
      4111451223,
      1706088902,
      314042704,
      2344532202,
      4240017532,
      1658658271,
      366619977,
      2362670323,
      4224994405,
      1303535960,
      984961486,
      2747007092,
      3569037538,
      1256170817,
      1037604311,
      2765210733,
      3554079995,
      1131014506,
      879679996,
      2909243462,
      3663771856,
      1141124467,
      855842277,
      2852801631,
      3708648649,
      1342533948,
      654459306,
      3188396048,
      3373015174,
      1466479909,
      544179635,
      3110523913,
      3462522015,
      1591671054,
      702138776,
      2966460450,
      3352799412,
      1504918807,
      783551873,
      3082640443,
      3233442989,
      3988292384,
      2596254646,
      62317068,
      1957810842,
      3939845945,
      2647816111,
      81470997,
      1943803523,
      3814918930,
      2489596804,
      225274430,
      2053790376,
      3826175755,
      2466906013,
      167816743,
      2097651377,
      4027552580,
      2265490386,
      503444072,
      1762050814,
      4150417245,
      2154129355,
      426522225,
      1852507879,
      4275313526,
      2312317920,
      282753626,
      1742555852,
      4189708143,
      2394877945,
      397917763,
      1622183637,
      3604390888,
      2714866558,
      953729732,
      1340076626,
      3518719985,
      2797360999,
      1068828381,
      1219638859,
      3624741850,
      2936675148,
      906185462,
      1090812512,
      3747672003,
      2825379669,
      829329135,
      1181335161,
      3412177804,
      3160834842,
      628085408,
      1382605366,
      3423369109,
      3138078467,
      570562233,
      1426400815,
      3317316542,
      2998733608,
      733239954,
      1555261956,
      3268935591,
      3050360625,
      752459403,
      1541320221,
      2607071920,
      3965973030,
      1969922972,
      40735498,
      2617837225,
      3943577151,
      1913087877,
      83908371,
      2512341634,
      3803740692,
      2075208622,
      213261112,
      2463272603,
      3855990285,
      2094854071,
      198958881,
      2262029012,
      4057260610,
      1759359992,
      534414190,
      2176718541,
      4139329115,
      1873836001,
      414664567,
      2282248934,
      4279200368,
      1711684554,
      285281116,
      2405801727,
      4167216745,
      1634467795,
      376229701,
      2685067896,
      3608007406,
      1308918612,
      956543938,
      2808555105,
      3495958263,
      1231636301,
      1047427035,
      2932959818,
      3654703836,
      1088359270,
      936918e3,
      2847714899,
      3736837829,
      1202900863,
      817233897,
      3183342108,
      3401237130,
      1404277552,
      615818150,
      3134207493,
      3453421203,
      1423857449,
      601450431,
      3009837614,
      3294710456,
      1567103746,
      711928724,
      3020668471,
      3272380065,
      1510334235,
      755167117
    ];
    var lookupTable = (0, util_1.uint32ArrayFrom)(a_lookUpTable);
    var aws_crc32_1 = require_aws_crc32();
    Object.defineProperty(exports2, "AwsCrc32", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return aws_crc32_1.AwsCrc32;
    }, "get") });
  }
});

// ../../node_modules/@aws-sdk/middleware-flexible-checksums/dist-cjs/getCrc32ChecksumAlgorithmFunction.js
var require_getCrc32ChecksumAlgorithmFunction = __commonJS({
  "../../node_modules/@aws-sdk/middleware-flexible-checksums/dist-cjs/getCrc32ChecksumAlgorithmFunction.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getCrc32ChecksumAlgorithmFunction = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var crc32_1 = require_main3();
    var util_1 = require_main();
    var zlib = tslib_1.__importStar(require("node:zlib"));
    var NodeCrc32 = class {
      static {
        __name(this, "NodeCrc32");
      }
      checksum = 0;
      update(data3) {
        this.checksum = zlib.crc32(data3, this.checksum);
      }
      async digest() {
        return (0, util_1.numToUint8)(this.checksum);
      }
      reset() {
        this.checksum = 0;
      }
    };
    var getCrc32ChecksumAlgorithmFunction = /* @__PURE__ */ __name(() => {
      if (typeof zlib.crc32 === "undefined") {
        return crc32_1.AwsCrc32;
      }
      return NodeCrc32;
    }, "getCrc32ChecksumAlgorithmFunction");
    exports2.getCrc32ChecksumAlgorithmFunction = getCrc32ChecksumAlgorithmFunction;
  }
});

// ../../node_modules/@aws-sdk/middleware-flexible-checksums/dist-cjs/index.js
var require_dist_cjs68 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-flexible-checksums/dist-cjs/index.js"(exports2) {
    "use strict";
    var client = (init_client5(), __toCommonJS(client_exports4));
    var protocolHttp = require_dist_cjs2();
    var utilStream = require_dist_cjs63();
    var isArrayBuffer7 = require_dist_cjs7();
    var crc32c = require_main2();
    var crc64Nvme = require_dist_cjs67();
    var getCrc32ChecksumAlgorithmFunction = require_getCrc32ChecksumAlgorithmFunction();
    var utilUtf8 = require_dist_cjs9();
    var utilMiddleware = require_dist_cjs6();
    var RequestChecksumCalculation = {
      WHEN_SUPPORTED: "WHEN_SUPPORTED",
      WHEN_REQUIRED: "WHEN_REQUIRED"
    };
    var DEFAULT_REQUEST_CHECKSUM_CALCULATION = RequestChecksumCalculation.WHEN_SUPPORTED;
    var ResponseChecksumValidation = {
      WHEN_SUPPORTED: "WHEN_SUPPORTED",
      WHEN_REQUIRED: "WHEN_REQUIRED"
    };
    var DEFAULT_RESPONSE_CHECKSUM_VALIDATION = RequestChecksumCalculation.WHEN_SUPPORTED;
    exports2.ChecksumAlgorithm = void 0;
    (function(ChecksumAlgorithm) {
      ChecksumAlgorithm["MD5"] = "MD5";
      ChecksumAlgorithm["CRC32"] = "CRC32";
      ChecksumAlgorithm["CRC32C"] = "CRC32C";
      ChecksumAlgorithm["CRC64NVME"] = "CRC64NVME";
      ChecksumAlgorithm["SHA1"] = "SHA1";
      ChecksumAlgorithm["SHA256"] = "SHA256";
    })(exports2.ChecksumAlgorithm || (exports2.ChecksumAlgorithm = {}));
    exports2.ChecksumLocation = void 0;
    (function(ChecksumLocation) {
      ChecksumLocation["HEADER"] = "header";
      ChecksumLocation["TRAILER"] = "trailer";
    })(exports2.ChecksumLocation || (exports2.ChecksumLocation = {}));
    var DEFAULT_CHECKSUM_ALGORITHM = exports2.ChecksumAlgorithm.CRC32;
    var SelectorType3;
    (function(SelectorType4) {
      SelectorType4["ENV"] = "env";
      SelectorType4["CONFIG"] = "shared config entry";
    })(SelectorType3 || (SelectorType3 = {}));
    var stringUnionSelector = /* @__PURE__ */ __name((obj, key, union, type) => {
      if (!(key in obj))
        return void 0;
      const value = obj[key].toUpperCase();
      if (!Object.values(union).includes(value)) {
        throw new TypeError(`Cannot load ${type} '${key}'. Expected one of ${Object.values(union)}, got '${obj[key]}'.`);
      }
      return value;
    }, "stringUnionSelector");
    var ENV_REQUEST_CHECKSUM_CALCULATION = "AWS_REQUEST_CHECKSUM_CALCULATION";
    var CONFIG_REQUEST_CHECKSUM_CALCULATION = "request_checksum_calculation";
    var NODE_REQUEST_CHECKSUM_CALCULATION_CONFIG_OPTIONS = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => stringUnionSelector(env3, ENV_REQUEST_CHECKSUM_CALCULATION, RequestChecksumCalculation, SelectorType3.ENV), "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => stringUnionSelector(profile, CONFIG_REQUEST_CHECKSUM_CALCULATION, RequestChecksumCalculation, SelectorType3.CONFIG), "configFileSelector"),
      default: DEFAULT_REQUEST_CHECKSUM_CALCULATION
    };
    var ENV_RESPONSE_CHECKSUM_VALIDATION = "AWS_RESPONSE_CHECKSUM_VALIDATION";
    var CONFIG_RESPONSE_CHECKSUM_VALIDATION = "response_checksum_validation";
    var NODE_RESPONSE_CHECKSUM_VALIDATION_CONFIG_OPTIONS = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => stringUnionSelector(env3, ENV_RESPONSE_CHECKSUM_VALIDATION, ResponseChecksumValidation, SelectorType3.ENV), "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => stringUnionSelector(profile, CONFIG_RESPONSE_CHECKSUM_VALIDATION, ResponseChecksumValidation, SelectorType3.CONFIG), "configFileSelector"),
      default: DEFAULT_RESPONSE_CHECKSUM_VALIDATION
    };
    var getChecksumAlgorithmForRequest = /* @__PURE__ */ __name((input, { requestChecksumRequired, requestAlgorithmMember, requestChecksumCalculation }) => {
      if (!requestAlgorithmMember) {
        return requestChecksumCalculation === RequestChecksumCalculation.WHEN_SUPPORTED || requestChecksumRequired ? DEFAULT_CHECKSUM_ALGORITHM : void 0;
      }
      if (!input[requestAlgorithmMember]) {
        return void 0;
      }
      const checksumAlgorithm = input[requestAlgorithmMember];
      return checksumAlgorithm;
    }, "getChecksumAlgorithmForRequest");
    var getChecksumLocationName = /* @__PURE__ */ __name((algorithm) => algorithm === exports2.ChecksumAlgorithm.MD5 ? "content-md5" : `x-amz-checksum-${algorithm.toLowerCase()}`, "getChecksumLocationName");
    var hasHeader = /* @__PURE__ */ __name((header, headers) => {
      const soughtHeader = header.toLowerCase();
      for (const headerName of Object.keys(headers)) {
        if (soughtHeader === headerName.toLowerCase()) {
          return true;
        }
      }
      return false;
    }, "hasHeader");
    var hasHeaderWithPrefix = /* @__PURE__ */ __name((headerPrefix, headers) => {
      const soughtHeaderPrefix = headerPrefix.toLowerCase();
      for (const headerName of Object.keys(headers)) {
        if (headerName.toLowerCase().startsWith(soughtHeaderPrefix)) {
          return true;
        }
      }
      return false;
    }, "hasHeaderWithPrefix");
    var isStreaming = /* @__PURE__ */ __name((body) => body !== void 0 && typeof body !== "string" && !ArrayBuffer.isView(body) && !isArrayBuffer7.isArrayBuffer(body), "isStreaming");
    var CLIENT_SUPPORTED_ALGORITHMS = [
      exports2.ChecksumAlgorithm.CRC32,
      exports2.ChecksumAlgorithm.CRC32C,
      exports2.ChecksumAlgorithm.CRC64NVME,
      exports2.ChecksumAlgorithm.SHA1,
      exports2.ChecksumAlgorithm.SHA256
    ];
    var PRIORITY_ORDER_ALGORITHMS = [
      exports2.ChecksumAlgorithm.SHA256,
      exports2.ChecksumAlgorithm.SHA1,
      exports2.ChecksumAlgorithm.CRC32,
      exports2.ChecksumAlgorithm.CRC32C,
      exports2.ChecksumAlgorithm.CRC64NVME
    ];
    var selectChecksumAlgorithmFunction = /* @__PURE__ */ __name((checksumAlgorithm, config2) => {
      const { checksumAlgorithms = {} } = config2;
      switch (checksumAlgorithm) {
        case exports2.ChecksumAlgorithm.MD5:
          return checksumAlgorithms?.MD5 ?? config2.md5;
        case exports2.ChecksumAlgorithm.CRC32:
          return checksumAlgorithms?.CRC32 ?? getCrc32ChecksumAlgorithmFunction.getCrc32ChecksumAlgorithmFunction();
        case exports2.ChecksumAlgorithm.CRC32C:
          return checksumAlgorithms?.CRC32C ?? crc32c.AwsCrc32c;
        case exports2.ChecksumAlgorithm.CRC64NVME:
          if (typeof crc64Nvme.crc64NvmeCrtContainer.CrtCrc64Nvme !== "function") {
            return checksumAlgorithms?.CRC64NVME ?? crc64Nvme.Crc64Nvme;
          }
          return checksumAlgorithms?.CRC64NVME ?? crc64Nvme.crc64NvmeCrtContainer.CrtCrc64Nvme;
        case exports2.ChecksumAlgorithm.SHA1:
          return checksumAlgorithms?.SHA1 ?? config2.sha1;
        case exports2.ChecksumAlgorithm.SHA256:
          return checksumAlgorithms?.SHA256 ?? config2.sha256;
        default:
          if (checksumAlgorithms?.[checksumAlgorithm]) {
            return checksumAlgorithms[checksumAlgorithm];
          }
          throw new Error(`The checksum algorithm "${checksumAlgorithm}" is not supported by the client. Select one of ${CLIENT_SUPPORTED_ALGORITHMS}, or provide an implementation to  the client constructor checksums field.`);
      }
    }, "selectChecksumAlgorithmFunction");
    var stringHasher = /* @__PURE__ */ __name((checksumAlgorithmFn, body) => {
      const hash = new checksumAlgorithmFn();
      hash.update(utilUtf8.toUint8Array(body || ""));
      return hash.digest();
    }, "stringHasher");
    var flexibleChecksumsMiddlewareOptions = {
      name: "flexibleChecksumsMiddleware",
      step: "build",
      tags: ["BODY_CHECKSUM"],
      override: true
    };
    var flexibleChecksumsMiddleware = /* @__PURE__ */ __name((config2, middlewareConfig) => (next, context) => async (args) => {
      if (!protocolHttp.HttpRequest.isInstance(args.request)) {
        return next(args);
      }
      if (hasHeaderWithPrefix("x-amz-checksum-", args.request.headers)) {
        return next(args);
      }
      const { request: request4, input } = args;
      const { body: requestBody, headers } = request4;
      const { base64Encoder, streamHasher } = config2;
      const { requestChecksumRequired, requestAlgorithmMember } = middlewareConfig;
      const requestChecksumCalculation = await config2.requestChecksumCalculation();
      const requestAlgorithmMemberName = requestAlgorithmMember?.name;
      const requestAlgorithmMemberHttpHeader = requestAlgorithmMember?.httpHeader;
      if (requestAlgorithmMemberName && !input[requestAlgorithmMemberName]) {
        if (requestChecksumCalculation === RequestChecksumCalculation.WHEN_SUPPORTED || requestChecksumRequired) {
          input[requestAlgorithmMemberName] = DEFAULT_CHECKSUM_ALGORITHM;
          if (requestAlgorithmMemberHttpHeader) {
            headers[requestAlgorithmMemberHttpHeader] = DEFAULT_CHECKSUM_ALGORITHM;
          }
        }
      }
      const checksumAlgorithm = getChecksumAlgorithmForRequest(input, {
        requestChecksumRequired,
        requestAlgorithmMember: requestAlgorithmMember?.name,
        requestChecksumCalculation
      });
      let updatedBody = requestBody;
      let updatedHeaders = headers;
      if (checksumAlgorithm) {
        switch (checksumAlgorithm) {
          case exports2.ChecksumAlgorithm.CRC32:
            client.setFeature(context, "FLEXIBLE_CHECKSUMS_REQ_CRC32", "U");
            break;
          case exports2.ChecksumAlgorithm.CRC32C:
            client.setFeature(context, "FLEXIBLE_CHECKSUMS_REQ_CRC32C", "V");
            break;
          case exports2.ChecksumAlgorithm.CRC64NVME:
            client.setFeature(context, "FLEXIBLE_CHECKSUMS_REQ_CRC64", "W");
            break;
          case exports2.ChecksumAlgorithm.SHA1:
            client.setFeature(context, "FLEXIBLE_CHECKSUMS_REQ_SHA1", "X");
            break;
          case exports2.ChecksumAlgorithm.SHA256:
            client.setFeature(context, "FLEXIBLE_CHECKSUMS_REQ_SHA256", "Y");
            break;
        }
        const checksumLocationName = getChecksumLocationName(checksumAlgorithm);
        const checksumAlgorithmFn = selectChecksumAlgorithmFunction(checksumAlgorithm, config2);
        if (isStreaming(requestBody)) {
          const { getAwsChunkedEncodingStream: getAwsChunkedEncodingStream5, bodyLengthChecker } = config2;
          updatedBody = getAwsChunkedEncodingStream5(typeof config2.requestStreamBufferSize === "number" && config2.requestStreamBufferSize >= 8 * 1024 ? utilStream.createBufferedReadable(requestBody, config2.requestStreamBufferSize, context.logger) : requestBody, {
            base64Encoder,
            bodyLengthChecker,
            checksumLocationName,
            checksumAlgorithmFn,
            streamHasher
          });
          updatedHeaders = {
            ...headers,
            "content-encoding": headers["content-encoding"] ? `${headers["content-encoding"]},aws-chunked` : "aws-chunked",
            "transfer-encoding": "chunked",
            "x-amz-decoded-content-length": headers["content-length"],
            "x-amz-content-sha256": "STREAMING-UNSIGNED-PAYLOAD-TRAILER",
            "x-amz-trailer": checksumLocationName
          };
          delete updatedHeaders["content-length"];
        } else if (!hasHeader(checksumLocationName, headers)) {
          const rawChecksum = await stringHasher(checksumAlgorithmFn, requestBody);
          updatedHeaders = {
            ...headers,
            [checksumLocationName]: base64Encoder(rawChecksum)
          };
        }
      }
      try {
        const result2 = await next({
          ...args,
          request: {
            ...request4,
            headers: updatedHeaders,
            body: updatedBody
          }
        });
        return result2;
      } catch (e32) {
        if (e32 instanceof Error && e32.name === "InvalidChunkSizeError") {
          try {
            if (!e32.message.endsWith(".")) {
              e32.message += ".";
            }
            e32.message += " Set [requestStreamBufferSize=number e.g. 65_536] in client constructor to instruct AWS SDK to buffer your input stream.";
          } catch (ignored) {
          }
        }
        throw e32;
      }
    }, "flexibleChecksumsMiddleware");
    var flexibleChecksumsInputMiddlewareOptions = {
      name: "flexibleChecksumsInputMiddleware",
      toMiddleware: "serializerMiddleware",
      relation: "before",
      tags: ["BODY_CHECKSUM"],
      override: true
    };
    var flexibleChecksumsInputMiddleware = /* @__PURE__ */ __name((config2, middlewareConfig) => (next, context) => async (args) => {
      const input = args.input;
      const { requestValidationModeMember } = middlewareConfig;
      const requestChecksumCalculation = await config2.requestChecksumCalculation();
      const responseChecksumValidation = await config2.responseChecksumValidation();
      switch (requestChecksumCalculation) {
        case RequestChecksumCalculation.WHEN_REQUIRED:
          client.setFeature(context, "FLEXIBLE_CHECKSUMS_REQ_WHEN_REQUIRED", "a");
          break;
        case RequestChecksumCalculation.WHEN_SUPPORTED:
          client.setFeature(context, "FLEXIBLE_CHECKSUMS_REQ_WHEN_SUPPORTED", "Z");
          break;
      }
      switch (responseChecksumValidation) {
        case ResponseChecksumValidation.WHEN_REQUIRED:
          client.setFeature(context, "FLEXIBLE_CHECKSUMS_RES_WHEN_REQUIRED", "c");
          break;
        case ResponseChecksumValidation.WHEN_SUPPORTED:
          client.setFeature(context, "FLEXIBLE_CHECKSUMS_RES_WHEN_SUPPORTED", "b");
          break;
      }
      if (requestValidationModeMember && !input[requestValidationModeMember]) {
        if (responseChecksumValidation === ResponseChecksumValidation.WHEN_SUPPORTED) {
          input[requestValidationModeMember] = "ENABLED";
        }
      }
      return next(args);
    }, "flexibleChecksumsInputMiddleware");
    var getChecksumAlgorithmListForResponse = /* @__PURE__ */ __name((responseAlgorithms = []) => {
      const validChecksumAlgorithms = [];
      let i32 = PRIORITY_ORDER_ALGORITHMS.length;
      for (const algorithm of responseAlgorithms) {
        const priority = PRIORITY_ORDER_ALGORITHMS.indexOf(algorithm);
        if (priority !== -1) {
          validChecksumAlgorithms[priority] = algorithm;
        } else {
          validChecksumAlgorithms[i32++] = algorithm;
        }
      }
      return validChecksumAlgorithms.filter(Boolean);
    }, "getChecksumAlgorithmListForResponse");
    var isChecksumWithPartNumber = /* @__PURE__ */ __name((checksum) => {
      const lastHyphenIndex = checksum.lastIndexOf("-");
      if (lastHyphenIndex !== -1) {
        const numberPart = checksum.slice(lastHyphenIndex + 1);
        if (!numberPart.startsWith("0")) {
          const number = parseInt(numberPart, 10);
          if (!isNaN(number) && number >= 1 && number <= 1e4) {
            return true;
          }
        }
      }
      return false;
    }, "isChecksumWithPartNumber");
    var getChecksum = /* @__PURE__ */ __name(async (body, { checksumAlgorithmFn, base64Encoder }) => base64Encoder(await stringHasher(checksumAlgorithmFn, body)), "getChecksum");
    var validateChecksumFromResponse = /* @__PURE__ */ __name(async (response, { config: config2, responseAlgorithms, logger: logger5 }) => {
      const checksumAlgorithms = getChecksumAlgorithmListForResponse(responseAlgorithms);
      const { body: responseBody, headers: responseHeaders } = response;
      for (const algorithm of checksumAlgorithms) {
        const responseHeader = getChecksumLocationName(algorithm);
        const checksumFromResponse = responseHeaders[responseHeader];
        if (checksumFromResponse) {
          let checksumAlgorithmFn;
          try {
            checksumAlgorithmFn = selectChecksumAlgorithmFunction(algorithm, config2);
          } catch (error4) {
            if (algorithm === exports2.ChecksumAlgorithm.CRC64NVME) {
              logger5?.warn(`Skipping ${exports2.ChecksumAlgorithm.CRC64NVME} checksum validation: ${error4.message}`);
              continue;
            }
            throw error4;
          }
          const { base64Encoder } = config2;
          if (isStreaming(responseBody)) {
            response.body = utilStream.createChecksumStream({
              expectedChecksum: checksumFromResponse,
              checksumSourceLocation: responseHeader,
              checksum: new checksumAlgorithmFn(),
              source: responseBody,
              base64Encoder
            });
            return;
          }
          const checksum = await getChecksum(responseBody, { checksumAlgorithmFn, base64Encoder });
          if (checksum === checksumFromResponse) {
            break;
          }
          throw new Error(`Checksum mismatch: expected "${checksum}" but received "${checksumFromResponse}" in response header "${responseHeader}".`);
        }
      }
    }, "validateChecksumFromResponse");
    var flexibleChecksumsResponseMiddlewareOptions = {
      name: "flexibleChecksumsResponseMiddleware",
      toMiddleware: "deserializerMiddleware",
      relation: "after",
      tags: ["BODY_CHECKSUM"],
      override: true
    };
    var flexibleChecksumsResponseMiddleware = /* @__PURE__ */ __name((config2, middlewareConfig) => (next, context) => async (args) => {
      if (!protocolHttp.HttpRequest.isInstance(args.request)) {
        return next(args);
      }
      const input = args.input;
      const result2 = await next(args);
      const response = result2.response;
      const { requestValidationModeMember, responseAlgorithms } = middlewareConfig;
      if (requestValidationModeMember && input[requestValidationModeMember] === "ENABLED") {
        const { clientName, commandName } = context;
        const customChecksumAlgorithms = Object.keys(config2.checksumAlgorithms ?? {}).filter((algorithm) => {
          const responseHeader = getChecksumLocationName(algorithm);
          return response.headers[responseHeader] !== void 0;
        });
        const algoList = getChecksumAlgorithmListForResponse([
          ...responseAlgorithms ?? [],
          ...customChecksumAlgorithms
        ]);
        const isS3WholeObjectMultipartGetResponseChecksum = clientName === "S3Client" && commandName === "GetObjectCommand" && algoList.every((algorithm) => {
          const responseHeader = getChecksumLocationName(algorithm);
          const checksumFromResponse = response.headers[responseHeader];
          return !checksumFromResponse || isChecksumWithPartNumber(checksumFromResponse);
        });
        if (isS3WholeObjectMultipartGetResponseChecksum) {
          return result2;
        }
        await validateChecksumFromResponse(response, {
          config: config2,
          responseAlgorithms: algoList,
          logger: context.logger
        });
      }
      return result2;
    }, "flexibleChecksumsResponseMiddleware");
    var getFlexibleChecksumsPlugin = /* @__PURE__ */ __name((config2, middlewareConfig) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(flexibleChecksumsMiddleware(config2, middlewareConfig), flexibleChecksumsMiddlewareOptions);
        clientStack.addRelativeTo(flexibleChecksumsInputMiddleware(config2, middlewareConfig), flexibleChecksumsInputMiddlewareOptions);
        clientStack.addRelativeTo(flexibleChecksumsResponseMiddleware(config2, middlewareConfig), flexibleChecksumsResponseMiddlewareOptions);
      }, "applyToStack")
    }), "getFlexibleChecksumsPlugin");
    var resolveFlexibleChecksumsConfig = /* @__PURE__ */ __name((input) => {
      const { requestChecksumCalculation, responseChecksumValidation, requestStreamBufferSize } = input;
      return Object.assign(input, {
        requestChecksumCalculation: utilMiddleware.normalizeProvider(requestChecksumCalculation ?? DEFAULT_REQUEST_CHECKSUM_CALCULATION),
        responseChecksumValidation: utilMiddleware.normalizeProvider(responseChecksumValidation ?? DEFAULT_RESPONSE_CHECKSUM_VALIDATION),
        requestStreamBufferSize: Number(requestStreamBufferSize ?? 0),
        checksumAlgorithms: input.checksumAlgorithms ?? {}
      });
    }, "resolveFlexibleChecksumsConfig");
    exports2.CONFIG_REQUEST_CHECKSUM_CALCULATION = CONFIG_REQUEST_CHECKSUM_CALCULATION;
    exports2.CONFIG_RESPONSE_CHECKSUM_VALIDATION = CONFIG_RESPONSE_CHECKSUM_VALIDATION;
    exports2.DEFAULT_CHECKSUM_ALGORITHM = DEFAULT_CHECKSUM_ALGORITHM;
    exports2.DEFAULT_REQUEST_CHECKSUM_CALCULATION = DEFAULT_REQUEST_CHECKSUM_CALCULATION;
    exports2.DEFAULT_RESPONSE_CHECKSUM_VALIDATION = DEFAULT_RESPONSE_CHECKSUM_VALIDATION;
    exports2.ENV_REQUEST_CHECKSUM_CALCULATION = ENV_REQUEST_CHECKSUM_CALCULATION;
    exports2.ENV_RESPONSE_CHECKSUM_VALIDATION = ENV_RESPONSE_CHECKSUM_VALIDATION;
    exports2.NODE_REQUEST_CHECKSUM_CALCULATION_CONFIG_OPTIONS = NODE_REQUEST_CHECKSUM_CALCULATION_CONFIG_OPTIONS;
    exports2.NODE_RESPONSE_CHECKSUM_VALIDATION_CONFIG_OPTIONS = NODE_RESPONSE_CHECKSUM_VALIDATION_CONFIG_OPTIONS;
    exports2.RequestChecksumCalculation = RequestChecksumCalculation;
    exports2.ResponseChecksumValidation = ResponseChecksumValidation;
    exports2.flexibleChecksumsMiddleware = flexibleChecksumsMiddleware;
    exports2.flexibleChecksumsMiddlewareOptions = flexibleChecksumsMiddlewareOptions;
    exports2.getFlexibleChecksumsPlugin = getFlexibleChecksumsPlugin;
    exports2.resolveFlexibleChecksumsConfig = resolveFlexibleChecksumsConfig;
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/client/emitWarningIfUnsupportedVersion.js
var state5, emitWarningIfUnsupportedVersion9;
var init_emitWarningIfUnsupportedVersion5 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/client/emitWarningIfUnsupportedVersion.js"() {
    state5 = {
      warningEmitted: false
    };
    emitWarningIfUnsupportedVersion9 = /* @__PURE__ */ __name((version) => {
      if (version && !state5.warningEmitted) {
        if (process.env.AWS_SDK_JS_NODE_VERSION_SUPPORT_WARNING_DISABLED === "true") {
          state5.warningEmitted = true;
          return;
        }
        const userMajorVersion = parseInt(version.substring(1, version.indexOf(".")));
        const vv = 22;
        if (userMajorVersion < vv) {
          state5.warningEmitted = true;
          process.emitWarning(`NodeVersionSupportWarning: The AWS SDK for JavaScript (v3)
versions published after the first week of January 2027
will require node >=${vv}. You are running node ${version}.

To continue receiving updates to AWS services, bug fixes,
and security updates please upgrade to node >=${vv}.

More information can be found at: https://a.co/c895JFp`);
        }
      }
    }, "emitWarningIfUnsupportedVersion");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/client/longPollMiddleware.js
var longPollMiddleware5, longPollMiddlewareOptions5, getLongPollPlugin5;
var init_longPollMiddleware5 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/client/longPollMiddleware.js"() {
    longPollMiddleware5 = /* @__PURE__ */ __name(() => (next, context) => async (args) => {
      context.__retryLongPoll = true;
      return next(args);
    }, "longPollMiddleware");
    longPollMiddlewareOptions5 = {
      name: "longPollMiddleware",
      tags: ["RETRY"],
      step: "initialize",
      override: true
    };
    getLongPollPlugin5 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(longPollMiddleware5(), longPollMiddlewareOptions5);
      }, "applyToStack")
    }), "getLongPollPlugin");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/client/setCredentialFeature.js
function setCredentialFeature5(credentials, feature, value) {
  if (!credentials.$source) {
    credentials.$source = {};
  }
  credentials.$source[feature] = value;
  return credentials;
}
var init_setCredentialFeature5 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/client/setCredentialFeature.js"() {
    __name(setCredentialFeature5, "setCredentialFeature");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/client/setFeature.js
function setFeature6(context, feature, value) {
  if (!context.__aws_sdk_context) {
    context.__aws_sdk_context = {
      features: {}
    };
  } else if (!context.__aws_sdk_context.features) {
    context.__aws_sdk_context.features = {};
  }
  context.__aws_sdk_context.features[feature] = value;
}
var import_util_retry9;
var init_setFeature6 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/client/setFeature.js"() {
    import_util_retry9 = __toESM(require_dist_cjs22());
    import_util_retry9.Retry.v2026 ||= typeof process === "object" && process.env?.AWS_NEW_RETRIES_2026 === "true";
    __name(setFeature6, "setFeature");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/client/setTokenFeature.js
function setTokenFeature5(token, feature, value) {
  if (!token.$source) {
    token.$source = {};
  }
  token.$source[feature] = value;
  return token;
}
var init_setTokenFeature5 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/client/setTokenFeature.js"() {
    __name(setTokenFeature5, "setTokenFeature");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/client/index.js
var client_exports5 = {};
__export(client_exports5, {
  emitWarningIfUnsupportedVersion: () => emitWarningIfUnsupportedVersion9,
  getLongPollPlugin: () => getLongPollPlugin5,
  setCredentialFeature: () => setCredentialFeature5,
  setFeature: () => setFeature6,
  setTokenFeature: () => setTokenFeature5,
  state: () => state5
});
var init_client6 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/client/index.js"() {
    init_emitWarningIfUnsupportedVersion5();
    init_longPollMiddleware5();
    init_setCredentialFeature5();
    init_setFeature6();
    init_setTokenFeature5();
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/middleware-user-agent/dist-cjs/index.js
var require_dist_cjs69 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/middleware-user-agent/dist-cjs/index.js"(exports2) {
    "use strict";
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var utilEndpoints = require_dist_cjs21();
    var protocolHttp = require_dist_cjs2();
    var client = (init_client6(), __toCommonJS(client_exports5));
    var utilRetry = require_dist_cjs22();
    var DEFAULT_UA_APP_ID2 = void 0;
    function isValidUserAgentAppId2(appId) {
      if (appId === void 0) {
        return true;
      }
      return typeof appId === "string" && appId.length <= 50;
    }
    __name(isValidUserAgentAppId2, "isValidUserAgentAppId");
    function resolveUserAgentConfig29(input) {
      const normalizedAppIdProvider = core.normalizeProvider(input.userAgentAppId ?? DEFAULT_UA_APP_ID2);
      const { customUserAgent } = input;
      return Object.assign(input, {
        customUserAgent: typeof customUserAgent === "string" ? [[customUserAgent]] : customUserAgent,
        userAgentAppId: /* @__PURE__ */ __name(async () => {
          const appId = await normalizedAppIdProvider();
          if (!isValidUserAgentAppId2(appId)) {
            const logger5 = input.logger?.constructor?.name === "NoOpLogger" || !input.logger ? console : input.logger;
            if (typeof appId !== "string") {
              logger5?.warn("userAgentAppId must be a string or undefined.");
            } else if (appId.length > 50) {
              logger5?.warn("The provided userAgentAppId exceeds the maximum length of 50 characters.");
            }
          }
          return appId;
        }, "userAgentAppId")
      });
    }
    __name(resolveUserAgentConfig29, "resolveUserAgentConfig");
    var ACCOUNT_ID_ENDPOINT_REGEX2 = /\d{12}\.ddb/;
    async function checkFeatures2(context, config2, args) {
      const request4 = args.request;
      if (request4?.headers?.["smithy-protocol"] === "rpc-v2-cbor") {
        client.setFeature(context, "PROTOCOL_RPC_V2_CBOR", "M");
      }
      if (typeof config2.retryStrategy === "function") {
        const retryStrategy = await config2.retryStrategy();
        if (typeof retryStrategy.mode === "string") {
          switch (retryStrategy.mode) {
            case utilRetry.RETRY_MODES.ADAPTIVE:
              client.setFeature(context, "RETRY_MODE_ADAPTIVE", "F");
              break;
            case utilRetry.RETRY_MODES.STANDARD:
              client.setFeature(context, "RETRY_MODE_STANDARD", "E");
              break;
          }
        }
      }
      if (typeof config2.accountIdEndpointMode === "function") {
        const endpointV2 = context.endpointV2;
        if (String(endpointV2?.url?.hostname).match(ACCOUNT_ID_ENDPOINT_REGEX2)) {
          client.setFeature(context, "ACCOUNT_ID_ENDPOINT", "O");
        }
        switch (await config2.accountIdEndpointMode?.()) {
          case "disabled":
            client.setFeature(context, "ACCOUNT_ID_MODE_DISABLED", "Q");
            break;
          case "preferred":
            client.setFeature(context, "ACCOUNT_ID_MODE_PREFERRED", "P");
            break;
          case "required":
            client.setFeature(context, "ACCOUNT_ID_MODE_REQUIRED", "R");
            break;
        }
      }
      const identity = context.__smithy_context?.selectedHttpAuthScheme?.identity;
      if (identity?.$source) {
        const credentials = identity;
        if (credentials.accountId) {
          client.setFeature(context, "RESOLVED_ACCOUNT_ID", "T");
        }
        for (const [key, value] of Object.entries(credentials.$source ?? {})) {
          client.setFeature(context, key, value);
        }
      }
    }
    __name(checkFeatures2, "checkFeatures");
    var USER_AGENT3 = "user-agent";
    var X_AMZ_USER_AGENT2 = "x-amz-user-agent";
    var SPACE2 = " ";
    var UA_NAME_SEPARATOR2 = "/";
    var UA_NAME_ESCAPE_REGEX2 = /[^!$%&'*+\-.^_`|~\w]/g;
    var UA_VALUE_ESCAPE_REGEX2 = /[^!$%&'*+\-.^_`|~\w#]/g;
    var UA_ESCAPE_CHAR2 = "-";
    var BYTE_LIMIT2 = 1024;
    function encodeFeatures2(features) {
      let buffer = "";
      for (const key in features) {
        const val = features[key];
        if (buffer.length + val.length + 1 <= BYTE_LIMIT2) {
          if (buffer.length) {
            buffer += "," + val;
          } else {
            buffer += val;
          }
          continue;
        }
        break;
      }
      return buffer;
    }
    __name(encodeFeatures2, "encodeFeatures");
    var userAgentMiddleware2 = /* @__PURE__ */ __name((options) => (next, context) => async (args) => {
      const { request: request4 } = args;
      if (!protocolHttp.HttpRequest.isInstance(request4)) {
        return next(args);
      }
      const { headers } = request4;
      const userAgent = context?.userAgent?.map(escapeUserAgent2) || [];
      const defaultUserAgent2 = (await options.defaultUserAgentProvider()).map(escapeUserAgent2);
      await checkFeatures2(context, options, args);
      const awsContext = context;
      defaultUserAgent2.push(`m/${encodeFeatures2(Object.assign({}, context.__smithy_context?.features, awsContext.__aws_sdk_context?.features))}`);
      const customUserAgent = options?.customUserAgent?.map(escapeUserAgent2) || [];
      const appId = await options.userAgentAppId();
      if (appId) {
        defaultUserAgent2.push(escapeUserAgent2([`app`, `${appId}`]));
      }
      const prefix = utilEndpoints.getUserAgentPrefix();
      const sdkUserAgentValue = (prefix ? [prefix] : []).concat([...defaultUserAgent2, ...userAgent, ...customUserAgent]).join(SPACE2);
      const normalUAValue = [
        ...defaultUserAgent2.filter((section) => section.startsWith("aws-sdk-")),
        ...customUserAgent
      ].join(SPACE2);
      if (options.runtime !== "browser") {
        if (normalUAValue) {
          headers[X_AMZ_USER_AGENT2] = headers[X_AMZ_USER_AGENT2] ? `${headers[USER_AGENT3]} ${normalUAValue}` : normalUAValue;
        }
        headers[USER_AGENT3] = sdkUserAgentValue;
      } else {
        headers[X_AMZ_USER_AGENT2] = sdkUserAgentValue;
      }
      return next({
        ...args,
        request: request4
      });
    }, "userAgentMiddleware");
    var escapeUserAgent2 = /* @__PURE__ */ __name((userAgentPair) => {
      const name = userAgentPair[0].split(UA_NAME_SEPARATOR2).map((part) => part.replace(UA_NAME_ESCAPE_REGEX2, UA_ESCAPE_CHAR2)).join(UA_NAME_SEPARATOR2);
      const version = userAgentPair[1]?.replace(UA_VALUE_ESCAPE_REGEX2, UA_ESCAPE_CHAR2);
      const prefixSeparatorIndex = name.indexOf(UA_NAME_SEPARATOR2);
      const prefix = name.substring(0, prefixSeparatorIndex);
      let uaName = name.substring(prefixSeparatorIndex + 1);
      if (prefix === "api") {
        uaName = uaName.toLowerCase();
      }
      return [prefix, uaName, version].filter((item) => item && item.length > 0).reduce((acc, item, index) => {
        switch (index) {
          case 0:
            return item;
          case 1:
            return `${acc}/${item}`;
          default:
            return `${acc}#${item}`;
        }
      }, "");
    }, "escapeUserAgent");
    var getUserAgentMiddlewareOptions2 = {
      name: "getUserAgentMiddleware",
      step: "build",
      priority: "low",
      tags: ["SET_USER_AGENT", "USER_AGENT"],
      override: true
    };
    var getUserAgentPlugin29 = /* @__PURE__ */ __name((config2) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(userAgentMiddleware2(config2), getUserAgentMiddlewareOptions2);
      }, "applyToStack")
    }), "getUserAgentPlugin");
    exports2.DEFAULT_UA_APP_ID = DEFAULT_UA_APP_ID2;
    exports2.getUserAgentMiddlewareOptions = getUserAgentMiddlewareOptions2;
    exports2.getUserAgentPlugin = getUserAgentPlugin29;
    exports2.resolveUserAgentConfig = resolveUserAgentConfig29;
    exports2.userAgentMiddleware = userAgentMiddleware2;
  }
});

// ../../node_modules/@smithy/eventstream-serde-config-resolver/dist-cjs/index.js
var require_dist_cjs70 = __commonJS({
  "../../node_modules/@smithy/eventstream-serde-config-resolver/dist-cjs/index.js"(exports2) {
    "use strict";
    var resolveEventStreamSerdeConfig6 = /* @__PURE__ */ __name((input) => Object.assign(input, {
      eventStreamMarshaller: input.eventStreamSerdeProvider(input)
    }), "resolveEventStreamSerdeConfig");
    exports2.resolveEventStreamSerdeConfig = resolveEventStreamSerdeConfig6;
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/middleware-retry/dist-cjs/isStreamingPayload/isStreamingPayload.js
var require_isStreamingPayload3 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/middleware-retry/dist-cjs/isStreamingPayload/isStreamingPayload.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isStreamingPayload = void 0;
    var stream_1 = require("stream");
    var isStreamingPayload3 = /* @__PURE__ */ __name((request4) => request4?.body instanceof stream_1.Readable || typeof ReadableStream !== "undefined" && request4?.body instanceof ReadableStream, "isStreamingPayload");
    exports2.isStreamingPayload = isStreamingPayload3;
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/middleware-retry/dist-cjs/index.js
var require_dist_cjs71 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/middleware-retry/dist-cjs/index.js"(exports2) {
    "use strict";
    var utilRetry = require_dist_cjs22();
    var protocolHttp = require_dist_cjs2();
    var serviceErrorClassification = require_dist_cjs32();
    var uuid = require_dist_cjs19();
    var utilMiddleware = require_dist_cjs6();
    var smithyClient = require_dist_cjs34();
    var isStreamingPayload3 = require_isStreamingPayload3();
    var serde = (init_serde(), __toCommonJS(serde_exports));
    var asSdkError3 = /* @__PURE__ */ __name((error4) => {
      if (error4 instanceof Error)
        return error4;
      if (error4 instanceof Object)
        return Object.assign(new Error(), error4);
      if (typeof error4 === "string")
        return new Error(error4);
      return new Error(`AWS SDK error wrapper for ${error4}`);
    }, "asSdkError");
    var getDefaultRetryQuota3 = /* @__PURE__ */ __name((initialRetryTokens, options) => {
      const MAX_CAPACITY = initialRetryTokens;
      const noRetryIncrement = utilRetry.NO_RETRY_INCREMENT;
      const retryCost = utilRetry.RETRY_COST;
      const timeoutRetryCost = utilRetry.TIMEOUT_RETRY_COST;
      let availableCapacity = initialRetryTokens;
      const getCapacityAmount = /* @__PURE__ */ __name((error4) => error4.name === "TimeoutError" ? timeoutRetryCost : retryCost, "getCapacityAmount");
      const hasRetryTokens = /* @__PURE__ */ __name((error4) => getCapacityAmount(error4) <= availableCapacity, "hasRetryTokens");
      const retrieveRetryTokens = /* @__PURE__ */ __name((error4) => {
        if (!hasRetryTokens(error4)) {
          throw new Error("No retry token available");
        }
        const capacityAmount = getCapacityAmount(error4);
        availableCapacity -= capacityAmount;
        return capacityAmount;
      }, "retrieveRetryTokens");
      const releaseRetryTokens = /* @__PURE__ */ __name((capacityReleaseAmount) => {
        availableCapacity += capacityReleaseAmount ?? noRetryIncrement;
        availableCapacity = Math.min(availableCapacity, MAX_CAPACITY);
      }, "releaseRetryTokens");
      return Object.freeze({
        hasRetryTokens,
        retrieveRetryTokens,
        releaseRetryTokens
      });
    }, "getDefaultRetryQuota");
    var defaultDelayDecider3 = /* @__PURE__ */ __name((delayBase, attempts) => Math.floor(Math.min(utilRetry.MAXIMUM_RETRY_DELAY, Math.random() * 2 ** attempts * delayBase)), "defaultDelayDecider");
    var defaultRetryDecider3 = /* @__PURE__ */ __name((error4) => {
      if (!error4) {
        return false;
      }
      return serviceErrorClassification.isRetryableByTrait(error4) || serviceErrorClassification.isClockSkewError(error4) || serviceErrorClassification.isThrottlingError(error4) || serviceErrorClassification.isTransientError(error4);
    }, "defaultRetryDecider");
    var StandardRetryStrategy5 = class {
      static {
        __name(this, "StandardRetryStrategy");
      }
      maxAttemptsProvider;
      retryDecider;
      delayDecider;
      retryQuota;
      mode = utilRetry.RETRY_MODES.STANDARD;
      constructor(maxAttemptsProvider, options) {
        this.maxAttemptsProvider = maxAttemptsProvider;
        this.retryDecider = options?.retryDecider ?? defaultRetryDecider3;
        this.delayDecider = options?.delayDecider ?? defaultDelayDecider3;
        this.retryQuota = options?.retryQuota ?? getDefaultRetryQuota3(utilRetry.INITIAL_RETRY_TOKENS);
      }
      shouldRetry(error4, attempts, maxAttempts) {
        return attempts < maxAttempts && this.retryDecider(error4) && this.retryQuota.hasRetryTokens(error4);
      }
      async getMaxAttempts() {
        let maxAttempts;
        try {
          maxAttempts = await this.maxAttemptsProvider();
        } catch (error4) {
          maxAttempts = utilRetry.DEFAULT_MAX_ATTEMPTS;
        }
        return maxAttempts;
      }
      async retry(next, args, options) {
        let retryTokenAmount;
        let attempts = 0;
        let totalDelay = 0;
        const maxAttempts = await this.getMaxAttempts();
        const { request: request4 } = args;
        if (protocolHttp.HttpRequest.isInstance(request4)) {
          request4.headers[utilRetry.INVOCATION_ID_HEADER] = uuid.v4();
        }
        while (true) {
          try {
            if (protocolHttp.HttpRequest.isInstance(request4)) {
              request4.headers[utilRetry.REQUEST_HEADER] = `attempt=${attempts + 1}; max=${maxAttempts}`;
            }
            if (options?.beforeRequest) {
              await options.beforeRequest();
            }
            const { response, output } = await next(args);
            if (options?.afterRequest) {
              options.afterRequest(response);
            }
            this.retryQuota.releaseRetryTokens(retryTokenAmount);
            output.$metadata.attempts = attempts + 1;
            output.$metadata.totalRetryDelay = totalDelay;
            return { response, output };
          } catch (e32) {
            const err = asSdkError3(e32);
            attempts++;
            if (this.shouldRetry(err, attempts, maxAttempts)) {
              retryTokenAmount = this.retryQuota.retrieveRetryTokens(err);
              const delayFromDecider = this.delayDecider(serviceErrorClassification.isThrottlingError(err) ? utilRetry.THROTTLING_RETRY_DELAY_BASE : utilRetry.DEFAULT_RETRY_DELAY_BASE, attempts);
              const delayFromResponse = getDelayFromRetryAfterHeader3(err.$response);
              const delay = Math.max(delayFromResponse || 0, delayFromDecider);
              totalDelay += delay;
              await new Promise((resolve13) => setTimeout(resolve13, delay));
              continue;
            }
            if (!err.$metadata) {
              err.$metadata = {};
            }
            err.$metadata.attempts = attempts;
            err.$metadata.totalRetryDelay = totalDelay;
            throw err;
          }
        }
      }
    };
    var getDelayFromRetryAfterHeader3 = /* @__PURE__ */ __name((response) => {
      if (!protocolHttp.HttpResponse.isInstance(response))
        return;
      const retryAfterHeaderName = Object.keys(response.headers).find((key) => key.toLowerCase() === "retry-after");
      if (!retryAfterHeaderName)
        return;
      const retryAfter = response.headers[retryAfterHeaderName];
      const retryAfterSeconds = Number(retryAfter);
      if (!Number.isNaN(retryAfterSeconds))
        return retryAfterSeconds * 1e3;
      const retryAfterDate = new Date(retryAfter);
      return retryAfterDate.getTime() - Date.now();
    }, "getDelayFromRetryAfterHeader");
    var AdaptiveRetryStrategy5 = class extends StandardRetryStrategy5 {
      static {
        __name(this, "AdaptiveRetryStrategy");
      }
      rateLimiter;
      constructor(maxAttemptsProvider, options) {
        const { rateLimiter, ...superOptions } = options ?? {};
        super(maxAttemptsProvider, superOptions);
        this.rateLimiter = rateLimiter ?? new utilRetry.DefaultRateLimiter();
        this.mode = utilRetry.RETRY_MODES.ADAPTIVE;
      }
      async retry(next, args) {
        return super.retry(next, args, {
          beforeRequest: /* @__PURE__ */ __name(async () => {
            return this.rateLimiter.getSendToken();
          }, "beforeRequest"),
          afterRequest: /* @__PURE__ */ __name((response) => {
            this.rateLimiter.updateClientSendingRate(response);
          }, "afterRequest")
        });
      }
    };
    var ENV_MAX_ATTEMPTS3 = "AWS_MAX_ATTEMPTS";
    var CONFIG_MAX_ATTEMPTS3 = "max_attempts";
    var NODE_MAX_ATTEMPT_CONFIG_OPTIONS30 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => {
        const value = env3[ENV_MAX_ATTEMPTS3];
        if (!value)
          return void 0;
        const maxAttempt = parseInt(value);
        if (Number.isNaN(maxAttempt)) {
          throw new Error(`Environment variable ${ENV_MAX_ATTEMPTS3} mast be a number, got "${value}"`);
        }
        return maxAttempt;
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => {
        const value = profile[CONFIG_MAX_ATTEMPTS3];
        if (!value)
          return void 0;
        const maxAttempt = parseInt(value);
        if (Number.isNaN(maxAttempt)) {
          throw new Error(`Shared config file entry ${CONFIG_MAX_ATTEMPTS3} mast be a number, got "${value}"`);
        }
        return maxAttempt;
      }, "configFileSelector"),
      default: utilRetry.DEFAULT_MAX_ATTEMPTS
    };
    var resolveRetryConfig30 = /* @__PURE__ */ __name((input) => {
      const { retryStrategy, retryMode } = input;
      const maxAttempts = utilMiddleware.normalizeProvider(input.maxAttempts ?? utilRetry.DEFAULT_MAX_ATTEMPTS);
      let controller = retryStrategy ? Promise.resolve(retryStrategy) : void 0;
      const getDefault = /* @__PURE__ */ __name(async () => await utilMiddleware.normalizeProvider(retryMode)() === utilRetry.RETRY_MODES.ADAPTIVE ? new utilRetry.AdaptiveRetryStrategy(maxAttempts) : new utilRetry.StandardRetryStrategy(maxAttempts), "getDefault");
      return Object.assign(input, {
        maxAttempts,
        retryStrategy: /* @__PURE__ */ __name(() => controller ??= getDefault(), "retryStrategy")
      });
    }, "resolveRetryConfig");
    var ENV_RETRY_MODE3 = "AWS_RETRY_MODE";
    var CONFIG_RETRY_MODE3 = "retry_mode";
    var NODE_RETRY_MODE_CONFIG_OPTIONS30 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[ENV_RETRY_MODE3], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[CONFIG_RETRY_MODE3], "configFileSelector"),
      default: utilRetry.DEFAULT_RETRY_MODE
    };
    var omitRetryHeadersMiddleware3 = /* @__PURE__ */ __name(() => (next) => async (args) => {
      const { request: request4 } = args;
      if (protocolHttp.HttpRequest.isInstance(request4)) {
        delete request4.headers[utilRetry.INVOCATION_ID_HEADER];
        delete request4.headers[utilRetry.REQUEST_HEADER];
      }
      return next(args);
    }, "omitRetryHeadersMiddleware");
    var omitRetryHeadersMiddlewareOptions3 = {
      name: "omitRetryHeadersMiddleware",
      tags: ["RETRY", "HEADERS", "OMIT_RETRY_HEADERS"],
      relation: "before",
      toMiddleware: "awsAuthMiddleware",
      override: true
    };
    var getOmitRetryHeadersPlugin3 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.addRelativeTo(omitRetryHeadersMiddleware3(), omitRetryHeadersMiddlewareOptions3);
      }, "applyToStack")
    }), "getOmitRetryHeadersPlugin");
    function parseRetryAfterHeader3(response, logger5) {
      if (!protocolHttp.HttpResponse.isInstance(response)) {
        return;
      }
      for (const header of Object.keys(response.headers)) {
        const h32 = header.toLowerCase();
        if (h32 === "retry-after") {
          const retryAfter = response.headers[header];
          let retryAfterSeconds = NaN;
          if (retryAfter.endsWith("GMT")) {
            try {
              const date7 = serde.parseRfc7231DateTime(retryAfter);
              retryAfterSeconds = (date7.getTime() - Date.now()) / 1e3;
            } catch (e32) {
              logger5?.trace?.("Failed to parse retry-after header");
              logger5?.trace?.(e32);
            }
          } else if (retryAfter.match(/ GMT, ((\d+)|(\d+\.\d+))$/)) {
            retryAfterSeconds = Number(retryAfter.match(/ GMT, ([\d.]+)$/)?.[1]);
          } else if (retryAfter.match(/^((\d+)|(\d+\.\d+))$/)) {
            retryAfterSeconds = Number(retryAfter);
          } else if (Date.parse(retryAfter) >= Date.now()) {
            retryAfterSeconds = (Date.parse(retryAfter) - Date.now()) / 1e3;
          }
          if (isNaN(retryAfterSeconds)) {
            return;
          }
          return new Date(Date.now() + retryAfterSeconds * 1e3);
        } else if (h32 === "x-amz-retry-after") {
          const v = response.headers[header];
          const backoffMilliseconds = Number(v);
          if (isNaN(backoffMilliseconds)) {
            logger5?.trace?.(`Failed to parse x-amz-retry-after=${v}`);
            return;
          }
          return new Date(Date.now() + backoffMilliseconds);
        }
      }
    }
    __name(parseRetryAfterHeader3, "parseRetryAfterHeader");
    function getRetryAfterHint3(response, logger5) {
      return parseRetryAfterHeader3(response, logger5);
    }
    __name(getRetryAfterHint3, "getRetryAfterHint");
    var retryMiddleware3 = /* @__PURE__ */ __name((options) => (next, context) => async (args) => {
      let retryStrategy = await options.retryStrategy();
      const maxAttempts = await options.maxAttempts();
      if (isRetryStrategyV23(retryStrategy)) {
        retryStrategy = retryStrategy;
        let retryToken = await retryStrategy.acquireInitialRetryToken((context["partition_id"] ?? "") + (context.__retryLongPoll ? ":longpoll" : ""));
        let lastError = new Error();
        let attempts = 0;
        let totalRetryDelay = 0;
        const { request: request4 } = args;
        const isRequest = protocolHttp.HttpRequest.isInstance(request4);
        if (isRequest) {
          request4.headers[utilRetry.INVOCATION_ID_HEADER] = uuid.v4();
        }
        while (true) {
          try {
            if (isRequest) {
              request4.headers[utilRetry.REQUEST_HEADER] = `attempt=${attempts + 1}; max=${maxAttempts}`;
            }
            const { response, output } = await next(args);
            retryStrategy.recordSuccess(retryToken);
            output.$metadata.attempts = attempts + 1;
            output.$metadata.totalRetryDelay = totalRetryDelay;
            return { response, output };
          } catch (e32) {
            const retryErrorInfo = getRetryErrorInfo3(e32, options.logger);
            lastError = asSdkError3(e32);
            if (isRequest && isStreamingPayload3.isStreamingPayload(request4)) {
              (context.logger instanceof smithyClient.NoOpLogger ? console : context.logger)?.warn("An error was encountered in a non-retryable streaming request.");
              throw lastError;
            }
            try {
              retryToken = await retryStrategy.refreshRetryTokenForRetry(retryToken, retryErrorInfo);
            } catch (refreshError) {
              if (typeof refreshError.$backoff === "number") {
                await cooldown3(refreshError.$backoff);
              }
              if (!lastError.$metadata) {
                lastError.$metadata = {};
              }
              lastError.$metadata.attempts = attempts + 1;
              lastError.$metadata.totalRetryDelay = totalRetryDelay;
              throw lastError;
            }
            attempts = retryToken.getRetryCount();
            const delay = retryToken.getRetryDelay();
            totalRetryDelay += delay;
            await cooldown3(delay);
          }
        }
      } else {
        retryStrategy = retryStrategy;
        if (retryStrategy?.mode) {
          context.userAgent = [...context.userAgent || [], ["cfg/retry-mode", retryStrategy.mode]];
        }
        return retryStrategy.retry(next, args);
      }
    }, "retryMiddleware");
    var cooldown3 = /* @__PURE__ */ __name((ms) => new Promise((resolve13) => setTimeout(resolve13, ms)), "cooldown");
    var isRetryStrategyV23 = /* @__PURE__ */ __name((retryStrategy) => typeof retryStrategy.acquireInitialRetryToken !== "undefined" && typeof retryStrategy.refreshRetryTokenForRetry !== "undefined" && typeof retryStrategy.recordSuccess !== "undefined", "isRetryStrategyV2");
    var getRetryErrorInfo3 = /* @__PURE__ */ __name((error4, logger5) => {
      const errorInfo = {
        error: error4,
        errorType: getRetryErrorType3(error4)
      };
      const retryAfterHint = parseRetryAfterHeader3(error4.$response, logger5);
      if (retryAfterHint) {
        errorInfo.retryAfterHint = retryAfterHint;
      }
      return errorInfo;
    }, "getRetryErrorInfo");
    var getRetryErrorType3 = /* @__PURE__ */ __name((error4) => {
      if (serviceErrorClassification.isThrottlingError(error4))
        return "THROTTLING";
      if (serviceErrorClassification.isTransientError(error4))
        return "TRANSIENT";
      if (serviceErrorClassification.isServerError(error4))
        return "SERVER_ERROR";
      return "CLIENT_ERROR";
    }, "getRetryErrorType");
    var retryMiddlewareOptions3 = {
      name: "retryMiddleware",
      tags: ["RETRY"],
      step: "finalizeRequest",
      priority: "high",
      override: true
    };
    var getRetryPlugin30 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(retryMiddleware3(options), retryMiddlewareOptions3);
      }, "applyToStack")
    }), "getRetryPlugin");
    exports2.AdaptiveRetryStrategy = AdaptiveRetryStrategy5;
    exports2.CONFIG_MAX_ATTEMPTS = CONFIG_MAX_ATTEMPTS3;
    exports2.CONFIG_RETRY_MODE = CONFIG_RETRY_MODE3;
    exports2.ENV_MAX_ATTEMPTS = ENV_MAX_ATTEMPTS3;
    exports2.ENV_RETRY_MODE = ENV_RETRY_MODE3;
    exports2.NODE_MAX_ATTEMPT_CONFIG_OPTIONS = NODE_MAX_ATTEMPT_CONFIG_OPTIONS30;
    exports2.NODE_RETRY_MODE_CONFIG_OPTIONS = NODE_RETRY_MODE_CONFIG_OPTIONS30;
    exports2.StandardRetryStrategy = StandardRetryStrategy5;
    exports2.defaultDelayDecider = defaultDelayDecider3;
    exports2.defaultRetryDecider = defaultRetryDecider3;
    exports2.getOmitRetryHeadersPlugin = getOmitRetryHeadersPlugin3;
    exports2.getRetryAfterHint = getRetryAfterHint3;
    exports2.getRetryPlugin = getRetryPlugin30;
    exports2.omitRetryHeadersMiddleware = omitRetryHeadersMiddleware3;
    exports2.omitRetryHeadersMiddlewareOptions = omitRetryHeadersMiddlewareOptions3;
    exports2.resolveRetryConfig = resolveRetryConfig30;
    exports2.retryMiddleware = retryMiddleware3;
    exports2.retryMiddlewareOptions = retryMiddlewareOptions3;
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getDateHeader.js
var import_protocol_http19, getDateHeader3;
var init_getDateHeader3 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getDateHeader.js"() {
    import_protocol_http19 = __toESM(require_dist_cjs2());
    getDateHeader3 = /* @__PURE__ */ __name((response) => import_protocol_http19.HttpResponse.isInstance(response) ? response.headers?.date ?? response.headers?.Date : void 0, "getDateHeader");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getSkewCorrectedDate.js
var getSkewCorrectedDate3;
var init_getSkewCorrectedDate3 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getSkewCorrectedDate.js"() {
    getSkewCorrectedDate3 = /* @__PURE__ */ __name((systemClockOffset) => new Date(Date.now() + systemClockOffset), "getSkewCorrectedDate");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/isClockSkewed.js
var isClockSkewed3;
var init_isClockSkewed3 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/isClockSkewed.js"() {
    init_getSkewCorrectedDate3();
    isClockSkewed3 = /* @__PURE__ */ __name((clockTime, systemClockOffset) => Math.abs(getSkewCorrectedDate3(systemClockOffset).getTime() - clockTime) >= 3e5, "isClockSkewed");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getUpdatedSystemClockOffset.js
var getUpdatedSystemClockOffset3;
var init_getUpdatedSystemClockOffset3 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getUpdatedSystemClockOffset.js"() {
    init_isClockSkewed3();
    getUpdatedSystemClockOffset3 = /* @__PURE__ */ __name((clockTime, currentSystemClockOffset) => {
      const clockTimeInMs = Date.parse(clockTime);
      if (isClockSkewed3(clockTimeInMs, currentSystemClockOffset)) {
        return clockTimeInMs - Date.now();
      }
      return currentSystemClockOffset;
    }, "getUpdatedSystemClockOffset");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/index.js
var init_utils3 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/index.js"() {
    init_getDateHeader3();
    init_getSkewCorrectedDate3();
    init_getUpdatedSystemClockOffset3();
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4Signer.js
var import_protocol_http20, throwSigningPropertyError3, validateSigningProperties3, AwsSdkSigV4Signer3, AWSSDKSigV4Signer3;
var init_AwsSdkSigV4Signer3 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4Signer.js"() {
    import_protocol_http20 = __toESM(require_dist_cjs2());
    init_utils3();
    throwSigningPropertyError3 = /* @__PURE__ */ __name((name, property) => {
      if (!property) {
        throw new Error(`Property \`${name}\` is not resolved for AWS SDK SigV4Auth`);
      }
      return property;
    }, "throwSigningPropertyError");
    validateSigningProperties3 = /* @__PURE__ */ __name(async (signingProperties) => {
      const context = throwSigningPropertyError3("context", signingProperties.context);
      const config2 = throwSigningPropertyError3("config", signingProperties.config);
      const authScheme = context.endpointV2?.properties?.authSchemes?.[0];
      const signerFunction = throwSigningPropertyError3("signer", config2.signer);
      const signer = await signerFunction(authScheme);
      const signingRegion = signingProperties?.signingRegion;
      const signingRegionSet = signingProperties?.signingRegionSet;
      const signingName = signingProperties?.signingName;
      return {
        config: config2,
        signer,
        signingRegion,
        signingRegionSet,
        signingName
      };
    }, "validateSigningProperties");
    AwsSdkSigV4Signer3 = class {
      static {
        __name(this, "AwsSdkSigV4Signer");
      }
      async sign(httpRequest, identity, signingProperties) {
        if (!import_protocol_http20.HttpRequest.isInstance(httpRequest)) {
          throw new Error("The request is not an instance of `HttpRequest` and cannot be signed");
        }
        const validatedProps = await validateSigningProperties3(signingProperties);
        const { config: config2, signer } = validatedProps;
        let { signingRegion, signingName } = validatedProps;
        const handlerExecutionContext = signingProperties.context;
        if (handlerExecutionContext?.authSchemes?.length ?? 0 > 1) {
          const [first, second] = handlerExecutionContext.authSchemes;
          if (first?.name === "sigv4a" && second?.name === "sigv4") {
            signingRegion = second?.signingRegion ?? signingRegion;
            signingName = second?.signingName ?? signingName;
          }
        }
        const signedRequest = await signer.sign(httpRequest, {
          signingDate: getSkewCorrectedDate3(config2.systemClockOffset),
          signingRegion,
          signingService: signingName
        });
        return signedRequest;
      }
      errorHandler(signingProperties) {
        return (error4) => {
          const serverTime = error4.ServerTime ?? getDateHeader3(error4.$response);
          if (serverTime) {
            const config2 = throwSigningPropertyError3("config", signingProperties.config);
            const initialSystemClockOffset = config2.systemClockOffset;
            config2.systemClockOffset = getUpdatedSystemClockOffset3(serverTime, config2.systemClockOffset);
            const clockSkewCorrected = config2.systemClockOffset !== initialSystemClockOffset;
            if (clockSkewCorrected && error4.$metadata) {
              error4.$metadata.clockSkewCorrected = true;
            }
          }
          throw error4;
        };
      }
      successHandler(httpResponse, signingProperties) {
        const dateHeader = getDateHeader3(httpResponse);
        if (dateHeader) {
          const config2 = throwSigningPropertyError3("config", signingProperties.config);
          config2.systemClockOffset = getUpdatedSystemClockOffset3(dateHeader, config2.systemClockOffset);
        }
      }
    };
    AWSSDKSigV4Signer3 = AwsSdkSigV4Signer3;
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4ASigner.js
var import_protocol_http21, AwsSdkSigV4ASigner3;
var init_AwsSdkSigV4ASigner3 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4ASigner.js"() {
    import_protocol_http21 = __toESM(require_dist_cjs2());
    init_utils3();
    init_AwsSdkSigV4Signer3();
    AwsSdkSigV4ASigner3 = class extends AwsSdkSigV4Signer3 {
      static {
        __name(this, "AwsSdkSigV4ASigner");
      }
      async sign(httpRequest, identity, signingProperties) {
        if (!import_protocol_http21.HttpRequest.isInstance(httpRequest)) {
          throw new Error("The request is not an instance of `HttpRequest` and cannot be signed");
        }
        const { config: config2, signer, signingRegion, signingRegionSet, signingName } = await validateSigningProperties3(signingProperties);
        const configResolvedSigningRegionSet = await config2.sigv4aSigningRegionSet?.();
        const multiRegionOverride = (configResolvedSigningRegionSet ?? signingRegionSet ?? [signingRegion]).join(",");
        const signedRequest = await signer.sign(httpRequest, {
          signingDate: getSkewCorrectedDate3(config2.systemClockOffset),
          signingRegion: multiRegionOverride,
          signingService: signingName
        });
        return signedRequest;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getArrayForCommaSeparatedString.js
var getArrayForCommaSeparatedString3;
var init_getArrayForCommaSeparatedString3 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getArrayForCommaSeparatedString.js"() {
    getArrayForCommaSeparatedString3 = /* @__PURE__ */ __name((str) => typeof str === "string" && str.length > 0 ? str.split(",").map((item) => item.trim()) : [], "getArrayForCommaSeparatedString");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getBearerTokenEnvKey.js
var getBearerTokenEnvKey3;
var init_getBearerTokenEnvKey3 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getBearerTokenEnvKey.js"() {
    getBearerTokenEnvKey3 = /* @__PURE__ */ __name((signingName) => `AWS_BEARER_TOKEN_${signingName.replace(/[\s-]/g, "_").toUpperCase()}`, "getBearerTokenEnvKey");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/NODE_AUTH_SCHEME_PREFERENCE_OPTIONS.js
var NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY3, NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY3, NODE_AUTH_SCHEME_PREFERENCE_OPTIONS3;
var init_NODE_AUTH_SCHEME_PREFERENCE_OPTIONS3 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/NODE_AUTH_SCHEME_PREFERENCE_OPTIONS.js"() {
    init_getArrayForCommaSeparatedString3();
    init_getBearerTokenEnvKey3();
    NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY3 = "AWS_AUTH_SCHEME_PREFERENCE";
    NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY3 = "auth_scheme_preference";
    NODE_AUTH_SCHEME_PREFERENCE_OPTIONS3 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3, options) => {
        if (options?.signingName) {
          const bearerTokenKey = getBearerTokenEnvKey3(options.signingName);
          if (bearerTokenKey in env3)
            return ["httpBearerAuth"];
        }
        if (!(NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY3 in env3))
          return void 0;
        return getArrayForCommaSeparatedString3(env3[NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY3]);
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => {
        if (!(NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY3 in profile))
          return void 0;
        return getArrayForCommaSeparatedString3(profile[NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY3]);
      }, "configFileSelector"),
      default: []
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4AConfig.js
var import_property_provider3, resolveAwsSdkSigV4AConfig3, NODE_SIGV4A_CONFIG_OPTIONS3;
var init_resolveAwsSdkSigV4AConfig3 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4AConfig.js"() {
    init_dist_es();
    import_property_provider3 = __toESM(require_dist_cjs27());
    resolveAwsSdkSigV4AConfig3 = /* @__PURE__ */ __name((config2) => {
      config2.sigv4aSigningRegionSet = normalizeProvider(config2.sigv4aSigningRegionSet);
      return config2;
    }, "resolveAwsSdkSigV4AConfig");
    NODE_SIGV4A_CONFIG_OPTIONS3 = {
      environmentVariableSelector(env3) {
        if (env3.AWS_SIGV4A_SIGNING_REGION_SET) {
          return env3.AWS_SIGV4A_SIGNING_REGION_SET.split(",").map((_) => _.trim());
        }
        throw new import_property_provider3.ProviderError("AWS_SIGV4A_SIGNING_REGION_SET not set in env.", {
          tryNextLink: true
        });
      },
      configFileSelector(profile) {
        if (profile.sigv4a_signing_region_set) {
          return (profile.sigv4a_signing_region_set ?? "").split(",").map((_) => _.trim());
        }
        throw new import_property_provider3.ProviderError("sigv4a_signing_region_set not set in profile.", {
          tryNextLink: true
        });
      },
      default: void 0
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4Config.js
function normalizeCredentialProvider3(config2, { credentials, credentialDefaultProvider }) {
  let credentialsProvider;
  if (credentials) {
    if (!credentials?.memoized) {
      credentialsProvider = memoizeIdentityProvider(credentials, isIdentityExpired, doesIdentityRequireRefresh);
    } else {
      credentialsProvider = credentials;
    }
  } else {
    if (credentialDefaultProvider) {
      credentialsProvider = normalizeProvider(credentialDefaultProvider(Object.assign({}, config2, {
        parentClientConfig: config2
      })));
    } else {
      credentialsProvider = /* @__PURE__ */ __name(async () => {
        throw new Error("@aws-sdk/core::resolveAwsSdkSigV4Config - `credentials` not provided and no credentialDefaultProvider was configured.");
      }, "credentialsProvider");
    }
  }
  credentialsProvider.memoized = true;
  return credentialsProvider;
}
function bindCallerConfig3(config2, credentialsProvider) {
  if (credentialsProvider.configBound) {
    return credentialsProvider;
  }
  const fn = /* @__PURE__ */ __name(async (options) => credentialsProvider({ ...options, callerClientConfig: config2 }), "fn");
  fn.memoized = credentialsProvider.memoized;
  fn.configBound = true;
  return fn;
}
var import_signature_v43, resolveAwsSdkSigV4Config3, resolveAWSSDKSigV4Config3;
var init_resolveAwsSdkSigV4Config3 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4Config.js"() {
    init_client6();
    init_dist_es();
    import_signature_v43 = __toESM(require_dist_cjs36());
    resolveAwsSdkSigV4Config3 = /* @__PURE__ */ __name((config2) => {
      let inputCredentials = config2.credentials;
      let isUserSupplied = !!config2.credentials;
      let resolvedCredentials = void 0;
      Object.defineProperty(config2, "credentials", {
        set(credentials) {
          if (credentials && credentials !== inputCredentials && credentials !== resolvedCredentials) {
            isUserSupplied = true;
          }
          inputCredentials = credentials;
          const memoizedProvider = normalizeCredentialProvider3(config2, {
            credentials: inputCredentials,
            credentialDefaultProvider: config2.credentialDefaultProvider
          });
          const boundProvider = bindCallerConfig3(config2, memoizedProvider);
          if (isUserSupplied && !boundProvider.attributed) {
            const isCredentialObject = typeof inputCredentials === "object" && inputCredentials !== null;
            resolvedCredentials = /* @__PURE__ */ __name(async (options) => {
              const creds = await boundProvider(options);
              const attributedCreds = creds;
              if (isCredentialObject && (!attributedCreds.$source || Object.keys(attributedCreds.$source).length === 0)) {
                return setCredentialFeature5(attributedCreds, "CREDENTIALS_CODE", "e");
              }
              return attributedCreds;
            }, "resolvedCredentials");
            resolvedCredentials.memoized = boundProvider.memoized;
            resolvedCredentials.configBound = boundProvider.configBound;
            resolvedCredentials.attributed = true;
          } else {
            resolvedCredentials = boundProvider;
          }
        },
        get() {
          return resolvedCredentials;
        },
        enumerable: true,
        configurable: true
      });
      config2.credentials = inputCredentials;
      const { signingEscapePath = true, systemClockOffset = config2.systemClockOffset || 0, sha256 } = config2;
      let signer;
      if (config2.signer) {
        signer = normalizeProvider(config2.signer);
      } else if (config2.regionInfoProvider) {
        signer = /* @__PURE__ */ __name(() => normalizeProvider(config2.region)().then(async (region) => [
          await config2.regionInfoProvider(region, {
            useFipsEndpoint: await config2.useFipsEndpoint(),
            useDualstackEndpoint: await config2.useDualstackEndpoint()
          }) || {},
          region
        ]).then(([regionInfo, region]) => {
          const { signingRegion, signingService } = regionInfo;
          config2.signingRegion = config2.signingRegion || signingRegion || region;
          config2.signingName = config2.signingName || signingService || config2.serviceId;
          const params = {
            ...config2,
            credentials: config2.credentials,
            region: config2.signingRegion,
            service: config2.signingName,
            sha256,
            uriEscapePath: signingEscapePath
          };
          const SignerCtor = config2.signerConstructor || import_signature_v43.SignatureV4;
          return new SignerCtor(params);
        }), "signer");
      } else {
        signer = /* @__PURE__ */ __name(async (authScheme) => {
          authScheme = Object.assign({}, {
            name: "sigv4",
            signingName: config2.signingName || config2.defaultSigningName,
            signingRegion: await normalizeProvider(config2.region)(),
            properties: {}
          }, authScheme);
          const signingRegion = authScheme.signingRegion;
          const signingService = authScheme.signingName;
          config2.signingRegion = config2.signingRegion || signingRegion;
          config2.signingName = config2.signingName || signingService || config2.serviceId;
          const params = {
            ...config2,
            credentials: config2.credentials,
            region: config2.signingRegion,
            service: config2.signingName,
            sha256,
            uriEscapePath: signingEscapePath
          };
          const SignerCtor = config2.signerConstructor || import_signature_v43.SignatureV4;
          return new SignerCtor(params);
        }, "signer");
      }
      const resolvedConfig = Object.assign(config2, {
        systemClockOffset,
        signingEscapePath,
        signer
      });
      return resolvedConfig;
    }, "resolveAwsSdkSigV4Config");
    resolveAWSSDKSigV4Config3 = resolveAwsSdkSigV4Config3;
    __name(normalizeCredentialProvider3, "normalizeCredentialProvider");
    __name(bindCallerConfig3, "bindCallerConfig");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/index.js
var init_aws_sdk3 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/index.js"() {
    init_AwsSdkSigV4Signer3();
    init_AwsSdkSigV4ASigner3();
    init_NODE_AUTH_SCHEME_PREFERENCE_OPTIONS3();
    init_resolveAwsSdkSigV4AConfig3();
    init_resolveAwsSdkSigV4Config3();
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/index.js
var httpAuthSchemes_exports3 = {};
__export(httpAuthSchemes_exports3, {
  AWSSDKSigV4Signer: () => AWSSDKSigV4Signer3,
  AwsSdkSigV4ASigner: () => AwsSdkSigV4ASigner3,
  AwsSdkSigV4Signer: () => AwsSdkSigV4Signer3,
  NODE_AUTH_SCHEME_PREFERENCE_OPTIONS: () => NODE_AUTH_SCHEME_PREFERENCE_OPTIONS3,
  NODE_SIGV4A_CONFIG_OPTIONS: () => NODE_SIGV4A_CONFIG_OPTIONS3,
  getBearerTokenEnvKey: () => getBearerTokenEnvKey3,
  resolveAWSSDKSigV4Config: () => resolveAWSSDKSigV4Config3,
  resolveAwsSdkSigV4AConfig: () => resolveAwsSdkSigV4AConfig3,
  resolveAwsSdkSigV4Config: () => resolveAwsSdkSigV4Config3,
  validateSigningProperties: () => validateSigningProperties3
});
var init_httpAuthSchemes4 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/index.js"() {
    init_aws_sdk3();
    init_getBearerTokenEnvKey3();
  }
});

// ../../node_modules/@aws-sdk/client-s3/dist-cjs/endpoint/bdd.js
var require_bdd2 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/dist-cjs/endpoint/bdd.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.bdd = void 0;
    var util_endpoints_1 = require_dist_cjs20();
    var aw = "ref";
    var ax = "argv";
    var ay = "backend";
    var az = "authSchemes";
    var aA = "disableDoubleEncoding";
    var aB = "signingName";
    var aC = "signingRegion";
    var aD = "signingRegionSet";
    var a32 = -1;
    var b32 = true;
    var c32 = false;
    var d32 = "isSet";
    var e32 = "booleanEquals";
    var f32 = "stringEquals";
    var g32 = "coalesce";
    var h32 = "substring";
    var i32 = "";
    var j32 = "aws.partition";
    var k32 = "partitionResult";
    var l20 = "accessPointSuffix";
    var m20 = "regionPrefix";
    var n10 = /* @__PURE__ */ __name((n11) => "outpostId_ssa_" + n11 + i32, "n");
    var o10 = "hardwareType";
    var p10 = "ite";
    var q10 = "isValidHostLabel";
    var s = "sigv4";
    var t = "aws.isVirtualHostableS3Bucket";
    var u = "url";
    var v = "getAttr";
    var w = "bucketArn";
    var x = "--";
    var y = "arnType";
    var z = "accesspoint";
    var A = /* @__PURE__ */ __name((n11) => "accessPointName_ssa_" + n11 + i32, "A");
    var B = "s3-object-lambda";
    var C = "s3-outposts";
    var D = "bucketPartition";
    var E = "us-east-1";
    var F = "outpostType";
    var G = "name";
    var H = "s3";
    var I = "{url#scheme}://{Bucket}.{url#authority}{url#path}";
    var J = "{url#scheme}://{url#authority}{url#path}";
    var K = "{url#scheme}://{url#authority}{url#normalizedPath}{Bucket}";
    var L = "https://{Bucket}.s3-accelerate.{partitionResult#dnsSuffix}";
    var M = "https://{Bucket}.s3.{partitionResult#dnsSuffix}";
    var N = /* @__PURE__ */ __name((n11) => "{url#scheme}://{accessPointName_ssa_" + n11 + "}-{bucketArn#accountId}.{url#authority}{url#path}", "N");
    var O = /* @__PURE__ */ __name((n11) => "Invalid ARN: The access point name may only contain a-z, A-Z, 0-9 and `-`. Found: `{accessPointName_ssa_" + n11 + "}`", "O");
    var P = "sigv4a";
    var Q = "{url#scheme}://{url#authority}{url#normalizedPath}{uri_encoded_bucket}";
    var R = "https://s3.{partitionResult#dnsSuffix}/{uri_encoded_bucket}";
    var S = "https://s3.{partitionResult#dnsSuffix}";
    var T = { [aw]: "UseFIPS" };
    var U = { [aw]: "UseDualStack" };
    var V = { [aw]: "Bucket" };
    var W = { "fn": v, [ax]: [{ [aw]: k32 }, G] };
    var X = { [aw]: u };
    var Y = { [aw]: "Region" };
    var Z = { [aw]: w };
    var aa = { [aw]: y };
    var ab = { [aw]: "accessPointName_ssa_1" };
    var ac = { "fn": v, [ax]: [Z, "region"] };
    var ad = { [aw]: o10 };
    var ae = { "fn": v, [ax]: [Z, "service"] };
    var af = { "fn": v, [ax]: [Z, "accountId"] };
    var ag = { [ay]: "S3Express", [az]: [{ [aA]: true, [G]: "{_s3e_auth}", [aB]: "s3express", [aC]: "{Region}" }] };
    var ah = { [ay]: "S3Express", [az]: [{ [aA]: true, [G]: s, [aB]: "s3express", [aC]: "{Region}" }] };
    var ai = { [az]: [{ [aA]: true, [G]: P, [aB]: C, [aD]: ["*"] }, { [aA]: true, [G]: s, [aB]: C, [aC]: "{Region}" }] };
    var aj = { [az]: [{ [aA]: true, [G]: s, [aB]: H, [aC]: E }] };
    var ak = { [az]: [{ [aA]: true, [G]: s, [aB]: H, [aC]: "{Region}" }] };
    var al = { [az]: [{ [aA]: true, [G]: s, [aB]: B, [aC]: "{bucketArn#region}" }] };
    var am = { [az]: [{ [aA]: true, [G]: s, [aB]: H, [aC]: "{bucketArn#region}" }] };
    var an = { [az]: [{ [aA]: true, [G]: P, [aB]: C, [aD]: ["*"] }, { [aA]: true, [G]: s, [aB]: C, [aC]: "{bucketArn#region}" }] };
    var ao = { [az]: [{ [aA]: true, [G]: s, [aB]: B, [aC]: "{Region}" }] };
    var ap = [Y];
    var aq = [{ [aw]: "Endpoint" }];
    var as = [V];
    var at = [V, 0, 7, true];
    var au = [Z, "resourceId[1]"];
    var av = ["*"];
    var _data32 = {
      conditions: [
        [d32, ap],
        [e32, [{ [aw]: "Accelerate" }, b32]],
        [e32, [T, b32]],
        [e32, [U, b32]],
        [d32, aq],
        [d32, as],
        [f32, [{ fn: g32, [ax]: [{ fn: h32, [ax]: [V, 0, 6, b32] }, i32] }, "--x-s3"]],
        [f32, [{ fn: g32, [ax]: [{ fn: h32, [ax]: at }, i32] }, "--xa-s3"]],
        [j32, ap, k32],
        [h32, at, l20],
        [f32, [{ [aw]: l20 }, "--op-s3"]],
        [h32, [V, 8, 12, b32], m20],
        [h32, [V, 32, 49, b32], n10(2)],
        [h32, [V, 49, 50, b32], o10],
        [e32, [{ [aw]: "ForcePathStyle" }, b32]],
        [f32, [W, "aws-cn"]],
        [p10, [U, ".dualstack", i32], "_s3e_ds"],
        [q10, [{ [aw]: n10(2) }, c32]],
        [p10, [T, "-fips", i32], "_s3e_fips"],
        [p10, [{ fn: g32, [ax]: [{ [aw]: "DisableS3ExpressSessionAuth" }, c32] }, s, "sigv4-s3express"], "_s3e_auth"],
        [t, [V, c32]],
        ["parseURL", aq, u],
        [e32, [{ fn: g32, [ax]: [{ [aw]: "UseS3ExpressControlEndpoint" }, c32] }, b32]],
        [t, [V, b32]],
        [f32, [{ fn: v, [ax]: [X, "scheme"] }, "http"]],
        [q10, [Y, c32]],
        ["aws.parseArn", as, w],
        [v, [{ fn: "split", [ax]: [V, x, 0] }, "[-2]"], "s3expressAvailabilityZoneId"],
        [f32, [{ fn: g32, [ax]: [{ fn: h32, [ax]: [V, 0, 4, c32] }, i32] }, "arn:"]],
        [f32, [{ fn: g32, [ax]: [{ fn: h32, [ax]: [V, 16, 18, b32] }, i32] }, x]],
        [e32, [{ fn: v, [ax]: [X, "isIp"] }, b32]],
        [f32, [{ fn: g32, [ax]: [{ fn: h32, [ax]: [V, 21, 23, b32] }, i32] }, x]],
        [f32, [{ fn: g32, [ax]: [{ fn: h32, [ax]: [V, 27, 29, b32] }, i32] }, x]],
        [f32, [{ [aw]: m20 }, "beta"]],
        ["uriEncode", as, "uri_encoded_bucket"],
        [q10, [Y, b32]],
        [e32, [{ fn: g32, [ax]: [{ [aw]: "UseObjectLambdaEndpoint" }, c32] }, b32]],
        [v, [Z, "resourceId[0]"], y],
        [f32, [aa, i32]],
        [f32, [aa, z]],
        [v, au, A(1)],
        [f32, [ab, i32]],
        [f32, [ac, i32]],
        [f32, [{ fn: g32, [ax]: [{ fn: h32, [ax]: [V, 14, 16, b32] }, i32] }, x]],
        [f32, [ad, "e"]],
        [f32, [ad, "o"]],
        [f32, [Y, "aws-global"]],
        [f32, [{ fn: g32, [ax]: [{ fn: h32, [ax]: [V, 19, 21, b32] }, i32] }, x]],
        [f32, [ae, B]],
        [e32, [{ fn: g32, [ax]: [{ [aw]: "DisableAccessPoints" }, c32] }, b32]],
        [f32, [ae, C]],
        [j32, [ac], D],
        [q10, [ab, b32]],
        [f32, [{ fn: g32, [ax]: [{ fn: h32, [ax]: [V, 26, 28, b32] }, i32] }, x]],
        [f32, [{ fn: g32, [ax]: [{ fn: h32, [ax]: [V, 15, 17, b32] }, i32] }, x]],
        [v, [Z, "resourceId[4]"]],
        [f32, [{ fn: g32, [ax]: [{ fn: h32, [ax]: [V, 20, 22, b32] }, i32] }, x]],
        [e32, [{ [aw]: "UseGlobalEndpoint" }, b32]],
        [f32, [Y, E]],
        [v, au, n10(1)],
        [e32, [{ fn: g32, [ax]: [{ [aw]: "UseArnRegion" }, b32] }, b32]],
        [q10, [{ [aw]: n10(1) }, c32]],
        [v, [Z, "resourceId[2]"], F],
        [f32, [Y, ac]],
        [f32, [{ fn: v, [ax]: [{ [aw]: D }, G] }, W]],
        [e32, [{ [aw]: "DisableMultiRegionAccessPoints" }, b32]],
        [q10, [ac, b32]],
        [f32, [{ fn: v, [ax]: [Z, "partition"] }, W]],
        [f32, [af, i32]],
        [f32, [ae, H]],
        [q10, [af, c32]],
        [v, [Z, "resourceId[3]"], A(2)],
        [q10, [ab, c32]],
        [f32, [{ [aw]: F }, z]],
        [q10, [{ [aw]: A(2) }, c32]]
      ],
      results: [
        [a32],
        [a32, "Accelerate cannot be used with FIPS"],
        [a32, "Cannot set dual-stack in combination with a custom endpoint."],
        [a32, "A custom endpoint cannot be combined with FIPS"],
        [a32, "A custom endpoint cannot be combined with S3 Accelerate"],
        [a32, "Partition does not support FIPS"],
        [a32, "S3Express does not support S3 Accelerate."],
        ["{url#scheme}://{url#authority}/{uri_encoded_bucket}{url#path}", ag],
        [I, ag],
        [a32, "S3Express bucket name is not a valid virtual hostable name."],
        ["https://s3express-control{_s3e_fips}{_s3e_ds}.{Region}.{partitionResult#dnsSuffix}/{uri_encoded_bucket}", ah],
        ["https://{Bucket}.s3express{_s3e_fips}-{s3expressAvailabilityZoneId}{_s3e_ds}.{Region}.{partitionResult#dnsSuffix}", ag],
        [a32, "Unrecognized S3Express bucket name format."],
        [J, ag],
        ["https://s3express-control{_s3e_fips}{_s3e_ds}.{Region}.{partitionResult#dnsSuffix}", ah],
        [a32, "Expected a endpoint to be specified but no endpoint was found"],
        ["https://{Bucket}.ec2.{url#authority}", ai],
        ["https://{Bucket}.ec2.s3-outposts.{Region}.{partitionResult#dnsSuffix}", ai],
        ["https://{Bucket}.op-{outpostId_ssa_2}.{url#authority}", ai],
        ["https://{Bucket}.op-{outpostId_ssa_2}.s3-outposts.{Region}.{partitionResult#dnsSuffix}", ai],
        [a32, 'Unrecognized hardware type: "Expected hardware type o or e but got {hardwareType}"'],
        [a32, "Invalid Outposts Bucket alias - it must be a valid bucket name."],
        [a32, "Invalid ARN: The outpost Id must only contain a-z, A-Z, 0-9 and `-`."],
        [a32, "Custom endpoint `{Endpoint}` was not a valid URI"],
        [a32, "S3 Accelerate cannot be used in this region"],
        ["https://{Bucket}.s3-fips.dualstack.us-east-1.{partitionResult#dnsSuffix}", aj],
        ["https://{Bucket}.s3-fips.dualstack.{Region}.{partitionResult#dnsSuffix}", ak],
        ["https://{Bucket}.s3-fips.us-east-1.{partitionResult#dnsSuffix}", aj],
        ["https://{Bucket}.s3-fips.{Region}.{partitionResult#dnsSuffix}", ak],
        ["https://{Bucket}.s3-accelerate.dualstack.us-east-1.{partitionResult#dnsSuffix}", aj],
        ["https://{Bucket}.s3-accelerate.dualstack.{partitionResult#dnsSuffix}", ak],
        ["https://{Bucket}.s3.dualstack.us-east-1.{partitionResult#dnsSuffix}", aj],
        ["https://{Bucket}.s3.dualstack.{Region}.{partitionResult#dnsSuffix}", ak],
        [K, aj],
        [I, aj],
        [K, ak],
        [I, ak],
        [L, aj],
        [L, ak],
        [M, aj],
        [M, ak],
        ["https://{Bucket}.s3.{Region}.{partitionResult#dnsSuffix}", ak],
        [a32, "Invalid region: region was not a valid DNS name."],
        [a32, "S3 Object Lambda does not support Dual-stack"],
        [a32, "S3 Object Lambda does not support S3 Accelerate"],
        [a32, "Access points are not supported for this operation"],
        [a32, "Invalid configuration: region from ARN `{bucketArn#region}` does not match client region `{Region}` and UseArnRegion is `false`"],
        [a32, "Invalid ARN: Missing account id"],
        [N(1), al],
        ["https://{accessPointName_ssa_1}-{bucketArn#accountId}.s3-object-lambda-fips.{bucketArn#region}.{bucketPartition#dnsSuffix}", al],
        ["https://{accessPointName_ssa_1}-{bucketArn#accountId}.s3-object-lambda.{bucketArn#region}.{bucketPartition#dnsSuffix}", al],
        [a32, O(1)],
        [a32, "Invalid ARN: The account id may only contain a-z, A-Z, 0-9 and `-`. Found: `{bucketArn#accountId}`"],
        [a32, "Invalid region in ARN: `{bucketArn#region}` (invalid DNS name)"],
        [a32, "Client was configured for partition `{partitionResult#name}` but ARN (`{Bucket}`) has `{bucketPartition#name}`"],
        [a32, "Invalid ARN: The ARN may only contain a single resource component after `accesspoint`."],
        [a32, "Invalid ARN: bucket ARN is missing a region"],
        [a32, "Invalid ARN: Expected a resource of the format `accesspoint:<accesspoint name>` but no name was provided"],
        [a32, "Invalid ARN: Object Lambda ARNs only support `accesspoint` arn types, but found: `{arnType}`"],
        [a32, "Access Points do not support S3 Accelerate"],
        ["https://{accessPointName_ssa_1}-{bucketArn#accountId}.s3-accesspoint-fips.dualstack.{bucketArn#region}.{bucketPartition#dnsSuffix}", am],
        ["https://{accessPointName_ssa_1}-{bucketArn#accountId}.s3-accesspoint-fips.{bucketArn#region}.{bucketPartition#dnsSuffix}", am],
        ["https://{accessPointName_ssa_1}-{bucketArn#accountId}.s3-accesspoint.dualstack.{bucketArn#region}.{bucketPartition#dnsSuffix}", am],
        [N(1), am],
        ["https://{accessPointName_ssa_1}-{bucketArn#accountId}.s3-accesspoint.{bucketArn#region}.{bucketPartition#dnsSuffix}", am],
        [a32, "Invalid ARN: The ARN was not for the S3 service, found: {bucketArn#service}"],
        [a32, "S3 MRAP does not support dual-stack"],
        [a32, "S3 MRAP does not support FIPS"],
        [a32, "S3 MRAP does not support S3 Accelerate"],
        [a32, "Invalid configuration: Multi-Region Access Point ARNs are disabled."],
        ["https://{accessPointName_ssa_1}.accesspoint.s3-global.{partitionResult#dnsSuffix}", { [az]: [{ [aA]: b32, name: P, [aB]: H, [aD]: av }] }],
        [a32, "Client was configured for partition `{partitionResult#name}` but bucket referred to partition `{bucketArn#partition}`"],
        [a32, "Invalid Access Point Name"],
        [a32, "S3 Outposts does not support Dual-stack"],
        [a32, "S3 Outposts does not support FIPS"],
        [a32, "S3 Outposts does not support S3 Accelerate"],
        [a32, "Invalid Arn: Outpost Access Point ARN contains sub resources"],
        ["https://{accessPointName_ssa_2}-{bucketArn#accountId}.{outpostId_ssa_1}.{url#authority}", an],
        ["https://{accessPointName_ssa_2}-{bucketArn#accountId}.{outpostId_ssa_1}.s3-outposts.{bucketArn#region}.{bucketPartition#dnsSuffix}", an],
        [a32, O(2)],
        [a32, "Expected an outpost type `accesspoint`, found {outpostType}"],
        [a32, "Invalid ARN: expected an access point name"],
        [a32, "Invalid ARN: Expected a 4-component resource"],
        [a32, "Invalid ARN: The outpost Id may only contain a-z, A-Z, 0-9 and `-`. Found: `{outpostId_ssa_1}`"],
        [a32, "Invalid ARN: The Outpost Id was not set"],
        [a32, "Invalid ARN: Unrecognized format: {Bucket} (type: {arnType})"],
        [a32, "Invalid ARN: No ARN type specified"],
        [a32, "Invalid ARN: `{Bucket}` was not a valid ARN"],
        [a32, "Path-style addressing cannot be used with ARN buckets"],
        ["https://s3-fips.dualstack.us-east-1.{partitionResult#dnsSuffix}/{uri_encoded_bucket}", aj],
        ["https://s3-fips.dualstack.{Region}.{partitionResult#dnsSuffix}/{uri_encoded_bucket}", ak],
        ["https://s3-fips.us-east-1.{partitionResult#dnsSuffix}/{uri_encoded_bucket}", aj],
        ["https://s3-fips.{Region}.{partitionResult#dnsSuffix}/{uri_encoded_bucket}", ak],
        ["https://s3.dualstack.us-east-1.{partitionResult#dnsSuffix}/{uri_encoded_bucket}", aj],
        ["https://s3.dualstack.{Region}.{partitionResult#dnsSuffix}/{uri_encoded_bucket}", ak],
        [Q, aj],
        [Q, ak],
        [R, aj],
        [R, ak],
        ["https://s3.{Region}.{partitionResult#dnsSuffix}/{uri_encoded_bucket}", ak],
        [a32, "Path-style addressing cannot be used with S3 Accelerate"],
        [J, ao],
        ["https://s3-object-lambda-fips.{Region}.{partitionResult#dnsSuffix}", ao],
        ["https://s3-object-lambda.{Region}.{partitionResult#dnsSuffix}", ao],
        ["https://s3-fips.dualstack.us-east-1.{partitionResult#dnsSuffix}", aj],
        ["https://s3-fips.dualstack.{Region}.{partitionResult#dnsSuffix}", ak],
        ["https://s3-fips.us-east-1.{partitionResult#dnsSuffix}", aj],
        ["https://s3-fips.{Region}.{partitionResult#dnsSuffix}", ak],
        ["https://s3.dualstack.us-east-1.{partitionResult#dnsSuffix}", aj],
        ["https://s3.dualstack.{Region}.{partitionResult#dnsSuffix}", ak],
        [J, aj],
        [J, ak],
        [S, aj],
        [S, ak],
        ["https://s3.{Region}.{partitionResult#dnsSuffix}", ak],
        [a32, "A region must be set when sending requests to S3."]
      ]
    };
    var root32 = 2;
    var r32 = 1e8;
    var nodes32 = new Int32Array([
      -1,
      1,
      -1,
      0,
      3,
      r32 + 115,
      1,
      424,
      4,
      2,
      272,
      5,
      3,
      233,
      6,
      4,
      85,
      7,
      5,
      15,
      8,
      8,
      9,
      r32 + 115,
      16,
      10,
      13,
      18,
      11,
      13,
      19,
      12,
      13,
      22,
      r32 + 14,
      13,
      35,
      14,
      r32 + 42,
      36,
      r32 + 103,
      435,
      6,
      271,
      16,
      7,
      270,
      17,
      8,
      19,
      18,
      14,
      501,
      106,
      9,
      20,
      24,
      10,
      21,
      24,
      11,
      22,
      24,
      12,
      23,
      24,
      13,
      547,
      24,
      14,
      77,
      25,
      20,
      73,
      26,
      26,
      27,
      78,
      37,
      28,
      r32 + 86,
      38,
      r32 + 86,
      29,
      39,
      47,
      30,
      48,
      r32 + 58,
      31,
      50,
      32,
      r32 + 85,
      51,
      33,
      136,
      55,
      r32 + 76,
      34,
      59,
      35,
      r32 + 84,
      60,
      39,
      36,
      61,
      37,
      r32 + 83,
      62,
      38,
      146,
      63,
      41,
      r32 + 46,
      61,
      40,
      r32 + 83,
      62,
      41,
      150,
      64,
      42,
      r32 + 54,
      66,
      43,
      r32 + 53,
      70,
      44,
      r32 + 52,
      71,
      45,
      r32 + 81,
      73,
      46,
      r32 + 80,
      74,
      r32 + 78,
      r32 + 79,
      40,
      48,
      r32 + 57,
      41,
      r32 + 57,
      49,
      42,
      185,
      50,
      48,
      62,
      51,
      49,
      r32 + 45,
      52,
      51,
      53,
      526,
      60,
      56,
      54,
      62,
      r32 + 55,
      55,
      63,
      57,
      r32 + 46,
      62,
      r32 + 55,
      57,
      64,
      58,
      r32 + 54,
      66,
      59,
      r32 + 53,
      69,
      60,
      r32 + 65,
      70,
      61,
      r32 + 52,
      72,
      r32 + 64,
      r32 + 51,
      49,
      r32 + 45,
      63,
      51,
      64,
      526,
      60,
      67,
      65,
      62,
      r32 + 55,
      66,
      63,
      68,
      r32 + 46,
      62,
      r32 + 55,
      68,
      64,
      69,
      r32 + 54,
      66,
      70,
      r32 + 53,
      68,
      r32 + 47,
      71,
      70,
      72,
      r32 + 52,
      72,
      r32 + 50,
      r32 + 51,
      25,
      74,
      r32 + 42,
      46,
      r32 + 39,
      75,
      57,
      76,
      r32 + 41,
      58,
      r32 + 40,
      r32 + 41,
      26,
      r32 + 88,
      78,
      28,
      r32 + 87,
      79,
      34,
      82,
      80,
      35,
      81,
      545,
      36,
      r32 + 103,
      r32 + 115,
      46,
      r32 + 97,
      83,
      57,
      84,
      r32 + 99,
      58,
      r32 + 98,
      r32 + 99,
      5,
      101,
      86,
      8,
      87,
      r32 + 115,
      16,
      88,
      89,
      18,
      91,
      89,
      19,
      90,
      92,
      21,
      97,
      95,
      19,
      93,
      92,
      21,
      98,
      95,
      21,
      97,
      94,
      22,
      r32 + 14,
      95,
      35,
      96,
      r32 + 42,
      36,
      r32 + 103,
      r32 + 42,
      22,
      r32 + 13,
      98,
      35,
      99,
      r32 + 42,
      36,
      r32 + 101,
      100,
      46,
      r32 + 110,
      r32 + 111,
      6,
      214,
      102,
      7,
      208,
      103,
      8,
      119,
      104,
      14,
      118,
      105,
      21,
      106,
      r32 + 23,
      26,
      107,
      502,
      37,
      108,
      r32 + 86,
      38,
      r32 + 86,
      109,
      39,
      112,
      110,
      48,
      r32 + 58,
      111,
      50,
      136,
      r32 + 85,
      40,
      113,
      r32 + 57,
      41,
      r32 + 57,
      114,
      42,
      115,
      500,
      48,
      r32 + 56,
      116,
      52,
      117,
      r32 + 72,
      65,
      r32 + 69,
      r32 + 72,
      21,
      501,
      r32 + 23,
      9,
      120,
      124,
      10,
      121,
      124,
      11,
      122,
      124,
      12,
      123,
      124,
      13,
      202,
      124,
      14,
      195,
      125,
      20,
      190,
      126,
      21,
      127,
      r32 + 23,
      23,
      128,
      129,
      24,
      189,
      129,
      26,
      130,
      197,
      37,
      131,
      r32 + 86,
      38,
      r32 + 86,
      132,
      39,
      159,
      133,
      48,
      r32 + 58,
      134,
      50,
      135,
      r32 + 85,
      51,
      141,
      136,
      55,
      r32 + 76,
      137,
      59,
      138,
      r32 + 84,
      60,
      r32 + 83,
      139,
      61,
      140,
      r32 + 83,
      63,
      r32 + 83,
      r32 + 46,
      55,
      r32 + 76,
      142,
      59,
      143,
      r32 + 84,
      60,
      148,
      144,
      61,
      145,
      r32 + 83,
      62,
      147,
      146,
      63,
      150,
      r32 + 46,
      63,
      153,
      r32 + 46,
      61,
      149,
      r32 + 83,
      62,
      153,
      150,
      64,
      151,
      r32 + 54,
      66,
      152,
      r32 + 53,
      70,
      r32 + 82,
      r32 + 52,
      64,
      154,
      r32 + 54,
      66,
      155,
      r32 + 53,
      70,
      156,
      r32 + 52,
      71,
      157,
      r32 + 81,
      73,
      158,
      r32 + 80,
      74,
      r32 + 77,
      r32 + 79,
      40,
      160,
      r32 + 57,
      41,
      r32 + 57,
      161,
      42,
      185,
      162,
      48,
      174,
      163,
      49,
      r32 + 45,
      164,
      51,
      165,
      526,
      60,
      168,
      166,
      62,
      r32 + 55,
      167,
      63,
      169,
      r32 + 46,
      62,
      r32 + 55,
      169,
      64,
      170,
      r32 + 54,
      66,
      171,
      r32 + 53,
      69,
      172,
      r32 + 65,
      70,
      173,
      r32 + 52,
      72,
      r32 + 63,
      r32 + 51,
      49,
      r32 + 45,
      175,
      51,
      176,
      526,
      60,
      179,
      177,
      62,
      r32 + 55,
      178,
      63,
      180,
      r32 + 46,
      62,
      r32 + 55,
      180,
      64,
      181,
      r32 + 54,
      66,
      182,
      r32 + 53,
      68,
      r32 + 47,
      183,
      70,
      184,
      r32 + 52,
      72,
      r32 + 48,
      r32 + 51,
      48,
      r32 + 56,
      186,
      52,
      187,
      r32 + 72,
      65,
      r32 + 69,
      188,
      67,
      r32 + 70,
      r32 + 71,
      25,
      r32 + 36,
      r32 + 42,
      21,
      191,
      r32 + 23,
      25,
      192,
      r32 + 42,
      30,
      194,
      193,
      46,
      r32 + 34,
      r32 + 36,
      46,
      r32 + 33,
      r32 + 35,
      21,
      196,
      r32 + 23,
      26,
      r32 + 88,
      197,
      28,
      r32 + 87,
      198,
      34,
      201,
      199,
      35,
      200,
      545,
      36,
      r32 + 101,
      r32 + 115,
      46,
      r32 + 95,
      r32 + 96,
      17,
      203,
      r32 + 22,
      20,
      204,
      r32 + 21,
      21,
      205,
      550,
      33,
      206,
      550,
      44,
      r32 + 16,
      207,
      45,
      r32 + 18,
      r32 + 20,
      8,
      209,
      215,
      16,
      210,
      220,
      18,
      211,
      220,
      19,
      212,
      224,
      20,
      213,
      227,
      21,
      231,
      401,
      8,
      218,
      215,
      19,
      216,
      r32 + 9,
      20,
      217,
      227,
      21,
      231,
      r32 + 9,
      16,
      219,
      220,
      18,
      223,
      220,
      19,
      221,
      224,
      20,
      222,
      227,
      21,
      231,
      r32 + 12,
      19,
      226,
      224,
      20,
      225,
      r32 + 9,
      21,
      r32 + 9,
      r32 + 12,
      20,
      230,
      227,
      21,
      228,
      r32 + 9,
      30,
      229,
      r32 + 9,
      34,
      r32 + 7,
      r32 + 9,
      21,
      231,
      415,
      30,
      232,
      r32 + 8,
      34,
      r32 + 7,
      r32 + 8,
      4,
      r32 + 2,
      234,
      5,
      235,
      480,
      6,
      271,
      236,
      7,
      270,
      237,
      8,
      238,
      491,
      9,
      239,
      243,
      10,
      240,
      243,
      11,
      241,
      243,
      12,
      242,
      243,
      13,
      547,
      243,
      14,
      266,
      244,
      20,
      264,
      245,
      26,
      246,
      267,
      37,
      247,
      r32 + 86,
      38,
      r32 + 86,
      248,
      39,
      249,
      518,
      40,
      250,
      r32 + 57,
      41,
      r32 + 57,
      251,
      42,
      538,
      252,
      48,
      r32 + 43,
      253,
      49,
      r32 + 45,
      254,
      51,
      255,
      526,
      60,
      258,
      256,
      62,
      r32 + 55,
      257,
      63,
      259,
      r32 + 46,
      62,
      r32 + 55,
      259,
      64,
      260,
      r32 + 54,
      66,
      261,
      r32 + 53,
      69,
      262,
      r32 + 65,
      70,
      263,
      r32 + 52,
      72,
      r32 + 62,
      r32 + 51,
      25,
      265,
      r32 + 42,
      46,
      r32 + 31,
      r32 + 32,
      26,
      r32 + 88,
      267,
      28,
      r32 + 87,
      268,
      34,
      269,
      544,
      46,
      r32 + 93,
      r32 + 94,
      8,
      397,
      r32 + 9,
      8,
      407,
      r32 + 9,
      3,
      346,
      273,
      4,
      r32 + 3,
      274,
      5,
      284,
      275,
      8,
      276,
      r32 + 115,
      15,
      r32 + 5,
      277,
      16,
      278,
      281,
      18,
      279,
      281,
      19,
      280,
      281,
      22,
      r32 + 14,
      281,
      35,
      282,
      r32 + 42,
      36,
      r32 + 102,
      283,
      46,
      r32 + 106,
      r32 + 107,
      6,
      405,
      285,
      7,
      395,
      286,
      8,
      295,
      287,
      14,
      501,
      288,
      26,
      289,
      502,
      37,
      290,
      r32 + 86,
      38,
      r32 + 86,
      291,
      39,
      292,
      307,
      40,
      293,
      r32 + 57,
      41,
      r32 + 57,
      294,
      42,
      335,
      500,
      9,
      296,
      300,
      10,
      297,
      300,
      11,
      298,
      300,
      12,
      299,
      300,
      13,
      394,
      300,
      14,
      339,
      301,
      15,
      r32 + 5,
      302,
      20,
      337,
      303,
      26,
      304,
      341,
      37,
      305,
      r32 + 86,
      38,
      r32 + 86,
      306,
      39,
      309,
      307,
      48,
      r32 + 58,
      308,
      50,
      r32 + 74,
      r32 + 85,
      40,
      310,
      r32 + 57,
      41,
      r32 + 57,
      311,
      42,
      335,
      312,
      48,
      324,
      313,
      49,
      r32 + 45,
      314,
      51,
      315,
      526,
      60,
      318,
      316,
      62,
      r32 + 55,
      317,
      63,
      319,
      r32 + 46,
      62,
      r32 + 55,
      319,
      64,
      320,
      r32 + 54,
      66,
      321,
      r32 + 53,
      69,
      322,
      r32 + 65,
      70,
      323,
      r32 + 52,
      72,
      r32 + 61,
      r32 + 51,
      49,
      r32 + 45,
      325,
      51,
      326,
      526,
      60,
      329,
      327,
      62,
      r32 + 55,
      328,
      63,
      330,
      r32 + 46,
      62,
      r32 + 55,
      330,
      64,
      331,
      r32 + 54,
      66,
      332,
      r32 + 53,
      68,
      r32 + 47,
      333,
      70,
      334,
      r32 + 52,
      72,
      r32 + 49,
      r32 + 51,
      48,
      r32 + 56,
      336,
      52,
      r32 + 67,
      r32 + 72,
      25,
      338,
      r32 + 42,
      46,
      r32 + 27,
      r32 + 28,
      15,
      r32 + 5,
      340,
      26,
      r32 + 88,
      341,
      28,
      r32 + 87,
      342,
      34,
      345,
      343,
      35,
      344,
      545,
      36,
      r32 + 102,
      r32 + 115,
      46,
      r32 + 91,
      r32 + 92,
      4,
      r32 + 2,
      347,
      5,
      357,
      348,
      8,
      349,
      r32 + 115,
      15,
      r32 + 5,
      350,
      16,
      351,
      354,
      18,
      352,
      354,
      19,
      353,
      354,
      22,
      r32 + 14,
      354,
      35,
      355,
      r32 + 42,
      36,
      r32 + 43,
      356,
      46,
      r32 + 104,
      r32 + 105,
      6,
      405,
      358,
      7,
      395,
      359,
      8,
      360,
      491,
      9,
      361,
      365,
      10,
      362,
      365,
      11,
      363,
      365,
      12,
      364,
      365,
      13,
      394,
      365,
      14,
      389,
      366,
      15,
      r32 + 5,
      367,
      20,
      387,
      368,
      26,
      369,
      391,
      37,
      370,
      r32 + 86,
      38,
      r32 + 86,
      371,
      39,
      372,
      518,
      40,
      373,
      r32 + 57,
      41,
      r32 + 57,
      374,
      42,
      538,
      375,
      48,
      r32 + 43,
      376,
      49,
      r32 + 45,
      377,
      51,
      378,
      526,
      60,
      381,
      379,
      62,
      r32 + 55,
      380,
      63,
      382,
      r32 + 46,
      62,
      r32 + 55,
      382,
      64,
      383,
      r32 + 54,
      66,
      384,
      r32 + 53,
      69,
      385,
      r32 + 65,
      70,
      386,
      r32 + 52,
      72,
      r32 + 60,
      r32 + 51,
      25,
      388,
      r32 + 42,
      46,
      r32 + 25,
      r32 + 26,
      15,
      r32 + 5,
      390,
      26,
      r32 + 88,
      391,
      28,
      r32 + 87,
      392,
      34,
      393,
      544,
      46,
      r32 + 89,
      r32 + 90,
      15,
      r32 + 5,
      547,
      8,
      396,
      r32 + 9,
      15,
      r32 + 5,
      397,
      16,
      398,
      410,
      18,
      399,
      410,
      19,
      400,
      410,
      20,
      401,
      r32 + 9,
      27,
      402,
      r32 + 12,
      29,
      r32 + 11,
      403,
      31,
      r32 + 11,
      404,
      32,
      r32 + 11,
      422,
      8,
      406,
      r32 + 9,
      15,
      r32 + 5,
      407,
      16,
      408,
      410,
      18,
      409,
      410,
      19,
      411,
      410,
      20,
      r32 + 12,
      r32 + 9,
      20,
      414,
      412,
      22,
      413,
      r32 + 9,
      34,
      r32 + 10,
      r32 + 9,
      22,
      416,
      415,
      27,
      419,
      r32 + 12,
      27,
      418,
      417,
      34,
      r32 + 10,
      r32 + 12,
      34,
      r32 + 10,
      419,
      43,
      r32 + 11,
      420,
      47,
      r32 + 11,
      421,
      53,
      r32 + 11,
      422,
      54,
      r32 + 11,
      423,
      56,
      r32 + 11,
      r32 + 12,
      2,
      r32 + 1,
      425,
      3,
      478,
      426,
      4,
      r32 + 4,
      427,
      5,
      438,
      428,
      8,
      429,
      r32 + 115,
      16,
      430,
      433,
      18,
      431,
      433,
      19,
      432,
      433,
      22,
      r32 + 14,
      433,
      35,
      434,
      r32 + 42,
      36,
      r32 + 44,
      435,
      46,
      r32 + 112,
      436,
      57,
      437,
      r32 + 114,
      58,
      r32 + 113,
      r32 + 114,
      6,
      r32 + 6,
      439,
      7,
      r32 + 6,
      440,
      8,
      450,
      441,
      14,
      501,
      442,
      26,
      443,
      502,
      37,
      444,
      r32 + 86,
      38,
      r32 + 86,
      445,
      39,
      446,
      465,
      40,
      447,
      r32 + 57,
      41,
      r32 + 57,
      448,
      42,
      471,
      449,
      48,
      r32 + 44,
      500,
      9,
      451,
      455,
      10,
      452,
      455,
      11,
      453,
      455,
      12,
      454,
      455,
      13,
      547,
      455,
      14,
      473,
      456,
      15,
      460,
      457,
      20,
      458,
      461,
      25,
      459,
      r32 + 42,
      46,
      r32 + 37,
      r32 + 38,
      20,
      540,
      461,
      26,
      462,
      474,
      37,
      463,
      r32 + 86,
      38,
      r32 + 86,
      464,
      39,
      467,
      465,
      48,
      r32 + 58,
      466,
      50,
      r32 + 75,
      r32 + 85,
      40,
      468,
      r32 + 57,
      41,
      r32 + 57,
      469,
      42,
      471,
      470,
      48,
      r32 + 44,
      524,
      48,
      r32 + 44,
      472,
      52,
      r32 + 68,
      r32 + 72,
      26,
      r32 + 88,
      474,
      28,
      r32 + 87,
      475,
      34,
      r32 + 100,
      476,
      35,
      477,
      545,
      36,
      r32 + 44,
      r32 + 115,
      4,
      r32 + 2,
      479,
      5,
      488,
      480,
      8,
      481,
      r32 + 115,
      16,
      482,
      485,
      18,
      483,
      485,
      19,
      484,
      485,
      22,
      r32 + 14,
      485,
      35,
      486,
      r32 + 42,
      36,
      r32 + 43,
      487,
      46,
      r32 + 108,
      r32 + 109,
      6,
      r32 + 6,
      489,
      7,
      r32 + 6,
      490,
      8,
      503,
      491,
      14,
      501,
      492,
      26,
      493,
      502,
      37,
      494,
      r32 + 86,
      38,
      r32 + 86,
      495,
      39,
      496,
      518,
      40,
      497,
      r32 + 57,
      41,
      r32 + 57,
      498,
      42,
      538,
      499,
      48,
      r32 + 43,
      500,
      49,
      r32 + 45,
      526,
      26,
      r32 + 88,
      502,
      28,
      r32 + 87,
      r32 + 115,
      9,
      504,
      508,
      10,
      505,
      508,
      11,
      506,
      508,
      12,
      507,
      508,
      13,
      547,
      508,
      14,
      541,
      509,
      15,
      513,
      510,
      20,
      511,
      514,
      25,
      512,
      r32 + 42,
      46,
      r32 + 29,
      r32 + 30,
      20,
      540,
      514,
      26,
      515,
      542,
      37,
      516,
      r32 + 86,
      38,
      r32 + 86,
      517,
      39,
      520,
      518,
      48,
      r32 + 58,
      519,
      50,
      r32 + 73,
      r32 + 85,
      40,
      521,
      r32 + 57,
      41,
      r32 + 57,
      522,
      42,
      538,
      523,
      48,
      r32 + 43,
      524,
      49,
      r32 + 45,
      525,
      51,
      529,
      526,
      60,
      r32 + 55,
      527,
      62,
      r32 + 55,
      528,
      63,
      r32 + 55,
      r32 + 46,
      60,
      532,
      530,
      62,
      r32 + 55,
      531,
      63,
      533,
      r32 + 46,
      62,
      r32 + 55,
      533,
      64,
      534,
      r32 + 54,
      66,
      535,
      r32 + 53,
      69,
      536,
      r32 + 65,
      70,
      537,
      r32 + 52,
      72,
      r32 + 59,
      r32 + 51,
      48,
      r32 + 43,
      539,
      52,
      r32 + 66,
      r32 + 72,
      25,
      r32 + 24,
      r32 + 42,
      26,
      r32 + 88,
      542,
      28,
      r32 + 87,
      543,
      34,
      r32 + 100,
      544,
      35,
      546,
      545,
      36,
      r32 + 42,
      r32 + 115,
      36,
      r32 + 43,
      r32 + 115,
      17,
      548,
      r32 + 22,
      20,
      549,
      r32 + 21,
      33,
      552,
      550,
      44,
      r32 + 17,
      551,
      45,
      r32 + 19,
      r32 + 20,
      44,
      r32 + 15,
      553,
      45,
      r32 + 15,
      r32 + 20
    ]);
    exports2.bdd = util_endpoints_1.BinaryDecisionDiagram.from(nodes32, root32, _data32.conditions, _data32.results);
  }
});

// ../../node_modules/@aws-sdk/client-s3/dist-cjs/endpoint/endpointResolver.js
var require_endpointResolver2 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/dist-cjs/endpoint/endpointResolver.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.defaultEndpointResolver = void 0;
    var util_endpoints_1 = require_dist_cjs21();
    var util_endpoints_2 = require_dist_cjs20();
    var bdd_1 = require_bdd2();
    var cache32 = new util_endpoints_2.EndpointCache({
      size: 50,
      params: [
        "Accelerate",
        "Bucket",
        "DisableAccessPoints",
        "DisableMultiRegionAccessPoints",
        "DisableS3ExpressSessionAuth",
        "Endpoint",
        "ForcePathStyle",
        "Region",
        "UseArnRegion",
        "UseDualStack",
        "UseFIPS",
        "UseGlobalEndpoint",
        "UseObjectLambdaEndpoint",
        "UseS3ExpressControlEndpoint"
      ]
    });
    var defaultEndpointResolver32 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache32.get(endpointParams, () => (0, util_endpoints_2.decideEndpoint)(bdd_1.bdd, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    exports2.defaultEndpointResolver = defaultEndpointResolver32;
    util_endpoints_2.customEndpointFunctions.aws = util_endpoints_1.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-s3/dist-cjs/auth/httpAuthSchemeProvider.js
var require_httpAuthSchemeProvider2 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/dist-cjs/auth/httpAuthSchemeProvider.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.resolveHttpAuthSchemeConfig = exports2.defaultS3HttpAuthSchemeProvider = exports2.defaultS3HttpAuthSchemeParametersProvider = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes4(), __toCommonJS(httpAuthSchemes_exports3));
    var signature_v4_multi_region_1 = require_dist_cjs55();
    var middleware_endpoint_1 = require_dist_cjs31();
    var util_middleware_1 = require_dist_cjs6();
    var endpointResolver_1 = require_endpointResolver2();
    var createEndpointRuleSetHttpAuthSchemeParametersProvider10 = /* @__PURE__ */ __name((defaultHttpAuthSchemeParametersProvider) => async (config2, context, input) => {
      if (!input) {
        throw new Error("Could not find `input` for `defaultEndpointRuleSetHttpAuthSchemeParametersProvider`");
      }
      const defaultParameters = await defaultHttpAuthSchemeParametersProvider(config2, context, input);
      const instructionsFn = (0, util_middleware_1.getSmithyContext)(context)?.commandInstance?.constructor?.getEndpointParameterInstructions;
      if (!instructionsFn) {
        throw new Error(`getEndpointParameterInstructions() is not defined on '${context.commandName}'`);
      }
      const endpointParameters = await (0, middleware_endpoint_1.resolveParams)(input, { getEndpointParameterInstructions: instructionsFn }, config2);
      return Object.assign(defaultParameters, endpointParameters);
    }, "createEndpointRuleSetHttpAuthSchemeParametersProvider");
    var _defaultS3HttpAuthSchemeParametersProvider = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, util_middleware_1.getSmithyContext)(context).operation,
        region: await (0, util_middleware_1.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "_defaultS3HttpAuthSchemeParametersProvider");
    exports2.defaultS3HttpAuthSchemeParametersProvider = createEndpointRuleSetHttpAuthSchemeParametersProvider10(_defaultS3HttpAuthSchemeParametersProvider);
    function createAwsAuthSigv4HttpAuthOption32(authParameters) {
      return {
        schemeId: "aws.auth#sigv4",
        signingProperties: {
          name: "s3",
          region: authParameters.region
        },
        propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
          signingProperties: {
            config: config2,
            context
          }
        }), "propertiesExtractor")
      };
    }
    __name(createAwsAuthSigv4HttpAuthOption32, "createAwsAuthSigv4HttpAuthOption");
    function createAwsAuthSigv4aHttpAuthOption10(authParameters) {
      return {
        schemeId: "aws.auth#sigv4a",
        signingProperties: {
          name: "s3",
          region: authParameters.region
        },
        propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
          signingProperties: {
            config: config2,
            context
          }
        }), "propertiesExtractor")
      };
    }
    __name(createAwsAuthSigv4aHttpAuthOption10, "createAwsAuthSigv4aHttpAuthOption");
    var createEndpointRuleSetHttpAuthSchemeProvider10 = /* @__PURE__ */ __name((defaultEndpointResolver32, defaultHttpAuthSchemeResolver, createHttpAuthOptionFunctions) => {
      const endpointRuleSetHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
        const endpoint = defaultEndpointResolver32(authParameters);
        const authSchemes = endpoint.properties?.authSchemes;
        if (!authSchemes) {
          return defaultHttpAuthSchemeResolver(authParameters);
        }
        const options = [];
        for (const scheme of authSchemes) {
          const { name: resolvedName, properties = {}, ...rest } = scheme;
          const name = resolvedName.toLowerCase();
          if (resolvedName !== name) {
            console.warn(`HttpAuthScheme has been normalized with lowercasing: '${resolvedName}' to '${name}'`);
          }
          let schemeId;
          if (name === "sigv4a") {
            schemeId = "aws.auth#sigv4a";
            const sigv4Present = authSchemes.find((s) => {
              const name2 = s.name.toLowerCase();
              return name2 !== "sigv4a" && name2.startsWith("sigv4");
            });
            if (signature_v4_multi_region_1.SignatureV4MultiRegion.sigv4aDependency() === "none" && sigv4Present) {
              continue;
            }
          } else if (name.startsWith("sigv4")) {
            schemeId = "aws.auth#sigv4";
          } else {
            throw new Error(`Unknown HttpAuthScheme found in '@smithy.rules#endpointRuleSet': '${name}'`);
          }
          const createOption = createHttpAuthOptionFunctions[schemeId];
          if (!createOption) {
            throw new Error(`Could not find HttpAuthOption create function for '${schemeId}'`);
          }
          const option = createOption(authParameters);
          option.schemeId = schemeId;
          option.signingProperties = { ...option.signingProperties || {}, ...rest, ...properties };
          options.push(option);
        }
        return options;
      }, "endpointRuleSetHttpAuthSchemeProvider");
      return endpointRuleSetHttpAuthSchemeProvider;
    }, "createEndpointRuleSetHttpAuthSchemeProvider");
    var _defaultS3HttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption32(authParameters));
          options.push(createAwsAuthSigv4aHttpAuthOption10(authParameters));
        }
      }
      return options;
    }, "_defaultS3HttpAuthSchemeProvider");
    exports2.defaultS3HttpAuthSchemeProvider = createEndpointRuleSetHttpAuthSchemeProvider10(endpointResolver_1.defaultEndpointResolver, _defaultS3HttpAuthSchemeProvider, {
      "aws.auth#sigv4": createAwsAuthSigv4HttpAuthOption32,
      "aws.auth#sigv4a": createAwsAuthSigv4aHttpAuthOption10
    });
    var resolveHttpAuthSchemeConfig32 = /* @__PURE__ */ __name((config2) => {
      const config_0 = (0, httpAuthSchemes_1.resolveAwsSdkSigV4Config)(config2);
      const config_1 = (0, httpAuthSchemes_1.resolveAwsSdkSigV4AConfig)(config_0);
      return Object.assign(config_1, {
        authSchemePreference: (0, util_middleware_1.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
    exports2.resolveHttpAuthSchemeConfig = resolveHttpAuthSchemeConfig32;
  }
});

// ../../node_modules/@aws-sdk/client-s3/dist-cjs/models/S3ServiceException.js
var require_S3ServiceException = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/dist-cjs/models/S3ServiceException.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.S3ServiceException = exports2.__ServiceException = void 0;
    var smithy_client_1 = require_dist_cjs34();
    Object.defineProperty(exports2, "__ServiceException", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return smithy_client_1.ServiceException;
    }, "get") });
    var S3ServiceException = class _S3ServiceException extends smithy_client_1.ServiceException {
      static {
        __name(this, "S3ServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _S3ServiceException.prototype);
      }
    };
    exports2.S3ServiceException = S3ServiceException;
  }
});

// ../../node_modules/@aws-sdk/client-s3/dist-cjs/models/errors.js
var require_errors2 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/dist-cjs/models/errors.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ObjectAlreadyInActiveTierError = exports2.IdempotencyParameterMismatch = exports2.TooManyParts = exports2.InvalidWriteOffset = exports2.InvalidRequest = exports2.EncryptionTypeMismatch = exports2.NotFound = exports2.NoSuchKey = exports2.InvalidObjectState = exports2.NoSuchBucket = exports2.BucketAlreadyOwnedByYou = exports2.BucketAlreadyExists = exports2.ObjectNotInActiveTierError = exports2.AccessDenied = exports2.NoSuchUpload = void 0;
    var S3ServiceException_1 = require_S3ServiceException();
    var NoSuchUpload = class _NoSuchUpload extends S3ServiceException_1.S3ServiceException {
      static {
        __name(this, "NoSuchUpload");
      }
      name = "NoSuchUpload";
      $fault = "client";
      constructor(opts) {
        super({
          name: "NoSuchUpload",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _NoSuchUpload.prototype);
      }
    };
    exports2.NoSuchUpload = NoSuchUpload;
    var AccessDenied = class _AccessDenied extends S3ServiceException_1.S3ServiceException {
      static {
        __name(this, "AccessDenied");
      }
      name = "AccessDenied";
      $fault = "client";
      constructor(opts) {
        super({
          name: "AccessDenied",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AccessDenied.prototype);
      }
    };
    exports2.AccessDenied = AccessDenied;
    var ObjectNotInActiveTierError = class _ObjectNotInActiveTierError extends S3ServiceException_1.S3ServiceException {
      static {
        __name(this, "ObjectNotInActiveTierError");
      }
      name = "ObjectNotInActiveTierError";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ObjectNotInActiveTierError",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ObjectNotInActiveTierError.prototype);
      }
    };
    exports2.ObjectNotInActiveTierError = ObjectNotInActiveTierError;
    var BucketAlreadyExists = class _BucketAlreadyExists extends S3ServiceException_1.S3ServiceException {
      static {
        __name(this, "BucketAlreadyExists");
      }
      name = "BucketAlreadyExists";
      $fault = "client";
      constructor(opts) {
        super({
          name: "BucketAlreadyExists",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _BucketAlreadyExists.prototype);
      }
    };
    exports2.BucketAlreadyExists = BucketAlreadyExists;
    var BucketAlreadyOwnedByYou = class _BucketAlreadyOwnedByYou extends S3ServiceException_1.S3ServiceException {
      static {
        __name(this, "BucketAlreadyOwnedByYou");
      }
      name = "BucketAlreadyOwnedByYou";
      $fault = "client";
      constructor(opts) {
        super({
          name: "BucketAlreadyOwnedByYou",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _BucketAlreadyOwnedByYou.prototype);
      }
    };
    exports2.BucketAlreadyOwnedByYou = BucketAlreadyOwnedByYou;
    var NoSuchBucket = class _NoSuchBucket extends S3ServiceException_1.S3ServiceException {
      static {
        __name(this, "NoSuchBucket");
      }
      name = "NoSuchBucket";
      $fault = "client";
      constructor(opts) {
        super({
          name: "NoSuchBucket",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _NoSuchBucket.prototype);
      }
    };
    exports2.NoSuchBucket = NoSuchBucket;
    var InvalidObjectState = class _InvalidObjectState extends S3ServiceException_1.S3ServiceException {
      static {
        __name(this, "InvalidObjectState");
      }
      name = "InvalidObjectState";
      $fault = "client";
      StorageClass;
      AccessTier;
      constructor(opts) {
        super({
          name: "InvalidObjectState",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidObjectState.prototype);
        this.StorageClass = opts.StorageClass;
        this.AccessTier = opts.AccessTier;
      }
    };
    exports2.InvalidObjectState = InvalidObjectState;
    var NoSuchKey = class _NoSuchKey extends S3ServiceException_1.S3ServiceException {
      static {
        __name(this, "NoSuchKey");
      }
      name = "NoSuchKey";
      $fault = "client";
      constructor(opts) {
        super({
          name: "NoSuchKey",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _NoSuchKey.prototype);
      }
    };
    exports2.NoSuchKey = NoSuchKey;
    var NotFound = class _NotFound extends S3ServiceException_1.S3ServiceException {
      static {
        __name(this, "NotFound");
      }
      name = "NotFound";
      $fault = "client";
      constructor(opts) {
        super({
          name: "NotFound",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _NotFound.prototype);
      }
    };
    exports2.NotFound = NotFound;
    var EncryptionTypeMismatch = class _EncryptionTypeMismatch extends S3ServiceException_1.S3ServiceException {
      static {
        __name(this, "EncryptionTypeMismatch");
      }
      name = "EncryptionTypeMismatch";
      $fault = "client";
      constructor(opts) {
        super({
          name: "EncryptionTypeMismatch",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _EncryptionTypeMismatch.prototype);
      }
    };
    exports2.EncryptionTypeMismatch = EncryptionTypeMismatch;
    var InvalidRequest = class _InvalidRequest extends S3ServiceException_1.S3ServiceException {
      static {
        __name(this, "InvalidRequest");
      }
      name = "InvalidRequest";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidRequest",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidRequest.prototype);
      }
    };
    exports2.InvalidRequest = InvalidRequest;
    var InvalidWriteOffset = class _InvalidWriteOffset extends S3ServiceException_1.S3ServiceException {
      static {
        __name(this, "InvalidWriteOffset");
      }
      name = "InvalidWriteOffset";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidWriteOffset",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidWriteOffset.prototype);
      }
    };
    exports2.InvalidWriteOffset = InvalidWriteOffset;
    var TooManyParts = class _TooManyParts extends S3ServiceException_1.S3ServiceException {
      static {
        __name(this, "TooManyParts");
      }
      name = "TooManyParts";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TooManyParts",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyParts.prototype);
      }
    };
    exports2.TooManyParts = TooManyParts;
    var IdempotencyParameterMismatch = class _IdempotencyParameterMismatch extends S3ServiceException_1.S3ServiceException {
      static {
        __name(this, "IdempotencyParameterMismatch");
      }
      name = "IdempotencyParameterMismatch";
      $fault = "client";
      constructor(opts) {
        super({
          name: "IdempotencyParameterMismatch",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _IdempotencyParameterMismatch.prototype);
      }
    };
    exports2.IdempotencyParameterMismatch = IdempotencyParameterMismatch;
    var ObjectAlreadyInActiveTierError = class _ObjectAlreadyInActiveTierError extends S3ServiceException_1.S3ServiceException {
      static {
        __name(this, "ObjectAlreadyInActiveTierError");
      }
      name = "ObjectAlreadyInActiveTierError";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ObjectAlreadyInActiveTierError",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ObjectAlreadyInActiveTierError.prototype);
      }
    };
    exports2.ObjectAlreadyInActiveTierError = ObjectAlreadyInActiveTierError;
  }
});

// ../../node_modules/@aws-sdk/client-s3/dist-cjs/schemas/schemas_0.js
var require_schemas_02 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/dist-cjs/schemas/schemas_0.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.CreateBucketMetadataTableConfigurationRequest$ = exports2.CreateBucketMetadataConfigurationRequest$ = exports2.CreateBucketConfiguration$ = exports2.CORSRule$ = exports2.CORSConfiguration$ = exports2.CopyPartResult$ = exports2.CopyObjectResult$ = exports2.CopyObjectRequest$ = exports2.CopyObjectOutput$ = exports2.ContinuationEvent$ = exports2.Condition$ = exports2.CompleteMultipartUploadRequest$ = exports2.CompleteMultipartUploadOutput$ = exports2.CompletedPart$ = exports2.CompletedMultipartUpload$ = exports2.CommonPrefix$ = exports2.Checksum$ = exports2.BucketLoggingStatus$ = exports2.BucketLifecycleConfiguration$ = exports2.BucketInfo$ = exports2.Bucket$ = exports2.BlockedEncryptionTypes$ = exports2.AnalyticsS3BucketDestination$ = exports2.AnalyticsExportDestination$ = exports2.AnalyticsConfiguration$ = exports2.AnalyticsAndOperator$ = exports2.AccessControlTranslation$ = exports2.AccessControlPolicy$ = exports2.AccelerateConfiguration$ = exports2.AbortMultipartUploadRequest$ = exports2.AbortMultipartUploadOutput$ = exports2.AbortIncompleteMultipartUpload$ = exports2.AbacStatus$ = exports2.errorTypeRegistries = exports2.TooManyParts$ = exports2.ObjectNotInActiveTierError$ = exports2.ObjectAlreadyInActiveTierError$ = exports2.NotFound$ = exports2.NoSuchUpload$ = exports2.NoSuchKey$ = exports2.NoSuchBucket$ = exports2.InvalidWriteOffset$ = exports2.InvalidRequest$ = exports2.InvalidObjectState$ = exports2.IdempotencyParameterMismatch$ = exports2.EncryptionTypeMismatch$ = exports2.BucketAlreadyOwnedByYou$ = exports2.BucketAlreadyExists$ = exports2.AccessDenied$ = exports2.S3ServiceException$ = void 0;
    exports2.GetBucketAccelerateConfigurationRequest$ = exports2.GetBucketAccelerateConfigurationOutput$ = exports2.GetBucketAbacRequest$ = exports2.GetBucketAbacOutput$ = exports2.FilterRule$ = exports2.ExistingObjectReplication$ = exports2.EventBridgeConfiguration$ = exports2.ErrorDocument$ = exports2.ErrorDetails$ = exports2._Error$ = exports2.EndEvent$ = exports2.EncryptionConfiguration$ = exports2.Encryption$ = exports2.DestinationResult$ = exports2.Destination$ = exports2.DeletePublicAccessBlockRequest$ = exports2.DeleteObjectTaggingRequest$ = exports2.DeleteObjectTaggingOutput$ = exports2.DeleteObjectsRequest$ = exports2.DeleteObjectsOutput$ = exports2.DeleteObjectRequest$ = exports2.DeleteObjectOutput$ = exports2.DeleteMarkerReplication$ = exports2.DeleteMarkerEntry$ = exports2.DeletedObject$ = exports2.DeleteBucketWebsiteRequest$ = exports2.DeleteBucketTaggingRequest$ = exports2.DeleteBucketRequest$ = exports2.DeleteBucketReplicationRequest$ = exports2.DeleteBucketPolicyRequest$ = exports2.DeleteBucketOwnershipControlsRequest$ = exports2.DeleteBucketMetricsConfigurationRequest$ = exports2.DeleteBucketMetadataTableConfigurationRequest$ = exports2.DeleteBucketMetadataConfigurationRequest$ = exports2.DeleteBucketLifecycleRequest$ = exports2.DeleteBucketInventoryConfigurationRequest$ = exports2.DeleteBucketIntelligentTieringConfigurationRequest$ = exports2.DeleteBucketEncryptionRequest$ = exports2.DeleteBucketCorsRequest$ = exports2.DeleteBucketAnalyticsConfigurationRequest$ = exports2.Delete$ = exports2.DefaultRetention$ = exports2.CSVOutput$ = exports2.CSVInput$ = exports2.CreateSessionRequest$ = exports2.CreateSessionOutput$ = exports2.CreateMultipartUploadRequest$ = exports2.CreateMultipartUploadOutput$ = exports2.CreateBucketRequest$ = exports2.CreateBucketOutput$ = void 0;
    exports2.GetObjectLegalHoldRequest$ = exports2.GetObjectLegalHoldOutput$ = exports2.GetObjectAttributesRequest$ = exports2.GetObjectAttributesParts$ = exports2.GetObjectAttributesOutput$ = exports2.GetObjectAclRequest$ = exports2.GetObjectAclOutput$ = exports2.GetBucketWebsiteRequest$ = exports2.GetBucketWebsiteOutput$ = exports2.GetBucketVersioningRequest$ = exports2.GetBucketVersioningOutput$ = exports2.GetBucketTaggingRequest$ = exports2.GetBucketTaggingOutput$ = exports2.GetBucketRequestPaymentRequest$ = exports2.GetBucketRequestPaymentOutput$ = exports2.GetBucketReplicationRequest$ = exports2.GetBucketReplicationOutput$ = exports2.GetBucketPolicyStatusRequest$ = exports2.GetBucketPolicyStatusOutput$ = exports2.GetBucketPolicyRequest$ = exports2.GetBucketPolicyOutput$ = exports2.GetBucketOwnershipControlsRequest$ = exports2.GetBucketOwnershipControlsOutput$ = exports2.GetBucketNotificationConfigurationRequest$ = exports2.GetBucketMetricsConfigurationRequest$ = exports2.GetBucketMetricsConfigurationOutput$ = exports2.GetBucketMetadataTableConfigurationResult$ = exports2.GetBucketMetadataTableConfigurationRequest$ = exports2.GetBucketMetadataTableConfigurationOutput$ = exports2.GetBucketMetadataConfigurationResult$ = exports2.GetBucketMetadataConfigurationRequest$ = exports2.GetBucketMetadataConfigurationOutput$ = exports2.GetBucketLoggingRequest$ = exports2.GetBucketLoggingOutput$ = exports2.GetBucketLocationRequest$ = exports2.GetBucketLocationOutput$ = exports2.GetBucketLifecycleConfigurationRequest$ = exports2.GetBucketLifecycleConfigurationOutput$ = exports2.GetBucketInventoryConfigurationRequest$ = exports2.GetBucketInventoryConfigurationOutput$ = exports2.GetBucketIntelligentTieringConfigurationRequest$ = exports2.GetBucketIntelligentTieringConfigurationOutput$ = exports2.GetBucketEncryptionRequest$ = exports2.GetBucketEncryptionOutput$ = exports2.GetBucketCorsRequest$ = exports2.GetBucketCorsOutput$ = exports2.GetBucketAnalyticsConfigurationRequest$ = exports2.GetBucketAnalyticsConfigurationOutput$ = exports2.GetBucketAclRequest$ = exports2.GetBucketAclOutput$ = void 0;
    exports2.ListBucketInventoryConfigurationsRequest$ = exports2.ListBucketInventoryConfigurationsOutput$ = exports2.ListBucketIntelligentTieringConfigurationsRequest$ = exports2.ListBucketIntelligentTieringConfigurationsOutput$ = exports2.ListBucketAnalyticsConfigurationsRequest$ = exports2.ListBucketAnalyticsConfigurationsOutput$ = exports2.LifecycleRuleFilter$ = exports2.LifecycleRuleAndOperator$ = exports2.LifecycleRule$ = exports2.LifecycleExpiration$ = exports2.LambdaFunctionConfiguration$ = exports2.JSONOutput$ = exports2.JSONInput$ = exports2.JournalTableConfigurationUpdates$ = exports2.JournalTableConfigurationResult$ = exports2.JournalTableConfiguration$ = exports2.InventoryTableConfigurationUpdates$ = exports2.InventoryTableConfigurationResult$ = exports2.InventoryTableConfiguration$ = exports2.InventorySchedule$ = exports2.InventoryS3BucketDestination$ = exports2.InventoryFilter$ = exports2.InventoryEncryption$ = exports2.InventoryDestination$ = exports2.InventoryConfiguration$ = exports2.IntelligentTieringFilter$ = exports2.IntelligentTieringConfiguration$ = exports2.IntelligentTieringAndOperator$ = exports2.InputSerialization$ = exports2.Initiator$ = exports2.IndexDocument$ = exports2.HeadObjectRequest$ = exports2.HeadObjectOutput$ = exports2.HeadBucketRequest$ = exports2.HeadBucketOutput$ = exports2.Grantee$ = exports2.Grant$ = exports2.GlacierJobParameters$ = exports2.GetPublicAccessBlockRequest$ = exports2.GetPublicAccessBlockOutput$ = exports2.GetObjectTorrentRequest$ = exports2.GetObjectTorrentOutput$ = exports2.GetObjectTaggingRequest$ = exports2.GetObjectTaggingOutput$ = exports2.GetObjectRetentionRequest$ = exports2.GetObjectRetentionOutput$ = exports2.GetObjectRequest$ = exports2.GetObjectOutput$ = exports2.GetObjectLockConfigurationRequest$ = exports2.GetObjectLockConfigurationOutput$ = void 0;
    exports2.Progress$ = exports2.PolicyStatus$ = exports2.PartitionedPrefix$ = exports2.Part$ = exports2.ParquetInput$ = exports2.OwnershipControlsRule$ = exports2.OwnershipControls$ = exports2.Owner$ = exports2.OutputSerialization$ = exports2.OutputLocation$ = exports2.ObjectVersion$ = exports2.ObjectPart$ = exports2.ObjectLockRule$ = exports2.ObjectLockRetention$ = exports2.ObjectLockLegalHold$ = exports2.ObjectLockConfiguration$ = exports2.ObjectIdentifier$ = exports2._Object$ = exports2.NotificationConfigurationFilter$ = exports2.NotificationConfiguration$ = exports2.NoncurrentVersionTransition$ = exports2.NoncurrentVersionExpiration$ = exports2.MultipartUpload$ = exports2.MetricsConfiguration$ = exports2.MetricsAndOperator$ = exports2.Metrics$ = exports2.MetadataTableEncryptionConfiguration$ = exports2.MetadataTableConfigurationResult$ = exports2.MetadataTableConfiguration$ = exports2.MetadataEntry$ = exports2.MetadataConfigurationResult$ = exports2.MetadataConfiguration$ = exports2.LoggingEnabled$ = exports2.LocationInfo$ = exports2.ListPartsRequest$ = exports2.ListPartsOutput$ = exports2.ListObjectVersionsRequest$ = exports2.ListObjectVersionsOutput$ = exports2.ListObjectsV2Request$ = exports2.ListObjectsV2Output$ = exports2.ListObjectsRequest$ = exports2.ListObjectsOutput$ = exports2.ListMultipartUploadsRequest$ = exports2.ListMultipartUploadsOutput$ = exports2.ListDirectoryBucketsRequest$ = exports2.ListDirectoryBucketsOutput$ = exports2.ListBucketsRequest$ = exports2.ListBucketsOutput$ = exports2.ListBucketMetricsConfigurationsRequest$ = exports2.ListBucketMetricsConfigurationsOutput$ = void 0;
    exports2.RequestPaymentConfiguration$ = exports2.ReplicationTimeValue$ = exports2.ReplicationTime$ = exports2.ReplicationRuleFilter$ = exports2.ReplicationRuleAndOperator$ = exports2.ReplicationRule$ = exports2.ReplicationConfiguration$ = exports2.ReplicaModifications$ = exports2.RenameObjectRequest$ = exports2.RenameObjectOutput$ = exports2.RedirectAllRequestsTo$ = exports2.Redirect$ = exports2.RecordsEvent$ = exports2.RecordExpiration$ = exports2.QueueConfiguration$ = exports2.PutPublicAccessBlockRequest$ = exports2.PutObjectTaggingRequest$ = exports2.PutObjectTaggingOutput$ = exports2.PutObjectRetentionRequest$ = exports2.PutObjectRetentionOutput$ = exports2.PutObjectRequest$ = exports2.PutObjectOutput$ = exports2.PutObjectLockConfigurationRequest$ = exports2.PutObjectLockConfigurationOutput$ = exports2.PutObjectLegalHoldRequest$ = exports2.PutObjectLegalHoldOutput$ = exports2.PutObjectAclRequest$ = exports2.PutObjectAclOutput$ = exports2.PutBucketWebsiteRequest$ = exports2.PutBucketVersioningRequest$ = exports2.PutBucketTaggingRequest$ = exports2.PutBucketRequestPaymentRequest$ = exports2.PutBucketReplicationRequest$ = exports2.PutBucketPolicyRequest$ = exports2.PutBucketOwnershipControlsRequest$ = exports2.PutBucketNotificationConfigurationRequest$ = exports2.PutBucketMetricsConfigurationRequest$ = exports2.PutBucketLoggingRequest$ = exports2.PutBucketLifecycleConfigurationRequest$ = exports2.PutBucketLifecycleConfigurationOutput$ = exports2.PutBucketInventoryConfigurationRequest$ = exports2.PutBucketIntelligentTieringConfigurationRequest$ = exports2.PutBucketEncryptionRequest$ = exports2.PutBucketCorsRequest$ = exports2.PutBucketAnalyticsConfigurationRequest$ = exports2.PutBucketAclRequest$ = exports2.PutBucketAccelerateConfigurationRequest$ = exports2.PutBucketAbacRequest$ = exports2.PublicAccessBlockConfiguration$ = exports2.ProgressEvent$ = void 0;
    exports2.SelectObjectContentEventStream$ = exports2.ObjectEncryption$ = exports2.MetricsFilter$ = exports2.AnalyticsFilter$ = exports2.WriteGetObjectResponseRequest$ = exports2.WebsiteConfiguration$ = exports2.VersioningConfiguration$ = exports2.UploadPartRequest$ = exports2.UploadPartOutput$ = exports2.UploadPartCopyRequest$ = exports2.UploadPartCopyOutput$ = exports2.UpdateObjectEncryptionResponse$ = exports2.UpdateObjectEncryptionRequest$ = exports2.UpdateBucketMetadataJournalTableConfigurationRequest$ = exports2.UpdateBucketMetadataInventoryTableConfigurationRequest$ = exports2.Transition$ = exports2.TopicConfiguration$ = exports2.Tiering$ = exports2.TargetObjectKeyFormat$ = exports2.TargetGrant$ = exports2.Tagging$ = exports2.Tag$ = exports2.StorageClassAnalysisDataExport$ = exports2.StorageClassAnalysis$ = exports2.StatsEvent$ = exports2.Stats$ = exports2.SSES3$ = exports2.SSEKMSEncryption$ = exports2.SseKmsEncryptedObjects$ = exports2.SSEKMS$ = exports2.SourceSelectionCriteria$ = exports2.SimplePrefix$ = exports2.SessionCredentials$ = exports2.ServerSideEncryptionRule$ = exports2.ServerSideEncryptionConfiguration$ = exports2.ServerSideEncryptionByDefault$ = exports2.SelectParameters$ = exports2.SelectObjectContentRequest$ = exports2.SelectObjectContentOutput$ = exports2.ScanRange$ = exports2.S3TablesDestinationResult$ = exports2.S3TablesDestination$ = exports2.S3Location$ = exports2.S3KeyFilter$ = exports2.RoutingRule$ = exports2.RestoreStatus$ = exports2.RestoreRequest$ = exports2.RestoreObjectRequest$ = exports2.RestoreObjectOutput$ = exports2.RequestProgress$ = void 0;
    exports2.GetBucketWebsite$ = exports2.GetBucketVersioning$ = exports2.GetBucketTagging$ = exports2.GetBucketRequestPayment$ = exports2.GetBucketReplication$ = exports2.GetBucketPolicyStatus$ = exports2.GetBucketPolicy$ = exports2.GetBucketOwnershipControls$ = exports2.GetBucketNotificationConfiguration$ = exports2.GetBucketMetricsConfiguration$ = exports2.GetBucketMetadataTableConfiguration$ = exports2.GetBucketMetadataConfiguration$ = exports2.GetBucketLogging$ = exports2.GetBucketLocation$ = exports2.GetBucketLifecycleConfiguration$ = exports2.GetBucketInventoryConfiguration$ = exports2.GetBucketIntelligentTieringConfiguration$ = exports2.GetBucketEncryption$ = exports2.GetBucketCors$ = exports2.GetBucketAnalyticsConfiguration$ = exports2.GetBucketAcl$ = exports2.GetBucketAccelerateConfiguration$ = exports2.GetBucketAbac$ = exports2.DeletePublicAccessBlock$ = exports2.DeleteObjectTagging$ = exports2.DeleteObjects$ = exports2.DeleteObject$ = exports2.DeleteBucketWebsite$ = exports2.DeleteBucketTagging$ = exports2.DeleteBucketReplication$ = exports2.DeleteBucketPolicy$ = exports2.DeleteBucketOwnershipControls$ = exports2.DeleteBucketMetricsConfiguration$ = exports2.DeleteBucketMetadataTableConfiguration$ = exports2.DeleteBucketMetadataConfiguration$ = exports2.DeleteBucketLifecycle$ = exports2.DeleteBucketInventoryConfiguration$ = exports2.DeleteBucketIntelligentTieringConfiguration$ = exports2.DeleteBucketEncryption$ = exports2.DeleteBucketCors$ = exports2.DeleteBucketAnalyticsConfiguration$ = exports2.DeleteBucket$ = exports2.CreateSession$ = exports2.CreateMultipartUpload$ = exports2.CreateBucketMetadataTableConfiguration$ = exports2.CreateBucketMetadataConfiguration$ = exports2.CreateBucket$ = exports2.CopyObject$ = exports2.CompleteMultipartUpload$ = exports2.AbortMultipartUpload$ = void 0;
    exports2.RestoreObject$ = exports2.RenameObject$ = exports2.PutPublicAccessBlock$ = exports2.PutObjectTagging$ = exports2.PutObjectRetention$ = exports2.PutObjectLockConfiguration$ = exports2.PutObjectLegalHold$ = exports2.PutObjectAcl$ = exports2.PutObject$ = exports2.PutBucketWebsite$ = exports2.PutBucketVersioning$ = exports2.PutBucketTagging$ = exports2.PutBucketRequestPayment$ = exports2.PutBucketReplication$ = exports2.PutBucketPolicy$ = exports2.PutBucketOwnershipControls$ = exports2.PutBucketNotificationConfiguration$ = exports2.PutBucketMetricsConfiguration$ = exports2.PutBucketLogging$ = exports2.PutBucketLifecycleConfiguration$ = exports2.PutBucketInventoryConfiguration$ = exports2.PutBucketIntelligentTieringConfiguration$ = exports2.PutBucketEncryption$ = exports2.PutBucketCors$ = exports2.PutBucketAnalyticsConfiguration$ = exports2.PutBucketAcl$ = exports2.PutBucketAccelerateConfiguration$ = exports2.PutBucketAbac$ = exports2.ListParts$ = exports2.ListObjectVersions$ = exports2.ListObjectsV2$ = exports2.ListObjects$ = exports2.ListMultipartUploads$ = exports2.ListDirectoryBuckets$ = exports2.ListBuckets$ = exports2.ListBucketMetricsConfigurations$ = exports2.ListBucketInventoryConfigurations$ = exports2.ListBucketIntelligentTieringConfigurations$ = exports2.ListBucketAnalyticsConfigurations$ = exports2.HeadObject$ = exports2.HeadBucket$ = exports2.GetPublicAccessBlock$ = exports2.GetObjectTorrent$ = exports2.GetObjectTagging$ = exports2.GetObjectRetention$ = exports2.GetObjectLockConfiguration$ = exports2.GetObjectLegalHold$ = exports2.GetObjectAttributes$ = exports2.GetObjectAcl$ = exports2.GetObject$ = void 0;
    exports2.WriteGetObjectResponse$ = exports2.UploadPartCopy$ = exports2.UploadPart$ = exports2.UpdateObjectEncryption$ = exports2.UpdateBucketMetadataJournalTableConfiguration$ = exports2.UpdateBucketMetadataInventoryTableConfiguration$ = exports2.SelectObjectContent$ = void 0;
    var _A10 = "Account";
    var _AAO = "AnalyticsAndOperator";
    var _AC = "AccelerateConfiguration";
    var _ACL = "AccessControlList";
    var _ACL_ = "ACL";
    var _ACLn = "AnalyticsConfigurationList";
    var _ACP = "AccessControlPolicy";
    var _ACT = "AccessControlTranslation";
    var _ACn = "AnalyticsConfiguration";
    var _AD = "AccessDenied";
    var _ADb = "AbortDate";
    var _AED = "AnalyticsExportDestination";
    var _AF = "AnalyticsFilter";
    var _AH = "AllowedHeaders";
    var _AHl = "AllowedHeader";
    var _AI2 = "AccountId";
    var _AIMU = "AbortIncompleteMultipartUpload";
    var _AKI11 = "AccessKeyId";
    var _AM = "AllowedMethods";
    var _AMU = "AbortMultipartUpload";
    var _AMUO = "AbortMultipartUploadOutput";
    var _AMUR = "AbortMultipartUploadRequest";
    var _AMl = "AllowedMethod";
    var _AO = "AllowedOrigins";
    var _AOl = "AllowedOrigin";
    var _APA = "AccessPointAlias";
    var _APAc = "AccessPointArn";
    var _AQRD = "AllowQuotedRecordDelimiter";
    var _AR10 = "AcceptRanges";
    var _ARI10 = "AbortRuleId";
    var _AS = "AbacStatus";
    var _ASBD = "AnalyticsS3BucketDestination";
    var _ASSEBD = "ApplyServerSideEncryptionByDefault";
    var _ASr = "ArchiveStatus";
    var _AT13 = "AccessTier";
    var _An = "And";
    var _B = "Bucket";
    var _BA = "BucketArn";
    var _BAE = "BucketAlreadyExists";
    var _BAI = "BucketAccountId";
    var _BAOBY = "BucketAlreadyOwnedByYou";
    var _BET = "BlockedEncryptionTypes";
    var _BGR = "BypassGovernanceRetention";
    var _BI = "BucketInfo";
    var _BKE = "BucketKeyEnabled";
    var _BLC = "BucketLifecycleConfiguration";
    var _BLN = "BucketLocationName";
    var _BLS = "BucketLoggingStatus";
    var _BLT = "BucketLocationType";
    var _BN = "BucketNamespace";
    var _BNu = "BucketName";
    var _BP = "BytesProcessed";
    var _BPA = "BlockPublicAcls";
    var _BPP = "BlockPublicPolicy";
    var _BR = "BucketRegion";
    var _BRy = "BytesReturned";
    var _BS = "BytesScanned";
    var _Bo = "Body";
    var _Bu = "Buckets";
    var _C11 = "Checksum";
    var _CA10 = "ChecksumAlgorithm";
    var _CACL = "CannedACL";
    var _CB = "CreateBucket";
    var _CBC = "CreateBucketConfiguration";
    var _CBMC = "CreateBucketMetadataConfiguration";
    var _CBMCR = "CreateBucketMetadataConfigurationRequest";
    var _CBMTC = "CreateBucketMetadataTableConfiguration";
    var _CBMTCR = "CreateBucketMetadataTableConfigurationRequest";
    var _CBO = "CreateBucketOutput";
    var _CBR = "CreateBucketRequest";
    var _CC = "CacheControl";
    var _CCRC = "ChecksumCRC32";
    var _CCRCC = "ChecksumCRC32C";
    var _CCRCNVME = "ChecksumCRC64NVME";
    var _CC_ = "Cache-Control";
    var _CD = "CreationDate";
    var _CD_ = "Content-Disposition";
    var _CDo = "ContentDisposition";
    var _CE = "ContinuationEvent";
    var _CE_ = "Content-Encoding";
    var _CEo = "ContentEncoding";
    var _CF = "CloudFunction";
    var _CFC = "CloudFunctionConfiguration";
    var _CL = "ContentLanguage";
    var _CL_ = "Content-Language";
    var _CL__ = "Content-Length";
    var _CLo = "ContentLength";
    var _CM = "Content-MD5";
    var _CMD = "ChecksumMD5";
    var _CMDo = "ContentMD5";
    var _CMU = "CompletedMultipartUpload";
    var _CMUO = "CompleteMultipartUploadOutput";
    var _CMUOr = "CreateMultipartUploadOutput";
    var _CMUR = "CompleteMultipartUploadResult";
    var _CMURo = "CompleteMultipartUploadRequest";
    var _CMURr = "CreateMultipartUploadRequest";
    var _CMUo = "CompleteMultipartUpload";
    var _CMUr = "CreateMultipartUpload";
    var _CMh = "ChecksumMode";
    var _CO = "CopyObject";
    var _COO = "CopyObjectOutput";
    var _COR = "CopyObjectResult";
    var _CORSC = "CORSConfiguration";
    var _CORSR = "CORSRules";
    var _CORSRu = "CORSRule";
    var _CORo = "CopyObjectRequest";
    var _CP = "CommonPrefix";
    var _CPL = "CommonPrefixList";
    var _CPLo = "CompletedPartList";
    var _CPR = "CopyPartResult";
    var _CPo = "CompletedPart";
    var _CPom = "CommonPrefixes";
    var _CR = "ContentRange";
    var _CRSBA = "ConfirmRemoveSelfBucketAccess";
    var _CR_ = "Content-Range";
    var _CS4 = "CopySource";
    var _CSHA = "ChecksumSHA1";
    var _CSHAh = "ChecksumSHA256";
    var _CSHAhe = "ChecksumSHA512";
    var _CSIM = "CopySourceIfMatch";
    var _CSIMS = "CopySourceIfModifiedSince";
    var _CSINM = "CopySourceIfNoneMatch";
    var _CSIUS = "CopySourceIfUnmodifiedSince";
    var _CSO = "CreateSessionOutput";
    var _CSR = "CreateSessionResult";
    var _CSRo = "CopySourceRange";
    var _CSRr = "CreateSessionRequest";
    var _CSSSECA = "CopySourceSSECustomerAlgorithm";
    var _CSSSECK = "CopySourceSSECustomerKey";
    var _CSSSECKMD = "CopySourceSSECustomerKeyMD5";
    var _CSV = "CSV";
    var _CSVI = "CopySourceVersionId";
    var _CSVIn = "CSVInput";
    var _CSVO = "CSVOutput";
    var _CSo = "ConfigurationState";
    var _CSr = "CreateSession";
    var _CT4 = "ChecksumType";
    var _CT_ = "Content-Type";
    var _CTl = "ClientToken";
    var _CTo = "ContentType";
    var _CTom = "CompressionType";
    var _CTon = "ContinuationToken";
    var _CXXHASH = "ChecksumXXHASH64";
    var _CXXHASHh = "ChecksumXXHASH3";
    var _CXXHASHhe = "ChecksumXXHASH128";
    var _Co = "Condition";
    var _Cod = "Code";
    var _Com = "Comments";
    var _Con = "Contents";
    var _Cont = "Cont";
    var _Cr = "Credentials";
    var _D = "Days";
    var _DAI = "DaysAfterInitiation";
    var _DB = "DeleteBucket";
    var _DBAC = "DeleteBucketAnalyticsConfiguration";
    var _DBACR = "DeleteBucketAnalyticsConfigurationRequest";
    var _DBC = "DeleteBucketCors";
    var _DBCR = "DeleteBucketCorsRequest";
    var _DBE = "DeleteBucketEncryption";
    var _DBER = "DeleteBucketEncryptionRequest";
    var _DBIC = "DeleteBucketInventoryConfiguration";
    var _DBICR = "DeleteBucketInventoryConfigurationRequest";
    var _DBITC = "DeleteBucketIntelligentTieringConfiguration";
    var _DBITCR = "DeleteBucketIntelligentTieringConfigurationRequest";
    var _DBL = "DeleteBucketLifecycle";
    var _DBLR = "DeleteBucketLifecycleRequest";
    var _DBMC = "DeleteBucketMetadataConfiguration";
    var _DBMCR = "DeleteBucketMetadataConfigurationRequest";
    var _DBMCRe = "DeleteBucketMetricsConfigurationRequest";
    var _DBMCe = "DeleteBucketMetricsConfiguration";
    var _DBMTC = "DeleteBucketMetadataTableConfiguration";
    var _DBMTCR = "DeleteBucketMetadataTableConfigurationRequest";
    var _DBOC = "DeleteBucketOwnershipControls";
    var _DBOCR = "DeleteBucketOwnershipControlsRequest";
    var _DBP = "DeleteBucketPolicy";
    var _DBPR = "DeleteBucketPolicyRequest";
    var _DBR = "DeleteBucketRequest";
    var _DBRR = "DeleteBucketReplicationRequest";
    var _DBRe = "DeleteBucketReplication";
    var _DBT = "DeleteBucketTagging";
    var _DBTR = "DeleteBucketTaggingRequest";
    var _DBW = "DeleteBucketWebsite";
    var _DBWR = "DeleteBucketWebsiteRequest";
    var _DE = "DataExport";
    var _DIM = "DestinationIfMatch";
    var _DIMS = "DestinationIfModifiedSince";
    var _DINM = "DestinationIfNoneMatch";
    var _DIUS = "DestinationIfUnmodifiedSince";
    var _DM = "DeleteMarker";
    var _DME = "DeleteMarkerEntry";
    var _DMR = "DeleteMarkerReplication";
    var _DMVI = "DeleteMarkerVersionId";
    var _DMe = "DeleteMarkers";
    var _DN = "DisplayName";
    var _DO = "DeletedObject";
    var _DOO = "DeleteObjectOutput";
    var _DOOe = "DeleteObjectsOutput";
    var _DOR = "DeleteObjectRequest";
    var _DORe = "DeleteObjectsRequest";
    var _DOT = "DeleteObjectTagging";
    var _DOTO = "DeleteObjectTaggingOutput";
    var _DOTR = "DeleteObjectTaggingRequest";
    var _DOe = "DeletedObjects";
    var _DOel = "DeleteObject";
    var _DOele = "DeleteObjects";
    var _DPAB = "DeletePublicAccessBlock";
    var _DPABR = "DeletePublicAccessBlockRequest";
    var _DR = "DataRedundancy";
    var _DRe = "DefaultRetention";
    var _DRel = "DeleteResult";
    var _DRes = "DestinationResult";
    var _Da = "Date";
    var _De = "Delete";
    var _Del = "Deleted";
    var _Deli = "Delimiter";
    var _Des = "Destination";
    var _Desc = "Description";
    var _Det = "Details";
    var _E11 = "Expiration";
    var _EA = "EmailAddress";
    var _EBC = "EventBridgeConfiguration";
    var _EBO = "ExpectedBucketOwner";
    var _EC = "EncryptionConfiguration";
    var _ECr = "ErrorCode";
    var _ED = "ErrorDetails";
    var _EDr = "ErrorDocument";
    var _EE = "EndEvent";
    var _EH = "ExposeHeaders";
    var _EHx = "ExposeHeader";
    var _EM = "ErrorMessage";
    var _EODM = "ExpiredObjectDeleteMarker";
    var _EOR = "ExistingObjectReplication";
    var _ES = "ExpiresString";
    var _ESBO = "ExpectedSourceBucketOwner";
    var _ET = "EncryptionType";
    var _ETL = "EncryptionTypeList";
    var _ETM = "EncryptionTypeMismatch";
    var _ETa = "ETag";
    var _ETn = "EncodingType";
    var _ETv = "EventThreshold";
    var _ETx = "ExpressionType";
    var _En = "Encryption";
    var _Ena = "Enabled";
    var _End = "End";
    var _Er = "Errors";
    var _Err = "Error";
    var _Ev = "Events";
    var _Eve = "Event";
    var _Ex = "Expires";
    var _Exp = "Expression";
    var _F = "Filter";
    var _FD = "FieldDelimiter";
    var _FHI = "FileHeaderInfo";
    var _FO = "FetchOwner";
    var _FR = "FilterRule";
    var _FRL = "FilterRuleList";
    var _FRi = "FilterRules";
    var _Fi = "Field";
    var _Fo = "Format";
    var _Fr = "Frequency";
    var _G = "Grants";
    var _GBA = "GetBucketAbac";
    var _GBAC = "GetBucketAccelerateConfiguration";
    var _GBACO = "GetBucketAccelerateConfigurationOutput";
    var _GBACOe = "GetBucketAnalyticsConfigurationOutput";
    var _GBACR = "GetBucketAccelerateConfigurationRequest";
    var _GBACRe = "GetBucketAnalyticsConfigurationRequest";
    var _GBACe = "GetBucketAnalyticsConfiguration";
    var _GBAO = "GetBucketAbacOutput";
    var _GBAOe = "GetBucketAclOutput";
    var _GBAR = "GetBucketAbacRequest";
    var _GBARe = "GetBucketAclRequest";
    var _GBAe = "GetBucketAcl";
    var _GBC = "GetBucketCors";
    var _GBCO = "GetBucketCorsOutput";
    var _GBCR = "GetBucketCorsRequest";
    var _GBE = "GetBucketEncryption";
    var _GBEO = "GetBucketEncryptionOutput";
    var _GBER = "GetBucketEncryptionRequest";
    var _GBIC = "GetBucketInventoryConfiguration";
    var _GBICO = "GetBucketInventoryConfigurationOutput";
    var _GBICR = "GetBucketInventoryConfigurationRequest";
    var _GBITC = "GetBucketIntelligentTieringConfiguration";
    var _GBITCO = "GetBucketIntelligentTieringConfigurationOutput";
    var _GBITCR = "GetBucketIntelligentTieringConfigurationRequest";
    var _GBL = "GetBucketLocation";
    var _GBLC = "GetBucketLifecycleConfiguration";
    var _GBLCO = "GetBucketLifecycleConfigurationOutput";
    var _GBLCR = "GetBucketLifecycleConfigurationRequest";
    var _GBLO = "GetBucketLocationOutput";
    var _GBLOe = "GetBucketLoggingOutput";
    var _GBLR = "GetBucketLocationRequest";
    var _GBLRe = "GetBucketLoggingRequest";
    var _GBLe = "GetBucketLogging";
    var _GBMC = "GetBucketMetadataConfiguration";
    var _GBMCO = "GetBucketMetadataConfigurationOutput";
    var _GBMCOe = "GetBucketMetricsConfigurationOutput";
    var _GBMCR = "GetBucketMetadataConfigurationResult";
    var _GBMCRe = "GetBucketMetadataConfigurationRequest";
    var _GBMCRet = "GetBucketMetricsConfigurationRequest";
    var _GBMCe = "GetBucketMetricsConfiguration";
    var _GBMTC = "GetBucketMetadataTableConfiguration";
    var _GBMTCO = "GetBucketMetadataTableConfigurationOutput";
    var _GBMTCR = "GetBucketMetadataTableConfigurationResult";
    var _GBMTCRe = "GetBucketMetadataTableConfigurationRequest";
    var _GBNC = "GetBucketNotificationConfiguration";
    var _GBNCR = "GetBucketNotificationConfigurationRequest";
    var _GBOC = "GetBucketOwnershipControls";
    var _GBOCO = "GetBucketOwnershipControlsOutput";
    var _GBOCR = "GetBucketOwnershipControlsRequest";
    var _GBP = "GetBucketPolicy";
    var _GBPO = "GetBucketPolicyOutput";
    var _GBPR = "GetBucketPolicyRequest";
    var _GBPS = "GetBucketPolicyStatus";
    var _GBPSO = "GetBucketPolicyStatusOutput";
    var _GBPSR = "GetBucketPolicyStatusRequest";
    var _GBR = "GetBucketReplication";
    var _GBRO = "GetBucketReplicationOutput";
    var _GBRP = "GetBucketRequestPayment";
    var _GBRPO = "GetBucketRequestPaymentOutput";
    var _GBRPR = "GetBucketRequestPaymentRequest";
    var _GBRR = "GetBucketReplicationRequest";
    var _GBT = "GetBucketTagging";
    var _GBTO = "GetBucketTaggingOutput";
    var _GBTR = "GetBucketTaggingRequest";
    var _GBV = "GetBucketVersioning";
    var _GBVO = "GetBucketVersioningOutput";
    var _GBVR = "GetBucketVersioningRequest";
    var _GBW = "GetBucketWebsite";
    var _GBWO = "GetBucketWebsiteOutput";
    var _GBWR = "GetBucketWebsiteRequest";
    var _GFC = "GrantFullControl";
    var _GJP = "GlacierJobParameters";
    var _GO = "GetObject";
    var _GOA = "GetObjectAcl";
    var _GOAO = "GetObjectAclOutput";
    var _GOAOe = "GetObjectAttributesOutput";
    var _GOAP = "GetObjectAttributesParts";
    var _GOAR = "GetObjectAclRequest";
    var _GOARe = "GetObjectAttributesResponse";
    var _GOARet = "GetObjectAttributesRequest";
    var _GOAe = "GetObjectAttributes";
    var _GOLC = "GetObjectLockConfiguration";
    var _GOLCO = "GetObjectLockConfigurationOutput";
    var _GOLCR = "GetObjectLockConfigurationRequest";
    var _GOLH = "GetObjectLegalHold";
    var _GOLHO = "GetObjectLegalHoldOutput";
    var _GOLHR = "GetObjectLegalHoldRequest";
    var _GOO = "GetObjectOutput";
    var _GOR = "GetObjectRequest";
    var _GORO = "GetObjectRetentionOutput";
    var _GORR = "GetObjectRetentionRequest";
    var _GORe = "GetObjectRetention";
    var _GOT = "GetObjectTagging";
    var _GOTO = "GetObjectTaggingOutput";
    var _GOTOe = "GetObjectTorrentOutput";
    var _GOTR = "GetObjectTaggingRequest";
    var _GOTRe = "GetObjectTorrentRequest";
    var _GOTe = "GetObjectTorrent";
    var _GPAB = "GetPublicAccessBlock";
    var _GPABO = "GetPublicAccessBlockOutput";
    var _GPABR = "GetPublicAccessBlockRequest";
    var _GR = "GrantRead";
    var _GRACP = "GrantReadACP";
    var _GW = "GrantWrite";
    var _GWACP = "GrantWriteACP";
    var _Gr = "Grant";
    var _Gra = "Grantee";
    var _HB = "HeadBucket";
    var _HBO = "HeadBucketOutput";
    var _HBR = "HeadBucketRequest";
    var _HECRE = "HttpErrorCodeReturnedEquals";
    var _HN = "HostName";
    var _HO = "HeadObject";
    var _HOO = "HeadObjectOutput";
    var _HOR = "HeadObjectRequest";
    var _HRC = "HttpRedirectCode";
    var _I = "Id";
    var _IC = "InventoryConfiguration";
    var _ICL = "InventoryConfigurationList";
    var _ID = "ID";
    var _IDn = "IndexDocument";
    var _IDnv = "InventoryDestination";
    var _IE = "IsEnabled";
    var _IEn = "InventoryEncryption";
    var _IF = "InventoryFilter";
    var _IL = "IsLatest";
    var _IM = "IfMatch";
    var _IMIT = "IfMatchInitiatedTime";
    var _IMLMT = "IfMatchLastModifiedTime";
    var _IMS = "IfMatchSize";
    var _IMS_ = "If-Modified-Since";
    var _IMSf = "IfModifiedSince";
    var _IMUR = "InitiateMultipartUploadResult";
    var _IM_ = "If-Match";
    var _INM = "IfNoneMatch";
    var _INM_ = "If-None-Match";
    var _IOF = "InventoryOptionalFields";
    var _IOS = "InvalidObjectState";
    var _IOV = "IncludedObjectVersions";
    var _IP = "IsPublic";
    var _IPA = "IgnorePublicAcls";
    var _IPM = "IdempotencyParameterMismatch";
    var _IR = "InvalidRequest";
    var _IRIP = "IsRestoreInProgress";
    var _IS = "InputSerialization";
    var _ISBD = "InventoryS3BucketDestination";
    var _ISn = "InventorySchedule";
    var _IT4 = "IsTruncated";
    var _ITAO = "IntelligentTieringAndOperator";
    var _ITC = "IntelligentTieringConfiguration";
    var _ITCL = "IntelligentTieringConfigurationList";
    var _ITCR = "InventoryTableConfigurationResult";
    var _ITCU = "InventoryTableConfigurationUpdates";
    var _ITCn = "InventoryTableConfiguration";
    var _ITF = "IntelligentTieringFilter";
    var _IUS = "IfUnmodifiedSince";
    var _IUS_ = "If-Unmodified-Since";
    var _IWO = "InvalidWriteOffset";
    var _In = "Initiator";
    var _Ini = "Initiated";
    var _JSON = "JSON";
    var _JSONI = "JSONInput";
    var _JSONO = "JSONOutput";
    var _JTC = "JournalTableConfiguration";
    var _JTCR = "JournalTableConfigurationResult";
    var _JTCU = "JournalTableConfigurationUpdates";
    var _K10 = "Key";
    var _KC = "KeyCount";
    var _KI = "KeyId";
    var _KKA = "KmsKeyArn";
    var _KM = "KeyMarker";
    var _KMSC = "KMSContext";
    var _KMSKA = "KMSKeyArn";
    var _KMSKI = "KMSKeyId";
    var _KMSMKID = "KMSMasterKeyID";
    var _KPE = "KeyPrefixEquals";
    var _L2 = "Location";
    var _LAMBR = "ListAllMyBucketsResult";
    var _LAMDBR = "ListAllMyDirectoryBucketsResult";
    var _LB = "ListBuckets";
    var _LBAC = "ListBucketAnalyticsConfigurations";
    var _LBACO = "ListBucketAnalyticsConfigurationsOutput";
    var _LBACR = "ListBucketAnalyticsConfigurationResult";
    var _LBACRi = "ListBucketAnalyticsConfigurationsRequest";
    var _LBIC = "ListBucketInventoryConfigurations";
    var _LBICO = "ListBucketInventoryConfigurationsOutput";
    var _LBICR = "ListBucketInventoryConfigurationsRequest";
    var _LBITC = "ListBucketIntelligentTieringConfigurations";
    var _LBITCO = "ListBucketIntelligentTieringConfigurationsOutput";
    var _LBITCR = "ListBucketIntelligentTieringConfigurationsRequest";
    var _LBMC = "ListBucketMetricsConfigurations";
    var _LBMCO = "ListBucketMetricsConfigurationsOutput";
    var _LBMCR = "ListBucketMetricsConfigurationsRequest";
    var _LBO = "ListBucketsOutput";
    var _LBR = "ListBucketsRequest";
    var _LBRi = "ListBucketResult";
    var _LC = "LocationConstraint";
    var _LCi = "LifecycleConfiguration";
    var _LDB = "ListDirectoryBuckets";
    var _LDBO = "ListDirectoryBucketsOutput";
    var _LDBR = "ListDirectoryBucketsRequest";
    var _LE = "LoggingEnabled";
    var _LEi = "LifecycleExpiration";
    var _LFA = "LambdaFunctionArn";
    var _LFC = "LambdaFunctionConfiguration";
    var _LFCL = "LambdaFunctionConfigurationList";
    var _LFCa = "LambdaFunctionConfigurations";
    var _LH = "LegalHold";
    var _LI = "LocationInfo";
    var _LICR = "ListInventoryConfigurationsResult";
    var _LM2 = "LastModified";
    var _LMCR = "ListMetricsConfigurationsResult";
    var _LMT = "LastModifiedTime";
    var _LMU = "ListMultipartUploads";
    var _LMUO = "ListMultipartUploadsOutput";
    var _LMUR = "ListMultipartUploadsResult";
    var _LMURi = "ListMultipartUploadsRequest";
    var _LM_ = "Last-Modified";
    var _LO = "ListObjects";
    var _LOO = "ListObjectsOutput";
    var _LOR = "ListObjectsRequest";
    var _LOV = "ListObjectsV2";
    var _LOVO = "ListObjectsV2Output";
    var _LOVOi = "ListObjectVersionsOutput";
    var _LOVR = "ListObjectsV2Request";
    var _LOVRi = "ListObjectVersionsRequest";
    var _LOVi = "ListObjectVersions";
    var _LP = "ListParts";
    var _LPO = "ListPartsOutput";
    var _LPR = "ListPartsResult";
    var _LPRi = "ListPartsRequest";
    var _LR = "LifecycleRule";
    var _LRAO = "LifecycleRuleAndOperator";
    var _LRF = "LifecycleRuleFilter";
    var _LRi = "LifecycleRules";
    var _LVR = "ListVersionsResult";
    var _M = "Metadata";
    var _MAO = "MetricsAndOperator";
    var _MAS = "MaxAgeSeconds";
    var _MB = "MaxBuckets";
    var _MC = "MetadataConfiguration";
    var _MCL = "MetricsConfigurationList";
    var _MCR = "MetadataConfigurationResult";
    var _MCe = "MetricsConfiguration";
    var _MD = "MetadataDirective";
    var _MDB = "MaxDirectoryBuckets";
    var _MDf = "MfaDelete";
    var _ME = "MetadataEntry";
    var _MF = "MetricsFilter";
    var _MFA = "MFA";
    var _MFAD = "MFADelete";
    var _MK = "MaxKeys";
    var _MM = "MissingMeta";
    var _MOS = "MpuObjectSize";
    var _MP = "MaxParts";
    var _MTC = "MetadataTableConfiguration";
    var _MTCR = "MetadataTableConfigurationResult";
    var _MTEC = "MetadataTableEncryptionConfiguration";
    var _MU = "MultipartUpload";
    var _MUL = "MultipartUploadList";
    var _MUa = "MaxUploads";
    var _Ma = "Marker";
    var _Me = "Metrics";
    var _Mes = "Message";
    var _Mi = "Minutes";
    var _Mo = "Mode";
    var _N = "Name";
    var _NC = "NotificationConfiguration";
    var _NCF = "NotificationConfigurationFilter";
    var _NCT = "NextContinuationToken";
    var _ND = "NoncurrentDays";
    var _NEKKAS = "NonEmptyKmsKeyArnString";
    var _NF = "NotFound";
    var _NKM = "NextKeyMarker";
    var _NM = "NextMarker";
    var _NNV = "NewerNoncurrentVersions";
    var _NPNM = "NextPartNumberMarker";
    var _NSB = "NoSuchBucket";
    var _NSK = "NoSuchKey";
    var _NSU = "NoSuchUpload";
    var _NUIM = "NextUploadIdMarker";
    var _NVE = "NoncurrentVersionExpiration";
    var _NVIM = "NextVersionIdMarker";
    var _NVT = "NoncurrentVersionTransitions";
    var _NVTL = "NoncurrentVersionTransitionList";
    var _NVTo = "NoncurrentVersionTransition";
    var _O = "Owner";
    var _OA = "ObjectAttributes";
    var _OAIATE = "ObjectAlreadyInActiveTierError";
    var _OC = "OwnershipControls";
    var _OCR = "OwnershipControlsRule";
    var _OCRw = "OwnershipControlsRules";
    var _OE = "ObjectEncryption";
    var _OF = "OptionalFields";
    var _OI = "ObjectIdentifier";
    var _OIL = "ObjectIdentifierList";
    var _OL = "OutputLocation";
    var _OLC = "ObjectLockConfiguration";
    var _OLE = "ObjectLockEnabled";
    var _OLEFB = "ObjectLockEnabledForBucket";
    var _OLLH = "ObjectLockLegalHold";
    var _OLLHS = "ObjectLockLegalHoldStatus";
    var _OLM = "ObjectLockMode";
    var _OLR = "ObjectLockRetention";
    var _OLRUD = "ObjectLockRetainUntilDate";
    var _OLRb = "ObjectLockRule";
    var _OLb = "ObjectList";
    var _ONIATE = "ObjectNotInActiveTierError";
    var _OO = "ObjectOwnership";
    var _OOA = "OptionalObjectAttributes";
    var _OP = "ObjectParts";
    var _OPb = "ObjectPart";
    var _OS = "ObjectSize";
    var _OSGT = "ObjectSizeGreaterThan";
    var _OSLT = "ObjectSizeLessThan";
    var _OSV = "OutputSchemaVersion";
    var _OSu = "OutputSerialization";
    var _OV = "ObjectVersion";
    var _OVL = "ObjectVersionList";
    var _Ob = "Objects";
    var _Obj = "Object";
    var _P10 = "Prefix";
    var _PABC = "PublicAccessBlockConfiguration";
    var _PBA = "PutBucketAbac";
    var _PBAC = "PutBucketAccelerateConfiguration";
    var _PBACR = "PutBucketAccelerateConfigurationRequest";
    var _PBACRu = "PutBucketAnalyticsConfigurationRequest";
    var _PBACu = "PutBucketAnalyticsConfiguration";
    var _PBAR = "PutBucketAbacRequest";
    var _PBARu = "PutBucketAclRequest";
    var _PBAu = "PutBucketAcl";
    var _PBC = "PutBucketCors";
    var _PBCR = "PutBucketCorsRequest";
    var _PBE = "PutBucketEncryption";
    var _PBER = "PutBucketEncryptionRequest";
    var _PBIC = "PutBucketInventoryConfiguration";
    var _PBICR = "PutBucketInventoryConfigurationRequest";
    var _PBITC = "PutBucketIntelligentTieringConfiguration";
    var _PBITCR = "PutBucketIntelligentTieringConfigurationRequest";
    var _PBL = "PutBucketLogging";
    var _PBLC = "PutBucketLifecycleConfiguration";
    var _PBLCO = "PutBucketLifecycleConfigurationOutput";
    var _PBLCR = "PutBucketLifecycleConfigurationRequest";
    var _PBLR = "PutBucketLoggingRequest";
    var _PBMC = "PutBucketMetricsConfiguration";
    var _PBMCR = "PutBucketMetricsConfigurationRequest";
    var _PBNC = "PutBucketNotificationConfiguration";
    var _PBNCR = "PutBucketNotificationConfigurationRequest";
    var _PBOC = "PutBucketOwnershipControls";
    var _PBOCR = "PutBucketOwnershipControlsRequest";
    var _PBP = "PutBucketPolicy";
    var _PBPR = "PutBucketPolicyRequest";
    var _PBR = "PutBucketReplication";
    var _PBRP = "PutBucketRequestPayment";
    var _PBRPR = "PutBucketRequestPaymentRequest";
    var _PBRR = "PutBucketReplicationRequest";
    var _PBT = "PutBucketTagging";
    var _PBTR = "PutBucketTaggingRequest";
    var _PBV = "PutBucketVersioning";
    var _PBVR = "PutBucketVersioningRequest";
    var _PBW = "PutBucketWebsite";
    var _PBWR = "PutBucketWebsiteRequest";
    var _PC10 = "PartsCount";
    var _PDS = "PartitionDateSource";
    var _PE = "ProgressEvent";
    var _PI10 = "ParquetInput";
    var _PL = "PartsList";
    var _PN = "PartNumber";
    var _PNM = "PartNumberMarker";
    var _PO = "PutObject";
    var _POA = "PutObjectAcl";
    var _POAO = "PutObjectAclOutput";
    var _POAR = "PutObjectAclRequest";
    var _POLC = "PutObjectLockConfiguration";
    var _POLCO = "PutObjectLockConfigurationOutput";
    var _POLCR = "PutObjectLockConfigurationRequest";
    var _POLH = "PutObjectLegalHold";
    var _POLHO = "PutObjectLegalHoldOutput";
    var _POLHR = "PutObjectLegalHoldRequest";
    var _POO = "PutObjectOutput";
    var _POR = "PutObjectRequest";
    var _PORO = "PutObjectRetentionOutput";
    var _PORR = "PutObjectRetentionRequest";
    var _PORu = "PutObjectRetention";
    var _POT = "PutObjectTagging";
    var _POTO = "PutObjectTaggingOutput";
    var _POTR = "PutObjectTaggingRequest";
    var _PP = "PartitionedPrefix";
    var _PPAB = "PutPublicAccessBlock";
    var _PPABR = "PutPublicAccessBlockRequest";
    var _PS = "PolicyStatus";
    var _Pa = "Parts";
    var _Par = "Part";
    var _Parq = "Parquet";
    var _Pay = "Payer";
    var _Payl = "Payload";
    var _Pe = "Permission";
    var _Po = "Policy";
    var _Pr10 = "Progress";
    var _Pri = "Priority";
    var _Pro = "Protocol";
    var _Q = "Quiet";
    var _QA = "QueueArn";
    var _QC = "QuoteCharacter";
    var _QCL = "QueueConfigurationList";
    var _QCu = "QueueConfigurations";
    var _QCue = "QueueConfiguration";
    var _QEC = "QuoteEscapeCharacter";
    var _QF = "QuoteFields";
    var _Qu = "Queue";
    var _R = "Rules";
    var _RART = "RedirectAllRequestsTo";
    var _RC10 = "RequestCharged";
    var _RCC = "ResponseCacheControl";
    var _RCD = "ResponseContentDisposition";
    var _RCE2 = "ResponseContentEncoding";
    var _RCL = "ResponseContentLanguage";
    var _RCT = "ResponseContentType";
    var _RCe = "ReplicationConfiguration";
    var _RD = "RecordDelimiter";
    var _RE = "ResponseExpires";
    var _RED = "RestoreExpiryDate";
    var _REe = "RecordExpiration";
    var _REec = "RecordsEvent";
    var _RKKID = "ReplicaKmsKeyID";
    var _RKPW = "ReplaceKeyPrefixWith";
    var _RKW = "ReplaceKeyWith";
    var _RM = "ReplicaModifications";
    var _RO = "RenameObject";
    var _ROO = "RenameObjectOutput";
    var _ROOe = "RestoreObjectOutput";
    var _ROP = "RestoreOutputPath";
    var _ROR = "RenameObjectRequest";
    var _RORe = "RestoreObjectRequest";
    var _ROe = "RestoreObject";
    var _RP = "RequestPayer";
    var _RPB = "RestrictPublicBuckets";
    var _RPC = "RequestPaymentConfiguration";
    var _RPe = "RequestProgress";
    var _RR = "RoutingRules";
    var _RRAO = "ReplicationRuleAndOperator";
    var _RRF = "ReplicationRuleFilter";
    var _RRe = "ReplicationRule";
    var _RRep = "ReplicationRules";
    var _RReq = "RequestRoute";
    var _RRes = "RestoreRequest";
    var _RRo = "RoutingRule";
    var _RS = "ReplicationStatus";
    var _RSe = "RestoreStatus";
    var _RSen = "RenameSource";
    var _RT13 = "ReplicationTime";
    var _RTV = "ReplicationTimeValue";
    var _RTe = "RequestToken";
    var _RUD = "RetainUntilDate";
    var _Ra = "Range";
    var _Re = "Restore";
    var _Rec = "Records";
    var _Red = "Redirect";
    var _Ret = "Retention";
    var _Ro = "Role";
    var _Ru = "Rule";
    var _S = "Status";
    var _SA = "StartAfter";
    var _SAK10 = "SecretAccessKey";
    var _SAs = "SseAlgorithm";
    var _SB = "StreamingBlob";
    var _SBD = "S3BucketDestination";
    var _SC = "StorageClass";
    var _SCA = "StorageClassAnalysis";
    var _SCADE = "StorageClassAnalysisDataExport";
    var _SCV = "SessionCredentialValue";
    var _SCe = "SessionCredentials";
    var _SCt = "StatusCode";
    var _SDV = "SkipDestinationValidation";
    var _SE = "StatsEvent";
    var _SIM = "SourceIfMatch";
    var _SIMS = "SourceIfModifiedSince";
    var _SINM = "SourceIfNoneMatch";
    var _SIUS = "SourceIfUnmodifiedSince";
    var _SK2 = "SSE-KMS";
    var _SKEO = "SseKmsEncryptedObjects";
    var _SKF = "S3KeyFilter";
    var _SKe = "S3Key";
    var _SL = "S3Location";
    var _SM = "SessionMode";
    var _SOC = "SelectObjectContent";
    var _SOCES = "SelectObjectContentEventStream";
    var _SOCO = "SelectObjectContentOutput";
    var _SOCR = "SelectObjectContentRequest";
    var _SP = "SelectParameters";
    var _SPi = "SimplePrefix";
    var _SR = "ScanRange";
    var _SS = "SSE-S3";
    var _SSC = "SourceSelectionCriteria";
    var _SSE = "ServerSideEncryption";
    var _SSEA = "SSEAlgorithm";
    var _SSEBD = "ServerSideEncryptionByDefault";
    var _SSEC = "ServerSideEncryptionConfiguration";
    var _SSECA = "SSECustomerAlgorithm";
    var _SSECK = "SSECustomerKey";
    var _SSECKMD = "SSECustomerKeyMD5";
    var _SSEKMS = "SSEKMS";
    var _SSEKMSE = "SSEKMSEncryption";
    var _SSEKMSEC = "SSEKMSEncryptionContext";
    var _SSEKMSKI = "SSEKMSKeyId";
    var _SSER = "ServerSideEncryptionRule";
    var _SSERe = "ServerSideEncryptionRules";
    var _SSES = "SSES3";
    var _ST11 = "SessionToken";
    var _STD = "S3TablesDestination";
    var _STDR = "S3TablesDestinationResult";
    var _S_ = "S3";
    var _Sc = "Schedule";
    var _Si = "Size";
    var _St = "Start";
    var _Sta = "Stats";
    var _Su = "Suffix";
    var _T10 = "Tags";
    var _TA = "TableArn";
    var _TAo = "TopicArn";
    var _TB = "TargetBucket";
    var _TBA = "TableBucketArn";
    var _TBT = "TableBucketType";
    var _TC10 = "TagCount";
    var _TCL = "TopicConfigurationList";
    var _TCo = "TopicConfigurations";
    var _TCop = "TopicConfiguration";
    var _TD = "TaggingDirective";
    var _TDMOS = "TransitionDefaultMinimumObjectSize";
    var _TG = "TargetGrants";
    var _TGa = "TargetGrant";
    var _TL = "TieringList";
    var _TLr = "TransitionList";
    var _TMP = "TooManyParts";
    var _TN = "TableNamespace";
    var _TNa = "TableName";
    var _TOKF = "TargetObjectKeyFormat";
    var _TP = "TargetPrefix";
    var _TPC = "TotalPartsCount";
    var _TS = "TagSet";
    var _TSa = "TableStatus";
    var _Ta10 = "Tag";
    var _Tag = "Tagging";
    var _Ti = "Tier";
    var _Tie = "Tierings";
    var _Tier = "Tiering";
    var _Tim = "Time";
    var _To = "Token";
    var _Top = "Topic";
    var _Tr = "Transitions";
    var _Tra = "Transition";
    var _Ty = "Type";
    var _U = "Uploads";
    var _UBMITC = "UpdateBucketMetadataInventoryTableConfiguration";
    var _UBMITCR = "UpdateBucketMetadataInventoryTableConfigurationRequest";
    var _UBMJTC = "UpdateBucketMetadataJournalTableConfiguration";
    var _UBMJTCR = "UpdateBucketMetadataJournalTableConfigurationRequest";
    var _UI = "UploadId";
    var _UIM = "UploadIdMarker";
    var _UM = "UserMetadata";
    var _UOE = "UpdateObjectEncryption";
    var _UOER = "UpdateObjectEncryptionRequest";
    var _UOERp = "UpdateObjectEncryptionResponse";
    var _UP = "UploadPart";
    var _UPC = "UploadPartCopy";
    var _UPCO = "UploadPartCopyOutput";
    var _UPCR = "UploadPartCopyRequest";
    var _UPO = "UploadPartOutput";
    var _UPR = "UploadPartRequest";
    var _URI = "URI";
    var _Up = "Upload";
    var _V10 = "Value";
    var _VC = "VersioningConfiguration";
    var _VI = "VersionId";
    var _VIM = "VersionIdMarker";
    var _Ve = "Versions";
    var _Ver = "Version";
    var _WC = "WebsiteConfiguration";
    var _WGOR = "WriteGetObjectResponse";
    var _WGORR = "WriteGetObjectResponseRequest";
    var _WOB = "WriteOffsetBytes";
    var _WRL = "WebsiteRedirectLocation";
    var _Y = "Years";
    var _ar = "accept-ranges";
    var _br = "bucket-region";
    var _c32 = "client";
    var _ct = "continuation-token";
    var _d = "delimiter";
    var _e32 = "error";
    var _eP = "eventPayload";
    var _en = "endpoint";
    var _et = "encoding-type";
    var _fo = "fetch-owner";
    var _h22 = "http";
    var _hC = "httpChecksum";
    var _hE32 = "httpError";
    var _hH10 = "httpHeader";
    var _hL = "hostLabel";
    var _hP = "httpPayload";
    var _hPH = "httpPrefixHeaders";
    var _hQ10 = "httpQuery";
    var _hi = "http://www.w3.org/2001/XMLSchema-instance";
    var _i = "id";
    var _iT13 = "idempotencyToken";
    var _km = "key-marker";
    var _m29 = "marker";
    var _mb = "max-buckets";
    var _mdb = "max-directory-buckets";
    var _mk = "max-keys";
    var _mp = "max-parts";
    var _mu = "max-uploads";
    var _p = "prefix";
    var _pN = "partNumber";
    var _pnm = "part-number-marker";
    var _rcc = "response-cache-control";
    var _rcd = "response-content-disposition";
    var _rce = "response-content-encoding";
    var _rcl = "response-content-language";
    var _rct = "response-content-type";
    var _re = "response-expires";
    var _s32 = "smithy.ts.sdk.synthetic.com.amazonaws.s3";
    var _sa = "start-after";
    var _st = "streaming";
    var _uI = "uploadId";
    var _uim = "upload-id-marker";
    var _vI = "versionId";
    var _vim = "version-id-marker";
    var _x = "xsi";
    var _xA = "xmlAttribute";
    var _xF = "xmlFlattened";
    var _xN = "xmlName";
    var _xNm = "xmlNamespace";
    var _xaa = "x-amz-acl";
    var _xaad = "x-amz-abort-date";
    var _xaapa = "x-amz-access-point-alias";
    var _xaari = "x-amz-abort-rule-id";
    var _xaas = "x-amz-archive-status";
    var _xaba = "x-amz-bucket-arn";
    var _xabgr = "x-amz-bypass-governance-retention";
    var _xabln = "x-amz-bucket-location-name";
    var _xablt = "x-amz-bucket-location-type";
    var _xabn = "x-amz-bucket-namespace";
    var _xabole = "x-amz-bucket-object-lock-enabled";
    var _xabolt = "x-amz-bucket-object-lock-token";
    var _xabr = "x-amz-bucket-region";
    var _xaca = "x-amz-checksum-algorithm";
    var _xacc = "x-amz-checksum-crc32";
    var _xacc_ = "x-amz-checksum-crc32c";
    var _xacc__ = "x-amz-checksum-crc64nvme";
    var _xacm = "x-amz-checksum-md5";
    var _xacm_ = "x-amz-checksum-mode";
    var _xacrsba = "x-amz-confirm-remove-self-bucket-access";
    var _xacs = "x-amz-checksum-sha1";
    var _xacs_ = "x-amz-checksum-sha256";
    var _xacs__ = "x-amz-checksum-sha512";
    var _xacs___ = "x-amz-copy-source";
    var _xacsim = "x-amz-copy-source-if-match";
    var _xacsims = "x-amz-copy-source-if-modified-since";
    var _xacsinm = "x-amz-copy-source-if-none-match";
    var _xacsius = "x-amz-copy-source-if-unmodified-since";
    var _xacsm = "x-amz-create-session-mode";
    var _xacsr = "x-amz-copy-source-range";
    var _xacssseca = "x-amz-copy-source-server-side-encryption-customer-algorithm";
    var _xacssseck = "x-amz-copy-source-server-side-encryption-customer-key";
    var _xacssseckM = "x-amz-copy-source-server-side-encryption-customer-key-MD5";
    var _xacsvi = "x-amz-copy-source-version-id";
    var _xact = "x-amz-checksum-type";
    var _xact_ = "x-amz-client-token";
    var _xacx = "x-amz-checksum-xxhash64";
    var _xacx_ = "x-amz-checksum-xxhash3";
    var _xacx__ = "x-amz-checksum-xxhash128";
    var _xadm = "x-amz-delete-marker";
    var _xae = "x-amz-expiration";
    var _xaebo = "x-amz-expected-bucket-owner";
    var _xafec = "x-amz-fwd-error-code";
    var _xafem = "x-amz-fwd-error-message";
    var _xafhCC = "x-amz-fwd-header-Cache-Control";
    var _xafhCD = "x-amz-fwd-header-Content-Disposition";
    var _xafhCE = "x-amz-fwd-header-Content-Encoding";
    var _xafhCL = "x-amz-fwd-header-Content-Language";
    var _xafhCR = "x-amz-fwd-header-Content-Range";
    var _xafhCT = "x-amz-fwd-header-Content-Type";
    var _xafhE = "x-amz-fwd-header-ETag";
    var _xafhE_ = "x-amz-fwd-header-Expires";
    var _xafhLM = "x-amz-fwd-header-Last-Modified";
    var _xafhar = "x-amz-fwd-header-accept-ranges";
    var _xafhxacc = "x-amz-fwd-header-x-amz-checksum-crc32";
    var _xafhxacc_ = "x-amz-fwd-header-x-amz-checksum-crc32c";
    var _xafhxacc__ = "x-amz-fwd-header-x-amz-checksum-crc64nvme";
    var _xafhxacm = "x-amz-fwd-header-x-amz-checksum-md5";
    var _xafhxacs = "x-amz-fwd-header-x-amz-checksum-sha1";
    var _xafhxacs_ = "x-amz-fwd-header-x-amz-checksum-sha256";
    var _xafhxacs__ = "x-amz-fwd-header-x-amz-checksum-sha512";
    var _xafhxacx = "x-amz-fwd-header-x-amz-checksum-xxhash64";
    var _xafhxacx_ = "x-amz-fwd-header-x-amz-checksum-xxhash3";
    var _xafhxacx__ = "x-amz-fwd-header-x-amz-checksum-xxhash128";
    var _xafhxadm = "x-amz-fwd-header-x-amz-delete-marker";
    var _xafhxae = "x-amz-fwd-header-x-amz-expiration";
    var _xafhxamm = "x-amz-fwd-header-x-amz-missing-meta";
    var _xafhxampc = "x-amz-fwd-header-x-amz-mp-parts-count";
    var _xafhxaollh = "x-amz-fwd-header-x-amz-object-lock-legal-hold";
    var _xafhxaolm = "x-amz-fwd-header-x-amz-object-lock-mode";
    var _xafhxaolrud = "x-amz-fwd-header-x-amz-object-lock-retain-until-date";
    var _xafhxar = "x-amz-fwd-header-x-amz-restore";
    var _xafhxarc = "x-amz-fwd-header-x-amz-request-charged";
    var _xafhxars = "x-amz-fwd-header-x-amz-replication-status";
    var _xafhxasc = "x-amz-fwd-header-x-amz-storage-class";
    var _xafhxasse = "x-amz-fwd-header-x-amz-server-side-encryption";
    var _xafhxasseakki = "x-amz-fwd-header-x-amz-server-side-encryption-aws-kms-key-id";
    var _xafhxassebke = "x-amz-fwd-header-x-amz-server-side-encryption-bucket-key-enabled";
    var _xafhxasseca = "x-amz-fwd-header-x-amz-server-side-encryption-customer-algorithm";
    var _xafhxasseckM = "x-amz-fwd-header-x-amz-server-side-encryption-customer-key-MD5";
    var _xafhxatc = "x-amz-fwd-header-x-amz-tagging-count";
    var _xafhxavi = "x-amz-fwd-header-x-amz-version-id";
    var _xafs = "x-amz-fwd-status";
    var _xagfc = "x-amz-grant-full-control";
    var _xagr = "x-amz-grant-read";
    var _xagra = "x-amz-grant-read-acp";
    var _xagw = "x-amz-grant-write";
    var _xagwa = "x-amz-grant-write-acp";
    var _xaimit = "x-amz-if-match-initiated-time";
    var _xaimlmt = "x-amz-if-match-last-modified-time";
    var _xaims = "x-amz-if-match-size";
    var _xam = "x-amz-meta-";
    var _xam_ = "x-amz-mfa";
    var _xamd = "x-amz-metadata-directive";
    var _xamm = "x-amz-missing-meta";
    var _xamos = "x-amz-mp-object-size";
    var _xamp = "x-amz-max-parts";
    var _xampc = "x-amz-mp-parts-count";
    var _xaoa = "x-amz-object-attributes";
    var _xaollh = "x-amz-object-lock-legal-hold";
    var _xaolm = "x-amz-object-lock-mode";
    var _xaolrud = "x-amz-object-lock-retain-until-date";
    var _xaoo = "x-amz-object-ownership";
    var _xaooa = "x-amz-optional-object-attributes";
    var _xaos = "x-amz-object-size";
    var _xapnm = "x-amz-part-number-marker";
    var _xar = "x-amz-restore";
    var _xarc = "x-amz-request-charged";
    var _xarop = "x-amz-restore-output-path";
    var _xarp = "x-amz-request-payer";
    var _xarr = "x-amz-request-route";
    var _xars = "x-amz-replication-status";
    var _xars_ = "x-amz-rename-source";
    var _xarsim = "x-amz-rename-source-if-match";
    var _xarsims = "x-amz-rename-source-if-modified-since";
    var _xarsinm = "x-amz-rename-source-if-none-match";
    var _xarsius = "x-amz-rename-source-if-unmodified-since";
    var _xart = "x-amz-request-token";
    var _xasc = "x-amz-storage-class";
    var _xasca = "x-amz-sdk-checksum-algorithm";
    var _xasdv = "x-amz-skip-destination-validation";
    var _xasebo = "x-amz-source-expected-bucket-owner";
    var _xasse = "x-amz-server-side-encryption";
    var _xasseakki = "x-amz-server-side-encryption-aws-kms-key-id";
    var _xassebke = "x-amz-server-side-encryption-bucket-key-enabled";
    var _xassec = "x-amz-server-side-encryption-context";
    var _xasseca = "x-amz-server-side-encryption-customer-algorithm";
    var _xasseck = "x-amz-server-side-encryption-customer-key";
    var _xasseckM = "x-amz-server-side-encryption-customer-key-MD5";
    var _xat = "x-amz-tagging";
    var _xatc = "x-amz-tagging-count";
    var _xatd = "x-amz-tagging-directive";
    var _xatdmos = "x-amz-transition-default-minimum-object-size";
    var _xavi = "x-amz-version-id";
    var _xawob = "x-amz-write-offset-bytes";
    var _xawrl = "x-amz-website-redirect-location";
    var _xs = "xsi:type";
    var n032 = "com.amazonaws.s3";
    var schema_1 = (init_schema4(), __toCommonJS(schema_exports));
    var errors_1 = require_errors2();
    var S3ServiceException_1 = require_S3ServiceException();
    var _s_registry32 = schema_1.TypeRegistry.for(_s32);
    exports2.S3ServiceException$ = [-3, _s32, "S3ServiceException", 0, [], []];
    _s_registry32.registerError(exports2.S3ServiceException$, S3ServiceException_1.S3ServiceException);
    var n0_registry32 = schema_1.TypeRegistry.for(n032);
    exports2.AccessDenied$ = [
      -3,
      n032,
      _AD,
      { [_e32]: _c32, [_hE32]: 403 },
      [],
      []
    ];
    n0_registry32.registerError(exports2.AccessDenied$, errors_1.AccessDenied);
    exports2.BucketAlreadyExists$ = [
      -3,
      n032,
      _BAE,
      { [_e32]: _c32, [_hE32]: 409 },
      [],
      []
    ];
    n0_registry32.registerError(exports2.BucketAlreadyExists$, errors_1.BucketAlreadyExists);
    exports2.BucketAlreadyOwnedByYou$ = [
      -3,
      n032,
      _BAOBY,
      { [_e32]: _c32, [_hE32]: 409 },
      [],
      []
    ];
    n0_registry32.registerError(exports2.BucketAlreadyOwnedByYou$, errors_1.BucketAlreadyOwnedByYou);
    exports2.EncryptionTypeMismatch$ = [
      -3,
      n032,
      _ETM,
      { [_e32]: _c32, [_hE32]: 400 },
      [],
      []
    ];
    n0_registry32.registerError(exports2.EncryptionTypeMismatch$, errors_1.EncryptionTypeMismatch);
    exports2.IdempotencyParameterMismatch$ = [
      -3,
      n032,
      _IPM,
      { [_e32]: _c32, [_hE32]: 400 },
      [],
      []
    ];
    n0_registry32.registerError(exports2.IdempotencyParameterMismatch$, errors_1.IdempotencyParameterMismatch);
    exports2.InvalidObjectState$ = [
      -3,
      n032,
      _IOS,
      { [_e32]: _c32, [_hE32]: 403 },
      [_SC, _AT13],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.InvalidObjectState$, errors_1.InvalidObjectState);
    exports2.InvalidRequest$ = [
      -3,
      n032,
      _IR,
      { [_e32]: _c32, [_hE32]: 400 },
      [],
      []
    ];
    n0_registry32.registerError(exports2.InvalidRequest$, errors_1.InvalidRequest);
    exports2.InvalidWriteOffset$ = [
      -3,
      n032,
      _IWO,
      { [_e32]: _c32, [_hE32]: 400 },
      [],
      []
    ];
    n0_registry32.registerError(exports2.InvalidWriteOffset$, errors_1.InvalidWriteOffset);
    exports2.NoSuchBucket$ = [
      -3,
      n032,
      _NSB,
      { [_e32]: _c32, [_hE32]: 404 },
      [],
      []
    ];
    n0_registry32.registerError(exports2.NoSuchBucket$, errors_1.NoSuchBucket);
    exports2.NoSuchKey$ = [
      -3,
      n032,
      _NSK,
      { [_e32]: _c32, [_hE32]: 404 },
      [],
      []
    ];
    n0_registry32.registerError(exports2.NoSuchKey$, errors_1.NoSuchKey);
    exports2.NoSuchUpload$ = [
      -3,
      n032,
      _NSU,
      { [_e32]: _c32, [_hE32]: 404 },
      [],
      []
    ];
    n0_registry32.registerError(exports2.NoSuchUpload$, errors_1.NoSuchUpload);
    exports2.NotFound$ = [
      -3,
      n032,
      _NF,
      { [_e32]: _c32 },
      [],
      []
    ];
    n0_registry32.registerError(exports2.NotFound$, errors_1.NotFound);
    exports2.ObjectAlreadyInActiveTierError$ = [
      -3,
      n032,
      _OAIATE,
      { [_e32]: _c32, [_hE32]: 403 },
      [],
      []
    ];
    n0_registry32.registerError(exports2.ObjectAlreadyInActiveTierError$, errors_1.ObjectAlreadyInActiveTierError);
    exports2.ObjectNotInActiveTierError$ = [
      -3,
      n032,
      _ONIATE,
      { [_e32]: _c32, [_hE32]: 403 },
      [],
      []
    ];
    n0_registry32.registerError(exports2.ObjectNotInActiveTierError$, errors_1.ObjectNotInActiveTierError);
    exports2.TooManyParts$ = [
      -3,
      n032,
      _TMP,
      { [_e32]: _c32, [_hE32]: 400 },
      [],
      []
    ];
    n0_registry32.registerError(exports2.TooManyParts$, errors_1.TooManyParts);
    exports2.errorTypeRegistries = [
      _s_registry32,
      n0_registry32
    ];
    var CopySourceSSECustomerKey = [0, n032, _CSSSECK, 8, 0];
    var NonEmptyKmsKeyArnString = [0, n032, _NEKKAS, 8, 0];
    var SessionCredentialValue = [0, n032, _SCV, 8, 0];
    var SSECustomerKey = [0, n032, _SSECK, 8, 0];
    var SSEKMSEncryptionContext = [0, n032, _SSEKMSEC, 8, 0];
    var SSEKMSKeyId = [0, n032, _SSEKMSKI, 8, 0];
    var StreamingBlob = [0, n032, _SB, { [_st]: 1 }, 42];
    exports2.AbacStatus$ = [
      3,
      n032,
      _AS,
      0,
      [_S],
      [0]
    ];
    exports2.AbortIncompleteMultipartUpload$ = [
      3,
      n032,
      _AIMU,
      0,
      [_DAI],
      [1]
    ];
    exports2.AbortMultipartUploadOutput$ = [
      3,
      n032,
      _AMUO,
      0,
      [_RC10],
      [[0, { [_hH10]: _xarc }]]
    ];
    exports2.AbortMultipartUploadRequest$ = [
      3,
      n032,
      _AMUR,
      0,
      [_B, _K10, _UI, _RP, _EBO, _IMIT],
      [[0, 1], [0, 1], [0, { [_hQ10]: _uI }], [0, { [_hH10]: _xarp }], [0, { [_hH10]: _xaebo }], [6, { [_hH10]: _xaimit }]],
      3
    ];
    exports2.AccelerateConfiguration$ = [
      3,
      n032,
      _AC,
      0,
      [_S],
      [0]
    ];
    exports2.AccessControlPolicy$ = [
      3,
      n032,
      _ACP,
      0,
      [_G, _O],
      [[() => Grants, { [_xN]: _ACL }], () => exports2.Owner$]
    ];
    exports2.AccessControlTranslation$ = [
      3,
      n032,
      _ACT,
      0,
      [_O],
      [0],
      1
    ];
    exports2.AnalyticsAndOperator$ = [
      3,
      n032,
      _AAO,
      0,
      [_P10, _T10],
      [0, [() => TagSet, { [_xF]: 1, [_xN]: _Ta10 }]]
    ];
    exports2.AnalyticsConfiguration$ = [
      3,
      n032,
      _ACn,
      0,
      [_I, _SCA, _F],
      [0, () => exports2.StorageClassAnalysis$, [() => exports2.AnalyticsFilter$, 0]],
      2
    ];
    exports2.AnalyticsExportDestination$ = [
      3,
      n032,
      _AED,
      0,
      [_SBD],
      [() => exports2.AnalyticsS3BucketDestination$],
      1
    ];
    exports2.AnalyticsS3BucketDestination$ = [
      3,
      n032,
      _ASBD,
      0,
      [_Fo, _B, _BAI, _P10],
      [0, 0, 0, 0],
      2
    ];
    exports2.BlockedEncryptionTypes$ = [
      3,
      n032,
      _BET,
      0,
      [_ET],
      [[() => EncryptionTypeList, { [_xF]: 1 }]]
    ];
    exports2.Bucket$ = [
      3,
      n032,
      _B,
      0,
      [_N, _CD, _BR, _BA],
      [0, 4, 0, 0]
    ];
    exports2.BucketInfo$ = [
      3,
      n032,
      _BI,
      0,
      [_DR, _Ty],
      [0, 0]
    ];
    exports2.BucketLifecycleConfiguration$ = [
      3,
      n032,
      _BLC,
      0,
      [_R],
      [[() => LifecycleRules, { [_xF]: 1, [_xN]: _Ru }]],
      1
    ];
    exports2.BucketLoggingStatus$ = [
      3,
      n032,
      _BLS,
      0,
      [_LE],
      [[() => exports2.LoggingEnabled$, 0]]
    ];
    exports2.Checksum$ = [
      3,
      n032,
      _C11,
      0,
      [_CCRC, _CCRCC, _CCRCNVME, _CSHA, _CSHAh, _CSHAhe, _CMD, _CXXHASH, _CXXHASHh, _CXXHASHhe, _CT4],
      [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]
    ];
    exports2.CommonPrefix$ = [
      3,
      n032,
      _CP,
      0,
      [_P10],
      [0]
    ];
    exports2.CompletedMultipartUpload$ = [
      3,
      n032,
      _CMU,
      0,
      [_Pa],
      [[() => CompletedPartList, { [_xF]: 1, [_xN]: _Par }]]
    ];
    exports2.CompletedPart$ = [
      3,
      n032,
      _CPo,
      0,
      [_ETa, _CCRC, _CCRCC, _CCRCNVME, _CSHA, _CSHAh, _CSHAhe, _CMD, _CXXHASH, _CXXHASHh, _CXXHASHhe, _PN],
      [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1]
    ];
    exports2.CompleteMultipartUploadOutput$ = [
      3,
      n032,
      _CMUO,
      { [_xN]: _CMUR },
      [_L2, _B, _K10, _E11, _ETa, _CCRC, _CCRCC, _CCRCNVME, _CSHA, _CSHAh, _CSHAhe, _CMD, _CXXHASH, _CXXHASHh, _CXXHASHhe, _CT4, _SSE, _VI, _SSEKMSKI, _BKE, _RC10],
      [0, 0, 0, [0, { [_hH10]: _xae }], 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, [0, { [_hH10]: _xasse }], [0, { [_hH10]: _xavi }], [() => SSEKMSKeyId, { [_hH10]: _xasseakki }], [2, { [_hH10]: _xassebke }], [0, { [_hH10]: _xarc }]]
    ];
    exports2.CompleteMultipartUploadRequest$ = [
      3,
      n032,
      _CMURo,
      0,
      [_B, _K10, _UI, _MU, _CCRC, _CCRCC, _CCRCNVME, _CSHA, _CSHAh, _CSHAhe, _CMD, _CXXHASH, _CXXHASHh, _CXXHASHhe, _CT4, _MOS, _RP, _EBO, _IM, _INM, _SSECA, _SSECK, _SSECKMD],
      [[0, 1], [0, 1], [0, { [_hQ10]: _uI }], [() => exports2.CompletedMultipartUpload$, { [_hP]: 1, [_xN]: _CMUo }], [0, { [_hH10]: _xacc }], [0, { [_hH10]: _xacc_ }], [0, { [_hH10]: _xacc__ }], [0, { [_hH10]: _xacs }], [0, { [_hH10]: _xacs_ }], [0, { [_hH10]: _xacs__ }], [0, { [_hH10]: _xacm }], [0, { [_hH10]: _xacx }], [0, { [_hH10]: _xacx_ }], [0, { [_hH10]: _xacx__ }], [0, { [_hH10]: _xact }], [1, { [_hH10]: _xamos }], [0, { [_hH10]: _xarp }], [0, { [_hH10]: _xaebo }], [0, { [_hH10]: _IM_ }], [0, { [_hH10]: _INM_ }], [0, { [_hH10]: _xasseca }], [() => SSECustomerKey, { [_hH10]: _xasseck }], [0, { [_hH10]: _xasseckM }]],
      3
    ];
    exports2.Condition$ = [
      3,
      n032,
      _Co,
      0,
      [_HECRE, _KPE],
      [0, 0]
    ];
    exports2.ContinuationEvent$ = [
      3,
      n032,
      _CE,
      0,
      [],
      []
    ];
    exports2.CopyObjectOutput$ = [
      3,
      n032,
      _COO,
      0,
      [_COR, _E11, _CSVI, _VI, _SSE, _SSECA, _SSECKMD, _SSEKMSKI, _SSEKMSEC, _BKE, _RC10],
      [[() => exports2.CopyObjectResult$, 16], [0, { [_hH10]: _xae }], [0, { [_hH10]: _xacsvi }], [0, { [_hH10]: _xavi }], [0, { [_hH10]: _xasse }], [0, { [_hH10]: _xasseca }], [0, { [_hH10]: _xasseckM }], [() => SSEKMSKeyId, { [_hH10]: _xasseakki }], [() => SSEKMSEncryptionContext, { [_hH10]: _xassec }], [2, { [_hH10]: _xassebke }], [0, { [_hH10]: _xarc }]]
    ];
    exports2.CopyObjectRequest$ = [
      3,
      n032,
      _CORo,
      0,
      [_B, _CS4, _K10, _ACL_, _CC, _CA10, _CDo, _CEo, _CL, _CTo, _CSIM, _CSIMS, _CSINM, _CSIUS, _Ex, _GFC, _GR, _GRACP, _GWACP, _IM, _INM, _M, _MD, _TD, _SSE, _SC, _WRL, _SSECA, _SSECK, _SSECKMD, _SSEKMSKI, _SSEKMSEC, _BKE, _CSSSECA, _CSSSECK, _CSSSECKMD, _RP, _Tag, _OLM, _OLRUD, _OLLHS, _EBO, _ESBO],
      [[0, 1], [0, { [_hH10]: _xacs___ }], [0, 1], [0, { [_hH10]: _xaa }], [0, { [_hH10]: _CC_ }], [0, { [_hH10]: _xaca }], [0, { [_hH10]: _CD_ }], [0, { [_hH10]: _CE_ }], [0, { [_hH10]: _CL_ }], [0, { [_hH10]: _CT_ }], [0, { [_hH10]: _xacsim }], [4, { [_hH10]: _xacsims }], [0, { [_hH10]: _xacsinm }], [4, { [_hH10]: _xacsius }], [4, { [_hH10]: _Ex }], [0, { [_hH10]: _xagfc }], [0, { [_hH10]: _xagr }], [0, { [_hH10]: _xagra }], [0, { [_hH10]: _xagwa }], [0, { [_hH10]: _IM_ }], [0, { [_hH10]: _INM_ }], [128 | 0, { [_hPH]: _xam }], [0, { [_hH10]: _xamd }], [0, { [_hH10]: _xatd }], [0, { [_hH10]: _xasse }], [0, { [_hH10]: _xasc }], [0, { [_hH10]: _xawrl }], [0, { [_hH10]: _xasseca }], [() => SSECustomerKey, { [_hH10]: _xasseck }], [0, { [_hH10]: _xasseckM }], [() => SSEKMSKeyId, { [_hH10]: _xasseakki }], [() => SSEKMSEncryptionContext, { [_hH10]: _xassec }], [2, { [_hH10]: _xassebke }], [0, { [_hH10]: _xacssseca }], [() => CopySourceSSECustomerKey, { [_hH10]: _xacssseck }], [0, { [_hH10]: _xacssseckM }], [0, { [_hH10]: _xarp }], [0, { [_hH10]: _xat }], [0, { [_hH10]: _xaolm }], [5, { [_hH10]: _xaolrud }], [0, { [_hH10]: _xaollh }], [0, { [_hH10]: _xaebo }], [0, { [_hH10]: _xasebo }]],
      3
    ];
    exports2.CopyObjectResult$ = [
      3,
      n032,
      _COR,
      0,
      [_ETa, _LM2, _CT4, _CCRC, _CCRCC, _CCRCNVME, _CSHA, _CSHAh, _CSHAhe, _CMD, _CXXHASH, _CXXHASHh, _CXXHASHhe],
      [0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]
    ];
    exports2.CopyPartResult$ = [
      3,
      n032,
      _CPR,
      0,
      [_ETa, _LM2, _CCRC, _CCRCC, _CCRCNVME, _CSHA, _CSHAh, _CSHAhe, _CMD, _CXXHASH, _CXXHASHh, _CXXHASHhe],
      [0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]
    ];
    exports2.CORSConfiguration$ = [
      3,
      n032,
      _CORSC,
      0,
      [_CORSR],
      [[() => CORSRules, { [_xF]: 1, [_xN]: _CORSRu }]],
      1
    ];
    exports2.CORSRule$ = [
      3,
      n032,
      _CORSRu,
      0,
      [_AM, _AO, _ID, _AH, _EH, _MAS],
      [[64 | 0, { [_xF]: 1, [_xN]: _AMl }], [64 | 0, { [_xF]: 1, [_xN]: _AOl }], 0, [64 | 0, { [_xF]: 1, [_xN]: _AHl }], [64 | 0, { [_xF]: 1, [_xN]: _EHx }], 1],
      2
    ];
    exports2.CreateBucketConfiguration$ = [
      3,
      n032,
      _CBC,
      0,
      [_LC, _L2, _B, _T10],
      [0, () => exports2.LocationInfo$, () => exports2.BucketInfo$, [() => TagSet, 0]]
    ];
    exports2.CreateBucketMetadataConfigurationRequest$ = [
      3,
      n032,
      _CBMCR,
      0,
      [_B, _MC, _CMDo, _CA10, _EBO],
      [[0, 1], [() => exports2.MetadataConfiguration$, { [_hP]: 1, [_xN]: _MC }], [0, { [_hH10]: _CM }], [0, { [_hH10]: _xasca }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.CreateBucketMetadataTableConfigurationRequest$ = [
      3,
      n032,
      _CBMTCR,
      0,
      [_B, _MTC, _CMDo, _CA10, _EBO],
      [[0, 1], [() => exports2.MetadataTableConfiguration$, { [_hP]: 1, [_xN]: _MTC }], [0, { [_hH10]: _CM }], [0, { [_hH10]: _xasca }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.CreateBucketOutput$ = [
      3,
      n032,
      _CBO,
      0,
      [_L2, _BA],
      [[0, { [_hH10]: _L2 }], [0, { [_hH10]: _xaba }]]
    ];
    exports2.CreateBucketRequest$ = [
      3,
      n032,
      _CBR,
      0,
      [_B, _ACL_, _CBC, _GFC, _GR, _GRACP, _GW, _GWACP, _OLEFB, _OO, _BN],
      [[0, 1], [0, { [_hH10]: _xaa }], [() => exports2.CreateBucketConfiguration$, { [_hP]: 1, [_xN]: _CBC }], [0, { [_hH10]: _xagfc }], [0, { [_hH10]: _xagr }], [0, { [_hH10]: _xagra }], [0, { [_hH10]: _xagw }], [0, { [_hH10]: _xagwa }], [2, { [_hH10]: _xabole }], [0, { [_hH10]: _xaoo }], [0, { [_hH10]: _xabn }]],
      1
    ];
    exports2.CreateMultipartUploadOutput$ = [
      3,
      n032,
      _CMUOr,
      { [_xN]: _IMUR },
      [_ADb, _ARI10, _B, _K10, _UI, _SSE, _SSECA, _SSECKMD, _SSEKMSKI, _SSEKMSEC, _BKE, _RC10, _CA10, _CT4],
      [[4, { [_hH10]: _xaad }], [0, { [_hH10]: _xaari }], [0, { [_xN]: _B }], 0, 0, [0, { [_hH10]: _xasse }], [0, { [_hH10]: _xasseca }], [0, { [_hH10]: _xasseckM }], [() => SSEKMSKeyId, { [_hH10]: _xasseakki }], [() => SSEKMSEncryptionContext, { [_hH10]: _xassec }], [2, { [_hH10]: _xassebke }], [0, { [_hH10]: _xarc }], [0, { [_hH10]: _xaca }], [0, { [_hH10]: _xact }]]
    ];
    exports2.CreateMultipartUploadRequest$ = [
      3,
      n032,
      _CMURr,
      0,
      [_B, _K10, _ACL_, _CC, _CDo, _CEo, _CL, _CTo, _Ex, _GFC, _GR, _GRACP, _GWACP, _M, _SSE, _SC, _WRL, _SSECA, _SSECK, _SSECKMD, _SSEKMSKI, _SSEKMSEC, _BKE, _RP, _Tag, _OLM, _OLRUD, _OLLHS, _EBO, _CA10, _CT4],
      [[0, 1], [0, 1], [0, { [_hH10]: _xaa }], [0, { [_hH10]: _CC_ }], [0, { [_hH10]: _CD_ }], [0, { [_hH10]: _CE_ }], [0, { [_hH10]: _CL_ }], [0, { [_hH10]: _CT_ }], [4, { [_hH10]: _Ex }], [0, { [_hH10]: _xagfc }], [0, { [_hH10]: _xagr }], [0, { [_hH10]: _xagra }], [0, { [_hH10]: _xagwa }], [128 | 0, { [_hPH]: _xam }], [0, { [_hH10]: _xasse }], [0, { [_hH10]: _xasc }], [0, { [_hH10]: _xawrl }], [0, { [_hH10]: _xasseca }], [() => SSECustomerKey, { [_hH10]: _xasseck }], [0, { [_hH10]: _xasseckM }], [() => SSEKMSKeyId, { [_hH10]: _xasseakki }], [() => SSEKMSEncryptionContext, { [_hH10]: _xassec }], [2, { [_hH10]: _xassebke }], [0, { [_hH10]: _xarp }], [0, { [_hH10]: _xat }], [0, { [_hH10]: _xaolm }], [5, { [_hH10]: _xaolrud }], [0, { [_hH10]: _xaollh }], [0, { [_hH10]: _xaebo }], [0, { [_hH10]: _xaca }], [0, { [_hH10]: _xact }]],
      2
    ];
    exports2.CreateSessionOutput$ = [
      3,
      n032,
      _CSO,
      { [_xN]: _CSR },
      [_Cr, _SSE, _SSEKMSKI, _SSEKMSEC, _BKE],
      [[() => exports2.SessionCredentials$, { [_xN]: _Cr }], [0, { [_hH10]: _xasse }], [() => SSEKMSKeyId, { [_hH10]: _xasseakki }], [() => SSEKMSEncryptionContext, { [_hH10]: _xassec }], [2, { [_hH10]: _xassebke }]],
      1
    ];
    exports2.CreateSessionRequest$ = [
      3,
      n032,
      _CSRr,
      0,
      [_B, _SM, _SSE, _SSEKMSKI, _SSEKMSEC, _BKE],
      [[0, 1], [0, { [_hH10]: _xacsm }], [0, { [_hH10]: _xasse }], [() => SSEKMSKeyId, { [_hH10]: _xasseakki }], [() => SSEKMSEncryptionContext, { [_hH10]: _xassec }], [2, { [_hH10]: _xassebke }]],
      1
    ];
    exports2.CSVInput$ = [
      3,
      n032,
      _CSVIn,
      0,
      [_FHI, _Com, _QEC, _RD, _FD, _QC, _AQRD],
      [0, 0, 0, 0, 0, 0, 2]
    ];
    exports2.CSVOutput$ = [
      3,
      n032,
      _CSVO,
      0,
      [_QF, _QEC, _RD, _FD, _QC],
      [0, 0, 0, 0, 0]
    ];
    exports2.DefaultRetention$ = [
      3,
      n032,
      _DRe,
      0,
      [_Mo, _D, _Y],
      [0, 1, 1]
    ];
    exports2.Delete$ = [
      3,
      n032,
      _De,
      0,
      [_Ob, _Q],
      [[() => ObjectIdentifierList, { [_xF]: 1, [_xN]: _Obj }], 2],
      1
    ];
    exports2.DeleteBucketAnalyticsConfigurationRequest$ = [
      3,
      n032,
      _DBACR,
      0,
      [_B, _I, _EBO],
      [[0, 1], [0, { [_hQ10]: _i }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.DeleteBucketCorsRequest$ = [
      3,
      n032,
      _DBCR,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.DeleteBucketEncryptionRequest$ = [
      3,
      n032,
      _DBER,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.DeleteBucketIntelligentTieringConfigurationRequest$ = [
      3,
      n032,
      _DBITCR,
      0,
      [_B, _I, _EBO],
      [[0, 1], [0, { [_hQ10]: _i }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.DeleteBucketInventoryConfigurationRequest$ = [
      3,
      n032,
      _DBICR,
      0,
      [_B, _I, _EBO],
      [[0, 1], [0, { [_hQ10]: _i }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.DeleteBucketLifecycleRequest$ = [
      3,
      n032,
      _DBLR,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.DeleteBucketMetadataConfigurationRequest$ = [
      3,
      n032,
      _DBMCR,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.DeleteBucketMetadataTableConfigurationRequest$ = [
      3,
      n032,
      _DBMTCR,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.DeleteBucketMetricsConfigurationRequest$ = [
      3,
      n032,
      _DBMCRe,
      0,
      [_B, _I, _EBO],
      [[0, 1], [0, { [_hQ10]: _i }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.DeleteBucketOwnershipControlsRequest$ = [
      3,
      n032,
      _DBOCR,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.DeleteBucketPolicyRequest$ = [
      3,
      n032,
      _DBPR,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.DeleteBucketReplicationRequest$ = [
      3,
      n032,
      _DBRR,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.DeleteBucketRequest$ = [
      3,
      n032,
      _DBR,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.DeleteBucketTaggingRequest$ = [
      3,
      n032,
      _DBTR,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.DeleteBucketWebsiteRequest$ = [
      3,
      n032,
      _DBWR,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.DeletedObject$ = [
      3,
      n032,
      _DO,
      0,
      [_K10, _VI, _DM, _DMVI],
      [0, 0, 2, 0]
    ];
    exports2.DeleteMarkerEntry$ = [
      3,
      n032,
      _DME,
      0,
      [_O, _K10, _VI, _IL, _LM2],
      [() => exports2.Owner$, 0, 0, 2, 4]
    ];
    exports2.DeleteMarkerReplication$ = [
      3,
      n032,
      _DMR,
      0,
      [_S],
      [0]
    ];
    exports2.DeleteObjectOutput$ = [
      3,
      n032,
      _DOO,
      0,
      [_DM, _VI, _RC10],
      [[2, { [_hH10]: _xadm }], [0, { [_hH10]: _xavi }], [0, { [_hH10]: _xarc }]]
    ];
    exports2.DeleteObjectRequest$ = [
      3,
      n032,
      _DOR,
      0,
      [_B, _K10, _MFA, _VI, _RP, _BGR, _EBO, _IM, _IMLMT, _IMS],
      [[0, 1], [0, 1], [0, { [_hH10]: _xam_ }], [0, { [_hQ10]: _vI }], [0, { [_hH10]: _xarp }], [2, { [_hH10]: _xabgr }], [0, { [_hH10]: _xaebo }], [0, { [_hH10]: _IM_ }], [6, { [_hH10]: _xaimlmt }], [1, { [_hH10]: _xaims }]],
      2
    ];
    exports2.DeleteObjectsOutput$ = [
      3,
      n032,
      _DOOe,
      { [_xN]: _DRel },
      [_Del, _RC10, _Er],
      [[() => DeletedObjects, { [_xF]: 1 }], [0, { [_hH10]: _xarc }], [() => Errors, { [_xF]: 1, [_xN]: _Err }]]
    ];
    exports2.DeleteObjectsRequest$ = [
      3,
      n032,
      _DORe,
      0,
      [_B, _De, _MFA, _RP, _BGR, _EBO, _CA10],
      [[0, 1], [() => exports2.Delete$, { [_hP]: 1, [_xN]: _De }], [0, { [_hH10]: _xam_ }], [0, { [_hH10]: _xarp }], [2, { [_hH10]: _xabgr }], [0, { [_hH10]: _xaebo }], [0, { [_hH10]: _xasca }]],
      2
    ];
    exports2.DeleteObjectTaggingOutput$ = [
      3,
      n032,
      _DOTO,
      0,
      [_VI],
      [[0, { [_hH10]: _xavi }]]
    ];
    exports2.DeleteObjectTaggingRequest$ = [
      3,
      n032,
      _DOTR,
      0,
      [_B, _K10, _VI, _EBO],
      [[0, 1], [0, 1], [0, { [_hQ10]: _vI }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.DeletePublicAccessBlockRequest$ = [
      3,
      n032,
      _DPABR,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.Destination$ = [
      3,
      n032,
      _Des,
      0,
      [_B, _A10, _SC, _ACT, _EC, _RT13, _Me],
      [0, 0, 0, () => exports2.AccessControlTranslation$, () => exports2.EncryptionConfiguration$, () => exports2.ReplicationTime$, () => exports2.Metrics$],
      1
    ];
    exports2.DestinationResult$ = [
      3,
      n032,
      _DRes,
      0,
      [_TBT, _TBA, _TN],
      [0, 0, 0]
    ];
    exports2.Encryption$ = [
      3,
      n032,
      _En,
      0,
      [_ET, _KMSKI, _KMSC],
      [0, [() => SSEKMSKeyId, 0], 0],
      1
    ];
    exports2.EncryptionConfiguration$ = [
      3,
      n032,
      _EC,
      0,
      [_RKKID],
      [0]
    ];
    exports2.EndEvent$ = [
      3,
      n032,
      _EE,
      0,
      [],
      []
    ];
    exports2._Error$ = [
      3,
      n032,
      _Err,
      0,
      [_K10, _VI, _Cod, _Mes],
      [0, 0, 0, 0]
    ];
    exports2.ErrorDetails$ = [
      3,
      n032,
      _ED,
      0,
      [_ECr, _EM],
      [0, 0]
    ];
    exports2.ErrorDocument$ = [
      3,
      n032,
      _EDr,
      0,
      [_K10],
      [0],
      1
    ];
    exports2.EventBridgeConfiguration$ = [
      3,
      n032,
      _EBC,
      0,
      [],
      []
    ];
    exports2.ExistingObjectReplication$ = [
      3,
      n032,
      _EOR,
      0,
      [_S],
      [0],
      1
    ];
    exports2.FilterRule$ = [
      3,
      n032,
      _FR,
      0,
      [_N, _V10],
      [0, 0]
    ];
    exports2.GetBucketAbacOutput$ = [
      3,
      n032,
      _GBAO,
      0,
      [_AS],
      [[() => exports2.AbacStatus$, 16]]
    ];
    exports2.GetBucketAbacRequest$ = [
      3,
      n032,
      _GBAR,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.GetBucketAccelerateConfigurationOutput$ = [
      3,
      n032,
      _GBACO,
      { [_xN]: _AC },
      [_S, _RC10],
      [0, [0, { [_hH10]: _xarc }]]
    ];
    exports2.GetBucketAccelerateConfigurationRequest$ = [
      3,
      n032,
      _GBACR,
      0,
      [_B, _EBO, _RP],
      [[0, 1], [0, { [_hH10]: _xaebo }], [0, { [_hH10]: _xarp }]],
      1
    ];
    exports2.GetBucketAclOutput$ = [
      3,
      n032,
      _GBAOe,
      { [_xN]: _ACP },
      [_O, _G],
      [() => exports2.Owner$, [() => Grants, { [_xN]: _ACL }]]
    ];
    exports2.GetBucketAclRequest$ = [
      3,
      n032,
      _GBARe,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.GetBucketAnalyticsConfigurationOutput$ = [
      3,
      n032,
      _GBACOe,
      0,
      [_ACn],
      [[() => exports2.AnalyticsConfiguration$, 16]]
    ];
    exports2.GetBucketAnalyticsConfigurationRequest$ = [
      3,
      n032,
      _GBACRe,
      0,
      [_B, _I, _EBO],
      [[0, 1], [0, { [_hQ10]: _i }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.GetBucketCorsOutput$ = [
      3,
      n032,
      _GBCO,
      { [_xN]: _CORSC },
      [_CORSR],
      [[() => CORSRules, { [_xF]: 1, [_xN]: _CORSRu }]]
    ];
    exports2.GetBucketCorsRequest$ = [
      3,
      n032,
      _GBCR,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.GetBucketEncryptionOutput$ = [
      3,
      n032,
      _GBEO,
      0,
      [_SSEC],
      [[() => exports2.ServerSideEncryptionConfiguration$, 16]]
    ];
    exports2.GetBucketEncryptionRequest$ = [
      3,
      n032,
      _GBER,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.GetBucketIntelligentTieringConfigurationOutput$ = [
      3,
      n032,
      _GBITCO,
      0,
      [_ITC],
      [[() => exports2.IntelligentTieringConfiguration$, 16]]
    ];
    exports2.GetBucketIntelligentTieringConfigurationRequest$ = [
      3,
      n032,
      _GBITCR,
      0,
      [_B, _I, _EBO],
      [[0, 1], [0, { [_hQ10]: _i }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.GetBucketInventoryConfigurationOutput$ = [
      3,
      n032,
      _GBICO,
      0,
      [_IC],
      [[() => exports2.InventoryConfiguration$, 16]]
    ];
    exports2.GetBucketInventoryConfigurationRequest$ = [
      3,
      n032,
      _GBICR,
      0,
      [_B, _I, _EBO],
      [[0, 1], [0, { [_hQ10]: _i }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.GetBucketLifecycleConfigurationOutput$ = [
      3,
      n032,
      _GBLCO,
      { [_xN]: _LCi },
      [_R, _TDMOS],
      [[() => LifecycleRules, { [_xF]: 1, [_xN]: _Ru }], [0, { [_hH10]: _xatdmos }]]
    ];
    exports2.GetBucketLifecycleConfigurationRequest$ = [
      3,
      n032,
      _GBLCR,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.GetBucketLocationOutput$ = [
      3,
      n032,
      _GBLO,
      { [_xN]: _LC },
      [_LC],
      [0]
    ];
    exports2.GetBucketLocationRequest$ = [
      3,
      n032,
      _GBLR,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.GetBucketLoggingOutput$ = [
      3,
      n032,
      _GBLOe,
      { [_xN]: _BLS },
      [_LE],
      [[() => exports2.LoggingEnabled$, 0]]
    ];
    exports2.GetBucketLoggingRequest$ = [
      3,
      n032,
      _GBLRe,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.GetBucketMetadataConfigurationOutput$ = [
      3,
      n032,
      _GBMCO,
      0,
      [_GBMCR],
      [[() => exports2.GetBucketMetadataConfigurationResult$, 16]]
    ];
    exports2.GetBucketMetadataConfigurationRequest$ = [
      3,
      n032,
      _GBMCRe,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.GetBucketMetadataConfigurationResult$ = [
      3,
      n032,
      _GBMCR,
      0,
      [_MCR],
      [() => exports2.MetadataConfigurationResult$],
      1
    ];
    exports2.GetBucketMetadataTableConfigurationOutput$ = [
      3,
      n032,
      _GBMTCO,
      0,
      [_GBMTCR],
      [[() => exports2.GetBucketMetadataTableConfigurationResult$, 16]]
    ];
    exports2.GetBucketMetadataTableConfigurationRequest$ = [
      3,
      n032,
      _GBMTCRe,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.GetBucketMetadataTableConfigurationResult$ = [
      3,
      n032,
      _GBMTCR,
      0,
      [_MTCR, _S, _Err],
      [() => exports2.MetadataTableConfigurationResult$, 0, () => exports2.ErrorDetails$],
      2
    ];
    exports2.GetBucketMetricsConfigurationOutput$ = [
      3,
      n032,
      _GBMCOe,
      0,
      [_MCe],
      [[() => exports2.MetricsConfiguration$, 16]]
    ];
    exports2.GetBucketMetricsConfigurationRequest$ = [
      3,
      n032,
      _GBMCRet,
      0,
      [_B, _I, _EBO],
      [[0, 1], [0, { [_hQ10]: _i }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.GetBucketNotificationConfigurationRequest$ = [
      3,
      n032,
      _GBNCR,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.GetBucketOwnershipControlsOutput$ = [
      3,
      n032,
      _GBOCO,
      0,
      [_OC],
      [[() => exports2.OwnershipControls$, 16]]
    ];
    exports2.GetBucketOwnershipControlsRequest$ = [
      3,
      n032,
      _GBOCR,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.GetBucketPolicyOutput$ = [
      3,
      n032,
      _GBPO,
      0,
      [_Po],
      [[0, 16]]
    ];
    exports2.GetBucketPolicyRequest$ = [
      3,
      n032,
      _GBPR,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.GetBucketPolicyStatusOutput$ = [
      3,
      n032,
      _GBPSO,
      0,
      [_PS],
      [[() => exports2.PolicyStatus$, 16]]
    ];
    exports2.GetBucketPolicyStatusRequest$ = [
      3,
      n032,
      _GBPSR,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.GetBucketReplicationOutput$ = [
      3,
      n032,
      _GBRO,
      0,
      [_RCe],
      [[() => exports2.ReplicationConfiguration$, 16]]
    ];
    exports2.GetBucketReplicationRequest$ = [
      3,
      n032,
      _GBRR,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.GetBucketRequestPaymentOutput$ = [
      3,
      n032,
      _GBRPO,
      { [_xN]: _RPC },
      [_Pay],
      [0]
    ];
    exports2.GetBucketRequestPaymentRequest$ = [
      3,
      n032,
      _GBRPR,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.GetBucketTaggingOutput$ = [
      3,
      n032,
      _GBTO,
      { [_xN]: _Tag },
      [_TS],
      [[() => TagSet, 0]],
      1
    ];
    exports2.GetBucketTaggingRequest$ = [
      3,
      n032,
      _GBTR,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.GetBucketVersioningOutput$ = [
      3,
      n032,
      _GBVO,
      { [_xN]: _VC },
      [_S, _MFAD],
      [0, [0, { [_xN]: _MDf }]]
    ];
    exports2.GetBucketVersioningRequest$ = [
      3,
      n032,
      _GBVR,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.GetBucketWebsiteOutput$ = [
      3,
      n032,
      _GBWO,
      { [_xN]: _WC },
      [_RART, _IDn, _EDr, _RR],
      [() => exports2.RedirectAllRequestsTo$, () => exports2.IndexDocument$, () => exports2.ErrorDocument$, [() => RoutingRules, 0]]
    ];
    exports2.GetBucketWebsiteRequest$ = [
      3,
      n032,
      _GBWR,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.GetObjectAclOutput$ = [
      3,
      n032,
      _GOAO,
      { [_xN]: _ACP },
      [_O, _G, _RC10],
      [() => exports2.Owner$, [() => Grants, { [_xN]: _ACL }], [0, { [_hH10]: _xarc }]]
    ];
    exports2.GetObjectAclRequest$ = [
      3,
      n032,
      _GOAR,
      0,
      [_B, _K10, _VI, _RP, _EBO],
      [[0, 1], [0, 1], [0, { [_hQ10]: _vI }], [0, { [_hH10]: _xarp }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.GetObjectAttributesOutput$ = [
      3,
      n032,
      _GOAOe,
      { [_xN]: _GOARe },
      [_DM, _LM2, _VI, _RC10, _ETa, _C11, _OP, _SC, _OS],
      [[2, { [_hH10]: _xadm }], [4, { [_hH10]: _LM_ }], [0, { [_hH10]: _xavi }], [0, { [_hH10]: _xarc }], 0, () => exports2.Checksum$, [() => exports2.GetObjectAttributesParts$, 0], 0, 1]
    ];
    exports2.GetObjectAttributesParts$ = [
      3,
      n032,
      _GOAP,
      0,
      [_TPC, _PNM, _NPNM, _MP, _IT4, _Pa],
      [[1, { [_xN]: _PC10 }], 0, 0, 1, 2, [() => PartsList, { [_xF]: 1, [_xN]: _Par }]]
    ];
    exports2.GetObjectAttributesRequest$ = [
      3,
      n032,
      _GOARet,
      0,
      [_B, _K10, _OA, _VI, _MP, _PNM, _SSECA, _SSECK, _SSECKMD, _RP, _EBO],
      [[0, 1], [0, 1], [64 | 0, { [_hH10]: _xaoa }], [0, { [_hQ10]: _vI }], [1, { [_hH10]: _xamp }], [0, { [_hH10]: _xapnm }], [0, { [_hH10]: _xasseca }], [() => SSECustomerKey, { [_hH10]: _xasseck }], [0, { [_hH10]: _xasseckM }], [0, { [_hH10]: _xarp }], [0, { [_hH10]: _xaebo }]],
      3
    ];
    exports2.GetObjectLegalHoldOutput$ = [
      3,
      n032,
      _GOLHO,
      0,
      [_LH],
      [[() => exports2.ObjectLockLegalHold$, { [_hP]: 1, [_xN]: _LH }]]
    ];
    exports2.GetObjectLegalHoldRequest$ = [
      3,
      n032,
      _GOLHR,
      0,
      [_B, _K10, _VI, _RP, _EBO],
      [[0, 1], [0, 1], [0, { [_hQ10]: _vI }], [0, { [_hH10]: _xarp }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.GetObjectLockConfigurationOutput$ = [
      3,
      n032,
      _GOLCO,
      0,
      [_OLC],
      [[() => exports2.ObjectLockConfiguration$, 16]]
    ];
    exports2.GetObjectLockConfigurationRequest$ = [
      3,
      n032,
      _GOLCR,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.GetObjectOutput$ = [
      3,
      n032,
      _GOO,
      0,
      [_Bo, _DM, _AR10, _E11, _Re, _LM2, _CLo, _ETa, _CCRC, _CCRCC, _CCRCNVME, _CSHA, _CSHAh, _CSHAhe, _CMD, _CXXHASH, _CXXHASHh, _CXXHASHhe, _CT4, _MM, _VI, _CC, _CDo, _CEo, _CL, _CR, _CTo, _Ex, _ES, _WRL, _SSE, _M, _SSECA, _SSECKMD, _SSEKMSKI, _BKE, _SC, _RC10, _RS, _PC10, _TC10, _OLM, _OLRUD, _OLLHS],
      [[() => StreamingBlob, 16], [2, { [_hH10]: _xadm }], [0, { [_hH10]: _ar }], [0, { [_hH10]: _xae }], [0, { [_hH10]: _xar }], [4, { [_hH10]: _LM_ }], [1, { [_hH10]: _CL__ }], [0, { [_hH10]: _ETa }], [0, { [_hH10]: _xacc }], [0, { [_hH10]: _xacc_ }], [0, { [_hH10]: _xacc__ }], [0, { [_hH10]: _xacs }], [0, { [_hH10]: _xacs_ }], [0, { [_hH10]: _xacs__ }], [0, { [_hH10]: _xacm }], [0, { [_hH10]: _xacx }], [0, { [_hH10]: _xacx_ }], [0, { [_hH10]: _xacx__ }], [0, { [_hH10]: _xact }], [1, { [_hH10]: _xamm }], [0, { [_hH10]: _xavi }], [0, { [_hH10]: _CC_ }], [0, { [_hH10]: _CD_ }], [0, { [_hH10]: _CE_ }], [0, { [_hH10]: _CL_ }], [0, { [_hH10]: _CR_ }], [0, { [_hH10]: _CT_ }], [4, { [_hH10]: _Ex }], [0, { [_hH10]: _ES }], [0, { [_hH10]: _xawrl }], [0, { [_hH10]: _xasse }], [128 | 0, { [_hPH]: _xam }], [0, { [_hH10]: _xasseca }], [0, { [_hH10]: _xasseckM }], [() => SSEKMSKeyId, { [_hH10]: _xasseakki }], [2, { [_hH10]: _xassebke }], [0, { [_hH10]: _xasc }], [0, { [_hH10]: _xarc }], [0, { [_hH10]: _xars }], [1, { [_hH10]: _xampc }], [1, { [_hH10]: _xatc }], [0, { [_hH10]: _xaolm }], [5, { [_hH10]: _xaolrud }], [0, { [_hH10]: _xaollh }]]
    ];
    exports2.GetObjectRequest$ = [
      3,
      n032,
      _GOR,
      0,
      [_B, _K10, _IM, _IMSf, _INM, _IUS, _Ra, _RCC, _RCD, _RCE2, _RCL, _RCT, _RE, _VI, _SSECA, _SSECK, _SSECKMD, _RP, _PN, _EBO, _CMh],
      [[0, 1], [0, 1], [0, { [_hH10]: _IM_ }], [4, { [_hH10]: _IMS_ }], [0, { [_hH10]: _INM_ }], [4, { [_hH10]: _IUS_ }], [0, { [_hH10]: _Ra }], [0, { [_hQ10]: _rcc }], [0, { [_hQ10]: _rcd }], [0, { [_hQ10]: _rce }], [0, { [_hQ10]: _rcl }], [0, { [_hQ10]: _rct }], [6, { [_hQ10]: _re }], [0, { [_hQ10]: _vI }], [0, { [_hH10]: _xasseca }], [() => SSECustomerKey, { [_hH10]: _xasseck }], [0, { [_hH10]: _xasseckM }], [0, { [_hH10]: _xarp }], [1, { [_hQ10]: _pN }], [0, { [_hH10]: _xaebo }], [0, { [_hH10]: _xacm_ }]],
      2
    ];
    exports2.GetObjectRetentionOutput$ = [
      3,
      n032,
      _GORO,
      0,
      [_Ret],
      [[() => exports2.ObjectLockRetention$, { [_hP]: 1, [_xN]: _Ret }]]
    ];
    exports2.GetObjectRetentionRequest$ = [
      3,
      n032,
      _GORR,
      0,
      [_B, _K10, _VI, _RP, _EBO],
      [[0, 1], [0, 1], [0, { [_hQ10]: _vI }], [0, { [_hH10]: _xarp }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.GetObjectTaggingOutput$ = [
      3,
      n032,
      _GOTO,
      { [_xN]: _Tag },
      [_TS, _VI],
      [[() => TagSet, 0], [0, { [_hH10]: _xavi }]],
      1
    ];
    exports2.GetObjectTaggingRequest$ = [
      3,
      n032,
      _GOTR,
      0,
      [_B, _K10, _VI, _EBO, _RP],
      [[0, 1], [0, 1], [0, { [_hQ10]: _vI }], [0, { [_hH10]: _xaebo }], [0, { [_hH10]: _xarp }]],
      2
    ];
    exports2.GetObjectTorrentOutput$ = [
      3,
      n032,
      _GOTOe,
      0,
      [_Bo, _RC10],
      [[() => StreamingBlob, 16], [0, { [_hH10]: _xarc }]]
    ];
    exports2.GetObjectTorrentRequest$ = [
      3,
      n032,
      _GOTRe,
      0,
      [_B, _K10, _RP, _EBO],
      [[0, 1], [0, 1], [0, { [_hH10]: _xarp }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.GetPublicAccessBlockOutput$ = [
      3,
      n032,
      _GPABO,
      0,
      [_PABC],
      [[() => exports2.PublicAccessBlockConfiguration$, 16]]
    ];
    exports2.GetPublicAccessBlockRequest$ = [
      3,
      n032,
      _GPABR,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.GlacierJobParameters$ = [
      3,
      n032,
      _GJP,
      0,
      [_Ti],
      [0],
      1
    ];
    exports2.Grant$ = [
      3,
      n032,
      _Gr,
      0,
      [_Gra, _Pe],
      [[() => exports2.Grantee$, { [_xNm]: [_x, _hi] }], 0]
    ];
    exports2.Grantee$ = [
      3,
      n032,
      _Gra,
      0,
      [_Ty, _DN, _EA, _ID, _URI],
      [[0, { [_xA]: 1, [_xN]: _xs }], 0, 0, 0, 0],
      1
    ];
    exports2.HeadBucketOutput$ = [
      3,
      n032,
      _HBO,
      0,
      [_BA, _BLT, _BLN, _BR, _APA],
      [[0, { [_hH10]: _xaba }], [0, { [_hH10]: _xablt }], [0, { [_hH10]: _xabln }], [0, { [_hH10]: _xabr }], [2, { [_hH10]: _xaapa }]]
    ];
    exports2.HeadBucketRequest$ = [
      3,
      n032,
      _HBR,
      0,
      [_B, _EBO],
      [[0, 1], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.HeadObjectOutput$ = [
      3,
      n032,
      _HOO,
      0,
      [_DM, _AR10, _E11, _Re, _ASr, _LM2, _CLo, _CCRC, _CCRCC, _CCRCNVME, _CSHA, _CSHAh, _CSHAhe, _CMD, _CXXHASH, _CXXHASHh, _CXXHASHhe, _CT4, _ETa, _MM, _VI, _CC, _CDo, _CEo, _CL, _CTo, _CR, _Ex, _ES, _WRL, _SSE, _M, _SSECA, _SSECKMD, _SSEKMSKI, _BKE, _SC, _RC10, _RS, _PC10, _TC10, _OLM, _OLRUD, _OLLHS],
      [[2, { [_hH10]: _xadm }], [0, { [_hH10]: _ar }], [0, { [_hH10]: _xae }], [0, { [_hH10]: _xar }], [0, { [_hH10]: _xaas }], [4, { [_hH10]: _LM_ }], [1, { [_hH10]: _CL__ }], [0, { [_hH10]: _xacc }], [0, { [_hH10]: _xacc_ }], [0, { [_hH10]: _xacc__ }], [0, { [_hH10]: _xacs }], [0, { [_hH10]: _xacs_ }], [0, { [_hH10]: _xacs__ }], [0, { [_hH10]: _xacm }], [0, { [_hH10]: _xacx }], [0, { [_hH10]: _xacx_ }], [0, { [_hH10]: _xacx__ }], [0, { [_hH10]: _xact }], [0, { [_hH10]: _ETa }], [1, { [_hH10]: _xamm }], [0, { [_hH10]: _xavi }], [0, { [_hH10]: _CC_ }], [0, { [_hH10]: _CD_ }], [0, { [_hH10]: _CE_ }], [0, { [_hH10]: _CL_ }], [0, { [_hH10]: _CT_ }], [0, { [_hH10]: _CR_ }], [4, { [_hH10]: _Ex }], [0, { [_hH10]: _ES }], [0, { [_hH10]: _xawrl }], [0, { [_hH10]: _xasse }], [128 | 0, { [_hPH]: _xam }], [0, { [_hH10]: _xasseca }], [0, { [_hH10]: _xasseckM }], [() => SSEKMSKeyId, { [_hH10]: _xasseakki }], [2, { [_hH10]: _xassebke }], [0, { [_hH10]: _xasc }], [0, { [_hH10]: _xarc }], [0, { [_hH10]: _xars }], [1, { [_hH10]: _xampc }], [1, { [_hH10]: _xatc }], [0, { [_hH10]: _xaolm }], [5, { [_hH10]: _xaolrud }], [0, { [_hH10]: _xaollh }]]
    ];
    exports2.HeadObjectRequest$ = [
      3,
      n032,
      _HOR,
      0,
      [_B, _K10, _IM, _IMSf, _INM, _IUS, _Ra, _RCC, _RCD, _RCE2, _RCL, _RCT, _RE, _VI, _SSECA, _SSECK, _SSECKMD, _RP, _PN, _EBO, _CMh],
      [[0, 1], [0, 1], [0, { [_hH10]: _IM_ }], [4, { [_hH10]: _IMS_ }], [0, { [_hH10]: _INM_ }], [4, { [_hH10]: _IUS_ }], [0, { [_hH10]: _Ra }], [0, { [_hQ10]: _rcc }], [0, { [_hQ10]: _rcd }], [0, { [_hQ10]: _rce }], [0, { [_hQ10]: _rcl }], [0, { [_hQ10]: _rct }], [6, { [_hQ10]: _re }], [0, { [_hQ10]: _vI }], [0, { [_hH10]: _xasseca }], [() => SSECustomerKey, { [_hH10]: _xasseck }], [0, { [_hH10]: _xasseckM }], [0, { [_hH10]: _xarp }], [1, { [_hQ10]: _pN }], [0, { [_hH10]: _xaebo }], [0, { [_hH10]: _xacm_ }]],
      2
    ];
    exports2.IndexDocument$ = [
      3,
      n032,
      _IDn,
      0,
      [_Su],
      [0],
      1
    ];
    exports2.Initiator$ = [
      3,
      n032,
      _In,
      0,
      [_ID, _DN],
      [0, 0]
    ];
    exports2.InputSerialization$ = [
      3,
      n032,
      _IS,
      0,
      [_CSV, _CTom, _JSON, _Parq],
      [() => exports2.CSVInput$, 0, () => exports2.JSONInput$, () => exports2.ParquetInput$]
    ];
    exports2.IntelligentTieringAndOperator$ = [
      3,
      n032,
      _ITAO,
      0,
      [_P10, _T10],
      [0, [() => TagSet, { [_xF]: 1, [_xN]: _Ta10 }]]
    ];
    exports2.IntelligentTieringConfiguration$ = [
      3,
      n032,
      _ITC,
      0,
      [_I, _S, _Tie, _F],
      [0, 0, [() => TieringList, { [_xF]: 1, [_xN]: _Tier }], [() => exports2.IntelligentTieringFilter$, 0]],
      3
    ];
    exports2.IntelligentTieringFilter$ = [
      3,
      n032,
      _ITF,
      0,
      [_P10, _Ta10, _An],
      [0, () => exports2.Tag$, [() => exports2.IntelligentTieringAndOperator$, 0]]
    ];
    exports2.InventoryConfiguration$ = [
      3,
      n032,
      _IC,
      0,
      [_Des, _IE, _I, _IOV, _Sc, _F, _OF],
      [[() => exports2.InventoryDestination$, 0], 2, 0, 0, () => exports2.InventorySchedule$, () => exports2.InventoryFilter$, [() => InventoryOptionalFields, 0]],
      5
    ];
    exports2.InventoryDestination$ = [
      3,
      n032,
      _IDnv,
      0,
      [_SBD],
      [[() => exports2.InventoryS3BucketDestination$, 0]],
      1
    ];
    exports2.InventoryEncryption$ = [
      3,
      n032,
      _IEn,
      0,
      [_SSES, _SSEKMS],
      [[() => exports2.SSES3$, { [_xN]: _SS }], [() => exports2.SSEKMS$, { [_xN]: _SK2 }]]
    ];
    exports2.InventoryFilter$ = [
      3,
      n032,
      _IF,
      0,
      [_P10],
      [0],
      1
    ];
    exports2.InventoryS3BucketDestination$ = [
      3,
      n032,
      _ISBD,
      0,
      [_B, _Fo, _AI2, _P10, _En],
      [0, 0, 0, 0, [() => exports2.InventoryEncryption$, 0]],
      2
    ];
    exports2.InventorySchedule$ = [
      3,
      n032,
      _ISn,
      0,
      [_Fr],
      [0],
      1
    ];
    exports2.InventoryTableConfiguration$ = [
      3,
      n032,
      _ITCn,
      0,
      [_CSo, _EC],
      [0, () => exports2.MetadataTableEncryptionConfiguration$],
      1
    ];
    exports2.InventoryTableConfigurationResult$ = [
      3,
      n032,
      _ITCR,
      0,
      [_CSo, _TSa, _Err, _TNa, _TA],
      [0, 0, () => exports2.ErrorDetails$, 0, 0],
      1
    ];
    exports2.InventoryTableConfigurationUpdates$ = [
      3,
      n032,
      _ITCU,
      0,
      [_CSo, _EC],
      [0, () => exports2.MetadataTableEncryptionConfiguration$],
      1
    ];
    exports2.JournalTableConfiguration$ = [
      3,
      n032,
      _JTC,
      0,
      [_REe, _EC],
      [() => exports2.RecordExpiration$, () => exports2.MetadataTableEncryptionConfiguration$],
      1
    ];
    exports2.JournalTableConfigurationResult$ = [
      3,
      n032,
      _JTCR,
      0,
      [_TSa, _TNa, _REe, _Err, _TA],
      [0, 0, () => exports2.RecordExpiration$, () => exports2.ErrorDetails$, 0],
      3
    ];
    exports2.JournalTableConfigurationUpdates$ = [
      3,
      n032,
      _JTCU,
      0,
      [_REe],
      [() => exports2.RecordExpiration$],
      1
    ];
    exports2.JSONInput$ = [
      3,
      n032,
      _JSONI,
      0,
      [_Ty],
      [0]
    ];
    exports2.JSONOutput$ = [
      3,
      n032,
      _JSONO,
      0,
      [_RD],
      [0]
    ];
    exports2.LambdaFunctionConfiguration$ = [
      3,
      n032,
      _LFC,
      0,
      [_LFA, _Ev, _I, _F],
      [[0, { [_xN]: _CF }], [64 | 0, { [_xF]: 1, [_xN]: _Eve }], 0, [() => exports2.NotificationConfigurationFilter$, 0]],
      2
    ];
    exports2.LifecycleExpiration$ = [
      3,
      n032,
      _LEi,
      0,
      [_Da, _D, _EODM],
      [5, 1, 2]
    ];
    exports2.LifecycleRule$ = [
      3,
      n032,
      _LR,
      0,
      [_S, _E11, _ID, _P10, _F, _Tr, _NVT, _NVE, _AIMU],
      [0, () => exports2.LifecycleExpiration$, 0, 0, [() => exports2.LifecycleRuleFilter$, 0], [() => TransitionList, { [_xF]: 1, [_xN]: _Tra }], [() => NoncurrentVersionTransitionList, { [_xF]: 1, [_xN]: _NVTo }], () => exports2.NoncurrentVersionExpiration$, () => exports2.AbortIncompleteMultipartUpload$],
      1
    ];
    exports2.LifecycleRuleAndOperator$ = [
      3,
      n032,
      _LRAO,
      0,
      [_P10, _T10, _OSGT, _OSLT],
      [0, [() => TagSet, { [_xF]: 1, [_xN]: _Ta10 }], 1, 1]
    ];
    exports2.LifecycleRuleFilter$ = [
      3,
      n032,
      _LRF,
      0,
      [_P10, _Ta10, _OSGT, _OSLT, _An],
      [0, () => exports2.Tag$, 1, 1, [() => exports2.LifecycleRuleAndOperator$, 0]]
    ];
    exports2.ListBucketAnalyticsConfigurationsOutput$ = [
      3,
      n032,
      _LBACO,
      { [_xN]: _LBACR },
      [_IT4, _CTon, _NCT, _ACLn],
      [2, 0, 0, [() => AnalyticsConfigurationList, { [_xF]: 1, [_xN]: _ACn }]]
    ];
    exports2.ListBucketAnalyticsConfigurationsRequest$ = [
      3,
      n032,
      _LBACRi,
      0,
      [_B, _CTon, _EBO],
      [[0, 1], [0, { [_hQ10]: _ct }], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.ListBucketIntelligentTieringConfigurationsOutput$ = [
      3,
      n032,
      _LBITCO,
      0,
      [_IT4, _CTon, _NCT, _ITCL],
      [2, 0, 0, [() => IntelligentTieringConfigurationList, { [_xF]: 1, [_xN]: _ITC }]]
    ];
    exports2.ListBucketIntelligentTieringConfigurationsRequest$ = [
      3,
      n032,
      _LBITCR,
      0,
      [_B, _CTon, _EBO],
      [[0, 1], [0, { [_hQ10]: _ct }], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.ListBucketInventoryConfigurationsOutput$ = [
      3,
      n032,
      _LBICO,
      { [_xN]: _LICR },
      [_CTon, _ICL, _IT4, _NCT],
      [0, [() => InventoryConfigurationList, { [_xF]: 1, [_xN]: _IC }], 2, 0]
    ];
    exports2.ListBucketInventoryConfigurationsRequest$ = [
      3,
      n032,
      _LBICR,
      0,
      [_B, _CTon, _EBO],
      [[0, 1], [0, { [_hQ10]: _ct }], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.ListBucketMetricsConfigurationsOutput$ = [
      3,
      n032,
      _LBMCO,
      { [_xN]: _LMCR },
      [_IT4, _CTon, _NCT, _MCL],
      [2, 0, 0, [() => MetricsConfigurationList, { [_xF]: 1, [_xN]: _MCe }]]
    ];
    exports2.ListBucketMetricsConfigurationsRequest$ = [
      3,
      n032,
      _LBMCR,
      0,
      [_B, _CTon, _EBO],
      [[0, 1], [0, { [_hQ10]: _ct }], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.ListBucketsOutput$ = [
      3,
      n032,
      _LBO,
      { [_xN]: _LAMBR },
      [_Bu, _O, _CTon, _P10],
      [[() => Buckets, 0], () => exports2.Owner$, 0, 0]
    ];
    exports2.ListBucketsRequest$ = [
      3,
      n032,
      _LBR,
      0,
      [_MB, _CTon, _P10, _BR],
      [[1, { [_hQ10]: _mb }], [0, { [_hQ10]: _ct }], [0, { [_hQ10]: _p }], [0, { [_hQ10]: _br }]]
    ];
    exports2.ListDirectoryBucketsOutput$ = [
      3,
      n032,
      _LDBO,
      { [_xN]: _LAMDBR },
      [_Bu, _CTon],
      [[() => Buckets, 0], 0]
    ];
    exports2.ListDirectoryBucketsRequest$ = [
      3,
      n032,
      _LDBR,
      0,
      [_CTon, _MDB],
      [[0, { [_hQ10]: _ct }], [1, { [_hQ10]: _mdb }]]
    ];
    exports2.ListMultipartUploadsOutput$ = [
      3,
      n032,
      _LMUO,
      { [_xN]: _LMUR },
      [_B, _KM, _UIM, _NKM, _P10, _Deli, _NUIM, _MUa, _IT4, _U, _CPom, _ETn, _RC10],
      [0, 0, 0, 0, 0, 0, 0, 1, 2, [() => MultipartUploadList, { [_xF]: 1, [_xN]: _Up }], [() => CommonPrefixList, { [_xF]: 1 }], 0, [0, { [_hH10]: _xarc }]]
    ];
    exports2.ListMultipartUploadsRequest$ = [
      3,
      n032,
      _LMURi,
      0,
      [_B, _Deli, _ETn, _KM, _MUa, _P10, _UIM, _EBO, _RP],
      [[0, 1], [0, { [_hQ10]: _d }], [0, { [_hQ10]: _et }], [0, { [_hQ10]: _km }], [1, { [_hQ10]: _mu }], [0, { [_hQ10]: _p }], [0, { [_hQ10]: _uim }], [0, { [_hH10]: _xaebo }], [0, { [_hH10]: _xarp }]],
      1
    ];
    exports2.ListObjectsOutput$ = [
      3,
      n032,
      _LOO,
      { [_xN]: _LBRi },
      [_IT4, _Ma, _NM, _Con, _N, _P10, _Deli, _MK, _CPom, _ETn, _RC10],
      [2, 0, 0, [() => ObjectList, { [_xF]: 1 }], 0, 0, 0, 1, [() => CommonPrefixList, { [_xF]: 1 }], 0, [0, { [_hH10]: _xarc }]]
    ];
    exports2.ListObjectsRequest$ = [
      3,
      n032,
      _LOR,
      0,
      [_B, _Deli, _ETn, _Ma, _MK, _P10, _RP, _EBO, _OOA],
      [[0, 1], [0, { [_hQ10]: _d }], [0, { [_hQ10]: _et }], [0, { [_hQ10]: _m29 }], [1, { [_hQ10]: _mk }], [0, { [_hQ10]: _p }], [0, { [_hH10]: _xarp }], [0, { [_hH10]: _xaebo }], [64 | 0, { [_hH10]: _xaooa }]],
      1
    ];
    exports2.ListObjectsV2Output$ = [
      3,
      n032,
      _LOVO,
      { [_xN]: _LBRi },
      [_IT4, _Con, _N, _P10, _Deli, _MK, _CPom, _ETn, _KC, _CTon, _NCT, _SA, _RC10],
      [2, [() => ObjectList, { [_xF]: 1 }], 0, 0, 0, 1, [() => CommonPrefixList, { [_xF]: 1 }], 0, 1, 0, 0, 0, [0, { [_hH10]: _xarc }]]
    ];
    exports2.ListObjectsV2Request$ = [
      3,
      n032,
      _LOVR,
      0,
      [_B, _Deli, _ETn, _MK, _P10, _CTon, _FO, _SA, _RP, _EBO, _OOA],
      [[0, 1], [0, { [_hQ10]: _d }], [0, { [_hQ10]: _et }], [1, { [_hQ10]: _mk }], [0, { [_hQ10]: _p }], [0, { [_hQ10]: _ct }], [2, { [_hQ10]: _fo }], [0, { [_hQ10]: _sa }], [0, { [_hH10]: _xarp }], [0, { [_hH10]: _xaebo }], [64 | 0, { [_hH10]: _xaooa }]],
      1
    ];
    exports2.ListObjectVersionsOutput$ = [
      3,
      n032,
      _LOVOi,
      { [_xN]: _LVR },
      [_IT4, _KM, _VIM, _NKM, _NVIM, _Ve, _DMe, _N, _P10, _Deli, _MK, _CPom, _ETn, _RC10],
      [2, 0, 0, 0, 0, [() => ObjectVersionList, { [_xF]: 1, [_xN]: _Ver }], [() => DeleteMarkers, { [_xF]: 1, [_xN]: _DM }], 0, 0, 0, 1, [() => CommonPrefixList, { [_xF]: 1 }], 0, [0, { [_hH10]: _xarc }]]
    ];
    exports2.ListObjectVersionsRequest$ = [
      3,
      n032,
      _LOVRi,
      0,
      [_B, _Deli, _ETn, _KM, _MK, _P10, _VIM, _EBO, _RP, _OOA],
      [[0, 1], [0, { [_hQ10]: _d }], [0, { [_hQ10]: _et }], [0, { [_hQ10]: _km }], [1, { [_hQ10]: _mk }], [0, { [_hQ10]: _p }], [0, { [_hQ10]: _vim }], [0, { [_hH10]: _xaebo }], [0, { [_hH10]: _xarp }], [64 | 0, { [_hH10]: _xaooa }]],
      1
    ];
    exports2.ListPartsOutput$ = [
      3,
      n032,
      _LPO,
      { [_xN]: _LPR },
      [_ADb, _ARI10, _B, _K10, _UI, _PNM, _NPNM, _MP, _IT4, _Pa, _In, _O, _SC, _RC10, _CA10, _CT4],
      [[4, { [_hH10]: _xaad }], [0, { [_hH10]: _xaari }], 0, 0, 0, 0, 0, 1, 2, [() => Parts, { [_xF]: 1, [_xN]: _Par }], () => exports2.Initiator$, () => exports2.Owner$, 0, [0, { [_hH10]: _xarc }], 0, 0]
    ];
    exports2.ListPartsRequest$ = [
      3,
      n032,
      _LPRi,
      0,
      [_B, _K10, _UI, _MP, _PNM, _RP, _EBO, _SSECA, _SSECK, _SSECKMD],
      [[0, 1], [0, 1], [0, { [_hQ10]: _uI }], [1, { [_hQ10]: _mp }], [0, { [_hQ10]: _pnm }], [0, { [_hH10]: _xarp }], [0, { [_hH10]: _xaebo }], [0, { [_hH10]: _xasseca }], [() => SSECustomerKey, { [_hH10]: _xasseck }], [0, { [_hH10]: _xasseckM }]],
      3
    ];
    exports2.LocationInfo$ = [
      3,
      n032,
      _LI,
      0,
      [_Ty, _N],
      [0, 0]
    ];
    exports2.LoggingEnabled$ = [
      3,
      n032,
      _LE,
      0,
      [_TB, _TP, _TG, _TOKF],
      [0, 0, [() => TargetGrants, 0], [() => exports2.TargetObjectKeyFormat$, 0]],
      2
    ];
    exports2.MetadataConfiguration$ = [
      3,
      n032,
      _MC,
      0,
      [_JTC, _ITCn],
      [() => exports2.JournalTableConfiguration$, () => exports2.InventoryTableConfiguration$],
      1
    ];
    exports2.MetadataConfigurationResult$ = [
      3,
      n032,
      _MCR,
      0,
      [_DRes, _JTCR, _ITCR],
      [() => exports2.DestinationResult$, () => exports2.JournalTableConfigurationResult$, () => exports2.InventoryTableConfigurationResult$],
      1
    ];
    exports2.MetadataEntry$ = [
      3,
      n032,
      _ME,
      0,
      [_N, _V10],
      [0, 0]
    ];
    exports2.MetadataTableConfiguration$ = [
      3,
      n032,
      _MTC,
      0,
      [_STD],
      [() => exports2.S3TablesDestination$],
      1
    ];
    exports2.MetadataTableConfigurationResult$ = [
      3,
      n032,
      _MTCR,
      0,
      [_STDR],
      [() => exports2.S3TablesDestinationResult$],
      1
    ];
    exports2.MetadataTableEncryptionConfiguration$ = [
      3,
      n032,
      _MTEC,
      0,
      [_SAs, _KKA],
      [0, 0],
      1
    ];
    exports2.Metrics$ = [
      3,
      n032,
      _Me,
      0,
      [_S, _ETv],
      [0, () => exports2.ReplicationTimeValue$],
      1
    ];
    exports2.MetricsAndOperator$ = [
      3,
      n032,
      _MAO,
      0,
      [_P10, _T10, _APAc],
      [0, [() => TagSet, { [_xF]: 1, [_xN]: _Ta10 }], 0]
    ];
    exports2.MetricsConfiguration$ = [
      3,
      n032,
      _MCe,
      0,
      [_I, _F],
      [0, [() => exports2.MetricsFilter$, 0]],
      1
    ];
    exports2.MultipartUpload$ = [
      3,
      n032,
      _MU,
      0,
      [_UI, _K10, _Ini, _SC, _O, _In, _CA10, _CT4],
      [0, 0, 4, 0, () => exports2.Owner$, () => exports2.Initiator$, 0, 0]
    ];
    exports2.NoncurrentVersionExpiration$ = [
      3,
      n032,
      _NVE,
      0,
      [_ND, _NNV],
      [1, 1]
    ];
    exports2.NoncurrentVersionTransition$ = [
      3,
      n032,
      _NVTo,
      0,
      [_ND, _SC, _NNV],
      [1, 0, 1]
    ];
    exports2.NotificationConfiguration$ = [
      3,
      n032,
      _NC,
      0,
      [_TCo, _QCu, _LFCa, _EBC],
      [[() => TopicConfigurationList, { [_xF]: 1, [_xN]: _TCop }], [() => QueueConfigurationList, { [_xF]: 1, [_xN]: _QCue }], [() => LambdaFunctionConfigurationList, { [_xF]: 1, [_xN]: _CFC }], () => exports2.EventBridgeConfiguration$]
    ];
    exports2.NotificationConfigurationFilter$ = [
      3,
      n032,
      _NCF,
      0,
      [_K10],
      [[() => exports2.S3KeyFilter$, { [_xN]: _SKe }]]
    ];
    exports2._Object$ = [
      3,
      n032,
      _Obj,
      0,
      [_K10, _LM2, _ETa, _CA10, _CT4, _Si, _SC, _O, _RSe],
      [0, 4, 0, [64 | 0, { [_xF]: 1 }], 0, 1, 0, () => exports2.Owner$, () => exports2.RestoreStatus$]
    ];
    exports2.ObjectIdentifier$ = [
      3,
      n032,
      _OI,
      0,
      [_K10, _VI, _ETa, _LMT, _Si],
      [0, 0, 0, 6, 1],
      1
    ];
    exports2.ObjectLockConfiguration$ = [
      3,
      n032,
      _OLC,
      0,
      [_OLE, _Ru],
      [0, () => exports2.ObjectLockRule$]
    ];
    exports2.ObjectLockLegalHold$ = [
      3,
      n032,
      _OLLH,
      0,
      [_S],
      [0]
    ];
    exports2.ObjectLockRetention$ = [
      3,
      n032,
      _OLR,
      0,
      [_Mo, _RUD],
      [0, 5]
    ];
    exports2.ObjectLockRule$ = [
      3,
      n032,
      _OLRb,
      0,
      [_DRe],
      [() => exports2.DefaultRetention$]
    ];
    exports2.ObjectPart$ = [
      3,
      n032,
      _OPb,
      0,
      [_PN, _Si, _CCRC, _CCRCC, _CCRCNVME, _CSHA, _CSHAh, _CSHAhe, _CMD, _CXXHASH, _CXXHASHh, _CXXHASHhe],
      [1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]
    ];
    exports2.ObjectVersion$ = [
      3,
      n032,
      _OV,
      0,
      [_ETa, _CA10, _CT4, _Si, _SC, _K10, _VI, _IL, _LM2, _O, _RSe],
      [0, [64 | 0, { [_xF]: 1 }], 0, 1, 0, 0, 0, 2, 4, () => exports2.Owner$, () => exports2.RestoreStatus$]
    ];
    exports2.OutputLocation$ = [
      3,
      n032,
      _OL,
      0,
      [_S_],
      [[() => exports2.S3Location$, 0]]
    ];
    exports2.OutputSerialization$ = [
      3,
      n032,
      _OSu,
      0,
      [_CSV, _JSON],
      [() => exports2.CSVOutput$, () => exports2.JSONOutput$]
    ];
    exports2.Owner$ = [
      3,
      n032,
      _O,
      0,
      [_DN, _ID],
      [0, 0]
    ];
    exports2.OwnershipControls$ = [
      3,
      n032,
      _OC,
      0,
      [_R],
      [[() => OwnershipControlsRules, { [_xF]: 1, [_xN]: _Ru }]],
      1
    ];
    exports2.OwnershipControlsRule$ = [
      3,
      n032,
      _OCR,
      0,
      [_OO],
      [0],
      1
    ];
    exports2.ParquetInput$ = [
      3,
      n032,
      _PI10,
      0,
      [],
      []
    ];
    exports2.Part$ = [
      3,
      n032,
      _Par,
      0,
      [_PN, _LM2, _ETa, _Si, _CCRC, _CCRCC, _CCRCNVME, _CSHA, _CSHAh, _CSHAhe, _CMD, _CXXHASH, _CXXHASHh, _CXXHASHhe],
      [1, 4, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]
    ];
    exports2.PartitionedPrefix$ = [
      3,
      n032,
      _PP,
      { [_xN]: _PP },
      [_PDS],
      [0]
    ];
    exports2.PolicyStatus$ = [
      3,
      n032,
      _PS,
      0,
      [_IP],
      [[2, { [_xN]: _IP }]]
    ];
    exports2.Progress$ = [
      3,
      n032,
      _Pr10,
      0,
      [_BS, _BP, _BRy],
      [1, 1, 1]
    ];
    exports2.ProgressEvent$ = [
      3,
      n032,
      _PE,
      0,
      [_Det],
      [[() => exports2.Progress$, { [_eP]: 1 }]]
    ];
    exports2.PublicAccessBlockConfiguration$ = [
      3,
      n032,
      _PABC,
      0,
      [_BPA, _IPA, _BPP, _RPB],
      [[2, { [_xN]: _BPA }], [2, { [_xN]: _IPA }], [2, { [_xN]: _BPP }], [2, { [_xN]: _RPB }]]
    ];
    exports2.PutBucketAbacRequest$ = [
      3,
      n032,
      _PBAR,
      0,
      [_B, _AS, _CMDo, _CA10, _EBO],
      [[0, 1], [() => exports2.AbacStatus$, { [_hP]: 1, [_xN]: _AS }], [0, { [_hH10]: _CM }], [0, { [_hH10]: _xasca }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.PutBucketAccelerateConfigurationRequest$ = [
      3,
      n032,
      _PBACR,
      0,
      [_B, _AC, _EBO, _CA10],
      [[0, 1], [() => exports2.AccelerateConfiguration$, { [_hP]: 1, [_xN]: _AC }], [0, { [_hH10]: _xaebo }], [0, { [_hH10]: _xasca }]],
      2
    ];
    exports2.PutBucketAclRequest$ = [
      3,
      n032,
      _PBARu,
      0,
      [_B, _ACL_, _ACP, _CMDo, _CA10, _GFC, _GR, _GRACP, _GW, _GWACP, _EBO],
      [[0, 1], [0, { [_hH10]: _xaa }], [() => exports2.AccessControlPolicy$, { [_hP]: 1, [_xN]: _ACP }], [0, { [_hH10]: _CM }], [0, { [_hH10]: _xasca }], [0, { [_hH10]: _xagfc }], [0, { [_hH10]: _xagr }], [0, { [_hH10]: _xagra }], [0, { [_hH10]: _xagw }], [0, { [_hH10]: _xagwa }], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.PutBucketAnalyticsConfigurationRequest$ = [
      3,
      n032,
      _PBACRu,
      0,
      [_B, _I, _ACn, _EBO],
      [[0, 1], [0, { [_hQ10]: _i }], [() => exports2.AnalyticsConfiguration$, { [_hP]: 1, [_xN]: _ACn }], [0, { [_hH10]: _xaebo }]],
      3
    ];
    exports2.PutBucketCorsRequest$ = [
      3,
      n032,
      _PBCR,
      0,
      [_B, _CORSC, _CMDo, _CA10, _EBO],
      [[0, 1], [() => exports2.CORSConfiguration$, { [_hP]: 1, [_xN]: _CORSC }], [0, { [_hH10]: _CM }], [0, { [_hH10]: _xasca }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.PutBucketEncryptionRequest$ = [
      3,
      n032,
      _PBER,
      0,
      [_B, _SSEC, _CMDo, _CA10, _EBO],
      [[0, 1], [() => exports2.ServerSideEncryptionConfiguration$, { [_hP]: 1, [_xN]: _SSEC }], [0, { [_hH10]: _CM }], [0, { [_hH10]: _xasca }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.PutBucketIntelligentTieringConfigurationRequest$ = [
      3,
      n032,
      _PBITCR,
      0,
      [_B, _I, _ITC, _EBO],
      [[0, 1], [0, { [_hQ10]: _i }], [() => exports2.IntelligentTieringConfiguration$, { [_hP]: 1, [_xN]: _ITC }], [0, { [_hH10]: _xaebo }]],
      3
    ];
    exports2.PutBucketInventoryConfigurationRequest$ = [
      3,
      n032,
      _PBICR,
      0,
      [_B, _I, _IC, _EBO],
      [[0, 1], [0, { [_hQ10]: _i }], [() => exports2.InventoryConfiguration$, { [_hP]: 1, [_xN]: _IC }], [0, { [_hH10]: _xaebo }]],
      3
    ];
    exports2.PutBucketLifecycleConfigurationOutput$ = [
      3,
      n032,
      _PBLCO,
      0,
      [_TDMOS],
      [[0, { [_hH10]: _xatdmos }]]
    ];
    exports2.PutBucketLifecycleConfigurationRequest$ = [
      3,
      n032,
      _PBLCR,
      0,
      [_B, _CA10, _LCi, _EBO, _TDMOS],
      [[0, 1], [0, { [_hH10]: _xasca }], [() => exports2.BucketLifecycleConfiguration$, { [_hP]: 1, [_xN]: _LCi }], [0, { [_hH10]: _xaebo }], [0, { [_hH10]: _xatdmos }]],
      1
    ];
    exports2.PutBucketLoggingRequest$ = [
      3,
      n032,
      _PBLR,
      0,
      [_B, _BLS, _CMDo, _CA10, _EBO],
      [[0, 1], [() => exports2.BucketLoggingStatus$, { [_hP]: 1, [_xN]: _BLS }], [0, { [_hH10]: _CM }], [0, { [_hH10]: _xasca }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.PutBucketMetricsConfigurationRequest$ = [
      3,
      n032,
      _PBMCR,
      0,
      [_B, _I, _MCe, _EBO],
      [[0, 1], [0, { [_hQ10]: _i }], [() => exports2.MetricsConfiguration$, { [_hP]: 1, [_xN]: _MCe }], [0, { [_hH10]: _xaebo }]],
      3
    ];
    exports2.PutBucketNotificationConfigurationRequest$ = [
      3,
      n032,
      _PBNCR,
      0,
      [_B, _NC, _EBO, _SDV],
      [[0, 1], [() => exports2.NotificationConfiguration$, { [_hP]: 1, [_xN]: _NC }], [0, { [_hH10]: _xaebo }], [2, { [_hH10]: _xasdv }]],
      2
    ];
    exports2.PutBucketOwnershipControlsRequest$ = [
      3,
      n032,
      _PBOCR,
      0,
      [_B, _OC, _CMDo, _EBO, _CA10],
      [[0, 1], [() => exports2.OwnershipControls$, { [_hP]: 1, [_xN]: _OC }], [0, { [_hH10]: _CM }], [0, { [_hH10]: _xaebo }], [0, { [_hH10]: _xasca }]],
      2
    ];
    exports2.PutBucketPolicyRequest$ = [
      3,
      n032,
      _PBPR,
      0,
      [_B, _Po, _CMDo, _CA10, _CRSBA, _EBO],
      [[0, 1], [0, 16], [0, { [_hH10]: _CM }], [0, { [_hH10]: _xasca }], [2, { [_hH10]: _xacrsba }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.PutBucketReplicationRequest$ = [
      3,
      n032,
      _PBRR,
      0,
      [_B, _RCe, _CMDo, _CA10, _To, _EBO],
      [[0, 1], [() => exports2.ReplicationConfiguration$, { [_hP]: 1, [_xN]: _RCe }], [0, { [_hH10]: _CM }], [0, { [_hH10]: _xasca }], [0, { [_hH10]: _xabolt }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.PutBucketRequestPaymentRequest$ = [
      3,
      n032,
      _PBRPR,
      0,
      [_B, _RPC, _CMDo, _CA10, _EBO],
      [[0, 1], [() => exports2.RequestPaymentConfiguration$, { [_hP]: 1, [_xN]: _RPC }], [0, { [_hH10]: _CM }], [0, { [_hH10]: _xasca }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.PutBucketTaggingRequest$ = [
      3,
      n032,
      _PBTR,
      0,
      [_B, _Tag, _CMDo, _CA10, _EBO],
      [[0, 1], [() => exports2.Tagging$, { [_hP]: 1, [_xN]: _Tag }], [0, { [_hH10]: _CM }], [0, { [_hH10]: _xasca }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.PutBucketVersioningRequest$ = [
      3,
      n032,
      _PBVR,
      0,
      [_B, _VC, _CMDo, _CA10, _MFA, _EBO],
      [[0, 1], [() => exports2.VersioningConfiguration$, { [_hP]: 1, [_xN]: _VC }], [0, { [_hH10]: _CM }], [0, { [_hH10]: _xasca }], [0, { [_hH10]: _xam_ }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.PutBucketWebsiteRequest$ = [
      3,
      n032,
      _PBWR,
      0,
      [_B, _WC, _CMDo, _CA10, _EBO],
      [[0, 1], [() => exports2.WebsiteConfiguration$, { [_hP]: 1, [_xN]: _WC }], [0, { [_hH10]: _CM }], [0, { [_hH10]: _xasca }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.PutObjectAclOutput$ = [
      3,
      n032,
      _POAO,
      0,
      [_RC10],
      [[0, { [_hH10]: _xarc }]]
    ];
    exports2.PutObjectAclRequest$ = [
      3,
      n032,
      _POAR,
      0,
      [_B, _K10, _ACL_, _ACP, _CMDo, _CA10, _GFC, _GR, _GRACP, _GW, _GWACP, _RP, _VI, _EBO],
      [[0, 1], [0, 1], [0, { [_hH10]: _xaa }], [() => exports2.AccessControlPolicy$, { [_hP]: 1, [_xN]: _ACP }], [0, { [_hH10]: _CM }], [0, { [_hH10]: _xasca }], [0, { [_hH10]: _xagfc }], [0, { [_hH10]: _xagr }], [0, { [_hH10]: _xagra }], [0, { [_hH10]: _xagw }], [0, { [_hH10]: _xagwa }], [0, { [_hH10]: _xarp }], [0, { [_hQ10]: _vI }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.PutObjectLegalHoldOutput$ = [
      3,
      n032,
      _POLHO,
      0,
      [_RC10],
      [[0, { [_hH10]: _xarc }]]
    ];
    exports2.PutObjectLegalHoldRequest$ = [
      3,
      n032,
      _POLHR,
      0,
      [_B, _K10, _LH, _RP, _VI, _CMDo, _CA10, _EBO],
      [[0, 1], [0, 1], [() => exports2.ObjectLockLegalHold$, { [_hP]: 1, [_xN]: _LH }], [0, { [_hH10]: _xarp }], [0, { [_hQ10]: _vI }], [0, { [_hH10]: _CM }], [0, { [_hH10]: _xasca }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.PutObjectLockConfigurationOutput$ = [
      3,
      n032,
      _POLCO,
      0,
      [_RC10],
      [[0, { [_hH10]: _xarc }]]
    ];
    exports2.PutObjectLockConfigurationRequest$ = [
      3,
      n032,
      _POLCR,
      0,
      [_B, _OLC, _RP, _To, _CMDo, _CA10, _EBO],
      [[0, 1], [() => exports2.ObjectLockConfiguration$, { [_hP]: 1, [_xN]: _OLC }], [0, { [_hH10]: _xarp }], [0, { [_hH10]: _xabolt }], [0, { [_hH10]: _CM }], [0, { [_hH10]: _xasca }], [0, { [_hH10]: _xaebo }]],
      1
    ];
    exports2.PutObjectOutput$ = [
      3,
      n032,
      _POO,
      0,
      [_E11, _ETa, _CCRC, _CCRCC, _CCRCNVME, _CSHA, _CSHAh, _CSHAhe, _CMD, _CXXHASH, _CXXHASHh, _CXXHASHhe, _CT4, _SSE, _VI, _SSECA, _SSECKMD, _SSEKMSKI, _SSEKMSEC, _BKE, _Si, _RC10],
      [[0, { [_hH10]: _xae }], [0, { [_hH10]: _ETa }], [0, { [_hH10]: _xacc }], [0, { [_hH10]: _xacc_ }], [0, { [_hH10]: _xacc__ }], [0, { [_hH10]: _xacs }], [0, { [_hH10]: _xacs_ }], [0, { [_hH10]: _xacs__ }], [0, { [_hH10]: _xacm }], [0, { [_hH10]: _xacx }], [0, { [_hH10]: _xacx_ }], [0, { [_hH10]: _xacx__ }], [0, { [_hH10]: _xact }], [0, { [_hH10]: _xasse }], [0, { [_hH10]: _xavi }], [0, { [_hH10]: _xasseca }], [0, { [_hH10]: _xasseckM }], [() => SSEKMSKeyId, { [_hH10]: _xasseakki }], [() => SSEKMSEncryptionContext, { [_hH10]: _xassec }], [2, { [_hH10]: _xassebke }], [1, { [_hH10]: _xaos }], [0, { [_hH10]: _xarc }]]
    ];
    exports2.PutObjectRequest$ = [
      3,
      n032,
      _POR,
      0,
      [_B, _K10, _ACL_, _Bo, _CC, _CDo, _CEo, _CL, _CLo, _CMDo, _CTo, _CA10, _CCRC, _CCRCC, _CCRCNVME, _CSHA, _CSHAh, _CSHAhe, _CMD, _CXXHASH, _CXXHASHh, _CXXHASHhe, _Ex, _IM, _INM, _GFC, _GR, _GRACP, _GWACP, _WOB, _M, _SSE, _SC, _WRL, _SSECA, _SSECK, _SSECKMD, _SSEKMSKI, _SSEKMSEC, _BKE, _RP, _Tag, _OLM, _OLRUD, _OLLHS, _EBO],
      [[0, 1], [0, 1], [0, { [_hH10]: _xaa }], [() => StreamingBlob, 16], [0, { [_hH10]: _CC_ }], [0, { [_hH10]: _CD_ }], [0, { [_hH10]: _CE_ }], [0, { [_hH10]: _CL_ }], [1, { [_hH10]: _CL__ }], [0, { [_hH10]: _CM }], [0, { [_hH10]: _CT_ }], [0, { [_hH10]: _xasca }], [0, { [_hH10]: _xacc }], [0, { [_hH10]: _xacc_ }], [0, { [_hH10]: _xacc__ }], [0, { [_hH10]: _xacs }], [0, { [_hH10]: _xacs_ }], [0, { [_hH10]: _xacs__ }], [0, { [_hH10]: _xacm }], [0, { [_hH10]: _xacx }], [0, { [_hH10]: _xacx_ }], [0, { [_hH10]: _xacx__ }], [4, { [_hH10]: _Ex }], [0, { [_hH10]: _IM_ }], [0, { [_hH10]: _INM_ }], [0, { [_hH10]: _xagfc }], [0, { [_hH10]: _xagr }], [0, { [_hH10]: _xagra }], [0, { [_hH10]: _xagwa }], [1, { [_hH10]: _xawob }], [128 | 0, { [_hPH]: _xam }], [0, { [_hH10]: _xasse }], [0, { [_hH10]: _xasc }], [0, { [_hH10]: _xawrl }], [0, { [_hH10]: _xasseca }], [() => SSECustomerKey, { [_hH10]: _xasseck }], [0, { [_hH10]: _xasseckM }], [() => SSEKMSKeyId, { [_hH10]: _xasseakki }], [() => SSEKMSEncryptionContext, { [_hH10]: _xassec }], [2, { [_hH10]: _xassebke }], [0, { [_hH10]: _xarp }], [0, { [_hH10]: _xat }], [0, { [_hH10]: _xaolm }], [5, { [_hH10]: _xaolrud }], [0, { [_hH10]: _xaollh }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.PutObjectRetentionOutput$ = [
      3,
      n032,
      _PORO,
      0,
      [_RC10],
      [[0, { [_hH10]: _xarc }]]
    ];
    exports2.PutObjectRetentionRequest$ = [
      3,
      n032,
      _PORR,
      0,
      [_B, _K10, _Ret, _RP, _VI, _BGR, _CMDo, _CA10, _EBO],
      [[0, 1], [0, 1], [() => exports2.ObjectLockRetention$, { [_hP]: 1, [_xN]: _Ret }], [0, { [_hH10]: _xarp }], [0, { [_hQ10]: _vI }], [2, { [_hH10]: _xabgr }], [0, { [_hH10]: _CM }], [0, { [_hH10]: _xasca }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.PutObjectTaggingOutput$ = [
      3,
      n032,
      _POTO,
      0,
      [_VI],
      [[0, { [_hH10]: _xavi }]]
    ];
    exports2.PutObjectTaggingRequest$ = [
      3,
      n032,
      _POTR,
      0,
      [_B, _K10, _Tag, _VI, _CMDo, _CA10, _EBO, _RP],
      [[0, 1], [0, 1], [() => exports2.Tagging$, { [_hP]: 1, [_xN]: _Tag }], [0, { [_hQ10]: _vI }], [0, { [_hH10]: _CM }], [0, { [_hH10]: _xasca }], [0, { [_hH10]: _xaebo }], [0, { [_hH10]: _xarp }]],
      3
    ];
    exports2.PutPublicAccessBlockRequest$ = [
      3,
      n032,
      _PPABR,
      0,
      [_B, _PABC, _CMDo, _CA10, _EBO],
      [[0, 1], [() => exports2.PublicAccessBlockConfiguration$, { [_hP]: 1, [_xN]: _PABC }], [0, { [_hH10]: _CM }], [0, { [_hH10]: _xasca }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.QueueConfiguration$ = [
      3,
      n032,
      _QCue,
      0,
      [_QA, _Ev, _I, _F],
      [[0, { [_xN]: _Qu }], [64 | 0, { [_xF]: 1, [_xN]: _Eve }], 0, [() => exports2.NotificationConfigurationFilter$, 0]],
      2
    ];
    exports2.RecordExpiration$ = [
      3,
      n032,
      _REe,
      0,
      [_E11, _D],
      [0, 1],
      1
    ];
    exports2.RecordsEvent$ = [
      3,
      n032,
      _REec,
      0,
      [_Payl],
      [[21, { [_eP]: 1 }]]
    ];
    exports2.Redirect$ = [
      3,
      n032,
      _Red,
      0,
      [_HN, _HRC, _Pro, _RKPW, _RKW],
      [0, 0, 0, 0, 0]
    ];
    exports2.RedirectAllRequestsTo$ = [
      3,
      n032,
      _RART,
      0,
      [_HN, _Pro],
      [0, 0],
      1
    ];
    exports2.RenameObjectOutput$ = [
      3,
      n032,
      _ROO,
      0,
      [],
      []
    ];
    exports2.RenameObjectRequest$ = [
      3,
      n032,
      _ROR,
      0,
      [_B, _K10, _RSen, _DIM, _DINM, _DIMS, _DIUS, _SIM, _SINM, _SIMS, _SIUS, _CTl],
      [[0, 1], [0, 1], [0, { [_hH10]: _xars_ }], [0, { [_hH10]: _IM_ }], [0, { [_hH10]: _INM_ }], [4, { [_hH10]: _IMS_ }], [4, { [_hH10]: _IUS_ }], [0, { [_hH10]: _xarsim }], [0, { [_hH10]: _xarsinm }], [6, { [_hH10]: _xarsims }], [6, { [_hH10]: _xarsius }], [0, { [_hH10]: _xact_, [_iT13]: 1 }]],
      3
    ];
    exports2.ReplicaModifications$ = [
      3,
      n032,
      _RM,
      0,
      [_S],
      [0],
      1
    ];
    exports2.ReplicationConfiguration$ = [
      3,
      n032,
      _RCe,
      0,
      [_Ro, _R],
      [0, [() => ReplicationRules, { [_xF]: 1, [_xN]: _Ru }]],
      2
    ];
    exports2.ReplicationRule$ = [
      3,
      n032,
      _RRe,
      0,
      [_S, _Des, _ID, _Pri, _P10, _F, _SSC, _EOR, _DMR],
      [0, () => exports2.Destination$, 0, 1, 0, [() => exports2.ReplicationRuleFilter$, 0], () => exports2.SourceSelectionCriteria$, () => exports2.ExistingObjectReplication$, () => exports2.DeleteMarkerReplication$],
      2
    ];
    exports2.ReplicationRuleAndOperator$ = [
      3,
      n032,
      _RRAO,
      0,
      [_P10, _T10],
      [0, [() => TagSet, { [_xF]: 1, [_xN]: _Ta10 }]]
    ];
    exports2.ReplicationRuleFilter$ = [
      3,
      n032,
      _RRF,
      0,
      [_P10, _Ta10, _An],
      [0, () => exports2.Tag$, [() => exports2.ReplicationRuleAndOperator$, 0]]
    ];
    exports2.ReplicationTime$ = [
      3,
      n032,
      _RT13,
      0,
      [_S, _Tim],
      [0, () => exports2.ReplicationTimeValue$],
      2
    ];
    exports2.ReplicationTimeValue$ = [
      3,
      n032,
      _RTV,
      0,
      [_Mi],
      [1]
    ];
    exports2.RequestPaymentConfiguration$ = [
      3,
      n032,
      _RPC,
      0,
      [_Pay],
      [0],
      1
    ];
    exports2.RequestProgress$ = [
      3,
      n032,
      _RPe,
      0,
      [_Ena],
      [2]
    ];
    exports2.RestoreObjectOutput$ = [
      3,
      n032,
      _ROOe,
      0,
      [_RC10, _ROP],
      [[0, { [_hH10]: _xarc }], [0, { [_hH10]: _xarop }]]
    ];
    exports2.RestoreObjectRequest$ = [
      3,
      n032,
      _RORe,
      0,
      [_B, _K10, _VI, _RRes, _RP, _CA10, _EBO],
      [[0, 1], [0, 1], [0, { [_hQ10]: _vI }], [() => exports2.RestoreRequest$, { [_hP]: 1, [_xN]: _RRes }], [0, { [_hH10]: _xarp }], [0, { [_hH10]: _xasca }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.RestoreRequest$ = [
      3,
      n032,
      _RRes,
      0,
      [_D, _GJP, _Ty, _Ti, _Desc, _SP, _OL],
      [1, () => exports2.GlacierJobParameters$, 0, 0, 0, () => exports2.SelectParameters$, [() => exports2.OutputLocation$, 0]]
    ];
    exports2.RestoreStatus$ = [
      3,
      n032,
      _RSe,
      0,
      [_IRIP, _RED],
      [2, 4]
    ];
    exports2.RoutingRule$ = [
      3,
      n032,
      _RRo,
      0,
      [_Red, _Co],
      [() => exports2.Redirect$, () => exports2.Condition$],
      1
    ];
    exports2.S3KeyFilter$ = [
      3,
      n032,
      _SKF,
      0,
      [_FRi],
      [[() => FilterRuleList, { [_xF]: 1, [_xN]: _FR }]]
    ];
    exports2.S3Location$ = [
      3,
      n032,
      _SL,
      0,
      [_BNu, _P10, _En, _CACL, _ACL, _Tag, _UM, _SC],
      [0, 0, [() => exports2.Encryption$, 0], 0, [() => Grants, 0], [() => exports2.Tagging$, 0], [() => UserMetadata, 0], 0],
      2
    ];
    exports2.S3TablesDestination$ = [
      3,
      n032,
      _STD,
      0,
      [_TBA, _TNa],
      [0, 0],
      2
    ];
    exports2.S3TablesDestinationResult$ = [
      3,
      n032,
      _STDR,
      0,
      [_TBA, _TNa, _TA, _TN],
      [0, 0, 0, 0],
      4
    ];
    exports2.ScanRange$ = [
      3,
      n032,
      _SR,
      0,
      [_St, _End],
      [1, 1]
    ];
    exports2.SelectObjectContentOutput$ = [
      3,
      n032,
      _SOCO,
      0,
      [_Payl],
      [[() => exports2.SelectObjectContentEventStream$, 16]]
    ];
    exports2.SelectObjectContentRequest$ = [
      3,
      n032,
      _SOCR,
      0,
      [_B, _K10, _Exp, _ETx, _IS, _OSu, _SSECA, _SSECK, _SSECKMD, _RPe, _SR, _EBO],
      [[0, 1], [0, 1], 0, 0, () => exports2.InputSerialization$, () => exports2.OutputSerialization$, [0, { [_hH10]: _xasseca }], [() => SSECustomerKey, { [_hH10]: _xasseck }], [0, { [_hH10]: _xasseckM }], () => exports2.RequestProgress$, () => exports2.ScanRange$, [0, { [_hH10]: _xaebo }]],
      6
    ];
    exports2.SelectParameters$ = [
      3,
      n032,
      _SP,
      0,
      [_IS, _ETx, _Exp, _OSu],
      [() => exports2.InputSerialization$, 0, 0, () => exports2.OutputSerialization$],
      4
    ];
    exports2.ServerSideEncryptionByDefault$ = [
      3,
      n032,
      _SSEBD,
      0,
      [_SSEA, _KMSMKID],
      [0, [() => SSEKMSKeyId, 0]],
      1
    ];
    exports2.ServerSideEncryptionConfiguration$ = [
      3,
      n032,
      _SSEC,
      0,
      [_R],
      [[() => ServerSideEncryptionRules, { [_xF]: 1, [_xN]: _Ru }]],
      1
    ];
    exports2.ServerSideEncryptionRule$ = [
      3,
      n032,
      _SSER,
      0,
      [_ASSEBD, _BKE, _BET],
      [[() => exports2.ServerSideEncryptionByDefault$, 0], 2, [() => exports2.BlockedEncryptionTypes$, 0]]
    ];
    exports2.SessionCredentials$ = [
      3,
      n032,
      _SCe,
      0,
      [_AKI11, _SAK10, _ST11, _E11],
      [[0, { [_xN]: _AKI11 }], [() => SessionCredentialValue, { [_xN]: _SAK10 }], [() => SessionCredentialValue, { [_xN]: _ST11 }], [4, { [_xN]: _E11 }]],
      4
    ];
    exports2.SimplePrefix$ = [
      3,
      n032,
      _SPi,
      { [_xN]: _SPi },
      [],
      []
    ];
    exports2.SourceSelectionCriteria$ = [
      3,
      n032,
      _SSC,
      0,
      [_SKEO, _RM],
      [() => exports2.SseKmsEncryptedObjects$, () => exports2.ReplicaModifications$]
    ];
    exports2.SSEKMS$ = [
      3,
      n032,
      _SSEKMS,
      { [_xN]: _SK2 },
      [_KI],
      [[() => SSEKMSKeyId, 0]],
      1
    ];
    exports2.SseKmsEncryptedObjects$ = [
      3,
      n032,
      _SKEO,
      0,
      [_S],
      [0],
      1
    ];
    exports2.SSEKMSEncryption$ = [
      3,
      n032,
      _SSEKMSE,
      { [_xN]: _SK2 },
      [_KMSKA, _BKE],
      [[() => NonEmptyKmsKeyArnString, 0], 2],
      1
    ];
    exports2.SSES3$ = [
      3,
      n032,
      _SSES,
      { [_xN]: _SS },
      [],
      []
    ];
    exports2.Stats$ = [
      3,
      n032,
      _Sta,
      0,
      [_BS, _BP, _BRy],
      [1, 1, 1]
    ];
    exports2.StatsEvent$ = [
      3,
      n032,
      _SE,
      0,
      [_Det],
      [[() => exports2.Stats$, { [_eP]: 1 }]]
    ];
    exports2.StorageClassAnalysis$ = [
      3,
      n032,
      _SCA,
      0,
      [_DE],
      [() => exports2.StorageClassAnalysisDataExport$]
    ];
    exports2.StorageClassAnalysisDataExport$ = [
      3,
      n032,
      _SCADE,
      0,
      [_OSV, _Des],
      [0, () => exports2.AnalyticsExportDestination$],
      2
    ];
    exports2.Tag$ = [
      3,
      n032,
      _Ta10,
      0,
      [_K10, _V10],
      [0, 0],
      2
    ];
    exports2.Tagging$ = [
      3,
      n032,
      _Tag,
      0,
      [_TS],
      [[() => TagSet, 0]],
      1
    ];
    exports2.TargetGrant$ = [
      3,
      n032,
      _TGa,
      0,
      [_Gra, _Pe],
      [[() => exports2.Grantee$, { [_xNm]: [_x, _hi] }], 0]
    ];
    exports2.TargetObjectKeyFormat$ = [
      3,
      n032,
      _TOKF,
      0,
      [_SPi, _PP],
      [[() => exports2.SimplePrefix$, { [_xN]: _SPi }], [() => exports2.PartitionedPrefix$, { [_xN]: _PP }]]
    ];
    exports2.Tiering$ = [
      3,
      n032,
      _Tier,
      0,
      [_D, _AT13],
      [1, 0],
      2
    ];
    exports2.TopicConfiguration$ = [
      3,
      n032,
      _TCop,
      0,
      [_TAo, _Ev, _I, _F],
      [[0, { [_xN]: _Top }], [64 | 0, { [_xF]: 1, [_xN]: _Eve }], 0, [() => exports2.NotificationConfigurationFilter$, 0]],
      2
    ];
    exports2.Transition$ = [
      3,
      n032,
      _Tra,
      0,
      [_Da, _D, _SC],
      [5, 1, 0]
    ];
    exports2.UpdateBucketMetadataInventoryTableConfigurationRequest$ = [
      3,
      n032,
      _UBMITCR,
      0,
      [_B, _ITCn, _CMDo, _CA10, _EBO],
      [[0, 1], [() => exports2.InventoryTableConfigurationUpdates$, { [_hP]: 1, [_xN]: _ITCn }], [0, { [_hH10]: _CM }], [0, { [_hH10]: _xasca }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.UpdateBucketMetadataJournalTableConfigurationRequest$ = [
      3,
      n032,
      _UBMJTCR,
      0,
      [_B, _JTC, _CMDo, _CA10, _EBO],
      [[0, 1], [() => exports2.JournalTableConfigurationUpdates$, { [_hP]: 1, [_xN]: _JTC }], [0, { [_hH10]: _CM }], [0, { [_hH10]: _xasca }], [0, { [_hH10]: _xaebo }]],
      2
    ];
    exports2.UpdateObjectEncryptionRequest$ = [
      3,
      n032,
      _UOER,
      0,
      [_B, _K10, _OE, _VI, _RP, _EBO, _CMDo, _CA10],
      [[0, 1], [0, 1], [() => exports2.ObjectEncryption$, 16], [0, { [_hQ10]: _vI }], [0, { [_hH10]: _xarp }], [0, { [_hH10]: _xaebo }], [0, { [_hH10]: _CM }], [0, { [_hH10]: _xasca }]],
      3
    ];
    exports2.UpdateObjectEncryptionResponse$ = [
      3,
      n032,
      _UOERp,
      0,
      [_RC10],
      [[0, { [_hH10]: _xarc }]]
    ];
    exports2.UploadPartCopyOutput$ = [
      3,
      n032,
      _UPCO,
      0,
      [_CSVI, _CPR, _SSE, _SSECA, _SSECKMD, _SSEKMSKI, _BKE, _RC10],
      [[0, { [_hH10]: _xacsvi }], [() => exports2.CopyPartResult$, 16], [0, { [_hH10]: _xasse }], [0, { [_hH10]: _xasseca }], [0, { [_hH10]: _xasseckM }], [() => SSEKMSKeyId, { [_hH10]: _xasseakki }], [2, { [_hH10]: _xassebke }], [0, { [_hH10]: _xarc }]]
    ];
    exports2.UploadPartCopyRequest$ = [
      3,
      n032,
      _UPCR,
      0,
      [_B, _CS4, _K10, _PN, _UI, _CSIM, _CSIMS, _CSINM, _CSIUS, _CSRo, _SSECA, _SSECK, _SSECKMD, _CSSSECA, _CSSSECK, _CSSSECKMD, _RP, _EBO, _ESBO],
      [[0, 1], [0, { [_hH10]: _xacs___ }], [0, 1], [1, { [_hQ10]: _pN }], [0, { [_hQ10]: _uI }], [0, { [_hH10]: _xacsim }], [4, { [_hH10]: _xacsims }], [0, { [_hH10]: _xacsinm }], [4, { [_hH10]: _xacsius }], [0, { [_hH10]: _xacsr }], [0, { [_hH10]: _xasseca }], [() => SSECustomerKey, { [_hH10]: _xasseck }], [0, { [_hH10]: _xasseckM }], [0, { [_hH10]: _xacssseca }], [() => CopySourceSSECustomerKey, { [_hH10]: _xacssseck }], [0, { [_hH10]: _xacssseckM }], [0, { [_hH10]: _xarp }], [0, { [_hH10]: _xaebo }], [0, { [_hH10]: _xasebo }]],
      5
    ];
    exports2.UploadPartOutput$ = [
      3,
      n032,
      _UPO,
      0,
      [_SSE, _ETa, _CCRC, _CCRCC, _CCRCNVME, _CSHA, _CSHAh, _CSHAhe, _CMD, _CXXHASH, _CXXHASHh, _CXXHASHhe, _SSECA, _SSECKMD, _SSEKMSKI, _BKE, _RC10],
      [[0, { [_hH10]: _xasse }], [0, { [_hH10]: _ETa }], [0, { [_hH10]: _xacc }], [0, { [_hH10]: _xacc_ }], [0, { [_hH10]: _xacc__ }], [0, { [_hH10]: _xacs }], [0, { [_hH10]: _xacs_ }], [0, { [_hH10]: _xacs__ }], [0, { [_hH10]: _xacm }], [0, { [_hH10]: _xacx }], [0, { [_hH10]: _xacx_ }], [0, { [_hH10]: _xacx__ }], [0, { [_hH10]: _xasseca }], [0, { [_hH10]: _xasseckM }], [() => SSEKMSKeyId, { [_hH10]: _xasseakki }], [2, { [_hH10]: _xassebke }], [0, { [_hH10]: _xarc }]]
    ];
    exports2.UploadPartRequest$ = [
      3,
      n032,
      _UPR,
      0,
      [_B, _K10, _PN, _UI, _Bo, _CLo, _CMDo, _CA10, _CCRC, _CCRCC, _CCRCNVME, _CSHA, _CSHAh, _CSHAhe, _CMD, _CXXHASH, _CXXHASHh, _CXXHASHhe, _SSECA, _SSECK, _SSECKMD, _RP, _EBO],
      [[0, 1], [0, 1], [1, { [_hQ10]: _pN }], [0, { [_hQ10]: _uI }], [() => StreamingBlob, 16], [1, { [_hH10]: _CL__ }], [0, { [_hH10]: _CM }], [0, { [_hH10]: _xasca }], [0, { [_hH10]: _xacc }], [0, { [_hH10]: _xacc_ }], [0, { [_hH10]: _xacc__ }], [0, { [_hH10]: _xacs }], [0, { [_hH10]: _xacs_ }], [0, { [_hH10]: _xacs__ }], [0, { [_hH10]: _xacm }], [0, { [_hH10]: _xacx }], [0, { [_hH10]: _xacx_ }], [0, { [_hH10]: _xacx__ }], [0, { [_hH10]: _xasseca }], [() => SSECustomerKey, { [_hH10]: _xasseck }], [0, { [_hH10]: _xasseckM }], [0, { [_hH10]: _xarp }], [0, { [_hH10]: _xaebo }]],
      4
    ];
    exports2.VersioningConfiguration$ = [
      3,
      n032,
      _VC,
      0,
      [_MFAD, _S],
      [[0, { [_xN]: _MDf }], 0]
    ];
    exports2.WebsiteConfiguration$ = [
      3,
      n032,
      _WC,
      0,
      [_EDr, _IDn, _RART, _RR],
      [() => exports2.ErrorDocument$, () => exports2.IndexDocument$, () => exports2.RedirectAllRequestsTo$, [() => RoutingRules, 0]]
    ];
    exports2.WriteGetObjectResponseRequest$ = [
      3,
      n032,
      _WGORR,
      0,
      [_RReq, _RTe, _Bo, _SCt, _ECr, _EM, _AR10, _CC, _CDo, _CEo, _CL, _CLo, _CR, _CTo, _CCRC, _CCRCC, _CCRCNVME, _CSHA, _CSHAh, _CSHAhe, _CMD, _CXXHASH, _CXXHASHh, _CXXHASHhe, _DM, _ETa, _Ex, _E11, _LM2, _MM, _M, _OLM, _OLLHS, _OLRUD, _PC10, _RS, _RC10, _Re, _SSE, _SSECA, _SSEKMSKI, _SSECKMD, _SC, _TC10, _VI, _BKE],
      [[0, { [_hL]: 1, [_hH10]: _xarr }], [0, { [_hH10]: _xart }], [() => StreamingBlob, 16], [1, { [_hH10]: _xafs }], [0, { [_hH10]: _xafec }], [0, { [_hH10]: _xafem }], [0, { [_hH10]: _xafhar }], [0, { [_hH10]: _xafhCC }], [0, { [_hH10]: _xafhCD }], [0, { [_hH10]: _xafhCE }], [0, { [_hH10]: _xafhCL }], [1, { [_hH10]: _CL__ }], [0, { [_hH10]: _xafhCR }], [0, { [_hH10]: _xafhCT }], [0, { [_hH10]: _xafhxacc }], [0, { [_hH10]: _xafhxacc_ }], [0, { [_hH10]: _xafhxacc__ }], [0, { [_hH10]: _xafhxacs }], [0, { [_hH10]: _xafhxacs_ }], [0, { [_hH10]: _xafhxacs__ }], [0, { [_hH10]: _xafhxacm }], [0, { [_hH10]: _xafhxacx }], [0, { [_hH10]: _xafhxacx_ }], [0, { [_hH10]: _xafhxacx__ }], [2, { [_hH10]: _xafhxadm }], [0, { [_hH10]: _xafhE }], [4, { [_hH10]: _xafhE_ }], [0, { [_hH10]: _xafhxae }], [4, { [_hH10]: _xafhLM }], [1, { [_hH10]: _xafhxamm }], [128 | 0, { [_hPH]: _xam }], [0, { [_hH10]: _xafhxaolm }], [0, { [_hH10]: _xafhxaollh }], [5, { [_hH10]: _xafhxaolrud }], [1, { [_hH10]: _xafhxampc }], [0, { [_hH10]: _xafhxars }], [0, { [_hH10]: _xafhxarc }], [0, { [_hH10]: _xafhxar }], [0, { [_hH10]: _xafhxasse }], [0, { [_hH10]: _xafhxasseca }], [() => SSEKMSKeyId, { [_hH10]: _xafhxasseakki }], [0, { [_hH10]: _xafhxasseckM }], [0, { [_hH10]: _xafhxasc }], [1, { [_hH10]: _xafhxatc }], [0, { [_hH10]: _xafhxavi }], [2, { [_hH10]: _xafhxassebke }]],
      2
    ];
    var __Unit = "unit";
    var AllowedHeaders = 64 | 0;
    var AllowedMethods = 64 | 0;
    var AllowedOrigins = 64 | 0;
    var AnalyticsConfigurationList = [
      1,
      n032,
      _ACLn,
      0,
      [
        () => exports2.AnalyticsConfiguration$,
        0
      ]
    ];
    var Buckets = [
      1,
      n032,
      _Bu,
      0,
      [
        () => exports2.Bucket$,
        { [_xN]: _B }
      ]
    ];
    var ChecksumAlgorithmList = 64 | 0;
    var CommonPrefixList = [
      1,
      n032,
      _CPL,
      0,
      () => exports2.CommonPrefix$
    ];
    var CompletedPartList = [
      1,
      n032,
      _CPLo,
      0,
      () => exports2.CompletedPart$
    ];
    var CORSRules = [
      1,
      n032,
      _CORSR,
      0,
      [
        () => exports2.CORSRule$,
        0
      ]
    ];
    var DeletedObjects = [
      1,
      n032,
      _DOe,
      0,
      () => exports2.DeletedObject$
    ];
    var DeleteMarkers = [
      1,
      n032,
      _DMe,
      0,
      () => exports2.DeleteMarkerEntry$
    ];
    var EncryptionTypeList = [
      1,
      n032,
      _ETL,
      0,
      [
        0,
        { [_xN]: _ET }
      ]
    ];
    var Errors = [
      1,
      n032,
      _Er,
      0,
      () => exports2._Error$
    ];
    var EventList = 64 | 0;
    var ExposeHeaders = 64 | 0;
    var FilterRuleList = [
      1,
      n032,
      _FRL,
      0,
      () => exports2.FilterRule$
    ];
    var Grants = [
      1,
      n032,
      _G,
      0,
      [
        () => exports2.Grant$,
        { [_xN]: _Gr }
      ]
    ];
    var IntelligentTieringConfigurationList = [
      1,
      n032,
      _ITCL,
      0,
      [
        () => exports2.IntelligentTieringConfiguration$,
        0
      ]
    ];
    var InventoryConfigurationList = [
      1,
      n032,
      _ICL,
      0,
      [
        () => exports2.InventoryConfiguration$,
        0
      ]
    ];
    var InventoryOptionalFields = [
      1,
      n032,
      _IOF,
      0,
      [
        0,
        { [_xN]: _Fi }
      ]
    ];
    var LambdaFunctionConfigurationList = [
      1,
      n032,
      _LFCL,
      0,
      [
        () => exports2.LambdaFunctionConfiguration$,
        0
      ]
    ];
    var LifecycleRules = [
      1,
      n032,
      _LRi,
      0,
      [
        () => exports2.LifecycleRule$,
        0
      ]
    ];
    var MetricsConfigurationList = [
      1,
      n032,
      _MCL,
      0,
      [
        () => exports2.MetricsConfiguration$,
        0
      ]
    ];
    var MultipartUploadList = [
      1,
      n032,
      _MUL,
      0,
      () => exports2.MultipartUpload$
    ];
    var NoncurrentVersionTransitionList = [
      1,
      n032,
      _NVTL,
      0,
      () => exports2.NoncurrentVersionTransition$
    ];
    var ObjectAttributesList = 64 | 0;
    var ObjectIdentifierList = [
      1,
      n032,
      _OIL,
      0,
      () => exports2.ObjectIdentifier$
    ];
    var ObjectList = [
      1,
      n032,
      _OLb,
      0,
      [
        () => exports2._Object$,
        0
      ]
    ];
    var ObjectVersionList = [
      1,
      n032,
      _OVL,
      0,
      [
        () => exports2.ObjectVersion$,
        0
      ]
    ];
    var OptionalObjectAttributesList = 64 | 0;
    var OwnershipControlsRules = [
      1,
      n032,
      _OCRw,
      0,
      () => exports2.OwnershipControlsRule$
    ];
    var Parts = [
      1,
      n032,
      _Pa,
      0,
      () => exports2.Part$
    ];
    var PartsList = [
      1,
      n032,
      _PL,
      0,
      () => exports2.ObjectPart$
    ];
    var QueueConfigurationList = [
      1,
      n032,
      _QCL,
      0,
      [
        () => exports2.QueueConfiguration$,
        0
      ]
    ];
    var ReplicationRules = [
      1,
      n032,
      _RRep,
      0,
      [
        () => exports2.ReplicationRule$,
        0
      ]
    ];
    var RoutingRules = [
      1,
      n032,
      _RR,
      0,
      [
        () => exports2.RoutingRule$,
        { [_xN]: _RRo }
      ]
    ];
    var ServerSideEncryptionRules = [
      1,
      n032,
      _SSERe,
      0,
      [
        () => exports2.ServerSideEncryptionRule$,
        0
      ]
    ];
    var TagSet = [
      1,
      n032,
      _TS,
      0,
      [
        () => exports2.Tag$,
        { [_xN]: _Ta10 }
      ]
    ];
    var TargetGrants = [
      1,
      n032,
      _TG,
      0,
      [
        () => exports2.TargetGrant$,
        { [_xN]: _Gr }
      ]
    ];
    var TieringList = [
      1,
      n032,
      _TL,
      0,
      () => exports2.Tiering$
    ];
    var TopicConfigurationList = [
      1,
      n032,
      _TCL,
      0,
      [
        () => exports2.TopicConfiguration$,
        0
      ]
    ];
    var TransitionList = [
      1,
      n032,
      _TLr,
      0,
      () => exports2.Transition$
    ];
    var UserMetadata = [
      1,
      n032,
      _UM,
      0,
      [
        () => exports2.MetadataEntry$,
        { [_xN]: _ME }
      ]
    ];
    var Metadata = 128 | 0;
    exports2.AnalyticsFilter$ = [
      4,
      n032,
      _AF,
      0,
      [_P10, _Ta10, _An],
      [0, () => exports2.Tag$, [() => exports2.AnalyticsAndOperator$, 0]]
    ];
    exports2.MetricsFilter$ = [
      4,
      n032,
      _MF,
      0,
      [_P10, _Ta10, _APAc, _An],
      [0, () => exports2.Tag$, 0, [() => exports2.MetricsAndOperator$, 0]]
    ];
    exports2.ObjectEncryption$ = [
      4,
      n032,
      _OE,
      0,
      [_SSEKMS],
      [[() => exports2.SSEKMSEncryption$, { [_xN]: _SK2 }]]
    ];
    exports2.SelectObjectContentEventStream$ = [
      4,
      n032,
      _SOCES,
      { [_st]: 1 },
      [_Rec, _Sta, _Pr10, _Cont, _End],
      [[() => exports2.RecordsEvent$, 0], [() => exports2.StatsEvent$, 0], [() => exports2.ProgressEvent$, 0], () => exports2.ContinuationEvent$, () => exports2.EndEvent$]
    ];
    exports2.AbortMultipartUpload$ = [
      9,
      n032,
      _AMU,
      { [_h22]: ["DELETE", "/{Key+}?x-id=AbortMultipartUpload", 204] },
      () => exports2.AbortMultipartUploadRequest$,
      () => exports2.AbortMultipartUploadOutput$
    ];
    exports2.CompleteMultipartUpload$ = [
      9,
      n032,
      _CMUo,
      { [_h22]: ["POST", "/{Key+}", 200] },
      () => exports2.CompleteMultipartUploadRequest$,
      () => exports2.CompleteMultipartUploadOutput$
    ];
    exports2.CopyObject$ = [
      9,
      n032,
      _CO,
      { [_h22]: ["PUT", "/{Key+}?x-id=CopyObject", 200] },
      () => exports2.CopyObjectRequest$,
      () => exports2.CopyObjectOutput$
    ];
    exports2.CreateBucket$ = [
      9,
      n032,
      _CB,
      { [_h22]: ["PUT", "/", 200] },
      () => exports2.CreateBucketRequest$,
      () => exports2.CreateBucketOutput$
    ];
    exports2.CreateBucketMetadataConfiguration$ = [
      9,
      n032,
      _CBMC,
      { [_hC]: "-", [_h22]: ["POST", "/?metadataConfiguration", 200] },
      () => exports2.CreateBucketMetadataConfigurationRequest$,
      () => __Unit
    ];
    exports2.CreateBucketMetadataTableConfiguration$ = [
      9,
      n032,
      _CBMTC,
      { [_hC]: "-", [_h22]: ["POST", "/?metadataTable", 200] },
      () => exports2.CreateBucketMetadataTableConfigurationRequest$,
      () => __Unit
    ];
    exports2.CreateMultipartUpload$ = [
      9,
      n032,
      _CMUr,
      { [_h22]: ["POST", "/{Key+}?uploads", 200] },
      () => exports2.CreateMultipartUploadRequest$,
      () => exports2.CreateMultipartUploadOutput$
    ];
    exports2.CreateSession$ = [
      9,
      n032,
      _CSr,
      { [_h22]: ["GET", "/?session", 200] },
      () => exports2.CreateSessionRequest$,
      () => exports2.CreateSessionOutput$
    ];
    exports2.DeleteBucket$ = [
      9,
      n032,
      _DB,
      { [_h22]: ["DELETE", "/", 204] },
      () => exports2.DeleteBucketRequest$,
      () => __Unit
    ];
    exports2.DeleteBucketAnalyticsConfiguration$ = [
      9,
      n032,
      _DBAC,
      { [_h22]: ["DELETE", "/?analytics", 204] },
      () => exports2.DeleteBucketAnalyticsConfigurationRequest$,
      () => __Unit
    ];
    exports2.DeleteBucketCors$ = [
      9,
      n032,
      _DBC,
      { [_h22]: ["DELETE", "/?cors", 204] },
      () => exports2.DeleteBucketCorsRequest$,
      () => __Unit
    ];
    exports2.DeleteBucketEncryption$ = [
      9,
      n032,
      _DBE,
      { [_h22]: ["DELETE", "/?encryption", 204] },
      () => exports2.DeleteBucketEncryptionRequest$,
      () => __Unit
    ];
    exports2.DeleteBucketIntelligentTieringConfiguration$ = [
      9,
      n032,
      _DBITC,
      { [_h22]: ["DELETE", "/?intelligent-tiering", 204] },
      () => exports2.DeleteBucketIntelligentTieringConfigurationRequest$,
      () => __Unit
    ];
    exports2.DeleteBucketInventoryConfiguration$ = [
      9,
      n032,
      _DBIC,
      { [_h22]: ["DELETE", "/?inventory", 204] },
      () => exports2.DeleteBucketInventoryConfigurationRequest$,
      () => __Unit
    ];
    exports2.DeleteBucketLifecycle$ = [
      9,
      n032,
      _DBL,
      { [_h22]: ["DELETE", "/?lifecycle", 204] },
      () => exports2.DeleteBucketLifecycleRequest$,
      () => __Unit
    ];
    exports2.DeleteBucketMetadataConfiguration$ = [
      9,
      n032,
      _DBMC,
      { [_h22]: ["DELETE", "/?metadataConfiguration", 204] },
      () => exports2.DeleteBucketMetadataConfigurationRequest$,
      () => __Unit
    ];
    exports2.DeleteBucketMetadataTableConfiguration$ = [
      9,
      n032,
      _DBMTC,
      { [_h22]: ["DELETE", "/?metadataTable", 204] },
      () => exports2.DeleteBucketMetadataTableConfigurationRequest$,
      () => __Unit
    ];
    exports2.DeleteBucketMetricsConfiguration$ = [
      9,
      n032,
      _DBMCe,
      { [_h22]: ["DELETE", "/?metrics", 204] },
      () => exports2.DeleteBucketMetricsConfigurationRequest$,
      () => __Unit
    ];
    exports2.DeleteBucketOwnershipControls$ = [
      9,
      n032,
      _DBOC,
      { [_h22]: ["DELETE", "/?ownershipControls", 204] },
      () => exports2.DeleteBucketOwnershipControlsRequest$,
      () => __Unit
    ];
    exports2.DeleteBucketPolicy$ = [
      9,
      n032,
      _DBP,
      { [_h22]: ["DELETE", "/?policy", 204] },
      () => exports2.DeleteBucketPolicyRequest$,
      () => __Unit
    ];
    exports2.DeleteBucketReplication$ = [
      9,
      n032,
      _DBRe,
      { [_h22]: ["DELETE", "/?replication", 204] },
      () => exports2.DeleteBucketReplicationRequest$,
      () => __Unit
    ];
    exports2.DeleteBucketTagging$ = [
      9,
      n032,
      _DBT,
      { [_h22]: ["DELETE", "/?tagging", 204] },
      () => exports2.DeleteBucketTaggingRequest$,
      () => __Unit
    ];
    exports2.DeleteBucketWebsite$ = [
      9,
      n032,
      _DBW,
      { [_h22]: ["DELETE", "/?website", 204] },
      () => exports2.DeleteBucketWebsiteRequest$,
      () => __Unit
    ];
    exports2.DeleteObject$ = [
      9,
      n032,
      _DOel,
      { [_h22]: ["DELETE", "/{Key+}?x-id=DeleteObject", 204] },
      () => exports2.DeleteObjectRequest$,
      () => exports2.DeleteObjectOutput$
    ];
    exports2.DeleteObjects$ = [
      9,
      n032,
      _DOele,
      { [_hC]: "-", [_h22]: ["POST", "/?delete", 200] },
      () => exports2.DeleteObjectsRequest$,
      () => exports2.DeleteObjectsOutput$
    ];
    exports2.DeleteObjectTagging$ = [
      9,
      n032,
      _DOT,
      { [_h22]: ["DELETE", "/{Key+}?tagging", 204] },
      () => exports2.DeleteObjectTaggingRequest$,
      () => exports2.DeleteObjectTaggingOutput$
    ];
    exports2.DeletePublicAccessBlock$ = [
      9,
      n032,
      _DPAB,
      { [_h22]: ["DELETE", "/?publicAccessBlock", 204] },
      () => exports2.DeletePublicAccessBlockRequest$,
      () => __Unit
    ];
    exports2.GetBucketAbac$ = [
      9,
      n032,
      _GBA,
      { [_h22]: ["GET", "/?abac", 200] },
      () => exports2.GetBucketAbacRequest$,
      () => exports2.GetBucketAbacOutput$
    ];
    exports2.GetBucketAccelerateConfiguration$ = [
      9,
      n032,
      _GBAC,
      { [_h22]: ["GET", "/?accelerate", 200] },
      () => exports2.GetBucketAccelerateConfigurationRequest$,
      () => exports2.GetBucketAccelerateConfigurationOutput$
    ];
    exports2.GetBucketAcl$ = [
      9,
      n032,
      _GBAe,
      { [_h22]: ["GET", "/?acl", 200] },
      () => exports2.GetBucketAclRequest$,
      () => exports2.GetBucketAclOutput$
    ];
    exports2.GetBucketAnalyticsConfiguration$ = [
      9,
      n032,
      _GBACe,
      { [_h22]: ["GET", "/?analytics&x-id=GetBucketAnalyticsConfiguration", 200] },
      () => exports2.GetBucketAnalyticsConfigurationRequest$,
      () => exports2.GetBucketAnalyticsConfigurationOutput$
    ];
    exports2.GetBucketCors$ = [
      9,
      n032,
      _GBC,
      { [_h22]: ["GET", "/?cors", 200] },
      () => exports2.GetBucketCorsRequest$,
      () => exports2.GetBucketCorsOutput$
    ];
    exports2.GetBucketEncryption$ = [
      9,
      n032,
      _GBE,
      { [_h22]: ["GET", "/?encryption", 200] },
      () => exports2.GetBucketEncryptionRequest$,
      () => exports2.GetBucketEncryptionOutput$
    ];
    exports2.GetBucketIntelligentTieringConfiguration$ = [
      9,
      n032,
      _GBITC,
      { [_h22]: ["GET", "/?intelligent-tiering&x-id=GetBucketIntelligentTieringConfiguration", 200] },
      () => exports2.GetBucketIntelligentTieringConfigurationRequest$,
      () => exports2.GetBucketIntelligentTieringConfigurationOutput$
    ];
    exports2.GetBucketInventoryConfiguration$ = [
      9,
      n032,
      _GBIC,
      { [_h22]: ["GET", "/?inventory&x-id=GetBucketInventoryConfiguration", 200] },
      () => exports2.GetBucketInventoryConfigurationRequest$,
      () => exports2.GetBucketInventoryConfigurationOutput$
    ];
    exports2.GetBucketLifecycleConfiguration$ = [
      9,
      n032,
      _GBLC,
      { [_h22]: ["GET", "/?lifecycle", 200] },
      () => exports2.GetBucketLifecycleConfigurationRequest$,
      () => exports2.GetBucketLifecycleConfigurationOutput$
    ];
    exports2.GetBucketLocation$ = [
      9,
      n032,
      _GBL,
      { [_h22]: ["GET", "/?location", 200] },
      () => exports2.GetBucketLocationRequest$,
      () => exports2.GetBucketLocationOutput$
    ];
    exports2.GetBucketLogging$ = [
      9,
      n032,
      _GBLe,
      { [_h22]: ["GET", "/?logging", 200] },
      () => exports2.GetBucketLoggingRequest$,
      () => exports2.GetBucketLoggingOutput$
    ];
    exports2.GetBucketMetadataConfiguration$ = [
      9,
      n032,
      _GBMC,
      { [_h22]: ["GET", "/?metadataConfiguration", 200] },
      () => exports2.GetBucketMetadataConfigurationRequest$,
      () => exports2.GetBucketMetadataConfigurationOutput$
    ];
    exports2.GetBucketMetadataTableConfiguration$ = [
      9,
      n032,
      _GBMTC,
      { [_h22]: ["GET", "/?metadataTable", 200] },
      () => exports2.GetBucketMetadataTableConfigurationRequest$,
      () => exports2.GetBucketMetadataTableConfigurationOutput$
    ];
    exports2.GetBucketMetricsConfiguration$ = [
      9,
      n032,
      _GBMCe,
      { [_h22]: ["GET", "/?metrics&x-id=GetBucketMetricsConfiguration", 200] },
      () => exports2.GetBucketMetricsConfigurationRequest$,
      () => exports2.GetBucketMetricsConfigurationOutput$
    ];
    exports2.GetBucketNotificationConfiguration$ = [
      9,
      n032,
      _GBNC,
      { [_h22]: ["GET", "/?notification", 200] },
      () => exports2.GetBucketNotificationConfigurationRequest$,
      () => exports2.NotificationConfiguration$
    ];
    exports2.GetBucketOwnershipControls$ = [
      9,
      n032,
      _GBOC,
      { [_h22]: ["GET", "/?ownershipControls", 200] },
      () => exports2.GetBucketOwnershipControlsRequest$,
      () => exports2.GetBucketOwnershipControlsOutput$
    ];
    exports2.GetBucketPolicy$ = [
      9,
      n032,
      _GBP,
      { [_h22]: ["GET", "/?policy", 200] },
      () => exports2.GetBucketPolicyRequest$,
      () => exports2.GetBucketPolicyOutput$
    ];
    exports2.GetBucketPolicyStatus$ = [
      9,
      n032,
      _GBPS,
      { [_h22]: ["GET", "/?policyStatus", 200] },
      () => exports2.GetBucketPolicyStatusRequest$,
      () => exports2.GetBucketPolicyStatusOutput$
    ];
    exports2.GetBucketReplication$ = [
      9,
      n032,
      _GBR,
      { [_h22]: ["GET", "/?replication", 200] },
      () => exports2.GetBucketReplicationRequest$,
      () => exports2.GetBucketReplicationOutput$
    ];
    exports2.GetBucketRequestPayment$ = [
      9,
      n032,
      _GBRP,
      { [_h22]: ["GET", "/?requestPayment", 200] },
      () => exports2.GetBucketRequestPaymentRequest$,
      () => exports2.GetBucketRequestPaymentOutput$
    ];
    exports2.GetBucketTagging$ = [
      9,
      n032,
      _GBT,
      { [_h22]: ["GET", "/?tagging", 200] },
      () => exports2.GetBucketTaggingRequest$,
      () => exports2.GetBucketTaggingOutput$
    ];
    exports2.GetBucketVersioning$ = [
      9,
      n032,
      _GBV,
      { [_h22]: ["GET", "/?versioning", 200] },
      () => exports2.GetBucketVersioningRequest$,
      () => exports2.GetBucketVersioningOutput$
    ];
    exports2.GetBucketWebsite$ = [
      9,
      n032,
      _GBW,
      { [_h22]: ["GET", "/?website", 200] },
      () => exports2.GetBucketWebsiteRequest$,
      () => exports2.GetBucketWebsiteOutput$
    ];
    exports2.GetObject$ = [
      9,
      n032,
      _GO,
      { [_hC]: "-", [_h22]: ["GET", "/{Key+}?x-id=GetObject", 200] },
      () => exports2.GetObjectRequest$,
      () => exports2.GetObjectOutput$
    ];
    exports2.GetObjectAcl$ = [
      9,
      n032,
      _GOA,
      { [_h22]: ["GET", "/{Key+}?acl", 200] },
      () => exports2.GetObjectAclRequest$,
      () => exports2.GetObjectAclOutput$
    ];
    exports2.GetObjectAttributes$ = [
      9,
      n032,
      _GOAe,
      { [_h22]: ["GET", "/{Key+}?attributes", 200] },
      () => exports2.GetObjectAttributesRequest$,
      () => exports2.GetObjectAttributesOutput$
    ];
    exports2.GetObjectLegalHold$ = [
      9,
      n032,
      _GOLH,
      { [_h22]: ["GET", "/{Key+}?legal-hold", 200] },
      () => exports2.GetObjectLegalHoldRequest$,
      () => exports2.GetObjectLegalHoldOutput$
    ];
    exports2.GetObjectLockConfiguration$ = [
      9,
      n032,
      _GOLC,
      { [_h22]: ["GET", "/?object-lock", 200] },
      () => exports2.GetObjectLockConfigurationRequest$,
      () => exports2.GetObjectLockConfigurationOutput$
    ];
    exports2.GetObjectRetention$ = [
      9,
      n032,
      _GORe,
      { [_h22]: ["GET", "/{Key+}?retention", 200] },
      () => exports2.GetObjectRetentionRequest$,
      () => exports2.GetObjectRetentionOutput$
    ];
    exports2.GetObjectTagging$ = [
      9,
      n032,
      _GOT,
      { [_h22]: ["GET", "/{Key+}?tagging", 200] },
      () => exports2.GetObjectTaggingRequest$,
      () => exports2.GetObjectTaggingOutput$
    ];
    exports2.GetObjectTorrent$ = [
      9,
      n032,
      _GOTe,
      { [_h22]: ["GET", "/{Key+}?torrent", 200] },
      () => exports2.GetObjectTorrentRequest$,
      () => exports2.GetObjectTorrentOutput$
    ];
    exports2.GetPublicAccessBlock$ = [
      9,
      n032,
      _GPAB,
      { [_h22]: ["GET", "/?publicAccessBlock", 200] },
      () => exports2.GetPublicAccessBlockRequest$,
      () => exports2.GetPublicAccessBlockOutput$
    ];
    exports2.HeadBucket$ = [
      9,
      n032,
      _HB,
      { [_h22]: ["HEAD", "/", 200] },
      () => exports2.HeadBucketRequest$,
      () => exports2.HeadBucketOutput$
    ];
    exports2.HeadObject$ = [
      9,
      n032,
      _HO,
      { [_h22]: ["HEAD", "/{Key+}", 200] },
      () => exports2.HeadObjectRequest$,
      () => exports2.HeadObjectOutput$
    ];
    exports2.ListBucketAnalyticsConfigurations$ = [
      9,
      n032,
      _LBAC,
      { [_h22]: ["GET", "/?analytics&x-id=ListBucketAnalyticsConfigurations", 200] },
      () => exports2.ListBucketAnalyticsConfigurationsRequest$,
      () => exports2.ListBucketAnalyticsConfigurationsOutput$
    ];
    exports2.ListBucketIntelligentTieringConfigurations$ = [
      9,
      n032,
      _LBITC,
      { [_h22]: ["GET", "/?intelligent-tiering&x-id=ListBucketIntelligentTieringConfigurations", 200] },
      () => exports2.ListBucketIntelligentTieringConfigurationsRequest$,
      () => exports2.ListBucketIntelligentTieringConfigurationsOutput$
    ];
    exports2.ListBucketInventoryConfigurations$ = [
      9,
      n032,
      _LBIC,
      { [_h22]: ["GET", "/?inventory&x-id=ListBucketInventoryConfigurations", 200] },
      () => exports2.ListBucketInventoryConfigurationsRequest$,
      () => exports2.ListBucketInventoryConfigurationsOutput$
    ];
    exports2.ListBucketMetricsConfigurations$ = [
      9,
      n032,
      _LBMC,
      { [_h22]: ["GET", "/?metrics&x-id=ListBucketMetricsConfigurations", 200] },
      () => exports2.ListBucketMetricsConfigurationsRequest$,
      () => exports2.ListBucketMetricsConfigurationsOutput$
    ];
    exports2.ListBuckets$ = [
      9,
      n032,
      _LB,
      { [_h22]: ["GET", "/?x-id=ListBuckets", 200] },
      () => exports2.ListBucketsRequest$,
      () => exports2.ListBucketsOutput$
    ];
    exports2.ListDirectoryBuckets$ = [
      9,
      n032,
      _LDB,
      { [_h22]: ["GET", "/?x-id=ListDirectoryBuckets", 200] },
      () => exports2.ListDirectoryBucketsRequest$,
      () => exports2.ListDirectoryBucketsOutput$
    ];
    exports2.ListMultipartUploads$ = [
      9,
      n032,
      _LMU,
      { [_h22]: ["GET", "/?uploads", 200] },
      () => exports2.ListMultipartUploadsRequest$,
      () => exports2.ListMultipartUploadsOutput$
    ];
    exports2.ListObjects$ = [
      9,
      n032,
      _LO,
      { [_h22]: ["GET", "/", 200] },
      () => exports2.ListObjectsRequest$,
      () => exports2.ListObjectsOutput$
    ];
    exports2.ListObjectsV2$ = [
      9,
      n032,
      _LOV,
      { [_h22]: ["GET", "/?list-type=2", 200] },
      () => exports2.ListObjectsV2Request$,
      () => exports2.ListObjectsV2Output$
    ];
    exports2.ListObjectVersions$ = [
      9,
      n032,
      _LOVi,
      { [_h22]: ["GET", "/?versions", 200] },
      () => exports2.ListObjectVersionsRequest$,
      () => exports2.ListObjectVersionsOutput$
    ];
    exports2.ListParts$ = [
      9,
      n032,
      _LP,
      { [_h22]: ["GET", "/{Key+}?x-id=ListParts", 200] },
      () => exports2.ListPartsRequest$,
      () => exports2.ListPartsOutput$
    ];
    exports2.PutBucketAbac$ = [
      9,
      n032,
      _PBA,
      { [_hC]: "-", [_h22]: ["PUT", "/?abac", 200] },
      () => exports2.PutBucketAbacRequest$,
      () => __Unit
    ];
    exports2.PutBucketAccelerateConfiguration$ = [
      9,
      n032,
      _PBAC,
      { [_hC]: "-", [_h22]: ["PUT", "/?accelerate", 200] },
      () => exports2.PutBucketAccelerateConfigurationRequest$,
      () => __Unit
    ];
    exports2.PutBucketAcl$ = [
      9,
      n032,
      _PBAu,
      { [_hC]: "-", [_h22]: ["PUT", "/?acl", 200] },
      () => exports2.PutBucketAclRequest$,
      () => __Unit
    ];
    exports2.PutBucketAnalyticsConfiguration$ = [
      9,
      n032,
      _PBACu,
      { [_h22]: ["PUT", "/?analytics", 200] },
      () => exports2.PutBucketAnalyticsConfigurationRequest$,
      () => __Unit
    ];
    exports2.PutBucketCors$ = [
      9,
      n032,
      _PBC,
      { [_hC]: "-", [_h22]: ["PUT", "/?cors", 200] },
      () => exports2.PutBucketCorsRequest$,
      () => __Unit
    ];
    exports2.PutBucketEncryption$ = [
      9,
      n032,
      _PBE,
      { [_hC]: "-", [_h22]: ["PUT", "/?encryption", 200] },
      () => exports2.PutBucketEncryptionRequest$,
      () => __Unit
    ];
    exports2.PutBucketIntelligentTieringConfiguration$ = [
      9,
      n032,
      _PBITC,
      { [_h22]: ["PUT", "/?intelligent-tiering", 200] },
      () => exports2.PutBucketIntelligentTieringConfigurationRequest$,
      () => __Unit
    ];
    exports2.PutBucketInventoryConfiguration$ = [
      9,
      n032,
      _PBIC,
      { [_h22]: ["PUT", "/?inventory", 200] },
      () => exports2.PutBucketInventoryConfigurationRequest$,
      () => __Unit
    ];
    exports2.PutBucketLifecycleConfiguration$ = [
      9,
      n032,
      _PBLC,
      { [_hC]: "-", [_h22]: ["PUT", "/?lifecycle", 200] },
      () => exports2.PutBucketLifecycleConfigurationRequest$,
      () => exports2.PutBucketLifecycleConfigurationOutput$
    ];
    exports2.PutBucketLogging$ = [
      9,
      n032,
      _PBL,
      { [_hC]: "-", [_h22]: ["PUT", "/?logging", 200] },
      () => exports2.PutBucketLoggingRequest$,
      () => __Unit
    ];
    exports2.PutBucketMetricsConfiguration$ = [
      9,
      n032,
      _PBMC,
      { [_h22]: ["PUT", "/?metrics", 200] },
      () => exports2.PutBucketMetricsConfigurationRequest$,
      () => __Unit
    ];
    exports2.PutBucketNotificationConfiguration$ = [
      9,
      n032,
      _PBNC,
      { [_h22]: ["PUT", "/?notification", 200] },
      () => exports2.PutBucketNotificationConfigurationRequest$,
      () => __Unit
    ];
    exports2.PutBucketOwnershipControls$ = [
      9,
      n032,
      _PBOC,
      { [_hC]: "-", [_h22]: ["PUT", "/?ownershipControls", 200] },
      () => exports2.PutBucketOwnershipControlsRequest$,
      () => __Unit
    ];
    exports2.PutBucketPolicy$ = [
      9,
      n032,
      _PBP,
      { [_hC]: "-", [_h22]: ["PUT", "/?policy", 200] },
      () => exports2.PutBucketPolicyRequest$,
      () => __Unit
    ];
    exports2.PutBucketReplication$ = [
      9,
      n032,
      _PBR,
      { [_hC]: "-", [_h22]: ["PUT", "/?replication", 200] },
      () => exports2.PutBucketReplicationRequest$,
      () => __Unit
    ];
    exports2.PutBucketRequestPayment$ = [
      9,
      n032,
      _PBRP,
      { [_hC]: "-", [_h22]: ["PUT", "/?requestPayment", 200] },
      () => exports2.PutBucketRequestPaymentRequest$,
      () => __Unit
    ];
    exports2.PutBucketTagging$ = [
      9,
      n032,
      _PBT,
      { [_hC]: "-", [_h22]: ["PUT", "/?tagging", 200] },
      () => exports2.PutBucketTaggingRequest$,
      () => __Unit
    ];
    exports2.PutBucketVersioning$ = [
      9,
      n032,
      _PBV,
      { [_hC]: "-", [_h22]: ["PUT", "/?versioning", 200] },
      () => exports2.PutBucketVersioningRequest$,
      () => __Unit
    ];
    exports2.PutBucketWebsite$ = [
      9,
      n032,
      _PBW,
      { [_hC]: "-", [_h22]: ["PUT", "/?website", 200] },
      () => exports2.PutBucketWebsiteRequest$,
      () => __Unit
    ];
    exports2.PutObject$ = [
      9,
      n032,
      _PO,
      { [_hC]: "-", [_h22]: ["PUT", "/{Key+}?x-id=PutObject", 200] },
      () => exports2.PutObjectRequest$,
      () => exports2.PutObjectOutput$
    ];
    exports2.PutObjectAcl$ = [
      9,
      n032,
      _POA,
      { [_hC]: "-", [_h22]: ["PUT", "/{Key+}?acl", 200] },
      () => exports2.PutObjectAclRequest$,
      () => exports2.PutObjectAclOutput$
    ];
    exports2.PutObjectLegalHold$ = [
      9,
      n032,
      _POLH,
      { [_hC]: "-", [_h22]: ["PUT", "/{Key+}?legal-hold", 200] },
      () => exports2.PutObjectLegalHoldRequest$,
      () => exports2.PutObjectLegalHoldOutput$
    ];
    exports2.PutObjectLockConfiguration$ = [
      9,
      n032,
      _POLC,
      { [_hC]: "-", [_h22]: ["PUT", "/?object-lock", 200] },
      () => exports2.PutObjectLockConfigurationRequest$,
      () => exports2.PutObjectLockConfigurationOutput$
    ];
    exports2.PutObjectRetention$ = [
      9,
      n032,
      _PORu,
      { [_hC]: "-", [_h22]: ["PUT", "/{Key+}?retention", 200] },
      () => exports2.PutObjectRetentionRequest$,
      () => exports2.PutObjectRetentionOutput$
    ];
    exports2.PutObjectTagging$ = [
      9,
      n032,
      _POT,
      { [_hC]: "-", [_h22]: ["PUT", "/{Key+}?tagging", 200] },
      () => exports2.PutObjectTaggingRequest$,
      () => exports2.PutObjectTaggingOutput$
    ];
    exports2.PutPublicAccessBlock$ = [
      9,
      n032,
      _PPAB,
      { [_hC]: "-", [_h22]: ["PUT", "/?publicAccessBlock", 200] },
      () => exports2.PutPublicAccessBlockRequest$,
      () => __Unit
    ];
    exports2.RenameObject$ = [
      9,
      n032,
      _RO,
      { [_h22]: ["PUT", "/{Key+}?renameObject", 200] },
      () => exports2.RenameObjectRequest$,
      () => exports2.RenameObjectOutput$
    ];
    exports2.RestoreObject$ = [
      9,
      n032,
      _ROe,
      { [_hC]: "-", [_h22]: ["POST", "/{Key+}?restore", 200] },
      () => exports2.RestoreObjectRequest$,
      () => exports2.RestoreObjectOutput$
    ];
    exports2.SelectObjectContent$ = [
      9,
      n032,
      _SOC,
      { [_h22]: ["POST", "/{Key+}?select&select-type=2", 200] },
      () => exports2.SelectObjectContentRequest$,
      () => exports2.SelectObjectContentOutput$
    ];
    exports2.UpdateBucketMetadataInventoryTableConfiguration$ = [
      9,
      n032,
      _UBMITC,
      { [_hC]: "-", [_h22]: ["PUT", "/?metadataInventoryTable", 200] },
      () => exports2.UpdateBucketMetadataInventoryTableConfigurationRequest$,
      () => __Unit
    ];
    exports2.UpdateBucketMetadataJournalTableConfiguration$ = [
      9,
      n032,
      _UBMJTC,
      { [_hC]: "-", [_h22]: ["PUT", "/?metadataJournalTable", 200] },
      () => exports2.UpdateBucketMetadataJournalTableConfigurationRequest$,
      () => __Unit
    ];
    exports2.UpdateObjectEncryption$ = [
      9,
      n032,
      _UOE,
      { [_hC]: "-", [_h22]: ["PUT", "/{Key+}?encryption", 200] },
      () => exports2.UpdateObjectEncryptionRequest$,
      () => exports2.UpdateObjectEncryptionResponse$
    ];
    exports2.UploadPart$ = [
      9,
      n032,
      _UP,
      { [_hC]: "-", [_h22]: ["PUT", "/{Key+}?x-id=UploadPart", 200] },
      () => exports2.UploadPartRequest$,
      () => exports2.UploadPartOutput$
    ];
    exports2.UploadPartCopy$ = [
      9,
      n032,
      _UPC,
      { [_h22]: ["PUT", "/{Key+}?x-id=UploadPartCopy", 200] },
      () => exports2.UploadPartCopyRequest$,
      () => exports2.UploadPartCopyOutput$
    ];
    exports2.WriteGetObjectResponse$ = [
      9,
      n032,
      _WGOR,
      { [_en]: ["{RequestRoute}."], [_h22]: ["POST", "/WriteGetObjectResponse", 200] },
      () => exports2.WriteGetObjectResponseRequest$,
      () => __Unit
    ];
  }
});

// ../../node_modules/@aws-sdk/client-s3/package.json
var require_package2 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/package.json"(exports2, module2) {
    module2.exports = {
      name: "@aws-sdk/client-s3",
      description: "AWS SDK for JavaScript S3 Client for Node.js, Browser and React Native",
      version: "3.1045.0",
      scripts: {
        build: "concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline client-s3",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        "extract:docs": "api-extractor run --local",
        "generate:client": "node ../../scripts/generate-clients/single-service --solo s3",
        test: "yarn g:vitest run",
        "test:browser": "node ./test/browser-build/esbuild && yarn g:vitest run -c vitest.config.browser.mts",
        "test:browser:watch": "node ./test/browser-build/esbuild && yarn g:vitest watch -c vitest.config.browser.mts",
        "test:e2e": "yarn g:vitest run -c vitest.config.e2e.mts && yarn test:browser",
        "test:e2e:watch": "yarn g:vitest watch -c vitest.config.e2e.mts",
        "test:index": "tsc --noEmit ./test/index-types.ts && node ./test/index-objects.spec.mjs",
        "test:integration": "yarn g:vitest run -c vitest.config.integ.mts",
        "test:integration:watch": "yarn g:vitest watch -c vitest.config.integ.mts",
        "test:watch": "yarn g:vitest watch"
      },
      main: "./dist-cjs/index.js",
      types: "./dist-types/index.d.ts",
      module: "./dist-es/index.js",
      sideEffects: false,
      dependencies: {
        "@aws-crypto/sha1-browser": "5.2.0",
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.8",
        "@aws-sdk/credential-provider-node": "^3.972.39",
        "@aws-sdk/middleware-bucket-endpoint": "^3.972.10",
        "@aws-sdk/middleware-expect-continue": "^3.972.10",
        "@aws-sdk/middleware-flexible-checksums": "^3.974.16",
        "@aws-sdk/middleware-host-header": "^3.972.10",
        "@aws-sdk/middleware-location-constraint": "^3.972.10",
        "@aws-sdk/middleware-logger": "^3.972.10",
        "@aws-sdk/middleware-recursion-detection": "^3.972.11",
        "@aws-sdk/middleware-sdk-s3": "^3.972.37",
        "@aws-sdk/middleware-ssec": "^3.972.10",
        "@aws-sdk/middleware-user-agent": "^3.972.38",
        "@aws-sdk/region-config-resolver": "^3.972.13",
        "@aws-sdk/signature-v4-multi-region": "^3.996.25",
        "@aws-sdk/types": "^3.973.8",
        "@aws-sdk/util-endpoints": "^3.996.8",
        "@aws-sdk/util-user-agent-browser": "^3.972.10",
        "@aws-sdk/util-user-agent-node": "^3.973.24",
        "@smithy/config-resolver": "^4.4.17",
        "@smithy/core": "^3.23.17",
        "@smithy/eventstream-serde-browser": "^4.2.14",
        "@smithy/eventstream-serde-config-resolver": "^4.3.14",
        "@smithy/eventstream-serde-node": "^4.2.14",
        "@smithy/fetch-http-handler": "^5.3.17",
        "@smithy/hash-blob-browser": "^4.2.15",
        "@smithy/hash-node": "^4.2.14",
        "@smithy/hash-stream-node": "^4.2.14",
        "@smithy/invalid-dependency": "^4.2.14",
        "@smithy/md5-js": "^4.2.14",
        "@smithy/middleware-content-length": "^4.2.14",
        "@smithy/middleware-endpoint": "^4.4.32",
        "@smithy/middleware-retry": "^4.5.7",
        "@smithy/middleware-serde": "^4.2.20",
        "@smithy/middleware-stack": "^4.2.14",
        "@smithy/node-config-provider": "^4.3.14",
        "@smithy/node-http-handler": "^4.6.1",
        "@smithy/protocol-http": "^5.3.14",
        "@smithy/smithy-client": "^4.12.13",
        "@smithy/types": "^4.14.1",
        "@smithy/url-parser": "^4.2.14",
        "@smithy/util-base64": "^4.3.2",
        "@smithy/util-body-length-browser": "^4.2.2",
        "@smithy/util-body-length-node": "^4.2.3",
        "@smithy/util-defaults-mode-browser": "^4.3.49",
        "@smithy/util-defaults-mode-node": "^4.2.54",
        "@smithy/util-endpoints": "^3.4.2",
        "@smithy/util-middleware": "^4.2.14",
        "@smithy/util-retry": "^4.3.6",
        "@smithy/util-stream": "^4.5.25",
        "@smithy/util-utf8": "^4.2.2",
        "@smithy/util-waiter": "^4.3.0",
        tslib: "^2.6.2"
      },
      devDependencies: {
        "@aws-sdk/signature-v4-crt": "3.1045.0",
        "@smithy/snapshot-testing": "^2.0.8",
        "@tsconfig/node20": "20.1.8",
        "@types/node": "^20.14.8",
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3",
        vitest: "^4.0.17"
      },
      engines: {
        node: ">=20.0.0"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "dist-*/**"
      ],
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      browser: {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.browser"
      },
      "react-native": {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.native"
      },
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/clients/client-s3",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "clients/client-s3"
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-env/dist-cjs/index.js
var require_dist_cjs72 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-env/dist-cjs/index.js"(exports2) {
    "use strict";
    var client = (init_client6(), __toCommonJS(client_exports5));
    var propertyProvider = require_dist_cjs27();
    var ENV_KEY = "AWS_ACCESS_KEY_ID";
    var ENV_SECRET = "AWS_SECRET_ACCESS_KEY";
    var ENV_SESSION = "AWS_SESSION_TOKEN";
    var ENV_EXPIRATION = "AWS_CREDENTIAL_EXPIRATION";
    var ENV_CREDENTIAL_SCOPE = "AWS_CREDENTIAL_SCOPE";
    var ENV_ACCOUNT_ID = "AWS_ACCOUNT_ID";
    var fromEnv6 = /* @__PURE__ */ __name((init) => async () => {
      init?.logger?.debug("@aws-sdk/credential-provider-env - fromEnv");
      const accessKeyId = process.env[ENV_KEY];
      const secretAccessKey = process.env[ENV_SECRET];
      const sessionToken = process.env[ENV_SESSION];
      const expiry = process.env[ENV_EXPIRATION];
      const credentialScope = process.env[ENV_CREDENTIAL_SCOPE];
      const accountId = process.env[ENV_ACCOUNT_ID];
      if (accessKeyId && secretAccessKey) {
        const credentials = {
          accessKeyId,
          secretAccessKey,
          ...sessionToken && { sessionToken },
          ...expiry && { expiration: new Date(expiry) },
          ...credentialScope && { credentialScope },
          ...accountId && { accountId }
        };
        client.setCredentialFeature(credentials, "CREDENTIALS_ENV_VARS", "g");
        return credentials;
      }
      throw new propertyProvider.CredentialsProviderError("Unable to find environment variable credentials.", { logger: init?.logger });
    }, "fromEnv");
    exports2.ENV_ACCOUNT_ID = ENV_ACCOUNT_ID;
    exports2.ENV_CREDENTIAL_SCOPE = ENV_CREDENTIAL_SCOPE;
    exports2.ENV_EXPIRATION = ENV_EXPIRATION;
    exports2.ENV_KEY = ENV_KEY;
    exports2.ENV_SECRET = ENV_SECRET;
    exports2.ENV_SESSION = ENV_SESSION;
    exports2.fromEnv = fromEnv6;
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/checkUrl.js
var require_checkUrl2 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/checkUrl.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.checkUrl = void 0;
    var property_provider_1 = require_dist_cjs27();
    var ECS_CONTAINER_HOST = "169.254.170.2";
    var EKS_CONTAINER_HOST_IPv4 = "169.254.170.23";
    var EKS_CONTAINER_HOST_IPv6 = "[fd00:ec2::23]";
    var checkUrl = /* @__PURE__ */ __name((url, logger5) => {
      if (url.protocol === "https:") {
        return;
      }
      if (url.hostname === ECS_CONTAINER_HOST || url.hostname === EKS_CONTAINER_HOST_IPv4 || url.hostname === EKS_CONTAINER_HOST_IPv6) {
        return;
      }
      if (url.hostname.includes("[")) {
        if (url.hostname === "[::1]" || url.hostname === "[0000:0000:0000:0000:0000:0000:0000:0001]") {
          return;
        }
      } else {
        if (url.hostname === "localhost") {
          return;
        }
        const ipComponents = url.hostname.split(".");
        const inRange = /* @__PURE__ */ __name((component) => {
          const num = parseInt(component, 10);
          return 0 <= num && num <= 255;
        }, "inRange");
        if (ipComponents[0] === "127" && inRange(ipComponents[1]) && inRange(ipComponents[2]) && inRange(ipComponents[3]) && ipComponents.length === 4) {
          return;
        }
      }
      throw new property_provider_1.CredentialsProviderError(`URL not accepted. It must either be HTTPS or match one of the following:
  - loopback CIDR 127.0.0.0/8 or [::1/128]
  - ECS container host 169.254.170.2
  - EKS container host 169.254.170.23 or [fd00:ec2::23]`, { logger: logger5 });
    }, "checkUrl");
    exports2.checkUrl = checkUrl;
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.js
var require_ChecksumStream4 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ChecksumStream = void 0;
    var util_base64_1 = require_dist_cjs10();
    var stream_1 = require("stream");
    var ChecksumStream5 = class extends stream_1.Duplex {
      static {
        __name(this, "ChecksumStream");
      }
      expectedChecksum;
      checksumSourceLocation;
      checksum;
      source;
      base64Encoder;
      pendingCallback = null;
      constructor({ expectedChecksum, checksum, source, checksumSourceLocation, base64Encoder }) {
        super();
        if (typeof source.pipe === "function") {
          this.source = source;
        } else {
          throw new Error(`@smithy/util-stream: unsupported source type ${source?.constructor?.name ?? source} in ChecksumStream.`);
        }
        this.base64Encoder = base64Encoder ?? util_base64_1.toBase64;
        this.expectedChecksum = expectedChecksum;
        this.checksum = checksum;
        this.checksumSourceLocation = checksumSourceLocation;
        this.source.pipe(this);
      }
      _read(size) {
        if (this.pendingCallback) {
          const callback = this.pendingCallback;
          this.pendingCallback = null;
          callback();
        }
      }
      _write(chunk, encoding, callback) {
        try {
          this.checksum.update(chunk);
          const canPushMore = this.push(chunk);
          if (!canPushMore) {
            this.pendingCallback = callback;
            return;
          }
        } catch (e32) {
          return callback(e32);
        }
        return callback();
      }
      async _final(callback) {
        try {
          const digest = await this.checksum.digest();
          const received = this.base64Encoder(digest);
          if (this.expectedChecksum !== received) {
            return callback(new Error(`Checksum mismatch: expected "${this.expectedChecksum}" but received "${received}" in response header "${this.checksumSourceLocation}".`));
          }
        } catch (e32) {
          return callback(e32);
        }
        this.push(null);
        return callback();
      }
    };
    exports2.ChecksumStream = ChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/stream-type-check.js
var require_stream_type_check4 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/stream-type-check.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isBlob = exports2.isReadableStream = void 0;
    var isReadableStream6 = /* @__PURE__ */ __name((stream) => typeof ReadableStream === "function" && (stream?.constructor?.name === ReadableStream.name || stream instanceof ReadableStream), "isReadableStream");
    exports2.isReadableStream = isReadableStream6;
    var isBlob3 = /* @__PURE__ */ __name((blob) => {
      return typeof Blob === "function" && (blob?.constructor?.name === Blob.name || blob instanceof Blob);
    }, "isBlob");
    exports2.isBlob = isBlob3;
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.browser.js
var require_ChecksumStream_browser4 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ChecksumStream = void 0;
    var ReadableStreamRef3 = typeof ReadableStream === "function" ? ReadableStream : function() {
    };
    var ChecksumStream5 = class extends ReadableStreamRef3 {
      static {
        __name(this, "ChecksumStream");
      }
    };
    exports2.ChecksumStream = ChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.browser.js
var require_createChecksumStream_browser4 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createChecksumStream = void 0;
    var util_base64_1 = require_dist_cjs10();
    var stream_type_check_1 = require_stream_type_check4();
    var ChecksumStream_browser_1 = require_ChecksumStream_browser4();
    var createChecksumStream5 = /* @__PURE__ */ __name(({ expectedChecksum, checksum, source, checksumSourceLocation, base64Encoder }) => {
      if (!(0, stream_type_check_1.isReadableStream)(source)) {
        throw new Error(`@smithy/util-stream: unsupported source type ${source?.constructor?.name ?? source} in ChecksumStream.`);
      }
      const encoder = base64Encoder ?? util_base64_1.toBase64;
      if (typeof TransformStream !== "function") {
        throw new Error("@smithy/util-stream: unable to instantiate ChecksumStream because API unavailable: ReadableStream/TransformStream.");
      }
      const transform = new TransformStream({
        start() {
        },
        async transform(chunk, controller) {
          checksum.update(chunk);
          controller.enqueue(chunk);
        },
        async flush(controller) {
          const digest = await checksum.digest();
          const received = encoder(digest);
          if (expectedChecksum !== received) {
            const error4 = new Error(`Checksum mismatch: expected "${expectedChecksum}" but received "${received}" in response header "${checksumSourceLocation}".`);
            controller.error(error4);
          } else {
            controller.terminate();
          }
        }
      });
      source.pipeThrough(transform);
      const readable = transform.readable;
      Object.setPrototypeOf(readable, ChecksumStream_browser_1.ChecksumStream.prototype);
      return readable;
    }, "createChecksumStream");
    exports2.createChecksumStream = createChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.js
var require_createChecksumStream4 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createChecksumStream = createChecksumStream5;
    var stream_type_check_1 = require_stream_type_check4();
    var ChecksumStream_1 = require_ChecksumStream4();
    var createChecksumStream_browser_1 = require_createChecksumStream_browser4();
    function createChecksumStream5(init) {
      if (typeof ReadableStream === "function" && (0, stream_type_check_1.isReadableStream)(init.source)) {
        return (0, createChecksumStream_browser_1.createChecksumStream)(init);
      }
      return new ChecksumStream_1.ChecksumStream(init);
    }
    __name(createChecksumStream5, "createChecksumStream");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/ByteArrayCollector.js
var require_ByteArrayCollector4 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/ByteArrayCollector.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ByteArrayCollector = void 0;
    var ByteArrayCollector3 = class {
      static {
        __name(this, "ByteArrayCollector");
      }
      allocByteArray;
      byteLength = 0;
      byteArrays = [];
      constructor(allocByteArray) {
        this.allocByteArray = allocByteArray;
      }
      push(byteArray) {
        this.byteArrays.push(byteArray);
        this.byteLength += byteArray.byteLength;
      }
      flush() {
        if (this.byteArrays.length === 1) {
          const bytes = this.byteArrays[0];
          this.reset();
          return bytes;
        }
        const aggregation = this.allocByteArray(this.byteLength);
        let cursor3 = 0;
        for (let i32 = 0; i32 < this.byteArrays.length; ++i32) {
          const bytes = this.byteArrays[i32];
          aggregation.set(bytes, cursor3);
          cursor3 += bytes.byteLength;
        }
        this.reset();
        return aggregation;
      }
      reset() {
        this.byteArrays = [];
        this.byteLength = 0;
      }
    };
    exports2.ByteArrayCollector = ByteArrayCollector3;
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadableStream.js
var require_createBufferedReadableStream4 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadableStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createBufferedReadable = void 0;
    exports2.createBufferedReadableStream = createBufferedReadableStream3;
    exports2.merge = merge3;
    exports2.flush = flush3;
    exports2.sizeOf = sizeOf3;
    exports2.modeOf = modeOf3;
    var ByteArrayCollector_1 = require_ByteArrayCollector4();
    function createBufferedReadableStream3(upstream, size, logger5) {
      const reader = upstream.getReader();
      let streamBufferingLoggedWarning = false;
      let bytesSeen = 0;
      const buffers = ["", new ByteArrayCollector_1.ByteArrayCollector((size2) => new Uint8Array(size2))];
      let mode = -1;
      const pull = /* @__PURE__ */ __name(async (controller) => {
        const { value, done } = await reader.read();
        const chunk = value;
        if (done) {
          if (mode !== -1) {
            const remainder = flush3(buffers, mode);
            if (sizeOf3(remainder) > 0) {
              controller.enqueue(remainder);
            }
          }
          controller.close();
        } else {
          const chunkMode = modeOf3(chunk, false);
          if (mode !== chunkMode) {
            if (mode >= 0) {
              controller.enqueue(flush3(buffers, mode));
            }
            mode = chunkMode;
          }
          if (mode === -1) {
            controller.enqueue(chunk);
            return;
          }
          const chunkSize = sizeOf3(chunk);
          bytesSeen += chunkSize;
          const bufferSize = sizeOf3(buffers[mode]);
          if (chunkSize >= size && bufferSize === 0) {
            controller.enqueue(chunk);
          } else {
            const newSize = merge3(buffers, mode, chunk);
            if (!streamBufferingLoggedWarning && bytesSeen > size * 2) {
              streamBufferingLoggedWarning = true;
              logger5?.warn(`@smithy/util-stream - stream chunk size ${chunkSize} is below threshold of ${size}, automatically buffering.`);
            }
            if (newSize >= size) {
              controller.enqueue(flush3(buffers, mode));
            } else {
              await pull(controller);
            }
          }
        }
      }, "pull");
      return new ReadableStream({
        pull
      });
    }
    __name(createBufferedReadableStream3, "createBufferedReadableStream");
    exports2.createBufferedReadable = createBufferedReadableStream3;
    function merge3(buffers, mode, chunk) {
      switch (mode) {
        case 0:
          buffers[0] += chunk;
          return sizeOf3(buffers[0]);
        case 1:
        case 2:
          buffers[mode].push(chunk);
          return sizeOf3(buffers[mode]);
      }
    }
    __name(merge3, "merge");
    function flush3(buffers, mode) {
      switch (mode) {
        case 0:
          const s = buffers[0];
          buffers[0] = "";
          return s;
        case 1:
        case 2:
          return buffers[mode].flush();
      }
      throw new Error(`@smithy/util-stream - invalid index ${mode} given to flush()`);
    }
    __name(flush3, "flush");
    function sizeOf3(chunk) {
      return chunk?.byteLength ?? chunk?.length ?? 0;
    }
    __name(sizeOf3, "sizeOf");
    function modeOf3(chunk, allowBuffer = true) {
      if (allowBuffer && typeof Buffer !== "undefined" && chunk instanceof Buffer) {
        return 2;
      }
      if (chunk instanceof Uint8Array) {
        return 1;
      }
      if (typeof chunk === "string") {
        return 0;
      }
      return -1;
    }
    __name(modeOf3, "modeOf");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadable.js
var require_createBufferedReadable4 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadable.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createBufferedReadable = createBufferedReadable3;
    var node_stream_1 = require("node:stream");
    var ByteArrayCollector_1 = require_ByteArrayCollector4();
    var createBufferedReadableStream_1 = require_createBufferedReadableStream4();
    var stream_type_check_1 = require_stream_type_check4();
    function createBufferedReadable3(upstream, size, logger5) {
      if ((0, stream_type_check_1.isReadableStream)(upstream)) {
        return (0, createBufferedReadableStream_1.createBufferedReadableStream)(upstream, size, logger5);
      }
      const downstream = new node_stream_1.Readable({ read() {
      } });
      let streamBufferingLoggedWarning = false;
      let bytesSeen = 0;
      const buffers = [
        "",
        new ByteArrayCollector_1.ByteArrayCollector((size2) => new Uint8Array(size2)),
        new ByteArrayCollector_1.ByteArrayCollector((size2) => Buffer.from(new Uint8Array(size2)))
      ];
      let mode = -1;
      upstream.on("data", (chunk) => {
        const chunkMode = (0, createBufferedReadableStream_1.modeOf)(chunk, true);
        if (mode !== chunkMode) {
          if (mode >= 0) {
            downstream.push((0, createBufferedReadableStream_1.flush)(buffers, mode));
          }
          mode = chunkMode;
        }
        if (mode === -1) {
          downstream.push(chunk);
          return;
        }
        const chunkSize = (0, createBufferedReadableStream_1.sizeOf)(chunk);
        bytesSeen += chunkSize;
        const bufferSize = (0, createBufferedReadableStream_1.sizeOf)(buffers[mode]);
        if (chunkSize >= size && bufferSize === 0) {
          downstream.push(chunk);
        } else {
          const newSize = (0, createBufferedReadableStream_1.merge)(buffers, mode, chunk);
          if (!streamBufferingLoggedWarning && bytesSeen > size * 2) {
            streamBufferingLoggedWarning = true;
            logger5?.warn(`@smithy/util-stream - stream chunk size ${chunkSize} is below threshold of ${size}, automatically buffering.`);
          }
          if (newSize >= size) {
            downstream.push((0, createBufferedReadableStream_1.flush)(buffers, mode));
          }
        }
      });
      upstream.on("end", () => {
        if (mode !== -1) {
          const remainder = (0, createBufferedReadableStream_1.flush)(buffers, mode);
          if ((0, createBufferedReadableStream_1.sizeOf)(remainder) > 0) {
            downstream.push(remainder);
          }
        }
        downstream.push(null);
      });
      return downstream;
    }
    __name(createBufferedReadable3, "createBufferedReadable");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.browser.js
var require_getAwsChunkedEncodingStream_browser4 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getAwsChunkedEncodingStream = void 0;
    var getAwsChunkedEncodingStream5 = /* @__PURE__ */ __name((readableStream, options) => {
      const { base64Encoder, bodyLengthChecker, checksumAlgorithmFn, checksumLocationName, streamHasher } = options;
      const checksumRequired = base64Encoder !== void 0 && bodyLengthChecker !== void 0 && checksumAlgorithmFn !== void 0 && checksumLocationName !== void 0 && streamHasher !== void 0;
      const digest = checksumRequired ? streamHasher(checksumAlgorithmFn, readableStream) : void 0;
      const reader = readableStream.getReader();
      return new ReadableStream({
        async pull(controller) {
          const { value, done } = await reader.read();
          if (done) {
            controller.enqueue(`0\r
`);
            if (checksumRequired) {
              const checksum = base64Encoder(await digest);
              controller.enqueue(`${checksumLocationName}:${checksum}\r
`);
              controller.enqueue(`\r
`);
            }
            controller.close();
          } else {
            controller.enqueue(`${(bodyLengthChecker(value) || 0).toString(16)}\r
${value}\r
`);
          }
        }
      });
    }, "getAwsChunkedEncodingStream");
    exports2.getAwsChunkedEncodingStream = getAwsChunkedEncodingStream5;
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.js
var require_getAwsChunkedEncodingStream4 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getAwsChunkedEncodingStream = getAwsChunkedEncodingStream5;
    var node_stream_1 = require("node:stream");
    var getAwsChunkedEncodingStream_browser_1 = require_getAwsChunkedEncodingStream_browser4();
    var stream_type_check_1 = require_stream_type_check4();
    function getAwsChunkedEncodingStream5(stream, options) {
      const readable = stream;
      const readableStream = stream;
      if ((0, stream_type_check_1.isReadableStream)(readableStream)) {
        return (0, getAwsChunkedEncodingStream_browser_1.getAwsChunkedEncodingStream)(readableStream, options);
      }
      const { base64Encoder, bodyLengthChecker, checksumAlgorithmFn, checksumLocationName, streamHasher } = options;
      const checksumRequired = base64Encoder !== void 0 && checksumAlgorithmFn !== void 0 && checksumLocationName !== void 0 && streamHasher !== void 0;
      const digest = checksumRequired ? streamHasher(checksumAlgorithmFn, readable) : void 0;
      const awsChunkedEncodingStream = new node_stream_1.Readable({
        read: /* @__PURE__ */ __name(() => {
        }, "read")
      });
      readable.on("data", (data3) => {
        const length = bodyLengthChecker(data3) || 0;
        if (length === 0) {
          return;
        }
        awsChunkedEncodingStream.push(`${length.toString(16)}\r
`);
        awsChunkedEncodingStream.push(data3);
        awsChunkedEncodingStream.push("\r\n");
      });
      readable.on("end", async () => {
        awsChunkedEncodingStream.push(`0\r
`);
        if (checksumRequired) {
          const checksum = base64Encoder(await digest);
          awsChunkedEncodingStream.push(`${checksumLocationName}:${checksum}\r
`);
          awsChunkedEncodingStream.push(`\r
`);
        }
        awsChunkedEncodingStream.push(null);
      });
      return awsChunkedEncodingStream;
    }
    __name(getAwsChunkedEncodingStream5, "getAwsChunkedEncodingStream");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/headStream.browser.js
var require_headStream_browser4 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/headStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.headStream = headStream5;
    async function headStream5(stream, bytes) {
      let byteLengthCounter = 0;
      const chunks2 = [];
      const reader = stream.getReader();
      let isDone = false;
      while (!isDone) {
        const { done, value } = await reader.read();
        if (value) {
          chunks2.push(value);
          byteLengthCounter += value?.byteLength ?? 0;
        }
        if (byteLengthCounter >= bytes) {
          break;
        }
        isDone = done;
      }
      reader.releaseLock();
      const collected = new Uint8Array(Math.min(bytes, byteLengthCounter));
      let offset = 0;
      for (const chunk of chunks2) {
        if (chunk.byteLength > collected.byteLength - offset) {
          collected.set(chunk.subarray(0, collected.byteLength - offset), offset);
          break;
        } else {
          collected.set(chunk, offset);
        }
        offset += chunk.length;
      }
      return collected;
    }
    __name(headStream5, "headStream");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/headStream.js
var require_headStream4 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/headStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.headStream = void 0;
    var stream_1 = require("stream");
    var headStream_browser_1 = require_headStream_browser4();
    var stream_type_check_1 = require_stream_type_check4();
    var headStream5 = /* @__PURE__ */ __name((stream, bytes) => {
      if ((0, stream_type_check_1.isReadableStream)(stream)) {
        return (0, headStream_browser_1.headStream)(stream, bytes);
      }
      return new Promise((resolve13, reject) => {
        const collector = new Collector8();
        collector.limit = bytes;
        stream.pipe(collector);
        stream.on("error", (err) => {
          collector.end();
          reject(err);
        });
        collector.on("error", reject);
        collector.on("finish", function() {
          const bytes2 = new Uint8Array(Buffer.concat(this.buffers));
          resolve13(bytes2);
        });
      });
    }, "headStream");
    exports2.headStream = headStream5;
    var Collector8 = class extends stream_1.Writable {
      static {
        __name(this, "Collector");
      }
      buffers = [];
      limit = Infinity;
      bytesBuffered = 0;
      _write(chunk, encoding, callback) {
        this.buffers.push(chunk);
        this.bytesBuffered += chunk.byteLength ?? 0;
        if (this.bytesBuffered >= this.limit) {
          const excess = this.bytesBuffered - this.limit;
          const tailBuffer = this.buffers[this.buffers.length - 1];
          this.buffers[this.buffers.length - 1] = tailBuffer.subarray(0, tailBuffer.byteLength - excess);
          this.emit("finish");
        }
        callback();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.browser.js
var require_sdk_stream_mixin_browser4 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.sdkStreamMixin = void 0;
    var fetch_http_handler_1 = require_dist_cjs14();
    var util_base64_1 = require_dist_cjs10();
    var util_hex_encoding_1 = require_dist_cjs15();
    var util_utf8_1 = require_dist_cjs9();
    var stream_type_check_1 = require_stream_type_check4();
    var ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11 = "The stream has already been transformed.";
    var sdkStreamMixin12 = /* @__PURE__ */ __name((stream) => {
      if (!isBlobInstance6(stream) && !(0, stream_type_check_1.isReadableStream)(stream)) {
        const name = stream?.__proto__?.constructor?.name || stream;
        throw new Error(`Unexpected stream implementation, expect Blob or ReadableStream, got ${name}`);
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
        }
        transformed = true;
        return await (0, fetch_http_handler_1.streamCollector)(stream);
      }, "transformToByteArray");
      const blobToWebStream = /* @__PURE__ */ __name((blob) => {
        if (typeof blob.stream !== "function") {
          throw new Error("Cannot transform payload Blob to web stream. Please make sure the Blob.stream() is polyfilled.\nIf you are using React Native, this API is not yet supported, see: https://react-native.canny.io/feature-requests/p/fetch-streaming-body");
        }
        return blob.stream();
      }, "blobToWebStream");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === "base64") {
            return (0, util_base64_1.toBase64)(buf);
          } else if (encoding === "hex") {
            return (0, util_hex_encoding_1.toHex)(buf);
          } else if (encoding === void 0 || encoding === "utf8" || encoding === "utf-8") {
            return (0, util_utf8_1.toUtf8)(buf);
          } else if (typeof TextDecoder === "function") {
            return new TextDecoder(encoding).decode(buf);
          } else {
            throw new Error("TextDecoder is not available, please make sure polyfill is provided.");
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
          }
          transformed = true;
          if (isBlobInstance6(stream)) {
            return blobToWebStream(stream);
          } else if ((0, stream_type_check_1.isReadableStream)(stream)) {
            return stream;
          } else {
            throw new Error(`Cannot transform payload to web stream, got ${stream}`);
          }
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
    exports2.sdkStreamMixin = sdkStreamMixin12;
    var isBlobInstance6 = /* @__PURE__ */ __name((stream) => typeof Blob === "function" && stream instanceof Blob, "isBlobInstance");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.js
var require_sdk_stream_mixin4 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.sdkStreamMixin = void 0;
    var node_http_handler_1 = require_dist_cjs13();
    var util_buffer_from_1 = require_dist_cjs8();
    var stream_1 = require("stream");
    var sdk_stream_mixin_browser_1 = require_sdk_stream_mixin_browser4();
    var ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11 = "The stream has already been transformed.";
    var sdkStreamMixin12 = /* @__PURE__ */ __name((stream) => {
      if (!(stream instanceof stream_1.Readable)) {
        try {
          return (0, sdk_stream_mixin_browser_1.sdkStreamMixin)(stream);
        } catch (e32) {
          const name = stream?.__proto__?.constructor?.name || stream;
          throw new Error(`Unexpected stream implementation, expect Stream.Readable instance, got ${name}`);
        }
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
        }
        transformed = true;
        return await (0, node_http_handler_1.streamCollector)(stream);
      }, "transformToByteArray");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === void 0 || Buffer.isEncoding(encoding)) {
            return (0, util_buffer_from_1.fromArrayBuffer)(buf.buffer, buf.byteOffset, buf.byteLength).toString(encoding);
          } else {
            const decoder = new TextDecoder(encoding);
            return decoder.decode(buf);
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
          }
          if (stream.readableFlowing !== null) {
            throw new Error("The stream has been consumed by other callbacks.");
          }
          if (typeof stream_1.Readable.toWeb !== "function") {
            throw new Error("Readable.toWeb() is not supported. Please ensure a polyfill is available.");
          }
          transformed = true;
          return stream_1.Readable.toWeb(stream);
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
    exports2.sdkStreamMixin = sdkStreamMixin12;
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/splitStream.browser.js
var require_splitStream_browser4 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/splitStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.splitStream = splitStream5;
    async function splitStream5(stream) {
      if (typeof stream.stream === "function") {
        stream = stream.stream();
      }
      const readableStream = stream;
      return readableStream.tee();
    }
    __name(splitStream5, "splitStream");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/splitStream.js
var require_splitStream4 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/splitStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.splitStream = splitStream5;
    var stream_1 = require("stream");
    var splitStream_browser_1 = require_splitStream_browser4();
    var stream_type_check_1 = require_stream_type_check4();
    async function splitStream5(stream) {
      if ((0, stream_type_check_1.isReadableStream)(stream) || (0, stream_type_check_1.isBlob)(stream)) {
        return (0, splitStream_browser_1.splitStream)(stream);
      }
      const stream1 = new stream_1.PassThrough();
      const stream2 = new stream_1.PassThrough();
      stream.pipe(stream1);
      stream.pipe(stream2);
      return [stream1, stream2];
    }
    __name(splitStream5, "splitStream");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/index.js
var require_dist_cjs73 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-stream/dist-cjs/index.js"(exports2) {
    "use strict";
    var utilBase64 = require_dist_cjs10();
    var utilUtf8 = require_dist_cjs9();
    var ChecksumStream5 = require_ChecksumStream4();
    var createChecksumStream5 = require_createChecksumStream4();
    var createBufferedReadable3 = require_createBufferedReadable4();
    var getAwsChunkedEncodingStream5 = require_getAwsChunkedEncodingStream4();
    var headStream5 = require_headStream4();
    var sdkStreamMixin12 = require_sdk_stream_mixin4();
    var splitStream5 = require_splitStream4();
    var streamTypeCheck = require_stream_type_check4();
    var Uint8ArrayBlobAdapter8 = class _Uint8ArrayBlobAdapter extends Uint8Array {
      static {
        __name(this, "Uint8ArrayBlobAdapter");
      }
      static fromString(source, encoding = "utf-8") {
        if (typeof source === "string") {
          if (encoding === "base64") {
            return _Uint8ArrayBlobAdapter.mutate(utilBase64.fromBase64(source));
          }
          return _Uint8ArrayBlobAdapter.mutate(utilUtf8.fromUtf8(source));
        }
        throw new Error(`Unsupported conversion from ${typeof source} to Uint8ArrayBlobAdapter.`);
      }
      static mutate(source) {
        Object.setPrototypeOf(source, _Uint8ArrayBlobAdapter.prototype);
        return source;
      }
      transformToString(encoding = "utf-8") {
        if (encoding === "base64") {
          return utilBase64.toBase64(this);
        }
        return utilUtf8.toUtf8(this);
      }
    };
    exports2.isBlob = streamTypeCheck.isBlob;
    exports2.isReadableStream = streamTypeCheck.isReadableStream;
    exports2.Uint8ArrayBlobAdapter = Uint8ArrayBlobAdapter8;
    Object.prototype.hasOwnProperty.call(ChecksumStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: ChecksumStream5["__proto__"]
    });
    Object.keys(ChecksumStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = ChecksumStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(createChecksumStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: createChecksumStream5["__proto__"]
    });
    Object.keys(createChecksumStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = createChecksumStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(createBufferedReadable3, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: createBufferedReadable3["__proto__"]
    });
    Object.keys(createBufferedReadable3).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = createBufferedReadable3[k32];
    });
    Object.prototype.hasOwnProperty.call(getAwsChunkedEncodingStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: getAwsChunkedEncodingStream5["__proto__"]
    });
    Object.keys(getAwsChunkedEncodingStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = getAwsChunkedEncodingStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(headStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: headStream5["__proto__"]
    });
    Object.keys(headStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = headStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(sdkStreamMixin12, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: sdkStreamMixin12["__proto__"]
    });
    Object.keys(sdkStreamMixin12).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = sdkStreamMixin12[k32];
    });
    Object.prototype.hasOwnProperty.call(splitStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: splitStream5["__proto__"]
    });
    Object.keys(splitStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = splitStream5[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/requestHelpers.js
var require_requestHelpers2 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/requestHelpers.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createGetRequest = createGetRequest;
    exports2.getCredentials = getCredentials;
    var property_provider_1 = require_dist_cjs27();
    var protocol_http_1 = require_dist_cjs2();
    var smithy_client_1 = require_dist_cjs34();
    var util_stream_1 = require_dist_cjs73();
    function createGetRequest(url) {
      return new protocol_http_1.HttpRequest({
        protocol: url.protocol,
        hostname: url.hostname,
        port: Number(url.port),
        path: url.pathname,
        query: Array.from(url.searchParams.entries()).reduce((acc, [k32, v]) => {
          acc[k32] = v;
          return acc;
        }, {}),
        fragment: url.hash
      });
    }
    __name(createGetRequest, "createGetRequest");
    async function getCredentials(response, logger5) {
      const stream = (0, util_stream_1.sdkStreamMixin)(response.body);
      const str = await stream.transformToString();
      if (response.statusCode === 200) {
        const parsed = JSON.parse(str);
        if (typeof parsed.AccessKeyId !== "string" || typeof parsed.SecretAccessKey !== "string" || typeof parsed.Token !== "string" || typeof parsed.Expiration !== "string") {
          throw new property_provider_1.CredentialsProviderError("HTTP credential provider response not of the required format, an object matching: { AccessKeyId: string, SecretAccessKey: string, Token: string, Expiration: string(rfc3339) }", { logger: logger5 });
        }
        return {
          accessKeyId: parsed.AccessKeyId,
          secretAccessKey: parsed.SecretAccessKey,
          sessionToken: parsed.Token,
          expiration: (0, smithy_client_1.parseRfc3339DateTime)(parsed.Expiration)
        };
      }
      if (response.statusCode >= 400 && response.statusCode < 500) {
        let parsedBody = {};
        try {
          parsedBody = JSON.parse(str);
        } catch (e32) {
        }
        throw Object.assign(new property_provider_1.CredentialsProviderError(`Server responded with status: ${response.statusCode}`, { logger: logger5 }), {
          Code: parsedBody.Code,
          Message: parsedBody.Message
        });
      }
      throw new property_provider_1.CredentialsProviderError(`Server responded with status: ${response.statusCode}`, { logger: logger5 });
    }
    __name(getCredentials, "getCredentials");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/retry-wrapper.js
var require_retry_wrapper2 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/retry-wrapper.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.retryWrapper = void 0;
    var retryWrapper = /* @__PURE__ */ __name((toRetry, maxRetries, delayMs) => {
      return async () => {
        for (let i32 = 0; i32 < maxRetries; ++i32) {
          try {
            return await toRetry();
          } catch (e32) {
            await new Promise((resolve13) => setTimeout(resolve13, delayMs));
          }
        }
        return await toRetry();
      };
    }, "retryWrapper");
    exports2.retryWrapper = retryWrapper;
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/fromHttp.js
var require_fromHttp2 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/fromHttp.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromHttp = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var client_1 = (init_client6(), __toCommonJS(client_exports5));
    var node_http_handler_1 = require_dist_cjs13();
    var property_provider_1 = require_dist_cjs27();
    var promises_1 = tslib_1.__importDefault(require("node:fs/promises"));
    var checkUrl_1 = require_checkUrl2();
    var requestHelpers_1 = require_requestHelpers2();
    var retry_wrapper_1 = require_retry_wrapper2();
    var AWS_CONTAINER_CREDENTIALS_RELATIVE_URI = "AWS_CONTAINER_CREDENTIALS_RELATIVE_URI";
    var DEFAULT_LINK_LOCAL_HOST = "http://169.254.170.2";
    var AWS_CONTAINER_CREDENTIALS_FULL_URI = "AWS_CONTAINER_CREDENTIALS_FULL_URI";
    var AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE = "AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE";
    var AWS_CONTAINER_AUTHORIZATION_TOKEN = "AWS_CONTAINER_AUTHORIZATION_TOKEN";
    var fromHttp = /* @__PURE__ */ __name((options = {}) => {
      options.logger?.debug("@aws-sdk/credential-provider-http - fromHttp");
      let host;
      const relative5 = options.awsContainerCredentialsRelativeUri ?? process.env[AWS_CONTAINER_CREDENTIALS_RELATIVE_URI];
      const full = options.awsContainerCredentialsFullUri ?? process.env[AWS_CONTAINER_CREDENTIALS_FULL_URI];
      const token = options.awsContainerAuthorizationToken ?? process.env[AWS_CONTAINER_AUTHORIZATION_TOKEN];
      const tokenFile = options.awsContainerAuthorizationTokenFile ?? process.env[AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE];
      const warn2 = options.logger?.constructor?.name === "NoOpLogger" || !options.logger?.warn ? console.warn : options.logger.warn.bind(options.logger);
      if (relative5 && full) {
        warn2("@aws-sdk/credential-provider-http: you have set both awsContainerCredentialsRelativeUri and awsContainerCredentialsFullUri.");
        warn2("awsContainerCredentialsFullUri will take precedence.");
      }
      if (token && tokenFile) {
        warn2("@aws-sdk/credential-provider-http: you have set both awsContainerAuthorizationToken and awsContainerAuthorizationTokenFile.");
        warn2("awsContainerAuthorizationToken will take precedence.");
      }
      if (full) {
        host = full;
      } else if (relative5) {
        host = `${DEFAULT_LINK_LOCAL_HOST}${relative5}`;
      } else {
        throw new property_provider_1.CredentialsProviderError(`No HTTP credential provider host provided.
Set AWS_CONTAINER_CREDENTIALS_FULL_URI or AWS_CONTAINER_CREDENTIALS_RELATIVE_URI.`, { logger: options.logger });
      }
      const url = new URL(host);
      (0, checkUrl_1.checkUrl)(url, options.logger);
      const requestHandler = node_http_handler_1.NodeHttpHandler.create({
        requestTimeout: options.timeout ?? 1e3,
        connectionTimeout: options.timeout ?? 1e3
      });
      return (0, retry_wrapper_1.retryWrapper)(async () => {
        const request4 = (0, requestHelpers_1.createGetRequest)(url);
        if (token) {
          request4.headers.Authorization = token;
        } else if (tokenFile) {
          request4.headers.Authorization = (await promises_1.default.readFile(tokenFile)).toString();
        }
        try {
          const result2 = await requestHandler.handle(request4);
          return (0, requestHelpers_1.getCredentials)(result2.response).then((creds) => (0, client_1.setCredentialFeature)(creds, "CREDENTIALS_HTTP", "z"));
        } catch (e32) {
          throw new property_provider_1.CredentialsProviderError(String(e32), { logger: options.logger });
        }
      }, options.maxRetries ?? 3, options.timeout ?? 1e3);
    }, "fromHttp");
    exports2.fromHttp = fromHttp;
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-http/dist-cjs/index.js
var require_dist_cjs74 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-http/dist-cjs/index.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromHttp = void 0;
    var fromHttp_1 = require_fromHttp2();
    Object.defineProperty(exports2, "fromHttp", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return fromHttp_1.fromHttp;
    }, "get") });
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption5(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "awsssoportal",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption5(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var import_util_middleware10, defaultSSOHttpAuthSchemeParametersProvider2, defaultSSOHttpAuthSchemeProvider2, resolveHttpAuthSchemeConfig5;
var init_httpAuthSchemeProvider5 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes4();
    import_util_middleware10 = __toESM(require_dist_cjs6());
    defaultSSOHttpAuthSchemeParametersProvider2 = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, import_util_middleware10.getSmithyContext)(context).operation,
        region: await (0, import_util_middleware10.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultSSOHttpAuthSchemeParametersProvider");
    __name(createAwsAuthSigv4HttpAuthOption5, "createAwsAuthSigv4HttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption5, "createSmithyApiNoAuthHttpAuthOption");
    defaultSSOHttpAuthSchemeProvider2 = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "GetRoleCredentials": {
          options.push(createSmithyApiNoAuthHttpAuthOption5(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption5(authParameters));
        }
      }
      return options;
    }, "defaultSSOHttpAuthSchemeProvider");
    resolveHttpAuthSchemeConfig5 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveAwsSdkSigV4Config3(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, import_util_middleware10.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/EndpointParameters.js
var resolveClientEndpointParameters5, commonParams5;
var init_EndpointParameters5 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters5 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "awsssoportal"
      });
    }, "resolveClientEndpointParameters");
    commonParams5 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/package.json
var package_default3;
var init_package3 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/package.json"() {
    package_default3 = {
      name: "@aws-sdk/nested-clients",
      version: "3.997.6",
      description: "Nested clients for AWS SDK packages.",
      main: "./dist-cjs/index.js",
      module: "./dist-es/index.js",
      types: "./dist-types/index.d.ts",
      scripts: {
        build: "yarn lint && concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline nested-clients",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        lint: "node ../../scripts/validation/submodules-linter.js --pkg nested-clients",
        test: "yarn g:vitest run",
        "test:watch": "yarn g:vitest watch"
      },
      engines: {
        node: ">=20.0.0"
      },
      sideEffects: false,
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      dependencies: {
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.8",
        "@aws-sdk/middleware-host-header": "^3.972.10",
        "@aws-sdk/middleware-logger": "^3.972.10",
        "@aws-sdk/middleware-recursion-detection": "^3.972.11",
        "@aws-sdk/middleware-user-agent": "^3.972.38",
        "@aws-sdk/region-config-resolver": "^3.972.13",
        "@aws-sdk/signature-v4-multi-region": "^3.996.25",
        "@aws-sdk/types": "^3.973.8",
        "@aws-sdk/util-endpoints": "^3.996.8",
        "@aws-sdk/util-user-agent-browser": "^3.972.10",
        "@aws-sdk/util-user-agent-node": "^3.973.24",
        "@smithy/config-resolver": "^4.4.17",
        "@smithy/core": "^3.23.17",
        "@smithy/fetch-http-handler": "^5.3.17",
        "@smithy/hash-node": "^4.2.14",
        "@smithy/invalid-dependency": "^4.2.14",
        "@smithy/middleware-content-length": "^4.2.14",
        "@smithy/middleware-endpoint": "^4.4.32",
        "@smithy/middleware-retry": "^4.5.7",
        "@smithy/middleware-serde": "^4.2.20",
        "@smithy/middleware-stack": "^4.2.14",
        "@smithy/node-config-provider": "^4.3.14",
        "@smithy/node-http-handler": "^4.6.1",
        "@smithy/protocol-http": "^5.3.14",
        "@smithy/smithy-client": "^4.12.13",
        "@smithy/types": "^4.14.1",
        "@smithy/url-parser": "^4.2.14",
        "@smithy/util-base64": "^4.3.2",
        "@smithy/util-body-length-browser": "^4.2.2",
        "@smithy/util-body-length-node": "^4.2.3",
        "@smithy/util-defaults-mode-browser": "^4.3.49",
        "@smithy/util-defaults-mode-node": "^4.2.54",
        "@smithy/util-endpoints": "^3.4.2",
        "@smithy/util-middleware": "^4.2.14",
        "@smithy/util-retry": "^4.3.6",
        "@smithy/util-utf8": "^4.2.2",
        tslib: "^2.6.2"
      },
      devDependencies: {
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "./cognito-identity.d.ts",
        "./cognito-identity.js",
        "./signin.d.ts",
        "./signin.js",
        "./sso-oidc.d.ts",
        "./sso-oidc.js",
        "./sso.d.ts",
        "./sso.js",
        "./sts.d.ts",
        "./sts.js",
        "dist-*/**"
      ],
      browser: {
        "./dist-es/submodules/cognito-identity/runtimeConfig": "./dist-es/submodules/cognito-identity/runtimeConfig.browser",
        "./dist-es/submodules/signin/runtimeConfig": "./dist-es/submodules/signin/runtimeConfig.browser",
        "./dist-es/submodules/sso-oidc/runtimeConfig": "./dist-es/submodules/sso-oidc/runtimeConfig.browser",
        "./dist-es/submodules/sso/runtimeConfig": "./dist-es/submodules/sso/runtimeConfig.browser",
        "./dist-es/submodules/sts/runtimeConfig": "./dist-es/submodules/sts/runtimeConfig.browser"
      },
      "react-native": {},
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/packages/nested-clients",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "packages/nested-clients"
      },
      exports: {
        "./package.json": "./package.json",
        "./sso-oidc": {
          types: "./dist-types/submodules/sso-oidc/index.d.ts",
          module: "./dist-es/submodules/sso-oidc/index.js",
          node: "./dist-cjs/submodules/sso-oidc/index.js",
          import: "./dist-es/submodules/sso-oidc/index.js",
          require: "./dist-cjs/submodules/sso-oidc/index.js"
        },
        "./sts": {
          types: "./dist-types/submodules/sts/index.d.ts",
          module: "./dist-es/submodules/sts/index.js",
          node: "./dist-cjs/submodules/sts/index.js",
          import: "./dist-es/submodules/sts/index.js",
          require: "./dist-cjs/submodules/sts/index.js"
        },
        "./signin": {
          types: "./dist-types/submodules/signin/index.d.ts",
          module: "./dist-es/submodules/signin/index.js",
          node: "./dist-cjs/submodules/signin/index.js",
          import: "./dist-es/submodules/signin/index.js",
          require: "./dist-cjs/submodules/signin/index.js"
        },
        "./cognito-identity": {
          types: "./dist-types/submodules/cognito-identity/index.d.ts",
          module: "./dist-es/submodules/cognito-identity/index.js",
          node: "./dist-cjs/submodules/cognito-identity/index.js",
          import: "./dist-es/submodules/cognito-identity/index.js",
          require: "./dist-cjs/submodules/cognito-identity/index.js"
        },
        "./sso": {
          types: "./dist-types/submodules/sso/index.d.ts",
          module: "./dist-es/submodules/sso/index.js",
          node: "./dist-cjs/submodules/sso/index.js",
          import: "./dist-es/submodules/sso/index.js",
          require: "./dist-cjs/submodules/sso/index.js"
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/util-user-agent-node/dist-cjs/index.js
var require_dist_cjs75 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/util-user-agent-node/dist-cjs/index.js"(exports2) {
    "use strict";
    var node_os = require("node:os");
    var node_process = require("node:process");
    var utilConfigProvider = require_dist_cjs24();
    var promises5 = require("node:fs/promises");
    var node_path = require("node:path");
    var middlewareUserAgent = require_dist_cjs69();
    var getRuntimeUserAgentPair2 = /* @__PURE__ */ __name(() => {
      const runtimesToCheck = ["deno", "bun", "llrt"];
      for (const runtime of runtimesToCheck) {
        if (node_process.versions[runtime]) {
          return [`md/${runtime}`, node_process.versions[runtime]];
        }
      }
      return ["md/nodejs", node_process.versions.node];
    }, "getRuntimeUserAgentPair");
    var getNodeModulesParentDirs2 = /* @__PURE__ */ __name((dirname14) => {
      const cwd = process.cwd();
      if (!dirname14) {
        return [cwd];
      }
      const normalizedPath = node_path.normalize(dirname14);
      const parts = normalizedPath.split(node_path.sep);
      const nodeModulesIndex = parts.indexOf("node_modules");
      const parentDir = nodeModulesIndex !== -1 ? parts.slice(0, nodeModulesIndex).join(node_path.sep) : normalizedPath;
      if (cwd === parentDir) {
        return [cwd];
      }
      return [parentDir, cwd];
    }, "getNodeModulesParentDirs");
    var SEMVER_REGEX2 = /^(0|[1-9]\d*)\.(0|[1-9]\d*)\.(0|[1-9]\d*)(?:-((?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*)(?:\.(?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*))*))?(?:\+[0-9a-zA-Z-]+(?:\.[0-9a-zA-Z-]+)*)?$/;
    var getSanitizedTypeScriptVersion2 = /* @__PURE__ */ __name((version = "") => {
      const match = version.match(SEMVER_REGEX2);
      if (!match) {
        return void 0;
      }
      const [major6, minor, patch, prerelease] = [match[1], match[2], match[3], match[4]];
      return prerelease ? `${major6}.${minor}.${patch}-${prerelease}` : `${major6}.${minor}.${patch}`;
    }, "getSanitizedTypeScriptVersion");
    var ALLOWED_PREFIXES2 = ["^", "~", ">=", "<=", ">", "<"];
    var ALLOWED_DIST_TAGS2 = ["latest", "beta", "dev", "rc", "insiders", "next"];
    var getSanitizedDevTypeScriptVersion2 = /* @__PURE__ */ __name((version = "") => {
      if (ALLOWED_DIST_TAGS2.includes(version)) {
        return version;
      }
      const prefix = ALLOWED_PREFIXES2.find((p10) => version.startsWith(p10)) ?? "";
      const sanitizedTypeScriptVersion = getSanitizedTypeScriptVersion2(version.slice(prefix.length));
      if (!sanitizedTypeScriptVersion) {
        return void 0;
      }
      return `${prefix}${sanitizedTypeScriptVersion}`;
    }, "getSanitizedDevTypeScriptVersion");
    var tscVersion2;
    var TS_PACKAGE_JSON2 = node_path.join("node_modules", "typescript", "package.json");
    var getTypeScriptUserAgentPair2 = /* @__PURE__ */ __name(async () => {
      if (tscVersion2 === null) {
        return void 0;
      } else if (typeof tscVersion2 === "string") {
        return ["md/tsc", tscVersion2];
      }
      let isTypeScriptDetectionDisabled = false;
      try {
        isTypeScriptDetectionDisabled = utilConfigProvider.booleanSelector(process.env, "AWS_SDK_JS_TYPESCRIPT_DETECTION_DISABLED", utilConfigProvider.SelectorType.ENV) || false;
      } catch {
      }
      if (isTypeScriptDetectionDisabled) {
        tscVersion2 = null;
        return void 0;
      }
      const dirname14 = typeof __dirname !== "undefined" ? __dirname : void 0;
      const nodeModulesParentDirs = getNodeModulesParentDirs2(dirname14);
      let versionFromApp;
      for (const nodeModulesParentDir of nodeModulesParentDirs) {
        try {
          const appPackageJsonPath = node_path.join(nodeModulesParentDir, "package.json");
          const packageJson = await promises5.readFile(appPackageJsonPath, "utf-8");
          const { dependencies, devDependencies } = JSON.parse(packageJson);
          const version = devDependencies?.typescript ?? dependencies?.typescript;
          if (typeof version !== "string") {
            continue;
          }
          versionFromApp = version;
          break;
        } catch {
        }
      }
      if (!versionFromApp) {
        tscVersion2 = null;
        return void 0;
      }
      let versionFromNodeModules;
      for (const nodeModulesParentDir of nodeModulesParentDirs) {
        try {
          const tsPackageJsonPath = node_path.join(nodeModulesParentDir, TS_PACKAGE_JSON2);
          const packageJson = await promises5.readFile(tsPackageJsonPath, "utf-8");
          const { version } = JSON.parse(packageJson);
          const sanitizedVersion2 = getSanitizedTypeScriptVersion2(version);
          if (typeof sanitizedVersion2 !== "string") {
            continue;
          }
          versionFromNodeModules = sanitizedVersion2;
          break;
        } catch {
        }
      }
      if (versionFromNodeModules) {
        tscVersion2 = versionFromNodeModules;
        return ["md/tsc", tscVersion2];
      }
      const sanitizedVersion = getSanitizedDevTypeScriptVersion2(versionFromApp);
      if (typeof sanitizedVersion !== "string") {
        tscVersion2 = null;
        return void 0;
      }
      tscVersion2 = `dev_${sanitizedVersion}`;
      return ["md/tsc", tscVersion2];
    }, "getTypeScriptUserAgentPair");
    var crtAvailability2 = {
      isCrtAvailable: false
    };
    var isCrtAvailable2 = /* @__PURE__ */ __name(() => {
      if (crtAvailability2.isCrtAvailable) {
        return ["md/crt-avail"];
      }
      return null;
    }, "isCrtAvailable");
    var createDefaultUserAgentProvider29 = /* @__PURE__ */ __name(({ serviceId, clientVersion }) => {
      const runtimeUserAgentPair = getRuntimeUserAgentPair2();
      return async (config2) => {
        const sections = [
          ["aws-sdk-js", clientVersion],
          ["ua", "2.1"],
          [`os/${node_os.platform()}`, node_os.release()],
          ["lang/js"],
          runtimeUserAgentPair
        ];
        const typescriptUserAgentPair = await getTypeScriptUserAgentPair2();
        if (typescriptUserAgentPair) {
          sections.push(typescriptUserAgentPair);
        }
        const crtAvailable = isCrtAvailable2();
        if (crtAvailable) {
          sections.push(crtAvailable);
        }
        if (serviceId) {
          sections.push([`api/${serviceId}`, clientVersion]);
        }
        if (node_process.env.AWS_EXECUTION_ENV) {
          sections.push([`exec-env/${node_process.env.AWS_EXECUTION_ENV}`]);
        }
        const appId = await config2?.userAgentAppId?.();
        const resolvedUserAgent = appId ? [...sections, [`app/${appId}`]] : [...sections];
        return resolvedUserAgent;
      };
    }, "createDefaultUserAgentProvider");
    var defaultUserAgent2 = createDefaultUserAgentProvider29;
    var UA_APP_ID_ENV_NAME2 = "AWS_SDK_UA_APP_ID";
    var UA_APP_ID_INI_NAME2 = "sdk_ua_app_id";
    var UA_APP_ID_INI_NAME_DEPRECATED2 = "sdk-ua-app-id";
    var NODE_APP_ID_CONFIG_OPTIONS29 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[UA_APP_ID_ENV_NAME2], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[UA_APP_ID_INI_NAME2] ?? profile[UA_APP_ID_INI_NAME_DEPRECATED2], "configFileSelector"),
      default: middlewareUserAgent.DEFAULT_UA_APP_ID
    };
    exports2.NODE_APP_ID_CONFIG_OPTIONS = NODE_APP_ID_CONFIG_OPTIONS29;
    exports2.UA_APP_ID_ENV_NAME = UA_APP_ID_ENV_NAME2;
    exports2.UA_APP_ID_INI_NAME = UA_APP_ID_INI_NAME2;
    exports2.createDefaultUserAgentProvider = createDefaultUserAgentProvider29;
    exports2.crtAvailability = crtAvailability2;
    exports2.defaultUserAgent = defaultUserAgent2;
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ProtocolLib.js
var import_smithy_client46, ProtocolLib4;
var init_ProtocolLib4 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ProtocolLib.js"() {
    init_schema4();
    import_smithy_client46 = __toESM(require_dist_cjs34());
    ProtocolLib4 = class {
      static {
        __name(this, "ProtocolLib");
      }
      queryCompat;
      errorRegistry;
      constructor(queryCompat = false) {
        this.queryCompat = queryCompat;
      }
      resolveRestContentType(defaultContentType, inputSchema) {
        const members = inputSchema.getMemberSchemas();
        const httpPayloadMember = Object.values(members).find((m20) => {
          return !!m20.getMergedTraits().httpPayload;
        });
        if (httpPayloadMember) {
          const mediaType = httpPayloadMember.getMergedTraits().mediaType;
          if (mediaType) {
            return mediaType;
          } else if (httpPayloadMember.isStringSchema()) {
            return "text/plain";
          } else if (httpPayloadMember.isBlobSchema()) {
            return "application/octet-stream";
          } else {
            return defaultContentType;
          }
        } else if (!inputSchema.isUnitSchema()) {
          const hasBody = Object.values(members).find((m20) => {
            const { httpQuery, httpQueryParams, httpHeader, httpLabel, httpPrefixHeaders } = m20.getMergedTraits();
            const noPrefixHeaders = httpPrefixHeaders === void 0;
            return !httpQuery && !httpQueryParams && !httpHeader && !httpLabel && noPrefixHeaders;
          });
          if (hasBody) {
            return defaultContentType;
          }
        }
      }
      async getErrorSchemaOrThrowBaseException(errorIdentifier, defaultNamespace, response, dataObject, metadata, getErrorSchema) {
        let errorName = errorIdentifier;
        if (errorIdentifier.includes("#")) {
          [, errorName] = errorIdentifier.split("#");
        }
        const errorMetadata = {
          $metadata: metadata,
          $fault: response.statusCode < 500 ? "client" : "server"
        };
        if (!this.errorRegistry) {
          throw new Error("@aws-sdk/core/protocols - error handler not initialized.");
        }
        try {
          const errorSchema = getErrorSchema?.(this.errorRegistry, errorName) ?? this.errorRegistry.getSchema(errorIdentifier);
          return { errorSchema, errorMetadata };
        } catch (e32) {
          dataObject.message = dataObject.message ?? dataObject.Message ?? "UnknownError";
          const synthetic = this.errorRegistry;
          const baseExceptionSchema = synthetic.getBaseException();
          if (baseExceptionSchema) {
            const ErrorCtor = synthetic.getErrorCtor(baseExceptionSchema) ?? Error;
            throw this.decorateServiceException(Object.assign(new ErrorCtor({ name: errorName }), errorMetadata), dataObject);
          }
          const d32 = dataObject;
          const message2 = d32?.message ?? d32?.Message ?? d32?.Error?.Message ?? d32?.Error?.message;
          throw this.decorateServiceException(Object.assign(new Error(message2), {
            name: errorName
          }, errorMetadata), dataObject);
        }
      }
      compose(composite, errorIdentifier, defaultNamespace) {
        let namespace = defaultNamespace;
        if (errorIdentifier.includes("#")) {
          [namespace] = errorIdentifier.split("#");
        }
        const staticRegistry = TypeRegistry.for(namespace);
        const defaultSyntheticRegistry = TypeRegistry.for("smithy.ts.sdk.synthetic." + defaultNamespace);
        composite.copyFrom(staticRegistry);
        composite.copyFrom(defaultSyntheticRegistry);
        this.errorRegistry = composite;
      }
      decorateServiceException(exception, additions = {}) {
        if (this.queryCompat) {
          const msg = exception.Message ?? additions.Message;
          const error4 = (0, import_smithy_client46.decorateServiceException)(exception, additions);
          if (msg) {
            error4.message = msg;
          }
          const errorObj = error4.Error ?? {};
          errorObj.Type = error4.Error?.Type;
          errorObj.Code = error4.Error?.Code;
          errorObj.Message = error4.Error?.message ?? error4.Error?.Message ?? msg;
          error4.Error = errorObj;
          const reqId = error4.$metadata.requestId;
          if (reqId) {
            error4.RequestId = reqId;
          }
          return error4;
        }
        return (0, import_smithy_client46.decorateServiceException)(exception, additions);
      }
      setQueryCompatError(output, response) {
        const queryErrorHeader = response.headers?.["x-amzn-query-error"];
        if (output !== void 0 && queryErrorHeader != null) {
          const [Code, Type] = queryErrorHeader.split(";");
          const keys = Object.keys(output);
          const Error2 = {
            Code,
            Type
          };
          output.Code = Code;
          output.Type = Type;
          for (let i32 = 0; i32 < keys.length; i32++) {
            const k32 = keys[i32];
            Error2[k32 === "message" ? "Message" : k32] = output[k32];
          }
          delete Error2.__type;
          output.Error = Error2;
        }
      }
      queryCompatOutput(queryCompatErrorData, errorData) {
        if (queryCompatErrorData.Error) {
          errorData.Error = queryCompatErrorData.Error;
        }
        if (queryCompatErrorData.Type) {
          errorData.Type = queryCompatErrorData.Type;
        }
        if (queryCompatErrorData.Code) {
          errorData.Code = queryCompatErrorData.Code;
        }
      }
      findQueryCompatibleError(registry, errorName) {
        try {
          return registry.getSchema(errorName);
        } catch (e32) {
          return registry.find((schema) => NormalizedSchema.of(schema).getMergedTraits().awsQueryError?.[0] === errorName);
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/cbor/AwsSmithyRpcV2CborProtocol.js
var init_AwsSmithyRpcV2CborProtocol4 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/cbor/AwsSmithyRpcV2CborProtocol.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/coercing-serializers.js
var init_coercing_serializers4 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/coercing-serializers.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ConfigurableSerdeContext.js
var SerdeContextConfig4;
var init_ConfigurableSerdeContext4 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ConfigurableSerdeContext.js"() {
    SerdeContextConfig4 = class {
      static {
        __name(this, "SerdeContextConfig");
      }
      serdeContext;
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/UnionSerde.js
var UnionSerde4;
var init_UnionSerde4 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/UnionSerde.js"() {
    UnionSerde4 = class {
      static {
        __name(this, "UnionSerde");
      }
      from;
      to;
      keys;
      constructor(from, to) {
        this.from = from;
        this.to = to;
        const keys = Object.keys(this.from);
        const set = new Set(keys);
        set.delete("__type");
        this.keys = set;
      }
      mark(key) {
        this.keys.delete(key);
      }
      hasUnknown() {
        return this.keys.size === 1 && Object.keys(this.to).length === 0;
      }
      writeUnknown() {
        if (this.hasUnknown()) {
          const k32 = this.keys.values().next().value;
          const v = this.from[k32];
          this.to.$unknown = [k32, v];
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReviver.js
function jsonReviver4(key, value, context) {
  if (context?.source) {
    const numericString = context.source;
    if (typeof value === "number") {
      if (value > Number.MAX_SAFE_INTEGER || value < Number.MIN_SAFE_INTEGER || numericString !== String(value)) {
        const isFractional = numericString.includes(".");
        if (isFractional) {
          return new NumericValue(numericString, "bigDecimal");
        } else {
          return BigInt(numericString);
        }
      }
    }
  }
  return value;
}
var init_jsonReviver4 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReviver.js"() {
    init_serde();
    __name(jsonReviver4, "jsonReviver");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/common.js
var import_smithy_client47, import_util_utf815, collectBodyString4;
var init_common5 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/common.js"() {
    import_smithy_client47 = __toESM(require_dist_cjs34());
    import_util_utf815 = __toESM(require_dist_cjs9());
    collectBodyString4 = /* @__PURE__ */ __name((streamBody, context) => (0, import_smithy_client47.collectBody)(streamBody, context).then((body) => (context?.utf8Encoder ?? import_util_utf815.toUtf8)(body)), "collectBodyString");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/parseJsonBody.js
var parseJsonBody4, findKey4, sanitizeErrorCode4, loadRestJsonErrorCode4;
var init_parseJsonBody4 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/parseJsonBody.js"() {
    init_common5();
    parseJsonBody4 = /* @__PURE__ */ __name((streamBody, context) => collectBodyString4(streamBody, context).then((encoded) => {
      if (encoded.length) {
        try {
          return JSON.parse(encoded);
        } catch (e32) {
          if (e32?.name === "SyntaxError") {
            Object.defineProperty(e32, "$responseBodyText", {
              value: encoded
            });
          }
          throw e32;
        }
      }
      return {};
    }), "parseJsonBody");
    findKey4 = /* @__PURE__ */ __name((object, key) => Object.keys(object).find((k32) => k32.toLowerCase() === key.toLowerCase()), "findKey");
    sanitizeErrorCode4 = /* @__PURE__ */ __name((rawValue) => {
      let cleanValue = rawValue;
      if (typeof cleanValue === "number") {
        cleanValue = cleanValue.toString();
      }
      if (cleanValue.indexOf(",") >= 0) {
        cleanValue = cleanValue.split(",")[0];
      }
      if (cleanValue.indexOf(":") >= 0) {
        cleanValue = cleanValue.split(":")[0];
      }
      if (cleanValue.indexOf("#") >= 0) {
        cleanValue = cleanValue.split("#")[1];
      }
      return cleanValue;
    }, "sanitizeErrorCode");
    loadRestJsonErrorCode4 = /* @__PURE__ */ __name((output, data3) => {
      const headerKey = findKey4(output.headers, "x-amzn-errortype");
      if (headerKey !== void 0) {
        return sanitizeErrorCode4(output.headers[headerKey]);
      }
      if (data3 && typeof data3 === "object") {
        const codeKey = findKey4(data3, "code");
        if (codeKey && data3[codeKey] !== void 0) {
          return sanitizeErrorCode4(data3[codeKey]);
        }
        if (data3["__type"] !== void 0) {
          return sanitizeErrorCode4(data3["__type"]);
        }
      }
    }, "loadRestJsonErrorCode");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeDeserializer.js
var import_util_base6418, JsonShapeDeserializer4;
var init_JsonShapeDeserializer4 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeDeserializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_util_base6418 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext4();
    init_UnionSerde4();
    init_jsonReviver4();
    init_parseJsonBody4();
    JsonShapeDeserializer4 = class extends SerdeContextConfig4 {
      static {
        __name(this, "JsonShapeDeserializer");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      async read(schema, data3) {
        return this._read(schema, typeof data3 === "string" ? JSON.parse(data3, jsonReviver4) : await parseJsonBody4(data3, this.serdeContext));
      }
      readObject(schema, data3) {
        return this._read(schema, data3);
      }
      _read(schema, value) {
        const isObject3 = value !== null && typeof value === "object";
        const ns = NormalizedSchema.of(schema);
        if (isObject3) {
          if (ns.isStructSchema()) {
            const record = value;
            const union = ns.isUnionSchema();
            const out = {};
            let nameMap = void 0;
            const { jsonName } = this.settings;
            if (jsonName) {
              nameMap = {};
            }
            let unionSerde;
            if (union) {
              unionSerde = new UnionSerde4(record, out);
            }
            for (const [memberName, memberSchema] of ns.structIterator()) {
              let fromKey = memberName;
              if (jsonName) {
                fromKey = memberSchema.getMergedTraits().jsonName ?? fromKey;
                nameMap[fromKey] = memberName;
              }
              if (union) {
                unionSerde.mark(fromKey);
              }
              if (record[fromKey] != null) {
                out[memberName] = this._read(memberSchema, record[fromKey]);
              }
            }
            if (union) {
              unionSerde.writeUnknown();
            } else if (typeof record.__type === "string") {
              for (const k32 in record) {
                const v = record[k32];
                const t = jsonName ? nameMap[k32] ?? k32 : k32;
                if (!(t in out)) {
                  out[t] = v;
                }
              }
            }
            return out;
          }
          if (Array.isArray(value) && ns.isListSchema()) {
            const listMember = ns.getValueSchema();
            const out = [];
            for (const item of value) {
              out.push(this._read(listMember, item));
            }
            return out;
          }
          if (ns.isMapSchema()) {
            const mapMember = ns.getValueSchema();
            const out = {};
            for (const _k in value) {
              out[_k] = this._read(mapMember, value[_k]);
            }
            return out;
          }
        }
        if (ns.isBlobSchema() && typeof value === "string") {
          return (0, import_util_base6418.fromBase64)(value);
        }
        const mediaType = ns.getMergedTraits().mediaType;
        if (ns.isStringSchema() && typeof value === "string" && mediaType) {
          const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
          if (isJson) {
            return LazyJsonString.from(value);
          }
          return value;
        }
        if (ns.isTimestampSchema() && value != null) {
          const format32 = determineTimestampFormat(ns, this.settings);
          switch (format32) {
            case 5:
              return parseRfc3339DateTimeWithOffset(value);
            case 6:
              return parseRfc7231DateTime(value);
            case 7:
              return parseEpochTimestamp(value);
            default:
              console.warn("Missing timestamp format, parsing value with Date constructor:", value);
              return new Date(value);
          }
        }
        if (ns.isBigIntegerSchema() && (typeof value === "number" || typeof value === "string")) {
          return BigInt(value);
        }
        if (ns.isBigDecimalSchema() && value != void 0) {
          if (value instanceof NumericValue) {
            return value;
          }
          const untyped = value;
          if (untyped.type === "bigDecimal" && "string" in untyped) {
            return new NumericValue(untyped.string, untyped.type);
          }
          return new NumericValue(String(value), "bigDecimal");
        }
        if (ns.isNumericSchema() && typeof value === "string") {
          switch (value) {
            case "Infinity":
              return Infinity;
            case "-Infinity":
              return -Infinity;
            case "NaN":
              return NaN;
          }
          return value;
        }
        if (ns.isDocumentSchema()) {
          if (isObject3) {
            const out = Array.isArray(value) ? [] : {};
            for (const k32 in value) {
              const v = value[k32];
              if (v instanceof NumericValue) {
                out[k32] = v;
              } else {
                out[k32] = this._read(ns, v);
              }
            }
            return out;
          } else {
            return structuredClone(value);
          }
        }
        return value;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReplacer.js
var NUMERIC_CONTROL_CHAR4, JsonReplacer4;
var init_jsonReplacer4 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReplacer.js"() {
    init_serde();
    NUMERIC_CONTROL_CHAR4 = String.fromCharCode(925);
    JsonReplacer4 = class {
      static {
        __name(this, "JsonReplacer");
      }
      values = /* @__PURE__ */ new Map();
      counter = 0;
      stage = 0;
      createReplacer() {
        if (this.stage === 1) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer already created.");
        }
        if (this.stage === 2) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer exhausted.");
        }
        this.stage = 1;
        return (key, value) => {
          if (value instanceof NumericValue) {
            const v = `${NUMERIC_CONTROL_CHAR4 + "nv" + this.counter++}_` + value.string;
            this.values.set(`"${v}"`, value.string);
            return v;
          }
          if (typeof value === "bigint") {
            const s = value.toString();
            const v = `${NUMERIC_CONTROL_CHAR4 + "b" + this.counter++}_` + s;
            this.values.set(`"${v}"`, s);
            return v;
          }
          return value;
        };
      }
      replaceInJson(json) {
        if (this.stage === 0) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer not created yet.");
        }
        if (this.stage === 2) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer exhausted.");
        }
        this.stage = 2;
        if (this.counter === 0) {
          return json;
        }
        for (const [key, value] of this.values) {
          json = json.replace(key, value);
        }
        return json;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeSerializer.js
var import_util_base6419, JsonShapeSerializer4;
var init_JsonShapeSerializer4 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeSerializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_util_base6419 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext4();
    init_jsonReplacer4();
    JsonShapeSerializer4 = class extends SerdeContextConfig4 {
      static {
        __name(this, "JsonShapeSerializer");
      }
      settings;
      buffer;
      useReplacer = false;
      rootSchema;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value) {
        this.rootSchema = NormalizedSchema.of(schema);
        this.buffer = this._write(this.rootSchema, value);
      }
      flush() {
        const { rootSchema, useReplacer } = this;
        this.rootSchema = void 0;
        this.useReplacer = false;
        if (rootSchema?.isStructSchema() || rootSchema?.isDocumentSchema()) {
          if (!useReplacer) {
            return JSON.stringify(this.buffer);
          }
          const replacer = new JsonReplacer4();
          return replacer.replaceInJson(JSON.stringify(this.buffer, replacer.createReplacer(), 0));
        }
        return this.buffer;
      }
      writeDiscriminatedDocument(schema, value) {
        this.write(schema, value);
        if (typeof this.buffer === "object") {
          this.buffer.__type = NormalizedSchema.of(schema).getName(true);
        }
      }
      _write(schema, value, container) {
        const isObject3 = value !== null && typeof value === "object";
        const ns = NormalizedSchema.of(schema);
        if (isObject3) {
          if (ns.isStructSchema()) {
            const record = value;
            const out = {};
            const { jsonName } = this.settings;
            let nameMap = void 0;
            if (jsonName) {
              nameMap = {};
            }
            let outCount = 0;
            for (const [memberName, memberSchema] of ns.structIterator()) {
              const serializableValue = this._write(memberSchema, record[memberName], ns);
              if (serializableValue !== void 0) {
                let targetKey = memberName;
                if (jsonName) {
                  targetKey = memberSchema.getMergedTraits().jsonName ?? memberName;
                  nameMap[memberName] = targetKey;
                }
                out[targetKey] = serializableValue;
                outCount++;
              }
            }
            if (ns.isUnionSchema() && outCount === 0) {
              const { $unknown } = record;
              if (Array.isArray($unknown)) {
                const [k32, v] = $unknown;
                out[k32] = this._write(15, v);
              }
            } else if (typeof record.__type === "string") {
              for (const k32 in record) {
                const v = record[k32];
                const targetKey = jsonName ? nameMap[k32] ?? k32 : k32;
                if (!(targetKey in out)) {
                  out[targetKey] = this._write(15, v);
                }
              }
            }
            return out;
          }
          if (Array.isArray(value) && ns.isListSchema()) {
            const listMember = ns.getValueSchema();
            const out = [];
            const sparse = !!ns.getMergedTraits().sparse;
            for (const item of value) {
              if (sparse || item != null) {
                out.push(this._write(listMember, item));
              }
            }
            return out;
          }
          if (ns.isMapSchema()) {
            const mapMember = ns.getValueSchema();
            const out = {};
            const sparse = !!ns.getMergedTraits().sparse;
            for (const _k in value) {
              const _v = value[_k];
              if (sparse || _v != null) {
                out[_k] = this._write(mapMember, _v);
              }
            }
            return out;
          }
          if (value instanceof Uint8Array && (ns.isBlobSchema() || ns.isDocumentSchema())) {
            if (ns === this.rootSchema) {
              return value;
            }
            return (this.serdeContext?.base64Encoder ?? import_util_base6419.toBase64)(value);
          }
          if (value instanceof Date && (ns.isTimestampSchema() || ns.isDocumentSchema())) {
            const format32 = determineTimestampFormat(ns, this.settings);
            switch (format32) {
              case 5:
                return value.toISOString().replace(".000Z", "Z");
              case 6:
                return dateToUtcString(value);
              case 7:
                return value.getTime() / 1e3;
              default:
                console.warn("Missing timestamp format, using epoch seconds", value);
                return value.getTime() / 1e3;
            }
          }
          if (value instanceof NumericValue) {
            this.useReplacer = true;
          }
        }
        if (value === null && container?.isStructSchema()) {
          return void 0;
        }
        if (ns.isStringSchema()) {
          if (typeof value === "undefined" && ns.isIdempotencyToken()) {
            return (0, import_uuid.v4)();
          }
          const mediaType = ns.getMergedTraits().mediaType;
          if (value != null && mediaType) {
            const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
            if (isJson) {
              return LazyJsonString.from(value);
            }
          }
          return value;
        }
        if (typeof value === "number" && ns.isNumericSchema()) {
          if (Math.abs(value) === Infinity || isNaN(value)) {
            return String(value);
          }
          return value;
        }
        if (typeof value === "string" && ns.isBlobSchema()) {
          if (ns === this.rootSchema) {
            return value;
          }
          return (this.serdeContext?.base64Encoder ?? import_util_base6419.toBase64)(value);
        }
        if (typeof value === "bigint") {
          this.useReplacer = true;
        }
        if (ns.isDocumentSchema()) {
          if (isObject3) {
            const out = Array.isArray(value) ? [] : {};
            for (const k32 in value) {
              const v = value[k32];
              if (v instanceof NumericValue) {
                this.useReplacer = true;
                out[k32] = v;
              } else {
                out[k32] = this._write(ns, v);
              }
            }
            return out;
          } else {
            return structuredClone(value);
          }
        }
        return value;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonCodec.js
var JsonCodec4;
var init_JsonCodec4 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonCodec.js"() {
    init_ConfigurableSerdeContext4();
    init_JsonShapeDeserializer4();
    init_JsonShapeSerializer4();
    JsonCodec4 = class extends SerdeContextConfig4 {
      static {
        __name(this, "JsonCodec");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      createSerializer() {
        const serializer = new JsonShapeSerializer4(this.settings);
        serializer.setSerdeContext(this.serdeContext);
        return serializer;
      }
      createDeserializer() {
        const deserializer = new JsonShapeDeserializer4(this.settings);
        deserializer.setSerdeContext(this.serdeContext);
        return deserializer;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJsonRpcProtocol.js
var init_AwsJsonRpcProtocol4 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJsonRpcProtocol.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_0Protocol.js
var init_AwsJson1_0Protocol4 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_0Protocol.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_1Protocol.js
var init_AwsJson1_1Protocol4 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_1Protocol.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsRestJsonProtocol.js
var AwsRestJsonProtocol4;
var init_AwsRestJsonProtocol4 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsRestJsonProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib4();
    init_JsonCodec4();
    init_parseJsonBody4();
    AwsRestJsonProtocol4 = class extends HttpBindingProtocol {
      static {
        __name(this, "AwsRestJsonProtocol");
      }
      serializer;
      deserializer;
      codec;
      mixin = new ProtocolLib4();
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32 }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32
        });
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 7
          },
          httpBindings: true,
          jsonName: true
        };
        this.codec = new JsonCodec4(settings);
        this.serializer = new HttpInterceptingShapeSerializer(this.codec.createSerializer(), settings);
        this.deserializer = new HttpInterceptingShapeDeserializer(this.codec.createDeserializer(), settings);
      }
      getShapeId() {
        return "aws.protocols#restJson1";
      }
      getPayloadCodec() {
        return this.codec;
      }
      setSerdeContext(serdeContext) {
        this.codec.setSerdeContext(serdeContext);
        super.setSerdeContext(serdeContext);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        const inputSchema = NormalizedSchema.of(operationSchema.input);
        if (!request4.headers["content-type"]) {
          const contentType = this.mixin.resolveRestContentType(this.getDefaultContentType(), inputSchema);
          if (contentType) {
            request4.headers["content-type"] = contentType;
          }
        }
        if (request4.body == null && request4.headers["content-type"] === this.getDefaultContentType()) {
          request4.body = "{}";
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        const output = await super.deserializeResponse(operationSchema, context, response);
        const outputSchema = NormalizedSchema.of(operationSchema.output);
        for (const [name, member7] of outputSchema.structIterator()) {
          if (member7.getMemberTraits().httpPayload && !(name in output)) {
            output[name] = null;
          }
        }
        return output;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = loadRestJsonErrorCode4(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        await this.deserializeHttpMessage(errorSchema, context, response, dataObject);
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().jsonName ?? name;
          output[name] = errorDeserializer.readObject(member7, dataObject[target]);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      getDefaultContentType() {
        return "application/json";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/awsExpectUnion.js
var init_awsExpectUnion4 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/awsExpectUnion.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeDeserializer.js
var import_xml_builder7, import_smithy_client48, import_util_utf816, XmlShapeDeserializer3;
var init_XmlShapeDeserializer4 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeDeserializer.js"() {
    import_xml_builder7 = __toESM(require_dist_cjs47());
    init_protocols();
    init_schema4();
    import_smithy_client48 = __toESM(require_dist_cjs34());
    import_util_utf816 = __toESM(require_dist_cjs9());
    init_ConfigurableSerdeContext4();
    init_UnionSerde4();
    XmlShapeDeserializer3 = class extends SerdeContextConfig4 {
      static {
        __name(this, "XmlShapeDeserializer");
      }
      settings;
      stringDeserializer;
      constructor(settings) {
        super();
        this.settings = settings;
        this.stringDeserializer = new FromStringShapeDeserializer(settings);
      }
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
        this.stringDeserializer.setSerdeContext(serdeContext);
      }
      read(schema, bytes, key) {
        const ns = NormalizedSchema.of(schema);
        const memberSchemas = ns.getMemberSchemas();
        const isEventPayload = ns.isStructSchema() && ns.isMemberSchema() && !!Object.values(memberSchemas).find((memberNs) => {
          return !!memberNs.getMemberTraits().eventPayload;
        });
        if (isEventPayload) {
          const output = {};
          const memberName = Object.keys(memberSchemas)[0];
          const eventMemberSchema = memberSchemas[memberName];
          if (eventMemberSchema.isBlobSchema()) {
            output[memberName] = bytes;
          } else {
            output[memberName] = this.read(memberSchemas[memberName], bytes);
          }
          return output;
        }
        const xmlString = (this.serdeContext?.utf8Encoder ?? import_util_utf816.toUtf8)(bytes);
        const parsedObject = this.parseXml(xmlString);
        return this.readSchema(schema, key ? parsedObject[key] : parsedObject);
      }
      readSchema(_schema, value) {
        const ns = NormalizedSchema.of(_schema);
        if (ns.isUnitSchema()) {
          return;
        }
        const traits = ns.getMergedTraits();
        if (ns.isListSchema() && !Array.isArray(value)) {
          return this.readSchema(ns, [value]);
        }
        if (value == null) {
          return value;
        }
        if (typeof value === "object") {
          const flat = !!traits.xmlFlattened;
          if (ns.isListSchema()) {
            const listValue = ns.getValueSchema();
            const buffer2 = [];
            const sourceKey = listValue.getMergedTraits().xmlName ?? "member";
            const source = flat ? value : (value[0] ?? value)[sourceKey];
            if (source == null) {
              return buffer2;
            }
            const sourceArray = Array.isArray(source) ? source : [source];
            for (const v of sourceArray) {
              buffer2.push(this.readSchema(listValue, v));
            }
            return buffer2;
          }
          const buffer = {};
          if (ns.isMapSchema()) {
            const keyNs = ns.getKeySchema();
            const memberNs = ns.getValueSchema();
            let entries;
            if (flat) {
              entries = Array.isArray(value) ? value : [value];
            } else {
              entries = Array.isArray(value.entry) ? value.entry : [value.entry];
            }
            const keyProperty = keyNs.getMergedTraits().xmlName ?? "key";
            const valueProperty = memberNs.getMergedTraits().xmlName ?? "value";
            for (const entry of entries) {
              const key = entry[keyProperty];
              const value2 = entry[valueProperty];
              buffer[key] = this.readSchema(memberNs, value2);
            }
            return buffer;
          }
          if (ns.isStructSchema()) {
            const union = ns.isUnionSchema();
            let unionSerde;
            if (union) {
              unionSerde = new UnionSerde4(value, buffer);
            }
            for (const [memberName, memberSchema] of ns.structIterator()) {
              const memberTraits = memberSchema.getMergedTraits();
              const xmlObjectKey = !memberTraits.httpPayload ? memberSchema.getMemberTraits().xmlName ?? memberName : memberTraits.xmlName ?? memberSchema.getName();
              if (union) {
                unionSerde.mark(xmlObjectKey);
              }
              if (value[xmlObjectKey] != null) {
                buffer[memberName] = this.readSchema(memberSchema, value[xmlObjectKey]);
              }
            }
            if (union) {
              unionSerde.writeUnknown();
            }
            return buffer;
          }
          if (ns.isDocumentSchema()) {
            return value;
          }
          throw new Error(`@aws-sdk/core/protocols - xml deserializer unhandled schema type for ${ns.getName(true)}`);
        }
        if (ns.isListSchema()) {
          return [];
        }
        if (ns.isMapSchema() || ns.isStructSchema()) {
          return {};
        }
        return this.stringDeserializer.read(ns, value);
      }
      parseXml(xml) {
        if (xml.length) {
          let parsedObj;
          try {
            parsedObj = (0, import_xml_builder7.parseXML)(xml);
          } catch (e32) {
            if (e32 && typeof e32 === "object") {
              Object.defineProperty(e32, "$responseBodyText", {
                value: xml
              });
            }
            throw e32;
          }
          const textNodeName = "#text";
          const key = Object.keys(parsedObj)[0];
          const parsedObjToReturn = parsedObj[key];
          if (parsedObjToReturn[textNodeName]) {
            parsedObjToReturn[key] = parsedObjToReturn[textNodeName];
            delete parsedObjToReturn[textNodeName];
          }
          return (0, import_smithy_client48.getValueFromTextNode)(parsedObjToReturn);
        }
        return {};
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QueryShapeSerializer.js
var import_smithy_client49, import_util_base6420, QueryShapeSerializer3;
var init_QueryShapeSerializer4 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QueryShapeSerializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_smithy_client49 = __toESM(require_dist_cjs34());
    import_util_base6420 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext4();
    QueryShapeSerializer3 = class extends SerdeContextConfig4 {
      static {
        __name(this, "QueryShapeSerializer");
      }
      settings;
      buffer;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value, prefix = "") {
        if (this.buffer === void 0) {
          this.buffer = "";
        }
        const ns = NormalizedSchema.of(schema);
        if (prefix && !prefix.endsWith(".")) {
          prefix += ".";
        }
        if (ns.isBlobSchema()) {
          if (typeof value === "string" || value instanceof Uint8Array) {
            this.writeKey(prefix);
            this.writeValue((this.serdeContext?.base64Encoder ?? import_util_base6420.toBase64)(value));
          }
        } else if (ns.isBooleanSchema() || ns.isNumericSchema() || ns.isStringSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(String(value));
          } else if (ns.isIdempotencyToken()) {
            this.writeKey(prefix);
            this.writeValue((0, import_uuid.v4)());
          }
        } else if (ns.isBigIntegerSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(String(value));
          }
        } else if (ns.isBigDecimalSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(value instanceof NumericValue ? value.string : String(value));
          }
        } else if (ns.isTimestampSchema()) {
          if (value instanceof Date) {
            this.writeKey(prefix);
            const format32 = determineTimestampFormat(ns, this.settings);
            switch (format32) {
              case 5:
                this.writeValue(value.toISOString().replace(".000Z", "Z"));
                break;
              case 6:
                this.writeValue((0, import_smithy_client49.dateToUtcString)(value));
                break;
              case 7:
                this.writeValue(String(value.getTime() / 1e3));
                break;
            }
          }
        } else if (ns.isDocumentSchema()) {
          if (Array.isArray(value)) {
            this.write(64 | 15, value, prefix);
          } else if (value instanceof Date) {
            this.write(4, value, prefix);
          } else if (value instanceof Uint8Array) {
            this.write(21, value, prefix);
          } else if (value && typeof value === "object") {
            this.write(128 | 15, value, prefix);
          } else {
            this.writeKey(prefix);
            this.writeValue(String(value));
          }
        } else if (ns.isListSchema()) {
          if (Array.isArray(value)) {
            if (value.length === 0) {
              if (this.settings.serializeEmptyLists) {
                this.writeKey(prefix);
                this.writeValue("");
              }
            } else {
              const member7 = ns.getValueSchema();
              const flat = this.settings.flattenLists || ns.getMergedTraits().xmlFlattened;
              let i32 = 1;
              for (const item of value) {
                if (item == null) {
                  continue;
                }
                const traits = member7.getMergedTraits();
                const suffix = this.getKey("member", traits.xmlName, traits.ec2QueryName);
                const key = flat ? `${prefix}${i32}` : `${prefix}${suffix}.${i32}`;
                this.write(member7, item, key);
                ++i32;
              }
            }
          }
        } else if (ns.isMapSchema()) {
          if (value && typeof value === "object") {
            const keySchema = ns.getKeySchema();
            const memberSchema = ns.getValueSchema();
            const flat = ns.getMergedTraits().xmlFlattened;
            let i32 = 1;
            for (const k32 in value) {
              const v = value[k32];
              if (v == null) {
                continue;
              }
              const keyTraits = keySchema.getMergedTraits();
              const keySuffix = this.getKey("key", keyTraits.xmlName, keyTraits.ec2QueryName);
              const key = flat ? `${prefix}${i32}.${keySuffix}` : `${prefix}entry.${i32}.${keySuffix}`;
              const valTraits = memberSchema.getMergedTraits();
              const valueSuffix = this.getKey("value", valTraits.xmlName, valTraits.ec2QueryName);
              const valueKey = flat ? `${prefix}${i32}.${valueSuffix}` : `${prefix}entry.${i32}.${valueSuffix}`;
              this.write(keySchema, k32, key);
              this.write(memberSchema, v, valueKey);
              ++i32;
            }
          }
        } else if (ns.isStructSchema()) {
          if (value && typeof value === "object") {
            let didWriteMember = false;
            for (const [memberName, member7] of ns.structIterator()) {
              if (value[memberName] == null && !member7.isIdempotencyToken()) {
                continue;
              }
              const traits = member7.getMergedTraits();
              const suffix = this.getKey(memberName, traits.xmlName, traits.ec2QueryName, "struct");
              const key = `${prefix}${suffix}`;
              this.write(member7, value[memberName], key);
              didWriteMember = true;
            }
            if (!didWriteMember && ns.isUnionSchema()) {
              const { $unknown } = value;
              if (Array.isArray($unknown)) {
                const [k32, v] = $unknown;
                const key = `${prefix}${k32}`;
                this.write(15, v, key);
              }
            }
          }
        } else if (ns.isUnitSchema()) {
        } else {
          throw new Error(`@aws-sdk/core/protocols - QuerySerializer unrecognized schema type ${ns.getName(true)}`);
        }
      }
      flush() {
        if (this.buffer === void 0) {
          throw new Error("@aws-sdk/core/protocols - QuerySerializer cannot flush with nothing written to buffer.");
        }
        const str = this.buffer;
        delete this.buffer;
        return str;
      }
      getKey(memberName, xmlName, ec2QueryName, keySource) {
        const { ec2, capitalizeKeys } = this.settings;
        if (ec2 && ec2QueryName) {
          return ec2QueryName;
        }
        const key = xmlName ?? memberName;
        if (capitalizeKeys && keySource === "struct") {
          return key[0].toUpperCase() + key.slice(1);
        }
        return key;
      }
      writeKey(key) {
        if (key.endsWith(".")) {
          key = key.slice(0, key.length - 1);
        }
        this.buffer += `&${extendedEncodeURIComponent(key)}=`;
      }
      writeValue(value) {
        this.buffer += extendedEncodeURIComponent(value);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsQueryProtocol.js
var AwsQueryProtocol3;
var init_AwsQueryProtocol4 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsQueryProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib4();
    init_XmlShapeDeserializer4();
    init_QueryShapeSerializer4();
    AwsQueryProtocol3 = class extends RpcProtocol {
      static {
        __name(this, "AwsQueryProtocol");
      }
      options;
      serializer;
      deserializer;
      mixin = new ProtocolLib4();
      constructor(options) {
        super({
          defaultNamespace: options.defaultNamespace,
          errorTypeRegistries: options.errorTypeRegistries
        });
        this.options = options;
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 5
          },
          httpBindings: false,
          xmlNamespace: options.xmlNamespace,
          serviceNamespace: options.defaultNamespace,
          serializeEmptyLists: true
        };
        this.serializer = new QueryShapeSerializer3(settings);
        this.deserializer = new XmlShapeDeserializer3(settings);
      }
      getShapeId() {
        return "aws.protocols#awsQuery";
      }
      setSerdeContext(serdeContext) {
        this.serializer.setSerdeContext(serdeContext);
        this.deserializer.setSerdeContext(serdeContext);
      }
      getPayloadCodec() {
        throw new Error("AWSQuery protocol has no payload codec.");
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        if (!request4.path.endsWith("/")) {
          request4.path += "/";
        }
        request4.headers["content-type"] = "application/x-www-form-urlencoded";
        if (deref(operationSchema.input) === "unit" || !request4.body) {
          request4.body = "";
        }
        const action = operationSchema.name.split("#")[1] ?? operationSchema.name;
        request4.body = `Action=${action}&Version=${this.options.version}` + request4.body;
        if (request4.body.endsWith("&")) {
          request4.body = request4.body.slice(-1);
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        const deserializer = this.deserializer;
        const ns = NormalizedSchema.of(operationSchema.output);
        const dataObject = {};
        if (response.statusCode >= 300) {
          const bytes2 = await collectBody(response.body, context);
          if (bytes2.byteLength > 0) {
            Object.assign(dataObject, await deserializer.read(15, bytes2));
          }
          await this.handleError(operationSchema, context, response, dataObject, this.deserializeMetadata(response));
        }
        for (const header in response.headers) {
          const value = response.headers[header];
          delete response.headers[header];
          response.headers[header.toLowerCase()] = value;
        }
        const shortName = operationSchema.name.split("#")[1] ?? operationSchema.name;
        const awsQueryResultKey = ns.isStructSchema() && this.useNestedResult() ? shortName + "Result" : void 0;
        const bytes = await collectBody(response.body, context);
        if (bytes.byteLength > 0) {
          Object.assign(dataObject, await deserializer.read(ns, bytes, awsQueryResultKey));
        }
        dataObject.$metadata = this.deserializeMetadata(response);
        return dataObject;
      }
      useNestedResult() {
        return true;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = this.loadQueryErrorCode(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const errorData = this.loadQueryError(dataObject) ?? {};
        const message2 = this.loadQueryErrorMessage(dataObject);
        errorData.message = message2;
        errorData.Error = {
          Type: errorData.Type,
          Code: errorData.Code,
          Message: message2
        };
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, errorData, metadata, this.mixin.findQueryCompatibleError);
        const ns = NormalizedSchema.of(errorSchema);
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        const output = {
          Type: errorData.Error.Type,
          Code: errorData.Error.Code,
          Error: errorData.Error
        };
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().xmlName ?? name;
          const value = errorData[target] ?? dataObject[target];
          output[name] = this.deserializer.readSchema(member7, value);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      loadQueryErrorCode(output, data3) {
        const code = (data3.Errors?.[0]?.Error ?? data3.Errors?.Error ?? data3.Error)?.Code;
        if (code !== void 0) {
          return code;
        }
        if (output.statusCode == 404) {
          return "NotFound";
        }
      }
      loadQueryError(data3) {
        return data3.Errors?.[0]?.Error ?? data3.Errors?.Error ?? data3.Error;
      }
      loadQueryErrorMessage(data3) {
        const errorData = this.loadQueryError(data3);
        return errorData?.message ?? errorData?.Message ?? data3.message ?? data3.Message ?? "Unknown";
      }
      getDefaultContentType() {
        return "application/x-www-form-urlencoded";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsEc2QueryProtocol.js
var init_AwsEc2QueryProtocol4 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsEc2QueryProtocol.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QuerySerializerSettings.js
var init_QuerySerializerSettings4 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QuerySerializerSettings.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/parseXmlBody.js
var init_parseXmlBody4 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/parseXmlBody.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeSerializer.js
var init_XmlShapeSerializer4 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeSerializer.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlCodec.js
var init_XmlCodec4 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlCodec.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/AwsRestXmlProtocol.js
var init_AwsRestXmlProtocol4 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/AwsRestXmlProtocol.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/index.js
var init_protocols6 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/core/dist-es/submodules/protocols/index.js"() {
    init_AwsSmithyRpcV2CborProtocol4();
    init_coercing_serializers4();
    init_AwsJson1_0Protocol4();
    init_AwsJson1_1Protocol4();
    init_AwsJsonRpcProtocol4();
    init_AwsRestJsonProtocol4();
    init_JsonCodec4();
    init_JsonShapeDeserializer4();
    init_JsonShapeSerializer4();
    init_awsExpectUnion4();
    init_parseJsonBody4();
    init_AwsEc2QueryProtocol4();
    init_AwsQueryProtocol4();
    init_QuerySerializerSettings4();
    init_QueryShapeSerializer4();
    init_AwsRestXmlProtocol4();
    init_XmlCodec4();
    init_XmlShapeDeserializer4();
    init_XmlShapeSerializer4();
    init_parseXmlBody4();
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/bdd.js
var import_util_endpoints13, k5, a5, b5, c5, d5, e5, f5, g5, h5, i5, j5, _data5, root5, r5, nodes5, bdd5;
var init_bdd5 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/bdd.js"() {
    import_util_endpoints13 = __toESM(require_dist_cjs20());
    k5 = "ref";
    a5 = -1;
    b5 = true;
    c5 = "isSet";
    d5 = "PartitionResult";
    e5 = "booleanEquals";
    f5 = "getAttr";
    g5 = { [k5]: "Endpoint" };
    h5 = { [k5]: d5 };
    i5 = {};
    j5 = [{ [k5]: "Region" }];
    _data5 = {
      conditions: [
        [c5, [g5]],
        [c5, j5],
        ["aws.partition", j5, d5],
        [e5, [{ [k5]: "UseFIPS" }, b5]],
        [e5, [{ [k5]: "UseDualStack" }, b5]],
        [e5, [{ fn: f5, argv: [h5, "supportsDualStack"] }, b5]],
        [e5, [{ fn: f5, argv: [h5, "supportsFIPS"] }, b5]],
        ["stringEquals", [{ fn: f5, argv: [h5, "name"] }, "aws-us-gov"]]
      ],
      results: [
        [a5],
        [a5, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a5, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [g5, i5],
        ["https://portal.sso-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", i5],
        [a5, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://portal.sso.{Region}.amazonaws.com", i5],
        ["https://portal.sso-fips.{Region}.{PartitionResult#dnsSuffix}", i5],
        [a5, "FIPS is enabled but this partition does not support FIPS"],
        ["https://portal.sso.{Region}.{PartitionResult#dualStackDnsSuffix}", i5],
        [a5, "DualStack is enabled but this partition does not support DualStack"],
        ["https://portal.sso.{Region}.{PartitionResult#dnsSuffix}", i5],
        [a5, "Invalid Configuration: Missing Region"]
      ]
    };
    root5 = 2;
    r5 = 1e8;
    nodes5 = new Int32Array([
      -1,
      1,
      -1,
      0,
      13,
      3,
      1,
      4,
      r5 + 12,
      2,
      5,
      r5 + 12,
      3,
      8,
      6,
      4,
      7,
      r5 + 11,
      5,
      r5 + 9,
      r5 + 10,
      4,
      11,
      9,
      6,
      10,
      r5 + 8,
      7,
      r5 + 6,
      r5 + 7,
      5,
      12,
      r5 + 5,
      6,
      r5 + 4,
      r5 + 5,
      3,
      r5 + 1,
      14,
      4,
      r5 + 2,
      r5 + 3
    ]);
    bdd5 = import_util_endpoints13.BinaryDecisionDiagram.from(nodes5, root5, _data5.conditions, _data5.results);
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/endpointResolver.js
var import_util_endpoints14, import_util_endpoints15, cache5, defaultEndpointResolver5;
var init_endpointResolver5 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/endpointResolver.js"() {
    import_util_endpoints14 = __toESM(require_dist_cjs21());
    import_util_endpoints15 = __toESM(require_dist_cjs20());
    init_bdd5();
    cache5 = new import_util_endpoints15.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    defaultEndpointResolver5 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache5.get(endpointParams, () => (0, import_util_endpoints15.decideEndpoint)(bdd5, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    import_util_endpoints15.customEndpointFunctions.aws = import_util_endpoints14.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/SSOServiceException.js
var import_smithy_client50, SSOServiceException2;
var init_SSOServiceException2 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/SSOServiceException.js"() {
    import_smithy_client50 = __toESM(require_dist_cjs34());
    SSOServiceException2 = class _SSOServiceException extends import_smithy_client50.ServiceException {
      static {
        __name(this, "SSOServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _SSOServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/errors.js
var InvalidRequestException3, ResourceNotFoundException2, TooManyRequestsException2, UnauthorizedException2;
var init_errors5 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/errors.js"() {
    init_SSOServiceException2();
    InvalidRequestException3 = class _InvalidRequestException extends SSOServiceException2 {
      static {
        __name(this, "InvalidRequestException");
      }
      name = "InvalidRequestException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidRequestException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidRequestException.prototype);
      }
    };
    ResourceNotFoundException2 = class _ResourceNotFoundException extends SSOServiceException2 {
      static {
        __name(this, "ResourceNotFoundException");
      }
      name = "ResourceNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ResourceNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceNotFoundException.prototype);
      }
    };
    TooManyRequestsException2 = class _TooManyRequestsException extends SSOServiceException2 {
      static {
        __name(this, "TooManyRequestsException");
      }
      name = "TooManyRequestsException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TooManyRequestsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyRequestsException.prototype);
      }
    };
    UnauthorizedException2 = class _UnauthorizedException extends SSOServiceException2 {
      static {
        __name(this, "UnauthorizedException");
      }
      name = "UnauthorizedException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "UnauthorizedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnauthorizedException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/schemas/schemas_0.js
var _ATT2, _GRC2, _GRCR2, _GRCRe2, _IRE3, _RC2, _RNFE2, _SAKT2, _STT2, _TMRE3, _UE2, _aI2, _aKI3, _aT4, _ai2, _c5, _e5, _ex2, _h4, _hE5, _hH2, _hQ2, _m4, _rC2, _rN2, _rn2, _s5, _sAK3, _sT3, _xasbt2, n05, _s_registry5, SSOServiceException$2, n0_registry5, InvalidRequestException$3, ResourceNotFoundException$2, TooManyRequestsException$2, UnauthorizedException$2, errorTypeRegistries5, AccessTokenType2, SecretAccessKeyType2, SessionTokenType2, GetRoleCredentialsRequest$2, GetRoleCredentialsResponse$2, RoleCredentials$2, GetRoleCredentials$2;
var init_schemas_05 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/schemas/schemas_0.js"() {
    init_schema4();
    init_errors5();
    init_SSOServiceException2();
    _ATT2 = "AccessTokenType";
    _GRC2 = "GetRoleCredentials";
    _GRCR2 = "GetRoleCredentialsRequest";
    _GRCRe2 = "GetRoleCredentialsResponse";
    _IRE3 = "InvalidRequestException";
    _RC2 = "RoleCredentials";
    _RNFE2 = "ResourceNotFoundException";
    _SAKT2 = "SecretAccessKeyType";
    _STT2 = "SessionTokenType";
    _TMRE3 = "TooManyRequestsException";
    _UE2 = "UnauthorizedException";
    _aI2 = "accountId";
    _aKI3 = "accessKeyId";
    _aT4 = "accessToken";
    _ai2 = "account_id";
    _c5 = "client";
    _e5 = "error";
    _ex2 = "expiration";
    _h4 = "http";
    _hE5 = "httpError";
    _hH2 = "httpHeader";
    _hQ2 = "httpQuery";
    _m4 = "message";
    _rC2 = "roleCredentials";
    _rN2 = "roleName";
    _rn2 = "role_name";
    _s5 = "smithy.ts.sdk.synthetic.com.amazonaws.sso";
    _sAK3 = "secretAccessKey";
    _sT3 = "sessionToken";
    _xasbt2 = "x-amz-sso_bearer_token";
    n05 = "com.amazonaws.sso";
    _s_registry5 = TypeRegistry.for(_s5);
    SSOServiceException$2 = [-3, _s5, "SSOServiceException", 0, [], []];
    _s_registry5.registerError(SSOServiceException$2, SSOServiceException2);
    n0_registry5 = TypeRegistry.for(n05);
    InvalidRequestException$3 = [-3, n05, _IRE3, { [_e5]: _c5, [_hE5]: 400 }, [_m4], [0]];
    n0_registry5.registerError(InvalidRequestException$3, InvalidRequestException3);
    ResourceNotFoundException$2 = [-3, n05, _RNFE2, { [_e5]: _c5, [_hE5]: 404 }, [_m4], [0]];
    n0_registry5.registerError(ResourceNotFoundException$2, ResourceNotFoundException2);
    TooManyRequestsException$2 = [-3, n05, _TMRE3, { [_e5]: _c5, [_hE5]: 429 }, [_m4], [0]];
    n0_registry5.registerError(TooManyRequestsException$2, TooManyRequestsException2);
    UnauthorizedException$2 = [-3, n05, _UE2, { [_e5]: _c5, [_hE5]: 401 }, [_m4], [0]];
    n0_registry5.registerError(UnauthorizedException$2, UnauthorizedException2);
    errorTypeRegistries5 = [_s_registry5, n0_registry5];
    AccessTokenType2 = [0, n05, _ATT2, 8, 0];
    SecretAccessKeyType2 = [0, n05, _SAKT2, 8, 0];
    SessionTokenType2 = [0, n05, _STT2, 8, 0];
    GetRoleCredentialsRequest$2 = [
      3,
      n05,
      _GRCR2,
      0,
      [_rN2, _aI2, _aT4],
      [
        [0, { [_hQ2]: _rn2 }],
        [0, { [_hQ2]: _ai2 }],
        [() => AccessTokenType2, { [_hH2]: _xasbt2 }]
      ],
      3
    ];
    GetRoleCredentialsResponse$2 = [
      3,
      n05,
      _GRCRe2,
      0,
      [_rC2],
      [[() => RoleCredentials$2, 0]]
    ];
    RoleCredentials$2 = [
      3,
      n05,
      _RC2,
      0,
      [_aKI3, _sAK3, _sT3, _ex2],
      [0, [() => SecretAccessKeyType2, 0], [() => SessionTokenType2, 0], 1]
    ];
    GetRoleCredentials$2 = [
      9,
      n05,
      _GRC2,
      { [_h4]: ["GET", "/federation/credentials", 200] },
      () => GetRoleCredentialsRequest$2,
      () => GetRoleCredentialsResponse$2
    ];
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.shared.js
var import_smithy_client51, import_url_parser6, import_util_base6421, import_util_utf817, getRuntimeConfig9;
var init_runtimeConfig_shared5 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.shared.js"() {
    init_httpAuthSchemes4();
    init_protocols6();
    init_dist_es();
    import_smithy_client51 = __toESM(require_dist_cjs34());
    import_url_parser6 = __toESM(require_dist_cjs18());
    import_util_base6421 = __toESM(require_dist_cjs10());
    import_util_utf817 = __toESM(require_dist_cjs9());
    init_httpAuthSchemeProvider5();
    init_endpointResolver5();
    init_schemas_05();
    getRuntimeConfig9 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2019-06-10",
        base64Decoder: config2?.base64Decoder ?? import_util_base6421.fromBase64,
        base64Encoder: config2?.base64Encoder ?? import_util_base6421.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver5,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSSOHttpAuthSchemeProvider2,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer3()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        logger: config2?.logger ?? new import_smithy_client51.NoOpLogger(),
        protocol: config2?.protocol ?? AwsRestJsonProtocol4,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.sso",
          errorTypeRegistries: errorTypeRegistries5,
          version: "2019-06-10",
          serviceTarget: "SWBPortalService"
        },
        serviceId: config2?.serviceId ?? "SSO",
        urlParser: config2?.urlParser ?? import_url_parser6.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? import_util_utf817.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? import_util_utf817.toUtf8
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.js
var import_util_user_agent_node5, import_config_resolver9, import_hash_node5, import_middleware_retry9, import_node_config_provider5, import_node_http_handler5, import_smithy_client52, import_util_body_length_node5, import_util_defaults_mode_node5, import_util_retry10, getRuntimeConfig10;
var init_runtimeConfig5 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.js"() {
    init_package3();
    init_client6();
    init_httpAuthSchemes4();
    import_util_user_agent_node5 = __toESM(require_dist_cjs75());
    import_config_resolver9 = __toESM(require_dist_cjs25());
    import_hash_node5 = __toESM(require_dist_cjs44());
    import_middleware_retry9 = __toESM(require_dist_cjs71());
    import_node_config_provider5 = __toESM(require_dist_cjs29());
    import_node_http_handler5 = __toESM(require_dist_cjs13());
    import_smithy_client52 = __toESM(require_dist_cjs34());
    import_util_body_length_node5 = __toESM(require_dist_cjs45());
    import_util_defaults_mode_node5 = __toESM(require_dist_cjs46());
    import_util_retry10 = __toESM(require_dist_cjs22());
    init_runtimeConfig_shared5();
    getRuntimeConfig10 = /* @__PURE__ */ __name((config2) => {
      (0, import_smithy_client52.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, import_util_defaults_mode_node5.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(import_smithy_client52.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig9(config2);
      emitWarningIfUnsupportedVersion9(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, import_node_config_provider5.loadConfig)(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS3, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? import_util_body_length_node5.calculateBodyLength,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, import_util_user_agent_node5.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_default3.version }),
        maxAttempts: config2?.maxAttempts ?? (0, import_node_config_provider5.loadConfig)(import_middleware_retry9.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, import_node_config_provider5.loadConfig)(import_config_resolver9.NODE_REGION_CONFIG_OPTIONS, { ...import_config_resolver9.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: import_node_http_handler5.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, import_node_config_provider5.loadConfig)({
          ...import_middleware_retry9.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || import_util_retry10.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? import_hash_node5.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? import_node_http_handler5.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, import_node_config_provider5.loadConfig)(import_config_resolver9.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, import_node_config_provider5.loadConfig)(import_config_resolver9.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, import_node_config_provider5.loadConfig)(import_util_user_agent_node5.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration5, resolveHttpAuthRuntimeConfig5;
var init_httpAuthExtensionConfiguration5 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration5 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig5 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeExtensions.js
var import_region_config_resolver6, import_protocol_http22, import_smithy_client53, resolveRuntimeExtensions5;
var init_runtimeExtensions5 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeExtensions.js"() {
    import_region_config_resolver6 = __toESM(require_dist_cjs48());
    import_protocol_http22 = __toESM(require_dist_cjs2());
    import_smithy_client53 = __toESM(require_dist_cjs34());
    init_httpAuthExtensionConfiguration5();
    resolveRuntimeExtensions5 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign((0, import_region_config_resolver6.getAwsRegionExtensionConfiguration)(runtimeConfig), (0, import_smithy_client53.getDefaultExtensionConfiguration)(runtimeConfig), (0, import_protocol_http22.getHttpHandlerExtensionConfiguration)(runtimeConfig), getHttpAuthExtensionConfiguration5(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, (0, import_region_config_resolver6.resolveAwsRegionExtensionConfiguration)(extensionConfiguration), (0, import_smithy_client53.resolveDefaultRuntimeConfig)(extensionConfiguration), (0, import_protocol_http22.resolveHttpHandlerRuntimeConfig)(extensionConfiguration), resolveHttpAuthRuntimeConfig5(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSOClient.js
var import_middleware_host_header5, import_middleware_logger5, import_middleware_recursion_detection5, import_middleware_user_agent5, import_config_resolver10, import_middleware_content_length5, import_middleware_endpoint11, import_middleware_retry10, import_smithy_client54, SSOClient2;
var init_SSOClient2 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSOClient.js"() {
    import_middleware_host_header5 = __toESM(require_dist_cjs3());
    import_middleware_logger5 = __toESM(require_dist_cjs4());
    import_middleware_recursion_detection5 = __toESM(require_dist_cjs5());
    import_middleware_user_agent5 = __toESM(require_dist_cjs69());
    import_config_resolver10 = __toESM(require_dist_cjs25());
    init_dist_es();
    init_schema4();
    import_middleware_content_length5 = __toESM(require_dist_cjs26());
    import_middleware_endpoint11 = __toESM(require_dist_cjs31());
    import_middleware_retry10 = __toESM(require_dist_cjs71());
    import_smithy_client54 = __toESM(require_dist_cjs34());
    init_httpAuthSchemeProvider5();
    init_EndpointParameters5();
    init_runtimeConfig5();
    init_runtimeExtensions5();
    SSOClient2 = class extends import_smithy_client54.Client {
      static {
        __name(this, "SSOClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig10(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters5(_config_0);
        const _config_2 = (0, import_middleware_user_agent5.resolveUserAgentConfig)(_config_1);
        const _config_3 = (0, import_middleware_retry10.resolveRetryConfig)(_config_2);
        const _config_4 = (0, import_config_resolver10.resolveRegionConfig)(_config_3);
        const _config_5 = (0, import_middleware_host_header5.resolveHostHeaderConfig)(_config_4);
        const _config_6 = (0, import_middleware_endpoint11.resolveEndpointConfig)(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig5(_config_6);
        const _config_8 = resolveRuntimeExtensions5(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin(this.config));
        this.middlewareStack.use((0, import_middleware_user_agent5.getUserAgentPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_retry10.getRetryPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_content_length5.getContentLengthPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_host_header5.getHostHeaderPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_logger5.getLoggerPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_recursion_detection5.getRecursionDetectionPlugin)(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: defaultSSOHttpAuthSchemeParametersProvider2,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/GetRoleCredentialsCommand.js
var import_middleware_endpoint12, import_smithy_client55, GetRoleCredentialsCommand2;
var init_GetRoleCredentialsCommand2 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/GetRoleCredentialsCommand.js"() {
    import_middleware_endpoint12 = __toESM(require_dist_cjs31());
    import_smithy_client55 = __toESM(require_dist_cjs34());
    init_EndpointParameters5();
    init_schemas_05();
    GetRoleCredentialsCommand2 = class extends import_smithy_client55.Command.classBuilder().ep(commonParams5).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint12.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("SWBPortalService", "GetRoleCredentials", {}).n("SSOClient", "GetRoleCredentialsCommand").sc(GetRoleCredentials$2).build() {
      static {
        __name(this, "GetRoleCredentialsCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSO.js
var import_smithy_client56, commands5, SSO2;
var init_SSO2 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSO.js"() {
    import_smithy_client56 = __toESM(require_dist_cjs34());
    init_GetRoleCredentialsCommand2();
    init_SSOClient2();
    commands5 = {
      GetRoleCredentialsCommand: GetRoleCredentialsCommand2
    };
    SSO2 = class extends SSOClient2 {
      static {
        __name(this, "SSO");
      }
    };
    (0, import_smithy_client56.createAggregatedClient)(commands5, SSO2);
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/index.js
var init_commands6 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/index.js"() {
    init_GetRoleCredentialsCommand2();
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/models_0.js
var init_models_05 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/index.js
var sso_exports2 = {};
__export(sso_exports2, {
  $Command: () => import_smithy_client55.Command,
  GetRoleCredentials$: () => GetRoleCredentials$2,
  GetRoleCredentialsCommand: () => GetRoleCredentialsCommand2,
  GetRoleCredentialsRequest$: () => GetRoleCredentialsRequest$2,
  GetRoleCredentialsResponse$: () => GetRoleCredentialsResponse$2,
  InvalidRequestException: () => InvalidRequestException3,
  InvalidRequestException$: () => InvalidRequestException$3,
  ResourceNotFoundException: () => ResourceNotFoundException2,
  ResourceNotFoundException$: () => ResourceNotFoundException$2,
  RoleCredentials$: () => RoleCredentials$2,
  SSO: () => SSO2,
  SSOClient: () => SSOClient2,
  SSOServiceException: () => SSOServiceException2,
  SSOServiceException$: () => SSOServiceException$2,
  TooManyRequestsException: () => TooManyRequestsException2,
  TooManyRequestsException$: () => TooManyRequestsException$2,
  UnauthorizedException: () => UnauthorizedException2,
  UnauthorizedException$: () => UnauthorizedException$2,
  __Client: () => import_smithy_client54.Client,
  errorTypeRegistries: () => errorTypeRegistries5
});
var init_sso2 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/index.js"() {
    init_SSOClient2();
    init_SSO2();
    init_commands6();
    init_schemas_05();
    init_errors5();
    init_models_05();
    init_SSOServiceException2();
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/loadSso-BKDNrsal.js
var require_loadSso_BKDNrsal2 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/loadSso-BKDNrsal.js"(exports2) {
    "use strict";
    var sso = (init_sso2(), __toCommonJS(sso_exports2));
    exports2.GetRoleCredentialsCommand = sso.GetRoleCredentialsCommand;
    exports2.SSOClient = sso.SSOClient;
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/index.js
var require_dist_cjs76 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/index.js"(exports2) {
    "use strict";
    var propertyProvider = require_dist_cjs27();
    var sharedIniFileLoader = require_dist_cjs28();
    var client = (init_client6(), __toCommonJS(client_exports5));
    var tokenProviders = require_dist_cjs49();
    var isSsoProfile = /* @__PURE__ */ __name((arg) => arg && (typeof arg.sso_start_url === "string" || typeof arg.sso_account_id === "string" || typeof arg.sso_session === "string" || typeof arg.sso_region === "string" || typeof arg.sso_role_name === "string"), "isSsoProfile");
    var SHOULD_FAIL_CREDENTIAL_CHAIN = false;
    var resolveSSOCredentials = /* @__PURE__ */ __name(async ({ ssoStartUrl, ssoSession, ssoAccountId, ssoRegion, ssoRoleName, ssoClient, clientConfig, parentClientConfig, callerClientConfig, profile, filepath, configFilepath, ignoreCache, logger: logger5 }) => {
      let token;
      const refreshMessage = `To refresh this SSO session run aws sso login with the corresponding profile.`;
      if (ssoSession) {
        try {
          const _token = await tokenProviders.fromSso({
            profile,
            filepath,
            configFilepath,
            ignoreCache
          })();
          token = {
            accessToken: _token.token,
            expiresAt: new Date(_token.expiration).toISOString()
          };
        } catch (e32) {
          throw new propertyProvider.CredentialsProviderError(e32.message, {
            tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
            logger: logger5
          });
        }
      } else {
        try {
          token = await sharedIniFileLoader.getSSOTokenFromFile(ssoStartUrl);
        } catch (e32) {
          throw new propertyProvider.CredentialsProviderError(`The SSO session associated with this profile is invalid. ${refreshMessage}`, {
            tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
            logger: logger5
          });
        }
      }
      if (new Date(token.expiresAt).getTime() - Date.now() <= 0) {
        throw new propertyProvider.CredentialsProviderError(`The SSO session associated with this profile has expired. ${refreshMessage}`, {
          tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
          logger: logger5
        });
      }
      const { accessToken } = token;
      const { SSOClient: SSOClient10, GetRoleCredentialsCommand: GetRoleCredentialsCommand10 } = await Promise.resolve().then(function() {
        return require_loadSso_BKDNrsal2();
      });
      const sso = ssoClient || new SSOClient10(Object.assign({}, clientConfig ?? {}, {
        logger: clientConfig?.logger ?? callerClientConfig?.logger ?? parentClientConfig?.logger,
        region: clientConfig?.region ?? ssoRegion,
        userAgentAppId: clientConfig?.userAgentAppId ?? callerClientConfig?.userAgentAppId ?? parentClientConfig?.userAgentAppId
      }));
      let ssoResp;
      try {
        ssoResp = await sso.send(new GetRoleCredentialsCommand10({
          accountId: ssoAccountId,
          roleName: ssoRoleName,
          accessToken
        }));
      } catch (e32) {
        throw new propertyProvider.CredentialsProviderError(e32, {
          tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
          logger: logger5
        });
      }
      const { roleCredentials: { accessKeyId, secretAccessKey, sessionToken, expiration, credentialScope, accountId } = {} } = ssoResp;
      if (!accessKeyId || !secretAccessKey || !sessionToken || !expiration) {
        throw new propertyProvider.CredentialsProviderError("SSO returns an invalid temporary credential.", {
          tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
          logger: logger5
        });
      }
      const credentials = {
        accessKeyId,
        secretAccessKey,
        sessionToken,
        expiration: new Date(expiration),
        ...credentialScope && { credentialScope },
        ...accountId && { accountId }
      };
      if (ssoSession) {
        client.setCredentialFeature(credentials, "CREDENTIALS_SSO", "s");
      } else {
        client.setCredentialFeature(credentials, "CREDENTIALS_SSO_LEGACY", "u");
      }
      return credentials;
    }, "resolveSSOCredentials");
    var validateSsoProfile = /* @__PURE__ */ __name((profile, logger5) => {
      const { sso_start_url, sso_account_id, sso_region, sso_role_name } = profile;
      if (!sso_start_url || !sso_account_id || !sso_region || !sso_role_name) {
        throw new propertyProvider.CredentialsProviderError(`Profile is configured with invalid SSO credentials. Required parameters "sso_account_id", "sso_region", "sso_role_name", "sso_start_url". Got ${Object.keys(profile).join(", ")}
Reference: https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-sso.html`, { tryNextLink: false, logger: logger5 });
      }
      return profile;
    }, "validateSsoProfile");
    var fromSSO = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/credential-provider-sso - fromSSO");
      const { ssoStartUrl, ssoAccountId, ssoRegion, ssoRoleName, ssoSession } = init;
      const { ssoClient } = init;
      const profileName = sharedIniFileLoader.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      });
      if (!ssoStartUrl && !ssoAccountId && !ssoRegion && !ssoRoleName && !ssoSession) {
        const profiles = await sharedIniFileLoader.parseKnownFiles(init);
        const profile = profiles[profileName];
        if (!profile) {
          throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} was not found.`, { logger: init.logger });
        }
        if (!isSsoProfile(profile)) {
          throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} is not configured with SSO credentials.`, {
            logger: init.logger
          });
        }
        if (profile?.sso_session) {
          const ssoSessions = await sharedIniFileLoader.loadSsoSessionData(init);
          const session = ssoSessions[profile.sso_session];
          const conflictMsg = ` configurations in profile ${profileName} and sso-session ${profile.sso_session}`;
          if (ssoRegion && ssoRegion !== session.sso_region) {
            throw new propertyProvider.CredentialsProviderError(`Conflicting SSO region` + conflictMsg, {
              tryNextLink: false,
              logger: init.logger
            });
          }
          if (ssoStartUrl && ssoStartUrl !== session.sso_start_url) {
            throw new propertyProvider.CredentialsProviderError(`Conflicting SSO start_url` + conflictMsg, {
              tryNextLink: false,
              logger: init.logger
            });
          }
          profile.sso_region = session.sso_region;
          profile.sso_start_url = session.sso_start_url;
        }
        const { sso_start_url, sso_account_id, sso_region, sso_role_name, sso_session } = validateSsoProfile(profile, init.logger);
        return resolveSSOCredentials({
          ssoStartUrl: sso_start_url,
          ssoSession: sso_session,
          ssoAccountId: sso_account_id,
          ssoRegion: sso_region,
          ssoRoleName: sso_role_name,
          ssoClient,
          clientConfig: init.clientConfig,
          parentClientConfig: init.parentClientConfig,
          callerClientConfig: init.callerClientConfig,
          profile: profileName,
          filepath: init.filepath,
          configFilepath: init.configFilepath,
          ignoreCache: init.ignoreCache,
          logger: init.logger
        });
      } else if (!ssoStartUrl || !ssoAccountId || !ssoRegion || !ssoRoleName) {
        throw new propertyProvider.CredentialsProviderError('Incomplete configuration. The fromSSO() argument hash must include "ssoStartUrl", "ssoAccountId", "ssoRegion", "ssoRoleName"', { tryNextLink: false, logger: init.logger });
      } else {
        return resolveSSOCredentials({
          ssoStartUrl,
          ssoSession,
          ssoAccountId,
          ssoRegion,
          ssoRoleName,
          ssoClient,
          clientConfig: init.clientConfig,
          parentClientConfig: init.parentClientConfig,
          callerClientConfig: init.callerClientConfig,
          profile: profileName,
          filepath: init.filepath,
          configFilepath: init.configFilepath,
          ignoreCache: init.ignoreCache,
          logger: init.logger
        });
      }
    }, "fromSSO");
    exports2.fromSSO = fromSSO;
    exports2.isSsoProfile = isSsoProfile;
    exports2.validateSsoProfile = validateSsoProfile;
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption6(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "signin",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption6(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var import_util_middleware11, defaultSigninHttpAuthSchemeParametersProvider2, defaultSigninHttpAuthSchemeProvider2, resolveHttpAuthSchemeConfig6;
var init_httpAuthSchemeProvider6 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes4();
    import_util_middleware11 = __toESM(require_dist_cjs6());
    defaultSigninHttpAuthSchemeParametersProvider2 = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, import_util_middleware11.getSmithyContext)(context).operation,
        region: await (0, import_util_middleware11.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultSigninHttpAuthSchemeParametersProvider");
    __name(createAwsAuthSigv4HttpAuthOption6, "createAwsAuthSigv4HttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption6, "createSmithyApiNoAuthHttpAuthOption");
    defaultSigninHttpAuthSchemeProvider2 = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "CreateOAuth2Token": {
          options.push(createSmithyApiNoAuthHttpAuthOption6(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption6(authParameters));
        }
      }
      return options;
    }, "defaultSigninHttpAuthSchemeProvider");
    resolveHttpAuthSchemeConfig6 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveAwsSdkSigV4Config3(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, import_util_middleware11.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/EndpointParameters.js
var resolveClientEndpointParameters6, commonParams6;
var init_EndpointParameters6 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters6 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "signin"
      });
    }, "resolveClientEndpointParameters");
    commonParams6 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/bdd.js
var import_util_endpoints16, m3, a6, b6, c6, d6, e6, f6, g6, h6, i6, j6, k6, l3, _data6, root6, r6, nodes6, bdd6;
var init_bdd6 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/bdd.js"() {
    import_util_endpoints16 = __toESM(require_dist_cjs20());
    m3 = "ref";
    a6 = -1;
    b6 = true;
    c6 = "isSet";
    d6 = "PartitionResult";
    e6 = "booleanEquals";
    f6 = "getAttr";
    g6 = "stringEquals";
    h6 = { [m3]: "Endpoint" };
    i6 = { [m3]: d6 };
    j6 = { fn: f6, argv: [i6, "name"] };
    k6 = {};
    l3 = [{ [m3]: "Region" }];
    _data6 = {
      conditions: [
        [c6, [h6]],
        [c6, l3],
        ["aws.partition", l3, d6],
        [e6, [{ [m3]: "UseFIPS" }, b6]],
        [e6, [{ [m3]: "UseDualStack" }, b6]],
        [e6, [{ fn: f6, argv: [i6, "supportsDualStack"] }, b6]],
        [e6, [{ fn: f6, argv: [i6, "supportsFIPS"] }, b6]],
        [g6, [j6, "aws"]],
        [g6, [j6, "aws-cn"]],
        [g6, [j6, "aws-us-gov"]]
      ],
      results: [
        [a6],
        [a6, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a6, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [h6, k6],
        ["https://{Region}.signin.aws.amazon.com", k6],
        ["https://{Region}.signin.amazonaws.cn", k6],
        ["https://{Region}.signin.amazonaws-us-gov.com", k6],
        ["https://signin-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", k6],
        [a6, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://signin-fips.{Region}.{PartitionResult#dnsSuffix}", k6],
        [a6, "FIPS is enabled but this partition does not support FIPS"],
        ["https://signin.{Region}.{PartitionResult#dualStackDnsSuffix}", k6],
        [a6, "DualStack is enabled but this partition does not support DualStack"],
        ["https://signin.{Region}.{PartitionResult#dnsSuffix}", k6],
        [a6, "Invalid Configuration: Missing Region"]
      ]
    };
    root6 = 2;
    r6 = 1e8;
    nodes6 = new Int32Array([
      -1,
      1,
      -1,
      0,
      15,
      3,
      1,
      4,
      r6 + 14,
      2,
      5,
      r6 + 14,
      3,
      11,
      6,
      4,
      10,
      7,
      7,
      r6 + 4,
      8,
      8,
      r6 + 5,
      9,
      9,
      r6 + 6,
      r6 + 13,
      5,
      r6 + 11,
      r6 + 12,
      4,
      13,
      12,
      6,
      r6 + 9,
      r6 + 10,
      5,
      14,
      r6 + 8,
      6,
      r6 + 7,
      r6 + 8,
      3,
      r6 + 1,
      16,
      4,
      r6 + 2,
      r6 + 3
    ]);
    bdd6 = import_util_endpoints16.BinaryDecisionDiagram.from(nodes6, root6, _data6.conditions, _data6.results);
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/endpointResolver.js
var import_util_endpoints17, import_util_endpoints18, cache6, defaultEndpointResolver6;
var init_endpointResolver6 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/endpointResolver.js"() {
    import_util_endpoints17 = __toESM(require_dist_cjs21());
    import_util_endpoints18 = __toESM(require_dist_cjs20());
    init_bdd6();
    cache6 = new import_util_endpoints18.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    defaultEndpointResolver6 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache6.get(endpointParams, () => (0, import_util_endpoints18.decideEndpoint)(bdd6, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    import_util_endpoints18.customEndpointFunctions.aws = import_util_endpoints17.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/SigninServiceException.js
var import_smithy_client57, SigninServiceException2;
var init_SigninServiceException2 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/SigninServiceException.js"() {
    import_smithy_client57 = __toESM(require_dist_cjs34());
    SigninServiceException2 = class _SigninServiceException extends import_smithy_client57.ServiceException {
      static {
        __name(this, "SigninServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _SigninServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/errors.js
var AccessDeniedException3, InternalServerException3, TooManyRequestsError2, ValidationException2;
var init_errors6 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/errors.js"() {
    init_SigninServiceException2();
    AccessDeniedException3 = class _AccessDeniedException extends SigninServiceException2 {
      static {
        __name(this, "AccessDeniedException");
      }
      name = "AccessDeniedException";
      $fault = "client";
      error;
      constructor(opts) {
        super({
          name: "AccessDeniedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AccessDeniedException.prototype);
        this.error = opts.error;
      }
    };
    InternalServerException3 = class _InternalServerException extends SigninServiceException2 {
      static {
        __name(this, "InternalServerException");
      }
      name = "InternalServerException";
      $fault = "server";
      error;
      constructor(opts) {
        super({
          name: "InternalServerException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _InternalServerException.prototype);
        this.error = opts.error;
      }
    };
    TooManyRequestsError2 = class _TooManyRequestsError extends SigninServiceException2 {
      static {
        __name(this, "TooManyRequestsError");
      }
      name = "TooManyRequestsError";
      $fault = "client";
      error;
      constructor(opts) {
        super({
          name: "TooManyRequestsError",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyRequestsError.prototype);
        this.error = opts.error;
      }
    };
    ValidationException2 = class _ValidationException extends SigninServiceException2 {
      static {
        __name(this, "ValidationException");
      }
      name = "ValidationException";
      $fault = "client";
      error;
      constructor(opts) {
        super({
          name: "ValidationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ValidationException.prototype);
        this.error = opts.error;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/schemas/schemas_0.js
var _ADE3, _AT3, _COAT2, _COATR2, _COATRB2, _COATRBr2, _COATRr2, _ISE3, _RT3, _TMRE4, _VE2, _aKI4, _aT5, _c6, _cI3, _cV3, _co3, _e6, _eI3, _gT3, _h5, _hE6, _iT3, _jN2, _m5, _rT3, _rU3, _s6, _sAK4, _sT4, _se3, _tI2, _tO2, _tT3, n06, _s_registry6, SigninServiceException$2, n0_registry6, AccessDeniedException$3, InternalServerException$3, TooManyRequestsError$2, ValidationException$2, errorTypeRegistries6, RefreshToken3, AccessToken$2, CreateOAuth2TokenRequest$2, CreateOAuth2TokenRequestBody$2, CreateOAuth2TokenResponse$2, CreateOAuth2TokenResponseBody$2, CreateOAuth2Token$2;
var init_schemas_06 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/schemas/schemas_0.js"() {
    init_schema4();
    init_errors6();
    init_SigninServiceException2();
    _ADE3 = "AccessDeniedException";
    _AT3 = "AccessToken";
    _COAT2 = "CreateOAuth2Token";
    _COATR2 = "CreateOAuth2TokenRequest";
    _COATRB2 = "CreateOAuth2TokenRequestBody";
    _COATRBr2 = "CreateOAuth2TokenResponseBody";
    _COATRr2 = "CreateOAuth2TokenResponse";
    _ISE3 = "InternalServerException";
    _RT3 = "RefreshToken";
    _TMRE4 = "TooManyRequestsError";
    _VE2 = "ValidationException";
    _aKI4 = "accessKeyId";
    _aT5 = "accessToken";
    _c6 = "client";
    _cI3 = "clientId";
    _cV3 = "codeVerifier";
    _co3 = "code";
    _e6 = "error";
    _eI3 = "expiresIn";
    _gT3 = "grantType";
    _h5 = "http";
    _hE6 = "httpError";
    _iT3 = "idToken";
    _jN2 = "jsonName";
    _m5 = "message";
    _rT3 = "refreshToken";
    _rU3 = "redirectUri";
    _s6 = "smithy.ts.sdk.synthetic.com.amazonaws.signin";
    _sAK4 = "secretAccessKey";
    _sT4 = "sessionToken";
    _se3 = "server";
    _tI2 = "tokenInput";
    _tO2 = "tokenOutput";
    _tT3 = "tokenType";
    n06 = "com.amazonaws.signin";
    _s_registry6 = TypeRegistry.for(_s6);
    SigninServiceException$2 = [-3, _s6, "SigninServiceException", 0, [], []];
    _s_registry6.registerError(SigninServiceException$2, SigninServiceException2);
    n0_registry6 = TypeRegistry.for(n06);
    AccessDeniedException$3 = [-3, n06, _ADE3, { [_e6]: _c6 }, [_e6, _m5], [0, 0], 2];
    n0_registry6.registerError(AccessDeniedException$3, AccessDeniedException3);
    InternalServerException$3 = [-3, n06, _ISE3, { [_e6]: _se3, [_hE6]: 500 }, [_e6, _m5], [0, 0], 2];
    n0_registry6.registerError(InternalServerException$3, InternalServerException3);
    TooManyRequestsError$2 = [-3, n06, _TMRE4, { [_e6]: _c6, [_hE6]: 429 }, [_e6, _m5], [0, 0], 2];
    n0_registry6.registerError(TooManyRequestsError$2, TooManyRequestsError2);
    ValidationException$2 = [-3, n06, _VE2, { [_e6]: _c6, [_hE6]: 400 }, [_e6, _m5], [0, 0], 2];
    n0_registry6.registerError(ValidationException$2, ValidationException2);
    errorTypeRegistries6 = [_s_registry6, n0_registry6];
    RefreshToken3 = [0, n06, _RT3, 8, 0];
    AccessToken$2 = [
      3,
      n06,
      _AT3,
      8,
      [_aKI4, _sAK4, _sT4],
      [
        [0, { [_jN2]: _aKI4 }],
        [0, { [_jN2]: _sAK4 }],
        [0, { [_jN2]: _sT4 }]
      ],
      3
    ];
    CreateOAuth2TokenRequest$2 = [
      3,
      n06,
      _COATR2,
      0,
      [_tI2],
      [[() => CreateOAuth2TokenRequestBody$2, 16]],
      1
    ];
    CreateOAuth2TokenRequestBody$2 = [
      3,
      n06,
      _COATRB2,
      0,
      [_cI3, _gT3, _co3, _rU3, _cV3, _rT3],
      [
        [0, { [_jN2]: _cI3 }],
        [0, { [_jN2]: _gT3 }],
        0,
        [0, { [_jN2]: _rU3 }],
        [0, { [_jN2]: _cV3 }],
        [() => RefreshToken3, { [_jN2]: _rT3 }]
      ],
      2
    ];
    CreateOAuth2TokenResponse$2 = [
      3,
      n06,
      _COATRr2,
      0,
      [_tO2],
      [[() => CreateOAuth2TokenResponseBody$2, 16]],
      1
    ];
    CreateOAuth2TokenResponseBody$2 = [
      3,
      n06,
      _COATRBr2,
      0,
      [_aT5, _tT3, _eI3, _rT3, _iT3],
      [
        [() => AccessToken$2, { [_jN2]: _aT5 }],
        [0, { [_jN2]: _tT3 }],
        [1, { [_jN2]: _eI3 }],
        [() => RefreshToken3, { [_jN2]: _rT3 }],
        [0, { [_jN2]: _iT3 }]
      ],
      4
    ];
    CreateOAuth2Token$2 = [
      9,
      n06,
      _COAT2,
      { [_h5]: ["POST", "/v1/token", 200] },
      () => CreateOAuth2TokenRequest$2,
      () => CreateOAuth2TokenResponse$2
    ];
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.shared.js
var import_smithy_client58, import_url_parser7, import_util_base6422, import_util_utf818, getRuntimeConfig11;
var init_runtimeConfig_shared6 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.shared.js"() {
    init_httpAuthSchemes4();
    init_protocols6();
    init_dist_es();
    import_smithy_client58 = __toESM(require_dist_cjs34());
    import_url_parser7 = __toESM(require_dist_cjs18());
    import_util_base6422 = __toESM(require_dist_cjs10());
    import_util_utf818 = __toESM(require_dist_cjs9());
    init_httpAuthSchemeProvider6();
    init_endpointResolver6();
    init_schemas_06();
    getRuntimeConfig11 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2023-01-01",
        base64Decoder: config2?.base64Decoder ?? import_util_base6422.fromBase64,
        base64Encoder: config2?.base64Encoder ?? import_util_base6422.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver6,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSigninHttpAuthSchemeProvider2,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer3()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        logger: config2?.logger ?? new import_smithy_client58.NoOpLogger(),
        protocol: config2?.protocol ?? AwsRestJsonProtocol4,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.signin",
          errorTypeRegistries: errorTypeRegistries6,
          version: "2023-01-01",
          serviceTarget: "Signin"
        },
        serviceId: config2?.serviceId ?? "Signin",
        urlParser: config2?.urlParser ?? import_url_parser7.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? import_util_utf818.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? import_util_utf818.toUtf8
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.js
var import_util_user_agent_node6, import_config_resolver11, import_hash_node6, import_middleware_retry11, import_node_config_provider6, import_node_http_handler6, import_smithy_client59, import_util_body_length_node6, import_util_defaults_mode_node6, import_util_retry11, getRuntimeConfig12;
var init_runtimeConfig6 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.js"() {
    init_package3();
    init_client6();
    init_httpAuthSchemes4();
    import_util_user_agent_node6 = __toESM(require_dist_cjs75());
    import_config_resolver11 = __toESM(require_dist_cjs25());
    import_hash_node6 = __toESM(require_dist_cjs44());
    import_middleware_retry11 = __toESM(require_dist_cjs71());
    import_node_config_provider6 = __toESM(require_dist_cjs29());
    import_node_http_handler6 = __toESM(require_dist_cjs13());
    import_smithy_client59 = __toESM(require_dist_cjs34());
    import_util_body_length_node6 = __toESM(require_dist_cjs45());
    import_util_defaults_mode_node6 = __toESM(require_dist_cjs46());
    import_util_retry11 = __toESM(require_dist_cjs22());
    init_runtimeConfig_shared6();
    getRuntimeConfig12 = /* @__PURE__ */ __name((config2) => {
      (0, import_smithy_client59.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, import_util_defaults_mode_node6.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(import_smithy_client59.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig11(config2);
      emitWarningIfUnsupportedVersion9(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, import_node_config_provider6.loadConfig)(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS3, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? import_util_body_length_node6.calculateBodyLength,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, import_util_user_agent_node6.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_default3.version }),
        maxAttempts: config2?.maxAttempts ?? (0, import_node_config_provider6.loadConfig)(import_middleware_retry11.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, import_node_config_provider6.loadConfig)(import_config_resolver11.NODE_REGION_CONFIG_OPTIONS, { ...import_config_resolver11.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: import_node_http_handler6.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, import_node_config_provider6.loadConfig)({
          ...import_middleware_retry11.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || import_util_retry11.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? import_hash_node6.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? import_node_http_handler6.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, import_node_config_provider6.loadConfig)(import_config_resolver11.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, import_node_config_provider6.loadConfig)(import_config_resolver11.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, import_node_config_provider6.loadConfig)(import_util_user_agent_node6.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration6, resolveHttpAuthRuntimeConfig6;
var init_httpAuthExtensionConfiguration6 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration6 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig6 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeExtensions.js
var import_region_config_resolver7, import_protocol_http23, import_smithy_client60, resolveRuntimeExtensions6;
var init_runtimeExtensions6 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeExtensions.js"() {
    import_region_config_resolver7 = __toESM(require_dist_cjs48());
    import_protocol_http23 = __toESM(require_dist_cjs2());
    import_smithy_client60 = __toESM(require_dist_cjs34());
    init_httpAuthExtensionConfiguration6();
    resolveRuntimeExtensions6 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign((0, import_region_config_resolver7.getAwsRegionExtensionConfiguration)(runtimeConfig), (0, import_smithy_client60.getDefaultExtensionConfiguration)(runtimeConfig), (0, import_protocol_http23.getHttpHandlerExtensionConfiguration)(runtimeConfig), getHttpAuthExtensionConfiguration6(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, (0, import_region_config_resolver7.resolveAwsRegionExtensionConfiguration)(extensionConfiguration), (0, import_smithy_client60.resolveDefaultRuntimeConfig)(extensionConfiguration), (0, import_protocol_http23.resolveHttpHandlerRuntimeConfig)(extensionConfiguration), resolveHttpAuthRuntimeConfig6(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/SigninClient.js
var import_middleware_host_header6, import_middleware_logger6, import_middleware_recursion_detection6, import_middleware_user_agent6, import_config_resolver12, import_middleware_content_length6, import_middleware_endpoint13, import_middleware_retry12, import_smithy_client61, SigninClient2;
var init_SigninClient2 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/SigninClient.js"() {
    import_middleware_host_header6 = __toESM(require_dist_cjs3());
    import_middleware_logger6 = __toESM(require_dist_cjs4());
    import_middleware_recursion_detection6 = __toESM(require_dist_cjs5());
    import_middleware_user_agent6 = __toESM(require_dist_cjs69());
    import_config_resolver12 = __toESM(require_dist_cjs25());
    init_dist_es();
    init_schema4();
    import_middleware_content_length6 = __toESM(require_dist_cjs26());
    import_middleware_endpoint13 = __toESM(require_dist_cjs31());
    import_middleware_retry12 = __toESM(require_dist_cjs71());
    import_smithy_client61 = __toESM(require_dist_cjs34());
    init_httpAuthSchemeProvider6();
    init_EndpointParameters6();
    init_runtimeConfig6();
    init_runtimeExtensions6();
    SigninClient2 = class extends import_smithy_client61.Client {
      static {
        __name(this, "SigninClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig12(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters6(_config_0);
        const _config_2 = (0, import_middleware_user_agent6.resolveUserAgentConfig)(_config_1);
        const _config_3 = (0, import_middleware_retry12.resolveRetryConfig)(_config_2);
        const _config_4 = (0, import_config_resolver12.resolveRegionConfig)(_config_3);
        const _config_5 = (0, import_middleware_host_header6.resolveHostHeaderConfig)(_config_4);
        const _config_6 = (0, import_middleware_endpoint13.resolveEndpointConfig)(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig6(_config_6);
        const _config_8 = resolveRuntimeExtensions6(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin(this.config));
        this.middlewareStack.use((0, import_middleware_user_agent6.getUserAgentPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_retry12.getRetryPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_content_length6.getContentLengthPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_host_header6.getHostHeaderPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_logger6.getLoggerPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_recursion_detection6.getRecursionDetectionPlugin)(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: defaultSigninHttpAuthSchemeParametersProvider2,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/CreateOAuth2TokenCommand.js
var import_middleware_endpoint14, import_smithy_client62, CreateOAuth2TokenCommand2;
var init_CreateOAuth2TokenCommand2 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/CreateOAuth2TokenCommand.js"() {
    import_middleware_endpoint14 = __toESM(require_dist_cjs31());
    import_smithy_client62 = __toESM(require_dist_cjs34());
    init_EndpointParameters6();
    init_schemas_06();
    CreateOAuth2TokenCommand2 = class extends import_smithy_client62.Command.classBuilder().ep(commonParams6).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint14.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("Signin", "CreateOAuth2Token", {}).n("SigninClient", "CreateOAuth2TokenCommand").sc(CreateOAuth2Token$2).build() {
      static {
        __name(this, "CreateOAuth2TokenCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/Signin.js
var import_smithy_client63, commands6, Signin2;
var init_Signin2 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/Signin.js"() {
    import_smithy_client63 = __toESM(require_dist_cjs34());
    init_CreateOAuth2TokenCommand2();
    init_SigninClient2();
    commands6 = {
      CreateOAuth2TokenCommand: CreateOAuth2TokenCommand2
    };
    Signin2 = class extends SigninClient2 {
      static {
        __name(this, "Signin");
      }
    };
    (0, import_smithy_client63.createAggregatedClient)(commands6, Signin2);
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/index.js
var init_commands7 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/index.js"() {
    init_CreateOAuth2TokenCommand2();
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/enums.js
var OAuth2ErrorCode2;
var init_enums3 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/enums.js"() {
    OAuth2ErrorCode2 = {
      AUTHCODE_EXPIRED: "AUTHCODE_EXPIRED",
      INSUFFICIENT_PERMISSIONS: "INSUFFICIENT_PERMISSIONS",
      INVALID_REQUEST: "INVALID_REQUEST",
      SERVER_ERROR: "server_error",
      TOKEN_EXPIRED: "TOKEN_EXPIRED",
      USER_CREDENTIALS_CHANGED: "USER_CREDENTIALS_CHANGED"
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/models_0.js
var init_models_06 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/index.js
var signin_exports2 = {};
__export(signin_exports2, {
  $Command: () => import_smithy_client62.Command,
  AccessDeniedException: () => AccessDeniedException3,
  AccessDeniedException$: () => AccessDeniedException$3,
  AccessToken$: () => AccessToken$2,
  CreateOAuth2Token$: () => CreateOAuth2Token$2,
  CreateOAuth2TokenCommand: () => CreateOAuth2TokenCommand2,
  CreateOAuth2TokenRequest$: () => CreateOAuth2TokenRequest$2,
  CreateOAuth2TokenRequestBody$: () => CreateOAuth2TokenRequestBody$2,
  CreateOAuth2TokenResponse$: () => CreateOAuth2TokenResponse$2,
  CreateOAuth2TokenResponseBody$: () => CreateOAuth2TokenResponseBody$2,
  InternalServerException: () => InternalServerException3,
  InternalServerException$: () => InternalServerException$3,
  OAuth2ErrorCode: () => OAuth2ErrorCode2,
  Signin: () => Signin2,
  SigninClient: () => SigninClient2,
  SigninServiceException: () => SigninServiceException2,
  SigninServiceException$: () => SigninServiceException$2,
  TooManyRequestsError: () => TooManyRequestsError2,
  TooManyRequestsError$: () => TooManyRequestsError$2,
  ValidationException: () => ValidationException2,
  ValidationException$: () => ValidationException$2,
  __Client: () => import_smithy_client61.Client,
  errorTypeRegistries: () => errorTypeRegistries6
});
var init_signin2 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/index.js"() {
    init_SigninClient2();
    init_Signin2();
    init_commands7();
    init_schemas_06();
    init_enums3();
    init_errors6();
    init_models_06();
    init_SigninServiceException2();
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-login/dist-cjs/index.js
var require_dist_cjs77 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-login/dist-cjs/index.js"(exports2) {
    "use strict";
    var client = (init_client6(), __toCommonJS(client_exports5));
    var propertyProvider = require_dist_cjs27();
    var sharedIniFileLoader = require_dist_cjs28();
    var protocolHttp = require_dist_cjs2();
    var node_crypto = require("node:crypto");
    var node_fs = require("node:fs");
    var node_os = require("node:os");
    var node_path = require("node:path");
    var LoginCredentialsFetcher = class _LoginCredentialsFetcher {
      static {
        __name(this, "LoginCredentialsFetcher");
      }
      profileData;
      init;
      callerClientConfig;
      static REFRESH_THRESHOLD = 5 * 60 * 1e3;
      constructor(profileData, init, callerClientConfig) {
        this.profileData = profileData;
        this.init = init;
        this.callerClientConfig = callerClientConfig;
      }
      async loadCredentials() {
        const token = await this.loadToken();
        if (!token) {
          throw new propertyProvider.CredentialsProviderError(`Failed to load a token for session ${this.loginSession}, please re-authenticate using aws login`, { tryNextLink: false, logger: this.logger });
        }
        const accessToken = token.accessToken;
        const now = Date.now();
        const expiryTime = new Date(accessToken.expiresAt).getTime();
        const timeUntilExpiry = expiryTime - now;
        if (timeUntilExpiry <= _LoginCredentialsFetcher.REFRESH_THRESHOLD) {
          return this.refresh(token);
        }
        return {
          accessKeyId: accessToken.accessKeyId,
          secretAccessKey: accessToken.secretAccessKey,
          sessionToken: accessToken.sessionToken,
          accountId: accessToken.accountId,
          expiration: new Date(accessToken.expiresAt)
        };
      }
      get logger() {
        return this.init?.logger;
      }
      get loginSession() {
        return this.profileData.login_session;
      }
      async refresh(token) {
        const { SigninClient: SigninClient10, CreateOAuth2TokenCommand: CreateOAuth2TokenCommand10 } = await Promise.resolve().then(() => (init_signin2(), signin_exports2));
        const { logger: logger5, userAgentAppId } = this.callerClientConfig ?? {};
        const isH210 = /* @__PURE__ */ __name((requestHandler2) => {
          return requestHandler2?.metadata?.handlerProtocol === "h2";
        }, "isH2");
        const requestHandler = isH210(this.callerClientConfig?.requestHandler) ? void 0 : this.callerClientConfig?.requestHandler;
        const region = this.profileData.region ?? await this.callerClientConfig?.region?.() ?? process.env.AWS_REGION;
        const client2 = new SigninClient10({
          credentials: {
            accessKeyId: "",
            secretAccessKey: ""
          },
          region,
          requestHandler,
          logger: logger5,
          userAgentAppId,
          ...this.init?.clientConfig
        });
        this.createDPoPInterceptor(client2.middlewareStack);
        const commandInput = {
          tokenInput: {
            clientId: token.clientId,
            refreshToken: token.refreshToken,
            grantType: "refresh_token"
          }
        };
        try {
          const response = await client2.send(new CreateOAuth2TokenCommand10(commandInput));
          const { accessKeyId, secretAccessKey, sessionToken } = response.tokenOutput?.accessToken ?? {};
          const { refreshToken, expiresIn } = response.tokenOutput ?? {};
          if (!accessKeyId || !secretAccessKey || !sessionToken || !refreshToken) {
            throw new propertyProvider.CredentialsProviderError("Token refresh response missing required fields", {
              logger: this.logger,
              tryNextLink: false
            });
          }
          const expiresInMs = (expiresIn ?? 900) * 1e3;
          const expiration = new Date(Date.now() + expiresInMs);
          const updatedToken = {
            ...token,
            accessToken: {
              ...token.accessToken,
              accessKeyId,
              secretAccessKey,
              sessionToken,
              expiresAt: expiration.toISOString()
            },
            refreshToken
          };
          await this.saveToken(updatedToken);
          const newAccessToken = updatedToken.accessToken;
          return {
            accessKeyId: newAccessToken.accessKeyId,
            secretAccessKey: newAccessToken.secretAccessKey,
            sessionToken: newAccessToken.sessionToken,
            accountId: newAccessToken.accountId,
            expiration
          };
        } catch (error4) {
          if (error4.name === "AccessDeniedException") {
            const errorType = error4.error;
            let message2;
            switch (errorType) {
              case "TOKEN_EXPIRED":
                message2 = "Your session has expired. Please reauthenticate.";
                break;
              case "USER_CREDENTIALS_CHANGED":
                message2 = "Unable to refresh credentials because of a change in your password. Please reauthenticate with your new password.";
                break;
              case "INSUFFICIENT_PERMISSIONS":
                message2 = "Unable to refresh credentials due to insufficient permissions. You may be missing permission for the 'CreateOAuth2Token' action.";
                break;
              default:
                message2 = `Failed to refresh token: ${String(error4)}. Please re-authenticate using \`aws login\``;
            }
            throw new propertyProvider.CredentialsProviderError(message2, { logger: this.logger, tryNextLink: false });
          }
          throw new propertyProvider.CredentialsProviderError(`Failed to refresh token: ${String(error4)}. Please re-authenticate using aws login`, { logger: this.logger });
        }
      }
      async loadToken() {
        const tokenFilePath = this.getTokenFilePath();
        try {
          let tokenData;
          try {
            tokenData = await sharedIniFileLoader.readFile(tokenFilePath, { ignoreCache: this.init?.ignoreCache });
          } catch {
            tokenData = await node_fs.promises.readFile(tokenFilePath, "utf8");
          }
          const token = JSON.parse(tokenData);
          const missingFields = ["accessToken", "clientId", "refreshToken", "dpopKey"].filter((k32) => !token[k32]);
          if (!token.accessToken?.accountId) {
            missingFields.push("accountId");
          }
          if (missingFields.length > 0) {
            throw new propertyProvider.CredentialsProviderError(`Token validation failed, missing fields: ${missingFields.join(", ")}`, {
              logger: this.logger,
              tryNextLink: false
            });
          }
          return token;
        } catch (error4) {
          throw new propertyProvider.CredentialsProviderError(`Failed to load token from ${tokenFilePath}: ${String(error4)}`, {
            logger: this.logger,
            tryNextLink: false
          });
        }
      }
      async saveToken(token) {
        const tokenFilePath = this.getTokenFilePath();
        const directory = node_path.dirname(tokenFilePath);
        try {
          await node_fs.promises.mkdir(directory, { recursive: true });
        } catch (error4) {
        }
        await node_fs.promises.writeFile(tokenFilePath, JSON.stringify(token, null, 2), "utf8");
      }
      getTokenFilePath() {
        const directory = process.env.AWS_LOGIN_CACHE_DIRECTORY ?? node_path.join(node_os.homedir(), ".aws", "login", "cache");
        const loginSessionBytes = Buffer.from(this.loginSession, "utf8");
        const loginSessionSha256 = node_crypto.createHash("sha256").update(loginSessionBytes).digest("hex");
        return node_path.join(directory, `${loginSessionSha256}.json`);
      }
      derToRawSignature(derSignature) {
        let offset = 2;
        if (derSignature[offset] !== 2) {
          throw new Error("Invalid DER signature");
        }
        offset++;
        const rLength = derSignature[offset++];
        let r32 = derSignature.subarray(offset, offset + rLength);
        offset += rLength;
        if (derSignature[offset] !== 2) {
          throw new Error("Invalid DER signature");
        }
        offset++;
        const sLength = derSignature[offset++];
        let s = derSignature.subarray(offset, offset + sLength);
        r32 = r32[0] === 0 ? r32.subarray(1) : r32;
        s = s[0] === 0 ? s.subarray(1) : s;
        const rPadded = Buffer.concat([Buffer.alloc(32 - r32.length), r32]);
        const sPadded = Buffer.concat([Buffer.alloc(32 - s.length), s]);
        return Buffer.concat([rPadded, sPadded]);
      }
      createDPoPInterceptor(middlewareStack) {
        middlewareStack.add((next) => async (args) => {
          if (protocolHttp.HttpRequest.isInstance(args.request)) {
            const request4 = args.request;
            const actualEndpoint = `${request4.protocol}//${request4.hostname}${request4.port ? `:${request4.port}` : ""}${request4.path}`;
            const dpop = await this.generateDpop(request4.method, actualEndpoint);
            request4.headers = {
              ...request4.headers,
              DPoP: dpop
            };
          }
          return next(args);
        }, {
          step: "finalizeRequest",
          name: "dpopInterceptor",
          override: true
        });
      }
      async generateDpop(method = "POST", endpoint) {
        const token = await this.loadToken();
        try {
          const privateKey = node_crypto.createPrivateKey({
            key: token.dpopKey,
            format: "pem",
            type: "sec1"
          });
          const publicKey = node_crypto.createPublicKey(privateKey);
          const publicDer = publicKey.export({ format: "der", type: "spki" });
          let pointStart = -1;
          for (let i32 = 0; i32 < publicDer.length; i32++) {
            if (publicDer[i32] === 4) {
              pointStart = i32;
              break;
            }
          }
          const x = publicDer.slice(pointStart + 1, pointStart + 33);
          const y = publicDer.slice(pointStart + 33, pointStart + 65);
          const header = {
            alg: "ES256",
            typ: "dpop+jwt",
            jwk: {
              kty: "EC",
              crv: "P-256",
              x: x.toString("base64url"),
              y: y.toString("base64url")
            }
          };
          const payload3 = {
            jti: crypto.randomUUID(),
            htm: method,
            htu: endpoint,
            iat: Math.floor(Date.now() / 1e3)
          };
          const headerB64 = Buffer.from(JSON.stringify(header)).toString("base64url");
          const payloadB64 = Buffer.from(JSON.stringify(payload3)).toString("base64url");
          const message2 = `${headerB64}.${payloadB64}`;
          const asn1Signature = node_crypto.sign("sha256", Buffer.from(message2), privateKey);
          const rawSignature = this.derToRawSignature(asn1Signature);
          const signatureB64 = rawSignature.toString("base64url");
          return `${message2}.${signatureB64}`;
        } catch (error4) {
          throw new propertyProvider.CredentialsProviderError(`Failed to generate Dpop proof: ${error4 instanceof Error ? error4.message : String(error4)}`, { logger: this.logger, tryNextLink: false });
        }
      }
    };
    var fromLoginCredentials = /* @__PURE__ */ __name((init) => async ({ callerClientConfig } = {}) => {
      init?.logger?.debug?.("@aws-sdk/credential-providers - fromLoginCredentials");
      const profiles = await sharedIniFileLoader.parseKnownFiles(init || {});
      const profileName = sharedIniFileLoader.getProfileName({
        profile: init?.profile ?? callerClientConfig?.profile
      });
      const profile = profiles[profileName];
      if (!profile?.login_session) {
        throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} does not contain login_session.`, {
          tryNextLink: true,
          logger: init?.logger
        });
      }
      const fetcher = new LoginCredentialsFetcher(profile, init, callerClientConfig);
      const credentials = await fetcher.loadCredentials();
      return client.setCredentialFeature(credentials, "CREDENTIALS_LOGIN", "AD");
    }, "fromLoginCredentials");
    exports2.fromLoginCredentials = fromLoginCredentials;
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/bdd.js
var import_util_endpoints19, q2, a7, b7, c7, d7, e7, f7, g7, h7, i7, j7, k7, l4, m4, n2, o2, p2, _data7, root7, r7, nodes7, bdd7;
var init_bdd7 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/bdd.js"() {
    import_util_endpoints19 = __toESM(require_dist_cjs20());
    q2 = "ref";
    a7 = -1;
    b7 = true;
    c7 = "isSet";
    d7 = "PartitionResult";
    e7 = "booleanEquals";
    f7 = "stringEquals";
    g7 = "getAttr";
    h7 = "us-east-1";
    i7 = "sigv4";
    j7 = "sts";
    k7 = "https://sts.{Region}.{PartitionResult#dnsSuffix}";
    l4 = { [q2]: "Endpoint" };
    m4 = { [q2]: "Region" };
    n2 = { [q2]: d7 };
    o2 = {};
    p2 = [m4];
    _data7 = {
      conditions: [
        [c7, [l4]],
        [c7, p2],
        ["aws.partition", p2, d7],
        [e7, [{ [q2]: "UseFIPS" }, b7]],
        [e7, [{ [q2]: "UseDualStack" }, b7]],
        [f7, [m4, "aws-global"]],
        [e7, [{ [q2]: "UseGlobalEndpoint" }, b7]],
        [f7, [m4, "eu-central-1"]],
        [e7, [{ fn: g7, argv: [n2, "supportsDualStack"] }, b7]],
        [e7, [{ fn: g7, argv: [n2, "supportsFIPS"] }, b7]],
        [f7, [m4, "ap-south-1"]],
        [f7, [m4, "eu-north-1"]],
        [f7, [m4, "eu-west-1"]],
        [f7, [m4, "eu-west-2"]],
        [f7, [m4, "eu-west-3"]],
        [f7, [m4, "sa-east-1"]],
        [f7, [m4, h7]],
        [f7, [m4, "us-east-2"]],
        [f7, [m4, "us-west-2"]],
        [f7, [m4, "us-west-1"]],
        [f7, [m4, "ca-central-1"]],
        [f7, [m4, "ap-southeast-1"]],
        [f7, [m4, "ap-northeast-1"]],
        [f7, [m4, "ap-southeast-2"]],
        [f7, [{ fn: g7, argv: [n2, "name"] }, "aws-us-gov"]]
      ],
      results: [
        [a7],
        ["https://sts.amazonaws.com", { authSchemes: [{ name: i7, signingName: j7, signingRegion: h7 }] }],
        [k7, { authSchemes: [{ name: i7, signingName: j7, signingRegion: "{Region}" }] }],
        [a7, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a7, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [l4, o2],
        ["https://sts-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", o2],
        [a7, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://sts.{Region}.amazonaws.com", o2],
        ["https://sts-fips.{Region}.{PartitionResult#dnsSuffix}", o2],
        [a7, "FIPS is enabled but this partition does not support FIPS"],
        ["https://sts.{Region}.{PartitionResult#dualStackDnsSuffix}", o2],
        [a7, "DualStack is enabled but this partition does not support DualStack"],
        [k7, o2],
        [a7, "Invalid Configuration: Missing Region"]
      ]
    };
    root7 = 2;
    r7 = 1e8;
    nodes7 = new Int32Array([
      -1,
      1,
      -1,
      0,
      30,
      3,
      1,
      4,
      r7 + 14,
      2,
      5,
      r7 + 14,
      3,
      25,
      6,
      4,
      24,
      7,
      5,
      r7 + 1,
      8,
      6,
      9,
      r7 + 13,
      7,
      r7 + 1,
      10,
      10,
      r7 + 1,
      11,
      11,
      r7 + 1,
      12,
      12,
      r7 + 1,
      13,
      13,
      r7 + 1,
      14,
      14,
      r7 + 1,
      15,
      15,
      r7 + 1,
      16,
      16,
      r7 + 1,
      17,
      17,
      r7 + 1,
      18,
      18,
      r7 + 1,
      19,
      19,
      r7 + 1,
      20,
      20,
      r7 + 1,
      21,
      21,
      r7 + 1,
      22,
      22,
      r7 + 1,
      23,
      23,
      r7 + 1,
      r7 + 2,
      8,
      r7 + 11,
      r7 + 12,
      4,
      28,
      26,
      9,
      27,
      r7 + 10,
      24,
      r7 + 8,
      r7 + 9,
      8,
      29,
      r7 + 7,
      9,
      r7 + 6,
      r7 + 7,
      3,
      r7 + 3,
      31,
      4,
      r7 + 4,
      r7 + 5
    ]);
    bdd7 = import_util_endpoints19.BinaryDecisionDiagram.from(nodes7, root7, _data7.conditions, _data7.results);
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/endpointResolver.js
var import_util_endpoints20, import_util_endpoints21, cache7, defaultEndpointResolver7;
var init_endpointResolver7 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/endpointResolver.js"() {
    import_util_endpoints20 = __toESM(require_dist_cjs21());
    import_util_endpoints21 = __toESM(require_dist_cjs20());
    init_bdd7();
    cache7 = new import_util_endpoints21.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS", "UseGlobalEndpoint"]
    });
    defaultEndpointResolver7 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache7.get(endpointParams, () => (0, import_util_endpoints21.decideEndpoint)(bdd7, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    import_util_endpoints21.customEndpointFunctions.aws = import_util_endpoints20.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption7(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "sts",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createAwsAuthSigv4aHttpAuthOption2(authParameters) {
  return {
    schemeId: "aws.auth#sigv4a",
    signingProperties: {
      name: "sts",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption7(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var import_signature_v4_multi_region3, import_middleware_endpoint15, import_util_middleware12, createEndpointRuleSetHttpAuthSchemeParametersProvider2, _defaultSTSHttpAuthSchemeParametersProvider2, defaultSTSHttpAuthSchemeParametersProvider2, createEndpointRuleSetHttpAuthSchemeProvider2, _defaultSTSHttpAuthSchemeProvider2, defaultSTSHttpAuthSchemeProvider2, resolveStsAuthConfig2, resolveHttpAuthSchemeConfig7;
var init_httpAuthSchemeProvider7 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes4();
    import_signature_v4_multi_region3 = __toESM(require_dist_cjs55());
    import_middleware_endpoint15 = __toESM(require_dist_cjs31());
    import_util_middleware12 = __toESM(require_dist_cjs6());
    init_endpointResolver7();
    init_STSClient2();
    createEndpointRuleSetHttpAuthSchemeParametersProvider2 = /* @__PURE__ */ __name((defaultHttpAuthSchemeParametersProvider) => async (config2, context, input) => {
      if (!input) {
        throw new Error("Could not find `input` for `defaultEndpointRuleSetHttpAuthSchemeParametersProvider`");
      }
      const defaultParameters = await defaultHttpAuthSchemeParametersProvider(config2, context, input);
      const instructionsFn = (0, import_util_middleware12.getSmithyContext)(context)?.commandInstance?.constructor?.getEndpointParameterInstructions;
      if (!instructionsFn) {
        throw new Error(`getEndpointParameterInstructions() is not defined on '${context.commandName}'`);
      }
      const endpointParameters = await (0, import_middleware_endpoint15.resolveParams)(input, { getEndpointParameterInstructions: instructionsFn }, config2);
      return Object.assign(defaultParameters, endpointParameters);
    }, "createEndpointRuleSetHttpAuthSchemeParametersProvider");
    _defaultSTSHttpAuthSchemeParametersProvider2 = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, import_util_middleware12.getSmithyContext)(context).operation,
        region: await (0, import_util_middleware12.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "_defaultSTSHttpAuthSchemeParametersProvider");
    defaultSTSHttpAuthSchemeParametersProvider2 = createEndpointRuleSetHttpAuthSchemeParametersProvider2(_defaultSTSHttpAuthSchemeParametersProvider2);
    __name(createAwsAuthSigv4HttpAuthOption7, "createAwsAuthSigv4HttpAuthOption");
    __name(createAwsAuthSigv4aHttpAuthOption2, "createAwsAuthSigv4aHttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption7, "createSmithyApiNoAuthHttpAuthOption");
    createEndpointRuleSetHttpAuthSchemeProvider2 = /* @__PURE__ */ __name((defaultEndpointResolver32, defaultHttpAuthSchemeResolver, createHttpAuthOptionFunctions) => {
      const endpointRuleSetHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
        const endpoint = defaultEndpointResolver32(authParameters);
        const authSchemes = endpoint.properties?.authSchemes;
        if (!authSchemes) {
          return defaultHttpAuthSchemeResolver(authParameters);
        }
        const options = [];
        for (const scheme of authSchemes) {
          const { name: resolvedName, properties = {}, ...rest } = scheme;
          const name = resolvedName.toLowerCase();
          if (resolvedName !== name) {
            console.warn(`HttpAuthScheme has been normalized with lowercasing: '${resolvedName}' to '${name}'`);
          }
          let schemeId;
          if (name === "sigv4a") {
            schemeId = "aws.auth#sigv4a";
            const sigv4Present = authSchemes.find((s) => {
              const name2 = s.name.toLowerCase();
              return name2 !== "sigv4a" && name2.startsWith("sigv4");
            });
            if (import_signature_v4_multi_region3.SignatureV4MultiRegion.sigv4aDependency() === "none" && sigv4Present) {
              continue;
            }
          } else if (name.startsWith("sigv4")) {
            schemeId = "aws.auth#sigv4";
          } else {
            throw new Error(`Unknown HttpAuthScheme found in '@smithy.rules#endpointRuleSet': '${name}'`);
          }
          const createOption = createHttpAuthOptionFunctions[schemeId];
          if (!createOption) {
            throw new Error(`Could not find HttpAuthOption create function for '${schemeId}'`);
          }
          const option = createOption(authParameters);
          option.schemeId = schemeId;
          option.signingProperties = { ...option.signingProperties || {}, ...rest, ...properties };
          options.push(option);
        }
        return options;
      }, "endpointRuleSetHttpAuthSchemeProvider");
      return endpointRuleSetHttpAuthSchemeProvider;
    }, "createEndpointRuleSetHttpAuthSchemeProvider");
    _defaultSTSHttpAuthSchemeProvider2 = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "AssumeRoleWithWebIdentity": {
          options.push(createSmithyApiNoAuthHttpAuthOption7(authParameters));
          options.push(createAwsAuthSigv4aHttpAuthOption2(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption7(authParameters));
          options.push(createAwsAuthSigv4aHttpAuthOption2(authParameters));
        }
      }
      return options;
    }, "_defaultSTSHttpAuthSchemeProvider");
    defaultSTSHttpAuthSchemeProvider2 = createEndpointRuleSetHttpAuthSchemeProvider2(defaultEndpointResolver7, _defaultSTSHttpAuthSchemeProvider2, {
      "aws.auth#sigv4": createAwsAuthSigv4HttpAuthOption7,
      "aws.auth#sigv4a": createAwsAuthSigv4aHttpAuthOption2,
      "smithy.api#noAuth": createSmithyApiNoAuthHttpAuthOption7
    });
    resolveStsAuthConfig2 = /* @__PURE__ */ __name((input) => Object.assign(input, {
      stsClientCtor: STSClient2
    }), "resolveStsAuthConfig");
    resolveHttpAuthSchemeConfig7 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveStsAuthConfig2(config2);
      const config_1 = resolveAwsSdkSigV4Config3(config_0);
      const config_2 = resolveAwsSdkSigV4AConfig3(config_1);
      return Object.assign(config_2, {
        authSchemePreference: (0, import_util_middleware12.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/EndpointParameters.js
var resolveClientEndpointParameters7, commonParams7;
var init_EndpointParameters7 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters7 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        useGlobalEndpoint: options.useGlobalEndpoint ?? false,
        defaultSigningName: "sts"
      });
    }, "resolveClientEndpointParameters");
    commonParams7 = {
      UseGlobalEndpoint: { type: "builtInParams", name: "useGlobalEndpoint" },
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/STSServiceException.js
var import_smithy_client64, STSServiceException2;
var init_STSServiceException2 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/STSServiceException.js"() {
    import_smithy_client64 = __toESM(require_dist_cjs34());
    STSServiceException2 = class _STSServiceException extends import_smithy_client64.ServiceException {
      static {
        __name(this, "STSServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _STSServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/errors.js
var ExpiredTokenException3, MalformedPolicyDocumentException2, PackedPolicyTooLargeException2, RegionDisabledException2, IDPRejectedClaimException2, InvalidIdentityTokenException2, IDPCommunicationErrorException2;
var init_errors7 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/errors.js"() {
    init_STSServiceException2();
    ExpiredTokenException3 = class _ExpiredTokenException extends STSServiceException2 {
      static {
        __name(this, "ExpiredTokenException");
      }
      name = "ExpiredTokenException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ExpiredTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ExpiredTokenException.prototype);
      }
    };
    MalformedPolicyDocumentException2 = class _MalformedPolicyDocumentException extends STSServiceException2 {
      static {
        __name(this, "MalformedPolicyDocumentException");
      }
      name = "MalformedPolicyDocumentException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "MalformedPolicyDocumentException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _MalformedPolicyDocumentException.prototype);
      }
    };
    PackedPolicyTooLargeException2 = class _PackedPolicyTooLargeException extends STSServiceException2 {
      static {
        __name(this, "PackedPolicyTooLargeException");
      }
      name = "PackedPolicyTooLargeException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "PackedPolicyTooLargeException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _PackedPolicyTooLargeException.prototype);
      }
    };
    RegionDisabledException2 = class _RegionDisabledException extends STSServiceException2 {
      static {
        __name(this, "RegionDisabledException");
      }
      name = "RegionDisabledException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "RegionDisabledException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _RegionDisabledException.prototype);
      }
    };
    IDPRejectedClaimException2 = class _IDPRejectedClaimException extends STSServiceException2 {
      static {
        __name(this, "IDPRejectedClaimException");
      }
      name = "IDPRejectedClaimException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "IDPRejectedClaimException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _IDPRejectedClaimException.prototype);
      }
    };
    InvalidIdentityTokenException2 = class _InvalidIdentityTokenException extends STSServiceException2 {
      static {
        __name(this, "InvalidIdentityTokenException");
      }
      name = "InvalidIdentityTokenException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidIdentityTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidIdentityTokenException.prototype);
      }
    };
    IDPCommunicationErrorException2 = class _IDPCommunicationErrorException extends STSServiceException2 {
      static {
        __name(this, "IDPCommunicationErrorException");
      }
      name = "IDPCommunicationErrorException";
      $fault = "client";
      $retryable = {};
      constructor(opts) {
        super({
          name: "IDPCommunicationErrorException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _IDPCommunicationErrorException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/schemas/schemas_0.js
var _A2, _AKI2, _AR2, _ARI2, _ARR2, _ARRs2, _ARU2, _ARWWI2, _ARWWIR2, _ARWWIRs2, _Au2, _C2, _CA2, _DS2, _E2, _EI2, _ETE3, _IDPCEE2, _IDPRCE2, _IITE2, _K2, _MPDE2, _P2, _PA2, _PAr2, _PC2, _PCLT2, _PCr2, _PDT2, _PI2, _PPS2, _PPTLE2, _Pr2, _RA2, _RDE2, _RSN2, _SAK2, _SFWIT2, _SI2, _SN2, _ST2, _T2, _TC2, _TTK2, _Ta2, _V2, _WIT2, _a2, _aKST2, _aQE2, _c7, _cTT2, _e7, _hE7, _m6, _pDLT2, _s7, _tLT2, n07, _s_registry7, STSServiceException$2, n0_registry7, ExpiredTokenException$3, IDPCommunicationErrorException$2, IDPRejectedClaimException$2, InvalidIdentityTokenException$2, MalformedPolicyDocumentException$2, PackedPolicyTooLargeException$2, RegionDisabledException$2, errorTypeRegistries7, accessKeySecretType2, clientTokenType2, AssumedRoleUser$2, AssumeRoleRequest$2, AssumeRoleResponse$2, AssumeRoleWithWebIdentityRequest$2, AssumeRoleWithWebIdentityResponse$2, Credentials$2, PolicyDescriptorType$2, ProvidedContext$2, Tag$2, policyDescriptorListType2, ProvidedContextsListType2, tagKeyListType2, tagListType2, AssumeRole$2, AssumeRoleWithWebIdentity$2;
var init_schemas_07 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/schemas/schemas_0.js"() {
    init_schema4();
    init_errors7();
    init_STSServiceException2();
    _A2 = "Arn";
    _AKI2 = "AccessKeyId";
    _AR2 = "AssumeRole";
    _ARI2 = "AssumedRoleId";
    _ARR2 = "AssumeRoleRequest";
    _ARRs2 = "AssumeRoleResponse";
    _ARU2 = "AssumedRoleUser";
    _ARWWI2 = "AssumeRoleWithWebIdentity";
    _ARWWIR2 = "AssumeRoleWithWebIdentityRequest";
    _ARWWIRs2 = "AssumeRoleWithWebIdentityResponse";
    _Au2 = "Audience";
    _C2 = "Credentials";
    _CA2 = "ContextAssertion";
    _DS2 = "DurationSeconds";
    _E2 = "Expiration";
    _EI2 = "ExternalId";
    _ETE3 = "ExpiredTokenException";
    _IDPCEE2 = "IDPCommunicationErrorException";
    _IDPRCE2 = "IDPRejectedClaimException";
    _IITE2 = "InvalidIdentityTokenException";
    _K2 = "Key";
    _MPDE2 = "MalformedPolicyDocumentException";
    _P2 = "Policy";
    _PA2 = "PolicyArns";
    _PAr2 = "ProviderArn";
    _PC2 = "ProvidedContexts";
    _PCLT2 = "ProvidedContextsListType";
    _PCr2 = "ProvidedContext";
    _PDT2 = "PolicyDescriptorType";
    _PI2 = "ProviderId";
    _PPS2 = "PackedPolicySize";
    _PPTLE2 = "PackedPolicyTooLargeException";
    _Pr2 = "Provider";
    _RA2 = "RoleArn";
    _RDE2 = "RegionDisabledException";
    _RSN2 = "RoleSessionName";
    _SAK2 = "SecretAccessKey";
    _SFWIT2 = "SubjectFromWebIdentityToken";
    _SI2 = "SourceIdentity";
    _SN2 = "SerialNumber";
    _ST2 = "SessionToken";
    _T2 = "Tags";
    _TC2 = "TokenCode";
    _TTK2 = "TransitiveTagKeys";
    _Ta2 = "Tag";
    _V2 = "Value";
    _WIT2 = "WebIdentityToken";
    _a2 = "arn";
    _aKST2 = "accessKeySecretType";
    _aQE2 = "awsQueryError";
    _c7 = "client";
    _cTT2 = "clientTokenType";
    _e7 = "error";
    _hE7 = "httpError";
    _m6 = "message";
    _pDLT2 = "policyDescriptorListType";
    _s7 = "smithy.ts.sdk.synthetic.com.amazonaws.sts";
    _tLT2 = "tagListType";
    n07 = "com.amazonaws.sts";
    _s_registry7 = TypeRegistry.for(_s7);
    STSServiceException$2 = [-3, _s7, "STSServiceException", 0, [], []];
    _s_registry7.registerError(STSServiceException$2, STSServiceException2);
    n0_registry7 = TypeRegistry.for(n07);
    ExpiredTokenException$3 = [
      -3,
      n07,
      _ETE3,
      { [_aQE2]: [`ExpiredTokenException`, 400], [_e7]: _c7, [_hE7]: 400 },
      [_m6],
      [0]
    ];
    n0_registry7.registerError(ExpiredTokenException$3, ExpiredTokenException3);
    IDPCommunicationErrorException$2 = [
      -3,
      n07,
      _IDPCEE2,
      { [_aQE2]: [`IDPCommunicationError`, 400], [_e7]: _c7, [_hE7]: 400 },
      [_m6],
      [0]
    ];
    n0_registry7.registerError(IDPCommunicationErrorException$2, IDPCommunicationErrorException2);
    IDPRejectedClaimException$2 = [
      -3,
      n07,
      _IDPRCE2,
      { [_aQE2]: [`IDPRejectedClaim`, 403], [_e7]: _c7, [_hE7]: 403 },
      [_m6],
      [0]
    ];
    n0_registry7.registerError(IDPRejectedClaimException$2, IDPRejectedClaimException2);
    InvalidIdentityTokenException$2 = [
      -3,
      n07,
      _IITE2,
      { [_aQE2]: [`InvalidIdentityToken`, 400], [_e7]: _c7, [_hE7]: 400 },
      [_m6],
      [0]
    ];
    n0_registry7.registerError(InvalidIdentityTokenException$2, InvalidIdentityTokenException2);
    MalformedPolicyDocumentException$2 = [
      -3,
      n07,
      _MPDE2,
      { [_aQE2]: [`MalformedPolicyDocument`, 400], [_e7]: _c7, [_hE7]: 400 },
      [_m6],
      [0]
    ];
    n0_registry7.registerError(MalformedPolicyDocumentException$2, MalformedPolicyDocumentException2);
    PackedPolicyTooLargeException$2 = [
      -3,
      n07,
      _PPTLE2,
      { [_aQE2]: [`PackedPolicyTooLarge`, 400], [_e7]: _c7, [_hE7]: 400 },
      [_m6],
      [0]
    ];
    n0_registry7.registerError(PackedPolicyTooLargeException$2, PackedPolicyTooLargeException2);
    RegionDisabledException$2 = [
      -3,
      n07,
      _RDE2,
      { [_aQE2]: [`RegionDisabledException`, 403], [_e7]: _c7, [_hE7]: 403 },
      [_m6],
      [0]
    ];
    n0_registry7.registerError(RegionDisabledException$2, RegionDisabledException2);
    errorTypeRegistries7 = [_s_registry7, n0_registry7];
    accessKeySecretType2 = [0, n07, _aKST2, 8, 0];
    clientTokenType2 = [0, n07, _cTT2, 8, 0];
    AssumedRoleUser$2 = [3, n07, _ARU2, 0, [_ARI2, _A2], [0, 0], 2];
    AssumeRoleRequest$2 = [
      3,
      n07,
      _ARR2,
      0,
      [_RA2, _RSN2, _PA2, _P2, _DS2, _T2, _TTK2, _EI2, _SN2, _TC2, _SI2, _PC2],
      [0, 0, () => policyDescriptorListType2, 0, 1, () => tagListType2, 64 | 0, 0, 0, 0, 0, () => ProvidedContextsListType2],
      2
    ];
    AssumeRoleResponse$2 = [
      3,
      n07,
      _ARRs2,
      0,
      [_C2, _ARU2, _PPS2, _SI2],
      [[() => Credentials$2, 0], () => AssumedRoleUser$2, 1, 0]
    ];
    AssumeRoleWithWebIdentityRequest$2 = [
      3,
      n07,
      _ARWWIR2,
      0,
      [_RA2, _RSN2, _WIT2, _PI2, _PA2, _P2, _DS2],
      [0, 0, [() => clientTokenType2, 0], 0, () => policyDescriptorListType2, 0, 1],
      3
    ];
    AssumeRoleWithWebIdentityResponse$2 = [
      3,
      n07,
      _ARWWIRs2,
      0,
      [_C2, _SFWIT2, _ARU2, _PPS2, _Pr2, _Au2, _SI2],
      [[() => Credentials$2, 0], 0, () => AssumedRoleUser$2, 1, 0, 0, 0]
    ];
    Credentials$2 = [
      3,
      n07,
      _C2,
      0,
      [_AKI2, _SAK2, _ST2, _E2],
      [0, [() => accessKeySecretType2, 0], 0, 4],
      4
    ];
    PolicyDescriptorType$2 = [3, n07, _PDT2, 0, [_a2], [0]];
    ProvidedContext$2 = [3, n07, _PCr2, 0, [_PAr2, _CA2], [0, 0]];
    Tag$2 = [3, n07, _Ta2, 0, [_K2, _V2], [0, 0], 2];
    policyDescriptorListType2 = [1, n07, _pDLT2, 0, () => PolicyDescriptorType$2];
    ProvidedContextsListType2 = [1, n07, _PCLT2, 0, () => ProvidedContext$2];
    tagKeyListType2 = 64 | 0;
    tagListType2 = [1, n07, _tLT2, 0, () => Tag$2];
    AssumeRole$2 = [9, n07, _AR2, 0, () => AssumeRoleRequest$2, () => AssumeRoleResponse$2];
    AssumeRoleWithWebIdentity$2 = [
      9,
      n07,
      _ARWWI2,
      0,
      () => AssumeRoleWithWebIdentityRequest$2,
      () => AssumeRoleWithWebIdentityResponse$2
    ];
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.shared.js
var import_signature_v4_multi_region4, import_smithy_client65, import_url_parser8, import_util_base6423, import_util_utf819, getRuntimeConfig13;
var init_runtimeConfig_shared7 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.shared.js"() {
    init_httpAuthSchemes4();
    init_protocols6();
    import_signature_v4_multi_region4 = __toESM(require_dist_cjs55());
    init_dist_es();
    import_smithy_client65 = __toESM(require_dist_cjs34());
    import_url_parser8 = __toESM(require_dist_cjs18());
    import_util_base6423 = __toESM(require_dist_cjs10());
    import_util_utf819 = __toESM(require_dist_cjs9());
    init_httpAuthSchemeProvider7();
    init_endpointResolver7();
    init_schemas_07();
    getRuntimeConfig13 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2011-06-15",
        base64Decoder: config2?.base64Decoder ?? import_util_base6423.fromBase64,
        base64Encoder: config2?.base64Encoder ?? import_util_base6423.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver7,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSTSHttpAuthSchemeProvider2,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer3()
          },
          {
            schemeId: "aws.auth#sigv4a",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4a"), "identityProvider"),
            signer: new AwsSdkSigV4ASigner3()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        logger: config2?.logger ?? new import_smithy_client65.NoOpLogger(),
        protocol: config2?.protocol ?? AwsQueryProtocol3,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.sts",
          errorTypeRegistries: errorTypeRegistries7,
          xmlNamespace: "https://sts.amazonaws.com/doc/2011-06-15/",
          version: "2011-06-15",
          serviceTarget: "AWSSecurityTokenServiceV20110615"
        },
        serviceId: config2?.serviceId ?? "STS",
        signerConstructor: config2?.signerConstructor ?? import_signature_v4_multi_region4.SignatureV4MultiRegion,
        urlParser: config2?.urlParser ?? import_url_parser8.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? import_util_utf819.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? import_util_utf819.toUtf8
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.js
var import_util_user_agent_node7, import_config_resolver13, import_hash_node7, import_middleware_retry13, import_node_config_provider7, import_node_http_handler7, import_smithy_client66, import_util_body_length_node7, import_util_defaults_mode_node7, import_util_retry12, getRuntimeConfig14;
var init_runtimeConfig7 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.js"() {
    init_package3();
    init_client6();
    init_httpAuthSchemes4();
    import_util_user_agent_node7 = __toESM(require_dist_cjs75());
    import_config_resolver13 = __toESM(require_dist_cjs25());
    init_dist_es();
    import_hash_node7 = __toESM(require_dist_cjs44());
    import_middleware_retry13 = __toESM(require_dist_cjs71());
    import_node_config_provider7 = __toESM(require_dist_cjs29());
    import_node_http_handler7 = __toESM(require_dist_cjs13());
    import_smithy_client66 = __toESM(require_dist_cjs34());
    import_util_body_length_node7 = __toESM(require_dist_cjs45());
    import_util_defaults_mode_node7 = __toESM(require_dist_cjs46());
    import_util_retry12 = __toESM(require_dist_cjs22());
    init_runtimeConfig_shared7();
    getRuntimeConfig14 = /* @__PURE__ */ __name((config2) => {
      (0, import_smithy_client66.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, import_util_defaults_mode_node7.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(import_smithy_client66.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig13(config2);
      emitWarningIfUnsupportedVersion9(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, import_node_config_provider7.loadConfig)(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS3, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? import_util_body_length_node7.calculateBodyLength,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, import_util_user_agent_node7.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_default3.version }),
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4") || (async (idProps) => await config2.credentialDefaultProvider(idProps?.__config || {})()), "identityProvider"),
            signer: new AwsSdkSigV4Signer3()
          },
          {
            schemeId: "aws.auth#sigv4a",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4a"), "identityProvider"),
            signer: new AwsSdkSigV4ASigner3()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        maxAttempts: config2?.maxAttempts ?? (0, import_node_config_provider7.loadConfig)(import_middleware_retry13.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, import_node_config_provider7.loadConfig)(import_config_resolver13.NODE_REGION_CONFIG_OPTIONS, { ...import_config_resolver13.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: import_node_http_handler7.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, import_node_config_provider7.loadConfig)({
          ...import_middleware_retry13.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || import_util_retry12.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? import_hash_node7.Hash.bind(null, "sha256"),
        sigv4aSigningRegionSet: config2?.sigv4aSigningRegionSet ?? (0, import_node_config_provider7.loadConfig)(NODE_SIGV4A_CONFIG_OPTIONS3, loaderConfig),
        streamCollector: config2?.streamCollector ?? import_node_http_handler7.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, import_node_config_provider7.loadConfig)(import_config_resolver13.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, import_node_config_provider7.loadConfig)(import_config_resolver13.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, import_node_config_provider7.loadConfig)(import_util_user_agent_node7.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration7, resolveHttpAuthRuntimeConfig7;
var init_httpAuthExtensionConfiguration7 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration7 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig7 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeExtensions.js
var import_region_config_resolver8, import_protocol_http24, import_smithy_client67, resolveRuntimeExtensions7;
var init_runtimeExtensions7 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeExtensions.js"() {
    import_region_config_resolver8 = __toESM(require_dist_cjs48());
    import_protocol_http24 = __toESM(require_dist_cjs2());
    import_smithy_client67 = __toESM(require_dist_cjs34());
    init_httpAuthExtensionConfiguration7();
    resolveRuntimeExtensions7 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign((0, import_region_config_resolver8.getAwsRegionExtensionConfiguration)(runtimeConfig), (0, import_smithy_client67.getDefaultExtensionConfiguration)(runtimeConfig), (0, import_protocol_http24.getHttpHandlerExtensionConfiguration)(runtimeConfig), getHttpAuthExtensionConfiguration7(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, (0, import_region_config_resolver8.resolveAwsRegionExtensionConfiguration)(extensionConfiguration), (0, import_smithy_client67.resolveDefaultRuntimeConfig)(extensionConfiguration), (0, import_protocol_http24.resolveHttpHandlerRuntimeConfig)(extensionConfiguration), resolveHttpAuthRuntimeConfig7(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STSClient.js
var import_middleware_host_header7, import_middleware_logger7, import_middleware_recursion_detection7, import_middleware_user_agent7, import_config_resolver14, import_middleware_content_length7, import_middleware_endpoint16, import_middleware_retry14, import_smithy_client68, STSClient2;
var init_STSClient2 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STSClient.js"() {
    import_middleware_host_header7 = __toESM(require_dist_cjs3());
    import_middleware_logger7 = __toESM(require_dist_cjs4());
    import_middleware_recursion_detection7 = __toESM(require_dist_cjs5());
    import_middleware_user_agent7 = __toESM(require_dist_cjs69());
    import_config_resolver14 = __toESM(require_dist_cjs25());
    init_dist_es();
    init_schema4();
    import_middleware_content_length7 = __toESM(require_dist_cjs26());
    import_middleware_endpoint16 = __toESM(require_dist_cjs31());
    import_middleware_retry14 = __toESM(require_dist_cjs71());
    import_smithy_client68 = __toESM(require_dist_cjs34());
    init_httpAuthSchemeProvider7();
    init_EndpointParameters7();
    init_runtimeConfig7();
    init_runtimeExtensions7();
    STSClient2 = class extends import_smithy_client68.Client {
      static {
        __name(this, "STSClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig14(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters7(_config_0);
        const _config_2 = (0, import_middleware_user_agent7.resolveUserAgentConfig)(_config_1);
        const _config_3 = (0, import_middleware_retry14.resolveRetryConfig)(_config_2);
        const _config_4 = (0, import_config_resolver14.resolveRegionConfig)(_config_3);
        const _config_5 = (0, import_middleware_host_header7.resolveHostHeaderConfig)(_config_4);
        const _config_6 = (0, import_middleware_endpoint16.resolveEndpointConfig)(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig7(_config_6);
        const _config_8 = resolveRuntimeExtensions7(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin(this.config));
        this.middlewareStack.use((0, import_middleware_user_agent7.getUserAgentPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_retry14.getRetryPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_content_length7.getContentLengthPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_host_header7.getHostHeaderPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_logger7.getLoggerPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_recursion_detection7.getRecursionDetectionPlugin)(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: defaultSTSHttpAuthSchemeParametersProvider2,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials,
            "aws.auth#sigv4a": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleCommand.js
var import_middleware_endpoint17, import_smithy_client69, AssumeRoleCommand2;
var init_AssumeRoleCommand2 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleCommand.js"() {
    import_middleware_endpoint17 = __toESM(require_dist_cjs31());
    import_smithy_client69 = __toESM(require_dist_cjs34());
    init_EndpointParameters7();
    init_schemas_07();
    AssumeRoleCommand2 = class extends import_smithy_client69.Command.classBuilder().ep(commonParams7).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint17.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "AssumeRole", {}).n("STSClient", "AssumeRoleCommand").sc(AssumeRole$2).build() {
      static {
        __name(this, "AssumeRoleCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleWithWebIdentityCommand.js
var import_middleware_endpoint18, import_smithy_client70, AssumeRoleWithWebIdentityCommand2;
var init_AssumeRoleWithWebIdentityCommand2 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleWithWebIdentityCommand.js"() {
    import_middleware_endpoint18 = __toESM(require_dist_cjs31());
    import_smithy_client70 = __toESM(require_dist_cjs34());
    init_EndpointParameters7();
    init_schemas_07();
    AssumeRoleWithWebIdentityCommand2 = class extends import_smithy_client70.Command.classBuilder().ep(commonParams7).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint18.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "AssumeRoleWithWebIdentity", {}).n("STSClient", "AssumeRoleWithWebIdentityCommand").sc(AssumeRoleWithWebIdentity$2).build() {
      static {
        __name(this, "AssumeRoleWithWebIdentityCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STS.js
var import_smithy_client71, commands7, STS2;
var init_STS2 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STS.js"() {
    import_smithy_client71 = __toESM(require_dist_cjs34());
    init_AssumeRoleCommand2();
    init_AssumeRoleWithWebIdentityCommand2();
    init_STSClient2();
    commands7 = {
      AssumeRoleCommand: AssumeRoleCommand2,
      AssumeRoleWithWebIdentityCommand: AssumeRoleWithWebIdentityCommand2
    };
    STS2 = class extends STSClient2 {
      static {
        __name(this, "STS");
      }
    };
    (0, import_smithy_client71.createAggregatedClient)(commands7, STS2);
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/index.js
var init_commands8 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/index.js"() {
    init_AssumeRoleCommand2();
    init_AssumeRoleWithWebIdentityCommand2();
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/models_0.js
var init_models_07 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultStsRoleAssumers.js
var import_region_config_resolver9, getAccountIdFromAssumedRoleUser2, resolveRegion2, getDefaultRoleAssumer3, getDefaultRoleAssumerWithWebIdentity3, isH22;
var init_defaultStsRoleAssumers2 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultStsRoleAssumers.js"() {
    init_client6();
    import_region_config_resolver9 = __toESM(require_dist_cjs48());
    init_AssumeRoleCommand2();
    init_AssumeRoleWithWebIdentityCommand2();
    getAccountIdFromAssumedRoleUser2 = /* @__PURE__ */ __name((assumedRoleUser) => {
      if (typeof assumedRoleUser?.Arn === "string") {
        const arnComponents = assumedRoleUser.Arn.split(":");
        if (arnComponents.length > 4 && arnComponents[4] !== "") {
          return arnComponents[4];
        }
      }
      return void 0;
    }, "getAccountIdFromAssumedRoleUser");
    resolveRegion2 = /* @__PURE__ */ __name(async (_region, _parentRegion, credentialProviderLogger, loaderConfig = {}) => {
      const region = typeof _region === "function" ? await _region() : _region;
      const parentRegion = typeof _parentRegion === "function" ? await _parentRegion() : _parentRegion;
      let stsDefaultRegion = "";
      const resolvedRegion = region ?? parentRegion ?? (stsDefaultRegion = await (0, import_region_config_resolver9.stsRegionDefaultResolver)(loaderConfig)());
      credentialProviderLogger?.debug?.("@aws-sdk/client-sts::resolveRegion", "accepting first of:", `${region} (credential provider clientConfig)`, `${parentRegion} (contextual client)`, `${stsDefaultRegion} (STS default: AWS_REGION, profile region, or us-east-1)`);
      return resolvedRegion;
    }, "resolveRegion");
    getDefaultRoleAssumer3 = /* @__PURE__ */ __name((stsOptions, STSClient12) => {
      let stsClient;
      let closureSourceCreds;
      return async (sourceCreds, params) => {
        closureSourceCreds = sourceCreds;
        if (!stsClient) {
          const { logger: logger5 = stsOptions?.parentClientConfig?.logger, profile = stsOptions?.parentClientConfig?.profile, region, requestHandler = stsOptions?.parentClientConfig?.requestHandler, credentialProviderLogger, userAgentAppId = stsOptions?.parentClientConfig?.userAgentAppId } = stsOptions;
          const resolvedRegion = await resolveRegion2(region, stsOptions?.parentClientConfig?.region, credentialProviderLogger, {
            logger: logger5,
            profile
          });
          const isCompatibleRequestHandler = !isH22(requestHandler);
          stsClient = new STSClient12({
            ...stsOptions,
            userAgentAppId,
            profile,
            credentialDefaultProvider: /* @__PURE__ */ __name(() => async () => closureSourceCreds, "credentialDefaultProvider"),
            region: resolvedRegion,
            requestHandler: isCompatibleRequestHandler ? requestHandler : void 0,
            logger: logger5
          });
        }
        const { Credentials, AssumedRoleUser } = await stsClient.send(new AssumeRoleCommand2(params));
        if (!Credentials || !Credentials.AccessKeyId || !Credentials.SecretAccessKey) {
          throw new Error(`Invalid response from STS.assumeRole call with role ${params.RoleArn}`);
        }
        const accountId = getAccountIdFromAssumedRoleUser2(AssumedRoleUser);
        const credentials = {
          accessKeyId: Credentials.AccessKeyId,
          secretAccessKey: Credentials.SecretAccessKey,
          sessionToken: Credentials.SessionToken,
          expiration: Credentials.Expiration,
          ...Credentials.CredentialScope && { credentialScope: Credentials.CredentialScope },
          ...accountId && { accountId }
        };
        setCredentialFeature5(credentials, "CREDENTIALS_STS_ASSUME_ROLE", "i");
        return credentials;
      };
    }, "getDefaultRoleAssumer");
    getDefaultRoleAssumerWithWebIdentity3 = /* @__PURE__ */ __name((stsOptions, STSClient12) => {
      let stsClient;
      return async (params) => {
        if (!stsClient) {
          const { logger: logger5 = stsOptions?.parentClientConfig?.logger, profile = stsOptions?.parentClientConfig?.profile, region, requestHandler = stsOptions?.parentClientConfig?.requestHandler, credentialProviderLogger, userAgentAppId = stsOptions?.parentClientConfig?.userAgentAppId } = stsOptions;
          const resolvedRegion = await resolveRegion2(region, stsOptions?.parentClientConfig?.region, credentialProviderLogger, {
            logger: logger5,
            profile
          });
          const isCompatibleRequestHandler = !isH22(requestHandler);
          stsClient = new STSClient12({
            ...stsOptions,
            userAgentAppId,
            profile,
            region: resolvedRegion,
            requestHandler: isCompatibleRequestHandler ? requestHandler : void 0,
            logger: logger5
          });
        }
        const { Credentials, AssumedRoleUser } = await stsClient.send(new AssumeRoleWithWebIdentityCommand2(params));
        if (!Credentials || !Credentials.AccessKeyId || !Credentials.SecretAccessKey) {
          throw new Error(`Invalid response from STS.assumeRoleWithWebIdentity call with role ${params.RoleArn}`);
        }
        const accountId = getAccountIdFromAssumedRoleUser2(AssumedRoleUser);
        const credentials = {
          accessKeyId: Credentials.AccessKeyId,
          secretAccessKey: Credentials.SecretAccessKey,
          sessionToken: Credentials.SessionToken,
          expiration: Credentials.Expiration,
          ...Credentials.CredentialScope && { credentialScope: Credentials.CredentialScope },
          ...accountId && { accountId }
        };
        if (accountId) {
          setCredentialFeature5(credentials, "RESOLVED_ACCOUNT_ID", "T");
        }
        setCredentialFeature5(credentials, "CREDENTIALS_STS_ASSUME_ROLE_WEB_ID", "k");
        return credentials;
      };
    }, "getDefaultRoleAssumerWithWebIdentity");
    isH22 = /* @__PURE__ */ __name((requestHandler) => {
      return requestHandler?.metadata?.handlerProtocol === "h2";
    }, "isH2");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultRoleAssumers.js
var getCustomizableStsClientCtor2, getDefaultRoleAssumer4, getDefaultRoleAssumerWithWebIdentity4, decorateDefaultCredentialProvider2;
var init_defaultRoleAssumers2 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultRoleAssumers.js"() {
    init_defaultStsRoleAssumers2();
    init_STSClient2();
    getCustomizableStsClientCtor2 = /* @__PURE__ */ __name((baseCtor, customizations) => {
      if (!customizations)
        return baseCtor;
      else
        return class CustomizableSTSClient extends baseCtor {
          static {
            __name(this, "CustomizableSTSClient");
          }
          constructor(config2) {
            super(config2);
            for (const customization of customizations) {
              this.middlewareStack.use(customization);
            }
          }
        };
    }, "getCustomizableStsClientCtor");
    getDefaultRoleAssumer4 = /* @__PURE__ */ __name((stsOptions = {}, stsPlugins) => getDefaultRoleAssumer3(stsOptions, getCustomizableStsClientCtor2(STSClient2, stsPlugins)), "getDefaultRoleAssumer");
    getDefaultRoleAssumerWithWebIdentity4 = /* @__PURE__ */ __name((stsOptions = {}, stsPlugins) => getDefaultRoleAssumerWithWebIdentity3(stsOptions, getCustomizableStsClientCtor2(STSClient2, stsPlugins)), "getDefaultRoleAssumerWithWebIdentity");
    decorateDefaultCredentialProvider2 = /* @__PURE__ */ __name((provider) => (input) => provider({
      roleAssumer: getDefaultRoleAssumer4(input),
      roleAssumerWithWebIdentity: getDefaultRoleAssumerWithWebIdentity4(input),
      ...input
    }), "decorateDefaultCredentialProvider");
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/index.js
var sts_exports2 = {};
__export(sts_exports2, {
  AssumeRole$: () => AssumeRole$2,
  AssumeRoleCommand: () => AssumeRoleCommand2,
  AssumeRoleRequest$: () => AssumeRoleRequest$2,
  AssumeRoleResponse$: () => AssumeRoleResponse$2,
  AssumeRoleWithWebIdentity$: () => AssumeRoleWithWebIdentity$2,
  AssumeRoleWithWebIdentityCommand: () => AssumeRoleWithWebIdentityCommand2,
  AssumeRoleWithWebIdentityRequest$: () => AssumeRoleWithWebIdentityRequest$2,
  AssumeRoleWithWebIdentityResponse$: () => AssumeRoleWithWebIdentityResponse$2,
  AssumedRoleUser$: () => AssumedRoleUser$2,
  Credentials$: () => Credentials$2,
  ExpiredTokenException: () => ExpiredTokenException3,
  ExpiredTokenException$: () => ExpiredTokenException$3,
  IDPCommunicationErrorException: () => IDPCommunicationErrorException2,
  IDPCommunicationErrorException$: () => IDPCommunicationErrorException$2,
  IDPRejectedClaimException: () => IDPRejectedClaimException2,
  IDPRejectedClaimException$: () => IDPRejectedClaimException$2,
  InvalidIdentityTokenException: () => InvalidIdentityTokenException2,
  InvalidIdentityTokenException$: () => InvalidIdentityTokenException$2,
  MalformedPolicyDocumentException: () => MalformedPolicyDocumentException2,
  MalformedPolicyDocumentException$: () => MalformedPolicyDocumentException$2,
  PackedPolicyTooLargeException: () => PackedPolicyTooLargeException2,
  PackedPolicyTooLargeException$: () => PackedPolicyTooLargeException$2,
  PolicyDescriptorType$: () => PolicyDescriptorType$2,
  ProvidedContext$: () => ProvidedContext$2,
  RegionDisabledException: () => RegionDisabledException2,
  RegionDisabledException$: () => RegionDisabledException$2,
  STS: () => STS2,
  STSClient: () => STSClient2,
  STSServiceException: () => STSServiceException2,
  STSServiceException$: () => STSServiceException$2,
  Tag$: () => Tag$2,
  __Client: () => import_smithy_client68.Client,
  decorateDefaultCredentialProvider: () => decorateDefaultCredentialProvider2,
  errorTypeRegistries: () => errorTypeRegistries7,
  getDefaultRoleAssumer: () => getDefaultRoleAssumer4,
  getDefaultRoleAssumerWithWebIdentity: () => getDefaultRoleAssumerWithWebIdentity4
});
var init_sts2 = __esm({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/index.js"() {
    init_STSClient2();
    init_STS2();
    init_commands8();
    init_schemas_07();
    init_errors7();
    init_models_07();
    init_defaultRoleAssumers2();
    init_STSServiceException2();
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-process/dist-cjs/index.js
var require_dist_cjs78 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-process/dist-cjs/index.js"(exports2) {
    "use strict";
    var sharedIniFileLoader = require_dist_cjs28();
    var propertyProvider = require_dist_cjs27();
    var node_child_process = require("node:child_process");
    var node_util = require("node:util");
    var client = (init_client6(), __toCommonJS(client_exports5));
    var getValidatedProcessCredentials = /* @__PURE__ */ __name((profileName, data3, profiles) => {
      if (data3.Version !== 1) {
        throw Error(`Profile ${profileName} credential_process did not return Version 1.`);
      }
      if (data3.AccessKeyId === void 0 || data3.SecretAccessKey === void 0) {
        throw Error(`Profile ${profileName} credential_process returned invalid credentials.`);
      }
      if (data3.Expiration) {
        const currentTime = /* @__PURE__ */ new Date();
        const expireTime = new Date(data3.Expiration);
        if (expireTime < currentTime) {
          throw Error(`Profile ${profileName} credential_process returned expired credentials.`);
        }
      }
      let accountId = data3.AccountId;
      if (!accountId && profiles?.[profileName]?.aws_account_id) {
        accountId = profiles[profileName].aws_account_id;
      }
      const credentials = {
        accessKeyId: data3.AccessKeyId,
        secretAccessKey: data3.SecretAccessKey,
        ...data3.SessionToken && { sessionToken: data3.SessionToken },
        ...data3.Expiration && { expiration: new Date(data3.Expiration) },
        ...data3.CredentialScope && { credentialScope: data3.CredentialScope },
        ...accountId && { accountId }
      };
      client.setCredentialFeature(credentials, "CREDENTIALS_PROCESS", "w");
      return credentials;
    }, "getValidatedProcessCredentials");
    var resolveProcessCredentials = /* @__PURE__ */ __name(async (profileName, profiles, logger5) => {
      const profile = profiles[profileName];
      if (profiles[profileName]) {
        const credentialProcess = profile["credential_process"];
        if (credentialProcess !== void 0) {
          const execPromise = node_util.promisify(sharedIniFileLoader.externalDataInterceptor?.getTokenRecord?.().exec ?? node_child_process.exec);
          try {
            const { stdout } = await execPromise(credentialProcess);
            let data3;
            try {
              data3 = JSON.parse(stdout.trim());
            } catch {
              throw Error(`Profile ${profileName} credential_process returned invalid JSON.`);
            }
            return getValidatedProcessCredentials(profileName, data3, profiles);
          } catch (error4) {
            throw new propertyProvider.CredentialsProviderError(error4.message, { logger: logger5 });
          }
        } else {
          throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} did not contain credential_process.`, { logger: logger5 });
        }
      } else {
        throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} could not be found in shared credentials file.`, {
          logger: logger5
        });
      }
    }, "resolveProcessCredentials");
    var fromProcess = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/credential-provider-process - fromProcess");
      const profiles = await sharedIniFileLoader.parseKnownFiles(init);
      return resolveProcessCredentials(sharedIniFileLoader.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      }), profiles, init.logger);
    }, "fromProcess");
    exports2.fromProcess = fromProcess;
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromWebToken.js
var require_fromWebToken2 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromWebToken.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __setModuleDefault2 = exports2 && exports2.__setModuleDefault || (Object.create ? (function(o10, v) {
      Object.defineProperty(o10, "default", { enumerable: true, value: v });
    }) : function(o10, v) {
      o10["default"] = v;
    });
    var __importStar2 = exports2 && exports2.__importStar || /* @__PURE__ */ (function() {
      var ownKeys2 = /* @__PURE__ */ __name(function(o10) {
        ownKeys2 = Object.getOwnPropertyNames || function(o11) {
          var ar = [];
          for (var k32 in o11) if (Object.prototype.hasOwnProperty.call(o11, k32)) ar[ar.length] = k32;
          return ar;
        };
        return ownKeys2(o10);
      }, "ownKeys");
      return function(mod) {
        if (mod && mod.__esModule) return mod;
        var result2 = {};
        if (mod != null) {
          for (var k32 = ownKeys2(mod), i32 = 0; i32 < k32.length; i32++) if (k32[i32] !== "default") __createBinding3(result2, mod, k32[i32]);
        }
        __setModuleDefault2(result2, mod);
        return result2;
      };
    })();
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromWebToken = void 0;
    var fromWebToken = /* @__PURE__ */ __name((init) => async (awsIdentityProperties) => {
      init.logger?.debug("@aws-sdk/credential-provider-web-identity - fromWebToken");
      const { roleArn, roleSessionName, webIdentityToken, providerId, policyArns, policy, durationSeconds } = init;
      let { roleAssumerWithWebIdentity } = init;
      if (!roleAssumerWithWebIdentity) {
        const { getDefaultRoleAssumerWithWebIdentity: getDefaultRoleAssumerWithWebIdentity19 } = await Promise.resolve().then(() => __importStar2((init_sts2(), __toCommonJS(sts_exports2))));
        roleAssumerWithWebIdentity = getDefaultRoleAssumerWithWebIdentity19({
          ...init.clientConfig,
          credentialProviderLogger: init.logger,
          parentClientConfig: {
            ...awsIdentityProperties?.callerClientConfig,
            ...init.parentClientConfig
          }
        }, init.clientPlugins);
      }
      return roleAssumerWithWebIdentity({
        RoleArn: roleArn,
        RoleSessionName: roleSessionName ?? `aws-sdk-js-session-${Date.now()}`,
        WebIdentityToken: webIdentityToken,
        ProviderId: providerId,
        PolicyArns: policyArns,
        Policy: policy,
        DurationSeconds: durationSeconds
      });
    }, "fromWebToken");
    exports2.fromWebToken = fromWebToken;
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromTokenFile.js
var require_fromTokenFile2 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromTokenFile.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromTokenFile = void 0;
    var client_1 = (init_client6(), __toCommonJS(client_exports5));
    var property_provider_1 = require_dist_cjs27();
    var shared_ini_file_loader_1 = require_dist_cjs28();
    var node_fs_1 = require("node:fs");
    var fromWebToken_1 = require_fromWebToken2();
    var ENV_TOKEN_FILE = "AWS_WEB_IDENTITY_TOKEN_FILE";
    var ENV_ROLE_ARN = "AWS_ROLE_ARN";
    var ENV_ROLE_SESSION_NAME = "AWS_ROLE_SESSION_NAME";
    var fromTokenFile = /* @__PURE__ */ __name((init = {}) => async (awsIdentityProperties) => {
      init.logger?.debug("@aws-sdk/credential-provider-web-identity - fromTokenFile");
      const webIdentityTokenFile = init?.webIdentityTokenFile ?? process.env[ENV_TOKEN_FILE];
      const roleArn = init?.roleArn ?? process.env[ENV_ROLE_ARN];
      const roleSessionName = init?.roleSessionName ?? process.env[ENV_ROLE_SESSION_NAME];
      if (!webIdentityTokenFile || !roleArn) {
        throw new property_provider_1.CredentialsProviderError("Web identity configuration not specified", {
          logger: init.logger
        });
      }
      const credentials = await (0, fromWebToken_1.fromWebToken)({
        ...init,
        webIdentityToken: shared_ini_file_loader_1.externalDataInterceptor?.getTokenRecord?.()[webIdentityTokenFile] ?? (0, node_fs_1.readFileSync)(webIdentityTokenFile, { encoding: "ascii" }),
        roleArn,
        roleSessionName
      })(awsIdentityProperties);
      if (webIdentityTokenFile === process.env[ENV_TOKEN_FILE]) {
        (0, client_1.setCredentialFeature)(credentials, "CREDENTIALS_ENV_VARS_STS_WEB_ID_TOKEN", "h");
      }
      return credentials;
    }, "fromTokenFile");
    exports2.fromTokenFile = fromTokenFile;
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/index.js
var require_dist_cjs79 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/index.js"(exports2) {
    "use strict";
    var fromTokenFile = require_fromTokenFile2();
    var fromWebToken = require_fromWebToken2();
    Object.prototype.hasOwnProperty.call(fromTokenFile, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: fromTokenFile["__proto__"]
    });
    Object.keys(fromTokenFile).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = fromTokenFile[k32];
    });
    Object.prototype.hasOwnProperty.call(fromWebToken, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: fromWebToken["__proto__"]
    });
    Object.keys(fromWebToken).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = fromWebToken[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-ini/dist-cjs/index.js
var require_dist_cjs80 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-ini/dist-cjs/index.js"(exports2) {
    "use strict";
    var sharedIniFileLoader = require_dist_cjs28();
    var propertyProvider = require_dist_cjs27();
    var client = (init_client6(), __toCommonJS(client_exports5));
    var credentialProviderLogin = require_dist_cjs77();
    var resolveCredentialSource = /* @__PURE__ */ __name((credentialSource, profileName, logger5) => {
      const sourceProvidersMap = {
        EcsContainer: /* @__PURE__ */ __name(async (options) => {
          const { fromHttp } = await Promise.resolve().then(() => __toESM(require_dist_cjs74()));
          const { fromContainerMetadata } = await Promise.resolve().then(() => __toESM(require_dist_cjs38()));
          logger5?.debug("@aws-sdk/credential-provider-ini - credential_source is EcsContainer");
          return async () => propertyProvider.chain(fromHttp(options ?? {}), fromContainerMetadata(options))().then(setNamedProvider);
        }, "EcsContainer"),
        Ec2InstanceMetadata: /* @__PURE__ */ __name(async (options) => {
          logger5?.debug("@aws-sdk/credential-provider-ini - credential_source is Ec2InstanceMetadata");
          const { fromInstanceMetadata } = await Promise.resolve().then(() => __toESM(require_dist_cjs38()));
          return async () => fromInstanceMetadata(options)().then(setNamedProvider);
        }, "Ec2InstanceMetadata"),
        Environment: /* @__PURE__ */ __name(async (options) => {
          logger5?.debug("@aws-sdk/credential-provider-ini - credential_source is Environment");
          const { fromEnv: fromEnv6 } = await Promise.resolve().then(() => __toESM(require_dist_cjs72()));
          return async () => fromEnv6(options)().then(setNamedProvider);
        }, "Environment")
      };
      if (credentialSource in sourceProvidersMap) {
        return sourceProvidersMap[credentialSource];
      } else {
        throw new propertyProvider.CredentialsProviderError(`Unsupported credential source in profile ${profileName}. Got ${credentialSource}, expected EcsContainer or Ec2InstanceMetadata or Environment.`, { logger: logger5 });
      }
    }, "resolveCredentialSource");
    var setNamedProvider = /* @__PURE__ */ __name((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_NAMED_PROVIDER", "p"), "setNamedProvider");
    var isAssumeRoleProfile = /* @__PURE__ */ __name((arg, { profile = "default", logger: logger5 } = {}) => {
      return Boolean(arg) && typeof arg === "object" && typeof arg.role_arn === "string" && ["undefined", "string"].indexOf(typeof arg.role_session_name) > -1 && ["undefined", "string"].indexOf(typeof arg.external_id) > -1 && ["undefined", "string"].indexOf(typeof arg.mfa_serial) > -1 && (isAssumeRoleWithSourceProfile(arg, { profile, logger: logger5 }) || isCredentialSourceProfile(arg, { profile, logger: logger5 }));
    }, "isAssumeRoleProfile");
    var isAssumeRoleWithSourceProfile = /* @__PURE__ */ __name((arg, { profile, logger: logger5 }) => {
      const withSourceProfile = typeof arg.source_profile === "string" && typeof arg.credential_source === "undefined";
      if (withSourceProfile) {
        logger5?.debug?.(`    ${profile} isAssumeRoleWithSourceProfile source_profile=${arg.source_profile}`);
      }
      return withSourceProfile;
    }, "isAssumeRoleWithSourceProfile");
    var isCredentialSourceProfile = /* @__PURE__ */ __name((arg, { profile, logger: logger5 }) => {
      const withProviderProfile = typeof arg.credential_source === "string" && typeof arg.source_profile === "undefined";
      if (withProviderProfile) {
        logger5?.debug?.(`    ${profile} isCredentialSourceProfile credential_source=${arg.credential_source}`);
      }
      return withProviderProfile;
    }, "isCredentialSourceProfile");
    var resolveAssumeRoleCredentials = /* @__PURE__ */ __name(async (profileName, profiles, options, callerClientConfig, visitedProfiles = {}, resolveProfileData2) => {
      options.logger?.debug("@aws-sdk/credential-provider-ini - resolveAssumeRoleCredentials (STS)");
      const profileData = profiles[profileName];
      const { source_profile, region } = profileData;
      if (!options.roleAssumer) {
        const { getDefaultRoleAssumer: getDefaultRoleAssumer19 } = await Promise.resolve().then(() => (init_sts2(), sts_exports2));
        options.roleAssumer = getDefaultRoleAssumer19({
          ...options.clientConfig,
          credentialProviderLogger: options.logger,
          parentClientConfig: {
            ...callerClientConfig,
            ...options?.parentClientConfig,
            region: region ?? options?.parentClientConfig?.region ?? callerClientConfig?.region
          }
        }, options.clientPlugins);
      }
      if (source_profile && source_profile in visitedProfiles) {
        throw new propertyProvider.CredentialsProviderError(`Detected a cycle attempting to resolve credentials for profile ${sharedIniFileLoader.getProfileName(options)}. Profiles visited: ` + Object.keys(visitedProfiles).join(", "), { logger: options.logger });
      }
      options.logger?.debug(`@aws-sdk/credential-provider-ini - finding credential resolver using ${source_profile ? `source_profile=[${source_profile}]` : `profile=[${profileName}]`}`);
      const sourceCredsProvider = source_profile ? resolveProfileData2(source_profile, profiles, options, callerClientConfig, {
        ...visitedProfiles,
        [source_profile]: true
      }, isCredentialSourceWithoutRoleArn(profiles[source_profile] ?? {})) : (await resolveCredentialSource(profileData.credential_source, profileName, options.logger)(options))();
      if (isCredentialSourceWithoutRoleArn(profileData)) {
        return sourceCredsProvider.then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SOURCE_PROFILE", "o"));
      } else {
        const params = {
          RoleArn: profileData.role_arn,
          RoleSessionName: profileData.role_session_name || `aws-sdk-js-${Date.now()}`,
          ExternalId: profileData.external_id,
          DurationSeconds: parseInt(profileData.duration_seconds || "3600", 10)
        };
        const { mfa_serial } = profileData;
        if (mfa_serial) {
          if (!options.mfaCodeProvider) {
            throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} requires multi-factor authentication, but no MFA code callback was provided.`, { logger: options.logger, tryNextLink: false });
          }
          params.SerialNumber = mfa_serial;
          params.TokenCode = await options.mfaCodeProvider(mfa_serial);
        }
        const sourceCreds = await sourceCredsProvider;
        return options.roleAssumer(sourceCreds, params).then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SOURCE_PROFILE", "o"));
      }
    }, "resolveAssumeRoleCredentials");
    var isCredentialSourceWithoutRoleArn = /* @__PURE__ */ __name((section) => {
      return !section.role_arn && !!section.credential_source;
    }, "isCredentialSourceWithoutRoleArn");
    var isLoginProfile = /* @__PURE__ */ __name((data3) => {
      return Boolean(data3 && data3.login_session);
    }, "isLoginProfile");
    var resolveLoginCredentials = /* @__PURE__ */ __name(async (profileName, options, callerClientConfig) => {
      const credentials = await credentialProviderLogin.fromLoginCredentials({
        ...options,
        profile: profileName
      })({ callerClientConfig });
      return client.setCredentialFeature(credentials, "CREDENTIALS_PROFILE_LOGIN", "AC");
    }, "resolveLoginCredentials");
    var isProcessProfile = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.credential_process === "string", "isProcessProfile");
    var resolveProcessCredentials = /* @__PURE__ */ __name(async (options, profile) => Promise.resolve().then(() => __toESM(require_dist_cjs78())).then(({ fromProcess }) => fromProcess({
      ...options,
      profile
    })().then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_PROCESS", "v"))), "resolveProcessCredentials");
    var resolveSsoCredentials = /* @__PURE__ */ __name(async (profile, profileData, options = {}, callerClientConfig) => {
      const { fromSSO } = await Promise.resolve().then(() => __toESM(require_dist_cjs76()));
      return fromSSO({
        profile,
        logger: options.logger,
        parentClientConfig: options.parentClientConfig,
        clientConfig: options.clientConfig
      })({
        callerClientConfig
      }).then((creds) => {
        if (profileData.sso_session) {
          return client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SSO", "r");
        } else {
          return client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SSO_LEGACY", "t");
        }
      });
    }, "resolveSsoCredentials");
    var isSsoProfile = /* @__PURE__ */ __name((arg) => arg && (typeof arg.sso_start_url === "string" || typeof arg.sso_account_id === "string" || typeof arg.sso_session === "string" || typeof arg.sso_region === "string" || typeof arg.sso_role_name === "string"), "isSsoProfile");
    var isStaticCredsProfile = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.aws_access_key_id === "string" && typeof arg.aws_secret_access_key === "string" && ["undefined", "string"].indexOf(typeof arg.aws_session_token) > -1 && ["undefined", "string"].indexOf(typeof arg.aws_account_id) > -1, "isStaticCredsProfile");
    var resolveStaticCredentials = /* @__PURE__ */ __name(async (profile, options) => {
      options?.logger?.debug("@aws-sdk/credential-provider-ini - resolveStaticCredentials");
      const credentials = {
        accessKeyId: profile.aws_access_key_id,
        secretAccessKey: profile.aws_secret_access_key,
        sessionToken: profile.aws_session_token,
        ...profile.aws_credential_scope && { credentialScope: profile.aws_credential_scope },
        ...profile.aws_account_id && { accountId: profile.aws_account_id }
      };
      return client.setCredentialFeature(credentials, "CREDENTIALS_PROFILE", "n");
    }, "resolveStaticCredentials");
    var isWebIdentityProfile = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.web_identity_token_file === "string" && typeof arg.role_arn === "string" && ["undefined", "string"].indexOf(typeof arg.role_session_name) > -1, "isWebIdentityProfile");
    var resolveWebIdentityCredentials = /* @__PURE__ */ __name(async (profile, options, callerClientConfig) => Promise.resolve().then(() => __toESM(require_dist_cjs79())).then(({ fromTokenFile }) => fromTokenFile({
      webIdentityTokenFile: profile.web_identity_token_file,
      roleArn: profile.role_arn,
      roleSessionName: profile.role_session_name,
      roleAssumerWithWebIdentity: options.roleAssumerWithWebIdentity,
      logger: options.logger,
      parentClientConfig: options.parentClientConfig
    })({
      callerClientConfig
    }).then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_STS_WEB_ID_TOKEN", "q"))), "resolveWebIdentityCredentials");
    var resolveProfileData = /* @__PURE__ */ __name(async (profileName, profiles, options, callerClientConfig, visitedProfiles = {}, isAssumeRoleRecursiveCall = false) => {
      const data3 = profiles[profileName];
      if (Object.keys(visitedProfiles).length > 0 && isStaticCredsProfile(data3)) {
        return resolveStaticCredentials(data3, options);
      }
      if (isAssumeRoleRecursiveCall || isAssumeRoleProfile(data3, { profile: profileName, logger: options.logger })) {
        return resolveAssumeRoleCredentials(profileName, profiles, options, callerClientConfig, visitedProfiles, resolveProfileData);
      }
      if (isStaticCredsProfile(data3)) {
        return resolveStaticCredentials(data3, options);
      }
      if (isWebIdentityProfile(data3)) {
        return resolveWebIdentityCredentials(data3, options, callerClientConfig);
      }
      if (isProcessProfile(data3)) {
        return resolveProcessCredentials(options, profileName);
      }
      if (isSsoProfile(data3)) {
        return await resolveSsoCredentials(profileName, data3, options, callerClientConfig);
      }
      if (isLoginProfile(data3)) {
        return resolveLoginCredentials(profileName, options, callerClientConfig);
      }
      throw new propertyProvider.CredentialsProviderError(`Could not resolve credentials using profile: [${profileName}] in configuration/credentials file(s).`, { logger: options.logger });
    }, "resolveProfileData");
    var fromIni2 = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/credential-provider-ini - fromIni");
      const profiles = await sharedIniFileLoader.parseKnownFiles(init);
      return resolveProfileData(sharedIniFileLoader.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      }), profiles, init, callerClientConfig);
    }, "fromIni");
    exports2.fromIni = fromIni2;
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-node/dist-cjs/index.js
var require_dist_cjs81 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@aws-sdk/credential-provider-node/dist-cjs/index.js"(exports2) {
    "use strict";
    var credentialProviderEnv = require_dist_cjs72();
    var propertyProvider = require_dist_cjs27();
    var sharedIniFileLoader = require_dist_cjs28();
    var ENV_IMDS_DISABLED3 = "AWS_EC2_METADATA_DISABLED";
    var remoteProvider = /* @__PURE__ */ __name(async (init) => {
      const { ENV_CMDS_FULL_URI, ENV_CMDS_RELATIVE_URI, fromContainerMetadata, fromInstanceMetadata } = await Promise.resolve().then(() => __toESM(require_dist_cjs38()));
      if (process.env[ENV_CMDS_RELATIVE_URI] || process.env[ENV_CMDS_FULL_URI]) {
        init.logger?.debug("@aws-sdk/credential-provider-node - remoteProvider::fromHttp/fromContainerMetadata");
        const { fromHttp } = await Promise.resolve().then(() => __toESM(require_dist_cjs74()));
        return propertyProvider.chain(fromHttp(init), fromContainerMetadata(init));
      }
      if (process.env[ENV_IMDS_DISABLED3] && process.env[ENV_IMDS_DISABLED3] !== "false") {
        return async () => {
          throw new propertyProvider.CredentialsProviderError("EC2 Instance Metadata Service access disabled", { logger: init.logger });
        };
      }
      init.logger?.debug("@aws-sdk/credential-provider-node - remoteProvider::fromInstanceMetadata");
      return fromInstanceMetadata(init);
    }, "remoteProvider");
    function memoizeChain(providers, treatAsExpired) {
      const chain5 = internalCreateChain(providers);
      let activeLock;
      let passiveLock;
      let credentials;
      const provider = /* @__PURE__ */ __name(async (options) => {
        if (options?.forceRefresh) {
          return await chain5(options);
        }
        if (credentials?.expiration) {
          if (credentials?.expiration?.getTime() < Date.now()) {
            credentials = void 0;
          }
        }
        if (activeLock) {
          await activeLock;
        } else if (!credentials || treatAsExpired?.(credentials)) {
          if (credentials) {
            if (!passiveLock) {
              passiveLock = chain5(options).then((c32) => {
                credentials = c32;
              }).finally(() => {
                passiveLock = void 0;
              });
            }
          } else {
            activeLock = chain5(options).then((c32) => {
              credentials = c32;
            }).finally(() => {
              activeLock = void 0;
            });
            return provider(options);
          }
        }
        return credentials;
      }, "provider");
      return provider;
    }
    __name(memoizeChain, "memoizeChain");
    var internalCreateChain = /* @__PURE__ */ __name((providers) => async (awsIdentityProperties) => {
      let lastProviderError;
      for (const provider of providers) {
        try {
          return await provider(awsIdentityProperties);
        } catch (err) {
          lastProviderError = err;
          if (err?.tryNextLink) {
            continue;
          }
          throw err;
        }
      }
      throw lastProviderError;
    }, "internalCreateChain");
    var multipleCredentialSourceWarningEmitted = false;
    var defaultProvider = /* @__PURE__ */ __name((init = {}) => memoizeChain([
      async () => {
        const profile = init.profile ?? process.env[sharedIniFileLoader.ENV_PROFILE];
        if (profile) {
          const envStaticCredentialsAreSet = process.env[credentialProviderEnv.ENV_KEY] && process.env[credentialProviderEnv.ENV_SECRET];
          if (envStaticCredentialsAreSet) {
            if (!multipleCredentialSourceWarningEmitted) {
              const warnFn = init.logger?.warn && init.logger?.constructor?.name !== "NoOpLogger" ? init.logger.warn.bind(init.logger) : console.warn;
              warnFn(`@aws-sdk/credential-provider-node - defaultProvider::fromEnv WARNING:
    Multiple credential sources detected: 
    Both AWS_PROFILE and the pair AWS_ACCESS_KEY_ID/AWS_SECRET_ACCESS_KEY static credentials are set.
    This SDK will proceed with the AWS_PROFILE value.
    
    However, a future version may change this behavior to prefer the ENV static credentials.
    Please ensure that your environment only sets either the AWS_PROFILE or the
    AWS_ACCESS_KEY_ID/AWS_SECRET_ACCESS_KEY pair.
`);
              multipleCredentialSourceWarningEmitted = true;
            }
          }
          throw new propertyProvider.CredentialsProviderError("AWS_PROFILE is set, skipping fromEnv provider.", {
            logger: init.logger,
            tryNextLink: true
          });
        }
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromEnv");
        return credentialProviderEnv.fromEnv(init)();
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromSSO");
        const { ssoStartUrl, ssoAccountId, ssoRegion, ssoRoleName, ssoSession } = init;
        if (!ssoStartUrl && !ssoAccountId && !ssoRegion && !ssoRoleName && !ssoSession) {
          throw new propertyProvider.CredentialsProviderError("Skipping SSO provider in default chain (inputs do not include SSO fields).", { logger: init.logger });
        }
        const { fromSSO } = await Promise.resolve().then(() => __toESM(require_dist_cjs76()));
        return fromSSO(init)(awsIdentityProperties);
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromIni");
        const { fromIni: fromIni2 } = await Promise.resolve().then(() => __toESM(require_dist_cjs80()));
        return fromIni2(init)(awsIdentityProperties);
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromProcess");
        const { fromProcess } = await Promise.resolve().then(() => __toESM(require_dist_cjs78()));
        return fromProcess(init)(awsIdentityProperties);
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromTokenFile");
        const { fromTokenFile } = await Promise.resolve().then(() => __toESM(require_dist_cjs79()));
        return fromTokenFile(init)(awsIdentityProperties);
      },
      async () => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::remoteProvider");
        return (await remoteProvider(init))();
      },
      async () => {
        throw new propertyProvider.CredentialsProviderError("Could not load credentials from any providers", {
          tryNextLink: false,
          logger: init.logger
        });
      }
    ], credentialsTreatedAsExpired), "defaultProvider");
    var credentialsWillNeedRefresh = /* @__PURE__ */ __name((credentials) => credentials?.expiration !== void 0, "credentialsWillNeedRefresh");
    var credentialsTreatedAsExpired = /* @__PURE__ */ __name((credentials) => credentials?.expiration !== void 0 && credentials.expiration.getTime() - Date.now() < 3e5, "credentialsTreatedAsExpired");
    exports2.credentialsTreatedAsExpired = credentialsTreatedAsExpired;
    exports2.credentialsWillNeedRefresh = credentialsWillNeedRefresh;
    exports2.defaultProvider = defaultProvider;
  }
});

// ../../node_modules/@aws-sdk/middleware-bucket-endpoint/dist-cjs/index.js
var require_dist_cjs82 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-bucket-endpoint/dist-cjs/index.js"(exports2) {
    "use strict";
    var utilConfigProvider = require_dist_cjs24();
    var utilArnParser = require_dist_cjs53();
    var protocolHttp = require_dist_cjs2();
    var NODE_DISABLE_MULTIREGION_ACCESS_POINT_ENV_NAME = "AWS_S3_DISABLE_MULTIREGION_ACCESS_POINTS";
    var NODE_DISABLE_MULTIREGION_ACCESS_POINT_INI_NAME = "s3_disable_multiregion_access_points";
    var NODE_DISABLE_MULTIREGION_ACCESS_POINT_CONFIG_OPTIONS = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => utilConfigProvider.booleanSelector(env3, NODE_DISABLE_MULTIREGION_ACCESS_POINT_ENV_NAME, utilConfigProvider.SelectorType.ENV), "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => utilConfigProvider.booleanSelector(profile, NODE_DISABLE_MULTIREGION_ACCESS_POINT_INI_NAME, utilConfigProvider.SelectorType.CONFIG), "configFileSelector"),
      default: false
    };
    var NODE_USE_ARN_REGION_ENV_NAME = "AWS_S3_USE_ARN_REGION";
    var NODE_USE_ARN_REGION_INI_NAME = "s3_use_arn_region";
    var NODE_USE_ARN_REGION_CONFIG_OPTIONS = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => utilConfigProvider.booleanSelector(env3, NODE_USE_ARN_REGION_ENV_NAME, utilConfigProvider.SelectorType.ENV), "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => utilConfigProvider.booleanSelector(profile, NODE_USE_ARN_REGION_INI_NAME, utilConfigProvider.SelectorType.CONFIG), "configFileSelector"),
      default: void 0
    };
    var DOMAIN_PATTERN5 = /^[a-z0-9][a-z0-9\.\-]{1,61}[a-z0-9]$/;
    var IP_ADDRESS_PATTERN5 = /(\d+\.){3}\d+/;
    var DOTS_PATTERN5 = /\.\./;
    var DOT_PATTERN = /\./;
    var S3_HOSTNAME_PATTERN = /^(.+\.)?s3(-fips)?(\.dualstack)?[.-]([a-z0-9-]+)\./;
    var S3_US_EAST_1_ALTNAME_PATTERN = /^s3(-external-1)?\.amazonaws\.com$/;
    var AWS_PARTITION_SUFFIX = "amazonaws.com";
    var isBucketNameOptions = /* @__PURE__ */ __name((options) => typeof options.bucketName === "string", "isBucketNameOptions");
    var isDnsCompatibleBucketName5 = /* @__PURE__ */ __name((bucketName) => DOMAIN_PATTERN5.test(bucketName) && !IP_ADDRESS_PATTERN5.test(bucketName) && !DOTS_PATTERN5.test(bucketName), "isDnsCompatibleBucketName");
    var getRegionalSuffix = /* @__PURE__ */ __name((hostname) => {
      const parts = hostname.match(S3_HOSTNAME_PATTERN);
      return [parts[4], hostname.replace(new RegExp(`^${parts[0]}`), "")];
    }, "getRegionalSuffix");
    var getSuffix = /* @__PURE__ */ __name((hostname) => S3_US_EAST_1_ALTNAME_PATTERN.test(hostname) ? ["us-east-1", AWS_PARTITION_SUFFIX] : getRegionalSuffix(hostname), "getSuffix");
    var getSuffixForArnEndpoint = /* @__PURE__ */ __name((hostname) => S3_US_EAST_1_ALTNAME_PATTERN.test(hostname) ? [hostname.replace(`.${AWS_PARTITION_SUFFIX}`, ""), AWS_PARTITION_SUFFIX] : getRegionalSuffix(hostname), "getSuffixForArnEndpoint");
    var validateArnEndpointOptions = /* @__PURE__ */ __name((options) => {
      if (options.pathStyleEndpoint) {
        throw new Error("Path-style S3 endpoint is not supported when bucket is an ARN");
      }
      if (options.accelerateEndpoint) {
        throw new Error("Accelerate endpoint is not supported when bucket is an ARN");
      }
      if (!options.tlsCompatible) {
        throw new Error("HTTPS is required when bucket is an ARN");
      }
    }, "validateArnEndpointOptions");
    var validateService = /* @__PURE__ */ __name((service) => {
      if (service !== "s3" && service !== "s3-outposts" && service !== "s3-object-lambda") {
        throw new Error("Expect 's3' or 's3-outposts' or 's3-object-lambda' in ARN service component");
      }
    }, "validateService");
    var validateS3Service = /* @__PURE__ */ __name((service) => {
      if (service !== "s3") {
        throw new Error("Expect 's3' in Accesspoint ARN service component");
      }
    }, "validateS3Service");
    var validateOutpostService = /* @__PURE__ */ __name((service) => {
      if (service !== "s3-outposts") {
        throw new Error("Expect 's3-posts' in Outpost ARN service component");
      }
    }, "validateOutpostService");
    var validatePartition = /* @__PURE__ */ __name((partition4, options) => {
      if (partition4 !== options.clientPartition) {
        throw new Error(`Partition in ARN is incompatible, got "${partition4}" but expected "${options.clientPartition}"`);
      }
    }, "validatePartition");
    var validateRegion = /* @__PURE__ */ __name((region, options) => {
    }, "validateRegion");
    var validateRegionalClient = /* @__PURE__ */ __name((region) => {
      if (["s3-external-1", "aws-global"].includes(region)) {
        throw new Error(`Client region ${region} is not regional`);
      }
    }, "validateRegionalClient");
    var validateAccountId = /* @__PURE__ */ __name((accountId) => {
      if (!/[0-9]{12}/.exec(accountId)) {
        throw new Error("Access point ARN accountID does not match regex '[0-9]{12}'");
      }
    }, "validateAccountId");
    var validateDNSHostLabel = /* @__PURE__ */ __name((label, options = { tlsCompatible: true }) => {
      if (label.length >= 64 || !/^[a-z0-9][a-z0-9.-]*[a-z0-9]$/.test(label) || /(\d+\.){3}\d+/.test(label) || /[.-]{2}/.test(label) || options?.tlsCompatible && DOT_PATTERN.test(label)) {
        throw new Error(`Invalid DNS label ${label}`);
      }
    }, "validateDNSHostLabel");
    var validateCustomEndpoint = /* @__PURE__ */ __name((options) => {
      if (options.isCustomEndpoint) {
        if (options.dualstackEndpoint)
          throw new Error("Dualstack endpoint is not supported with custom endpoint");
        if (options.accelerateEndpoint)
          throw new Error("Accelerate endpoint is not supported with custom endpoint");
      }
    }, "validateCustomEndpoint");
    var getArnResources = /* @__PURE__ */ __name((resource) => {
      const delimiter2 = resource.includes(":") ? ":" : "/";
      const [resourceType, ...rest] = resource.split(delimiter2);
      if (resourceType === "accesspoint") {
        if (rest.length !== 1 || rest[0] === "") {
          throw new Error(`Access Point ARN should have one resource accesspoint${delimiter2}{accesspointname}`);
        }
        return { accesspointName: rest[0] };
      } else if (resourceType === "outpost") {
        if (!rest[0] || rest[1] !== "accesspoint" || !rest[2] || rest.length !== 3) {
          throw new Error(`Outpost ARN should have resource outpost${delimiter2}{outpostId}${delimiter2}accesspoint${delimiter2}{accesspointName}`);
        }
        const [outpostId, _, accesspointName] = rest;
        return { outpostId, accesspointName };
      } else {
        throw new Error(`ARN resource should begin with 'accesspoint${delimiter2}' or 'outpost${delimiter2}'`);
      }
    }, "getArnResources");
    var validateNoDualstack = /* @__PURE__ */ __name((dualstackEndpoint) => {
    }, "validateNoDualstack");
    var validateNoFIPS = /* @__PURE__ */ __name((useFipsEndpoint) => {
      if (useFipsEndpoint)
        throw new Error(`FIPS region is not supported with Outpost.`);
    }, "validateNoFIPS");
    var validateMrapAlias = /* @__PURE__ */ __name((name) => {
      try {
        name.split(".").forEach((label) => {
          validateDNSHostLabel(label);
        });
      } catch (e32) {
        throw new Error(`"${name}" is not a DNS compatible name.`);
      }
    }, "validateMrapAlias");
    var bucketHostname = /* @__PURE__ */ __name((options) => {
      validateCustomEndpoint(options);
      return isBucketNameOptions(options) ? getEndpointFromBucketName(options) : getEndpointFromArn(options);
    }, "bucketHostname");
    var getEndpointFromBucketName = /* @__PURE__ */ __name(({ accelerateEndpoint = false, clientRegion: region, baseHostname, bucketName, dualstackEndpoint = false, fipsEndpoint = false, pathStyleEndpoint = false, tlsCompatible = true, isCustomEndpoint = false }) => {
      const [clientRegion, hostnameSuffix] = isCustomEndpoint ? [region, baseHostname] : getSuffix(baseHostname);
      if (pathStyleEndpoint || !isDnsCompatibleBucketName5(bucketName) || tlsCompatible && DOT_PATTERN.test(bucketName)) {
        return {
          bucketEndpoint: false,
          hostname: dualstackEndpoint ? `s3.dualstack.${clientRegion}.${hostnameSuffix}` : baseHostname
        };
      }
      if (accelerateEndpoint) {
        baseHostname = `s3-accelerate${dualstackEndpoint ? ".dualstack" : ""}.${hostnameSuffix}`;
      } else if (dualstackEndpoint) {
        baseHostname = `s3.dualstack.${clientRegion}.${hostnameSuffix}`;
      }
      return {
        bucketEndpoint: true,
        hostname: `${bucketName}.${baseHostname}`
      };
    }, "getEndpointFromBucketName");
    var getEndpointFromArn = /* @__PURE__ */ __name((options) => {
      const { isCustomEndpoint, baseHostname, clientRegion } = options;
      const hostnameSuffix = isCustomEndpoint ? baseHostname : getSuffixForArnEndpoint(baseHostname)[1];
      const { pathStyleEndpoint, accelerateEndpoint = false, fipsEndpoint = false, tlsCompatible = true, bucketName, clientPartition = "aws" } = options;
      validateArnEndpointOptions({ pathStyleEndpoint, accelerateEndpoint, tlsCompatible });
      const { service, partition: partition4, accountId, region, resource } = bucketName;
      validateService(service);
      validatePartition(partition4, { clientPartition });
      validateAccountId(accountId);
      const { accesspointName, outpostId } = getArnResources(resource);
      if (service === "s3-object-lambda") {
        return getEndpointFromObjectLambdaArn({ ...options, tlsCompatible, bucketName, accesspointName, hostnameSuffix });
      }
      if (region === "") {
        return getEndpointFromMRAPArn({ ...options, mrapAlias: accesspointName, hostnameSuffix });
      }
      if (outpostId) {
        return getEndpointFromOutpostArn({ ...options, clientRegion, outpostId, accesspointName, hostnameSuffix });
      }
      return getEndpointFromAccessPointArn({ ...options, clientRegion, accesspointName, hostnameSuffix });
    }, "getEndpointFromArn");
    var getEndpointFromObjectLambdaArn = /* @__PURE__ */ __name(({ dualstackEndpoint = false, fipsEndpoint = false, tlsCompatible = true, useArnRegion, clientRegion, clientSigningRegion = clientRegion, accesspointName, bucketName, hostnameSuffix }) => {
      const { accountId, region, service } = bucketName;
      validateRegionalClient(clientRegion);
      const DNSHostLabel = `${accesspointName}-${accountId}`;
      validateDNSHostLabel(DNSHostLabel, { tlsCompatible });
      const endpointRegion = useArnRegion ? region : clientRegion;
      const signingRegion = useArnRegion ? region : clientSigningRegion;
      return {
        bucketEndpoint: true,
        hostname: `${DNSHostLabel}.${service}${fipsEndpoint ? "-fips" : ""}.${endpointRegion}.${hostnameSuffix}`,
        signingRegion,
        signingService: service
      };
    }, "getEndpointFromObjectLambdaArn");
    var getEndpointFromMRAPArn = /* @__PURE__ */ __name(({ disableMultiregionAccessPoints, dualstackEndpoint = false, isCustomEndpoint, mrapAlias, hostnameSuffix }) => {
      if (disableMultiregionAccessPoints === true) {
        throw new Error("SDK is attempting to use a MRAP ARN. Please enable to feature.");
      }
      validateMrapAlias(mrapAlias);
      return {
        bucketEndpoint: true,
        hostname: `${mrapAlias}${isCustomEndpoint ? "" : `.accesspoint.s3-global`}.${hostnameSuffix}`,
        signingRegion: "*"
      };
    }, "getEndpointFromMRAPArn");
    var getEndpointFromOutpostArn = /* @__PURE__ */ __name(({ useArnRegion, clientRegion, clientSigningRegion = clientRegion, bucketName, outpostId, dualstackEndpoint = false, fipsEndpoint = false, tlsCompatible = true, accesspointName, isCustomEndpoint, hostnameSuffix }) => {
      validateRegionalClient(clientRegion);
      const DNSHostLabel = `${accesspointName}-${bucketName.accountId}`;
      validateDNSHostLabel(DNSHostLabel, { tlsCompatible });
      const endpointRegion = useArnRegion ? bucketName.region : clientRegion;
      const signingRegion = useArnRegion ? bucketName.region : clientSigningRegion;
      validateOutpostService(bucketName.service);
      validateDNSHostLabel(outpostId, { tlsCompatible });
      validateNoFIPS(fipsEndpoint);
      const hostnamePrefix = `${DNSHostLabel}.${outpostId}`;
      return {
        bucketEndpoint: true,
        hostname: `${hostnamePrefix}${isCustomEndpoint ? "" : `.s3-outposts.${endpointRegion}`}.${hostnameSuffix}`,
        signingRegion,
        signingService: "s3-outposts"
      };
    }, "getEndpointFromOutpostArn");
    var getEndpointFromAccessPointArn = /* @__PURE__ */ __name(({ useArnRegion, clientRegion, clientSigningRegion = clientRegion, bucketName, dualstackEndpoint = false, fipsEndpoint = false, tlsCompatible = true, accesspointName, isCustomEndpoint, hostnameSuffix }) => {
      validateRegionalClient(clientRegion);
      const hostnamePrefix = `${accesspointName}-${bucketName.accountId}`;
      validateDNSHostLabel(hostnamePrefix, { tlsCompatible });
      const endpointRegion = useArnRegion ? bucketName.region : clientRegion;
      const signingRegion = useArnRegion ? bucketName.region : clientSigningRegion;
      validateS3Service(bucketName.service);
      return {
        bucketEndpoint: true,
        hostname: `${hostnamePrefix}${isCustomEndpoint ? "" : `.s3-accesspoint${fipsEndpoint ? "-fips" : ""}${dualstackEndpoint ? ".dualstack" : ""}.${endpointRegion}`}.${hostnameSuffix}`,
        signingRegion
      };
    }, "getEndpointFromAccessPointArn");
    var bucketEndpointMiddleware = /* @__PURE__ */ __name((options) => (next, context) => async (args) => {
      const { Bucket: bucketName } = args.input;
      let replaceBucketInPath = options.bucketEndpoint;
      const request4 = args.request;
      if (protocolHttp.HttpRequest.isInstance(request4)) {
        if (options.bucketEndpoint) {
          request4.hostname = bucketName;
        } else if (utilArnParser.validate(bucketName)) {
          const bucketArn = utilArnParser.parse(bucketName);
          const clientRegion = await options.region();
          const useDualstackEndpoint = await options.useDualstackEndpoint();
          const useFipsEndpoint = await options.useFipsEndpoint();
          const { partition: partition4, signingRegion = clientRegion } = await options.regionInfoProvider(clientRegion, { useDualstackEndpoint, useFipsEndpoint }) || {};
          const useArnRegion = await options.useArnRegion();
          const { hostname, bucketEndpoint, signingRegion: modifiedSigningRegion, signingService } = bucketHostname({
            bucketName: bucketArn,
            baseHostname: request4.hostname,
            accelerateEndpoint: options.useAccelerateEndpoint,
            dualstackEndpoint: useDualstackEndpoint,
            fipsEndpoint: useFipsEndpoint,
            pathStyleEndpoint: options.forcePathStyle,
            tlsCompatible: request4.protocol === "https:",
            useArnRegion,
            clientPartition: partition4,
            clientSigningRegion: signingRegion,
            clientRegion,
            isCustomEndpoint: options.isCustomEndpoint,
            disableMultiregionAccessPoints: await options.disableMultiregionAccessPoints()
          });
          if (modifiedSigningRegion && modifiedSigningRegion !== signingRegion) {
            context["signing_region"] = modifiedSigningRegion;
          }
          if (signingService && signingService !== "s3") {
            context["signing_service"] = signingService;
          }
          request4.hostname = hostname;
          replaceBucketInPath = bucketEndpoint;
        } else {
          const clientRegion = await options.region();
          const dualstackEndpoint = await options.useDualstackEndpoint();
          const fipsEndpoint = await options.useFipsEndpoint();
          const { hostname, bucketEndpoint } = bucketHostname({
            bucketName,
            clientRegion,
            baseHostname: request4.hostname,
            accelerateEndpoint: options.useAccelerateEndpoint,
            dualstackEndpoint,
            fipsEndpoint,
            pathStyleEndpoint: options.forcePathStyle,
            tlsCompatible: request4.protocol === "https:",
            isCustomEndpoint: options.isCustomEndpoint
          });
          request4.hostname = hostname;
          replaceBucketInPath = bucketEndpoint;
        }
        if (replaceBucketInPath) {
          request4.path = request4.path.replace(/^(\/)?[^\/]+/, "");
          if (request4.path === "") {
            request4.path = "/";
          }
        }
      }
      return next({ ...args, request: request4 });
    }, "bucketEndpointMiddleware");
    var bucketEndpointMiddlewareOptions = {
      tags: ["BUCKET_ENDPOINT"],
      name: "bucketEndpointMiddleware",
      relation: "before",
      toMiddleware: "hostHeaderMiddleware",
      override: true
    };
    var getBucketEndpointPlugin = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.addRelativeTo(bucketEndpointMiddleware(options), bucketEndpointMiddlewareOptions);
      }, "applyToStack")
    }), "getBucketEndpointPlugin");
    function resolveBucketEndpointConfig(input) {
      const { bucketEndpoint = false, forcePathStyle = false, useAccelerateEndpoint = false, useArnRegion, disableMultiregionAccessPoints = false } = input;
      return Object.assign(input, {
        bucketEndpoint,
        forcePathStyle,
        useAccelerateEndpoint,
        useArnRegion: typeof useArnRegion === "function" ? useArnRegion : () => Promise.resolve(useArnRegion),
        disableMultiregionAccessPoints: typeof disableMultiregionAccessPoints === "function" ? disableMultiregionAccessPoints : () => Promise.resolve(disableMultiregionAccessPoints)
      });
    }
    __name(resolveBucketEndpointConfig, "resolveBucketEndpointConfig");
    exports2.NODE_DISABLE_MULTIREGION_ACCESS_POINT_CONFIG_OPTIONS = NODE_DISABLE_MULTIREGION_ACCESS_POINT_CONFIG_OPTIONS;
    exports2.NODE_DISABLE_MULTIREGION_ACCESS_POINT_ENV_NAME = NODE_DISABLE_MULTIREGION_ACCESS_POINT_ENV_NAME;
    exports2.NODE_DISABLE_MULTIREGION_ACCESS_POINT_INI_NAME = NODE_DISABLE_MULTIREGION_ACCESS_POINT_INI_NAME;
    exports2.NODE_USE_ARN_REGION_CONFIG_OPTIONS = NODE_USE_ARN_REGION_CONFIG_OPTIONS;
    exports2.NODE_USE_ARN_REGION_ENV_NAME = NODE_USE_ARN_REGION_ENV_NAME;
    exports2.NODE_USE_ARN_REGION_INI_NAME = NODE_USE_ARN_REGION_INI_NAME;
    exports2.bucketEndpointMiddleware = bucketEndpointMiddleware;
    exports2.bucketEndpointMiddlewareOptions = bucketEndpointMiddlewareOptions;
    exports2.bucketHostname = bucketHostname;
    exports2.getArnResources = getArnResources;
    exports2.getBucketEndpointPlugin = getBucketEndpointPlugin;
    exports2.getSuffixForArnEndpoint = getSuffixForArnEndpoint;
    exports2.resolveBucketEndpointConfig = resolveBucketEndpointConfig;
    exports2.validateAccountId = validateAccountId;
    exports2.validateDNSHostLabel = validateDNSHostLabel;
    exports2.validateNoDualstack = validateNoDualstack;
    exports2.validateNoFIPS = validateNoFIPS;
    exports2.validateOutpostService = validateOutpostService;
    exports2.validatePartition = validatePartition;
    exports2.validateRegion = validateRegion;
  }
});

// ../../node_modules/@smithy/eventstream-codec/dist-cjs/index.js
var require_dist_cjs83 = __commonJS({
  "../../node_modules/@smithy/eventstream-codec/dist-cjs/index.js"(exports2) {
    "use strict";
    var crc32 = require_main3();
    var utilHexEncoding = require_dist_cjs15();
    var Int646 = class _Int64 {
      static {
        __name(this, "Int64");
      }
      bytes;
      constructor(bytes) {
        this.bytes = bytes;
        if (bytes.byteLength !== 8) {
          throw new Error("Int64 buffers must be exactly 8 bytes");
        }
      }
      static fromNumber(number) {
        if (number > 9223372036854776e3 || number < -9223372036854776e3) {
          throw new Error(`${number} is too large (or, if negative, too small) to represent as an Int64`);
        }
        const bytes = new Uint8Array(8);
        for (let i32 = 7, remaining = Math.abs(Math.round(number)); i32 > -1 && remaining > 0; i32--, remaining /= 256) {
          bytes[i32] = remaining;
        }
        if (number < 0) {
          negate6(bytes);
        }
        return new _Int64(bytes);
      }
      valueOf() {
        const bytes = this.bytes.slice(0);
        const negative = bytes[0] & 128;
        if (negative) {
          negate6(bytes);
        }
        return parseInt(utilHexEncoding.toHex(bytes), 16) * (negative ? -1 : 1);
      }
      toString() {
        return String(this.valueOf());
      }
    };
    function negate6(bytes) {
      for (let i32 = 0; i32 < 8; i32++) {
        bytes[i32] ^= 255;
      }
      for (let i32 = 7; i32 > -1; i32--) {
        bytes[i32]++;
        if (bytes[i32] !== 0)
          break;
      }
    }
    __name(negate6, "negate");
    var HeaderMarshaller6 = class {
      static {
        __name(this, "HeaderMarshaller");
      }
      toUtf8;
      fromUtf8;
      constructor(toUtf862, fromUtf842) {
        this.toUtf8 = toUtf862;
        this.fromUtf8 = fromUtf842;
      }
      format(headers) {
        const chunks2 = [];
        for (const headerName of Object.keys(headers)) {
          const bytes = this.fromUtf8(headerName);
          chunks2.push(Uint8Array.from([bytes.byteLength]), bytes, this.formatHeaderValue(headers[headerName]));
        }
        const out = new Uint8Array(chunks2.reduce((carry, bytes) => carry + bytes.byteLength, 0));
        let position = 0;
        for (const chunk of chunks2) {
          out.set(chunk, position);
          position += chunk.byteLength;
        }
        return out;
      }
      formatHeaderValue(header) {
        switch (header.type) {
          case "boolean":
            return Uint8Array.from([header.value ? 0 : 1]);
          case "byte":
            return Uint8Array.from([2, header.value]);
          case "short":
            const shortView = new DataView(new ArrayBuffer(3));
            shortView.setUint8(0, 3);
            shortView.setInt16(1, header.value, false);
            return new Uint8Array(shortView.buffer);
          case "integer":
            const intView = new DataView(new ArrayBuffer(5));
            intView.setUint8(0, 4);
            intView.setInt32(1, header.value, false);
            return new Uint8Array(intView.buffer);
          case "long":
            const longBytes = new Uint8Array(9);
            longBytes[0] = 5;
            longBytes.set(header.value.bytes, 1);
            return longBytes;
          case "binary":
            const binView = new DataView(new ArrayBuffer(3 + header.value.byteLength));
            binView.setUint8(0, 6);
            binView.setUint16(1, header.value.byteLength, false);
            const binBytes = new Uint8Array(binView.buffer);
            binBytes.set(header.value, 3);
            return binBytes;
          case "string":
            const utf8Bytes = this.fromUtf8(header.value);
            const strView = new DataView(new ArrayBuffer(3 + utf8Bytes.byteLength));
            strView.setUint8(0, 7);
            strView.setUint16(1, utf8Bytes.byteLength, false);
            const strBytes = new Uint8Array(strView.buffer);
            strBytes.set(utf8Bytes, 3);
            return strBytes;
          case "timestamp":
            const tsBytes = new Uint8Array(9);
            tsBytes[0] = 8;
            tsBytes.set(Int646.fromNumber(header.value.valueOf()).bytes, 1);
            return tsBytes;
          case "uuid":
            if (!UUID_PATTERN6.test(header.value)) {
              throw new Error(`Invalid UUID received: ${header.value}`);
            }
            const uuidBytes = new Uint8Array(17);
            uuidBytes[0] = 9;
            uuidBytes.set(utilHexEncoding.fromHex(header.value.replace(/\-/g, "")), 1);
            return uuidBytes;
        }
      }
      parse(headers) {
        const out = {};
        let position = 0;
        while (position < headers.byteLength) {
          const nameLength = headers.getUint8(position++);
          const name = this.toUtf8(new Uint8Array(headers.buffer, headers.byteOffset + position, nameLength));
          position += nameLength;
          switch (headers.getUint8(position++)) {
            case 0:
              out[name] = {
                type: BOOLEAN_TAG6,
                value: true
              };
              break;
            case 1:
              out[name] = {
                type: BOOLEAN_TAG6,
                value: false
              };
              break;
            case 2:
              out[name] = {
                type: BYTE_TAG6,
                value: headers.getInt8(position++)
              };
              break;
            case 3:
              out[name] = {
                type: SHORT_TAG6,
                value: headers.getInt16(position, false)
              };
              position += 2;
              break;
            case 4:
              out[name] = {
                type: INT_TAG6,
                value: headers.getInt32(position, false)
              };
              position += 4;
              break;
            case 5:
              out[name] = {
                type: LONG_TAG6,
                value: new Int646(new Uint8Array(headers.buffer, headers.byteOffset + position, 8))
              };
              position += 8;
              break;
            case 6:
              const binaryLength = headers.getUint16(position, false);
              position += 2;
              out[name] = {
                type: BINARY_TAG6,
                value: new Uint8Array(headers.buffer, headers.byteOffset + position, binaryLength)
              };
              position += binaryLength;
              break;
            case 7:
              const stringLength = headers.getUint16(position, false);
              position += 2;
              out[name] = {
                type: STRING_TAG6,
                value: this.toUtf8(new Uint8Array(headers.buffer, headers.byteOffset + position, stringLength))
              };
              position += stringLength;
              break;
            case 8:
              out[name] = {
                type: TIMESTAMP_TAG6,
                value: new Date(new Int646(new Uint8Array(headers.buffer, headers.byteOffset + position, 8)).valueOf())
              };
              position += 8;
              break;
            case 9:
              const uuidBytes = new Uint8Array(headers.buffer, headers.byteOffset + position, 16);
              position += 16;
              out[name] = {
                type: UUID_TAG6,
                value: `${utilHexEncoding.toHex(uuidBytes.subarray(0, 4))}-${utilHexEncoding.toHex(uuidBytes.subarray(4, 6))}-${utilHexEncoding.toHex(uuidBytes.subarray(6, 8))}-${utilHexEncoding.toHex(uuidBytes.subarray(8, 10))}-${utilHexEncoding.toHex(uuidBytes.subarray(10))}`
              };
              break;
            default:
              throw new Error(`Unrecognized header type tag`);
          }
        }
        return out;
      }
    };
    var HEADER_VALUE_TYPE6;
    (function(HEADER_VALUE_TYPE7) {
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["boolTrue"] = 0] = "boolTrue";
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["boolFalse"] = 1] = "boolFalse";
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["byte"] = 2] = "byte";
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["short"] = 3] = "short";
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["integer"] = 4] = "integer";
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["long"] = 5] = "long";
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["byteArray"] = 6] = "byteArray";
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["string"] = 7] = "string";
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["timestamp"] = 8] = "timestamp";
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["uuid"] = 9] = "uuid";
    })(HEADER_VALUE_TYPE6 || (HEADER_VALUE_TYPE6 = {}));
    var BOOLEAN_TAG6 = "boolean";
    var BYTE_TAG6 = "byte";
    var SHORT_TAG6 = "short";
    var INT_TAG6 = "integer";
    var LONG_TAG6 = "long";
    var BINARY_TAG6 = "binary";
    var STRING_TAG6 = "string";
    var TIMESTAMP_TAG6 = "timestamp";
    var UUID_TAG6 = "uuid";
    var UUID_PATTERN6 = /^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$/;
    var PRELUDE_MEMBER_LENGTH6 = 4;
    var PRELUDE_LENGTH6 = PRELUDE_MEMBER_LENGTH6 * 2;
    var CHECKSUM_LENGTH6 = 4;
    var MINIMUM_MESSAGE_LENGTH6 = PRELUDE_LENGTH6 + CHECKSUM_LENGTH6 * 2;
    function splitMessage6({ byteLength, byteOffset, buffer }) {
      if (byteLength < MINIMUM_MESSAGE_LENGTH6) {
        throw new Error("Provided message too short to accommodate event stream message overhead");
      }
      const view = new DataView(buffer, byteOffset, byteLength);
      const messageLength = view.getUint32(0, false);
      if (byteLength !== messageLength) {
        throw new Error("Reported message length does not match received message length");
      }
      const headerLength = view.getUint32(PRELUDE_MEMBER_LENGTH6, false);
      const expectedPreludeChecksum = view.getUint32(PRELUDE_LENGTH6, false);
      const expectedMessageChecksum = view.getUint32(byteLength - CHECKSUM_LENGTH6, false);
      const checksummer = new crc32.Crc32().update(new Uint8Array(buffer, byteOffset, PRELUDE_LENGTH6));
      if (expectedPreludeChecksum !== checksummer.digest()) {
        throw new Error(`The prelude checksum specified in the message (${expectedPreludeChecksum}) does not match the calculated CRC32 checksum (${checksummer.digest()})`);
      }
      checksummer.update(new Uint8Array(buffer, byteOffset + PRELUDE_LENGTH6, byteLength - (PRELUDE_LENGTH6 + CHECKSUM_LENGTH6)));
      if (expectedMessageChecksum !== checksummer.digest()) {
        throw new Error(`The message checksum (${checksummer.digest()}) did not match the expected value of ${expectedMessageChecksum}`);
      }
      return {
        headers: new DataView(buffer, byteOffset + PRELUDE_LENGTH6 + CHECKSUM_LENGTH6, headerLength),
        body: new Uint8Array(buffer, byteOffset + PRELUDE_LENGTH6 + CHECKSUM_LENGTH6 + headerLength, messageLength - headerLength - (PRELUDE_LENGTH6 + CHECKSUM_LENGTH6 + CHECKSUM_LENGTH6))
      };
    }
    __name(splitMessage6, "splitMessage");
    var EventStreamCodec6 = class {
      static {
        __name(this, "EventStreamCodec");
      }
      headerMarshaller;
      messageBuffer;
      isEndOfStream;
      constructor(toUtf862, fromUtf842) {
        this.headerMarshaller = new HeaderMarshaller6(toUtf862, fromUtf842);
        this.messageBuffer = [];
        this.isEndOfStream = false;
      }
      feed(message2) {
        this.messageBuffer.push(this.decode(message2));
      }
      endOfStream() {
        this.isEndOfStream = true;
      }
      getMessage() {
        const message2 = this.messageBuffer.pop();
        const isEndOfStream = this.isEndOfStream;
        return {
          getMessage() {
            return message2;
          },
          isEndOfStream() {
            return isEndOfStream;
          }
        };
      }
      getAvailableMessages() {
        const messages = this.messageBuffer;
        this.messageBuffer = [];
        const isEndOfStream = this.isEndOfStream;
        return {
          getMessages() {
            return messages;
          },
          isEndOfStream() {
            return isEndOfStream;
          }
        };
      }
      encode({ headers: rawHeaders, body }) {
        const headers = this.headerMarshaller.format(rawHeaders);
        const length = headers.byteLength + body.byteLength + 16;
        const out = new Uint8Array(length);
        const view = new DataView(out.buffer, out.byteOffset, out.byteLength);
        const checksum = new crc32.Crc32();
        view.setUint32(0, length, false);
        view.setUint32(4, headers.byteLength, false);
        view.setUint32(8, checksum.update(out.subarray(0, 8)).digest(), false);
        out.set(headers, 12);
        out.set(body, headers.byteLength + 12);
        view.setUint32(length - 4, checksum.update(out.subarray(8, length - 4)).digest(), false);
        return out;
      }
      decode(message2) {
        const { headers, body } = splitMessage6(message2);
        return { headers: this.headerMarshaller.parse(headers), body };
      }
      formatHeaders(rawHeaders) {
        return this.headerMarshaller.format(rawHeaders);
      }
    };
    var MessageDecoderStream6 = class {
      static {
        __name(this, "MessageDecoderStream");
      }
      options;
      constructor(options) {
        this.options = options;
      }
      [Symbol.asyncIterator]() {
        return this.asyncIterator();
      }
      async *asyncIterator() {
        for await (const bytes of this.options.inputStream) {
          const decoded = this.options.decoder.decode(bytes);
          yield decoded;
        }
      }
    };
    var MessageEncoderStream6 = class {
      static {
        __name(this, "MessageEncoderStream");
      }
      options;
      constructor(options) {
        this.options = options;
      }
      [Symbol.asyncIterator]() {
        return this.asyncIterator();
      }
      async *asyncIterator() {
        for await (const msg of this.options.messageStream) {
          const encoded = this.options.encoder.encode(msg);
          yield encoded;
        }
        if (this.options.includeEndFrame) {
          yield new Uint8Array(0);
        }
      }
    };
    var SmithyMessageDecoderStream6 = class {
      static {
        __name(this, "SmithyMessageDecoderStream");
      }
      options;
      constructor(options) {
        this.options = options;
      }
      [Symbol.asyncIterator]() {
        return this.asyncIterator();
      }
      async *asyncIterator() {
        for await (const message2 of this.options.messageStream) {
          const deserialized = await this.options.deserializer(message2);
          if (deserialized === void 0)
            continue;
          yield deserialized;
        }
      }
    };
    var SmithyMessageEncoderStream6 = class {
      static {
        __name(this, "SmithyMessageEncoderStream");
      }
      options;
      constructor(options) {
        this.options = options;
      }
      [Symbol.asyncIterator]() {
        return this.asyncIterator();
      }
      async *asyncIterator() {
        for await (const chunk of this.options.inputStream) {
          const payloadBuf = this.options.serializer(chunk);
          yield payloadBuf;
        }
      }
    };
    exports2.EventStreamCodec = EventStreamCodec6;
    exports2.HeaderMarshaller = HeaderMarshaller6;
    exports2.Int64 = Int646;
    exports2.MessageDecoderStream = MessageDecoderStream6;
    exports2.MessageEncoderStream = MessageEncoderStream6;
    exports2.SmithyMessageDecoderStream = SmithyMessageDecoderStream6;
    exports2.SmithyMessageEncoderStream = SmithyMessageEncoderStream6;
  }
});

// ../../node_modules/@smithy/eventstream-serde-universal/dist-cjs/index.js
var require_dist_cjs84 = __commonJS({
  "../../node_modules/@smithy/eventstream-serde-universal/dist-cjs/index.js"(exports2) {
    "use strict";
    var eventstreamCodec = require_dist_cjs83();
    function getChunkedStream6(source) {
      let currentMessageTotalLength = 0;
      let currentMessagePendingLength = 0;
      let currentMessage = null;
      let messageLengthBuffer = null;
      const allocateMessage = /* @__PURE__ */ __name((size) => {
        if (typeof size !== "number") {
          throw new Error("Attempted to allocate an event message where size was not a number: " + size);
        }
        currentMessageTotalLength = size;
        currentMessagePendingLength = 4;
        currentMessage = new Uint8Array(size);
        const currentMessageView = new DataView(currentMessage.buffer);
        currentMessageView.setUint32(0, size, false);
      }, "allocateMessage");
      const iterator = /* @__PURE__ */ __name(async function* () {
        const sourceIterator = source[Symbol.asyncIterator]();
        while (true) {
          const { value, done } = await sourceIterator.next();
          if (done) {
            if (!currentMessageTotalLength) {
              return;
            } else if (currentMessageTotalLength === currentMessagePendingLength) {
              yield currentMessage;
            } else {
              throw new Error("Truncated event message received.");
            }
            return;
          }
          const chunkLength = value.length;
          let currentOffset = 0;
          while (currentOffset < chunkLength) {
            if (!currentMessage) {
              const bytesRemaining = chunkLength - currentOffset;
              if (!messageLengthBuffer) {
                messageLengthBuffer = new Uint8Array(4);
              }
              const numBytesForTotal = Math.min(4 - currentMessagePendingLength, bytesRemaining);
              messageLengthBuffer.set(value.slice(currentOffset, currentOffset + numBytesForTotal), currentMessagePendingLength);
              currentMessagePendingLength += numBytesForTotal;
              currentOffset += numBytesForTotal;
              if (currentMessagePendingLength < 4) {
                break;
              }
              allocateMessage(new DataView(messageLengthBuffer.buffer).getUint32(0, false));
              messageLengthBuffer = null;
            }
            const numBytesToWrite = Math.min(currentMessageTotalLength - currentMessagePendingLength, chunkLength - currentOffset);
            currentMessage.set(value.slice(currentOffset, currentOffset + numBytesToWrite), currentMessagePendingLength);
            currentMessagePendingLength += numBytesToWrite;
            currentOffset += numBytesToWrite;
            if (currentMessageTotalLength && currentMessageTotalLength === currentMessagePendingLength) {
              yield currentMessage;
              currentMessage = null;
              currentMessageTotalLength = 0;
              currentMessagePendingLength = 0;
            }
          }
        }
      }, "iterator");
      return {
        [Symbol.asyncIterator]: iterator
      };
    }
    __name(getChunkedStream6, "getChunkedStream");
    function getMessageUnmarshaller6(deserializer, toUtf862) {
      return async function(message2) {
        const { value: messageType } = message2.headers[":message-type"];
        if (messageType === "error") {
          const unmodeledError = new Error(message2.headers[":error-message"].value || "UnknownError");
          unmodeledError.name = message2.headers[":error-code"].value;
          throw unmodeledError;
        } else if (messageType === "exception") {
          const code = message2.headers[":exception-type"].value;
          const exception = { [code]: message2 };
          const deserializedException = await deserializer(exception);
          if (deserializedException.$unknown) {
            const error4 = new Error(toUtf862(message2.body));
            error4.name = code;
            throw error4;
          }
          throw deserializedException[code];
        } else if (messageType === "event") {
          const event = {
            [message2.headers[":event-type"].value]: message2
          };
          const deserialized = await deserializer(event);
          if (deserialized.$unknown)
            return;
          return deserialized;
        } else {
          throw Error(`Unrecognizable event type: ${message2.headers[":event-type"].value}`);
        }
      };
    }
    __name(getMessageUnmarshaller6, "getMessageUnmarshaller");
    var EventStreamMarshaller11 = class {
      static {
        __name(this, "EventStreamMarshaller");
      }
      eventStreamCodec;
      utfEncoder;
      constructor({ utf8Encoder, utf8Decoder }) {
        this.eventStreamCodec = new eventstreamCodec.EventStreamCodec(utf8Encoder, utf8Decoder);
        this.utfEncoder = utf8Encoder;
      }
      deserialize(body, deserializer) {
        const inputStream = getChunkedStream6(body);
        return new eventstreamCodec.SmithyMessageDecoderStream({
          messageStream: new eventstreamCodec.MessageDecoderStream({ inputStream, decoder: this.eventStreamCodec }),
          deserializer: getMessageUnmarshaller6(deserializer, this.utfEncoder)
        });
      }
      serialize(inputStream, serializer) {
        return new eventstreamCodec.MessageEncoderStream({
          messageStream: new eventstreamCodec.SmithyMessageEncoderStream({ inputStream, serializer }),
          encoder: this.eventStreamCodec,
          includeEndFrame: true
        });
      }
    };
    var eventStreamSerdeProvider11 = /* @__PURE__ */ __name((options) => new EventStreamMarshaller11(options), "eventStreamSerdeProvider");
    exports2.EventStreamMarshaller = EventStreamMarshaller11;
    exports2.eventStreamSerdeProvider = eventStreamSerdeProvider11;
  }
});

// ../../node_modules/@smithy/eventstream-serde-node/dist-cjs/index.js
var require_dist_cjs85 = __commonJS({
  "../../node_modules/@smithy/eventstream-serde-node/dist-cjs/index.js"(exports2) {
    "use strict";
    var eventstreamSerdeUniversal = require_dist_cjs84();
    var stream = require("stream");
    async function* readabletoIterable(readStream) {
      let streamEnded = false;
      let generationEnded = false;
      const records = new Array();
      readStream.on("error", (err) => {
        if (!streamEnded) {
          streamEnded = true;
        }
        if (err) {
          throw err;
        }
      });
      readStream.on("data", (data3) => {
        records.push(data3);
      });
      readStream.on("end", () => {
        streamEnded = true;
      });
      while (!generationEnded) {
        const value = await new Promise((resolve13) => setTimeout(() => resolve13(records.shift()), 0));
        if (value) {
          yield value;
        }
        generationEnded = streamEnded && records.length === 0;
      }
    }
    __name(readabletoIterable, "readabletoIterable");
    var EventStreamMarshaller11 = class {
      static {
        __name(this, "EventStreamMarshaller");
      }
      universalMarshaller;
      constructor({ utf8Encoder, utf8Decoder }) {
        this.universalMarshaller = new eventstreamSerdeUniversal.EventStreamMarshaller({
          utf8Decoder,
          utf8Encoder
        });
      }
      deserialize(body, deserializer) {
        const bodyIterable = typeof body[Symbol.asyncIterator] === "function" ? body : readabletoIterable(body);
        return this.universalMarshaller.deserialize(bodyIterable, deserializer);
      }
      serialize(input, serializer) {
        return stream.Readable.from(this.universalMarshaller.serialize(input, serializer));
      }
    };
    var eventStreamSerdeProvider11 = /* @__PURE__ */ __name((options) => new EventStreamMarshaller11(options), "eventStreamSerdeProvider");
    exports2.EventStreamMarshaller = EventStreamMarshaller11;
    exports2.eventStreamSerdeProvider = eventStreamSerdeProvider11;
  }
});

// ../../node_modules/@smithy/hash-stream-node/dist-cjs/index.js
var require_dist_cjs86 = __commonJS({
  "../../node_modules/@smithy/hash-stream-node/dist-cjs/index.js"(exports2) {
    "use strict";
    var fs51 = require("fs");
    var utilUtf8 = require_dist_cjs9();
    var stream = require("stream");
    var HashCalculator = class extends stream.Writable {
      static {
        __name(this, "HashCalculator");
      }
      hash;
      constructor(hash, options) {
        super(options);
        this.hash = hash;
      }
      _write(chunk, encoding, callback) {
        try {
          this.hash.update(utilUtf8.toUint8Array(chunk));
        } catch (err) {
          return callback(err);
        }
        callback();
      }
    };
    var fileStreamHasher = /* @__PURE__ */ __name((hashCtor, fileStream) => new Promise((resolve13, reject) => {
      if (!isReadStream(fileStream)) {
        reject(new Error("Unable to calculate hash for non-file streams."));
        return;
      }
      const fileStreamTee = fs51.createReadStream(fileStream.path, {
        start: fileStream.start,
        end: fileStream.end
      });
      const hash = new hashCtor();
      const hashCalculator = new HashCalculator(hash);
      fileStreamTee.pipe(hashCalculator);
      fileStreamTee.on("error", (err) => {
        hashCalculator.end();
        reject(err);
      });
      hashCalculator.on("error", reject);
      hashCalculator.on("finish", function() {
        hash.digest().then(resolve13).catch(reject);
      });
    }), "fileStreamHasher");
    var isReadStream = /* @__PURE__ */ __name((stream2) => typeof stream2.path === "string", "isReadStream");
    var readableStreamHasher = /* @__PURE__ */ __name((hashCtor, readableStream) => {
      if (readableStream.readableFlowing !== null) {
        throw new Error("Unable to calculate hash for flowing readable stream");
      }
      const hash = new hashCtor();
      const hashCalculator = new HashCalculator(hash);
      readableStream.pipe(hashCalculator);
      return new Promise((resolve13, reject) => {
        readableStream.on("error", (err) => {
          hashCalculator.end();
          reject(err);
        });
        hashCalculator.on("error", reject);
        hashCalculator.on("finish", () => {
          hash.digest().then(resolve13).catch(reject);
        });
      });
    }, "readableStreamHasher");
    exports2.fileStreamHasher = fileStreamHasher;
    exports2.readableStreamHasher = readableStreamHasher;
  }
});

// ../../node_modules/@aws-sdk/client-s3/dist-cjs/runtimeConfig.shared.js
var require_runtimeConfig_shared2 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/dist-cjs/runtimeConfig.shared.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes4(), __toCommonJS(httpAuthSchemes_exports3));
    var middleware_sdk_s3_1 = require_dist_cjs54();
    var signature_v4_multi_region_1 = require_dist_cjs55();
    var smithy_client_1 = require_dist_cjs34();
    var url_parser_1 = require_dist_cjs18();
    var util_base64_1 = require_dist_cjs10();
    var util_stream_1 = require_dist_cjs73();
    var util_utf8_1 = require_dist_cjs9();
    var httpAuthSchemeProvider_1 = require_httpAuthSchemeProvider2();
    var endpointResolver_1 = require_endpointResolver2();
    var schemas_0_1 = require_schemas_02();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2006-03-01",
        base64Decoder: config2?.base64Decoder ?? util_base64_1.fromBase64,
        base64Encoder: config2?.base64Encoder ?? util_base64_1.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? endpointResolver_1.defaultEndpointResolver,
        extensions: config2?.extensions ?? [],
        getAwsChunkedEncodingStream: config2?.getAwsChunkedEncodingStream ?? util_stream_1.getAwsChunkedEncodingStream,
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? httpAuthSchemeProvider_1.defaultS3HttpAuthSchemeProvider,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new httpAuthSchemes_1.AwsSdkSigV4Signer()
          },
          {
            schemeId: "aws.auth#sigv4a",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4a"), "identityProvider"),
            signer: new httpAuthSchemes_1.AwsSdkSigV4ASigner()
          }
        ],
        logger: config2?.logger ?? new smithy_client_1.NoOpLogger(),
        protocol: config2?.protocol ?? middleware_sdk_s3_1.S3RestXmlProtocol,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.s3",
          errorTypeRegistries: schemas_0_1.errorTypeRegistries,
          xmlNamespace: "http://s3.amazonaws.com/doc/2006-03-01/",
          version: "2006-03-01",
          serviceTarget: "AmazonS3"
        },
        sdkStreamMixin: config2?.sdkStreamMixin ?? util_stream_1.sdkStreamMixin,
        serviceId: config2?.serviceId ?? "S3",
        signerConstructor: config2?.signerConstructor ?? signature_v4_multi_region_1.SignatureV4MultiRegion,
        signingEscapePath: config2?.signingEscapePath ?? false,
        urlParser: config2?.urlParser ?? url_parser_1.parseUrl,
        useArnRegion: config2?.useArnRegion ?? void 0,
        utf8Decoder: config2?.utf8Decoder ?? util_utf8_1.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? util_utf8_1.toUtf8
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-s3/dist-cjs/runtimeConfig.js
var require_runtimeConfig2 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/dist-cjs/runtimeConfig.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var package_json_1 = tslib_1.__importDefault(require_package2());
    var client_1 = (init_client6(), __toCommonJS(client_exports5));
    var httpAuthSchemes_1 = (init_httpAuthSchemes4(), __toCommonJS(httpAuthSchemes_exports3));
    var credential_provider_node_1 = require_dist_cjs81();
    var middleware_bucket_endpoint_1 = require_dist_cjs82();
    var middleware_flexible_checksums_1 = require_dist_cjs68();
    var middleware_sdk_s3_1 = require_dist_cjs54();
    var util_user_agent_node_1 = require_dist_cjs75();
    var config_resolver_1 = require_dist_cjs25();
    var eventstream_serde_node_1 = require_dist_cjs85();
    var hash_node_1 = require_dist_cjs44();
    var hash_stream_node_1 = require_dist_cjs86();
    var middleware_retry_1 = require_dist_cjs71();
    var node_config_provider_1 = require_dist_cjs29();
    var node_http_handler_1 = require_dist_cjs13();
    var smithy_client_1 = require_dist_cjs34();
    var util_body_length_node_1 = require_dist_cjs45();
    var util_defaults_mode_node_1 = require_dist_cjs46();
    var util_retry_1 = require_dist_cjs22();
    var runtimeConfig_shared_1 = require_runtimeConfig_shared2();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      (0, smithy_client_1.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, util_defaults_mode_node_1.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(smithy_client_1.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = (0, runtimeConfig_shared_1.getRuntimeConfig)(config2);
      (0, client_1.emitWarningIfUnsupportedVersion)(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, node_config_provider_1.loadConfig)(httpAuthSchemes_1.NODE_AUTH_SCHEME_PREFERENCE_OPTIONS, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? util_body_length_node_1.calculateBodyLength,
        credentialDefaultProvider: config2?.credentialDefaultProvider ?? credential_provider_node_1.defaultProvider,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, util_user_agent_node_1.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_json_1.default.version }),
        disableS3ExpressSessionAuth: config2?.disableS3ExpressSessionAuth ?? (0, node_config_provider_1.loadConfig)(middleware_sdk_s3_1.NODE_DISABLE_S3_EXPRESS_SESSION_AUTH_OPTIONS, loaderConfig),
        eventStreamSerdeProvider: config2?.eventStreamSerdeProvider ?? eventstream_serde_node_1.eventStreamSerdeProvider,
        maxAttempts: config2?.maxAttempts ?? (0, node_config_provider_1.loadConfig)(middleware_retry_1.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        md5: config2?.md5 ?? hash_node_1.Hash.bind(null, "md5"),
        region: config2?.region ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_REGION_CONFIG_OPTIONS, { ...config_resolver_1.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestChecksumCalculation: config2?.requestChecksumCalculation ?? (0, node_config_provider_1.loadConfig)(middleware_flexible_checksums_1.NODE_REQUEST_CHECKSUM_CALCULATION_CONFIG_OPTIONS, loaderConfig),
        requestHandler: node_http_handler_1.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        responseChecksumValidation: config2?.responseChecksumValidation ?? (0, node_config_provider_1.loadConfig)(middleware_flexible_checksums_1.NODE_RESPONSE_CHECKSUM_VALIDATION_CONFIG_OPTIONS, loaderConfig),
        retryMode: config2?.retryMode ?? (0, node_config_provider_1.loadConfig)({
          ...middleware_retry_1.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || util_retry_1.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha1: config2?.sha1 ?? hash_node_1.Hash.bind(null, "sha1"),
        sha256: config2?.sha256 ?? hash_node_1.Hash.bind(null, "sha256"),
        sigv4aSigningRegionSet: config2?.sigv4aSigningRegionSet ?? (0, node_config_provider_1.loadConfig)(httpAuthSchemes_1.NODE_SIGV4A_CONFIG_OPTIONS, loaderConfig),
        streamCollector: config2?.streamCollector ?? node_http_handler_1.streamCollector,
        streamHasher: config2?.streamHasher ?? hash_stream_node_1.readableStreamHasher,
        useArnRegion: config2?.useArnRegion ?? (0, node_config_provider_1.loadConfig)(middleware_bucket_endpoint_1.NODE_USE_ARN_REGION_CONFIG_OPTIONS, loaderConfig),
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, node_config_provider_1.loadConfig)(util_user_agent_node_1.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/middleware-ssec/dist-cjs/index.js
var require_dist_cjs87 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-ssec/dist-cjs/index.js"(exports2) {
    "use strict";
    function ssecMiddleware(options) {
      return (next) => async (args) => {
        const input = { ...args.input };
        const properties = [
          {
            target: "SSECustomerKey",
            hash: "SSECustomerKeyMD5"
          },
          {
            target: "CopySourceSSECustomerKey",
            hash: "CopySourceSSECustomerKeyMD5"
          }
        ];
        for (const prop of properties) {
          const value = input[prop.target];
          if (value) {
            let valueForHash;
            if (typeof value === "string") {
              if (isValidBase64EncodedSSECustomerKey(value, options)) {
                valueForHash = options.base64Decoder(value);
              } else {
                valueForHash = options.utf8Decoder(value);
                input[prop.target] = options.base64Encoder(valueForHash);
              }
            } else {
              valueForHash = ArrayBuffer.isView(value) ? new Uint8Array(value.buffer, value.byteOffset, value.byteLength) : new Uint8Array(value);
              input[prop.target] = options.base64Encoder(valueForHash);
            }
            const hash = new options.md5();
            hash.update(valueForHash);
            input[prop.hash] = options.base64Encoder(await hash.digest());
          }
        }
        return next({
          ...args,
          input
        });
      };
    }
    __name(ssecMiddleware, "ssecMiddleware");
    var ssecMiddlewareOptions = {
      name: "ssecMiddleware",
      step: "initialize",
      tags: ["SSE"],
      override: true
    };
    var getSsecPlugin = /* @__PURE__ */ __name((config2) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(ssecMiddleware(config2), ssecMiddlewareOptions);
      }, "applyToStack")
    }), "getSsecPlugin");
    function isValidBase64EncodedSSECustomerKey(str, options) {
      const base64Regex = /^(?:[A-Za-z0-9+/]{4})*([A-Za-z0-9+/]{2}==|[A-Za-z0-9+/]{3}=)?$/;
      if (!base64Regex.test(str))
        return false;
      try {
        const decodedBytes = options.base64Decoder(str);
        return decodedBytes.length === 32;
      } catch {
        return false;
      }
    }
    __name(isValidBase64EncodedSSECustomerKey, "isValidBase64EncodedSSECustomerKey");
    exports2.getSsecPlugin = getSsecPlugin;
    exports2.isValidBase64EncodedSSECustomerKey = isValidBase64EncodedSSECustomerKey;
    exports2.ssecMiddleware = ssecMiddleware;
    exports2.ssecMiddlewareOptions = ssecMiddlewareOptions;
  }
});

// ../../node_modules/@aws-sdk/middleware-location-constraint/dist-cjs/index.js
var require_dist_cjs88 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-location-constraint/dist-cjs/index.js"(exports2) {
    "use strict";
    function locationConstraintMiddleware(options) {
      return (next) => async (args) => {
        const { CreateBucketConfiguration } = args.input;
        const region = await options.region();
        if (!CreateBucketConfiguration?.LocationConstraint && !CreateBucketConfiguration?.Location) {
          if (region !== "us-east-1") {
            args.input.CreateBucketConfiguration = args.input.CreateBucketConfiguration ?? {};
            args.input.CreateBucketConfiguration.LocationConstraint = region;
          }
        }
        return next(args);
      };
    }
    __name(locationConstraintMiddleware, "locationConstraintMiddleware");
    var locationConstraintMiddlewareOptions = {
      step: "initialize",
      tags: ["LOCATION_CONSTRAINT", "CREATE_BUCKET_CONFIGURATION"],
      name: "locationConstraintMiddleware",
      override: true
    };
    var getLocationConstraintPlugin = /* @__PURE__ */ __name((config2) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(locationConstraintMiddleware(config2), locationConstraintMiddlewareOptions);
      }, "applyToStack")
    }), "getLocationConstraintPlugin");
    exports2.getLocationConstraintPlugin = getLocationConstraintPlugin;
    exports2.locationConstraintMiddleware = locationConstraintMiddleware;
    exports2.locationConstraintMiddlewareOptions = locationConstraintMiddlewareOptions;
  }
});

// ../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-waiter/dist-cjs/index.js
var require_dist_cjs89 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/node_modules/@smithy/util-waiter/dist-cjs/index.js"(exports2) {
    "use strict";
    var getCircularReplacer3 = /* @__PURE__ */ __name(() => {
      const seen = /* @__PURE__ */ new WeakSet();
      return (key, value) => {
        if (typeof value === "object" && value !== null) {
          if (seen.has(value)) {
            return "[Circular]";
          }
          seen.add(value);
        }
        return value;
      };
    }, "getCircularReplacer");
    var sleep4 = /* @__PURE__ */ __name((seconds) => {
      return new Promise((resolve13) => setTimeout(resolve13, seconds * 1e3));
    }, "sleep");
    var waiterServiceDefaults3 = {
      minDelay: 2,
      maxDelay: 120
    };
    exports2.WaiterState = void 0;
    (function(WaiterState3) {
      WaiterState3["ABORTED"] = "ABORTED";
      WaiterState3["FAILURE"] = "FAILURE";
      WaiterState3["SUCCESS"] = "SUCCESS";
      WaiterState3["RETRY"] = "RETRY";
      WaiterState3["TIMEOUT"] = "TIMEOUT";
    })(exports2.WaiterState || (exports2.WaiterState = {}));
    var checkExceptions3 = /* @__PURE__ */ __name((result2) => {
      if (result2.state === exports2.WaiterState.ABORTED) {
        const abortError = new Error(`${JSON.stringify({
          ...result2,
          reason: "Request was aborted"
        }, getCircularReplacer3())}`);
        abortError.name = "AbortError";
        throw abortError;
      } else if (result2.state === exports2.WaiterState.TIMEOUT) {
        const timeoutError = new Error(`${JSON.stringify({
          ...result2,
          reason: "Waiter has timed out"
        }, getCircularReplacer3())}`);
        timeoutError.name = "TimeoutError";
        throw timeoutError;
      } else if (result2.state !== exports2.WaiterState.SUCCESS) {
        throw new Error(`${JSON.stringify(result2, getCircularReplacer3())}`);
      }
      return result2;
    }, "checkExceptions");
    var runPolling3 = /* @__PURE__ */ __name(async ({ minDelay, maxDelay, maxWaitTime, abortController, client, abortSignal }, input, acceptorChecks) => {
      const observedResponses = {};
      const [minDelayMs, maxDelayMs] = [minDelay * 1e3, maxDelay * 1e3];
      let currentAttempt = 0;
      const waitUntil = Date.now() + maxWaitTime * 1e3;
      const warn403Time = Date.now() + 6e4;
      let didWarn403 = false;
      while (true) {
        if (currentAttempt > 0) {
          const delayMs = exponentialBackoffWithJitter3(minDelayMs, maxDelayMs, currentAttempt, waitUntil);
          if (abortController?.signal?.aborted || abortSignal?.aborted) {
            const message2 = "AbortController signal aborted.";
            observedResponses[message2] |= 0;
            observedResponses[message2] += 1;
            return { state: exports2.WaiterState.ABORTED, observedResponses };
          }
          if (Date.now() + delayMs > waitUntil) {
            return { state: exports2.WaiterState.TIMEOUT, observedResponses };
          }
          await sleep4(delayMs / 1e3);
        }
        const { state: state13, reason } = await acceptorChecks(client, input);
        if (reason) {
          const message2 = createMessageFromResponse3(reason);
          observedResponses[message2] |= 0;
          observedResponses[message2] += 1;
        }
        if (state13 !== exports2.WaiterState.RETRY) {
          return { state: state13, reason, final: reason, observedResponses };
        }
        currentAttempt += 1;
        if (!didWarn403 && Date.now() >= warn403Time) {
          checkWarn4033(observedResponses, client);
          didWarn403 = true;
        }
      }
    }, "runPolling");
    var checkWarn4033 = /* @__PURE__ */ __name((observedResponses = {}, client) => {
      const orderedErrors = Object.keys(observedResponses);
      let count403 = 0;
      for (const response of orderedErrors) {
        const n10 = observedResponses[response] | 0;
        if (response.startsWith("403:")) {
          count403 += n10;
        }
      }
      const clientLogger = client?.config?.logger;
      const warningLogger = typeof clientLogger?.warn === "function" && !clientLogger.constructor?.name?.includes?.("NoOpLogger") ? clientLogger : console;
      if (count403 >= 3 || orderedErrors[orderedErrors.length - 1].startsWith("403:")) {
        warningLogger.warn(`@smithy/util-waiter WARN - 403 status code encountered during waiter polling.`);
      }
    }, "checkWarn403");
    var createMessageFromResponse3 = /* @__PURE__ */ __name((reason) => {
      const status = reason?.$response?.statusCode ?? reason?.$metadata?.httpStatusCode;
      if (reason?.$responseBodyText) {
        return `${status ? status + ": " : ""}Deserialization error for body: ${reason.$responseBodyText}`;
      }
      if (status) {
        if (reason?.$response || reason?.message) {
          return `${status ?? "Unknown"}: ${reason?.message}`;
        }
        return `${status}: OK`;
      }
      return String(reason?.message ?? JSON.stringify(reason, getCircularReplacer3()) ?? "Unknown");
    }, "createMessageFromResponse");
    var exponentialBackoffWithJitter3 = /* @__PURE__ */ __name((minDelayMs, maxDelayMs, attempt, waitUntil) => {
      const attemptCountCeiling = Math.log(maxDelayMs / minDelayMs) / Math.log(2) + 1;
      if (attempt > attemptCountCeiling) {
        return maxDelayMs;
      }
      const delay = minDelayMs * 2 ** (attempt - 1);
      const capped = Math.min(delay, maxDelayMs);
      const waitFor2 = randomInRange3(minDelayMs, capped);
      if (Date.now() + waitFor2 > waitUntil) {
        const timeRemaining = waitUntil - Date.now();
        return Math.max(0, timeRemaining - 500);
      }
      return waitFor2;
    }, "exponentialBackoffWithJitter");
    var randomInRange3 = /* @__PURE__ */ __name((min, max) => min + Math.random() * (max - min), "randomInRange");
    var validateWaiterOptions3 = /* @__PURE__ */ __name((options) => {
      if (options.maxWaitTime <= 0) {
        throw new Error(`WaiterConfiguration.maxWaitTime must be greater than 0`);
      } else if (options.minDelay <= 0) {
        throw new Error(`WaiterConfiguration.minDelay must be greater than 0`);
      } else if (options.maxDelay <= 0) {
        throw new Error(`WaiterConfiguration.maxDelay must be greater than 0`);
      } else if (options.maxWaitTime <= options.minDelay) {
        throw new Error(`WaiterConfiguration.maxWaitTime [${options.maxWaitTime}] must be greater than WaiterConfiguration.minDelay [${options.minDelay}] for this waiter`);
      } else if (options.maxDelay < options.minDelay) {
        throw new Error(`WaiterConfiguration.maxDelay [${options.maxDelay}] must be greater than WaiterConfiguration.minDelay [${options.minDelay}] for this waiter`);
      }
    }, "validateWaiterOptions");
    var abortTimeout3 = /* @__PURE__ */ __name((abortSignal) => {
      let onAbort;
      const promise = new Promise((resolve13) => {
        onAbort = /* @__PURE__ */ __name(() => resolve13({ state: exports2.WaiterState.ABORTED }), "onAbort");
        if (typeof abortSignal.addEventListener === "function") {
          abortSignal.addEventListener("abort", onAbort);
        } else {
          abortSignal.onabort = onAbort;
        }
      });
      return {
        clearListener() {
          if (typeof abortSignal.removeEventListener === "function") {
            abortSignal.removeEventListener("abort", onAbort);
          }
        },
        aborted: promise
      };
    }, "abortTimeout");
    var createWaiter3 = /* @__PURE__ */ __name(async (options, input, acceptorChecks) => {
      const params = {
        ...waiterServiceDefaults3,
        ...options
      };
      validateWaiterOptions3(params);
      const exitConditions = [runPolling3(params, input, acceptorChecks)];
      const finalize = [];
      if (options.abortSignal) {
        const { aborted, clearListener } = abortTimeout3(options.abortSignal);
        finalize.push(clearListener);
        exitConditions.push(aborted);
      }
      if (options.abortController?.signal) {
        const { aborted, clearListener } = abortTimeout3(options.abortController.signal);
        finalize.push(clearListener);
        exitConditions.push(aborted);
      }
      return Promise.race(exitConditions).then((result2) => {
        for (const fn of finalize) {
          fn();
        }
        return result2;
      });
    }, "createWaiter");
    exports2.checkExceptions = checkExceptions3;
    exports2.createWaiter = createWaiter3;
    exports2.waiterServiceDefaults = waiterServiceDefaults3;
  }
});

// ../../node_modules/@aws-sdk/client-s3/dist-cjs/index.js
var require_dist_cjs90 = __commonJS({
  "../../node_modules/@aws-sdk/client-s3/dist-cjs/index.js"(exports2) {
    "use strict";
    var middlewareExpectContinue = require_dist_cjs62();
    var middlewareFlexibleChecksums = require_dist_cjs68();
    var middlewareHostHeader = require_dist_cjs3();
    var middlewareLogger = require_dist_cjs4();
    var middlewareRecursionDetection = require_dist_cjs5();
    var middlewareSdkS3 = require_dist_cjs54();
    var middlewareUserAgent = require_dist_cjs69();
    var configResolver = require_dist_cjs25();
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var schema = (init_schema4(), __toCommonJS(schema_exports));
    var eventstreamSerdeConfigResolver = require_dist_cjs70();
    var middlewareContentLength = require_dist_cjs26();
    var middlewareEndpoint = require_dist_cjs31();
    var middlewareRetry = require_dist_cjs71();
    var smithyClient = require_dist_cjs34();
    var httpAuthSchemeProvider = require_httpAuthSchemeProvider2();
    var schemas_0 = require_schemas_02();
    var runtimeConfig = require_runtimeConfig2();
    var regionConfigResolver = require_dist_cjs48();
    var protocolHttp = require_dist_cjs2();
    var middlewareSsec = require_dist_cjs87();
    var middlewareLocationConstraint = require_dist_cjs88();
    var utilWaiter = require_dist_cjs89();
    var errors = require_errors2();
    var S3ServiceException = require_S3ServiceException();
    var resolveClientEndpointParameters32 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        forcePathStyle: options.forcePathStyle ?? false,
        useAccelerateEndpoint: options.useAccelerateEndpoint ?? false,
        useGlobalEndpoint: options.useGlobalEndpoint ?? false,
        disableMultiregionAccessPoints: options.disableMultiregionAccessPoints ?? false,
        defaultSigningName: "s3",
        clientContextParams: options.clientContextParams ?? {}
      });
    }, "resolveClientEndpointParameters");
    var commonParams32 = {
      ForcePathStyle: { type: "clientContextParams", name: "forcePathStyle" },
      UseArnRegion: { type: "clientContextParams", name: "useArnRegion" },
      DisableMultiRegionAccessPoints: { type: "clientContextParams", name: "disableMultiregionAccessPoints" },
      Accelerate: { type: "clientContextParams", name: "useAccelerateEndpoint" },
      DisableS3ExpressSessionAuth: { type: "clientContextParams", name: "disableS3ExpressSessionAuth" },
      UseGlobalEndpoint: { type: "builtInParams", name: "useGlobalEndpoint" },
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
    var CreateSessionCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      DisableS3ExpressSessionAuth: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "CreateSession", {}).n("S3Client", "CreateSessionCommand").sc(schemas_0.CreateSession$).build() {
      static {
        __name(this, "CreateSessionCommand");
      }
    };
    var getHttpAuthExtensionConfiguration32 = /* @__PURE__ */ __name((runtimeConfig2) => {
      const _httpAuthSchemes = runtimeConfig2.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig2.httpAuthSchemeProvider;
      let _credentials = runtimeConfig2.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider2) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider2;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    var resolveHttpAuthRuntimeConfig32 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
    var resolveRuntimeExtensions32 = /* @__PURE__ */ __name((runtimeConfig2, extensions) => {
      const extensionConfiguration = Object.assign(regionConfigResolver.getAwsRegionExtensionConfiguration(runtimeConfig2), smithyClient.getDefaultExtensionConfiguration(runtimeConfig2), protocolHttp.getHttpHandlerExtensionConfiguration(runtimeConfig2), getHttpAuthExtensionConfiguration32(runtimeConfig2));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig2, regionConfigResolver.resolveAwsRegionExtensionConfiguration(extensionConfiguration), smithyClient.resolveDefaultRuntimeConfig(extensionConfiguration), protocolHttp.resolveHttpHandlerRuntimeConfig(extensionConfiguration), resolveHttpAuthRuntimeConfig32(extensionConfiguration));
    }, "resolveRuntimeExtensions");
    var S3Client4 = class extends smithyClient.Client {
      static {
        __name(this, "S3Client");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = runtimeConfig.getRuntimeConfig(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters32(_config_0);
        const _config_2 = middlewareUserAgent.resolveUserAgentConfig(_config_1);
        const _config_3 = middlewareFlexibleChecksums.resolveFlexibleChecksumsConfig(_config_2);
        const _config_4 = middlewareRetry.resolveRetryConfig(_config_3);
        const _config_5 = configResolver.resolveRegionConfig(_config_4);
        const _config_6 = middlewareHostHeader.resolveHostHeaderConfig(_config_5);
        const _config_7 = middlewareEndpoint.resolveEndpointConfig(_config_6);
        const _config_8 = eventstreamSerdeConfigResolver.resolveEventStreamSerdeConfig(_config_7);
        const _config_9 = httpAuthSchemeProvider.resolveHttpAuthSchemeConfig(_config_8);
        const _config_10 = middlewareSdkS3.resolveS3Config(_config_9, { session: [() => this, CreateSessionCommand] });
        const _config_11 = resolveRuntimeExtensions32(_config_10, configuration?.extensions || []);
        this.config = _config_11;
        this.middlewareStack.use(schema.getSchemaSerdePlugin(this.config));
        this.middlewareStack.use(middlewareUserAgent.getUserAgentPlugin(this.config));
        this.middlewareStack.use(middlewareRetry.getRetryPlugin(this.config));
        this.middlewareStack.use(middlewareContentLength.getContentLengthPlugin(this.config));
        this.middlewareStack.use(middlewareHostHeader.getHostHeaderPlugin(this.config));
        this.middlewareStack.use(middlewareLogger.getLoggerPlugin(this.config));
        this.middlewareStack.use(middlewareRecursionDetection.getRecursionDetectionPlugin(this.config));
        this.middlewareStack.use(core.getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: httpAuthSchemeProvider.defaultS3HttpAuthSchemeParametersProvider,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new core.DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials,
            "aws.auth#sigv4a": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(core.getHttpSigningPlugin(this.config));
        this.middlewareStack.use(middlewareSdkS3.getValidateBucketNamePlugin(this.config));
        this.middlewareStack.use(middlewareExpectContinue.getAddExpectContinuePlugin(this.config));
        this.middlewareStack.use(middlewareSdkS3.getRegionRedirectMiddlewarePlugin(this.config));
        this.middlewareStack.use(middlewareSdkS3.getS3ExpressPlugin(this.config));
        this.middlewareStack.use(middlewareSdkS3.getS3ExpressHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
    var AbortMultipartUploadCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" },
      Key: { type: "contextParams", name: "Key" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "AbortMultipartUpload", {}).n("S3Client", "AbortMultipartUploadCommand").sc(schemas_0.AbortMultipartUpload$).build() {
      static {
        __name(this, "AbortMultipartUploadCommand");
      }
    };
    var CompleteMultipartUploadCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" },
      Key: { type: "contextParams", name: "Key" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2),
        middlewareSsec.getSsecPlugin(config2)
      ];
    }).s("AmazonS3", "CompleteMultipartUpload", {}).n("S3Client", "CompleteMultipartUploadCommand").sc(schemas_0.CompleteMultipartUpload$).build() {
      static {
        __name(this, "CompleteMultipartUploadCommand");
      }
    };
    var CopyObjectCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      DisableS3ExpressSessionAuth: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" },
      Key: { type: "contextParams", name: "Key" },
      CopySource: { type: "contextParams", name: "CopySource" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2),
        middlewareSsec.getSsecPlugin(config2)
      ];
    }).s("AmazonS3", "CopyObject", {}).n("S3Client", "CopyObjectCommand").sc(schemas_0.CopyObject$).build() {
      static {
        __name(this, "CopyObjectCommand");
      }
    };
    var CreateBucketCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      DisableAccessPoints: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2),
        middlewareLocationConstraint.getLocationConstraintPlugin(config2)
      ];
    }).s("AmazonS3", "CreateBucket", {}).n("S3Client", "CreateBucketCommand").sc(schemas_0.CreateBucket$).build() {
      static {
        __name(this, "CreateBucketCommand");
      }
    };
    var CreateBucketMetadataConfigurationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: true
        })
      ];
    }).s("AmazonS3", "CreateBucketMetadataConfiguration", {}).n("S3Client", "CreateBucketMetadataConfigurationCommand").sc(schemas_0.CreateBucketMetadataConfiguration$).build() {
      static {
        __name(this, "CreateBucketMetadataConfigurationCommand");
      }
    };
    var CreateBucketMetadataTableConfigurationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: true
        })
      ];
    }).s("AmazonS3", "CreateBucketMetadataTableConfiguration", {}).n("S3Client", "CreateBucketMetadataTableConfigurationCommand").sc(schemas_0.CreateBucketMetadataTableConfiguration$).build() {
      static {
        __name(this, "CreateBucketMetadataTableConfigurationCommand");
      }
    };
    var CreateMultipartUploadCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" },
      Key: { type: "contextParams", name: "Key" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2),
        middlewareSsec.getSsecPlugin(config2)
      ];
    }).s("AmazonS3", "CreateMultipartUpload", {}).n("S3Client", "CreateMultipartUploadCommand").sc(schemas_0.CreateMultipartUpload$).build() {
      static {
        __name(this, "CreateMultipartUploadCommand");
      }
    };
    var DeleteBucketAnalyticsConfigurationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonS3", "DeleteBucketAnalyticsConfiguration", {}).n("S3Client", "DeleteBucketAnalyticsConfigurationCommand").sc(schemas_0.DeleteBucketAnalyticsConfiguration$).build() {
      static {
        __name(this, "DeleteBucketAnalyticsConfigurationCommand");
      }
    };
    var DeleteBucketCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonS3", "DeleteBucket", {}).n("S3Client", "DeleteBucketCommand").sc(schemas_0.DeleteBucket$).build() {
      static {
        __name(this, "DeleteBucketCommand");
      }
    };
    var DeleteBucketCorsCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonS3", "DeleteBucketCors", {}).n("S3Client", "DeleteBucketCorsCommand").sc(schemas_0.DeleteBucketCors$).build() {
      static {
        __name(this, "DeleteBucketCorsCommand");
      }
    };
    var DeleteBucketEncryptionCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonS3", "DeleteBucketEncryption", {}).n("S3Client", "DeleteBucketEncryptionCommand").sc(schemas_0.DeleteBucketEncryption$).build() {
      static {
        __name(this, "DeleteBucketEncryptionCommand");
      }
    };
    var DeleteBucketIntelligentTieringConfigurationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonS3", "DeleteBucketIntelligentTieringConfiguration", {}).n("S3Client", "DeleteBucketIntelligentTieringConfigurationCommand").sc(schemas_0.DeleteBucketIntelligentTieringConfiguration$).build() {
      static {
        __name(this, "DeleteBucketIntelligentTieringConfigurationCommand");
      }
    };
    var DeleteBucketInventoryConfigurationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonS3", "DeleteBucketInventoryConfiguration", {}).n("S3Client", "DeleteBucketInventoryConfigurationCommand").sc(schemas_0.DeleteBucketInventoryConfiguration$).build() {
      static {
        __name(this, "DeleteBucketInventoryConfigurationCommand");
      }
    };
    var DeleteBucketLifecycleCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonS3", "DeleteBucketLifecycle", {}).n("S3Client", "DeleteBucketLifecycleCommand").sc(schemas_0.DeleteBucketLifecycle$).build() {
      static {
        __name(this, "DeleteBucketLifecycleCommand");
      }
    };
    var DeleteBucketMetadataConfigurationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonS3", "DeleteBucketMetadataConfiguration", {}).n("S3Client", "DeleteBucketMetadataConfigurationCommand").sc(schemas_0.DeleteBucketMetadataConfiguration$).build() {
      static {
        __name(this, "DeleteBucketMetadataConfigurationCommand");
      }
    };
    var DeleteBucketMetadataTableConfigurationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonS3", "DeleteBucketMetadataTableConfiguration", {}).n("S3Client", "DeleteBucketMetadataTableConfigurationCommand").sc(schemas_0.DeleteBucketMetadataTableConfiguration$).build() {
      static {
        __name(this, "DeleteBucketMetadataTableConfigurationCommand");
      }
    };
    var DeleteBucketMetricsConfigurationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonS3", "DeleteBucketMetricsConfiguration", {}).n("S3Client", "DeleteBucketMetricsConfigurationCommand").sc(schemas_0.DeleteBucketMetricsConfiguration$).build() {
      static {
        __name(this, "DeleteBucketMetricsConfigurationCommand");
      }
    };
    var DeleteBucketOwnershipControlsCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonS3", "DeleteBucketOwnershipControls", {}).n("S3Client", "DeleteBucketOwnershipControlsCommand").sc(schemas_0.DeleteBucketOwnershipControls$).build() {
      static {
        __name(this, "DeleteBucketOwnershipControlsCommand");
      }
    };
    var DeleteBucketPolicyCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonS3", "DeleteBucketPolicy", {}).n("S3Client", "DeleteBucketPolicyCommand").sc(schemas_0.DeleteBucketPolicy$).build() {
      static {
        __name(this, "DeleteBucketPolicyCommand");
      }
    };
    var DeleteBucketReplicationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonS3", "DeleteBucketReplication", {}).n("S3Client", "DeleteBucketReplicationCommand").sc(schemas_0.DeleteBucketReplication$).build() {
      static {
        __name(this, "DeleteBucketReplicationCommand");
      }
    };
    var DeleteBucketTaggingCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonS3", "DeleteBucketTagging", {}).n("S3Client", "DeleteBucketTaggingCommand").sc(schemas_0.DeleteBucketTagging$).build() {
      static {
        __name(this, "DeleteBucketTaggingCommand");
      }
    };
    var DeleteBucketWebsiteCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonS3", "DeleteBucketWebsite", {}).n("S3Client", "DeleteBucketWebsiteCommand").sc(schemas_0.DeleteBucketWebsite$).build() {
      static {
        __name(this, "DeleteBucketWebsiteCommand");
      }
    };
    var DeleteObjectCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" },
      Key: { type: "contextParams", name: "Key" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "DeleteObject", {}).n("S3Client", "DeleteObjectCommand").sc(schemas_0.DeleteObject$).build() {
      static {
        __name(this, "DeleteObjectCommand");
      }
    };
    var DeleteObjectsCommand2 = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: true
        }),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "DeleteObjects", {}).n("S3Client", "DeleteObjectsCommand").sc(schemas_0.DeleteObjects$).build() {
      static {
        __name(this, "DeleteObjectsCommand");
      }
    };
    var DeleteObjectTaggingCommand2 = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "DeleteObjectTagging", {}).n("S3Client", "DeleteObjectTaggingCommand").sc(schemas_0.DeleteObjectTagging$).build() {
      static {
        __name(this, "DeleteObjectTaggingCommand");
      }
    };
    var DeletePublicAccessBlockCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonS3", "DeletePublicAccessBlock", {}).n("S3Client", "DeletePublicAccessBlockCommand").sc(schemas_0.DeletePublicAccessBlock$).build() {
      static {
        __name(this, "DeletePublicAccessBlockCommand");
      }
    };
    var GetBucketAbacCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "GetBucketAbac", {}).n("S3Client", "GetBucketAbacCommand").sc(schemas_0.GetBucketAbac$).build() {
      static {
        __name(this, "GetBucketAbacCommand");
      }
    };
    var GetBucketAccelerateConfigurationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "GetBucketAccelerateConfiguration", {}).n("S3Client", "GetBucketAccelerateConfigurationCommand").sc(schemas_0.GetBucketAccelerateConfiguration$).build() {
      static {
        __name(this, "GetBucketAccelerateConfigurationCommand");
      }
    };
    var GetBucketAclCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "GetBucketAcl", {}).n("S3Client", "GetBucketAclCommand").sc(schemas_0.GetBucketAcl$).build() {
      static {
        __name(this, "GetBucketAclCommand");
      }
    };
    var GetBucketAnalyticsConfigurationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "GetBucketAnalyticsConfiguration", {}).n("S3Client", "GetBucketAnalyticsConfigurationCommand").sc(schemas_0.GetBucketAnalyticsConfiguration$).build() {
      static {
        __name(this, "GetBucketAnalyticsConfigurationCommand");
      }
    };
    var GetBucketCorsCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "GetBucketCors", {}).n("S3Client", "GetBucketCorsCommand").sc(schemas_0.GetBucketCors$).build() {
      static {
        __name(this, "GetBucketCorsCommand");
      }
    };
    var GetBucketEncryptionCommand3 = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "GetBucketEncryption", {}).n("S3Client", "GetBucketEncryptionCommand").sc(schemas_0.GetBucketEncryption$).build() {
      static {
        __name(this, "GetBucketEncryptionCommand");
      }
    };
    var GetBucketIntelligentTieringConfigurationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "GetBucketIntelligentTieringConfiguration", {}).n("S3Client", "GetBucketIntelligentTieringConfigurationCommand").sc(schemas_0.GetBucketIntelligentTieringConfiguration$).build() {
      static {
        __name(this, "GetBucketIntelligentTieringConfigurationCommand");
      }
    };
    var GetBucketInventoryConfigurationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "GetBucketInventoryConfiguration", {}).n("S3Client", "GetBucketInventoryConfigurationCommand").sc(schemas_0.GetBucketInventoryConfiguration$).build() {
      static {
        __name(this, "GetBucketInventoryConfigurationCommand");
      }
    };
    var GetBucketLifecycleConfigurationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "GetBucketLifecycleConfiguration", {}).n("S3Client", "GetBucketLifecycleConfigurationCommand").sc(schemas_0.GetBucketLifecycleConfiguration$).build() {
      static {
        __name(this, "GetBucketLifecycleConfigurationCommand");
      }
    };
    var GetBucketLocationCommand3 = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "GetBucketLocation", {}).n("S3Client", "GetBucketLocationCommand").sc(schemas_0.GetBucketLocation$).build() {
      static {
        __name(this, "GetBucketLocationCommand");
      }
    };
    var GetBucketLoggingCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "GetBucketLogging", {}).n("S3Client", "GetBucketLoggingCommand").sc(schemas_0.GetBucketLogging$).build() {
      static {
        __name(this, "GetBucketLoggingCommand");
      }
    };
    var GetBucketMetadataConfigurationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "GetBucketMetadataConfiguration", {}).n("S3Client", "GetBucketMetadataConfigurationCommand").sc(schemas_0.GetBucketMetadataConfiguration$).build() {
      static {
        __name(this, "GetBucketMetadataConfigurationCommand");
      }
    };
    var GetBucketMetadataTableConfigurationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "GetBucketMetadataTableConfiguration", {}).n("S3Client", "GetBucketMetadataTableConfigurationCommand").sc(schemas_0.GetBucketMetadataTableConfiguration$).build() {
      static {
        __name(this, "GetBucketMetadataTableConfigurationCommand");
      }
    };
    var GetBucketMetricsConfigurationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "GetBucketMetricsConfiguration", {}).n("S3Client", "GetBucketMetricsConfigurationCommand").sc(schemas_0.GetBucketMetricsConfiguration$).build() {
      static {
        __name(this, "GetBucketMetricsConfigurationCommand");
      }
    };
    var GetBucketNotificationConfigurationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "GetBucketNotificationConfiguration", {}).n("S3Client", "GetBucketNotificationConfigurationCommand").sc(schemas_0.GetBucketNotificationConfiguration$).build() {
      static {
        __name(this, "GetBucketNotificationConfigurationCommand");
      }
    };
    var GetBucketOwnershipControlsCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "GetBucketOwnershipControls", {}).n("S3Client", "GetBucketOwnershipControlsCommand").sc(schemas_0.GetBucketOwnershipControls$).build() {
      static {
        __name(this, "GetBucketOwnershipControlsCommand");
      }
    };
    var GetBucketPolicyCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonS3", "GetBucketPolicy", {}).n("S3Client", "GetBucketPolicyCommand").sc(schemas_0.GetBucketPolicy$).build() {
      static {
        __name(this, "GetBucketPolicyCommand");
      }
    };
    var GetBucketPolicyStatusCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "GetBucketPolicyStatus", {}).n("S3Client", "GetBucketPolicyStatusCommand").sc(schemas_0.GetBucketPolicyStatus$).build() {
      static {
        __name(this, "GetBucketPolicyStatusCommand");
      }
    };
    var GetBucketReplicationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "GetBucketReplication", {}).n("S3Client", "GetBucketReplicationCommand").sc(schemas_0.GetBucketReplication$).build() {
      static {
        __name(this, "GetBucketReplicationCommand");
      }
    };
    var GetBucketRequestPaymentCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "GetBucketRequestPayment", {}).n("S3Client", "GetBucketRequestPaymentCommand").sc(schemas_0.GetBucketRequestPayment$).build() {
      static {
        __name(this, "GetBucketRequestPaymentCommand");
      }
    };
    var GetBucketTaggingCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "GetBucketTagging", {}).n("S3Client", "GetBucketTaggingCommand").sc(schemas_0.GetBucketTagging$).build() {
      static {
        __name(this, "GetBucketTaggingCommand");
      }
    };
    var GetBucketVersioningCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "GetBucketVersioning", {}).n("S3Client", "GetBucketVersioningCommand").sc(schemas_0.GetBucketVersioning$).build() {
      static {
        __name(this, "GetBucketVersioningCommand");
      }
    };
    var GetBucketWebsiteCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "GetBucketWebsite", {}).n("S3Client", "GetBucketWebsiteCommand").sc(schemas_0.GetBucketWebsite$).build() {
      static {
        __name(this, "GetBucketWebsiteCommand");
      }
    };
    var GetObjectAclCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" },
      Key: { type: "contextParams", name: "Key" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "GetObjectAcl", {}).n("S3Client", "GetObjectAclCommand").sc(schemas_0.GetObjectAcl$).build() {
      static {
        __name(this, "GetObjectAclCommand");
      }
    };
    var GetObjectAttributesCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2),
        middlewareSsec.getSsecPlugin(config2)
      ];
    }).s("AmazonS3", "GetObjectAttributes", {}).n("S3Client", "GetObjectAttributesCommand").sc(schemas_0.GetObjectAttributes$).build() {
      static {
        __name(this, "GetObjectAttributesCommand");
      }
    };
    var GetObjectCommand2 = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" },
      Key: { type: "contextParams", name: "Key" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestChecksumRequired: false,
          requestValidationModeMember: "ChecksumMode",
          "responseAlgorithms": ["CRC64NVME", "CRC32", "CRC32C", "SHA256", "SHA1", "SHA512", "MD5", "XXHASH64", "XXHASH3", "XXHASH128"]
        }),
        middlewareSsec.getSsecPlugin(config2),
        middlewareSdkS3.getS3ExpiresMiddlewarePlugin(config2)
      ];
    }).s("AmazonS3", "GetObject", {}).n("S3Client", "GetObjectCommand").sc(schemas_0.GetObject$).build() {
      static {
        __name(this, "GetObjectCommand");
      }
    };
    var GetObjectLegalHoldCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "GetObjectLegalHold", {}).n("S3Client", "GetObjectLegalHoldCommand").sc(schemas_0.GetObjectLegalHold$).build() {
      static {
        __name(this, "GetObjectLegalHoldCommand");
      }
    };
    var GetObjectLockConfigurationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "GetObjectLockConfiguration", {}).n("S3Client", "GetObjectLockConfigurationCommand").sc(schemas_0.GetObjectLockConfiguration$).build() {
      static {
        __name(this, "GetObjectLockConfigurationCommand");
      }
    };
    var GetObjectRetentionCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "GetObjectRetention", {}).n("S3Client", "GetObjectRetentionCommand").sc(schemas_0.GetObjectRetention$).build() {
      static {
        __name(this, "GetObjectRetentionCommand");
      }
    };
    var GetObjectTaggingCommand2 = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "GetObjectTagging", {}).n("S3Client", "GetObjectTaggingCommand").sc(schemas_0.GetObjectTagging$).build() {
      static {
        __name(this, "GetObjectTaggingCommand");
      }
    };
    var GetObjectTorrentCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonS3", "GetObjectTorrent", {}).n("S3Client", "GetObjectTorrentCommand").sc(schemas_0.GetObjectTorrent$).build() {
      static {
        __name(this, "GetObjectTorrentCommand");
      }
    };
    var GetPublicAccessBlockCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "GetPublicAccessBlock", {}).n("S3Client", "GetPublicAccessBlockCommand").sc(schemas_0.GetPublicAccessBlock$).build() {
      static {
        __name(this, "GetPublicAccessBlockCommand");
      }
    };
    var HeadBucketCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "HeadBucket", {}).n("S3Client", "HeadBucketCommand").sc(schemas_0.HeadBucket$).build() {
      static {
        __name(this, "HeadBucketCommand");
      }
    };
    var HeadObjectCommand2 = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" },
      Key: { type: "contextParams", name: "Key" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2),
        middlewareSsec.getSsecPlugin(config2),
        middlewareSdkS3.getS3ExpiresMiddlewarePlugin(config2)
      ];
    }).s("AmazonS3", "HeadObject", {}).n("S3Client", "HeadObjectCommand").sc(schemas_0.HeadObject$).build() {
      static {
        __name(this, "HeadObjectCommand");
      }
    };
    var ListBucketAnalyticsConfigurationsCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "ListBucketAnalyticsConfigurations", {}).n("S3Client", "ListBucketAnalyticsConfigurationsCommand").sc(schemas_0.ListBucketAnalyticsConfigurations$).build() {
      static {
        __name(this, "ListBucketAnalyticsConfigurationsCommand");
      }
    };
    var ListBucketIntelligentTieringConfigurationsCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "ListBucketIntelligentTieringConfigurations", {}).n("S3Client", "ListBucketIntelligentTieringConfigurationsCommand").sc(schemas_0.ListBucketIntelligentTieringConfigurations$).build() {
      static {
        __name(this, "ListBucketIntelligentTieringConfigurationsCommand");
      }
    };
    var ListBucketInventoryConfigurationsCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "ListBucketInventoryConfigurations", {}).n("S3Client", "ListBucketInventoryConfigurationsCommand").sc(schemas_0.ListBucketInventoryConfigurations$).build() {
      static {
        __name(this, "ListBucketInventoryConfigurationsCommand");
      }
    };
    var ListBucketMetricsConfigurationsCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "ListBucketMetricsConfigurations", {}).n("S3Client", "ListBucketMetricsConfigurationsCommand").sc(schemas_0.ListBucketMetricsConfigurations$).build() {
      static {
        __name(this, "ListBucketMetricsConfigurationsCommand");
      }
    };
    var ListBucketsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "ListBuckets", {}).n("S3Client", "ListBucketsCommand").sc(schemas_0.ListBuckets$).build() {
      static {
        __name(this, "ListBucketsCommand");
      }
    };
    var ListDirectoryBucketsCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "ListDirectoryBuckets", {}).n("S3Client", "ListDirectoryBucketsCommand").sc(schemas_0.ListDirectoryBuckets$).build() {
      static {
        __name(this, "ListDirectoryBucketsCommand");
      }
    };
    var ListMultipartUploadsCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" },
      Prefix: { type: "contextParams", name: "Prefix" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "ListMultipartUploads", {}).n("S3Client", "ListMultipartUploadsCommand").sc(schemas_0.ListMultipartUploads$).build() {
      static {
        __name(this, "ListMultipartUploadsCommand");
      }
    };
    var ListObjectsCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" },
      Prefix: { type: "contextParams", name: "Prefix" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "ListObjects", {}).n("S3Client", "ListObjectsCommand").sc(schemas_0.ListObjects$).build() {
      static {
        __name(this, "ListObjectsCommand");
      }
    };
    var ListObjectsV2Command3 = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" },
      Prefix: { type: "contextParams", name: "Prefix" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "ListObjectsV2", {}).n("S3Client", "ListObjectsV2Command").sc(schemas_0.ListObjectsV2$).build() {
      static {
        __name(this, "ListObjectsV2Command");
      }
    };
    var ListObjectVersionsCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" },
      Prefix: { type: "contextParams", name: "Prefix" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "ListObjectVersions", {}).n("S3Client", "ListObjectVersionsCommand").sc(schemas_0.ListObjectVersions$).build() {
      static {
        __name(this, "ListObjectVersionsCommand");
      }
    };
    var ListPartsCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" },
      Key: { type: "contextParams", name: "Key" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2),
        middlewareSsec.getSsecPlugin(config2)
      ];
    }).s("AmazonS3", "ListParts", {}).n("S3Client", "ListPartsCommand").sc(schemas_0.ListParts$).build() {
      static {
        __name(this, "ListPartsCommand");
      }
    };
    var PutBucketAbacCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: false
        })
      ];
    }).s("AmazonS3", "PutBucketAbac", {}).n("S3Client", "PutBucketAbacCommand").sc(schemas_0.PutBucketAbac$).build() {
      static {
        __name(this, "PutBucketAbacCommand");
      }
    };
    var PutBucketAccelerateConfigurationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: false
        })
      ];
    }).s("AmazonS3", "PutBucketAccelerateConfiguration", {}).n("S3Client", "PutBucketAccelerateConfigurationCommand").sc(schemas_0.PutBucketAccelerateConfiguration$).build() {
      static {
        __name(this, "PutBucketAccelerateConfigurationCommand");
      }
    };
    var PutBucketAclCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: true
        })
      ];
    }).s("AmazonS3", "PutBucketAcl", {}).n("S3Client", "PutBucketAclCommand").sc(schemas_0.PutBucketAcl$).build() {
      static {
        __name(this, "PutBucketAclCommand");
      }
    };
    var PutBucketAnalyticsConfigurationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonS3", "PutBucketAnalyticsConfiguration", {}).n("S3Client", "PutBucketAnalyticsConfigurationCommand").sc(schemas_0.PutBucketAnalyticsConfiguration$).build() {
      static {
        __name(this, "PutBucketAnalyticsConfigurationCommand");
      }
    };
    var PutBucketCorsCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: true
        })
      ];
    }).s("AmazonS3", "PutBucketCors", {}).n("S3Client", "PutBucketCorsCommand").sc(schemas_0.PutBucketCors$).build() {
      static {
        __name(this, "PutBucketCorsCommand");
      }
    };
    var PutBucketEncryptionCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: true
        })
      ];
    }).s("AmazonS3", "PutBucketEncryption", {}).n("S3Client", "PutBucketEncryptionCommand").sc(schemas_0.PutBucketEncryption$).build() {
      static {
        __name(this, "PutBucketEncryptionCommand");
      }
    };
    var PutBucketIntelligentTieringConfigurationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonS3", "PutBucketIntelligentTieringConfiguration", {}).n("S3Client", "PutBucketIntelligentTieringConfigurationCommand").sc(schemas_0.PutBucketIntelligentTieringConfiguration$).build() {
      static {
        __name(this, "PutBucketIntelligentTieringConfigurationCommand");
      }
    };
    var PutBucketInventoryConfigurationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonS3", "PutBucketInventoryConfiguration", {}).n("S3Client", "PutBucketInventoryConfigurationCommand").sc(schemas_0.PutBucketInventoryConfiguration$).build() {
      static {
        __name(this, "PutBucketInventoryConfigurationCommand");
      }
    };
    var PutBucketLifecycleConfigurationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: true
        }),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "PutBucketLifecycleConfiguration", {}).n("S3Client", "PutBucketLifecycleConfigurationCommand").sc(schemas_0.PutBucketLifecycleConfiguration$).build() {
      static {
        __name(this, "PutBucketLifecycleConfigurationCommand");
      }
    };
    var PutBucketLoggingCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: true
        })
      ];
    }).s("AmazonS3", "PutBucketLogging", {}).n("S3Client", "PutBucketLoggingCommand").sc(schemas_0.PutBucketLogging$).build() {
      static {
        __name(this, "PutBucketLoggingCommand");
      }
    };
    var PutBucketMetricsConfigurationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonS3", "PutBucketMetricsConfiguration", {}).n("S3Client", "PutBucketMetricsConfigurationCommand").sc(schemas_0.PutBucketMetricsConfiguration$).build() {
      static {
        __name(this, "PutBucketMetricsConfigurationCommand");
      }
    };
    var PutBucketNotificationConfigurationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonS3", "PutBucketNotificationConfiguration", {}).n("S3Client", "PutBucketNotificationConfigurationCommand").sc(schemas_0.PutBucketNotificationConfiguration$).build() {
      static {
        __name(this, "PutBucketNotificationConfigurationCommand");
      }
    };
    var PutBucketOwnershipControlsCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: true
        })
      ];
    }).s("AmazonS3", "PutBucketOwnershipControls", {}).n("S3Client", "PutBucketOwnershipControlsCommand").sc(schemas_0.PutBucketOwnershipControls$).build() {
      static {
        __name(this, "PutBucketOwnershipControlsCommand");
      }
    };
    var PutBucketPolicyCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: true
        })
      ];
    }).s("AmazonS3", "PutBucketPolicy", {}).n("S3Client", "PutBucketPolicyCommand").sc(schemas_0.PutBucketPolicy$).build() {
      static {
        __name(this, "PutBucketPolicyCommand");
      }
    };
    var PutBucketReplicationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: true
        })
      ];
    }).s("AmazonS3", "PutBucketReplication", {}).n("S3Client", "PutBucketReplicationCommand").sc(schemas_0.PutBucketReplication$).build() {
      static {
        __name(this, "PutBucketReplicationCommand");
      }
    };
    var PutBucketRequestPaymentCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: true
        })
      ];
    }).s("AmazonS3", "PutBucketRequestPayment", {}).n("S3Client", "PutBucketRequestPaymentCommand").sc(schemas_0.PutBucketRequestPayment$).build() {
      static {
        __name(this, "PutBucketRequestPaymentCommand");
      }
    };
    var PutBucketTaggingCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: true
        })
      ];
    }).s("AmazonS3", "PutBucketTagging", {}).n("S3Client", "PutBucketTaggingCommand").sc(schemas_0.PutBucketTagging$).build() {
      static {
        __name(this, "PutBucketTaggingCommand");
      }
    };
    var PutBucketVersioningCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: true
        })
      ];
    }).s("AmazonS3", "PutBucketVersioning", {}).n("S3Client", "PutBucketVersioningCommand").sc(schemas_0.PutBucketVersioning$).build() {
      static {
        __name(this, "PutBucketVersioningCommand");
      }
    };
    var PutBucketWebsiteCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: true
        })
      ];
    }).s("AmazonS3", "PutBucketWebsite", {}).n("S3Client", "PutBucketWebsiteCommand").sc(schemas_0.PutBucketWebsite$).build() {
      static {
        __name(this, "PutBucketWebsiteCommand");
      }
    };
    var PutObjectAclCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" },
      Key: { type: "contextParams", name: "Key" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: true
        }),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "PutObjectAcl", {}).n("S3Client", "PutObjectAclCommand").sc(schemas_0.PutObjectAcl$).build() {
      static {
        __name(this, "PutObjectAclCommand");
      }
    };
    var PutObjectCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" },
      Key: { type: "contextParams", name: "Key" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: false
        }),
        middlewareSdkS3.getCheckContentLengthHeaderPlugin(config2),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2),
        middlewareSsec.getSsecPlugin(config2)
      ];
    }).s("AmazonS3", "PutObject", {}).n("S3Client", "PutObjectCommand").sc(schemas_0.PutObject$).build() {
      static {
        __name(this, "PutObjectCommand");
      }
    };
    var PutObjectLegalHoldCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: true
        }),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "PutObjectLegalHold", {}).n("S3Client", "PutObjectLegalHoldCommand").sc(schemas_0.PutObjectLegalHold$).build() {
      static {
        __name(this, "PutObjectLegalHoldCommand");
      }
    };
    var PutObjectLockConfigurationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: true
        }),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "PutObjectLockConfiguration", {}).n("S3Client", "PutObjectLockConfigurationCommand").sc(schemas_0.PutObjectLockConfiguration$).build() {
      static {
        __name(this, "PutObjectLockConfigurationCommand");
      }
    };
    var PutObjectRetentionCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: true
        }),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "PutObjectRetention", {}).n("S3Client", "PutObjectRetentionCommand").sc(schemas_0.PutObjectRetention$).build() {
      static {
        __name(this, "PutObjectRetentionCommand");
      }
    };
    var PutObjectTaggingCommand2 = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: true
        }),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "PutObjectTagging", {}).n("S3Client", "PutObjectTaggingCommand").sc(schemas_0.PutObjectTagging$).build() {
      static {
        __name(this, "PutObjectTaggingCommand");
      }
    };
    var PutPublicAccessBlockCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: true
        })
      ];
    }).s("AmazonS3", "PutPublicAccessBlock", {}).n("S3Client", "PutPublicAccessBlockCommand").sc(schemas_0.PutPublicAccessBlock$).build() {
      static {
        __name(this, "PutPublicAccessBlockCommand");
      }
    };
    var RenameObjectCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" },
      Key: { type: "contextParams", name: "Key" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "RenameObject", {}).n("S3Client", "RenameObjectCommand").sc(schemas_0.RenameObject$).build() {
      static {
        __name(this, "RenameObjectCommand");
      }
    };
    var RestoreObjectCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: false
        }),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "RestoreObject", {}).n("S3Client", "RestoreObjectCommand").sc(schemas_0.RestoreObject$).build() {
      static {
        __name(this, "RestoreObjectCommand");
      }
    };
    var SelectObjectContentCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSsec.getSsecPlugin(config2)
      ];
    }).s("AmazonS3", "SelectObjectContent", {
      eventStream: {
        output: true
      }
    }).n("S3Client", "SelectObjectContentCommand").sc(schemas_0.SelectObjectContent$).build() {
      static {
        __name(this, "SelectObjectContentCommand");
      }
    };
    var UpdateBucketMetadataInventoryTableConfigurationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: true
        })
      ];
    }).s("AmazonS3", "UpdateBucketMetadataInventoryTableConfiguration", {}).n("S3Client", "UpdateBucketMetadataInventoryTableConfigurationCommand").sc(schemas_0.UpdateBucketMetadataInventoryTableConfiguration$).build() {
      static {
        __name(this, "UpdateBucketMetadataInventoryTableConfigurationCommand");
      }
    };
    var UpdateBucketMetadataJournalTableConfigurationCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseS3ExpressControlEndpoint: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: true
        })
      ];
    }).s("AmazonS3", "UpdateBucketMetadataJournalTableConfiguration", {}).n("S3Client", "UpdateBucketMetadataJournalTableConfigurationCommand").sc(schemas_0.UpdateBucketMetadataJournalTableConfiguration$).build() {
      static {
        __name(this, "UpdateBucketMetadataJournalTableConfigurationCommand");
      }
    };
    var UpdateObjectEncryptionCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: true
        }),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2)
      ];
    }).s("AmazonS3", "UpdateObjectEncryption", {}).n("S3Client", "UpdateObjectEncryptionCommand").sc(schemas_0.UpdateObjectEncryption$).build() {
      static {
        __name(this, "UpdateObjectEncryptionCommand");
      }
    };
    var UploadPartCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      Bucket: { type: "contextParams", name: "Bucket" },
      Key: { type: "contextParams", name: "Key" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareFlexibleChecksums.getFlexibleChecksumsPlugin(config2, {
          requestAlgorithmMember: { "httpHeader": "x-amz-sdk-checksum-algorithm", "name": "ChecksumAlgorithm" },
          requestChecksumRequired: false
        }),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2),
        middlewareSsec.getSsecPlugin(config2)
      ];
    }).s("AmazonS3", "UploadPart", {}).n("S3Client", "UploadPartCommand").sc(schemas_0.UploadPart$).build() {
      static {
        __name(this, "UploadPartCommand");
      }
    };
    var UploadPartCopyCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      DisableS3ExpressSessionAuth: { type: "staticContextParams", value: true },
      Bucket: { type: "contextParams", name: "Bucket" }
    }).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkS3.getThrow200ExceptionsPlugin(config2),
        middlewareSsec.getSsecPlugin(config2)
      ];
    }).s("AmazonS3", "UploadPartCopy", {}).n("S3Client", "UploadPartCopyCommand").sc(schemas_0.UploadPartCopy$).build() {
      static {
        __name(this, "UploadPartCopyCommand");
      }
    };
    var WriteGetObjectResponseCommand = class extends smithyClient.Command.classBuilder().ep({
      ...commonParams32,
      UseObjectLambdaEndpoint: { type: "staticContextParams", value: true }
    }).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonS3", "WriteGetObjectResponse", {}).n("S3Client", "WriteGetObjectResponseCommand").sc(schemas_0.WriteGetObjectResponse$).build() {
      static {
        __name(this, "WriteGetObjectResponseCommand");
      }
    };
    var paginateListBuckets = core.createPaginator(S3Client4, ListBucketsCommand, "ContinuationToken", "ContinuationToken", "MaxBuckets");
    var paginateListDirectoryBuckets = core.createPaginator(S3Client4, ListDirectoryBucketsCommand, "ContinuationToken", "ContinuationToken", "MaxDirectoryBuckets");
    var paginateListObjectsV2 = core.createPaginator(S3Client4, ListObjectsV2Command3, "ContinuationToken", "NextContinuationToken", "MaxKeys");
    var paginateListParts = core.createPaginator(S3Client4, ListPartsCommand, "PartNumberMarker", "NextPartNumberMarker", "MaxParts");
    var checkState$3 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new HeadBucketCommand(input));
        reason = result2;
        return { state: utilWaiter.WaiterState.SUCCESS, reason };
      } catch (exception) {
        reason = exception;
        if (exception.name === "NotFound") {
          return { state: utilWaiter.WaiterState.RETRY, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$3");
    var waitForBucketExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$3);
    }, "waitForBucketExists");
    var waitUntilBucketExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$3);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilBucketExists");
    var checkState$2 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new HeadBucketCommand(input));
        reason = result2;
      } catch (exception) {
        reason = exception;
        if (exception.name === "NotFound") {
          return { state: utilWaiter.WaiterState.SUCCESS, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$2");
    var waitForBucketNotExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$2);
    }, "waitForBucketNotExists");
    var waitUntilBucketNotExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$2);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilBucketNotExists");
    var checkState$1 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new HeadObjectCommand2(input));
        reason = result2;
        return { state: utilWaiter.WaiterState.SUCCESS, reason };
      } catch (exception) {
        reason = exception;
        if (exception.name === "NotFound") {
          return { state: utilWaiter.WaiterState.RETRY, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$1");
    var waitForObjectExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$1);
    }, "waitForObjectExists");
    var waitUntilObjectExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$1);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilObjectExists");
    var checkState = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new HeadObjectCommand2(input));
        reason = result2;
      } catch (exception) {
        reason = exception;
        if (exception.name === "NotFound") {
          return { state: utilWaiter.WaiterState.SUCCESS, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState");
    var waitForObjectNotExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState);
    }, "waitForObjectNotExists");
    var waitUntilObjectNotExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilObjectNotExists");
    var commands32 = {
      AbortMultipartUploadCommand,
      CompleteMultipartUploadCommand,
      CopyObjectCommand,
      CreateBucketCommand,
      CreateBucketMetadataConfigurationCommand,
      CreateBucketMetadataTableConfigurationCommand,
      CreateMultipartUploadCommand,
      CreateSessionCommand,
      DeleteBucketCommand,
      DeleteBucketAnalyticsConfigurationCommand,
      DeleteBucketCorsCommand,
      DeleteBucketEncryptionCommand,
      DeleteBucketIntelligentTieringConfigurationCommand,
      DeleteBucketInventoryConfigurationCommand,
      DeleteBucketLifecycleCommand,
      DeleteBucketMetadataConfigurationCommand,
      DeleteBucketMetadataTableConfigurationCommand,
      DeleteBucketMetricsConfigurationCommand,
      DeleteBucketOwnershipControlsCommand,
      DeleteBucketPolicyCommand,
      DeleteBucketReplicationCommand,
      DeleteBucketTaggingCommand,
      DeleteBucketWebsiteCommand,
      DeleteObjectCommand,
      DeleteObjectsCommand: DeleteObjectsCommand2,
      DeleteObjectTaggingCommand: DeleteObjectTaggingCommand2,
      DeletePublicAccessBlockCommand,
      GetBucketAbacCommand,
      GetBucketAccelerateConfigurationCommand,
      GetBucketAclCommand,
      GetBucketAnalyticsConfigurationCommand,
      GetBucketCorsCommand,
      GetBucketEncryptionCommand: GetBucketEncryptionCommand3,
      GetBucketIntelligentTieringConfigurationCommand,
      GetBucketInventoryConfigurationCommand,
      GetBucketLifecycleConfigurationCommand,
      GetBucketLocationCommand: GetBucketLocationCommand3,
      GetBucketLoggingCommand,
      GetBucketMetadataConfigurationCommand,
      GetBucketMetadataTableConfigurationCommand,
      GetBucketMetricsConfigurationCommand,
      GetBucketNotificationConfigurationCommand,
      GetBucketOwnershipControlsCommand,
      GetBucketPolicyCommand,
      GetBucketPolicyStatusCommand,
      GetBucketReplicationCommand,
      GetBucketRequestPaymentCommand,
      GetBucketTaggingCommand,
      GetBucketVersioningCommand,
      GetBucketWebsiteCommand,
      GetObjectCommand: GetObjectCommand2,
      GetObjectAclCommand,
      GetObjectAttributesCommand,
      GetObjectLegalHoldCommand,
      GetObjectLockConfigurationCommand,
      GetObjectRetentionCommand,
      GetObjectTaggingCommand: GetObjectTaggingCommand2,
      GetObjectTorrentCommand,
      GetPublicAccessBlockCommand,
      HeadBucketCommand,
      HeadObjectCommand: HeadObjectCommand2,
      ListBucketAnalyticsConfigurationsCommand,
      ListBucketIntelligentTieringConfigurationsCommand,
      ListBucketInventoryConfigurationsCommand,
      ListBucketMetricsConfigurationsCommand,
      ListBucketsCommand,
      ListDirectoryBucketsCommand,
      ListMultipartUploadsCommand,
      ListObjectsCommand,
      ListObjectsV2Command: ListObjectsV2Command3,
      ListObjectVersionsCommand,
      ListPartsCommand,
      PutBucketAbacCommand,
      PutBucketAccelerateConfigurationCommand,
      PutBucketAclCommand,
      PutBucketAnalyticsConfigurationCommand,
      PutBucketCorsCommand,
      PutBucketEncryptionCommand,
      PutBucketIntelligentTieringConfigurationCommand,
      PutBucketInventoryConfigurationCommand,
      PutBucketLifecycleConfigurationCommand,
      PutBucketLoggingCommand,
      PutBucketMetricsConfigurationCommand,
      PutBucketNotificationConfigurationCommand,
      PutBucketOwnershipControlsCommand,
      PutBucketPolicyCommand,
      PutBucketReplicationCommand,
      PutBucketRequestPaymentCommand,
      PutBucketTaggingCommand,
      PutBucketVersioningCommand,
      PutBucketWebsiteCommand,
      PutObjectCommand,
      PutObjectAclCommand,
      PutObjectLegalHoldCommand,
      PutObjectLockConfigurationCommand,
      PutObjectRetentionCommand,
      PutObjectTaggingCommand: PutObjectTaggingCommand2,
      PutPublicAccessBlockCommand,
      RenameObjectCommand,
      RestoreObjectCommand,
      SelectObjectContentCommand,
      UpdateBucketMetadataInventoryTableConfigurationCommand,
      UpdateBucketMetadataJournalTableConfigurationCommand,
      UpdateObjectEncryptionCommand,
      UploadPartCommand,
      UploadPartCopyCommand,
      WriteGetObjectResponseCommand
    };
    var paginators = {
      paginateListBuckets,
      paginateListDirectoryBuckets,
      paginateListObjectsV2,
      paginateListParts
    };
    var waiters = {
      waitUntilBucketExists,
      waitUntilBucketNotExists,
      waitUntilObjectExists,
      waitUntilObjectNotExists
    };
    var S3 = class extends S3Client4 {
      static {
        __name(this, "S3");
      }
    };
    smithyClient.createAggregatedClient(commands32, S3, { paginators, waiters });
    var BucketAbacStatus = {
      Disabled: "Disabled",
      Enabled: "Enabled"
    };
    var RequestCharged = {
      requester: "requester"
    };
    var RequestPayer = {
      requester: "requester"
    };
    var BucketAccelerateStatus = {
      Enabled: "Enabled",
      Suspended: "Suspended"
    };
    var Type = {
      AmazonCustomerByEmail: "AmazonCustomerByEmail",
      CanonicalUser: "CanonicalUser",
      Group: "Group"
    };
    var Permission = {
      FULL_CONTROL: "FULL_CONTROL",
      READ: "READ",
      READ_ACP: "READ_ACP",
      WRITE: "WRITE",
      WRITE_ACP: "WRITE_ACP"
    };
    var OwnerOverride = {
      Destination: "Destination"
    };
    var ChecksumType = {
      COMPOSITE: "COMPOSITE",
      FULL_OBJECT: "FULL_OBJECT"
    };
    var ServerSideEncryption = {
      AES256: "AES256",
      aws_fsx: "aws:fsx",
      aws_kms: "aws:kms",
      aws_kms_dsse: "aws:kms:dsse"
    };
    var ObjectCannedACL = {
      authenticated_read: "authenticated-read",
      aws_exec_read: "aws-exec-read",
      bucket_owner_full_control: "bucket-owner-full-control",
      bucket_owner_read: "bucket-owner-read",
      private: "private",
      public_read: "public-read",
      public_read_write: "public-read-write"
    };
    var ChecksumAlgorithm = {
      CRC32: "CRC32",
      CRC32C: "CRC32C",
      CRC64NVME: "CRC64NVME",
      MD5: "MD5",
      SHA1: "SHA1",
      SHA256: "SHA256",
      SHA512: "SHA512",
      XXHASH128: "XXHASH128",
      XXHASH3: "XXHASH3",
      XXHASH64: "XXHASH64"
    };
    var MetadataDirective = {
      COPY: "COPY",
      REPLACE: "REPLACE"
    };
    var ObjectLockLegalHoldStatus = {
      OFF: "OFF",
      ON: "ON"
    };
    var ObjectLockMode = {
      COMPLIANCE: "COMPLIANCE",
      GOVERNANCE: "GOVERNANCE"
    };
    var StorageClass = {
      DEEP_ARCHIVE: "DEEP_ARCHIVE",
      EXPRESS_ONEZONE: "EXPRESS_ONEZONE",
      FSX_ONTAP: "FSX_ONTAP",
      FSX_OPENZFS: "FSX_OPENZFS",
      GLACIER: "GLACIER",
      GLACIER_IR: "GLACIER_IR",
      INTELLIGENT_TIERING: "INTELLIGENT_TIERING",
      ONEZONE_IA: "ONEZONE_IA",
      OUTPOSTS: "OUTPOSTS",
      REDUCED_REDUNDANCY: "REDUCED_REDUNDANCY",
      SNOW: "SNOW",
      STANDARD: "STANDARD",
      STANDARD_IA: "STANDARD_IA"
    };
    var TaggingDirective = {
      COPY: "COPY",
      REPLACE: "REPLACE"
    };
    var BucketCannedACL = {
      authenticated_read: "authenticated-read",
      private: "private",
      public_read: "public-read",
      public_read_write: "public-read-write"
    };
    var BucketNamespace = {
      ACCOUNT_REGIONAL: "account-regional",
      GLOBAL: "global"
    };
    var DataRedundancy = {
      SingleAvailabilityZone: "SingleAvailabilityZone",
      SingleLocalZone: "SingleLocalZone"
    };
    var BucketType = {
      Directory: "Directory"
    };
    var LocationType = {
      AvailabilityZone: "AvailabilityZone",
      LocalZone: "LocalZone"
    };
    var BucketLocationConstraint = {
      EU: "EU",
      af_south_1: "af-south-1",
      ap_east_1: "ap-east-1",
      ap_east_2: "ap-east-2",
      ap_northeast_1: "ap-northeast-1",
      ap_northeast_2: "ap-northeast-2",
      ap_northeast_3: "ap-northeast-3",
      ap_south_1: "ap-south-1",
      ap_south_2: "ap-south-2",
      ap_southeast_1: "ap-southeast-1",
      ap_southeast_2: "ap-southeast-2",
      ap_southeast_3: "ap-southeast-3",
      ap_southeast_4: "ap-southeast-4",
      ap_southeast_5: "ap-southeast-5",
      ap_southeast_6: "ap-southeast-6",
      ap_southeast_7: "ap-southeast-7",
      ca_central_1: "ca-central-1",
      ca_west_1: "ca-west-1",
      cn_north_1: "cn-north-1",
      cn_northwest_1: "cn-northwest-1",
      eu_central_1: "eu-central-1",
      eu_central_2: "eu-central-2",
      eu_north_1: "eu-north-1",
      eu_south_1: "eu-south-1",
      eu_south_2: "eu-south-2",
      eu_west_1: "eu-west-1",
      eu_west_2: "eu-west-2",
      eu_west_3: "eu-west-3",
      il_central_1: "il-central-1",
      me_central_1: "me-central-1",
      me_south_1: "me-south-1",
      mx_central_1: "mx-central-1",
      sa_east_1: "sa-east-1",
      us_east_2: "us-east-2",
      us_gov_east_1: "us-gov-east-1",
      us_gov_west_1: "us-gov-west-1",
      us_west_1: "us-west-1",
      us_west_2: "us-west-2"
    };
    var ObjectOwnership = {
      BucketOwnerEnforced: "BucketOwnerEnforced",
      BucketOwnerPreferred: "BucketOwnerPreferred",
      ObjectWriter: "ObjectWriter"
    };
    var InventoryConfigurationState = {
      DISABLED: "DISABLED",
      ENABLED: "ENABLED"
    };
    var TableSseAlgorithm = {
      AES256: "AES256",
      aws_kms: "aws:kms"
    };
    var ExpirationState = {
      DISABLED: "DISABLED",
      ENABLED: "ENABLED"
    };
    var SessionMode = {
      ReadOnly: "ReadOnly",
      ReadWrite: "ReadWrite"
    };
    var AnalyticsS3ExportFileFormat = {
      CSV: "CSV"
    };
    var StorageClassAnalysisSchemaVersion = {
      V_1: "V_1"
    };
    var EncryptionType = {
      NONE: "NONE",
      SSE_C: "SSE-C"
    };
    var IntelligentTieringStatus = {
      Disabled: "Disabled",
      Enabled: "Enabled"
    };
    var IntelligentTieringAccessTier = {
      ARCHIVE_ACCESS: "ARCHIVE_ACCESS",
      DEEP_ARCHIVE_ACCESS: "DEEP_ARCHIVE_ACCESS"
    };
    var InventoryFormat = {
      CSV: "CSV",
      ORC: "ORC",
      Parquet: "Parquet"
    };
    var InventoryIncludedObjectVersions = {
      All: "All",
      Current: "Current"
    };
    var InventoryOptionalField = {
      BucketKeyStatus: "BucketKeyStatus",
      ChecksumAlgorithm: "ChecksumAlgorithm",
      ETag: "ETag",
      EncryptionStatus: "EncryptionStatus",
      IntelligentTieringAccessTier: "IntelligentTieringAccessTier",
      IsMultipartUploaded: "IsMultipartUploaded",
      LastModifiedDate: "LastModifiedDate",
      LifecycleExpirationDate: "LifecycleExpirationDate",
      ObjectAccessControlList: "ObjectAccessControlList",
      ObjectLockLegalHoldStatus: "ObjectLockLegalHoldStatus",
      ObjectLockMode: "ObjectLockMode",
      ObjectLockRetainUntilDate: "ObjectLockRetainUntilDate",
      ObjectOwner: "ObjectOwner",
      ReplicationStatus: "ReplicationStatus",
      Size: "Size",
      StorageClass: "StorageClass"
    };
    var InventoryFrequency = {
      Daily: "Daily",
      Weekly: "Weekly"
    };
    var TransitionStorageClass = {
      DEEP_ARCHIVE: "DEEP_ARCHIVE",
      GLACIER: "GLACIER",
      GLACIER_IR: "GLACIER_IR",
      INTELLIGENT_TIERING: "INTELLIGENT_TIERING",
      ONEZONE_IA: "ONEZONE_IA",
      STANDARD_IA: "STANDARD_IA"
    };
    var ExpirationStatus = {
      Disabled: "Disabled",
      Enabled: "Enabled"
    };
    var TransitionDefaultMinimumObjectSize = {
      all_storage_classes_128K: "all_storage_classes_128K",
      varies_by_storage_class: "varies_by_storage_class"
    };
    var BucketLogsPermission = {
      FULL_CONTROL: "FULL_CONTROL",
      READ: "READ",
      WRITE: "WRITE"
    };
    var PartitionDateSource = {
      DeliveryTime: "DeliveryTime",
      EventTime: "EventTime"
    };
    var S3TablesBucketType = {
      aws: "aws",
      customer: "customer"
    };
    var Event = {
      s3_IntelligentTiering: "s3:IntelligentTiering",
      s3_LifecycleExpiration_: "s3:LifecycleExpiration:*",
      s3_LifecycleExpiration_Delete: "s3:LifecycleExpiration:Delete",
      s3_LifecycleExpiration_DeleteMarkerCreated: "s3:LifecycleExpiration:DeleteMarkerCreated",
      s3_LifecycleTransition: "s3:LifecycleTransition",
      s3_ObjectAcl_Put: "s3:ObjectAcl:Put",
      s3_ObjectCreated_: "s3:ObjectCreated:*",
      s3_ObjectCreated_CompleteMultipartUpload: "s3:ObjectCreated:CompleteMultipartUpload",
      s3_ObjectCreated_Copy: "s3:ObjectCreated:Copy",
      s3_ObjectCreated_Post: "s3:ObjectCreated:Post",
      s3_ObjectCreated_Put: "s3:ObjectCreated:Put",
      s3_ObjectRemoved_: "s3:ObjectRemoved:*",
      s3_ObjectRemoved_Delete: "s3:ObjectRemoved:Delete",
      s3_ObjectRemoved_DeleteMarkerCreated: "s3:ObjectRemoved:DeleteMarkerCreated",
      s3_ObjectRestore_: "s3:ObjectRestore:*",
      s3_ObjectRestore_Completed: "s3:ObjectRestore:Completed",
      s3_ObjectRestore_Delete: "s3:ObjectRestore:Delete",
      s3_ObjectRestore_Post: "s3:ObjectRestore:Post",
      s3_ObjectTagging_: "s3:ObjectTagging:*",
      s3_ObjectTagging_Delete: "s3:ObjectTagging:Delete",
      s3_ObjectTagging_Put: "s3:ObjectTagging:Put",
      s3_ReducedRedundancyLostObject: "s3:ReducedRedundancyLostObject",
      s3_Replication_: "s3:Replication:*",
      s3_Replication_OperationFailedReplication: "s3:Replication:OperationFailedReplication",
      s3_Replication_OperationMissedThreshold: "s3:Replication:OperationMissedThreshold",
      s3_Replication_OperationNotTracked: "s3:Replication:OperationNotTracked",
      s3_Replication_OperationReplicatedAfterThreshold: "s3:Replication:OperationReplicatedAfterThreshold"
    };
    var FilterRuleName = {
      prefix: "prefix",
      suffix: "suffix"
    };
    var DeleteMarkerReplicationStatus = {
      Disabled: "Disabled",
      Enabled: "Enabled"
    };
    var MetricsStatus = {
      Disabled: "Disabled",
      Enabled: "Enabled"
    };
    var ReplicationTimeStatus = {
      Disabled: "Disabled",
      Enabled: "Enabled"
    };
    var ExistingObjectReplicationStatus = {
      Disabled: "Disabled",
      Enabled: "Enabled"
    };
    var ReplicaModificationsStatus = {
      Disabled: "Disabled",
      Enabled: "Enabled"
    };
    var SseKmsEncryptedObjectsStatus = {
      Disabled: "Disabled",
      Enabled: "Enabled"
    };
    var ReplicationRuleStatus = {
      Disabled: "Disabled",
      Enabled: "Enabled"
    };
    var Payer = {
      BucketOwner: "BucketOwner",
      Requester: "Requester"
    };
    var MFADeleteStatus = {
      Disabled: "Disabled",
      Enabled: "Enabled"
    };
    var BucketVersioningStatus = {
      Enabled: "Enabled",
      Suspended: "Suspended"
    };
    var Protocol = {
      http: "http",
      https: "https"
    };
    var ReplicationStatus = {
      COMPLETE: "COMPLETE",
      COMPLETED: "COMPLETED",
      FAILED: "FAILED",
      PENDING: "PENDING",
      REPLICA: "REPLICA"
    };
    var ChecksumMode = {
      ENABLED: "ENABLED"
    };
    var ObjectAttributes = {
      CHECKSUM: "Checksum",
      ETAG: "ETag",
      OBJECT_PARTS: "ObjectParts",
      OBJECT_SIZE: "ObjectSize",
      STORAGE_CLASS: "StorageClass"
    };
    var ObjectLockEnabled = {
      Enabled: "Enabled"
    };
    var ObjectLockRetentionMode = {
      COMPLIANCE: "COMPLIANCE",
      GOVERNANCE: "GOVERNANCE"
    };
    var ArchiveStatus = {
      ARCHIVE_ACCESS: "ARCHIVE_ACCESS",
      DEEP_ARCHIVE_ACCESS: "DEEP_ARCHIVE_ACCESS"
    };
    var EncodingType = {
      url: "url"
    };
    var ObjectStorageClass = {
      DEEP_ARCHIVE: "DEEP_ARCHIVE",
      EXPRESS_ONEZONE: "EXPRESS_ONEZONE",
      FSX_ONTAP: "FSX_ONTAP",
      FSX_OPENZFS: "FSX_OPENZFS",
      GLACIER: "GLACIER",
      GLACIER_IR: "GLACIER_IR",
      INTELLIGENT_TIERING: "INTELLIGENT_TIERING",
      ONEZONE_IA: "ONEZONE_IA",
      OUTPOSTS: "OUTPOSTS",
      REDUCED_REDUNDANCY: "REDUCED_REDUNDANCY",
      SNOW: "SNOW",
      STANDARD: "STANDARD",
      STANDARD_IA: "STANDARD_IA"
    };
    var OptionalObjectAttributes = {
      RESTORE_STATUS: "RestoreStatus"
    };
    var ObjectVersionStorageClass = {
      STANDARD: "STANDARD"
    };
    var MFADelete = {
      Disabled: "Disabled",
      Enabled: "Enabled"
    };
    var Tier = {
      Bulk: "Bulk",
      Expedited: "Expedited",
      Standard: "Standard"
    };
    var ExpressionType = {
      SQL: "SQL"
    };
    var CompressionType = {
      BZIP2: "BZIP2",
      GZIP: "GZIP",
      NONE: "NONE"
    };
    var FileHeaderInfo = {
      IGNORE: "IGNORE",
      NONE: "NONE",
      USE: "USE"
    };
    var JSONType = {
      DOCUMENT: "DOCUMENT",
      LINES: "LINES"
    };
    var QuoteFields = {
      ALWAYS: "ALWAYS",
      ASNEEDED: "ASNEEDED"
    };
    var RestoreRequestType = {
      SELECT: "SELECT"
    };
    exports2.$Command = smithyClient.Command;
    exports2.__Client = smithyClient.Client;
    exports2.S3ServiceException = S3ServiceException.S3ServiceException;
    exports2.AbortMultipartUploadCommand = AbortMultipartUploadCommand;
    exports2.AnalyticsS3ExportFileFormat = AnalyticsS3ExportFileFormat;
    exports2.ArchiveStatus = ArchiveStatus;
    exports2.BucketAbacStatus = BucketAbacStatus;
    exports2.BucketAccelerateStatus = BucketAccelerateStatus;
    exports2.BucketCannedACL = BucketCannedACL;
    exports2.BucketLocationConstraint = BucketLocationConstraint;
    exports2.BucketLogsPermission = BucketLogsPermission;
    exports2.BucketNamespace = BucketNamespace;
    exports2.BucketType = BucketType;
    exports2.BucketVersioningStatus = BucketVersioningStatus;
    exports2.ChecksumAlgorithm = ChecksumAlgorithm;
    exports2.ChecksumMode = ChecksumMode;
    exports2.ChecksumType = ChecksumType;
    exports2.CompleteMultipartUploadCommand = CompleteMultipartUploadCommand;
    exports2.CompressionType = CompressionType;
    exports2.CopyObjectCommand = CopyObjectCommand;
    exports2.CreateBucketCommand = CreateBucketCommand;
    exports2.CreateBucketMetadataConfigurationCommand = CreateBucketMetadataConfigurationCommand;
    exports2.CreateBucketMetadataTableConfigurationCommand = CreateBucketMetadataTableConfigurationCommand;
    exports2.CreateMultipartUploadCommand = CreateMultipartUploadCommand;
    exports2.CreateSessionCommand = CreateSessionCommand;
    exports2.DataRedundancy = DataRedundancy;
    exports2.DeleteBucketAnalyticsConfigurationCommand = DeleteBucketAnalyticsConfigurationCommand;
    exports2.DeleteBucketCommand = DeleteBucketCommand;
    exports2.DeleteBucketCorsCommand = DeleteBucketCorsCommand;
    exports2.DeleteBucketEncryptionCommand = DeleteBucketEncryptionCommand;
    exports2.DeleteBucketIntelligentTieringConfigurationCommand = DeleteBucketIntelligentTieringConfigurationCommand;
    exports2.DeleteBucketInventoryConfigurationCommand = DeleteBucketInventoryConfigurationCommand;
    exports2.DeleteBucketLifecycleCommand = DeleteBucketLifecycleCommand;
    exports2.DeleteBucketMetadataConfigurationCommand = DeleteBucketMetadataConfigurationCommand;
    exports2.DeleteBucketMetadataTableConfigurationCommand = DeleteBucketMetadataTableConfigurationCommand;
    exports2.DeleteBucketMetricsConfigurationCommand = DeleteBucketMetricsConfigurationCommand;
    exports2.DeleteBucketOwnershipControlsCommand = DeleteBucketOwnershipControlsCommand;
    exports2.DeleteBucketPolicyCommand = DeleteBucketPolicyCommand;
    exports2.DeleteBucketReplicationCommand = DeleteBucketReplicationCommand;
    exports2.DeleteBucketTaggingCommand = DeleteBucketTaggingCommand;
    exports2.DeleteBucketWebsiteCommand = DeleteBucketWebsiteCommand;
    exports2.DeleteMarkerReplicationStatus = DeleteMarkerReplicationStatus;
    exports2.DeleteObjectCommand = DeleteObjectCommand;
    exports2.DeleteObjectTaggingCommand = DeleteObjectTaggingCommand2;
    exports2.DeleteObjectsCommand = DeleteObjectsCommand2;
    exports2.DeletePublicAccessBlockCommand = DeletePublicAccessBlockCommand;
    exports2.EncodingType = EncodingType;
    exports2.EncryptionType = EncryptionType;
    exports2.Event = Event;
    exports2.ExistingObjectReplicationStatus = ExistingObjectReplicationStatus;
    exports2.ExpirationState = ExpirationState;
    exports2.ExpirationStatus = ExpirationStatus;
    exports2.ExpressionType = ExpressionType;
    exports2.FileHeaderInfo = FileHeaderInfo;
    exports2.FilterRuleName = FilterRuleName;
    exports2.GetBucketAbacCommand = GetBucketAbacCommand;
    exports2.GetBucketAccelerateConfigurationCommand = GetBucketAccelerateConfigurationCommand;
    exports2.GetBucketAclCommand = GetBucketAclCommand;
    exports2.GetBucketAnalyticsConfigurationCommand = GetBucketAnalyticsConfigurationCommand;
    exports2.GetBucketCorsCommand = GetBucketCorsCommand;
    exports2.GetBucketEncryptionCommand = GetBucketEncryptionCommand3;
    exports2.GetBucketIntelligentTieringConfigurationCommand = GetBucketIntelligentTieringConfigurationCommand;
    exports2.GetBucketInventoryConfigurationCommand = GetBucketInventoryConfigurationCommand;
    exports2.GetBucketLifecycleConfigurationCommand = GetBucketLifecycleConfigurationCommand;
    exports2.GetBucketLocationCommand = GetBucketLocationCommand3;
    exports2.GetBucketLoggingCommand = GetBucketLoggingCommand;
    exports2.GetBucketMetadataConfigurationCommand = GetBucketMetadataConfigurationCommand;
    exports2.GetBucketMetadataTableConfigurationCommand = GetBucketMetadataTableConfigurationCommand;
    exports2.GetBucketMetricsConfigurationCommand = GetBucketMetricsConfigurationCommand;
    exports2.GetBucketNotificationConfigurationCommand = GetBucketNotificationConfigurationCommand;
    exports2.GetBucketOwnershipControlsCommand = GetBucketOwnershipControlsCommand;
    exports2.GetBucketPolicyCommand = GetBucketPolicyCommand;
    exports2.GetBucketPolicyStatusCommand = GetBucketPolicyStatusCommand;
    exports2.GetBucketReplicationCommand = GetBucketReplicationCommand;
    exports2.GetBucketRequestPaymentCommand = GetBucketRequestPaymentCommand;
    exports2.GetBucketTaggingCommand = GetBucketTaggingCommand;
    exports2.GetBucketVersioningCommand = GetBucketVersioningCommand;
    exports2.GetBucketWebsiteCommand = GetBucketWebsiteCommand;
    exports2.GetObjectAclCommand = GetObjectAclCommand;
    exports2.GetObjectAttributesCommand = GetObjectAttributesCommand;
    exports2.GetObjectCommand = GetObjectCommand2;
    exports2.GetObjectLegalHoldCommand = GetObjectLegalHoldCommand;
    exports2.GetObjectLockConfigurationCommand = GetObjectLockConfigurationCommand;
    exports2.GetObjectRetentionCommand = GetObjectRetentionCommand;
    exports2.GetObjectTaggingCommand = GetObjectTaggingCommand2;
    exports2.GetObjectTorrentCommand = GetObjectTorrentCommand;
    exports2.GetPublicAccessBlockCommand = GetPublicAccessBlockCommand;
    exports2.HeadBucketCommand = HeadBucketCommand;
    exports2.HeadObjectCommand = HeadObjectCommand2;
    exports2.IntelligentTieringAccessTier = IntelligentTieringAccessTier;
    exports2.IntelligentTieringStatus = IntelligentTieringStatus;
    exports2.InventoryConfigurationState = InventoryConfigurationState;
    exports2.InventoryFormat = InventoryFormat;
    exports2.InventoryFrequency = InventoryFrequency;
    exports2.InventoryIncludedObjectVersions = InventoryIncludedObjectVersions;
    exports2.InventoryOptionalField = InventoryOptionalField;
    exports2.JSONType = JSONType;
    exports2.ListBucketAnalyticsConfigurationsCommand = ListBucketAnalyticsConfigurationsCommand;
    exports2.ListBucketIntelligentTieringConfigurationsCommand = ListBucketIntelligentTieringConfigurationsCommand;
    exports2.ListBucketInventoryConfigurationsCommand = ListBucketInventoryConfigurationsCommand;
    exports2.ListBucketMetricsConfigurationsCommand = ListBucketMetricsConfigurationsCommand;
    exports2.ListBucketsCommand = ListBucketsCommand;
    exports2.ListDirectoryBucketsCommand = ListDirectoryBucketsCommand;
    exports2.ListMultipartUploadsCommand = ListMultipartUploadsCommand;
    exports2.ListObjectVersionsCommand = ListObjectVersionsCommand;
    exports2.ListObjectsCommand = ListObjectsCommand;
    exports2.ListObjectsV2Command = ListObjectsV2Command3;
    exports2.ListPartsCommand = ListPartsCommand;
    exports2.LocationType = LocationType;
    exports2.MFADelete = MFADelete;
    exports2.MFADeleteStatus = MFADeleteStatus;
    exports2.MetadataDirective = MetadataDirective;
    exports2.MetricsStatus = MetricsStatus;
    exports2.ObjectAttributes = ObjectAttributes;
    exports2.ObjectCannedACL = ObjectCannedACL;
    exports2.ObjectLockEnabled = ObjectLockEnabled;
    exports2.ObjectLockLegalHoldStatus = ObjectLockLegalHoldStatus;
    exports2.ObjectLockMode = ObjectLockMode;
    exports2.ObjectLockRetentionMode = ObjectLockRetentionMode;
    exports2.ObjectOwnership = ObjectOwnership;
    exports2.ObjectStorageClass = ObjectStorageClass;
    exports2.ObjectVersionStorageClass = ObjectVersionStorageClass;
    exports2.OptionalObjectAttributes = OptionalObjectAttributes;
    exports2.OwnerOverride = OwnerOverride;
    exports2.PartitionDateSource = PartitionDateSource;
    exports2.Payer = Payer;
    exports2.Permission = Permission;
    exports2.Protocol = Protocol;
    exports2.PutBucketAbacCommand = PutBucketAbacCommand;
    exports2.PutBucketAccelerateConfigurationCommand = PutBucketAccelerateConfigurationCommand;
    exports2.PutBucketAclCommand = PutBucketAclCommand;
    exports2.PutBucketAnalyticsConfigurationCommand = PutBucketAnalyticsConfigurationCommand;
    exports2.PutBucketCorsCommand = PutBucketCorsCommand;
    exports2.PutBucketEncryptionCommand = PutBucketEncryptionCommand;
    exports2.PutBucketIntelligentTieringConfigurationCommand = PutBucketIntelligentTieringConfigurationCommand;
    exports2.PutBucketInventoryConfigurationCommand = PutBucketInventoryConfigurationCommand;
    exports2.PutBucketLifecycleConfigurationCommand = PutBucketLifecycleConfigurationCommand;
    exports2.PutBucketLoggingCommand = PutBucketLoggingCommand;
    exports2.PutBucketMetricsConfigurationCommand = PutBucketMetricsConfigurationCommand;
    exports2.PutBucketNotificationConfigurationCommand = PutBucketNotificationConfigurationCommand;
    exports2.PutBucketOwnershipControlsCommand = PutBucketOwnershipControlsCommand;
    exports2.PutBucketPolicyCommand = PutBucketPolicyCommand;
    exports2.PutBucketReplicationCommand = PutBucketReplicationCommand;
    exports2.PutBucketRequestPaymentCommand = PutBucketRequestPaymentCommand;
    exports2.PutBucketTaggingCommand = PutBucketTaggingCommand;
    exports2.PutBucketVersioningCommand = PutBucketVersioningCommand;
    exports2.PutBucketWebsiteCommand = PutBucketWebsiteCommand;
    exports2.PutObjectAclCommand = PutObjectAclCommand;
    exports2.PutObjectCommand = PutObjectCommand;
    exports2.PutObjectLegalHoldCommand = PutObjectLegalHoldCommand;
    exports2.PutObjectLockConfigurationCommand = PutObjectLockConfigurationCommand;
    exports2.PutObjectRetentionCommand = PutObjectRetentionCommand;
    exports2.PutObjectTaggingCommand = PutObjectTaggingCommand2;
    exports2.PutPublicAccessBlockCommand = PutPublicAccessBlockCommand;
    exports2.QuoteFields = QuoteFields;
    exports2.RenameObjectCommand = RenameObjectCommand;
    exports2.ReplicaModificationsStatus = ReplicaModificationsStatus;
    exports2.ReplicationRuleStatus = ReplicationRuleStatus;
    exports2.ReplicationStatus = ReplicationStatus;
    exports2.ReplicationTimeStatus = ReplicationTimeStatus;
    exports2.RequestCharged = RequestCharged;
    exports2.RequestPayer = RequestPayer;
    exports2.RestoreObjectCommand = RestoreObjectCommand;
    exports2.RestoreRequestType = RestoreRequestType;
    exports2.S3 = S3;
    exports2.S3Client = S3Client4;
    exports2.S3TablesBucketType = S3TablesBucketType;
    exports2.SelectObjectContentCommand = SelectObjectContentCommand;
    exports2.ServerSideEncryption = ServerSideEncryption;
    exports2.SessionMode = SessionMode;
    exports2.SseKmsEncryptedObjectsStatus = SseKmsEncryptedObjectsStatus;
    exports2.StorageClass = StorageClass;
    exports2.StorageClassAnalysisSchemaVersion = StorageClassAnalysisSchemaVersion;
    exports2.TableSseAlgorithm = TableSseAlgorithm;
    exports2.TaggingDirective = TaggingDirective;
    exports2.Tier = Tier;
    exports2.TransitionDefaultMinimumObjectSize = TransitionDefaultMinimumObjectSize;
    exports2.TransitionStorageClass = TransitionStorageClass;
    exports2.Type = Type;
    exports2.UpdateBucketMetadataInventoryTableConfigurationCommand = UpdateBucketMetadataInventoryTableConfigurationCommand;
    exports2.UpdateBucketMetadataJournalTableConfigurationCommand = UpdateBucketMetadataJournalTableConfigurationCommand;
    exports2.UpdateObjectEncryptionCommand = UpdateObjectEncryptionCommand;
    exports2.UploadPartCommand = UploadPartCommand;
    exports2.UploadPartCopyCommand = UploadPartCopyCommand;
    exports2.WriteGetObjectResponseCommand = WriteGetObjectResponseCommand;
    exports2.paginateListBuckets = paginateListBuckets;
    exports2.paginateListDirectoryBuckets = paginateListDirectoryBuckets;
    exports2.paginateListObjectsV2 = paginateListObjectsV2;
    exports2.paginateListParts = paginateListParts;
    exports2.waitForBucketExists = waitForBucketExists;
    exports2.waitForBucketNotExists = waitForBucketNotExists;
    exports2.waitForObjectExists = waitForObjectExists;
    exports2.waitForObjectNotExists = waitForObjectNotExists;
    exports2.waitUntilBucketExists = waitUntilBucketExists;
    exports2.waitUntilBucketNotExists = waitUntilBucketNotExists;
    exports2.waitUntilObjectExists = waitUntilObjectExists;
    exports2.waitUntilObjectNotExists = waitUntilObjectNotExists;
    Object.prototype.hasOwnProperty.call(schemas_0, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: schemas_0["__proto__"]
    });
    Object.keys(schemas_0).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = schemas_0[k32];
    });
    Object.prototype.hasOwnProperty.call(errors, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: errors["__proto__"]
    });
    Object.keys(errors).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = errors[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/client/emitWarningIfUnsupportedVersion.js
var state6, emitWarningIfUnsupportedVersion13;
var init_emitWarningIfUnsupportedVersion6 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/client/emitWarningIfUnsupportedVersion.js"() {
    state6 = {
      warningEmitted: false
    };
    emitWarningIfUnsupportedVersion13 = /* @__PURE__ */ __name((version) => {
      if (version && !state6.warningEmitted) {
        if (process.env.AWS_SDK_JS_NODE_VERSION_SUPPORT_WARNING_DISABLED === "true") {
          state6.warningEmitted = true;
          return;
        }
        const userMajorVersion = parseInt(version.substring(1, version.indexOf(".")));
        const vv = 22;
        if (userMajorVersion < vv) {
          state6.warningEmitted = true;
          process.emitWarning(`NodeVersionSupportWarning: The AWS SDK for JavaScript (v3)
versions published after the first week of January 2027
will require node >=${vv}. You are running node ${version}.

To continue receiving updates to AWS services, bug fixes,
and security updates please upgrade to node >=${vv}.

More information can be found at: https://a.co/c895JFp`);
        }
      }
    }, "emitWarningIfUnsupportedVersion");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/client/longPollMiddleware.js
var longPollMiddleware6, longPollMiddlewareOptions6, getLongPollPlugin6;
var init_longPollMiddleware6 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/client/longPollMiddleware.js"() {
    longPollMiddleware6 = /* @__PURE__ */ __name(() => (next, context) => async (args) => {
      context.__retryLongPoll = true;
      return next(args);
    }, "longPollMiddleware");
    longPollMiddlewareOptions6 = {
      name: "longPollMiddleware",
      tags: ["RETRY"],
      step: "initialize",
      override: true
    };
    getLongPollPlugin6 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(longPollMiddleware6(), longPollMiddlewareOptions6);
      }, "applyToStack")
    }), "getLongPollPlugin");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/client/setCredentialFeature.js
function setCredentialFeature6(credentials, feature, value) {
  if (!credentials.$source) {
    credentials.$source = {};
  }
  credentials.$source[feature] = value;
  return credentials;
}
var init_setCredentialFeature6 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/client/setCredentialFeature.js"() {
    __name(setCredentialFeature6, "setCredentialFeature");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/client/setFeature.js
function setFeature7(context, feature, value) {
  if (!context.__aws_sdk_context) {
    context.__aws_sdk_context = {
      features: {}
    };
  } else if (!context.__aws_sdk_context.features) {
    context.__aws_sdk_context.features = {};
  }
  context.__aws_sdk_context.features[feature] = value;
}
var import_util_retry13;
var init_setFeature7 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/client/setFeature.js"() {
    import_util_retry13 = __toESM(require_dist_cjs22());
    import_util_retry13.Retry.v2026 ||= typeof process === "object" && process.env?.AWS_NEW_RETRIES_2026 === "true";
    __name(setFeature7, "setFeature");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/client/setTokenFeature.js
function setTokenFeature6(token, feature, value) {
  if (!token.$source) {
    token.$source = {};
  }
  token.$source[feature] = value;
  return token;
}
var init_setTokenFeature6 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/client/setTokenFeature.js"() {
    __name(setTokenFeature6, "setTokenFeature");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/client/index.js
var client_exports6 = {};
__export(client_exports6, {
  emitWarningIfUnsupportedVersion: () => emitWarningIfUnsupportedVersion13,
  getLongPollPlugin: () => getLongPollPlugin6,
  setCredentialFeature: () => setCredentialFeature6,
  setFeature: () => setFeature7,
  setTokenFeature: () => setTokenFeature6,
  state: () => state6
});
var init_client7 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/client/index.js"() {
    init_emitWarningIfUnsupportedVersion6();
    init_longPollMiddleware6();
    init_setCredentialFeature6();
    init_setFeature7();
    init_setTokenFeature6();
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/middleware-user-agent/dist-cjs/index.js
var require_dist_cjs91 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/middleware-user-agent/dist-cjs/index.js"(exports2) {
    "use strict";
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var utilEndpoints = require_dist_cjs21();
    var protocolHttp = require_dist_cjs2();
    var client = (init_client7(), __toCommonJS(client_exports6));
    var utilRetry = require_dist_cjs22();
    var DEFAULT_UA_APP_ID2 = void 0;
    function isValidUserAgentAppId2(appId) {
      if (appId === void 0) {
        return true;
      }
      return typeof appId === "string" && appId.length <= 50;
    }
    __name(isValidUserAgentAppId2, "isValidUserAgentAppId");
    function resolveUserAgentConfig29(input) {
      const normalizedAppIdProvider = core.normalizeProvider(input.userAgentAppId ?? DEFAULT_UA_APP_ID2);
      const { customUserAgent } = input;
      return Object.assign(input, {
        customUserAgent: typeof customUserAgent === "string" ? [[customUserAgent]] : customUserAgent,
        userAgentAppId: /* @__PURE__ */ __name(async () => {
          const appId = await normalizedAppIdProvider();
          if (!isValidUserAgentAppId2(appId)) {
            const logger5 = input.logger?.constructor?.name === "NoOpLogger" || !input.logger ? console : input.logger;
            if (typeof appId !== "string") {
              logger5?.warn("userAgentAppId must be a string or undefined.");
            } else if (appId.length > 50) {
              logger5?.warn("The provided userAgentAppId exceeds the maximum length of 50 characters.");
            }
          }
          return appId;
        }, "userAgentAppId")
      });
    }
    __name(resolveUserAgentConfig29, "resolveUserAgentConfig");
    var ACCOUNT_ID_ENDPOINT_REGEX2 = /\d{12}\.ddb/;
    async function checkFeatures2(context, config2, args) {
      const request4 = args.request;
      if (request4?.headers?.["smithy-protocol"] === "rpc-v2-cbor") {
        client.setFeature(context, "PROTOCOL_RPC_V2_CBOR", "M");
      }
      if (typeof config2.retryStrategy === "function") {
        const retryStrategy = await config2.retryStrategy();
        if (typeof retryStrategy.mode === "string") {
          switch (retryStrategy.mode) {
            case utilRetry.RETRY_MODES.ADAPTIVE:
              client.setFeature(context, "RETRY_MODE_ADAPTIVE", "F");
              break;
            case utilRetry.RETRY_MODES.STANDARD:
              client.setFeature(context, "RETRY_MODE_STANDARD", "E");
              break;
          }
        }
      }
      if (typeof config2.accountIdEndpointMode === "function") {
        const endpointV2 = context.endpointV2;
        if (String(endpointV2?.url?.hostname).match(ACCOUNT_ID_ENDPOINT_REGEX2)) {
          client.setFeature(context, "ACCOUNT_ID_ENDPOINT", "O");
        }
        switch (await config2.accountIdEndpointMode?.()) {
          case "disabled":
            client.setFeature(context, "ACCOUNT_ID_MODE_DISABLED", "Q");
            break;
          case "preferred":
            client.setFeature(context, "ACCOUNT_ID_MODE_PREFERRED", "P");
            break;
          case "required":
            client.setFeature(context, "ACCOUNT_ID_MODE_REQUIRED", "R");
            break;
        }
      }
      const identity = context.__smithy_context?.selectedHttpAuthScheme?.identity;
      if (identity?.$source) {
        const credentials = identity;
        if (credentials.accountId) {
          client.setFeature(context, "RESOLVED_ACCOUNT_ID", "T");
        }
        for (const [key, value] of Object.entries(credentials.$source ?? {})) {
          client.setFeature(context, key, value);
        }
      }
    }
    __name(checkFeatures2, "checkFeatures");
    var USER_AGENT3 = "user-agent";
    var X_AMZ_USER_AGENT2 = "x-amz-user-agent";
    var SPACE2 = " ";
    var UA_NAME_SEPARATOR2 = "/";
    var UA_NAME_ESCAPE_REGEX2 = /[^!$%&'*+\-.^_`|~\w]/g;
    var UA_VALUE_ESCAPE_REGEX2 = /[^!$%&'*+\-.^_`|~\w#]/g;
    var UA_ESCAPE_CHAR2 = "-";
    var BYTE_LIMIT2 = 1024;
    function encodeFeatures2(features) {
      let buffer = "";
      for (const key in features) {
        const val = features[key];
        if (buffer.length + val.length + 1 <= BYTE_LIMIT2) {
          if (buffer.length) {
            buffer += "," + val;
          } else {
            buffer += val;
          }
          continue;
        }
        break;
      }
      return buffer;
    }
    __name(encodeFeatures2, "encodeFeatures");
    var userAgentMiddleware2 = /* @__PURE__ */ __name((options) => (next, context) => async (args) => {
      const { request: request4 } = args;
      if (!protocolHttp.HttpRequest.isInstance(request4)) {
        return next(args);
      }
      const { headers } = request4;
      const userAgent = context?.userAgent?.map(escapeUserAgent2) || [];
      const defaultUserAgent2 = (await options.defaultUserAgentProvider()).map(escapeUserAgent2);
      await checkFeatures2(context, options, args);
      const awsContext = context;
      defaultUserAgent2.push(`m/${encodeFeatures2(Object.assign({}, context.__smithy_context?.features, awsContext.__aws_sdk_context?.features))}`);
      const customUserAgent = options?.customUserAgent?.map(escapeUserAgent2) || [];
      const appId = await options.userAgentAppId();
      if (appId) {
        defaultUserAgent2.push(escapeUserAgent2([`app`, `${appId}`]));
      }
      const prefix = utilEndpoints.getUserAgentPrefix();
      const sdkUserAgentValue = (prefix ? [prefix] : []).concat([...defaultUserAgent2, ...userAgent, ...customUserAgent]).join(SPACE2);
      const normalUAValue = [
        ...defaultUserAgent2.filter((section) => section.startsWith("aws-sdk-")),
        ...customUserAgent
      ].join(SPACE2);
      if (options.runtime !== "browser") {
        if (normalUAValue) {
          headers[X_AMZ_USER_AGENT2] = headers[X_AMZ_USER_AGENT2] ? `${headers[USER_AGENT3]} ${normalUAValue}` : normalUAValue;
        }
        headers[USER_AGENT3] = sdkUserAgentValue;
      } else {
        headers[X_AMZ_USER_AGENT2] = sdkUserAgentValue;
      }
      return next({
        ...args,
        request: request4
      });
    }, "userAgentMiddleware");
    var escapeUserAgent2 = /* @__PURE__ */ __name((userAgentPair) => {
      const name = userAgentPair[0].split(UA_NAME_SEPARATOR2).map((part) => part.replace(UA_NAME_ESCAPE_REGEX2, UA_ESCAPE_CHAR2)).join(UA_NAME_SEPARATOR2);
      const version = userAgentPair[1]?.replace(UA_VALUE_ESCAPE_REGEX2, UA_ESCAPE_CHAR2);
      const prefixSeparatorIndex = name.indexOf(UA_NAME_SEPARATOR2);
      const prefix = name.substring(0, prefixSeparatorIndex);
      let uaName = name.substring(prefixSeparatorIndex + 1);
      if (prefix === "api") {
        uaName = uaName.toLowerCase();
      }
      return [prefix, uaName, version].filter((item) => item && item.length > 0).reduce((acc, item, index) => {
        switch (index) {
          case 0:
            return item;
          case 1:
            return `${acc}/${item}`;
          default:
            return `${acc}#${item}`;
        }
      }, "");
    }, "escapeUserAgent");
    var getUserAgentMiddlewareOptions2 = {
      name: "getUserAgentMiddleware",
      step: "build",
      priority: "low",
      tags: ["SET_USER_AGENT", "USER_AGENT"],
      override: true
    };
    var getUserAgentPlugin29 = /* @__PURE__ */ __name((config2) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(userAgentMiddleware2(config2), getUserAgentMiddlewareOptions2);
      }, "applyToStack")
    }), "getUserAgentPlugin");
    exports2.DEFAULT_UA_APP_ID = DEFAULT_UA_APP_ID2;
    exports2.getUserAgentMiddlewareOptions = getUserAgentMiddlewareOptions2;
    exports2.getUserAgentPlugin = getUserAgentPlugin29;
    exports2.resolveUserAgentConfig = resolveUserAgentConfig29;
    exports2.userAgentMiddleware = userAgentMiddleware2;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/middleware-retry/dist-cjs/isStreamingPayload/isStreamingPayload.js
var require_isStreamingPayload4 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/middleware-retry/dist-cjs/isStreamingPayload/isStreamingPayload.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isStreamingPayload = void 0;
    var stream_1 = require("stream");
    var isStreamingPayload3 = /* @__PURE__ */ __name((request4) => request4?.body instanceof stream_1.Readable || typeof ReadableStream !== "undefined" && request4?.body instanceof ReadableStream, "isStreamingPayload");
    exports2.isStreamingPayload = isStreamingPayload3;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/middleware-retry/dist-cjs/index.js
var require_dist_cjs92 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/middleware-retry/dist-cjs/index.js"(exports2) {
    "use strict";
    var utilRetry = require_dist_cjs22();
    var protocolHttp = require_dist_cjs2();
    var serviceErrorClassification = require_dist_cjs32();
    var uuid = require_dist_cjs19();
    var utilMiddleware = require_dist_cjs6();
    var smithyClient = require_dist_cjs34();
    var isStreamingPayload3 = require_isStreamingPayload4();
    var serde = (init_serde(), __toCommonJS(serde_exports));
    var asSdkError3 = /* @__PURE__ */ __name((error4) => {
      if (error4 instanceof Error)
        return error4;
      if (error4 instanceof Object)
        return Object.assign(new Error(), error4);
      if (typeof error4 === "string")
        return new Error(error4);
      return new Error(`AWS SDK error wrapper for ${error4}`);
    }, "asSdkError");
    var getDefaultRetryQuota3 = /* @__PURE__ */ __name((initialRetryTokens, options) => {
      const MAX_CAPACITY = initialRetryTokens;
      const noRetryIncrement = utilRetry.NO_RETRY_INCREMENT;
      const retryCost = utilRetry.RETRY_COST;
      const timeoutRetryCost = utilRetry.TIMEOUT_RETRY_COST;
      let availableCapacity = initialRetryTokens;
      const getCapacityAmount = /* @__PURE__ */ __name((error4) => error4.name === "TimeoutError" ? timeoutRetryCost : retryCost, "getCapacityAmount");
      const hasRetryTokens = /* @__PURE__ */ __name((error4) => getCapacityAmount(error4) <= availableCapacity, "hasRetryTokens");
      const retrieveRetryTokens = /* @__PURE__ */ __name((error4) => {
        if (!hasRetryTokens(error4)) {
          throw new Error("No retry token available");
        }
        const capacityAmount = getCapacityAmount(error4);
        availableCapacity -= capacityAmount;
        return capacityAmount;
      }, "retrieveRetryTokens");
      const releaseRetryTokens = /* @__PURE__ */ __name((capacityReleaseAmount) => {
        availableCapacity += capacityReleaseAmount ?? noRetryIncrement;
        availableCapacity = Math.min(availableCapacity, MAX_CAPACITY);
      }, "releaseRetryTokens");
      return Object.freeze({
        hasRetryTokens,
        retrieveRetryTokens,
        releaseRetryTokens
      });
    }, "getDefaultRetryQuota");
    var defaultDelayDecider3 = /* @__PURE__ */ __name((delayBase, attempts) => Math.floor(Math.min(utilRetry.MAXIMUM_RETRY_DELAY, Math.random() * 2 ** attempts * delayBase)), "defaultDelayDecider");
    var defaultRetryDecider3 = /* @__PURE__ */ __name((error4) => {
      if (!error4) {
        return false;
      }
      return serviceErrorClassification.isRetryableByTrait(error4) || serviceErrorClassification.isClockSkewError(error4) || serviceErrorClassification.isThrottlingError(error4) || serviceErrorClassification.isTransientError(error4);
    }, "defaultRetryDecider");
    var StandardRetryStrategy5 = class {
      static {
        __name(this, "StandardRetryStrategy");
      }
      maxAttemptsProvider;
      retryDecider;
      delayDecider;
      retryQuota;
      mode = utilRetry.RETRY_MODES.STANDARD;
      constructor(maxAttemptsProvider, options) {
        this.maxAttemptsProvider = maxAttemptsProvider;
        this.retryDecider = options?.retryDecider ?? defaultRetryDecider3;
        this.delayDecider = options?.delayDecider ?? defaultDelayDecider3;
        this.retryQuota = options?.retryQuota ?? getDefaultRetryQuota3(utilRetry.INITIAL_RETRY_TOKENS);
      }
      shouldRetry(error4, attempts, maxAttempts) {
        return attempts < maxAttempts && this.retryDecider(error4) && this.retryQuota.hasRetryTokens(error4);
      }
      async getMaxAttempts() {
        let maxAttempts;
        try {
          maxAttempts = await this.maxAttemptsProvider();
        } catch (error4) {
          maxAttempts = utilRetry.DEFAULT_MAX_ATTEMPTS;
        }
        return maxAttempts;
      }
      async retry(next, args, options) {
        let retryTokenAmount;
        let attempts = 0;
        let totalDelay = 0;
        const maxAttempts = await this.getMaxAttempts();
        const { request: request4 } = args;
        if (protocolHttp.HttpRequest.isInstance(request4)) {
          request4.headers[utilRetry.INVOCATION_ID_HEADER] = uuid.v4();
        }
        while (true) {
          try {
            if (protocolHttp.HttpRequest.isInstance(request4)) {
              request4.headers[utilRetry.REQUEST_HEADER] = `attempt=${attempts + 1}; max=${maxAttempts}`;
            }
            if (options?.beforeRequest) {
              await options.beforeRequest();
            }
            const { response, output } = await next(args);
            if (options?.afterRequest) {
              options.afterRequest(response);
            }
            this.retryQuota.releaseRetryTokens(retryTokenAmount);
            output.$metadata.attempts = attempts + 1;
            output.$metadata.totalRetryDelay = totalDelay;
            return { response, output };
          } catch (e32) {
            const err = asSdkError3(e32);
            attempts++;
            if (this.shouldRetry(err, attempts, maxAttempts)) {
              retryTokenAmount = this.retryQuota.retrieveRetryTokens(err);
              const delayFromDecider = this.delayDecider(serviceErrorClassification.isThrottlingError(err) ? utilRetry.THROTTLING_RETRY_DELAY_BASE : utilRetry.DEFAULT_RETRY_DELAY_BASE, attempts);
              const delayFromResponse = getDelayFromRetryAfterHeader3(err.$response);
              const delay = Math.max(delayFromResponse || 0, delayFromDecider);
              totalDelay += delay;
              await new Promise((resolve13) => setTimeout(resolve13, delay));
              continue;
            }
            if (!err.$metadata) {
              err.$metadata = {};
            }
            err.$metadata.attempts = attempts;
            err.$metadata.totalRetryDelay = totalDelay;
            throw err;
          }
        }
      }
    };
    var getDelayFromRetryAfterHeader3 = /* @__PURE__ */ __name((response) => {
      if (!protocolHttp.HttpResponse.isInstance(response))
        return;
      const retryAfterHeaderName = Object.keys(response.headers).find((key) => key.toLowerCase() === "retry-after");
      if (!retryAfterHeaderName)
        return;
      const retryAfter = response.headers[retryAfterHeaderName];
      const retryAfterSeconds = Number(retryAfter);
      if (!Number.isNaN(retryAfterSeconds))
        return retryAfterSeconds * 1e3;
      const retryAfterDate = new Date(retryAfter);
      return retryAfterDate.getTime() - Date.now();
    }, "getDelayFromRetryAfterHeader");
    var AdaptiveRetryStrategy5 = class extends StandardRetryStrategy5 {
      static {
        __name(this, "AdaptiveRetryStrategy");
      }
      rateLimiter;
      constructor(maxAttemptsProvider, options) {
        const { rateLimiter, ...superOptions } = options ?? {};
        super(maxAttemptsProvider, superOptions);
        this.rateLimiter = rateLimiter ?? new utilRetry.DefaultRateLimiter();
        this.mode = utilRetry.RETRY_MODES.ADAPTIVE;
      }
      async retry(next, args) {
        return super.retry(next, args, {
          beforeRequest: /* @__PURE__ */ __name(async () => {
            return this.rateLimiter.getSendToken();
          }, "beforeRequest"),
          afterRequest: /* @__PURE__ */ __name((response) => {
            this.rateLimiter.updateClientSendingRate(response);
          }, "afterRequest")
        });
      }
    };
    var ENV_MAX_ATTEMPTS3 = "AWS_MAX_ATTEMPTS";
    var CONFIG_MAX_ATTEMPTS3 = "max_attempts";
    var NODE_MAX_ATTEMPT_CONFIG_OPTIONS30 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => {
        const value = env3[ENV_MAX_ATTEMPTS3];
        if (!value)
          return void 0;
        const maxAttempt = parseInt(value);
        if (Number.isNaN(maxAttempt)) {
          throw new Error(`Environment variable ${ENV_MAX_ATTEMPTS3} mast be a number, got "${value}"`);
        }
        return maxAttempt;
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => {
        const value = profile[CONFIG_MAX_ATTEMPTS3];
        if (!value)
          return void 0;
        const maxAttempt = parseInt(value);
        if (Number.isNaN(maxAttempt)) {
          throw new Error(`Shared config file entry ${CONFIG_MAX_ATTEMPTS3} mast be a number, got "${value}"`);
        }
        return maxAttempt;
      }, "configFileSelector"),
      default: utilRetry.DEFAULT_MAX_ATTEMPTS
    };
    var resolveRetryConfig30 = /* @__PURE__ */ __name((input) => {
      const { retryStrategy, retryMode } = input;
      const maxAttempts = utilMiddleware.normalizeProvider(input.maxAttempts ?? utilRetry.DEFAULT_MAX_ATTEMPTS);
      let controller = retryStrategy ? Promise.resolve(retryStrategy) : void 0;
      const getDefault = /* @__PURE__ */ __name(async () => await utilMiddleware.normalizeProvider(retryMode)() === utilRetry.RETRY_MODES.ADAPTIVE ? new utilRetry.AdaptiveRetryStrategy(maxAttempts) : new utilRetry.StandardRetryStrategy(maxAttempts), "getDefault");
      return Object.assign(input, {
        maxAttempts,
        retryStrategy: /* @__PURE__ */ __name(() => controller ??= getDefault(), "retryStrategy")
      });
    }, "resolveRetryConfig");
    var ENV_RETRY_MODE3 = "AWS_RETRY_MODE";
    var CONFIG_RETRY_MODE3 = "retry_mode";
    var NODE_RETRY_MODE_CONFIG_OPTIONS30 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[ENV_RETRY_MODE3], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[CONFIG_RETRY_MODE3], "configFileSelector"),
      default: utilRetry.DEFAULT_RETRY_MODE
    };
    var omitRetryHeadersMiddleware3 = /* @__PURE__ */ __name(() => (next) => async (args) => {
      const { request: request4 } = args;
      if (protocolHttp.HttpRequest.isInstance(request4)) {
        delete request4.headers[utilRetry.INVOCATION_ID_HEADER];
        delete request4.headers[utilRetry.REQUEST_HEADER];
      }
      return next(args);
    }, "omitRetryHeadersMiddleware");
    var omitRetryHeadersMiddlewareOptions3 = {
      name: "omitRetryHeadersMiddleware",
      tags: ["RETRY", "HEADERS", "OMIT_RETRY_HEADERS"],
      relation: "before",
      toMiddleware: "awsAuthMiddleware",
      override: true
    };
    var getOmitRetryHeadersPlugin3 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.addRelativeTo(omitRetryHeadersMiddleware3(), omitRetryHeadersMiddlewareOptions3);
      }, "applyToStack")
    }), "getOmitRetryHeadersPlugin");
    function parseRetryAfterHeader3(response, logger5) {
      if (!protocolHttp.HttpResponse.isInstance(response)) {
        return;
      }
      for (const header of Object.keys(response.headers)) {
        const h32 = header.toLowerCase();
        if (h32 === "retry-after") {
          const retryAfter = response.headers[header];
          let retryAfterSeconds = NaN;
          if (retryAfter.endsWith("GMT")) {
            try {
              const date7 = serde.parseRfc7231DateTime(retryAfter);
              retryAfterSeconds = (date7.getTime() - Date.now()) / 1e3;
            } catch (e32) {
              logger5?.trace?.("Failed to parse retry-after header");
              logger5?.trace?.(e32);
            }
          } else if (retryAfter.match(/ GMT, ((\d+)|(\d+\.\d+))$/)) {
            retryAfterSeconds = Number(retryAfter.match(/ GMT, ([\d.]+)$/)?.[1]);
          } else if (retryAfter.match(/^((\d+)|(\d+\.\d+))$/)) {
            retryAfterSeconds = Number(retryAfter);
          } else if (Date.parse(retryAfter) >= Date.now()) {
            retryAfterSeconds = (Date.parse(retryAfter) - Date.now()) / 1e3;
          }
          if (isNaN(retryAfterSeconds)) {
            return;
          }
          return new Date(Date.now() + retryAfterSeconds * 1e3);
        } else if (h32 === "x-amz-retry-after") {
          const v = response.headers[header];
          const backoffMilliseconds = Number(v);
          if (isNaN(backoffMilliseconds)) {
            logger5?.trace?.(`Failed to parse x-amz-retry-after=${v}`);
            return;
          }
          return new Date(Date.now() + backoffMilliseconds);
        }
      }
    }
    __name(parseRetryAfterHeader3, "parseRetryAfterHeader");
    function getRetryAfterHint3(response, logger5) {
      return parseRetryAfterHeader3(response, logger5);
    }
    __name(getRetryAfterHint3, "getRetryAfterHint");
    var retryMiddleware3 = /* @__PURE__ */ __name((options) => (next, context) => async (args) => {
      let retryStrategy = await options.retryStrategy();
      const maxAttempts = await options.maxAttempts();
      if (isRetryStrategyV23(retryStrategy)) {
        retryStrategy = retryStrategy;
        let retryToken = await retryStrategy.acquireInitialRetryToken((context["partition_id"] ?? "") + (context.__retryLongPoll ? ":longpoll" : ""));
        let lastError = new Error();
        let attempts = 0;
        let totalRetryDelay = 0;
        const { request: request4 } = args;
        const isRequest = protocolHttp.HttpRequest.isInstance(request4);
        if (isRequest) {
          request4.headers[utilRetry.INVOCATION_ID_HEADER] = uuid.v4();
        }
        while (true) {
          try {
            if (isRequest) {
              request4.headers[utilRetry.REQUEST_HEADER] = `attempt=${attempts + 1}; max=${maxAttempts}`;
            }
            const { response, output } = await next(args);
            retryStrategy.recordSuccess(retryToken);
            output.$metadata.attempts = attempts + 1;
            output.$metadata.totalRetryDelay = totalRetryDelay;
            return { response, output };
          } catch (e32) {
            const retryErrorInfo = getRetryErrorInfo3(e32, options.logger);
            lastError = asSdkError3(e32);
            if (isRequest && isStreamingPayload3.isStreamingPayload(request4)) {
              (context.logger instanceof smithyClient.NoOpLogger ? console : context.logger)?.warn("An error was encountered in a non-retryable streaming request.");
              throw lastError;
            }
            try {
              retryToken = await retryStrategy.refreshRetryTokenForRetry(retryToken, retryErrorInfo);
            } catch (refreshError) {
              if (typeof refreshError.$backoff === "number") {
                await cooldown3(refreshError.$backoff);
              }
              if (!lastError.$metadata) {
                lastError.$metadata = {};
              }
              lastError.$metadata.attempts = attempts + 1;
              lastError.$metadata.totalRetryDelay = totalRetryDelay;
              throw lastError;
            }
            attempts = retryToken.getRetryCount();
            const delay = retryToken.getRetryDelay();
            totalRetryDelay += delay;
            await cooldown3(delay);
          }
        }
      } else {
        retryStrategy = retryStrategy;
        if (retryStrategy?.mode) {
          context.userAgent = [...context.userAgent || [], ["cfg/retry-mode", retryStrategy.mode]];
        }
        return retryStrategy.retry(next, args);
      }
    }, "retryMiddleware");
    var cooldown3 = /* @__PURE__ */ __name((ms) => new Promise((resolve13) => setTimeout(resolve13, ms)), "cooldown");
    var isRetryStrategyV23 = /* @__PURE__ */ __name((retryStrategy) => typeof retryStrategy.acquireInitialRetryToken !== "undefined" && typeof retryStrategy.refreshRetryTokenForRetry !== "undefined" && typeof retryStrategy.recordSuccess !== "undefined", "isRetryStrategyV2");
    var getRetryErrorInfo3 = /* @__PURE__ */ __name((error4, logger5) => {
      const errorInfo = {
        error: error4,
        errorType: getRetryErrorType3(error4)
      };
      const retryAfterHint = parseRetryAfterHeader3(error4.$response, logger5);
      if (retryAfterHint) {
        errorInfo.retryAfterHint = retryAfterHint;
      }
      return errorInfo;
    }, "getRetryErrorInfo");
    var getRetryErrorType3 = /* @__PURE__ */ __name((error4) => {
      if (serviceErrorClassification.isThrottlingError(error4))
        return "THROTTLING";
      if (serviceErrorClassification.isTransientError(error4))
        return "TRANSIENT";
      if (serviceErrorClassification.isServerError(error4))
        return "SERVER_ERROR";
      return "CLIENT_ERROR";
    }, "getRetryErrorType");
    var retryMiddlewareOptions3 = {
      name: "retryMiddleware",
      tags: ["RETRY"],
      step: "finalizeRequest",
      priority: "high",
      override: true
    };
    var getRetryPlugin30 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(retryMiddleware3(options), retryMiddlewareOptions3);
      }, "applyToStack")
    }), "getRetryPlugin");
    exports2.AdaptiveRetryStrategy = AdaptiveRetryStrategy5;
    exports2.CONFIG_MAX_ATTEMPTS = CONFIG_MAX_ATTEMPTS3;
    exports2.CONFIG_RETRY_MODE = CONFIG_RETRY_MODE3;
    exports2.ENV_MAX_ATTEMPTS = ENV_MAX_ATTEMPTS3;
    exports2.ENV_RETRY_MODE = ENV_RETRY_MODE3;
    exports2.NODE_MAX_ATTEMPT_CONFIG_OPTIONS = NODE_MAX_ATTEMPT_CONFIG_OPTIONS30;
    exports2.NODE_RETRY_MODE_CONFIG_OPTIONS = NODE_RETRY_MODE_CONFIG_OPTIONS30;
    exports2.StandardRetryStrategy = StandardRetryStrategy5;
    exports2.defaultDelayDecider = defaultDelayDecider3;
    exports2.defaultRetryDecider = defaultRetryDecider3;
    exports2.getOmitRetryHeadersPlugin = getOmitRetryHeadersPlugin3;
    exports2.getRetryAfterHint = getRetryAfterHint3;
    exports2.getRetryPlugin = getRetryPlugin30;
    exports2.omitRetryHeadersMiddleware = omitRetryHeadersMiddleware3;
    exports2.omitRetryHeadersMiddlewareOptions = omitRetryHeadersMiddlewareOptions3;
    exports2.resolveRetryConfig = resolveRetryConfig30;
    exports2.retryMiddleware = retryMiddleware3;
    exports2.retryMiddlewareOptions = retryMiddlewareOptions3;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getDateHeader.js
var import_protocol_http25, getDateHeader4;
var init_getDateHeader4 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getDateHeader.js"() {
    import_protocol_http25 = __toESM(require_dist_cjs2());
    getDateHeader4 = /* @__PURE__ */ __name((response) => import_protocol_http25.HttpResponse.isInstance(response) ? response.headers?.date ?? response.headers?.Date : void 0, "getDateHeader");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getSkewCorrectedDate.js
var getSkewCorrectedDate4;
var init_getSkewCorrectedDate4 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getSkewCorrectedDate.js"() {
    getSkewCorrectedDate4 = /* @__PURE__ */ __name((systemClockOffset) => new Date(Date.now() + systemClockOffset), "getSkewCorrectedDate");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/isClockSkewed.js
var isClockSkewed4;
var init_isClockSkewed4 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/isClockSkewed.js"() {
    init_getSkewCorrectedDate4();
    isClockSkewed4 = /* @__PURE__ */ __name((clockTime, systemClockOffset) => Math.abs(getSkewCorrectedDate4(systemClockOffset).getTime() - clockTime) >= 3e5, "isClockSkewed");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getUpdatedSystemClockOffset.js
var getUpdatedSystemClockOffset4;
var init_getUpdatedSystemClockOffset4 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getUpdatedSystemClockOffset.js"() {
    init_isClockSkewed4();
    getUpdatedSystemClockOffset4 = /* @__PURE__ */ __name((clockTime, currentSystemClockOffset) => {
      const clockTimeInMs = Date.parse(clockTime);
      if (isClockSkewed4(clockTimeInMs, currentSystemClockOffset)) {
        return clockTimeInMs - Date.now();
      }
      return currentSystemClockOffset;
    }, "getUpdatedSystemClockOffset");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/index.js
var init_utils4 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/index.js"() {
    init_getDateHeader4();
    init_getSkewCorrectedDate4();
    init_getUpdatedSystemClockOffset4();
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4Signer.js
var import_protocol_http26, throwSigningPropertyError4, validateSigningProperties4, AwsSdkSigV4Signer4, AWSSDKSigV4Signer4;
var init_AwsSdkSigV4Signer4 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4Signer.js"() {
    import_protocol_http26 = __toESM(require_dist_cjs2());
    init_utils4();
    throwSigningPropertyError4 = /* @__PURE__ */ __name((name, property) => {
      if (!property) {
        throw new Error(`Property \`${name}\` is not resolved for AWS SDK SigV4Auth`);
      }
      return property;
    }, "throwSigningPropertyError");
    validateSigningProperties4 = /* @__PURE__ */ __name(async (signingProperties) => {
      const context = throwSigningPropertyError4("context", signingProperties.context);
      const config2 = throwSigningPropertyError4("config", signingProperties.config);
      const authScheme = context.endpointV2?.properties?.authSchemes?.[0];
      const signerFunction = throwSigningPropertyError4("signer", config2.signer);
      const signer = await signerFunction(authScheme);
      const signingRegion = signingProperties?.signingRegion;
      const signingRegionSet = signingProperties?.signingRegionSet;
      const signingName = signingProperties?.signingName;
      return {
        config: config2,
        signer,
        signingRegion,
        signingRegionSet,
        signingName
      };
    }, "validateSigningProperties");
    AwsSdkSigV4Signer4 = class {
      static {
        __name(this, "AwsSdkSigV4Signer");
      }
      async sign(httpRequest, identity, signingProperties) {
        if (!import_protocol_http26.HttpRequest.isInstance(httpRequest)) {
          throw new Error("The request is not an instance of `HttpRequest` and cannot be signed");
        }
        const validatedProps = await validateSigningProperties4(signingProperties);
        const { config: config2, signer } = validatedProps;
        let { signingRegion, signingName } = validatedProps;
        const handlerExecutionContext = signingProperties.context;
        if (handlerExecutionContext?.authSchemes?.length ?? 0 > 1) {
          const [first, second] = handlerExecutionContext.authSchemes;
          if (first?.name === "sigv4a" && second?.name === "sigv4") {
            signingRegion = second?.signingRegion ?? signingRegion;
            signingName = second?.signingName ?? signingName;
          }
        }
        const signedRequest = await signer.sign(httpRequest, {
          signingDate: getSkewCorrectedDate4(config2.systemClockOffset),
          signingRegion,
          signingService: signingName
        });
        return signedRequest;
      }
      errorHandler(signingProperties) {
        return (error4) => {
          const serverTime = error4.ServerTime ?? getDateHeader4(error4.$response);
          if (serverTime) {
            const config2 = throwSigningPropertyError4("config", signingProperties.config);
            const initialSystemClockOffset = config2.systemClockOffset;
            config2.systemClockOffset = getUpdatedSystemClockOffset4(serverTime, config2.systemClockOffset);
            const clockSkewCorrected = config2.systemClockOffset !== initialSystemClockOffset;
            if (clockSkewCorrected && error4.$metadata) {
              error4.$metadata.clockSkewCorrected = true;
            }
          }
          throw error4;
        };
      }
      successHandler(httpResponse, signingProperties) {
        const dateHeader = getDateHeader4(httpResponse);
        if (dateHeader) {
          const config2 = throwSigningPropertyError4("config", signingProperties.config);
          config2.systemClockOffset = getUpdatedSystemClockOffset4(dateHeader, config2.systemClockOffset);
        }
      }
    };
    AWSSDKSigV4Signer4 = AwsSdkSigV4Signer4;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4ASigner.js
var import_protocol_http27, AwsSdkSigV4ASigner4;
var init_AwsSdkSigV4ASigner4 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4ASigner.js"() {
    import_protocol_http27 = __toESM(require_dist_cjs2());
    init_utils4();
    init_AwsSdkSigV4Signer4();
    AwsSdkSigV4ASigner4 = class extends AwsSdkSigV4Signer4 {
      static {
        __name(this, "AwsSdkSigV4ASigner");
      }
      async sign(httpRequest, identity, signingProperties) {
        if (!import_protocol_http27.HttpRequest.isInstance(httpRequest)) {
          throw new Error("The request is not an instance of `HttpRequest` and cannot be signed");
        }
        const { config: config2, signer, signingRegion, signingRegionSet, signingName } = await validateSigningProperties4(signingProperties);
        const configResolvedSigningRegionSet = await config2.sigv4aSigningRegionSet?.();
        const multiRegionOverride = (configResolvedSigningRegionSet ?? signingRegionSet ?? [signingRegion]).join(",");
        const signedRequest = await signer.sign(httpRequest, {
          signingDate: getSkewCorrectedDate4(config2.systemClockOffset),
          signingRegion: multiRegionOverride,
          signingService: signingName
        });
        return signedRequest;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getArrayForCommaSeparatedString.js
var getArrayForCommaSeparatedString4;
var init_getArrayForCommaSeparatedString4 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getArrayForCommaSeparatedString.js"() {
    getArrayForCommaSeparatedString4 = /* @__PURE__ */ __name((str) => typeof str === "string" && str.length > 0 ? str.split(",").map((item) => item.trim()) : [], "getArrayForCommaSeparatedString");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getBearerTokenEnvKey.js
var getBearerTokenEnvKey4;
var init_getBearerTokenEnvKey4 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getBearerTokenEnvKey.js"() {
    getBearerTokenEnvKey4 = /* @__PURE__ */ __name((signingName) => `AWS_BEARER_TOKEN_${signingName.replace(/[\s-]/g, "_").toUpperCase()}`, "getBearerTokenEnvKey");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/NODE_AUTH_SCHEME_PREFERENCE_OPTIONS.js
var NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY4, NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY4, NODE_AUTH_SCHEME_PREFERENCE_OPTIONS4;
var init_NODE_AUTH_SCHEME_PREFERENCE_OPTIONS4 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/NODE_AUTH_SCHEME_PREFERENCE_OPTIONS.js"() {
    init_getArrayForCommaSeparatedString4();
    init_getBearerTokenEnvKey4();
    NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY4 = "AWS_AUTH_SCHEME_PREFERENCE";
    NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY4 = "auth_scheme_preference";
    NODE_AUTH_SCHEME_PREFERENCE_OPTIONS4 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3, options) => {
        if (options?.signingName) {
          const bearerTokenKey = getBearerTokenEnvKey4(options.signingName);
          if (bearerTokenKey in env3)
            return ["httpBearerAuth"];
        }
        if (!(NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY4 in env3))
          return void 0;
        return getArrayForCommaSeparatedString4(env3[NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY4]);
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => {
        if (!(NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY4 in profile))
          return void 0;
        return getArrayForCommaSeparatedString4(profile[NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY4]);
      }, "configFileSelector"),
      default: []
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4AConfig.js
var import_property_provider4, resolveAwsSdkSigV4AConfig4, NODE_SIGV4A_CONFIG_OPTIONS4;
var init_resolveAwsSdkSigV4AConfig4 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4AConfig.js"() {
    init_dist_es();
    import_property_provider4 = __toESM(require_dist_cjs27());
    resolveAwsSdkSigV4AConfig4 = /* @__PURE__ */ __name((config2) => {
      config2.sigv4aSigningRegionSet = normalizeProvider(config2.sigv4aSigningRegionSet);
      return config2;
    }, "resolveAwsSdkSigV4AConfig");
    NODE_SIGV4A_CONFIG_OPTIONS4 = {
      environmentVariableSelector(env3) {
        if (env3.AWS_SIGV4A_SIGNING_REGION_SET) {
          return env3.AWS_SIGV4A_SIGNING_REGION_SET.split(",").map((_) => _.trim());
        }
        throw new import_property_provider4.ProviderError("AWS_SIGV4A_SIGNING_REGION_SET not set in env.", {
          tryNextLink: true
        });
      },
      configFileSelector(profile) {
        if (profile.sigv4a_signing_region_set) {
          return (profile.sigv4a_signing_region_set ?? "").split(",").map((_) => _.trim());
        }
        throw new import_property_provider4.ProviderError("sigv4a_signing_region_set not set in profile.", {
          tryNextLink: true
        });
      },
      default: void 0
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4Config.js
function normalizeCredentialProvider4(config2, { credentials, credentialDefaultProvider }) {
  let credentialsProvider;
  if (credentials) {
    if (!credentials?.memoized) {
      credentialsProvider = memoizeIdentityProvider(credentials, isIdentityExpired, doesIdentityRequireRefresh);
    } else {
      credentialsProvider = credentials;
    }
  } else {
    if (credentialDefaultProvider) {
      credentialsProvider = normalizeProvider(credentialDefaultProvider(Object.assign({}, config2, {
        parentClientConfig: config2
      })));
    } else {
      credentialsProvider = /* @__PURE__ */ __name(async () => {
        throw new Error("@aws-sdk/core::resolveAwsSdkSigV4Config - `credentials` not provided and no credentialDefaultProvider was configured.");
      }, "credentialsProvider");
    }
  }
  credentialsProvider.memoized = true;
  return credentialsProvider;
}
function bindCallerConfig4(config2, credentialsProvider) {
  if (credentialsProvider.configBound) {
    return credentialsProvider;
  }
  const fn = /* @__PURE__ */ __name(async (options) => credentialsProvider({ ...options, callerClientConfig: config2 }), "fn");
  fn.memoized = credentialsProvider.memoized;
  fn.configBound = true;
  return fn;
}
var import_signature_v44, resolveAwsSdkSigV4Config4, resolveAWSSDKSigV4Config4;
var init_resolveAwsSdkSigV4Config4 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4Config.js"() {
    init_client7();
    init_dist_es();
    import_signature_v44 = __toESM(require_dist_cjs36());
    resolveAwsSdkSigV4Config4 = /* @__PURE__ */ __name((config2) => {
      let inputCredentials = config2.credentials;
      let isUserSupplied = !!config2.credentials;
      let resolvedCredentials = void 0;
      Object.defineProperty(config2, "credentials", {
        set(credentials) {
          if (credentials && credentials !== inputCredentials && credentials !== resolvedCredentials) {
            isUserSupplied = true;
          }
          inputCredentials = credentials;
          const memoizedProvider = normalizeCredentialProvider4(config2, {
            credentials: inputCredentials,
            credentialDefaultProvider: config2.credentialDefaultProvider
          });
          const boundProvider = bindCallerConfig4(config2, memoizedProvider);
          if (isUserSupplied && !boundProvider.attributed) {
            const isCredentialObject = typeof inputCredentials === "object" && inputCredentials !== null;
            resolvedCredentials = /* @__PURE__ */ __name(async (options) => {
              const creds = await boundProvider(options);
              const attributedCreds = creds;
              if (isCredentialObject && (!attributedCreds.$source || Object.keys(attributedCreds.$source).length === 0)) {
                return setCredentialFeature6(attributedCreds, "CREDENTIALS_CODE", "e");
              }
              return attributedCreds;
            }, "resolvedCredentials");
            resolvedCredentials.memoized = boundProvider.memoized;
            resolvedCredentials.configBound = boundProvider.configBound;
            resolvedCredentials.attributed = true;
          } else {
            resolvedCredentials = boundProvider;
          }
        },
        get() {
          return resolvedCredentials;
        },
        enumerable: true,
        configurable: true
      });
      config2.credentials = inputCredentials;
      const { signingEscapePath = true, systemClockOffset = config2.systemClockOffset || 0, sha256 } = config2;
      let signer;
      if (config2.signer) {
        signer = normalizeProvider(config2.signer);
      } else if (config2.regionInfoProvider) {
        signer = /* @__PURE__ */ __name(() => normalizeProvider(config2.region)().then(async (region) => [
          await config2.regionInfoProvider(region, {
            useFipsEndpoint: await config2.useFipsEndpoint(),
            useDualstackEndpoint: await config2.useDualstackEndpoint()
          }) || {},
          region
        ]).then(([regionInfo, region]) => {
          const { signingRegion, signingService } = regionInfo;
          config2.signingRegion = config2.signingRegion || signingRegion || region;
          config2.signingName = config2.signingName || signingService || config2.serviceId;
          const params = {
            ...config2,
            credentials: config2.credentials,
            region: config2.signingRegion,
            service: config2.signingName,
            sha256,
            uriEscapePath: signingEscapePath
          };
          const SignerCtor = config2.signerConstructor || import_signature_v44.SignatureV4;
          return new SignerCtor(params);
        }), "signer");
      } else {
        signer = /* @__PURE__ */ __name(async (authScheme) => {
          authScheme = Object.assign({}, {
            name: "sigv4",
            signingName: config2.signingName || config2.defaultSigningName,
            signingRegion: await normalizeProvider(config2.region)(),
            properties: {}
          }, authScheme);
          const signingRegion = authScheme.signingRegion;
          const signingService = authScheme.signingName;
          config2.signingRegion = config2.signingRegion || signingRegion;
          config2.signingName = config2.signingName || signingService || config2.serviceId;
          const params = {
            ...config2,
            credentials: config2.credentials,
            region: config2.signingRegion,
            service: config2.signingName,
            sha256,
            uriEscapePath: signingEscapePath
          };
          const SignerCtor = config2.signerConstructor || import_signature_v44.SignatureV4;
          return new SignerCtor(params);
        }, "signer");
      }
      const resolvedConfig = Object.assign(config2, {
        systemClockOffset,
        signingEscapePath,
        signer
      });
      return resolvedConfig;
    }, "resolveAwsSdkSigV4Config");
    resolveAWSSDKSigV4Config4 = resolveAwsSdkSigV4Config4;
    __name(normalizeCredentialProvider4, "normalizeCredentialProvider");
    __name(bindCallerConfig4, "bindCallerConfig");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/index.js
var init_aws_sdk4 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/index.js"() {
    init_AwsSdkSigV4Signer4();
    init_AwsSdkSigV4ASigner4();
    init_NODE_AUTH_SCHEME_PREFERENCE_OPTIONS4();
    init_resolveAwsSdkSigV4AConfig4();
    init_resolveAwsSdkSigV4Config4();
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/index.js
var httpAuthSchemes_exports4 = {};
__export(httpAuthSchemes_exports4, {
  AWSSDKSigV4Signer: () => AWSSDKSigV4Signer4,
  AwsSdkSigV4ASigner: () => AwsSdkSigV4ASigner4,
  AwsSdkSigV4Signer: () => AwsSdkSigV4Signer4,
  NODE_AUTH_SCHEME_PREFERENCE_OPTIONS: () => NODE_AUTH_SCHEME_PREFERENCE_OPTIONS4,
  NODE_SIGV4A_CONFIG_OPTIONS: () => NODE_SIGV4A_CONFIG_OPTIONS4,
  getBearerTokenEnvKey: () => getBearerTokenEnvKey4,
  resolveAWSSDKSigV4Config: () => resolveAWSSDKSigV4Config4,
  resolveAwsSdkSigV4AConfig: () => resolveAwsSdkSigV4AConfig4,
  resolveAwsSdkSigV4Config: () => resolveAwsSdkSigV4Config4,
  validateSigningProperties: () => validateSigningProperties4
});
var init_httpAuthSchemes5 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/index.js"() {
    init_aws_sdk4();
    init_getBearerTokenEnvKey4();
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/dist-cjs/auth/httpAuthSchemeProvider.js
var require_httpAuthSchemeProvider3 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/dist-cjs/auth/httpAuthSchemeProvider.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.resolveHttpAuthSchemeConfig = exports2.defaultSecretsManagerHttpAuthSchemeProvider = exports2.defaultSecretsManagerHttpAuthSchemeParametersProvider = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes5(), __toCommonJS(httpAuthSchemes_exports4));
    var util_middleware_1 = require_dist_cjs6();
    var defaultSecretsManagerHttpAuthSchemeParametersProvider = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, util_middleware_1.getSmithyContext)(context).operation,
        region: await (0, util_middleware_1.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultSecretsManagerHttpAuthSchemeParametersProvider");
    exports2.defaultSecretsManagerHttpAuthSchemeParametersProvider = defaultSecretsManagerHttpAuthSchemeParametersProvider;
    function createAwsAuthSigv4HttpAuthOption32(authParameters) {
      return {
        schemeId: "aws.auth#sigv4",
        signingProperties: {
          name: "secretsmanager",
          region: authParameters.region
        },
        propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
          signingProperties: {
            config: config2,
            context
          }
        }), "propertiesExtractor")
      };
    }
    __name(createAwsAuthSigv4HttpAuthOption32, "createAwsAuthSigv4HttpAuthOption");
    var defaultSecretsManagerHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption32(authParameters));
        }
      }
      return options;
    }, "defaultSecretsManagerHttpAuthSchemeProvider");
    exports2.defaultSecretsManagerHttpAuthSchemeProvider = defaultSecretsManagerHttpAuthSchemeProvider;
    var resolveHttpAuthSchemeConfig32 = /* @__PURE__ */ __name((config2) => {
      const config_0 = (0, httpAuthSchemes_1.resolveAwsSdkSigV4Config)(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, util_middleware_1.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
    exports2.resolveHttpAuthSchemeConfig = resolveHttpAuthSchemeConfig32;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/package.json
var require_package3 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/package.json"(exports2, module2) {
    module2.exports = {
      name: "@aws-sdk/client-secrets-manager",
      description: "AWS SDK for JavaScript Secrets Manager Client for Node.js, Browser and React Native",
      version: "3.1045.0",
      scripts: {
        build: "concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline client-secrets-manager",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        "extract:docs": "api-extractor run --local",
        "generate:client": "node ../../scripts/generate-clients/single-service --solo secrets-manager",
        test: "yarn g:vitest run --passWithNoTests",
        "test:index": "tsc --noEmit ./test/index-types.ts && node ./test/index-objects.spec.mjs",
        "test:integration": "yarn g:vitest run --passWithNoTests -c vitest.config.integ.mts",
        "test:integration:watch": "yarn g:vitest run --passWithNoTests -c vitest.config.integ.mts",
        "test:watch": "yarn g:vitest watch --passWithNoTests"
      },
      main: "./dist-cjs/index.js",
      types: "./dist-types/index.d.ts",
      module: "./dist-es/index.js",
      sideEffects: false,
      dependencies: {
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.8",
        "@aws-sdk/credential-provider-node": "^3.972.39",
        "@aws-sdk/middleware-host-header": "^3.972.10",
        "@aws-sdk/middleware-logger": "^3.972.10",
        "@aws-sdk/middleware-recursion-detection": "^3.972.11",
        "@aws-sdk/middleware-user-agent": "^3.972.38",
        "@aws-sdk/region-config-resolver": "^3.972.13",
        "@aws-sdk/types": "^3.973.8",
        "@aws-sdk/util-endpoints": "^3.996.8",
        "@aws-sdk/util-user-agent-browser": "^3.972.10",
        "@aws-sdk/util-user-agent-node": "^3.973.24",
        "@smithy/config-resolver": "^4.4.17",
        "@smithy/core": "^3.23.17",
        "@smithy/fetch-http-handler": "^5.3.17",
        "@smithy/hash-node": "^4.2.14",
        "@smithy/invalid-dependency": "^4.2.14",
        "@smithy/middleware-content-length": "^4.2.14",
        "@smithy/middleware-endpoint": "^4.4.32",
        "@smithy/middleware-retry": "^4.5.7",
        "@smithy/middleware-serde": "^4.2.20",
        "@smithy/middleware-stack": "^4.2.14",
        "@smithy/node-config-provider": "^4.3.14",
        "@smithy/node-http-handler": "^4.6.1",
        "@smithy/protocol-http": "^5.3.14",
        "@smithy/smithy-client": "^4.12.13",
        "@smithy/types": "^4.14.1",
        "@smithy/url-parser": "^4.2.14",
        "@smithy/util-base64": "^4.3.2",
        "@smithy/util-body-length-browser": "^4.2.2",
        "@smithy/util-body-length-node": "^4.2.3",
        "@smithy/util-defaults-mode-browser": "^4.3.49",
        "@smithy/util-defaults-mode-node": "^4.2.54",
        "@smithy/util-endpoints": "^3.4.2",
        "@smithy/util-middleware": "^4.2.14",
        "@smithy/util-retry": "^4.3.6",
        "@smithy/util-utf8": "^4.2.2",
        tslib: "^2.6.2"
      },
      devDependencies: {
        "@smithy/snapshot-testing": "^2.0.8",
        "@tsconfig/node20": "20.1.8",
        "@types/node": "^20.14.8",
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3",
        vitest: "^4.0.17"
      },
      engines: {
        node: ">=20.0.0"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "dist-*/**"
      ],
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      browser: {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.browser"
      },
      "react-native": {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.native"
      },
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/clients/client-secrets-manager",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "clients/client-secrets-manager"
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-env/dist-cjs/index.js
var require_dist_cjs93 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-env/dist-cjs/index.js"(exports2) {
    "use strict";
    var client = (init_client7(), __toCommonJS(client_exports6));
    var propertyProvider = require_dist_cjs27();
    var ENV_KEY = "AWS_ACCESS_KEY_ID";
    var ENV_SECRET = "AWS_SECRET_ACCESS_KEY";
    var ENV_SESSION = "AWS_SESSION_TOKEN";
    var ENV_EXPIRATION = "AWS_CREDENTIAL_EXPIRATION";
    var ENV_CREDENTIAL_SCOPE = "AWS_CREDENTIAL_SCOPE";
    var ENV_ACCOUNT_ID = "AWS_ACCOUNT_ID";
    var fromEnv6 = /* @__PURE__ */ __name((init) => async () => {
      init?.logger?.debug("@aws-sdk/credential-provider-env - fromEnv");
      const accessKeyId = process.env[ENV_KEY];
      const secretAccessKey = process.env[ENV_SECRET];
      const sessionToken = process.env[ENV_SESSION];
      const expiry = process.env[ENV_EXPIRATION];
      const credentialScope = process.env[ENV_CREDENTIAL_SCOPE];
      const accountId = process.env[ENV_ACCOUNT_ID];
      if (accessKeyId && secretAccessKey) {
        const credentials = {
          accessKeyId,
          secretAccessKey,
          ...sessionToken && { sessionToken },
          ...expiry && { expiration: new Date(expiry) },
          ...credentialScope && { credentialScope },
          ...accountId && { accountId }
        };
        client.setCredentialFeature(credentials, "CREDENTIALS_ENV_VARS", "g");
        return credentials;
      }
      throw new propertyProvider.CredentialsProviderError("Unable to find environment variable credentials.", { logger: init?.logger });
    }, "fromEnv");
    exports2.ENV_ACCOUNT_ID = ENV_ACCOUNT_ID;
    exports2.ENV_CREDENTIAL_SCOPE = ENV_CREDENTIAL_SCOPE;
    exports2.ENV_EXPIRATION = ENV_EXPIRATION;
    exports2.ENV_KEY = ENV_KEY;
    exports2.ENV_SECRET = ENV_SECRET;
    exports2.ENV_SESSION = ENV_SESSION;
    exports2.fromEnv = fromEnv6;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/checkUrl.js
var require_checkUrl3 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/checkUrl.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.checkUrl = void 0;
    var property_provider_1 = require_dist_cjs27();
    var ECS_CONTAINER_HOST = "169.254.170.2";
    var EKS_CONTAINER_HOST_IPv4 = "169.254.170.23";
    var EKS_CONTAINER_HOST_IPv6 = "[fd00:ec2::23]";
    var checkUrl = /* @__PURE__ */ __name((url, logger5) => {
      if (url.protocol === "https:") {
        return;
      }
      if (url.hostname === ECS_CONTAINER_HOST || url.hostname === EKS_CONTAINER_HOST_IPv4 || url.hostname === EKS_CONTAINER_HOST_IPv6) {
        return;
      }
      if (url.hostname.includes("[")) {
        if (url.hostname === "[::1]" || url.hostname === "[0000:0000:0000:0000:0000:0000:0000:0001]") {
          return;
        }
      } else {
        if (url.hostname === "localhost") {
          return;
        }
        const ipComponents = url.hostname.split(".");
        const inRange = /* @__PURE__ */ __name((component) => {
          const num = parseInt(component, 10);
          return 0 <= num && num <= 255;
        }, "inRange");
        if (ipComponents[0] === "127" && inRange(ipComponents[1]) && inRange(ipComponents[2]) && inRange(ipComponents[3]) && ipComponents.length === 4) {
          return;
        }
      }
      throw new property_provider_1.CredentialsProviderError(`URL not accepted. It must either be HTTPS or match one of the following:
  - loopback CIDR 127.0.0.0/8 or [::1/128]
  - ECS container host 169.254.170.2
  - EKS container host 169.254.170.23 or [fd00:ec2::23]`, { logger: logger5 });
    }, "checkUrl");
    exports2.checkUrl = checkUrl;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.js
var require_ChecksumStream5 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ChecksumStream = void 0;
    var util_base64_1 = require_dist_cjs10();
    var stream_1 = require("stream");
    var ChecksumStream5 = class extends stream_1.Duplex {
      static {
        __name(this, "ChecksumStream");
      }
      expectedChecksum;
      checksumSourceLocation;
      checksum;
      source;
      base64Encoder;
      pendingCallback = null;
      constructor({ expectedChecksum, checksum, source, checksumSourceLocation, base64Encoder }) {
        super();
        if (typeof source.pipe === "function") {
          this.source = source;
        } else {
          throw new Error(`@smithy/util-stream: unsupported source type ${source?.constructor?.name ?? source} in ChecksumStream.`);
        }
        this.base64Encoder = base64Encoder ?? util_base64_1.toBase64;
        this.expectedChecksum = expectedChecksum;
        this.checksum = checksum;
        this.checksumSourceLocation = checksumSourceLocation;
        this.source.pipe(this);
      }
      _read(size) {
        if (this.pendingCallback) {
          const callback = this.pendingCallback;
          this.pendingCallback = null;
          callback();
        }
      }
      _write(chunk, encoding, callback) {
        try {
          this.checksum.update(chunk);
          const canPushMore = this.push(chunk);
          if (!canPushMore) {
            this.pendingCallback = callback;
            return;
          }
        } catch (e32) {
          return callback(e32);
        }
        return callback();
      }
      async _final(callback) {
        try {
          const digest = await this.checksum.digest();
          const received = this.base64Encoder(digest);
          if (this.expectedChecksum !== received) {
            return callback(new Error(`Checksum mismatch: expected "${this.expectedChecksum}" but received "${received}" in response header "${this.checksumSourceLocation}".`));
          }
        } catch (e32) {
          return callback(e32);
        }
        this.push(null);
        return callback();
      }
    };
    exports2.ChecksumStream = ChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/stream-type-check.js
var require_stream_type_check5 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/stream-type-check.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isBlob = exports2.isReadableStream = void 0;
    var isReadableStream6 = /* @__PURE__ */ __name((stream) => typeof ReadableStream === "function" && (stream?.constructor?.name === ReadableStream.name || stream instanceof ReadableStream), "isReadableStream");
    exports2.isReadableStream = isReadableStream6;
    var isBlob3 = /* @__PURE__ */ __name((blob) => {
      return typeof Blob === "function" && (blob?.constructor?.name === Blob.name || blob instanceof Blob);
    }, "isBlob");
    exports2.isBlob = isBlob3;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.browser.js
var require_ChecksumStream_browser5 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ChecksumStream = void 0;
    var ReadableStreamRef3 = typeof ReadableStream === "function" ? ReadableStream : function() {
    };
    var ChecksumStream5 = class extends ReadableStreamRef3 {
      static {
        __name(this, "ChecksumStream");
      }
    };
    exports2.ChecksumStream = ChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.browser.js
var require_createChecksumStream_browser5 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createChecksumStream = void 0;
    var util_base64_1 = require_dist_cjs10();
    var stream_type_check_1 = require_stream_type_check5();
    var ChecksumStream_browser_1 = require_ChecksumStream_browser5();
    var createChecksumStream5 = /* @__PURE__ */ __name(({ expectedChecksum, checksum, source, checksumSourceLocation, base64Encoder }) => {
      if (!(0, stream_type_check_1.isReadableStream)(source)) {
        throw new Error(`@smithy/util-stream: unsupported source type ${source?.constructor?.name ?? source} in ChecksumStream.`);
      }
      const encoder = base64Encoder ?? util_base64_1.toBase64;
      if (typeof TransformStream !== "function") {
        throw new Error("@smithy/util-stream: unable to instantiate ChecksumStream because API unavailable: ReadableStream/TransformStream.");
      }
      const transform = new TransformStream({
        start() {
        },
        async transform(chunk, controller) {
          checksum.update(chunk);
          controller.enqueue(chunk);
        },
        async flush(controller) {
          const digest = await checksum.digest();
          const received = encoder(digest);
          if (expectedChecksum !== received) {
            const error4 = new Error(`Checksum mismatch: expected "${expectedChecksum}" but received "${received}" in response header "${checksumSourceLocation}".`);
            controller.error(error4);
          } else {
            controller.terminate();
          }
        }
      });
      source.pipeThrough(transform);
      const readable = transform.readable;
      Object.setPrototypeOf(readable, ChecksumStream_browser_1.ChecksumStream.prototype);
      return readable;
    }, "createChecksumStream");
    exports2.createChecksumStream = createChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.js
var require_createChecksumStream5 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createChecksumStream = createChecksumStream5;
    var stream_type_check_1 = require_stream_type_check5();
    var ChecksumStream_1 = require_ChecksumStream5();
    var createChecksumStream_browser_1 = require_createChecksumStream_browser5();
    function createChecksumStream5(init) {
      if (typeof ReadableStream === "function" && (0, stream_type_check_1.isReadableStream)(init.source)) {
        return (0, createChecksumStream_browser_1.createChecksumStream)(init);
      }
      return new ChecksumStream_1.ChecksumStream(init);
    }
    __name(createChecksumStream5, "createChecksumStream");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/ByteArrayCollector.js
var require_ByteArrayCollector5 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/ByteArrayCollector.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ByteArrayCollector = void 0;
    var ByteArrayCollector3 = class {
      static {
        __name(this, "ByteArrayCollector");
      }
      allocByteArray;
      byteLength = 0;
      byteArrays = [];
      constructor(allocByteArray) {
        this.allocByteArray = allocByteArray;
      }
      push(byteArray) {
        this.byteArrays.push(byteArray);
        this.byteLength += byteArray.byteLength;
      }
      flush() {
        if (this.byteArrays.length === 1) {
          const bytes = this.byteArrays[0];
          this.reset();
          return bytes;
        }
        const aggregation = this.allocByteArray(this.byteLength);
        let cursor3 = 0;
        for (let i32 = 0; i32 < this.byteArrays.length; ++i32) {
          const bytes = this.byteArrays[i32];
          aggregation.set(bytes, cursor3);
          cursor3 += bytes.byteLength;
        }
        this.reset();
        return aggregation;
      }
      reset() {
        this.byteArrays = [];
        this.byteLength = 0;
      }
    };
    exports2.ByteArrayCollector = ByteArrayCollector3;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadableStream.js
var require_createBufferedReadableStream5 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadableStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createBufferedReadable = void 0;
    exports2.createBufferedReadableStream = createBufferedReadableStream3;
    exports2.merge = merge3;
    exports2.flush = flush3;
    exports2.sizeOf = sizeOf3;
    exports2.modeOf = modeOf3;
    var ByteArrayCollector_1 = require_ByteArrayCollector5();
    function createBufferedReadableStream3(upstream, size, logger5) {
      const reader = upstream.getReader();
      let streamBufferingLoggedWarning = false;
      let bytesSeen = 0;
      const buffers = ["", new ByteArrayCollector_1.ByteArrayCollector((size2) => new Uint8Array(size2))];
      let mode = -1;
      const pull = /* @__PURE__ */ __name(async (controller) => {
        const { value, done } = await reader.read();
        const chunk = value;
        if (done) {
          if (mode !== -1) {
            const remainder = flush3(buffers, mode);
            if (sizeOf3(remainder) > 0) {
              controller.enqueue(remainder);
            }
          }
          controller.close();
        } else {
          const chunkMode = modeOf3(chunk, false);
          if (mode !== chunkMode) {
            if (mode >= 0) {
              controller.enqueue(flush3(buffers, mode));
            }
            mode = chunkMode;
          }
          if (mode === -1) {
            controller.enqueue(chunk);
            return;
          }
          const chunkSize = sizeOf3(chunk);
          bytesSeen += chunkSize;
          const bufferSize = sizeOf3(buffers[mode]);
          if (chunkSize >= size && bufferSize === 0) {
            controller.enqueue(chunk);
          } else {
            const newSize = merge3(buffers, mode, chunk);
            if (!streamBufferingLoggedWarning && bytesSeen > size * 2) {
              streamBufferingLoggedWarning = true;
              logger5?.warn(`@smithy/util-stream - stream chunk size ${chunkSize} is below threshold of ${size}, automatically buffering.`);
            }
            if (newSize >= size) {
              controller.enqueue(flush3(buffers, mode));
            } else {
              await pull(controller);
            }
          }
        }
      }, "pull");
      return new ReadableStream({
        pull
      });
    }
    __name(createBufferedReadableStream3, "createBufferedReadableStream");
    exports2.createBufferedReadable = createBufferedReadableStream3;
    function merge3(buffers, mode, chunk) {
      switch (mode) {
        case 0:
          buffers[0] += chunk;
          return sizeOf3(buffers[0]);
        case 1:
        case 2:
          buffers[mode].push(chunk);
          return sizeOf3(buffers[mode]);
      }
    }
    __name(merge3, "merge");
    function flush3(buffers, mode) {
      switch (mode) {
        case 0:
          const s = buffers[0];
          buffers[0] = "";
          return s;
        case 1:
        case 2:
          return buffers[mode].flush();
      }
      throw new Error(`@smithy/util-stream - invalid index ${mode} given to flush()`);
    }
    __name(flush3, "flush");
    function sizeOf3(chunk) {
      return chunk?.byteLength ?? chunk?.length ?? 0;
    }
    __name(sizeOf3, "sizeOf");
    function modeOf3(chunk, allowBuffer = true) {
      if (allowBuffer && typeof Buffer !== "undefined" && chunk instanceof Buffer) {
        return 2;
      }
      if (chunk instanceof Uint8Array) {
        return 1;
      }
      if (typeof chunk === "string") {
        return 0;
      }
      return -1;
    }
    __name(modeOf3, "modeOf");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadable.js
var require_createBufferedReadable5 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadable.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createBufferedReadable = createBufferedReadable3;
    var node_stream_1 = require("node:stream");
    var ByteArrayCollector_1 = require_ByteArrayCollector5();
    var createBufferedReadableStream_1 = require_createBufferedReadableStream5();
    var stream_type_check_1 = require_stream_type_check5();
    function createBufferedReadable3(upstream, size, logger5) {
      if ((0, stream_type_check_1.isReadableStream)(upstream)) {
        return (0, createBufferedReadableStream_1.createBufferedReadableStream)(upstream, size, logger5);
      }
      const downstream = new node_stream_1.Readable({ read() {
      } });
      let streamBufferingLoggedWarning = false;
      let bytesSeen = 0;
      const buffers = [
        "",
        new ByteArrayCollector_1.ByteArrayCollector((size2) => new Uint8Array(size2)),
        new ByteArrayCollector_1.ByteArrayCollector((size2) => Buffer.from(new Uint8Array(size2)))
      ];
      let mode = -1;
      upstream.on("data", (chunk) => {
        const chunkMode = (0, createBufferedReadableStream_1.modeOf)(chunk, true);
        if (mode !== chunkMode) {
          if (mode >= 0) {
            downstream.push((0, createBufferedReadableStream_1.flush)(buffers, mode));
          }
          mode = chunkMode;
        }
        if (mode === -1) {
          downstream.push(chunk);
          return;
        }
        const chunkSize = (0, createBufferedReadableStream_1.sizeOf)(chunk);
        bytesSeen += chunkSize;
        const bufferSize = (0, createBufferedReadableStream_1.sizeOf)(buffers[mode]);
        if (chunkSize >= size && bufferSize === 0) {
          downstream.push(chunk);
        } else {
          const newSize = (0, createBufferedReadableStream_1.merge)(buffers, mode, chunk);
          if (!streamBufferingLoggedWarning && bytesSeen > size * 2) {
            streamBufferingLoggedWarning = true;
            logger5?.warn(`@smithy/util-stream - stream chunk size ${chunkSize} is below threshold of ${size}, automatically buffering.`);
          }
          if (newSize >= size) {
            downstream.push((0, createBufferedReadableStream_1.flush)(buffers, mode));
          }
        }
      });
      upstream.on("end", () => {
        if (mode !== -1) {
          const remainder = (0, createBufferedReadableStream_1.flush)(buffers, mode);
          if ((0, createBufferedReadableStream_1.sizeOf)(remainder) > 0) {
            downstream.push(remainder);
          }
        }
        downstream.push(null);
      });
      return downstream;
    }
    __name(createBufferedReadable3, "createBufferedReadable");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.browser.js
var require_getAwsChunkedEncodingStream_browser5 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getAwsChunkedEncodingStream = void 0;
    var getAwsChunkedEncodingStream5 = /* @__PURE__ */ __name((readableStream, options) => {
      const { base64Encoder, bodyLengthChecker, checksumAlgorithmFn, checksumLocationName, streamHasher } = options;
      const checksumRequired = base64Encoder !== void 0 && bodyLengthChecker !== void 0 && checksumAlgorithmFn !== void 0 && checksumLocationName !== void 0 && streamHasher !== void 0;
      const digest = checksumRequired ? streamHasher(checksumAlgorithmFn, readableStream) : void 0;
      const reader = readableStream.getReader();
      return new ReadableStream({
        async pull(controller) {
          const { value, done } = await reader.read();
          if (done) {
            controller.enqueue(`0\r
`);
            if (checksumRequired) {
              const checksum = base64Encoder(await digest);
              controller.enqueue(`${checksumLocationName}:${checksum}\r
`);
              controller.enqueue(`\r
`);
            }
            controller.close();
          } else {
            controller.enqueue(`${(bodyLengthChecker(value) || 0).toString(16)}\r
${value}\r
`);
          }
        }
      });
    }, "getAwsChunkedEncodingStream");
    exports2.getAwsChunkedEncodingStream = getAwsChunkedEncodingStream5;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.js
var require_getAwsChunkedEncodingStream5 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getAwsChunkedEncodingStream = getAwsChunkedEncodingStream5;
    var node_stream_1 = require("node:stream");
    var getAwsChunkedEncodingStream_browser_1 = require_getAwsChunkedEncodingStream_browser5();
    var stream_type_check_1 = require_stream_type_check5();
    function getAwsChunkedEncodingStream5(stream, options) {
      const readable = stream;
      const readableStream = stream;
      if ((0, stream_type_check_1.isReadableStream)(readableStream)) {
        return (0, getAwsChunkedEncodingStream_browser_1.getAwsChunkedEncodingStream)(readableStream, options);
      }
      const { base64Encoder, bodyLengthChecker, checksumAlgorithmFn, checksumLocationName, streamHasher } = options;
      const checksumRequired = base64Encoder !== void 0 && checksumAlgorithmFn !== void 0 && checksumLocationName !== void 0 && streamHasher !== void 0;
      const digest = checksumRequired ? streamHasher(checksumAlgorithmFn, readable) : void 0;
      const awsChunkedEncodingStream = new node_stream_1.Readable({
        read: /* @__PURE__ */ __name(() => {
        }, "read")
      });
      readable.on("data", (data3) => {
        const length = bodyLengthChecker(data3) || 0;
        if (length === 0) {
          return;
        }
        awsChunkedEncodingStream.push(`${length.toString(16)}\r
`);
        awsChunkedEncodingStream.push(data3);
        awsChunkedEncodingStream.push("\r\n");
      });
      readable.on("end", async () => {
        awsChunkedEncodingStream.push(`0\r
`);
        if (checksumRequired) {
          const checksum = base64Encoder(await digest);
          awsChunkedEncodingStream.push(`${checksumLocationName}:${checksum}\r
`);
          awsChunkedEncodingStream.push(`\r
`);
        }
        awsChunkedEncodingStream.push(null);
      });
      return awsChunkedEncodingStream;
    }
    __name(getAwsChunkedEncodingStream5, "getAwsChunkedEncodingStream");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/headStream.browser.js
var require_headStream_browser5 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/headStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.headStream = headStream5;
    async function headStream5(stream, bytes) {
      let byteLengthCounter = 0;
      const chunks2 = [];
      const reader = stream.getReader();
      let isDone = false;
      while (!isDone) {
        const { done, value } = await reader.read();
        if (value) {
          chunks2.push(value);
          byteLengthCounter += value?.byteLength ?? 0;
        }
        if (byteLengthCounter >= bytes) {
          break;
        }
        isDone = done;
      }
      reader.releaseLock();
      const collected = new Uint8Array(Math.min(bytes, byteLengthCounter));
      let offset = 0;
      for (const chunk of chunks2) {
        if (chunk.byteLength > collected.byteLength - offset) {
          collected.set(chunk.subarray(0, collected.byteLength - offset), offset);
          break;
        } else {
          collected.set(chunk, offset);
        }
        offset += chunk.length;
      }
      return collected;
    }
    __name(headStream5, "headStream");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/headStream.js
var require_headStream5 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/headStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.headStream = void 0;
    var stream_1 = require("stream");
    var headStream_browser_1 = require_headStream_browser5();
    var stream_type_check_1 = require_stream_type_check5();
    var headStream5 = /* @__PURE__ */ __name((stream, bytes) => {
      if ((0, stream_type_check_1.isReadableStream)(stream)) {
        return (0, headStream_browser_1.headStream)(stream, bytes);
      }
      return new Promise((resolve13, reject) => {
        const collector = new Collector8();
        collector.limit = bytes;
        stream.pipe(collector);
        stream.on("error", (err) => {
          collector.end();
          reject(err);
        });
        collector.on("error", reject);
        collector.on("finish", function() {
          const bytes2 = new Uint8Array(Buffer.concat(this.buffers));
          resolve13(bytes2);
        });
      });
    }, "headStream");
    exports2.headStream = headStream5;
    var Collector8 = class extends stream_1.Writable {
      static {
        __name(this, "Collector");
      }
      buffers = [];
      limit = Infinity;
      bytesBuffered = 0;
      _write(chunk, encoding, callback) {
        this.buffers.push(chunk);
        this.bytesBuffered += chunk.byteLength ?? 0;
        if (this.bytesBuffered >= this.limit) {
          const excess = this.bytesBuffered - this.limit;
          const tailBuffer = this.buffers[this.buffers.length - 1];
          this.buffers[this.buffers.length - 1] = tailBuffer.subarray(0, tailBuffer.byteLength - excess);
          this.emit("finish");
        }
        callback();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.browser.js
var require_sdk_stream_mixin_browser5 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.sdkStreamMixin = void 0;
    var fetch_http_handler_1 = require_dist_cjs14();
    var util_base64_1 = require_dist_cjs10();
    var util_hex_encoding_1 = require_dist_cjs15();
    var util_utf8_1 = require_dist_cjs9();
    var stream_type_check_1 = require_stream_type_check5();
    var ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11 = "The stream has already been transformed.";
    var sdkStreamMixin12 = /* @__PURE__ */ __name((stream) => {
      if (!isBlobInstance6(stream) && !(0, stream_type_check_1.isReadableStream)(stream)) {
        const name = stream?.__proto__?.constructor?.name || stream;
        throw new Error(`Unexpected stream implementation, expect Blob or ReadableStream, got ${name}`);
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
        }
        transformed = true;
        return await (0, fetch_http_handler_1.streamCollector)(stream);
      }, "transformToByteArray");
      const blobToWebStream = /* @__PURE__ */ __name((blob) => {
        if (typeof blob.stream !== "function") {
          throw new Error("Cannot transform payload Blob to web stream. Please make sure the Blob.stream() is polyfilled.\nIf you are using React Native, this API is not yet supported, see: https://react-native.canny.io/feature-requests/p/fetch-streaming-body");
        }
        return blob.stream();
      }, "blobToWebStream");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === "base64") {
            return (0, util_base64_1.toBase64)(buf);
          } else if (encoding === "hex") {
            return (0, util_hex_encoding_1.toHex)(buf);
          } else if (encoding === void 0 || encoding === "utf8" || encoding === "utf-8") {
            return (0, util_utf8_1.toUtf8)(buf);
          } else if (typeof TextDecoder === "function") {
            return new TextDecoder(encoding).decode(buf);
          } else {
            throw new Error("TextDecoder is not available, please make sure polyfill is provided.");
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
          }
          transformed = true;
          if (isBlobInstance6(stream)) {
            return blobToWebStream(stream);
          } else if ((0, stream_type_check_1.isReadableStream)(stream)) {
            return stream;
          } else {
            throw new Error(`Cannot transform payload to web stream, got ${stream}`);
          }
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
    exports2.sdkStreamMixin = sdkStreamMixin12;
    var isBlobInstance6 = /* @__PURE__ */ __name((stream) => typeof Blob === "function" && stream instanceof Blob, "isBlobInstance");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.js
var require_sdk_stream_mixin5 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.sdkStreamMixin = void 0;
    var node_http_handler_1 = require_dist_cjs13();
    var util_buffer_from_1 = require_dist_cjs8();
    var stream_1 = require("stream");
    var sdk_stream_mixin_browser_1 = require_sdk_stream_mixin_browser5();
    var ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11 = "The stream has already been transformed.";
    var sdkStreamMixin12 = /* @__PURE__ */ __name((stream) => {
      if (!(stream instanceof stream_1.Readable)) {
        try {
          return (0, sdk_stream_mixin_browser_1.sdkStreamMixin)(stream);
        } catch (e32) {
          const name = stream?.__proto__?.constructor?.name || stream;
          throw new Error(`Unexpected stream implementation, expect Stream.Readable instance, got ${name}`);
        }
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
        }
        transformed = true;
        return await (0, node_http_handler_1.streamCollector)(stream);
      }, "transformToByteArray");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === void 0 || Buffer.isEncoding(encoding)) {
            return (0, util_buffer_from_1.fromArrayBuffer)(buf.buffer, buf.byteOffset, buf.byteLength).toString(encoding);
          } else {
            const decoder = new TextDecoder(encoding);
            return decoder.decode(buf);
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
          }
          if (stream.readableFlowing !== null) {
            throw new Error("The stream has been consumed by other callbacks.");
          }
          if (typeof stream_1.Readable.toWeb !== "function") {
            throw new Error("Readable.toWeb() is not supported. Please ensure a polyfill is available.");
          }
          transformed = true;
          return stream_1.Readable.toWeb(stream);
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
    exports2.sdkStreamMixin = sdkStreamMixin12;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/splitStream.browser.js
var require_splitStream_browser5 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/splitStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.splitStream = splitStream5;
    async function splitStream5(stream) {
      if (typeof stream.stream === "function") {
        stream = stream.stream();
      }
      const readableStream = stream;
      return readableStream.tee();
    }
    __name(splitStream5, "splitStream");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/splitStream.js
var require_splitStream5 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/splitStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.splitStream = splitStream5;
    var stream_1 = require("stream");
    var splitStream_browser_1 = require_splitStream_browser5();
    var stream_type_check_1 = require_stream_type_check5();
    async function splitStream5(stream) {
      if ((0, stream_type_check_1.isReadableStream)(stream) || (0, stream_type_check_1.isBlob)(stream)) {
        return (0, splitStream_browser_1.splitStream)(stream);
      }
      const stream1 = new stream_1.PassThrough();
      const stream2 = new stream_1.PassThrough();
      stream.pipe(stream1);
      stream.pipe(stream2);
      return [stream1, stream2];
    }
    __name(splitStream5, "splitStream");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/index.js
var require_dist_cjs94 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@smithy/util-stream/dist-cjs/index.js"(exports2) {
    "use strict";
    var utilBase64 = require_dist_cjs10();
    var utilUtf8 = require_dist_cjs9();
    var ChecksumStream5 = require_ChecksumStream5();
    var createChecksumStream5 = require_createChecksumStream5();
    var createBufferedReadable3 = require_createBufferedReadable5();
    var getAwsChunkedEncodingStream5 = require_getAwsChunkedEncodingStream5();
    var headStream5 = require_headStream5();
    var sdkStreamMixin12 = require_sdk_stream_mixin5();
    var splitStream5 = require_splitStream5();
    var streamTypeCheck = require_stream_type_check5();
    var Uint8ArrayBlobAdapter8 = class _Uint8ArrayBlobAdapter extends Uint8Array {
      static {
        __name(this, "Uint8ArrayBlobAdapter");
      }
      static fromString(source, encoding = "utf-8") {
        if (typeof source === "string") {
          if (encoding === "base64") {
            return _Uint8ArrayBlobAdapter.mutate(utilBase64.fromBase64(source));
          }
          return _Uint8ArrayBlobAdapter.mutate(utilUtf8.fromUtf8(source));
        }
        throw new Error(`Unsupported conversion from ${typeof source} to Uint8ArrayBlobAdapter.`);
      }
      static mutate(source) {
        Object.setPrototypeOf(source, _Uint8ArrayBlobAdapter.prototype);
        return source;
      }
      transformToString(encoding = "utf-8") {
        if (encoding === "base64") {
          return utilBase64.toBase64(this);
        }
        return utilUtf8.toUtf8(this);
      }
    };
    exports2.isBlob = streamTypeCheck.isBlob;
    exports2.isReadableStream = streamTypeCheck.isReadableStream;
    exports2.Uint8ArrayBlobAdapter = Uint8ArrayBlobAdapter8;
    Object.prototype.hasOwnProperty.call(ChecksumStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: ChecksumStream5["__proto__"]
    });
    Object.keys(ChecksumStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = ChecksumStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(createChecksumStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: createChecksumStream5["__proto__"]
    });
    Object.keys(createChecksumStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = createChecksumStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(createBufferedReadable3, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: createBufferedReadable3["__proto__"]
    });
    Object.keys(createBufferedReadable3).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = createBufferedReadable3[k32];
    });
    Object.prototype.hasOwnProperty.call(getAwsChunkedEncodingStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: getAwsChunkedEncodingStream5["__proto__"]
    });
    Object.keys(getAwsChunkedEncodingStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = getAwsChunkedEncodingStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(headStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: headStream5["__proto__"]
    });
    Object.keys(headStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = headStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(sdkStreamMixin12, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: sdkStreamMixin12["__proto__"]
    });
    Object.keys(sdkStreamMixin12).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = sdkStreamMixin12[k32];
    });
    Object.prototype.hasOwnProperty.call(splitStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: splitStream5["__proto__"]
    });
    Object.keys(splitStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = splitStream5[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/requestHelpers.js
var require_requestHelpers3 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/requestHelpers.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createGetRequest = createGetRequest;
    exports2.getCredentials = getCredentials;
    var property_provider_1 = require_dist_cjs27();
    var protocol_http_1 = require_dist_cjs2();
    var smithy_client_1 = require_dist_cjs34();
    var util_stream_1 = require_dist_cjs94();
    function createGetRequest(url) {
      return new protocol_http_1.HttpRequest({
        protocol: url.protocol,
        hostname: url.hostname,
        port: Number(url.port),
        path: url.pathname,
        query: Array.from(url.searchParams.entries()).reduce((acc, [k32, v]) => {
          acc[k32] = v;
          return acc;
        }, {}),
        fragment: url.hash
      });
    }
    __name(createGetRequest, "createGetRequest");
    async function getCredentials(response, logger5) {
      const stream = (0, util_stream_1.sdkStreamMixin)(response.body);
      const str = await stream.transformToString();
      if (response.statusCode === 200) {
        const parsed = JSON.parse(str);
        if (typeof parsed.AccessKeyId !== "string" || typeof parsed.SecretAccessKey !== "string" || typeof parsed.Token !== "string" || typeof parsed.Expiration !== "string") {
          throw new property_provider_1.CredentialsProviderError("HTTP credential provider response not of the required format, an object matching: { AccessKeyId: string, SecretAccessKey: string, Token: string, Expiration: string(rfc3339) }", { logger: logger5 });
        }
        return {
          accessKeyId: parsed.AccessKeyId,
          secretAccessKey: parsed.SecretAccessKey,
          sessionToken: parsed.Token,
          expiration: (0, smithy_client_1.parseRfc3339DateTime)(parsed.Expiration)
        };
      }
      if (response.statusCode >= 400 && response.statusCode < 500) {
        let parsedBody = {};
        try {
          parsedBody = JSON.parse(str);
        } catch (e32) {
        }
        throw Object.assign(new property_provider_1.CredentialsProviderError(`Server responded with status: ${response.statusCode}`, { logger: logger5 }), {
          Code: parsedBody.Code,
          Message: parsedBody.Message
        });
      }
      throw new property_provider_1.CredentialsProviderError(`Server responded with status: ${response.statusCode}`, { logger: logger5 });
    }
    __name(getCredentials, "getCredentials");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/retry-wrapper.js
var require_retry_wrapper3 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/retry-wrapper.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.retryWrapper = void 0;
    var retryWrapper = /* @__PURE__ */ __name((toRetry, maxRetries, delayMs) => {
      return async () => {
        for (let i32 = 0; i32 < maxRetries; ++i32) {
          try {
            return await toRetry();
          } catch (e32) {
            await new Promise((resolve13) => setTimeout(resolve13, delayMs));
          }
        }
        return await toRetry();
      };
    }, "retryWrapper");
    exports2.retryWrapper = retryWrapper;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/fromHttp.js
var require_fromHttp3 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/fromHttp.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromHttp = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var client_1 = (init_client7(), __toCommonJS(client_exports6));
    var node_http_handler_1 = require_dist_cjs13();
    var property_provider_1 = require_dist_cjs27();
    var promises_1 = tslib_1.__importDefault(require("node:fs/promises"));
    var checkUrl_1 = require_checkUrl3();
    var requestHelpers_1 = require_requestHelpers3();
    var retry_wrapper_1 = require_retry_wrapper3();
    var AWS_CONTAINER_CREDENTIALS_RELATIVE_URI = "AWS_CONTAINER_CREDENTIALS_RELATIVE_URI";
    var DEFAULT_LINK_LOCAL_HOST = "http://169.254.170.2";
    var AWS_CONTAINER_CREDENTIALS_FULL_URI = "AWS_CONTAINER_CREDENTIALS_FULL_URI";
    var AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE = "AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE";
    var AWS_CONTAINER_AUTHORIZATION_TOKEN = "AWS_CONTAINER_AUTHORIZATION_TOKEN";
    var fromHttp = /* @__PURE__ */ __name((options = {}) => {
      options.logger?.debug("@aws-sdk/credential-provider-http - fromHttp");
      let host;
      const relative5 = options.awsContainerCredentialsRelativeUri ?? process.env[AWS_CONTAINER_CREDENTIALS_RELATIVE_URI];
      const full = options.awsContainerCredentialsFullUri ?? process.env[AWS_CONTAINER_CREDENTIALS_FULL_URI];
      const token = options.awsContainerAuthorizationToken ?? process.env[AWS_CONTAINER_AUTHORIZATION_TOKEN];
      const tokenFile = options.awsContainerAuthorizationTokenFile ?? process.env[AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE];
      const warn2 = options.logger?.constructor?.name === "NoOpLogger" || !options.logger?.warn ? console.warn : options.logger.warn.bind(options.logger);
      if (relative5 && full) {
        warn2("@aws-sdk/credential-provider-http: you have set both awsContainerCredentialsRelativeUri and awsContainerCredentialsFullUri.");
        warn2("awsContainerCredentialsFullUri will take precedence.");
      }
      if (token && tokenFile) {
        warn2("@aws-sdk/credential-provider-http: you have set both awsContainerAuthorizationToken and awsContainerAuthorizationTokenFile.");
        warn2("awsContainerAuthorizationToken will take precedence.");
      }
      if (full) {
        host = full;
      } else if (relative5) {
        host = `${DEFAULT_LINK_LOCAL_HOST}${relative5}`;
      } else {
        throw new property_provider_1.CredentialsProviderError(`No HTTP credential provider host provided.
Set AWS_CONTAINER_CREDENTIALS_FULL_URI or AWS_CONTAINER_CREDENTIALS_RELATIVE_URI.`, { logger: options.logger });
      }
      const url = new URL(host);
      (0, checkUrl_1.checkUrl)(url, options.logger);
      const requestHandler = node_http_handler_1.NodeHttpHandler.create({
        requestTimeout: options.timeout ?? 1e3,
        connectionTimeout: options.timeout ?? 1e3
      });
      return (0, retry_wrapper_1.retryWrapper)(async () => {
        const request4 = (0, requestHelpers_1.createGetRequest)(url);
        if (token) {
          request4.headers.Authorization = token;
        } else if (tokenFile) {
          request4.headers.Authorization = (await promises_1.default.readFile(tokenFile)).toString();
        }
        try {
          const result2 = await requestHandler.handle(request4);
          return (0, requestHelpers_1.getCredentials)(result2.response).then((creds) => (0, client_1.setCredentialFeature)(creds, "CREDENTIALS_HTTP", "z"));
        } catch (e32) {
          throw new property_provider_1.CredentialsProviderError(String(e32), { logger: options.logger });
        }
      }, options.maxRetries ?? 3, options.timeout ?? 1e3);
    }, "fromHttp");
    exports2.fromHttp = fromHttp;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-http/dist-cjs/index.js
var require_dist_cjs95 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-http/dist-cjs/index.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromHttp = void 0;
    var fromHttp_1 = require_fromHttp3();
    Object.defineProperty(exports2, "fromHttp", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return fromHttp_1.fromHttp;
    }, "get") });
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption8(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "awsssoportal",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption8(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var import_util_middleware13, defaultSSOHttpAuthSchemeParametersProvider3, defaultSSOHttpAuthSchemeProvider3, resolveHttpAuthSchemeConfig8;
var init_httpAuthSchemeProvider8 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes5();
    import_util_middleware13 = __toESM(require_dist_cjs6());
    defaultSSOHttpAuthSchemeParametersProvider3 = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, import_util_middleware13.getSmithyContext)(context).operation,
        region: await (0, import_util_middleware13.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultSSOHttpAuthSchemeParametersProvider");
    __name(createAwsAuthSigv4HttpAuthOption8, "createAwsAuthSigv4HttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption8, "createSmithyApiNoAuthHttpAuthOption");
    defaultSSOHttpAuthSchemeProvider3 = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "GetRoleCredentials": {
          options.push(createSmithyApiNoAuthHttpAuthOption8(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption8(authParameters));
        }
      }
      return options;
    }, "defaultSSOHttpAuthSchemeProvider");
    resolveHttpAuthSchemeConfig8 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveAwsSdkSigV4Config4(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, import_util_middleware13.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/EndpointParameters.js
var resolveClientEndpointParameters8, commonParams8;
var init_EndpointParameters8 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters8 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "awsssoportal"
      });
    }, "resolveClientEndpointParameters");
    commonParams8 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/package.json
var package_default4;
var init_package4 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/package.json"() {
    package_default4 = {
      name: "@aws-sdk/nested-clients",
      version: "3.997.6",
      description: "Nested clients for AWS SDK packages.",
      main: "./dist-cjs/index.js",
      module: "./dist-es/index.js",
      types: "./dist-types/index.d.ts",
      scripts: {
        build: "yarn lint && concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline nested-clients",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        lint: "node ../../scripts/validation/submodules-linter.js --pkg nested-clients",
        test: "yarn g:vitest run",
        "test:watch": "yarn g:vitest watch"
      },
      engines: {
        node: ">=20.0.0"
      },
      sideEffects: false,
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      dependencies: {
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.8",
        "@aws-sdk/middleware-host-header": "^3.972.10",
        "@aws-sdk/middleware-logger": "^3.972.10",
        "@aws-sdk/middleware-recursion-detection": "^3.972.11",
        "@aws-sdk/middleware-user-agent": "^3.972.38",
        "@aws-sdk/region-config-resolver": "^3.972.13",
        "@aws-sdk/signature-v4-multi-region": "^3.996.25",
        "@aws-sdk/types": "^3.973.8",
        "@aws-sdk/util-endpoints": "^3.996.8",
        "@aws-sdk/util-user-agent-browser": "^3.972.10",
        "@aws-sdk/util-user-agent-node": "^3.973.24",
        "@smithy/config-resolver": "^4.4.17",
        "@smithy/core": "^3.23.17",
        "@smithy/fetch-http-handler": "^5.3.17",
        "@smithy/hash-node": "^4.2.14",
        "@smithy/invalid-dependency": "^4.2.14",
        "@smithy/middleware-content-length": "^4.2.14",
        "@smithy/middleware-endpoint": "^4.4.32",
        "@smithy/middleware-retry": "^4.5.7",
        "@smithy/middleware-serde": "^4.2.20",
        "@smithy/middleware-stack": "^4.2.14",
        "@smithy/node-config-provider": "^4.3.14",
        "@smithy/node-http-handler": "^4.6.1",
        "@smithy/protocol-http": "^5.3.14",
        "@smithy/smithy-client": "^4.12.13",
        "@smithy/types": "^4.14.1",
        "@smithy/url-parser": "^4.2.14",
        "@smithy/util-base64": "^4.3.2",
        "@smithy/util-body-length-browser": "^4.2.2",
        "@smithy/util-body-length-node": "^4.2.3",
        "@smithy/util-defaults-mode-browser": "^4.3.49",
        "@smithy/util-defaults-mode-node": "^4.2.54",
        "@smithy/util-endpoints": "^3.4.2",
        "@smithy/util-middleware": "^4.2.14",
        "@smithy/util-retry": "^4.3.6",
        "@smithy/util-utf8": "^4.2.2",
        tslib: "^2.6.2"
      },
      devDependencies: {
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "./cognito-identity.d.ts",
        "./cognito-identity.js",
        "./signin.d.ts",
        "./signin.js",
        "./sso-oidc.d.ts",
        "./sso-oidc.js",
        "./sso.d.ts",
        "./sso.js",
        "./sts.d.ts",
        "./sts.js",
        "dist-*/**"
      ],
      browser: {
        "./dist-es/submodules/cognito-identity/runtimeConfig": "./dist-es/submodules/cognito-identity/runtimeConfig.browser",
        "./dist-es/submodules/signin/runtimeConfig": "./dist-es/submodules/signin/runtimeConfig.browser",
        "./dist-es/submodules/sso-oidc/runtimeConfig": "./dist-es/submodules/sso-oidc/runtimeConfig.browser",
        "./dist-es/submodules/sso/runtimeConfig": "./dist-es/submodules/sso/runtimeConfig.browser",
        "./dist-es/submodules/sts/runtimeConfig": "./dist-es/submodules/sts/runtimeConfig.browser"
      },
      "react-native": {},
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/packages/nested-clients",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "packages/nested-clients"
      },
      exports: {
        "./package.json": "./package.json",
        "./sso-oidc": {
          types: "./dist-types/submodules/sso-oidc/index.d.ts",
          module: "./dist-es/submodules/sso-oidc/index.js",
          node: "./dist-cjs/submodules/sso-oidc/index.js",
          import: "./dist-es/submodules/sso-oidc/index.js",
          require: "./dist-cjs/submodules/sso-oidc/index.js"
        },
        "./sts": {
          types: "./dist-types/submodules/sts/index.d.ts",
          module: "./dist-es/submodules/sts/index.js",
          node: "./dist-cjs/submodules/sts/index.js",
          import: "./dist-es/submodules/sts/index.js",
          require: "./dist-cjs/submodules/sts/index.js"
        },
        "./signin": {
          types: "./dist-types/submodules/signin/index.d.ts",
          module: "./dist-es/submodules/signin/index.js",
          node: "./dist-cjs/submodules/signin/index.js",
          import: "./dist-es/submodules/signin/index.js",
          require: "./dist-cjs/submodules/signin/index.js"
        },
        "./cognito-identity": {
          types: "./dist-types/submodules/cognito-identity/index.d.ts",
          module: "./dist-es/submodules/cognito-identity/index.js",
          node: "./dist-cjs/submodules/cognito-identity/index.js",
          import: "./dist-es/submodules/cognito-identity/index.js",
          require: "./dist-cjs/submodules/cognito-identity/index.js"
        },
        "./sso": {
          types: "./dist-types/submodules/sso/index.d.ts",
          module: "./dist-es/submodules/sso/index.js",
          node: "./dist-cjs/submodules/sso/index.js",
          import: "./dist-es/submodules/sso/index.js",
          require: "./dist-cjs/submodules/sso/index.js"
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/util-user-agent-node/dist-cjs/index.js
var require_dist_cjs96 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/util-user-agent-node/dist-cjs/index.js"(exports2) {
    "use strict";
    var node_os = require("node:os");
    var node_process = require("node:process");
    var utilConfigProvider = require_dist_cjs24();
    var promises5 = require("node:fs/promises");
    var node_path = require("node:path");
    var middlewareUserAgent = require_dist_cjs91();
    var getRuntimeUserAgentPair2 = /* @__PURE__ */ __name(() => {
      const runtimesToCheck = ["deno", "bun", "llrt"];
      for (const runtime of runtimesToCheck) {
        if (node_process.versions[runtime]) {
          return [`md/${runtime}`, node_process.versions[runtime]];
        }
      }
      return ["md/nodejs", node_process.versions.node];
    }, "getRuntimeUserAgentPair");
    var getNodeModulesParentDirs2 = /* @__PURE__ */ __name((dirname14) => {
      const cwd = process.cwd();
      if (!dirname14) {
        return [cwd];
      }
      const normalizedPath = node_path.normalize(dirname14);
      const parts = normalizedPath.split(node_path.sep);
      const nodeModulesIndex = parts.indexOf("node_modules");
      const parentDir = nodeModulesIndex !== -1 ? parts.slice(0, nodeModulesIndex).join(node_path.sep) : normalizedPath;
      if (cwd === parentDir) {
        return [cwd];
      }
      return [parentDir, cwd];
    }, "getNodeModulesParentDirs");
    var SEMVER_REGEX2 = /^(0|[1-9]\d*)\.(0|[1-9]\d*)\.(0|[1-9]\d*)(?:-((?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*)(?:\.(?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*))*))?(?:\+[0-9a-zA-Z-]+(?:\.[0-9a-zA-Z-]+)*)?$/;
    var getSanitizedTypeScriptVersion2 = /* @__PURE__ */ __name((version = "") => {
      const match = version.match(SEMVER_REGEX2);
      if (!match) {
        return void 0;
      }
      const [major6, minor, patch, prerelease] = [match[1], match[2], match[3], match[4]];
      return prerelease ? `${major6}.${minor}.${patch}-${prerelease}` : `${major6}.${minor}.${patch}`;
    }, "getSanitizedTypeScriptVersion");
    var ALLOWED_PREFIXES2 = ["^", "~", ">=", "<=", ">", "<"];
    var ALLOWED_DIST_TAGS2 = ["latest", "beta", "dev", "rc", "insiders", "next"];
    var getSanitizedDevTypeScriptVersion2 = /* @__PURE__ */ __name((version = "") => {
      if (ALLOWED_DIST_TAGS2.includes(version)) {
        return version;
      }
      const prefix = ALLOWED_PREFIXES2.find((p10) => version.startsWith(p10)) ?? "";
      const sanitizedTypeScriptVersion = getSanitizedTypeScriptVersion2(version.slice(prefix.length));
      if (!sanitizedTypeScriptVersion) {
        return void 0;
      }
      return `${prefix}${sanitizedTypeScriptVersion}`;
    }, "getSanitizedDevTypeScriptVersion");
    var tscVersion2;
    var TS_PACKAGE_JSON2 = node_path.join("node_modules", "typescript", "package.json");
    var getTypeScriptUserAgentPair2 = /* @__PURE__ */ __name(async () => {
      if (tscVersion2 === null) {
        return void 0;
      } else if (typeof tscVersion2 === "string") {
        return ["md/tsc", tscVersion2];
      }
      let isTypeScriptDetectionDisabled = false;
      try {
        isTypeScriptDetectionDisabled = utilConfigProvider.booleanSelector(process.env, "AWS_SDK_JS_TYPESCRIPT_DETECTION_DISABLED", utilConfigProvider.SelectorType.ENV) || false;
      } catch {
      }
      if (isTypeScriptDetectionDisabled) {
        tscVersion2 = null;
        return void 0;
      }
      const dirname14 = typeof __dirname !== "undefined" ? __dirname : void 0;
      const nodeModulesParentDirs = getNodeModulesParentDirs2(dirname14);
      let versionFromApp;
      for (const nodeModulesParentDir of nodeModulesParentDirs) {
        try {
          const appPackageJsonPath = node_path.join(nodeModulesParentDir, "package.json");
          const packageJson = await promises5.readFile(appPackageJsonPath, "utf-8");
          const { dependencies, devDependencies } = JSON.parse(packageJson);
          const version = devDependencies?.typescript ?? dependencies?.typescript;
          if (typeof version !== "string") {
            continue;
          }
          versionFromApp = version;
          break;
        } catch {
        }
      }
      if (!versionFromApp) {
        tscVersion2 = null;
        return void 0;
      }
      let versionFromNodeModules;
      for (const nodeModulesParentDir of nodeModulesParentDirs) {
        try {
          const tsPackageJsonPath = node_path.join(nodeModulesParentDir, TS_PACKAGE_JSON2);
          const packageJson = await promises5.readFile(tsPackageJsonPath, "utf-8");
          const { version } = JSON.parse(packageJson);
          const sanitizedVersion2 = getSanitizedTypeScriptVersion2(version);
          if (typeof sanitizedVersion2 !== "string") {
            continue;
          }
          versionFromNodeModules = sanitizedVersion2;
          break;
        } catch {
        }
      }
      if (versionFromNodeModules) {
        tscVersion2 = versionFromNodeModules;
        return ["md/tsc", tscVersion2];
      }
      const sanitizedVersion = getSanitizedDevTypeScriptVersion2(versionFromApp);
      if (typeof sanitizedVersion !== "string") {
        tscVersion2 = null;
        return void 0;
      }
      tscVersion2 = `dev_${sanitizedVersion}`;
      return ["md/tsc", tscVersion2];
    }, "getTypeScriptUserAgentPair");
    var crtAvailability2 = {
      isCrtAvailable: false
    };
    var isCrtAvailable2 = /* @__PURE__ */ __name(() => {
      if (crtAvailability2.isCrtAvailable) {
        return ["md/crt-avail"];
      }
      return null;
    }, "isCrtAvailable");
    var createDefaultUserAgentProvider29 = /* @__PURE__ */ __name(({ serviceId, clientVersion }) => {
      const runtimeUserAgentPair = getRuntimeUserAgentPair2();
      return async (config2) => {
        const sections = [
          ["aws-sdk-js", clientVersion],
          ["ua", "2.1"],
          [`os/${node_os.platform()}`, node_os.release()],
          ["lang/js"],
          runtimeUserAgentPair
        ];
        const typescriptUserAgentPair = await getTypeScriptUserAgentPair2();
        if (typescriptUserAgentPair) {
          sections.push(typescriptUserAgentPair);
        }
        const crtAvailable = isCrtAvailable2();
        if (crtAvailable) {
          sections.push(crtAvailable);
        }
        if (serviceId) {
          sections.push([`api/${serviceId}`, clientVersion]);
        }
        if (node_process.env.AWS_EXECUTION_ENV) {
          sections.push([`exec-env/${node_process.env.AWS_EXECUTION_ENV}`]);
        }
        const appId = await config2?.userAgentAppId?.();
        const resolvedUserAgent = appId ? [...sections, [`app/${appId}`]] : [...sections];
        return resolvedUserAgent;
      };
    }, "createDefaultUserAgentProvider");
    var defaultUserAgent2 = createDefaultUserAgentProvider29;
    var UA_APP_ID_ENV_NAME2 = "AWS_SDK_UA_APP_ID";
    var UA_APP_ID_INI_NAME2 = "sdk_ua_app_id";
    var UA_APP_ID_INI_NAME_DEPRECATED2 = "sdk-ua-app-id";
    var NODE_APP_ID_CONFIG_OPTIONS29 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[UA_APP_ID_ENV_NAME2], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[UA_APP_ID_INI_NAME2] ?? profile[UA_APP_ID_INI_NAME_DEPRECATED2], "configFileSelector"),
      default: middlewareUserAgent.DEFAULT_UA_APP_ID
    };
    exports2.NODE_APP_ID_CONFIG_OPTIONS = NODE_APP_ID_CONFIG_OPTIONS29;
    exports2.UA_APP_ID_ENV_NAME = UA_APP_ID_ENV_NAME2;
    exports2.UA_APP_ID_INI_NAME = UA_APP_ID_INI_NAME2;
    exports2.createDefaultUserAgentProvider = createDefaultUserAgentProvider29;
    exports2.crtAvailability = crtAvailability2;
    exports2.defaultUserAgent = defaultUserAgent2;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ProtocolLib.js
var import_smithy_client72, ProtocolLib5;
var init_ProtocolLib5 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ProtocolLib.js"() {
    init_schema4();
    import_smithy_client72 = __toESM(require_dist_cjs34());
    ProtocolLib5 = class {
      static {
        __name(this, "ProtocolLib");
      }
      queryCompat;
      errorRegistry;
      constructor(queryCompat = false) {
        this.queryCompat = queryCompat;
      }
      resolveRestContentType(defaultContentType, inputSchema) {
        const members = inputSchema.getMemberSchemas();
        const httpPayloadMember = Object.values(members).find((m20) => {
          return !!m20.getMergedTraits().httpPayload;
        });
        if (httpPayloadMember) {
          const mediaType = httpPayloadMember.getMergedTraits().mediaType;
          if (mediaType) {
            return mediaType;
          } else if (httpPayloadMember.isStringSchema()) {
            return "text/plain";
          } else if (httpPayloadMember.isBlobSchema()) {
            return "application/octet-stream";
          } else {
            return defaultContentType;
          }
        } else if (!inputSchema.isUnitSchema()) {
          const hasBody = Object.values(members).find((m20) => {
            const { httpQuery, httpQueryParams, httpHeader, httpLabel, httpPrefixHeaders } = m20.getMergedTraits();
            const noPrefixHeaders = httpPrefixHeaders === void 0;
            return !httpQuery && !httpQueryParams && !httpHeader && !httpLabel && noPrefixHeaders;
          });
          if (hasBody) {
            return defaultContentType;
          }
        }
      }
      async getErrorSchemaOrThrowBaseException(errorIdentifier, defaultNamespace, response, dataObject, metadata, getErrorSchema) {
        let errorName = errorIdentifier;
        if (errorIdentifier.includes("#")) {
          [, errorName] = errorIdentifier.split("#");
        }
        const errorMetadata = {
          $metadata: metadata,
          $fault: response.statusCode < 500 ? "client" : "server"
        };
        if (!this.errorRegistry) {
          throw new Error("@aws-sdk/core/protocols - error handler not initialized.");
        }
        try {
          const errorSchema = getErrorSchema?.(this.errorRegistry, errorName) ?? this.errorRegistry.getSchema(errorIdentifier);
          return { errorSchema, errorMetadata };
        } catch (e32) {
          dataObject.message = dataObject.message ?? dataObject.Message ?? "UnknownError";
          const synthetic = this.errorRegistry;
          const baseExceptionSchema = synthetic.getBaseException();
          if (baseExceptionSchema) {
            const ErrorCtor = synthetic.getErrorCtor(baseExceptionSchema) ?? Error;
            throw this.decorateServiceException(Object.assign(new ErrorCtor({ name: errorName }), errorMetadata), dataObject);
          }
          const d32 = dataObject;
          const message2 = d32?.message ?? d32?.Message ?? d32?.Error?.Message ?? d32?.Error?.message;
          throw this.decorateServiceException(Object.assign(new Error(message2), {
            name: errorName
          }, errorMetadata), dataObject);
        }
      }
      compose(composite, errorIdentifier, defaultNamespace) {
        let namespace = defaultNamespace;
        if (errorIdentifier.includes("#")) {
          [namespace] = errorIdentifier.split("#");
        }
        const staticRegistry = TypeRegistry.for(namespace);
        const defaultSyntheticRegistry = TypeRegistry.for("smithy.ts.sdk.synthetic." + defaultNamespace);
        composite.copyFrom(staticRegistry);
        composite.copyFrom(defaultSyntheticRegistry);
        this.errorRegistry = composite;
      }
      decorateServiceException(exception, additions = {}) {
        if (this.queryCompat) {
          const msg = exception.Message ?? additions.Message;
          const error4 = (0, import_smithy_client72.decorateServiceException)(exception, additions);
          if (msg) {
            error4.message = msg;
          }
          const errorObj = error4.Error ?? {};
          errorObj.Type = error4.Error?.Type;
          errorObj.Code = error4.Error?.Code;
          errorObj.Message = error4.Error?.message ?? error4.Error?.Message ?? msg;
          error4.Error = errorObj;
          const reqId = error4.$metadata.requestId;
          if (reqId) {
            error4.RequestId = reqId;
          }
          return error4;
        }
        return (0, import_smithy_client72.decorateServiceException)(exception, additions);
      }
      setQueryCompatError(output, response) {
        const queryErrorHeader = response.headers?.["x-amzn-query-error"];
        if (output !== void 0 && queryErrorHeader != null) {
          const [Code, Type] = queryErrorHeader.split(";");
          const keys = Object.keys(output);
          const Error2 = {
            Code,
            Type
          };
          output.Code = Code;
          output.Type = Type;
          for (let i32 = 0; i32 < keys.length; i32++) {
            const k32 = keys[i32];
            Error2[k32 === "message" ? "Message" : k32] = output[k32];
          }
          delete Error2.__type;
          output.Error = Error2;
        }
      }
      queryCompatOutput(queryCompatErrorData, errorData) {
        if (queryCompatErrorData.Error) {
          errorData.Error = queryCompatErrorData.Error;
        }
        if (queryCompatErrorData.Type) {
          errorData.Type = queryCompatErrorData.Type;
        }
        if (queryCompatErrorData.Code) {
          errorData.Code = queryCompatErrorData.Code;
        }
      }
      findQueryCompatibleError(registry, errorName) {
        try {
          return registry.getSchema(errorName);
        } catch (e32) {
          return registry.find((schema) => NormalizedSchema.of(schema).getMergedTraits().awsQueryError?.[0] === errorName);
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/cbor/AwsSmithyRpcV2CborProtocol.js
var AwsSmithyRpcV2CborProtocol3;
var init_AwsSmithyRpcV2CborProtocol5 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/cbor/AwsSmithyRpcV2CborProtocol.js"() {
    init_cbor2();
    init_schema4();
    init_ProtocolLib5();
    AwsSmithyRpcV2CborProtocol3 = class extends SmithyRpcV2CborProtocol {
      static {
        __name(this, "AwsSmithyRpcV2CborProtocol");
      }
      awsQueryCompatible;
      mixin;
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, awsQueryCompatible }) {
        super({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32 });
        this.awsQueryCompatible = !!awsQueryCompatible;
        this.mixin = new ProtocolLib5(this.awsQueryCompatible);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        if (this.awsQueryCompatible) {
          request4.headers["x-amzn-query-mode"] = "true";
        }
        return request4;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        if (this.awsQueryCompatible) {
          this.mixin.setQueryCompatError(dataObject, response);
        }
        const errorName = (() => {
          const compatHeader = response.headers["x-amzn-query-error"];
          if (compatHeader && this.awsQueryCompatible) {
            return compatHeader.split(";")[0];
          }
          return loadSmithyRpcV2CborErrorCode(response, dataObject) ?? "Unknown";
        })();
        this.mixin.compose(this.compositeErrorRegistry, errorName, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorName, this.options.defaultNamespace, response, dataObject, metadata, this.awsQueryCompatible ? this.mixin.findQueryCompatibleError : void 0);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        const output = {};
        for (const [name, member7] of ns.structIterator()) {
          if (dataObject[name] != null) {
            output[name] = this.deserializer.readValue(member7, dataObject[name]);
          }
        }
        if (this.awsQueryCompatible) {
          this.mixin.queryCompatOutput(dataObject, output);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/coercing-serializers.js
var _toStr3, _toBool3, _toNum3;
var init_coercing_serializers5 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/coercing-serializers.js"() {
    _toStr3 = /* @__PURE__ */ __name((val) => {
      if (val == null) {
        return val;
      }
      if (typeof val === "number" || typeof val === "bigint") {
        const warning2 = new Error(`Received number ${val} where a string was expected.`);
        warning2.name = "Warning";
        console.warn(warning2);
        return String(val);
      }
      if (typeof val === "boolean") {
        const warning2 = new Error(`Received boolean ${val} where a string was expected.`);
        warning2.name = "Warning";
        console.warn(warning2);
        return String(val);
      }
      return val;
    }, "_toStr");
    _toBool3 = /* @__PURE__ */ __name((val) => {
      if (val == null) {
        return val;
      }
      if (typeof val === "number") {
      }
      if (typeof val === "string") {
        const lowercase = val.toLowerCase();
        if (val !== "" && lowercase !== "false" && lowercase !== "true") {
          const warning2 = new Error(`Received string "${val}" where a boolean was expected.`);
          warning2.name = "Warning";
          console.warn(warning2);
        }
        return val !== "" && lowercase !== "false";
      }
      return val;
    }, "_toBool");
    _toNum3 = /* @__PURE__ */ __name((val) => {
      if (val == null) {
        return val;
      }
      if (typeof val === "boolean") {
      }
      if (typeof val === "string") {
        const num = Number(val);
        if (num.toString() !== val) {
          const warning2 = new Error(`Received string "${val}" where a number was expected.`);
          warning2.name = "Warning";
          console.warn(warning2);
          return val;
        }
        return num;
      }
      return val;
    }, "_toNum");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ConfigurableSerdeContext.js
var SerdeContextConfig5;
var init_ConfigurableSerdeContext5 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ConfigurableSerdeContext.js"() {
    SerdeContextConfig5 = class {
      static {
        __name(this, "SerdeContextConfig");
      }
      serdeContext;
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/UnionSerde.js
var UnionSerde5;
var init_UnionSerde5 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/UnionSerde.js"() {
    UnionSerde5 = class {
      static {
        __name(this, "UnionSerde");
      }
      from;
      to;
      keys;
      constructor(from, to) {
        this.from = from;
        this.to = to;
        const keys = Object.keys(this.from);
        const set = new Set(keys);
        set.delete("__type");
        this.keys = set;
      }
      mark(key) {
        this.keys.delete(key);
      }
      hasUnknown() {
        return this.keys.size === 1 && Object.keys(this.to).length === 0;
      }
      writeUnknown() {
        if (this.hasUnknown()) {
          const k32 = this.keys.values().next().value;
          const v = this.from[k32];
          this.to.$unknown = [k32, v];
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReviver.js
function jsonReviver5(key, value, context) {
  if (context?.source) {
    const numericString = context.source;
    if (typeof value === "number") {
      if (value > Number.MAX_SAFE_INTEGER || value < Number.MIN_SAFE_INTEGER || numericString !== String(value)) {
        const isFractional = numericString.includes(".");
        if (isFractional) {
          return new NumericValue(numericString, "bigDecimal");
        } else {
          return BigInt(numericString);
        }
      }
    }
  }
  return value;
}
var init_jsonReviver5 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReviver.js"() {
    init_serde();
    __name(jsonReviver5, "jsonReviver");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/common.js
var import_smithy_client73, import_util_utf820, collectBodyString5;
var init_common6 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/common.js"() {
    import_smithy_client73 = __toESM(require_dist_cjs34());
    import_util_utf820 = __toESM(require_dist_cjs9());
    collectBodyString5 = /* @__PURE__ */ __name((streamBody, context) => (0, import_smithy_client73.collectBody)(streamBody, context).then((body) => (context?.utf8Encoder ?? import_util_utf820.toUtf8)(body)), "collectBodyString");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/parseJsonBody.js
var parseJsonBody5, parseJsonErrorBody3, findKey5, sanitizeErrorCode5, loadRestJsonErrorCode5;
var init_parseJsonBody5 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/parseJsonBody.js"() {
    init_common6();
    parseJsonBody5 = /* @__PURE__ */ __name((streamBody, context) => collectBodyString5(streamBody, context).then((encoded) => {
      if (encoded.length) {
        try {
          return JSON.parse(encoded);
        } catch (e32) {
          if (e32?.name === "SyntaxError") {
            Object.defineProperty(e32, "$responseBodyText", {
              value: encoded
            });
          }
          throw e32;
        }
      }
      return {};
    }), "parseJsonBody");
    parseJsonErrorBody3 = /* @__PURE__ */ __name(async (errorBody, context) => {
      const value = await parseJsonBody5(errorBody, context);
      value.message = value.message ?? value.Message;
      return value;
    }, "parseJsonErrorBody");
    findKey5 = /* @__PURE__ */ __name((object, key) => Object.keys(object).find((k32) => k32.toLowerCase() === key.toLowerCase()), "findKey");
    sanitizeErrorCode5 = /* @__PURE__ */ __name((rawValue) => {
      let cleanValue = rawValue;
      if (typeof cleanValue === "number") {
        cleanValue = cleanValue.toString();
      }
      if (cleanValue.indexOf(",") >= 0) {
        cleanValue = cleanValue.split(",")[0];
      }
      if (cleanValue.indexOf(":") >= 0) {
        cleanValue = cleanValue.split(":")[0];
      }
      if (cleanValue.indexOf("#") >= 0) {
        cleanValue = cleanValue.split("#")[1];
      }
      return cleanValue;
    }, "sanitizeErrorCode");
    loadRestJsonErrorCode5 = /* @__PURE__ */ __name((output, data3) => {
      const headerKey = findKey5(output.headers, "x-amzn-errortype");
      if (headerKey !== void 0) {
        return sanitizeErrorCode5(output.headers[headerKey]);
      }
      if (data3 && typeof data3 === "object") {
        const codeKey = findKey5(data3, "code");
        if (codeKey && data3[codeKey] !== void 0) {
          return sanitizeErrorCode5(data3[codeKey]);
        }
        if (data3["__type"] !== void 0) {
          return sanitizeErrorCode5(data3["__type"]);
        }
      }
    }, "loadRestJsonErrorCode");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeDeserializer.js
var import_util_base6424, JsonShapeDeserializer5;
var init_JsonShapeDeserializer5 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeDeserializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_util_base6424 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext5();
    init_UnionSerde5();
    init_jsonReviver5();
    init_parseJsonBody5();
    JsonShapeDeserializer5 = class extends SerdeContextConfig5 {
      static {
        __name(this, "JsonShapeDeserializer");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      async read(schema, data3) {
        return this._read(schema, typeof data3 === "string" ? JSON.parse(data3, jsonReviver5) : await parseJsonBody5(data3, this.serdeContext));
      }
      readObject(schema, data3) {
        return this._read(schema, data3);
      }
      _read(schema, value) {
        const isObject3 = value !== null && typeof value === "object";
        const ns = NormalizedSchema.of(schema);
        if (isObject3) {
          if (ns.isStructSchema()) {
            const record = value;
            const union = ns.isUnionSchema();
            const out = {};
            let nameMap = void 0;
            const { jsonName } = this.settings;
            if (jsonName) {
              nameMap = {};
            }
            let unionSerde;
            if (union) {
              unionSerde = new UnionSerde5(record, out);
            }
            for (const [memberName, memberSchema] of ns.structIterator()) {
              let fromKey = memberName;
              if (jsonName) {
                fromKey = memberSchema.getMergedTraits().jsonName ?? fromKey;
                nameMap[fromKey] = memberName;
              }
              if (union) {
                unionSerde.mark(fromKey);
              }
              if (record[fromKey] != null) {
                out[memberName] = this._read(memberSchema, record[fromKey]);
              }
            }
            if (union) {
              unionSerde.writeUnknown();
            } else if (typeof record.__type === "string") {
              for (const k32 in record) {
                const v = record[k32];
                const t = jsonName ? nameMap[k32] ?? k32 : k32;
                if (!(t in out)) {
                  out[t] = v;
                }
              }
            }
            return out;
          }
          if (Array.isArray(value) && ns.isListSchema()) {
            const listMember = ns.getValueSchema();
            const out = [];
            for (const item of value) {
              out.push(this._read(listMember, item));
            }
            return out;
          }
          if (ns.isMapSchema()) {
            const mapMember = ns.getValueSchema();
            const out = {};
            for (const _k in value) {
              out[_k] = this._read(mapMember, value[_k]);
            }
            return out;
          }
        }
        if (ns.isBlobSchema() && typeof value === "string") {
          return (0, import_util_base6424.fromBase64)(value);
        }
        const mediaType = ns.getMergedTraits().mediaType;
        if (ns.isStringSchema() && typeof value === "string" && mediaType) {
          const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
          if (isJson) {
            return LazyJsonString.from(value);
          }
          return value;
        }
        if (ns.isTimestampSchema() && value != null) {
          const format32 = determineTimestampFormat(ns, this.settings);
          switch (format32) {
            case 5:
              return parseRfc3339DateTimeWithOffset(value);
            case 6:
              return parseRfc7231DateTime(value);
            case 7:
              return parseEpochTimestamp(value);
            default:
              console.warn("Missing timestamp format, parsing value with Date constructor:", value);
              return new Date(value);
          }
        }
        if (ns.isBigIntegerSchema() && (typeof value === "number" || typeof value === "string")) {
          return BigInt(value);
        }
        if (ns.isBigDecimalSchema() && value != void 0) {
          if (value instanceof NumericValue) {
            return value;
          }
          const untyped = value;
          if (untyped.type === "bigDecimal" && "string" in untyped) {
            return new NumericValue(untyped.string, untyped.type);
          }
          return new NumericValue(String(value), "bigDecimal");
        }
        if (ns.isNumericSchema() && typeof value === "string") {
          switch (value) {
            case "Infinity":
              return Infinity;
            case "-Infinity":
              return -Infinity;
            case "NaN":
              return NaN;
          }
          return value;
        }
        if (ns.isDocumentSchema()) {
          if (isObject3) {
            const out = Array.isArray(value) ? [] : {};
            for (const k32 in value) {
              const v = value[k32];
              if (v instanceof NumericValue) {
                out[k32] = v;
              } else {
                out[k32] = this._read(ns, v);
              }
            }
            return out;
          } else {
            return structuredClone(value);
          }
        }
        return value;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReplacer.js
var NUMERIC_CONTROL_CHAR5, JsonReplacer5;
var init_jsonReplacer5 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReplacer.js"() {
    init_serde();
    NUMERIC_CONTROL_CHAR5 = String.fromCharCode(925);
    JsonReplacer5 = class {
      static {
        __name(this, "JsonReplacer");
      }
      values = /* @__PURE__ */ new Map();
      counter = 0;
      stage = 0;
      createReplacer() {
        if (this.stage === 1) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer already created.");
        }
        if (this.stage === 2) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer exhausted.");
        }
        this.stage = 1;
        return (key, value) => {
          if (value instanceof NumericValue) {
            const v = `${NUMERIC_CONTROL_CHAR5 + "nv" + this.counter++}_` + value.string;
            this.values.set(`"${v}"`, value.string);
            return v;
          }
          if (typeof value === "bigint") {
            const s = value.toString();
            const v = `${NUMERIC_CONTROL_CHAR5 + "b" + this.counter++}_` + s;
            this.values.set(`"${v}"`, s);
            return v;
          }
          return value;
        };
      }
      replaceInJson(json) {
        if (this.stage === 0) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer not created yet.");
        }
        if (this.stage === 2) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer exhausted.");
        }
        this.stage = 2;
        if (this.counter === 0) {
          return json;
        }
        for (const [key, value] of this.values) {
          json = json.replace(key, value);
        }
        return json;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeSerializer.js
var import_util_base6425, JsonShapeSerializer5;
var init_JsonShapeSerializer5 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeSerializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_util_base6425 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext5();
    init_jsonReplacer5();
    JsonShapeSerializer5 = class extends SerdeContextConfig5 {
      static {
        __name(this, "JsonShapeSerializer");
      }
      settings;
      buffer;
      useReplacer = false;
      rootSchema;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value) {
        this.rootSchema = NormalizedSchema.of(schema);
        this.buffer = this._write(this.rootSchema, value);
      }
      flush() {
        const { rootSchema, useReplacer } = this;
        this.rootSchema = void 0;
        this.useReplacer = false;
        if (rootSchema?.isStructSchema() || rootSchema?.isDocumentSchema()) {
          if (!useReplacer) {
            return JSON.stringify(this.buffer);
          }
          const replacer = new JsonReplacer5();
          return replacer.replaceInJson(JSON.stringify(this.buffer, replacer.createReplacer(), 0));
        }
        return this.buffer;
      }
      writeDiscriminatedDocument(schema, value) {
        this.write(schema, value);
        if (typeof this.buffer === "object") {
          this.buffer.__type = NormalizedSchema.of(schema).getName(true);
        }
      }
      _write(schema, value, container) {
        const isObject3 = value !== null && typeof value === "object";
        const ns = NormalizedSchema.of(schema);
        if (isObject3) {
          if (ns.isStructSchema()) {
            const record = value;
            const out = {};
            const { jsonName } = this.settings;
            let nameMap = void 0;
            if (jsonName) {
              nameMap = {};
            }
            let outCount = 0;
            for (const [memberName, memberSchema] of ns.structIterator()) {
              const serializableValue = this._write(memberSchema, record[memberName], ns);
              if (serializableValue !== void 0) {
                let targetKey = memberName;
                if (jsonName) {
                  targetKey = memberSchema.getMergedTraits().jsonName ?? memberName;
                  nameMap[memberName] = targetKey;
                }
                out[targetKey] = serializableValue;
                outCount++;
              }
            }
            if (ns.isUnionSchema() && outCount === 0) {
              const { $unknown } = record;
              if (Array.isArray($unknown)) {
                const [k32, v] = $unknown;
                out[k32] = this._write(15, v);
              }
            } else if (typeof record.__type === "string") {
              for (const k32 in record) {
                const v = record[k32];
                const targetKey = jsonName ? nameMap[k32] ?? k32 : k32;
                if (!(targetKey in out)) {
                  out[targetKey] = this._write(15, v);
                }
              }
            }
            return out;
          }
          if (Array.isArray(value) && ns.isListSchema()) {
            const listMember = ns.getValueSchema();
            const out = [];
            const sparse = !!ns.getMergedTraits().sparse;
            for (const item of value) {
              if (sparse || item != null) {
                out.push(this._write(listMember, item));
              }
            }
            return out;
          }
          if (ns.isMapSchema()) {
            const mapMember = ns.getValueSchema();
            const out = {};
            const sparse = !!ns.getMergedTraits().sparse;
            for (const _k in value) {
              const _v = value[_k];
              if (sparse || _v != null) {
                out[_k] = this._write(mapMember, _v);
              }
            }
            return out;
          }
          if (value instanceof Uint8Array && (ns.isBlobSchema() || ns.isDocumentSchema())) {
            if (ns === this.rootSchema) {
              return value;
            }
            return (this.serdeContext?.base64Encoder ?? import_util_base6425.toBase64)(value);
          }
          if (value instanceof Date && (ns.isTimestampSchema() || ns.isDocumentSchema())) {
            const format32 = determineTimestampFormat(ns, this.settings);
            switch (format32) {
              case 5:
                return value.toISOString().replace(".000Z", "Z");
              case 6:
                return dateToUtcString(value);
              case 7:
                return value.getTime() / 1e3;
              default:
                console.warn("Missing timestamp format, using epoch seconds", value);
                return value.getTime() / 1e3;
            }
          }
          if (value instanceof NumericValue) {
            this.useReplacer = true;
          }
        }
        if (value === null && container?.isStructSchema()) {
          return void 0;
        }
        if (ns.isStringSchema()) {
          if (typeof value === "undefined" && ns.isIdempotencyToken()) {
            return (0, import_uuid.v4)();
          }
          const mediaType = ns.getMergedTraits().mediaType;
          if (value != null && mediaType) {
            const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
            if (isJson) {
              return LazyJsonString.from(value);
            }
          }
          return value;
        }
        if (typeof value === "number" && ns.isNumericSchema()) {
          if (Math.abs(value) === Infinity || isNaN(value)) {
            return String(value);
          }
          return value;
        }
        if (typeof value === "string" && ns.isBlobSchema()) {
          if (ns === this.rootSchema) {
            return value;
          }
          return (this.serdeContext?.base64Encoder ?? import_util_base6425.toBase64)(value);
        }
        if (typeof value === "bigint") {
          this.useReplacer = true;
        }
        if (ns.isDocumentSchema()) {
          if (isObject3) {
            const out = Array.isArray(value) ? [] : {};
            for (const k32 in value) {
              const v = value[k32];
              if (v instanceof NumericValue) {
                this.useReplacer = true;
                out[k32] = v;
              } else {
                out[k32] = this._write(ns, v);
              }
            }
            return out;
          } else {
            return structuredClone(value);
          }
        }
        return value;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonCodec.js
var JsonCodec5;
var init_JsonCodec5 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonCodec.js"() {
    init_ConfigurableSerdeContext5();
    init_JsonShapeDeserializer5();
    init_JsonShapeSerializer5();
    JsonCodec5 = class extends SerdeContextConfig5 {
      static {
        __name(this, "JsonCodec");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      createSerializer() {
        const serializer = new JsonShapeSerializer5(this.settings);
        serializer.setSerdeContext(this.serdeContext);
        return serializer;
      }
      createDeserializer() {
        const deserializer = new JsonShapeDeserializer5(this.settings);
        deserializer.setSerdeContext(this.serdeContext);
        return deserializer;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJsonRpcProtocol.js
var AwsJsonRpcProtocol3;
var init_AwsJsonRpcProtocol5 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJsonRpcProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib5();
    init_JsonCodec5();
    init_parseJsonBody5();
    AwsJsonRpcProtocol3 = class extends RpcProtocol {
      static {
        __name(this, "AwsJsonRpcProtocol");
      }
      serializer;
      deserializer;
      serviceTarget;
      codec;
      mixin;
      awsQueryCompatible;
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, serviceTarget, awsQueryCompatible, jsonCodec }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32
        });
        this.serviceTarget = serviceTarget;
        this.codec = jsonCodec ?? new JsonCodec5({
          timestampFormat: {
            useTrait: true,
            default: 7
          },
          jsonName: false
        });
        this.serializer = this.codec.createSerializer();
        this.deserializer = this.codec.createDeserializer();
        this.awsQueryCompatible = !!awsQueryCompatible;
        this.mixin = new ProtocolLib5(this.awsQueryCompatible);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        if (!request4.path.endsWith("/")) {
          request4.path += "/";
        }
        request4.headers["content-type"] = `application/x-amz-json-${this.getJsonRpcVersion()}`;
        request4.headers["x-amz-target"] = `${this.serviceTarget}.${operationSchema.name}`;
        if (this.awsQueryCompatible) {
          request4.headers["x-amzn-query-mode"] = "true";
        }
        if (deref(operationSchema.input) === "unit" || !request4.body) {
          request4.body = "{}";
        }
        return request4;
      }
      getPayloadCodec() {
        return this.codec;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        if (this.awsQueryCompatible) {
          this.mixin.setQueryCompatError(dataObject, response);
        }
        const errorIdentifier = loadRestJsonErrorCode5(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata, this.awsQueryCompatible ? this.mixin.findQueryCompatibleError : void 0);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          if (dataObject[name] != null) {
            output[name] = errorDeserializer.readObject(member7, dataObject[name]);
          }
        }
        if (this.awsQueryCompatible) {
          this.mixin.queryCompatOutput(dataObject, output);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_0Protocol.js
var AwsJson1_0Protocol3;
var init_AwsJson1_0Protocol5 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_0Protocol.js"() {
    init_AwsJsonRpcProtocol5();
    AwsJson1_0Protocol3 = class extends AwsJsonRpcProtocol3 {
      static {
        __name(this, "AwsJson1_0Protocol");
      }
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, serviceTarget, awsQueryCompatible, jsonCodec }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32,
          serviceTarget,
          awsQueryCompatible,
          jsonCodec
        });
      }
      getShapeId() {
        return "aws.protocols#awsJson1_0";
      }
      getJsonRpcVersion() {
        return "1.0";
      }
      getDefaultContentType() {
        return "application/x-amz-json-1.0";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_1Protocol.js
var AwsJson1_1Protocol3;
var init_AwsJson1_1Protocol5 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_1Protocol.js"() {
    init_AwsJsonRpcProtocol5();
    AwsJson1_1Protocol3 = class extends AwsJsonRpcProtocol3 {
      static {
        __name(this, "AwsJson1_1Protocol");
      }
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, serviceTarget, awsQueryCompatible, jsonCodec }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32,
          serviceTarget,
          awsQueryCompatible,
          jsonCodec
        });
      }
      getShapeId() {
        return "aws.protocols#awsJson1_1";
      }
      getJsonRpcVersion() {
        return "1.1";
      }
      getDefaultContentType() {
        return "application/x-amz-json-1.1";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsRestJsonProtocol.js
var AwsRestJsonProtocol5;
var init_AwsRestJsonProtocol5 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsRestJsonProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib5();
    init_JsonCodec5();
    init_parseJsonBody5();
    AwsRestJsonProtocol5 = class extends HttpBindingProtocol {
      static {
        __name(this, "AwsRestJsonProtocol");
      }
      serializer;
      deserializer;
      codec;
      mixin = new ProtocolLib5();
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32 }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32
        });
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 7
          },
          httpBindings: true,
          jsonName: true
        };
        this.codec = new JsonCodec5(settings);
        this.serializer = new HttpInterceptingShapeSerializer(this.codec.createSerializer(), settings);
        this.deserializer = new HttpInterceptingShapeDeserializer(this.codec.createDeserializer(), settings);
      }
      getShapeId() {
        return "aws.protocols#restJson1";
      }
      getPayloadCodec() {
        return this.codec;
      }
      setSerdeContext(serdeContext) {
        this.codec.setSerdeContext(serdeContext);
        super.setSerdeContext(serdeContext);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        const inputSchema = NormalizedSchema.of(operationSchema.input);
        if (!request4.headers["content-type"]) {
          const contentType = this.mixin.resolveRestContentType(this.getDefaultContentType(), inputSchema);
          if (contentType) {
            request4.headers["content-type"] = contentType;
          }
        }
        if (request4.body == null && request4.headers["content-type"] === this.getDefaultContentType()) {
          request4.body = "{}";
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        const output = await super.deserializeResponse(operationSchema, context, response);
        const outputSchema = NormalizedSchema.of(operationSchema.output);
        for (const [name, member7] of outputSchema.structIterator()) {
          if (member7.getMemberTraits().httpPayload && !(name in output)) {
            output[name] = null;
          }
        }
        return output;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = loadRestJsonErrorCode5(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        await this.deserializeHttpMessage(errorSchema, context, response, dataObject);
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().jsonName ?? name;
          output[name] = errorDeserializer.readObject(member7, dataObject[target]);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      getDefaultContentType() {
        return "application/json";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/awsExpectUnion.js
var import_smithy_client74, awsExpectUnion3;
var init_awsExpectUnion5 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/awsExpectUnion.js"() {
    import_smithy_client74 = __toESM(require_dist_cjs34());
    awsExpectUnion3 = /* @__PURE__ */ __name((value) => {
      if (value == null) {
        return void 0;
      }
      if (typeof value === "object" && "__type" in value) {
        delete value.__type;
      }
      return (0, import_smithy_client74.expectUnion)(value);
    }, "awsExpectUnion");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeDeserializer.js
var import_xml_builder8, import_smithy_client75, import_util_utf821, XmlShapeDeserializer4;
var init_XmlShapeDeserializer5 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeDeserializer.js"() {
    import_xml_builder8 = __toESM(require_dist_cjs47());
    init_protocols();
    init_schema4();
    import_smithy_client75 = __toESM(require_dist_cjs34());
    import_util_utf821 = __toESM(require_dist_cjs9());
    init_ConfigurableSerdeContext5();
    init_UnionSerde5();
    XmlShapeDeserializer4 = class extends SerdeContextConfig5 {
      static {
        __name(this, "XmlShapeDeserializer");
      }
      settings;
      stringDeserializer;
      constructor(settings) {
        super();
        this.settings = settings;
        this.stringDeserializer = new FromStringShapeDeserializer(settings);
      }
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
        this.stringDeserializer.setSerdeContext(serdeContext);
      }
      read(schema, bytes, key) {
        const ns = NormalizedSchema.of(schema);
        const memberSchemas = ns.getMemberSchemas();
        const isEventPayload = ns.isStructSchema() && ns.isMemberSchema() && !!Object.values(memberSchemas).find((memberNs) => {
          return !!memberNs.getMemberTraits().eventPayload;
        });
        if (isEventPayload) {
          const output = {};
          const memberName = Object.keys(memberSchemas)[0];
          const eventMemberSchema = memberSchemas[memberName];
          if (eventMemberSchema.isBlobSchema()) {
            output[memberName] = bytes;
          } else {
            output[memberName] = this.read(memberSchemas[memberName], bytes);
          }
          return output;
        }
        const xmlString = (this.serdeContext?.utf8Encoder ?? import_util_utf821.toUtf8)(bytes);
        const parsedObject = this.parseXml(xmlString);
        return this.readSchema(schema, key ? parsedObject[key] : parsedObject);
      }
      readSchema(_schema, value) {
        const ns = NormalizedSchema.of(_schema);
        if (ns.isUnitSchema()) {
          return;
        }
        const traits = ns.getMergedTraits();
        if (ns.isListSchema() && !Array.isArray(value)) {
          return this.readSchema(ns, [value]);
        }
        if (value == null) {
          return value;
        }
        if (typeof value === "object") {
          const flat = !!traits.xmlFlattened;
          if (ns.isListSchema()) {
            const listValue = ns.getValueSchema();
            const buffer2 = [];
            const sourceKey = listValue.getMergedTraits().xmlName ?? "member";
            const source = flat ? value : (value[0] ?? value)[sourceKey];
            if (source == null) {
              return buffer2;
            }
            const sourceArray = Array.isArray(source) ? source : [source];
            for (const v of sourceArray) {
              buffer2.push(this.readSchema(listValue, v));
            }
            return buffer2;
          }
          const buffer = {};
          if (ns.isMapSchema()) {
            const keyNs = ns.getKeySchema();
            const memberNs = ns.getValueSchema();
            let entries;
            if (flat) {
              entries = Array.isArray(value) ? value : [value];
            } else {
              entries = Array.isArray(value.entry) ? value.entry : [value.entry];
            }
            const keyProperty = keyNs.getMergedTraits().xmlName ?? "key";
            const valueProperty = memberNs.getMergedTraits().xmlName ?? "value";
            for (const entry of entries) {
              const key = entry[keyProperty];
              const value2 = entry[valueProperty];
              buffer[key] = this.readSchema(memberNs, value2);
            }
            return buffer;
          }
          if (ns.isStructSchema()) {
            const union = ns.isUnionSchema();
            let unionSerde;
            if (union) {
              unionSerde = new UnionSerde5(value, buffer);
            }
            for (const [memberName, memberSchema] of ns.structIterator()) {
              const memberTraits = memberSchema.getMergedTraits();
              const xmlObjectKey = !memberTraits.httpPayload ? memberSchema.getMemberTraits().xmlName ?? memberName : memberTraits.xmlName ?? memberSchema.getName();
              if (union) {
                unionSerde.mark(xmlObjectKey);
              }
              if (value[xmlObjectKey] != null) {
                buffer[memberName] = this.readSchema(memberSchema, value[xmlObjectKey]);
              }
            }
            if (union) {
              unionSerde.writeUnknown();
            }
            return buffer;
          }
          if (ns.isDocumentSchema()) {
            return value;
          }
          throw new Error(`@aws-sdk/core/protocols - xml deserializer unhandled schema type for ${ns.getName(true)}`);
        }
        if (ns.isListSchema()) {
          return [];
        }
        if (ns.isMapSchema() || ns.isStructSchema()) {
          return {};
        }
        return this.stringDeserializer.read(ns, value);
      }
      parseXml(xml) {
        if (xml.length) {
          let parsedObj;
          try {
            parsedObj = (0, import_xml_builder8.parseXML)(xml);
          } catch (e32) {
            if (e32 && typeof e32 === "object") {
              Object.defineProperty(e32, "$responseBodyText", {
                value: xml
              });
            }
            throw e32;
          }
          const textNodeName = "#text";
          const key = Object.keys(parsedObj)[0];
          const parsedObjToReturn = parsedObj[key];
          if (parsedObjToReturn[textNodeName]) {
            parsedObjToReturn[key] = parsedObjToReturn[textNodeName];
            delete parsedObjToReturn[textNodeName];
          }
          return (0, import_smithy_client75.getValueFromTextNode)(parsedObjToReturn);
        }
        return {};
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QueryShapeSerializer.js
var import_smithy_client76, import_util_base6426, QueryShapeSerializer4;
var init_QueryShapeSerializer5 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QueryShapeSerializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_smithy_client76 = __toESM(require_dist_cjs34());
    import_util_base6426 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext5();
    QueryShapeSerializer4 = class extends SerdeContextConfig5 {
      static {
        __name(this, "QueryShapeSerializer");
      }
      settings;
      buffer;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value, prefix = "") {
        if (this.buffer === void 0) {
          this.buffer = "";
        }
        const ns = NormalizedSchema.of(schema);
        if (prefix && !prefix.endsWith(".")) {
          prefix += ".";
        }
        if (ns.isBlobSchema()) {
          if (typeof value === "string" || value instanceof Uint8Array) {
            this.writeKey(prefix);
            this.writeValue((this.serdeContext?.base64Encoder ?? import_util_base6426.toBase64)(value));
          }
        } else if (ns.isBooleanSchema() || ns.isNumericSchema() || ns.isStringSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(String(value));
          } else if (ns.isIdempotencyToken()) {
            this.writeKey(prefix);
            this.writeValue((0, import_uuid.v4)());
          }
        } else if (ns.isBigIntegerSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(String(value));
          }
        } else if (ns.isBigDecimalSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(value instanceof NumericValue ? value.string : String(value));
          }
        } else if (ns.isTimestampSchema()) {
          if (value instanceof Date) {
            this.writeKey(prefix);
            const format32 = determineTimestampFormat(ns, this.settings);
            switch (format32) {
              case 5:
                this.writeValue(value.toISOString().replace(".000Z", "Z"));
                break;
              case 6:
                this.writeValue((0, import_smithy_client76.dateToUtcString)(value));
                break;
              case 7:
                this.writeValue(String(value.getTime() / 1e3));
                break;
            }
          }
        } else if (ns.isDocumentSchema()) {
          if (Array.isArray(value)) {
            this.write(64 | 15, value, prefix);
          } else if (value instanceof Date) {
            this.write(4, value, prefix);
          } else if (value instanceof Uint8Array) {
            this.write(21, value, prefix);
          } else if (value && typeof value === "object") {
            this.write(128 | 15, value, prefix);
          } else {
            this.writeKey(prefix);
            this.writeValue(String(value));
          }
        } else if (ns.isListSchema()) {
          if (Array.isArray(value)) {
            if (value.length === 0) {
              if (this.settings.serializeEmptyLists) {
                this.writeKey(prefix);
                this.writeValue("");
              }
            } else {
              const member7 = ns.getValueSchema();
              const flat = this.settings.flattenLists || ns.getMergedTraits().xmlFlattened;
              let i32 = 1;
              for (const item of value) {
                if (item == null) {
                  continue;
                }
                const traits = member7.getMergedTraits();
                const suffix = this.getKey("member", traits.xmlName, traits.ec2QueryName);
                const key = flat ? `${prefix}${i32}` : `${prefix}${suffix}.${i32}`;
                this.write(member7, item, key);
                ++i32;
              }
            }
          }
        } else if (ns.isMapSchema()) {
          if (value && typeof value === "object") {
            const keySchema = ns.getKeySchema();
            const memberSchema = ns.getValueSchema();
            const flat = ns.getMergedTraits().xmlFlattened;
            let i32 = 1;
            for (const k32 in value) {
              const v = value[k32];
              if (v == null) {
                continue;
              }
              const keyTraits = keySchema.getMergedTraits();
              const keySuffix = this.getKey("key", keyTraits.xmlName, keyTraits.ec2QueryName);
              const key = flat ? `${prefix}${i32}.${keySuffix}` : `${prefix}entry.${i32}.${keySuffix}`;
              const valTraits = memberSchema.getMergedTraits();
              const valueSuffix = this.getKey("value", valTraits.xmlName, valTraits.ec2QueryName);
              const valueKey = flat ? `${prefix}${i32}.${valueSuffix}` : `${prefix}entry.${i32}.${valueSuffix}`;
              this.write(keySchema, k32, key);
              this.write(memberSchema, v, valueKey);
              ++i32;
            }
          }
        } else if (ns.isStructSchema()) {
          if (value && typeof value === "object") {
            let didWriteMember = false;
            for (const [memberName, member7] of ns.structIterator()) {
              if (value[memberName] == null && !member7.isIdempotencyToken()) {
                continue;
              }
              const traits = member7.getMergedTraits();
              const suffix = this.getKey(memberName, traits.xmlName, traits.ec2QueryName, "struct");
              const key = `${prefix}${suffix}`;
              this.write(member7, value[memberName], key);
              didWriteMember = true;
            }
            if (!didWriteMember && ns.isUnionSchema()) {
              const { $unknown } = value;
              if (Array.isArray($unknown)) {
                const [k32, v] = $unknown;
                const key = `${prefix}${k32}`;
                this.write(15, v, key);
              }
            }
          }
        } else if (ns.isUnitSchema()) {
        } else {
          throw new Error(`@aws-sdk/core/protocols - QuerySerializer unrecognized schema type ${ns.getName(true)}`);
        }
      }
      flush() {
        if (this.buffer === void 0) {
          throw new Error("@aws-sdk/core/protocols - QuerySerializer cannot flush with nothing written to buffer.");
        }
        const str = this.buffer;
        delete this.buffer;
        return str;
      }
      getKey(memberName, xmlName, ec2QueryName, keySource) {
        const { ec2, capitalizeKeys } = this.settings;
        if (ec2 && ec2QueryName) {
          return ec2QueryName;
        }
        const key = xmlName ?? memberName;
        if (capitalizeKeys && keySource === "struct") {
          return key[0].toUpperCase() + key.slice(1);
        }
        return key;
      }
      writeKey(key) {
        if (key.endsWith(".")) {
          key = key.slice(0, key.length - 1);
        }
        this.buffer += `&${extendedEncodeURIComponent(key)}=`;
      }
      writeValue(value) {
        this.buffer += extendedEncodeURIComponent(value);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsQueryProtocol.js
var AwsQueryProtocol4;
var init_AwsQueryProtocol5 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsQueryProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib5();
    init_XmlShapeDeserializer5();
    init_QueryShapeSerializer5();
    AwsQueryProtocol4 = class extends RpcProtocol {
      static {
        __name(this, "AwsQueryProtocol");
      }
      options;
      serializer;
      deserializer;
      mixin = new ProtocolLib5();
      constructor(options) {
        super({
          defaultNamespace: options.defaultNamespace,
          errorTypeRegistries: options.errorTypeRegistries
        });
        this.options = options;
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 5
          },
          httpBindings: false,
          xmlNamespace: options.xmlNamespace,
          serviceNamespace: options.defaultNamespace,
          serializeEmptyLists: true
        };
        this.serializer = new QueryShapeSerializer4(settings);
        this.deserializer = new XmlShapeDeserializer4(settings);
      }
      getShapeId() {
        return "aws.protocols#awsQuery";
      }
      setSerdeContext(serdeContext) {
        this.serializer.setSerdeContext(serdeContext);
        this.deserializer.setSerdeContext(serdeContext);
      }
      getPayloadCodec() {
        throw new Error("AWSQuery protocol has no payload codec.");
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        if (!request4.path.endsWith("/")) {
          request4.path += "/";
        }
        request4.headers["content-type"] = "application/x-www-form-urlencoded";
        if (deref(operationSchema.input) === "unit" || !request4.body) {
          request4.body = "";
        }
        const action = operationSchema.name.split("#")[1] ?? operationSchema.name;
        request4.body = `Action=${action}&Version=${this.options.version}` + request4.body;
        if (request4.body.endsWith("&")) {
          request4.body = request4.body.slice(-1);
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        const deserializer = this.deserializer;
        const ns = NormalizedSchema.of(operationSchema.output);
        const dataObject = {};
        if (response.statusCode >= 300) {
          const bytes2 = await collectBody(response.body, context);
          if (bytes2.byteLength > 0) {
            Object.assign(dataObject, await deserializer.read(15, bytes2));
          }
          await this.handleError(operationSchema, context, response, dataObject, this.deserializeMetadata(response));
        }
        for (const header in response.headers) {
          const value = response.headers[header];
          delete response.headers[header];
          response.headers[header.toLowerCase()] = value;
        }
        const shortName = operationSchema.name.split("#")[1] ?? operationSchema.name;
        const awsQueryResultKey = ns.isStructSchema() && this.useNestedResult() ? shortName + "Result" : void 0;
        const bytes = await collectBody(response.body, context);
        if (bytes.byteLength > 0) {
          Object.assign(dataObject, await deserializer.read(ns, bytes, awsQueryResultKey));
        }
        dataObject.$metadata = this.deserializeMetadata(response);
        return dataObject;
      }
      useNestedResult() {
        return true;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = this.loadQueryErrorCode(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const errorData = this.loadQueryError(dataObject) ?? {};
        const message2 = this.loadQueryErrorMessage(dataObject);
        errorData.message = message2;
        errorData.Error = {
          Type: errorData.Type,
          Code: errorData.Code,
          Message: message2
        };
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, errorData, metadata, this.mixin.findQueryCompatibleError);
        const ns = NormalizedSchema.of(errorSchema);
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        const output = {
          Type: errorData.Error.Type,
          Code: errorData.Error.Code,
          Error: errorData.Error
        };
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().xmlName ?? name;
          const value = errorData[target] ?? dataObject[target];
          output[name] = this.deserializer.readSchema(member7, value);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      loadQueryErrorCode(output, data3) {
        const code = (data3.Errors?.[0]?.Error ?? data3.Errors?.Error ?? data3.Error)?.Code;
        if (code !== void 0) {
          return code;
        }
        if (output.statusCode == 404) {
          return "NotFound";
        }
      }
      loadQueryError(data3) {
        return data3.Errors?.[0]?.Error ?? data3.Errors?.Error ?? data3.Error;
      }
      loadQueryErrorMessage(data3) {
        const errorData = this.loadQueryError(data3);
        return errorData?.message ?? errorData?.Message ?? data3.message ?? data3.Message ?? "Unknown";
      }
      getDefaultContentType() {
        return "application/x-www-form-urlencoded";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsEc2QueryProtocol.js
var AwsEc2QueryProtocol3;
var init_AwsEc2QueryProtocol5 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsEc2QueryProtocol.js"() {
    init_AwsQueryProtocol5();
    AwsEc2QueryProtocol3 = class extends AwsQueryProtocol4 {
      static {
        __name(this, "AwsEc2QueryProtocol");
      }
      options;
      constructor(options) {
        super(options);
        this.options = options;
        const ec2Settings = {
          capitalizeKeys: true,
          flattenLists: true,
          serializeEmptyLists: false,
          ec2: true
        };
        Object.assign(this.serializer.settings, ec2Settings);
      }
      getShapeId() {
        return "aws.protocols#ec2Query";
      }
      useNestedResult() {
        return false;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QuerySerializerSettings.js
var init_QuerySerializerSettings5 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QuerySerializerSettings.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/parseXmlBody.js
var import_xml_builder9, import_smithy_client77, parseXmlBody3, parseXmlErrorBody3, loadRestXmlErrorCode3;
var init_parseXmlBody5 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/parseXmlBody.js"() {
    import_xml_builder9 = __toESM(require_dist_cjs47());
    import_smithy_client77 = __toESM(require_dist_cjs34());
    init_common6();
    parseXmlBody3 = /* @__PURE__ */ __name((streamBody, context) => collectBodyString5(streamBody, context).then((encoded) => {
      if (encoded.length) {
        let parsedObj;
        try {
          parsedObj = (0, import_xml_builder9.parseXML)(encoded);
        } catch (e32) {
          if (e32 && typeof e32 === "object") {
            Object.defineProperty(e32, "$responseBodyText", {
              value: encoded
            });
          }
          throw e32;
        }
        const textNodeName = "#text";
        const key = Object.keys(parsedObj)[0];
        const parsedObjToReturn = parsedObj[key];
        if (parsedObjToReturn[textNodeName]) {
          parsedObjToReturn[key] = parsedObjToReturn[textNodeName];
          delete parsedObjToReturn[textNodeName];
        }
        return (0, import_smithy_client77.getValueFromTextNode)(parsedObjToReturn);
      }
      return {};
    }), "parseXmlBody");
    parseXmlErrorBody3 = /* @__PURE__ */ __name(async (errorBody, context) => {
      const value = await parseXmlBody3(errorBody, context);
      if (value.Error) {
        value.Error.message = value.Error.message ?? value.Error.Message;
      }
      return value;
    }, "parseXmlErrorBody");
    loadRestXmlErrorCode3 = /* @__PURE__ */ __name((output, data3) => {
      if (data3?.Error?.Code !== void 0) {
        return data3.Error.Code;
      }
      if (data3?.Code !== void 0) {
        return data3.Code;
      }
      if (output.statusCode == 404) {
        return "NotFound";
      }
    }, "loadRestXmlErrorCode");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeSerializer.js
var import_xml_builder10, import_smithy_client78, import_util_base6427, XmlShapeSerializer3;
var init_XmlShapeSerializer5 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeSerializer.js"() {
    import_xml_builder10 = __toESM(require_dist_cjs47());
    init_protocols();
    init_schema4();
    init_serde();
    import_smithy_client78 = __toESM(require_dist_cjs34());
    import_util_base6427 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext5();
    XmlShapeSerializer3 = class extends SerdeContextConfig5 {
      static {
        __name(this, "XmlShapeSerializer");
      }
      settings;
      stringBuffer;
      byteBuffer;
      buffer;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value) {
        const ns = NormalizedSchema.of(schema);
        if (ns.isStringSchema() && typeof value === "string") {
          this.stringBuffer = value;
        } else if (ns.isBlobSchema()) {
          this.byteBuffer = "byteLength" in value ? value : (this.serdeContext?.base64Decoder ?? import_util_base6427.fromBase64)(value);
        } else {
          this.buffer = this.writeStruct(ns, value, void 0);
          const traits = ns.getMergedTraits();
          if (traits.httpPayload && !traits.xmlName) {
            this.buffer.withName(ns.getName());
          }
        }
      }
      flush() {
        if (this.byteBuffer !== void 0) {
          const bytes = this.byteBuffer;
          delete this.byteBuffer;
          return bytes;
        }
        if (this.stringBuffer !== void 0) {
          const str = this.stringBuffer;
          delete this.stringBuffer;
          return str;
        }
        const buffer = this.buffer;
        if (this.settings.xmlNamespace) {
          if (!buffer?.attributes?.["xmlns"]) {
            buffer.addAttribute("xmlns", this.settings.xmlNamespace);
          }
        }
        delete this.buffer;
        return buffer.toString();
      }
      writeStruct(ns, value, parentXmlns) {
        const traits = ns.getMergedTraits();
        const name = ns.isMemberSchema() && !traits.httpPayload ? ns.getMemberTraits().xmlName ?? ns.getMemberName() : traits.xmlName ?? ns.getName();
        if (!name || !ns.isStructSchema()) {
          throw new Error(`@aws-sdk/core/protocols - xml serializer, cannot write struct with empty name or non-struct, schema=${ns.getName(true)}.`);
        }
        const structXmlNode = import_xml_builder10.XmlNode.of(name);
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(ns, parentXmlns);
        for (const [memberName, memberSchema] of ns.structIterator()) {
          const val = value[memberName];
          if (val != null || memberSchema.isIdempotencyToken()) {
            if (memberSchema.getMergedTraits().xmlAttribute) {
              structXmlNode.addAttribute(memberSchema.getMergedTraits().xmlName ?? memberName, this.writeSimple(memberSchema, val));
              continue;
            }
            if (memberSchema.isListSchema()) {
              this.writeList(memberSchema, val, structXmlNode, xmlns);
            } else if (memberSchema.isMapSchema()) {
              this.writeMap(memberSchema, val, structXmlNode, xmlns);
            } else if (memberSchema.isStructSchema()) {
              structXmlNode.addChildNode(this.writeStruct(memberSchema, val, xmlns));
            } else {
              const memberNode = import_xml_builder10.XmlNode.of(memberSchema.getMergedTraits().xmlName ?? memberSchema.getMemberName());
              this.writeSimpleInto(memberSchema, val, memberNode, xmlns);
              structXmlNode.addChildNode(memberNode);
            }
          }
        }
        const { $unknown } = value;
        if ($unknown && ns.isUnionSchema() && Array.isArray($unknown) && Object.keys(value).length === 1) {
          const [k32, v] = $unknown;
          const node = import_xml_builder10.XmlNode.of(k32);
          if (typeof v !== "string") {
            if (value instanceof import_xml_builder10.XmlNode || value instanceof import_xml_builder10.XmlText) {
              structXmlNode.addChildNode(value);
            } else {
              throw new Error(`@aws-sdk - $unknown union member in XML requires value of type string, @aws-sdk/xml-builder::XmlNode or XmlText.`);
            }
          }
          this.writeSimpleInto(0, v, node, xmlns);
          structXmlNode.addChildNode(node);
        }
        if (xmlns) {
          structXmlNode.addAttribute(xmlnsAttr, xmlns);
        }
        return structXmlNode;
      }
      writeList(listMember, array, container, parentXmlns) {
        if (!listMember.isMemberSchema()) {
          throw new Error(`@aws-sdk/core/protocols - xml serializer, cannot write non-member list: ${listMember.getName(true)}`);
        }
        const listTraits = listMember.getMergedTraits();
        const listValueSchema = listMember.getValueSchema();
        const listValueTraits = listValueSchema.getMergedTraits();
        const sparse = !!listValueTraits.sparse;
        const flat = !!listTraits.xmlFlattened;
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(listMember, parentXmlns);
        const writeItem = /* @__PURE__ */ __name((container2, value) => {
          if (listValueSchema.isListSchema()) {
            this.writeList(listValueSchema, Array.isArray(value) ? value : [value], container2, xmlns);
          } else if (listValueSchema.isMapSchema()) {
            this.writeMap(listValueSchema, value, container2, xmlns);
          } else if (listValueSchema.isStructSchema()) {
            const struct3 = this.writeStruct(listValueSchema, value, xmlns);
            container2.addChildNode(struct3.withName(flat ? listTraits.xmlName ?? listMember.getMemberName() : listValueTraits.xmlName ?? "member"));
          } else {
            const listItemNode = import_xml_builder10.XmlNode.of(flat ? listTraits.xmlName ?? listMember.getMemberName() : listValueTraits.xmlName ?? "member");
            this.writeSimpleInto(listValueSchema, value, listItemNode, xmlns);
            container2.addChildNode(listItemNode);
          }
        }, "writeItem");
        if (flat) {
          for (const value of array) {
            if (sparse || value != null) {
              writeItem(container, value);
            }
          }
        } else {
          const listNode = import_xml_builder10.XmlNode.of(listTraits.xmlName ?? listMember.getMemberName());
          if (xmlns) {
            listNode.addAttribute(xmlnsAttr, xmlns);
          }
          for (const value of array) {
            if (sparse || value != null) {
              writeItem(listNode, value);
            }
          }
          container.addChildNode(listNode);
        }
      }
      writeMap(mapMember, map5, container, parentXmlns, containerIsMap = false) {
        if (!mapMember.isMemberSchema()) {
          throw new Error(`@aws-sdk/core/protocols - xml serializer, cannot write non-member map: ${mapMember.getName(true)}`);
        }
        const mapTraits = mapMember.getMergedTraits();
        const mapKeySchema = mapMember.getKeySchema();
        const mapKeyTraits = mapKeySchema.getMergedTraits();
        const keyTag = mapKeyTraits.xmlName ?? "key";
        const mapValueSchema = mapMember.getValueSchema();
        const mapValueTraits = mapValueSchema.getMergedTraits();
        const valueTag = mapValueTraits.xmlName ?? "value";
        const sparse = !!mapValueTraits.sparse;
        const flat = !!mapTraits.xmlFlattened;
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(mapMember, parentXmlns);
        const addKeyValue = /* @__PURE__ */ __name((entry, key, val) => {
          const keyNode = import_xml_builder10.XmlNode.of(keyTag, key);
          const [keyXmlnsAttr, keyXmlns] = this.getXmlnsAttribute(mapKeySchema, xmlns);
          if (keyXmlns) {
            keyNode.addAttribute(keyXmlnsAttr, keyXmlns);
          }
          entry.addChildNode(keyNode);
          let valueNode = import_xml_builder10.XmlNode.of(valueTag);
          if (mapValueSchema.isListSchema()) {
            this.writeList(mapValueSchema, val, valueNode, xmlns);
          } else if (mapValueSchema.isMapSchema()) {
            this.writeMap(mapValueSchema, val, valueNode, xmlns, true);
          } else if (mapValueSchema.isStructSchema()) {
            valueNode = this.writeStruct(mapValueSchema, val, xmlns);
          } else {
            this.writeSimpleInto(mapValueSchema, val, valueNode, xmlns);
          }
          entry.addChildNode(valueNode);
        }, "addKeyValue");
        if (flat) {
          for (const key in map5) {
            const val = map5[key];
            if (sparse || val != null) {
              const entry = import_xml_builder10.XmlNode.of(mapTraits.xmlName ?? mapMember.getMemberName());
              addKeyValue(entry, key, val);
              container.addChildNode(entry);
            }
          }
        } else {
          let mapNode;
          if (!containerIsMap) {
            mapNode = import_xml_builder10.XmlNode.of(mapTraits.xmlName ?? mapMember.getMemberName());
            if (xmlns) {
              mapNode.addAttribute(xmlnsAttr, xmlns);
            }
            container.addChildNode(mapNode);
          }
          for (const key in map5) {
            const val = map5[key];
            if (sparse || val != null) {
              const entry = import_xml_builder10.XmlNode.of("entry");
              addKeyValue(entry, key, val);
              (containerIsMap ? container : mapNode).addChildNode(entry);
            }
          }
        }
      }
      writeSimple(_schema, value) {
        if (null === value) {
          throw new Error("@aws-sdk/core/protocols - (XML serializer) cannot write null value.");
        }
        const ns = NormalizedSchema.of(_schema);
        let nodeContents = null;
        if (value && typeof value === "object") {
          if (ns.isBlobSchema()) {
            nodeContents = (this.serdeContext?.base64Encoder ?? import_util_base6427.toBase64)(value);
          } else if (ns.isTimestampSchema() && value instanceof Date) {
            const format32 = determineTimestampFormat(ns, this.settings);
            switch (format32) {
              case 5:
                nodeContents = value.toISOString().replace(".000Z", "Z");
                break;
              case 6:
                nodeContents = (0, import_smithy_client78.dateToUtcString)(value);
                break;
              case 7:
                nodeContents = String(value.getTime() / 1e3);
                break;
              default:
                console.warn("Missing timestamp format, using http date", value);
                nodeContents = (0, import_smithy_client78.dateToUtcString)(value);
                break;
            }
          } else if (ns.isBigDecimalSchema() && value) {
            if (value instanceof NumericValue) {
              return value.string;
            }
            return String(value);
          } else if (ns.isMapSchema() || ns.isListSchema()) {
            throw new Error("@aws-sdk/core/protocols - xml serializer, cannot call _write() on List/Map schema, call writeList or writeMap() instead.");
          } else {
            throw new Error(`@aws-sdk/core/protocols - xml serializer, unhandled schema type for object value and schema: ${ns.getName(true)}`);
          }
        }
        if (ns.isBooleanSchema() || ns.isNumericSchema() || ns.isBigIntegerSchema() || ns.isBigDecimalSchema()) {
          nodeContents = String(value);
        }
        if (ns.isStringSchema()) {
          if (value === void 0 && ns.isIdempotencyToken()) {
            nodeContents = (0, import_uuid.v4)();
          } else {
            nodeContents = String(value);
          }
        }
        if (nodeContents === null) {
          throw new Error(`Unhandled schema-value pair ${ns.getName(true)}=${value}`);
        }
        return nodeContents;
      }
      writeSimpleInto(_schema, value, into, parentXmlns) {
        const nodeContents = this.writeSimple(_schema, value);
        const ns = NormalizedSchema.of(_schema);
        const content = new import_xml_builder10.XmlText(nodeContents);
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(ns, parentXmlns);
        if (xmlns) {
          into.addAttribute(xmlnsAttr, xmlns);
        }
        into.addChildNode(content);
      }
      getXmlnsAttribute(ns, parentXmlns) {
        const traits = ns.getMergedTraits();
        const [prefix, xmlns] = traits.xmlNamespace ?? [];
        if (xmlns && xmlns !== parentXmlns) {
          return [prefix ? `xmlns:${prefix}` : "xmlns", xmlns];
        }
        return [void 0, void 0];
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlCodec.js
var XmlCodec3;
var init_XmlCodec5 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlCodec.js"() {
    init_ConfigurableSerdeContext5();
    init_XmlShapeDeserializer5();
    init_XmlShapeSerializer5();
    XmlCodec3 = class extends SerdeContextConfig5 {
      static {
        __name(this, "XmlCodec");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      createSerializer() {
        const serializer = new XmlShapeSerializer3(this.settings);
        serializer.setSerdeContext(this.serdeContext);
        return serializer;
      }
      createDeserializer() {
        const deserializer = new XmlShapeDeserializer4(this.settings);
        deserializer.setSerdeContext(this.serdeContext);
        return deserializer;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/AwsRestXmlProtocol.js
var AwsRestXmlProtocol3;
var init_AwsRestXmlProtocol5 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/AwsRestXmlProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib5();
    init_parseXmlBody5();
    init_XmlCodec5();
    AwsRestXmlProtocol3 = class extends HttpBindingProtocol {
      static {
        __name(this, "AwsRestXmlProtocol");
      }
      codec;
      serializer;
      deserializer;
      mixin = new ProtocolLib5();
      constructor(options) {
        super(options);
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 5
          },
          httpBindings: true,
          xmlNamespace: options.xmlNamespace,
          serviceNamespace: options.defaultNamespace
        };
        this.codec = new XmlCodec3(settings);
        this.serializer = new HttpInterceptingShapeSerializer(this.codec.createSerializer(), settings);
        this.deserializer = new HttpInterceptingShapeDeserializer(this.codec.createDeserializer(), settings);
      }
      getPayloadCodec() {
        return this.codec;
      }
      getShapeId() {
        return "aws.protocols#restXml";
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        const inputSchema = NormalizedSchema.of(operationSchema.input);
        if (!request4.headers["content-type"]) {
          const contentType = this.mixin.resolveRestContentType(this.getDefaultContentType(), inputSchema);
          if (contentType) {
            request4.headers["content-type"] = contentType;
          }
        }
        if (typeof request4.body === "string" && request4.headers["content-type"] === this.getDefaultContentType() && !request4.body.startsWith("<?xml ") && !this.hasUnstructuredPayloadBinding(inputSchema)) {
          request4.body = '<?xml version="1.0" encoding="UTF-8"?>' + request4.body;
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        return super.deserializeResponse(operationSchema, context, response);
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = loadRestXmlErrorCode3(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        if (dataObject.Error && typeof dataObject.Error === "object") {
          for (const key of Object.keys(dataObject.Error)) {
            dataObject[key] = dataObject.Error[key];
            if (key.toLowerCase() === "message") {
              dataObject.message = dataObject.Error[key];
            }
          }
        }
        if (dataObject.RequestId && !metadata.requestId) {
          metadata.requestId = dataObject.RequestId;
        }
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.Error?.message ?? dataObject.Error?.Message ?? dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        await this.deserializeHttpMessage(errorSchema, context, response, dataObject);
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().xmlName ?? name;
          const value = dataObject.Error?.[target] ?? dataObject[target];
          output[name] = errorDeserializer.readSchema(member7, value);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      getDefaultContentType() {
        return "application/xml";
      }
      hasUnstructuredPayloadBinding(ns) {
        for (const [, member7] of ns.structIterator()) {
          if (member7.getMergedTraits().httpPayload) {
            return !(member7.isStructSchema() || member7.isMapSchema() || member7.isListSchema());
          }
        }
        return false;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/index.js
var protocols_exports4 = {};
__export(protocols_exports4, {
  AwsEc2QueryProtocol: () => AwsEc2QueryProtocol3,
  AwsJson1_0Protocol: () => AwsJson1_0Protocol3,
  AwsJson1_1Protocol: () => AwsJson1_1Protocol3,
  AwsJsonRpcProtocol: () => AwsJsonRpcProtocol3,
  AwsQueryProtocol: () => AwsQueryProtocol4,
  AwsRestJsonProtocol: () => AwsRestJsonProtocol5,
  AwsRestXmlProtocol: () => AwsRestXmlProtocol3,
  AwsSmithyRpcV2CborProtocol: () => AwsSmithyRpcV2CborProtocol3,
  JsonCodec: () => JsonCodec5,
  JsonShapeDeserializer: () => JsonShapeDeserializer5,
  JsonShapeSerializer: () => JsonShapeSerializer5,
  QueryShapeSerializer: () => QueryShapeSerializer4,
  XmlCodec: () => XmlCodec3,
  XmlShapeDeserializer: () => XmlShapeDeserializer4,
  XmlShapeSerializer: () => XmlShapeSerializer3,
  _toBool: () => _toBool3,
  _toNum: () => _toNum3,
  _toStr: () => _toStr3,
  awsExpectUnion: () => awsExpectUnion3,
  loadRestJsonErrorCode: () => loadRestJsonErrorCode5,
  loadRestXmlErrorCode: () => loadRestXmlErrorCode3,
  parseJsonBody: () => parseJsonBody5,
  parseJsonErrorBody: () => parseJsonErrorBody3,
  parseXmlBody: () => parseXmlBody3,
  parseXmlErrorBody: () => parseXmlErrorBody3
});
var init_protocols7 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/core/dist-es/submodules/protocols/index.js"() {
    init_AwsSmithyRpcV2CborProtocol5();
    init_coercing_serializers5();
    init_AwsJson1_0Protocol5();
    init_AwsJson1_1Protocol5();
    init_AwsJsonRpcProtocol5();
    init_AwsRestJsonProtocol5();
    init_JsonCodec5();
    init_JsonShapeDeserializer5();
    init_JsonShapeSerializer5();
    init_awsExpectUnion5();
    init_parseJsonBody5();
    init_AwsEc2QueryProtocol5();
    init_AwsQueryProtocol5();
    init_QuerySerializerSettings5();
    init_QueryShapeSerializer5();
    init_AwsRestXmlProtocol5();
    init_XmlCodec5();
    init_XmlShapeDeserializer5();
    init_XmlShapeSerializer5();
    init_parseXmlBody5();
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/bdd.js
var import_util_endpoints22, k8, a8, b8, c8, d8, e8, f8, g8, h8, i8, j8, _data8, root8, r8, nodes8, bdd8;
var init_bdd8 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/bdd.js"() {
    import_util_endpoints22 = __toESM(require_dist_cjs20());
    k8 = "ref";
    a8 = -1;
    b8 = true;
    c8 = "isSet";
    d8 = "PartitionResult";
    e8 = "booleanEquals";
    f8 = "getAttr";
    g8 = { [k8]: "Endpoint" };
    h8 = { [k8]: d8 };
    i8 = {};
    j8 = [{ [k8]: "Region" }];
    _data8 = {
      conditions: [
        [c8, [g8]],
        [c8, j8],
        ["aws.partition", j8, d8],
        [e8, [{ [k8]: "UseFIPS" }, b8]],
        [e8, [{ [k8]: "UseDualStack" }, b8]],
        [e8, [{ fn: f8, argv: [h8, "supportsDualStack"] }, b8]],
        [e8, [{ fn: f8, argv: [h8, "supportsFIPS"] }, b8]],
        ["stringEquals", [{ fn: f8, argv: [h8, "name"] }, "aws-us-gov"]]
      ],
      results: [
        [a8],
        [a8, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a8, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [g8, i8],
        ["https://portal.sso-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", i8],
        [a8, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://portal.sso.{Region}.amazonaws.com", i8],
        ["https://portal.sso-fips.{Region}.{PartitionResult#dnsSuffix}", i8],
        [a8, "FIPS is enabled but this partition does not support FIPS"],
        ["https://portal.sso.{Region}.{PartitionResult#dualStackDnsSuffix}", i8],
        [a8, "DualStack is enabled but this partition does not support DualStack"],
        ["https://portal.sso.{Region}.{PartitionResult#dnsSuffix}", i8],
        [a8, "Invalid Configuration: Missing Region"]
      ]
    };
    root8 = 2;
    r8 = 1e8;
    nodes8 = new Int32Array([
      -1,
      1,
      -1,
      0,
      13,
      3,
      1,
      4,
      r8 + 12,
      2,
      5,
      r8 + 12,
      3,
      8,
      6,
      4,
      7,
      r8 + 11,
      5,
      r8 + 9,
      r8 + 10,
      4,
      11,
      9,
      6,
      10,
      r8 + 8,
      7,
      r8 + 6,
      r8 + 7,
      5,
      12,
      r8 + 5,
      6,
      r8 + 4,
      r8 + 5,
      3,
      r8 + 1,
      14,
      4,
      r8 + 2,
      r8 + 3
    ]);
    bdd8 = import_util_endpoints22.BinaryDecisionDiagram.from(nodes8, root8, _data8.conditions, _data8.results);
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/endpointResolver.js
var import_util_endpoints23, import_util_endpoints24, cache8, defaultEndpointResolver8;
var init_endpointResolver8 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/endpointResolver.js"() {
    import_util_endpoints23 = __toESM(require_dist_cjs21());
    import_util_endpoints24 = __toESM(require_dist_cjs20());
    init_bdd8();
    cache8 = new import_util_endpoints24.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    defaultEndpointResolver8 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache8.get(endpointParams, () => (0, import_util_endpoints24.decideEndpoint)(bdd8, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    import_util_endpoints24.customEndpointFunctions.aws = import_util_endpoints23.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/SSOServiceException.js
var import_smithy_client79, SSOServiceException3;
var init_SSOServiceException3 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/SSOServiceException.js"() {
    import_smithy_client79 = __toESM(require_dist_cjs34());
    SSOServiceException3 = class _SSOServiceException extends import_smithy_client79.ServiceException {
      static {
        __name(this, "SSOServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _SSOServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/errors.js
var InvalidRequestException4, ResourceNotFoundException3, TooManyRequestsException3, UnauthorizedException3;
var init_errors8 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/errors.js"() {
    init_SSOServiceException3();
    InvalidRequestException4 = class _InvalidRequestException extends SSOServiceException3 {
      static {
        __name(this, "InvalidRequestException");
      }
      name = "InvalidRequestException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidRequestException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidRequestException.prototype);
      }
    };
    ResourceNotFoundException3 = class _ResourceNotFoundException extends SSOServiceException3 {
      static {
        __name(this, "ResourceNotFoundException");
      }
      name = "ResourceNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ResourceNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceNotFoundException.prototype);
      }
    };
    TooManyRequestsException3 = class _TooManyRequestsException extends SSOServiceException3 {
      static {
        __name(this, "TooManyRequestsException");
      }
      name = "TooManyRequestsException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TooManyRequestsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyRequestsException.prototype);
      }
    };
    UnauthorizedException3 = class _UnauthorizedException extends SSOServiceException3 {
      static {
        __name(this, "UnauthorizedException");
      }
      name = "UnauthorizedException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "UnauthorizedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnauthorizedException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/schemas/schemas_0.js
var _ATT3, _GRC3, _GRCR3, _GRCRe3, _IRE4, _RC3, _RNFE3, _SAKT3, _STT3, _TMRE5, _UE3, _aI3, _aKI5, _aT6, _ai3, _c8, _e8, _ex3, _h6, _hE8, _hH3, _hQ3, _m7, _rC3, _rN3, _rn3, _s8, _sAK5, _sT5, _xasbt3, n08, _s_registry8, SSOServiceException$3, n0_registry8, InvalidRequestException$4, ResourceNotFoundException$3, TooManyRequestsException$3, UnauthorizedException$3, errorTypeRegistries8, AccessTokenType3, SecretAccessKeyType3, SessionTokenType3, GetRoleCredentialsRequest$3, GetRoleCredentialsResponse$3, RoleCredentials$3, GetRoleCredentials$3;
var init_schemas_08 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/schemas/schemas_0.js"() {
    init_schema4();
    init_errors8();
    init_SSOServiceException3();
    _ATT3 = "AccessTokenType";
    _GRC3 = "GetRoleCredentials";
    _GRCR3 = "GetRoleCredentialsRequest";
    _GRCRe3 = "GetRoleCredentialsResponse";
    _IRE4 = "InvalidRequestException";
    _RC3 = "RoleCredentials";
    _RNFE3 = "ResourceNotFoundException";
    _SAKT3 = "SecretAccessKeyType";
    _STT3 = "SessionTokenType";
    _TMRE5 = "TooManyRequestsException";
    _UE3 = "UnauthorizedException";
    _aI3 = "accountId";
    _aKI5 = "accessKeyId";
    _aT6 = "accessToken";
    _ai3 = "account_id";
    _c8 = "client";
    _e8 = "error";
    _ex3 = "expiration";
    _h6 = "http";
    _hE8 = "httpError";
    _hH3 = "httpHeader";
    _hQ3 = "httpQuery";
    _m7 = "message";
    _rC3 = "roleCredentials";
    _rN3 = "roleName";
    _rn3 = "role_name";
    _s8 = "smithy.ts.sdk.synthetic.com.amazonaws.sso";
    _sAK5 = "secretAccessKey";
    _sT5 = "sessionToken";
    _xasbt3 = "x-amz-sso_bearer_token";
    n08 = "com.amazonaws.sso";
    _s_registry8 = TypeRegistry.for(_s8);
    SSOServiceException$3 = [-3, _s8, "SSOServiceException", 0, [], []];
    _s_registry8.registerError(SSOServiceException$3, SSOServiceException3);
    n0_registry8 = TypeRegistry.for(n08);
    InvalidRequestException$4 = [-3, n08, _IRE4, { [_e8]: _c8, [_hE8]: 400 }, [_m7], [0]];
    n0_registry8.registerError(InvalidRequestException$4, InvalidRequestException4);
    ResourceNotFoundException$3 = [-3, n08, _RNFE3, { [_e8]: _c8, [_hE8]: 404 }, [_m7], [0]];
    n0_registry8.registerError(ResourceNotFoundException$3, ResourceNotFoundException3);
    TooManyRequestsException$3 = [-3, n08, _TMRE5, { [_e8]: _c8, [_hE8]: 429 }, [_m7], [0]];
    n0_registry8.registerError(TooManyRequestsException$3, TooManyRequestsException3);
    UnauthorizedException$3 = [-3, n08, _UE3, { [_e8]: _c8, [_hE8]: 401 }, [_m7], [0]];
    n0_registry8.registerError(UnauthorizedException$3, UnauthorizedException3);
    errorTypeRegistries8 = [_s_registry8, n0_registry8];
    AccessTokenType3 = [0, n08, _ATT3, 8, 0];
    SecretAccessKeyType3 = [0, n08, _SAKT3, 8, 0];
    SessionTokenType3 = [0, n08, _STT3, 8, 0];
    GetRoleCredentialsRequest$3 = [
      3,
      n08,
      _GRCR3,
      0,
      [_rN3, _aI3, _aT6],
      [
        [0, { [_hQ3]: _rn3 }],
        [0, { [_hQ3]: _ai3 }],
        [() => AccessTokenType3, { [_hH3]: _xasbt3 }]
      ],
      3
    ];
    GetRoleCredentialsResponse$3 = [
      3,
      n08,
      _GRCRe3,
      0,
      [_rC3],
      [[() => RoleCredentials$3, 0]]
    ];
    RoleCredentials$3 = [
      3,
      n08,
      _RC3,
      0,
      [_aKI5, _sAK5, _sT5, _ex3],
      [0, [() => SecretAccessKeyType3, 0], [() => SessionTokenType3, 0], 1]
    ];
    GetRoleCredentials$3 = [
      9,
      n08,
      _GRC3,
      { [_h6]: ["GET", "/federation/credentials", 200] },
      () => GetRoleCredentialsRequest$3,
      () => GetRoleCredentialsResponse$3
    ];
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.shared.js
var import_smithy_client80, import_url_parser9, import_util_base6428, import_util_utf822, getRuntimeConfig15;
var init_runtimeConfig_shared8 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.shared.js"() {
    init_httpAuthSchemes5();
    init_protocols7();
    init_dist_es();
    import_smithy_client80 = __toESM(require_dist_cjs34());
    import_url_parser9 = __toESM(require_dist_cjs18());
    import_util_base6428 = __toESM(require_dist_cjs10());
    import_util_utf822 = __toESM(require_dist_cjs9());
    init_httpAuthSchemeProvider8();
    init_endpointResolver8();
    init_schemas_08();
    getRuntimeConfig15 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2019-06-10",
        base64Decoder: config2?.base64Decoder ?? import_util_base6428.fromBase64,
        base64Encoder: config2?.base64Encoder ?? import_util_base6428.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver8,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSSOHttpAuthSchemeProvider3,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer4()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        logger: config2?.logger ?? new import_smithy_client80.NoOpLogger(),
        protocol: config2?.protocol ?? AwsRestJsonProtocol5,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.sso",
          errorTypeRegistries: errorTypeRegistries8,
          version: "2019-06-10",
          serviceTarget: "SWBPortalService"
        },
        serviceId: config2?.serviceId ?? "SSO",
        urlParser: config2?.urlParser ?? import_url_parser9.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? import_util_utf822.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? import_util_utf822.toUtf8
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.js
var import_util_user_agent_node8, import_config_resolver15, import_hash_node8, import_middleware_retry15, import_node_config_provider8, import_node_http_handler8, import_smithy_client81, import_util_body_length_node8, import_util_defaults_mode_node8, import_util_retry14, getRuntimeConfig16;
var init_runtimeConfig8 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.js"() {
    init_package4();
    init_client7();
    init_httpAuthSchemes5();
    import_util_user_agent_node8 = __toESM(require_dist_cjs96());
    import_config_resolver15 = __toESM(require_dist_cjs25());
    import_hash_node8 = __toESM(require_dist_cjs44());
    import_middleware_retry15 = __toESM(require_dist_cjs92());
    import_node_config_provider8 = __toESM(require_dist_cjs29());
    import_node_http_handler8 = __toESM(require_dist_cjs13());
    import_smithy_client81 = __toESM(require_dist_cjs34());
    import_util_body_length_node8 = __toESM(require_dist_cjs45());
    import_util_defaults_mode_node8 = __toESM(require_dist_cjs46());
    import_util_retry14 = __toESM(require_dist_cjs22());
    init_runtimeConfig_shared8();
    getRuntimeConfig16 = /* @__PURE__ */ __name((config2) => {
      (0, import_smithy_client81.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, import_util_defaults_mode_node8.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(import_smithy_client81.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig15(config2);
      emitWarningIfUnsupportedVersion13(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, import_node_config_provider8.loadConfig)(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS4, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? import_util_body_length_node8.calculateBodyLength,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, import_util_user_agent_node8.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_default4.version }),
        maxAttempts: config2?.maxAttempts ?? (0, import_node_config_provider8.loadConfig)(import_middleware_retry15.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, import_node_config_provider8.loadConfig)(import_config_resolver15.NODE_REGION_CONFIG_OPTIONS, { ...import_config_resolver15.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: import_node_http_handler8.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, import_node_config_provider8.loadConfig)({
          ...import_middleware_retry15.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || import_util_retry14.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? import_hash_node8.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? import_node_http_handler8.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, import_node_config_provider8.loadConfig)(import_config_resolver15.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, import_node_config_provider8.loadConfig)(import_config_resolver15.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, import_node_config_provider8.loadConfig)(import_util_user_agent_node8.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration8, resolveHttpAuthRuntimeConfig8;
var init_httpAuthExtensionConfiguration8 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration8 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig8 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeExtensions.js
var import_region_config_resolver10, import_protocol_http28, import_smithy_client82, resolveRuntimeExtensions8;
var init_runtimeExtensions8 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeExtensions.js"() {
    import_region_config_resolver10 = __toESM(require_dist_cjs48());
    import_protocol_http28 = __toESM(require_dist_cjs2());
    import_smithy_client82 = __toESM(require_dist_cjs34());
    init_httpAuthExtensionConfiguration8();
    resolveRuntimeExtensions8 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign((0, import_region_config_resolver10.getAwsRegionExtensionConfiguration)(runtimeConfig), (0, import_smithy_client82.getDefaultExtensionConfiguration)(runtimeConfig), (0, import_protocol_http28.getHttpHandlerExtensionConfiguration)(runtimeConfig), getHttpAuthExtensionConfiguration8(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, (0, import_region_config_resolver10.resolveAwsRegionExtensionConfiguration)(extensionConfiguration), (0, import_smithy_client82.resolveDefaultRuntimeConfig)(extensionConfiguration), (0, import_protocol_http28.resolveHttpHandlerRuntimeConfig)(extensionConfiguration), resolveHttpAuthRuntimeConfig8(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSOClient.js
var import_middleware_host_header8, import_middleware_logger8, import_middleware_recursion_detection8, import_middleware_user_agent8, import_config_resolver16, import_middleware_content_length8, import_middleware_endpoint19, import_middleware_retry16, import_smithy_client83, SSOClient3;
var init_SSOClient3 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSOClient.js"() {
    import_middleware_host_header8 = __toESM(require_dist_cjs3());
    import_middleware_logger8 = __toESM(require_dist_cjs4());
    import_middleware_recursion_detection8 = __toESM(require_dist_cjs5());
    import_middleware_user_agent8 = __toESM(require_dist_cjs91());
    import_config_resolver16 = __toESM(require_dist_cjs25());
    init_dist_es();
    init_schema4();
    import_middleware_content_length8 = __toESM(require_dist_cjs26());
    import_middleware_endpoint19 = __toESM(require_dist_cjs31());
    import_middleware_retry16 = __toESM(require_dist_cjs92());
    import_smithy_client83 = __toESM(require_dist_cjs34());
    init_httpAuthSchemeProvider8();
    init_EndpointParameters8();
    init_runtimeConfig8();
    init_runtimeExtensions8();
    SSOClient3 = class extends import_smithy_client83.Client {
      static {
        __name(this, "SSOClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig16(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters8(_config_0);
        const _config_2 = (0, import_middleware_user_agent8.resolveUserAgentConfig)(_config_1);
        const _config_3 = (0, import_middleware_retry16.resolveRetryConfig)(_config_2);
        const _config_4 = (0, import_config_resolver16.resolveRegionConfig)(_config_3);
        const _config_5 = (0, import_middleware_host_header8.resolveHostHeaderConfig)(_config_4);
        const _config_6 = (0, import_middleware_endpoint19.resolveEndpointConfig)(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig8(_config_6);
        const _config_8 = resolveRuntimeExtensions8(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin(this.config));
        this.middlewareStack.use((0, import_middleware_user_agent8.getUserAgentPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_retry16.getRetryPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_content_length8.getContentLengthPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_host_header8.getHostHeaderPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_logger8.getLoggerPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_recursion_detection8.getRecursionDetectionPlugin)(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: defaultSSOHttpAuthSchemeParametersProvider3,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/GetRoleCredentialsCommand.js
var import_middleware_endpoint20, import_smithy_client84, GetRoleCredentialsCommand3;
var init_GetRoleCredentialsCommand3 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/GetRoleCredentialsCommand.js"() {
    import_middleware_endpoint20 = __toESM(require_dist_cjs31());
    import_smithy_client84 = __toESM(require_dist_cjs34());
    init_EndpointParameters8();
    init_schemas_08();
    GetRoleCredentialsCommand3 = class extends import_smithy_client84.Command.classBuilder().ep(commonParams8).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint20.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("SWBPortalService", "GetRoleCredentials", {}).n("SSOClient", "GetRoleCredentialsCommand").sc(GetRoleCredentials$3).build() {
      static {
        __name(this, "GetRoleCredentialsCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSO.js
var import_smithy_client85, commands8, SSO3;
var init_SSO3 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSO.js"() {
    import_smithy_client85 = __toESM(require_dist_cjs34());
    init_GetRoleCredentialsCommand3();
    init_SSOClient3();
    commands8 = {
      GetRoleCredentialsCommand: GetRoleCredentialsCommand3
    };
    SSO3 = class extends SSOClient3 {
      static {
        __name(this, "SSO");
      }
    };
    (0, import_smithy_client85.createAggregatedClient)(commands8, SSO3);
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/index.js
var init_commands9 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/index.js"() {
    init_GetRoleCredentialsCommand3();
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/models_0.js
var init_models_08 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/index.js
var sso_exports3 = {};
__export(sso_exports3, {
  $Command: () => import_smithy_client84.Command,
  GetRoleCredentials$: () => GetRoleCredentials$3,
  GetRoleCredentialsCommand: () => GetRoleCredentialsCommand3,
  GetRoleCredentialsRequest$: () => GetRoleCredentialsRequest$3,
  GetRoleCredentialsResponse$: () => GetRoleCredentialsResponse$3,
  InvalidRequestException: () => InvalidRequestException4,
  InvalidRequestException$: () => InvalidRequestException$4,
  ResourceNotFoundException: () => ResourceNotFoundException3,
  ResourceNotFoundException$: () => ResourceNotFoundException$3,
  RoleCredentials$: () => RoleCredentials$3,
  SSO: () => SSO3,
  SSOClient: () => SSOClient3,
  SSOServiceException: () => SSOServiceException3,
  SSOServiceException$: () => SSOServiceException$3,
  TooManyRequestsException: () => TooManyRequestsException3,
  TooManyRequestsException$: () => TooManyRequestsException$3,
  UnauthorizedException: () => UnauthorizedException3,
  UnauthorizedException$: () => UnauthorizedException$3,
  __Client: () => import_smithy_client83.Client,
  errorTypeRegistries: () => errorTypeRegistries8
});
var init_sso3 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/index.js"() {
    init_SSOClient3();
    init_SSO3();
    init_commands9();
    init_schemas_08();
    init_errors8();
    init_models_08();
    init_SSOServiceException3();
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/loadSso-BKDNrsal.js
var require_loadSso_BKDNrsal3 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/loadSso-BKDNrsal.js"(exports2) {
    "use strict";
    var sso = (init_sso3(), __toCommonJS(sso_exports3));
    exports2.GetRoleCredentialsCommand = sso.GetRoleCredentialsCommand;
    exports2.SSOClient = sso.SSOClient;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/index.js
var require_dist_cjs97 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/index.js"(exports2) {
    "use strict";
    var propertyProvider = require_dist_cjs27();
    var sharedIniFileLoader = require_dist_cjs28();
    var client = (init_client7(), __toCommonJS(client_exports6));
    var tokenProviders = require_dist_cjs49();
    var isSsoProfile = /* @__PURE__ */ __name((arg) => arg && (typeof arg.sso_start_url === "string" || typeof arg.sso_account_id === "string" || typeof arg.sso_session === "string" || typeof arg.sso_region === "string" || typeof arg.sso_role_name === "string"), "isSsoProfile");
    var SHOULD_FAIL_CREDENTIAL_CHAIN = false;
    var resolveSSOCredentials = /* @__PURE__ */ __name(async ({ ssoStartUrl, ssoSession, ssoAccountId, ssoRegion, ssoRoleName, ssoClient, clientConfig, parentClientConfig, callerClientConfig, profile, filepath, configFilepath, ignoreCache, logger: logger5 }) => {
      let token;
      const refreshMessage = `To refresh this SSO session run aws sso login with the corresponding profile.`;
      if (ssoSession) {
        try {
          const _token = await tokenProviders.fromSso({
            profile,
            filepath,
            configFilepath,
            ignoreCache
          })();
          token = {
            accessToken: _token.token,
            expiresAt: new Date(_token.expiration).toISOString()
          };
        } catch (e32) {
          throw new propertyProvider.CredentialsProviderError(e32.message, {
            tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
            logger: logger5
          });
        }
      } else {
        try {
          token = await sharedIniFileLoader.getSSOTokenFromFile(ssoStartUrl);
        } catch (e32) {
          throw new propertyProvider.CredentialsProviderError(`The SSO session associated with this profile is invalid. ${refreshMessage}`, {
            tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
            logger: logger5
          });
        }
      }
      if (new Date(token.expiresAt).getTime() - Date.now() <= 0) {
        throw new propertyProvider.CredentialsProviderError(`The SSO session associated with this profile has expired. ${refreshMessage}`, {
          tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
          logger: logger5
        });
      }
      const { accessToken } = token;
      const { SSOClient: SSOClient10, GetRoleCredentialsCommand: GetRoleCredentialsCommand10 } = await Promise.resolve().then(function() {
        return require_loadSso_BKDNrsal3();
      });
      const sso = ssoClient || new SSOClient10(Object.assign({}, clientConfig ?? {}, {
        logger: clientConfig?.logger ?? callerClientConfig?.logger ?? parentClientConfig?.logger,
        region: clientConfig?.region ?? ssoRegion,
        userAgentAppId: clientConfig?.userAgentAppId ?? callerClientConfig?.userAgentAppId ?? parentClientConfig?.userAgentAppId
      }));
      let ssoResp;
      try {
        ssoResp = await sso.send(new GetRoleCredentialsCommand10({
          accountId: ssoAccountId,
          roleName: ssoRoleName,
          accessToken
        }));
      } catch (e32) {
        throw new propertyProvider.CredentialsProviderError(e32, {
          tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
          logger: logger5
        });
      }
      const { roleCredentials: { accessKeyId, secretAccessKey, sessionToken, expiration, credentialScope, accountId } = {} } = ssoResp;
      if (!accessKeyId || !secretAccessKey || !sessionToken || !expiration) {
        throw new propertyProvider.CredentialsProviderError("SSO returns an invalid temporary credential.", {
          tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
          logger: logger5
        });
      }
      const credentials = {
        accessKeyId,
        secretAccessKey,
        sessionToken,
        expiration: new Date(expiration),
        ...credentialScope && { credentialScope },
        ...accountId && { accountId }
      };
      if (ssoSession) {
        client.setCredentialFeature(credentials, "CREDENTIALS_SSO", "s");
      } else {
        client.setCredentialFeature(credentials, "CREDENTIALS_SSO_LEGACY", "u");
      }
      return credentials;
    }, "resolveSSOCredentials");
    var validateSsoProfile = /* @__PURE__ */ __name((profile, logger5) => {
      const { sso_start_url, sso_account_id, sso_region, sso_role_name } = profile;
      if (!sso_start_url || !sso_account_id || !sso_region || !sso_role_name) {
        throw new propertyProvider.CredentialsProviderError(`Profile is configured with invalid SSO credentials. Required parameters "sso_account_id", "sso_region", "sso_role_name", "sso_start_url". Got ${Object.keys(profile).join(", ")}
Reference: https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-sso.html`, { tryNextLink: false, logger: logger5 });
      }
      return profile;
    }, "validateSsoProfile");
    var fromSSO = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/credential-provider-sso - fromSSO");
      const { ssoStartUrl, ssoAccountId, ssoRegion, ssoRoleName, ssoSession } = init;
      const { ssoClient } = init;
      const profileName = sharedIniFileLoader.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      });
      if (!ssoStartUrl && !ssoAccountId && !ssoRegion && !ssoRoleName && !ssoSession) {
        const profiles = await sharedIniFileLoader.parseKnownFiles(init);
        const profile = profiles[profileName];
        if (!profile) {
          throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} was not found.`, { logger: init.logger });
        }
        if (!isSsoProfile(profile)) {
          throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} is not configured with SSO credentials.`, {
            logger: init.logger
          });
        }
        if (profile?.sso_session) {
          const ssoSessions = await sharedIniFileLoader.loadSsoSessionData(init);
          const session = ssoSessions[profile.sso_session];
          const conflictMsg = ` configurations in profile ${profileName} and sso-session ${profile.sso_session}`;
          if (ssoRegion && ssoRegion !== session.sso_region) {
            throw new propertyProvider.CredentialsProviderError(`Conflicting SSO region` + conflictMsg, {
              tryNextLink: false,
              logger: init.logger
            });
          }
          if (ssoStartUrl && ssoStartUrl !== session.sso_start_url) {
            throw new propertyProvider.CredentialsProviderError(`Conflicting SSO start_url` + conflictMsg, {
              tryNextLink: false,
              logger: init.logger
            });
          }
          profile.sso_region = session.sso_region;
          profile.sso_start_url = session.sso_start_url;
        }
        const { sso_start_url, sso_account_id, sso_region, sso_role_name, sso_session } = validateSsoProfile(profile, init.logger);
        return resolveSSOCredentials({
          ssoStartUrl: sso_start_url,
          ssoSession: sso_session,
          ssoAccountId: sso_account_id,
          ssoRegion: sso_region,
          ssoRoleName: sso_role_name,
          ssoClient,
          clientConfig: init.clientConfig,
          parentClientConfig: init.parentClientConfig,
          callerClientConfig: init.callerClientConfig,
          profile: profileName,
          filepath: init.filepath,
          configFilepath: init.configFilepath,
          ignoreCache: init.ignoreCache,
          logger: init.logger
        });
      } else if (!ssoStartUrl || !ssoAccountId || !ssoRegion || !ssoRoleName) {
        throw new propertyProvider.CredentialsProviderError('Incomplete configuration. The fromSSO() argument hash must include "ssoStartUrl", "ssoAccountId", "ssoRegion", "ssoRoleName"', { tryNextLink: false, logger: init.logger });
      } else {
        return resolveSSOCredentials({
          ssoStartUrl,
          ssoSession,
          ssoAccountId,
          ssoRegion,
          ssoRoleName,
          ssoClient,
          clientConfig: init.clientConfig,
          parentClientConfig: init.parentClientConfig,
          callerClientConfig: init.callerClientConfig,
          profile: profileName,
          filepath: init.filepath,
          configFilepath: init.configFilepath,
          ignoreCache: init.ignoreCache,
          logger: init.logger
        });
      }
    }, "fromSSO");
    exports2.fromSSO = fromSSO;
    exports2.isSsoProfile = isSsoProfile;
    exports2.validateSsoProfile = validateSsoProfile;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption9(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "signin",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption9(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var import_util_middleware14, defaultSigninHttpAuthSchemeParametersProvider3, defaultSigninHttpAuthSchemeProvider3, resolveHttpAuthSchemeConfig9;
var init_httpAuthSchemeProvider9 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes5();
    import_util_middleware14 = __toESM(require_dist_cjs6());
    defaultSigninHttpAuthSchemeParametersProvider3 = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, import_util_middleware14.getSmithyContext)(context).operation,
        region: await (0, import_util_middleware14.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultSigninHttpAuthSchemeParametersProvider");
    __name(createAwsAuthSigv4HttpAuthOption9, "createAwsAuthSigv4HttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption9, "createSmithyApiNoAuthHttpAuthOption");
    defaultSigninHttpAuthSchemeProvider3 = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "CreateOAuth2Token": {
          options.push(createSmithyApiNoAuthHttpAuthOption9(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption9(authParameters));
        }
      }
      return options;
    }, "defaultSigninHttpAuthSchemeProvider");
    resolveHttpAuthSchemeConfig9 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveAwsSdkSigV4Config4(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, import_util_middleware14.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/EndpointParameters.js
var resolveClientEndpointParameters9, commonParams9;
var init_EndpointParameters9 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters9 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "signin"
      });
    }, "resolveClientEndpointParameters");
    commonParams9 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/bdd.js
var import_util_endpoints25, m5, a9, b9, c9, d9, e9, f9, g9, h9, i9, j9, k9, l5, _data9, root9, r9, nodes9, bdd9;
var init_bdd9 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/bdd.js"() {
    import_util_endpoints25 = __toESM(require_dist_cjs20());
    m5 = "ref";
    a9 = -1;
    b9 = true;
    c9 = "isSet";
    d9 = "PartitionResult";
    e9 = "booleanEquals";
    f9 = "getAttr";
    g9 = "stringEquals";
    h9 = { [m5]: "Endpoint" };
    i9 = { [m5]: d9 };
    j9 = { fn: f9, argv: [i9, "name"] };
    k9 = {};
    l5 = [{ [m5]: "Region" }];
    _data9 = {
      conditions: [
        [c9, [h9]],
        [c9, l5],
        ["aws.partition", l5, d9],
        [e9, [{ [m5]: "UseFIPS" }, b9]],
        [e9, [{ [m5]: "UseDualStack" }, b9]],
        [e9, [{ fn: f9, argv: [i9, "supportsDualStack"] }, b9]],
        [e9, [{ fn: f9, argv: [i9, "supportsFIPS"] }, b9]],
        [g9, [j9, "aws"]],
        [g9, [j9, "aws-cn"]],
        [g9, [j9, "aws-us-gov"]]
      ],
      results: [
        [a9],
        [a9, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a9, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [h9, k9],
        ["https://{Region}.signin.aws.amazon.com", k9],
        ["https://{Region}.signin.amazonaws.cn", k9],
        ["https://{Region}.signin.amazonaws-us-gov.com", k9],
        ["https://signin-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", k9],
        [a9, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://signin-fips.{Region}.{PartitionResult#dnsSuffix}", k9],
        [a9, "FIPS is enabled but this partition does not support FIPS"],
        ["https://signin.{Region}.{PartitionResult#dualStackDnsSuffix}", k9],
        [a9, "DualStack is enabled but this partition does not support DualStack"],
        ["https://signin.{Region}.{PartitionResult#dnsSuffix}", k9],
        [a9, "Invalid Configuration: Missing Region"]
      ]
    };
    root9 = 2;
    r9 = 1e8;
    nodes9 = new Int32Array([
      -1,
      1,
      -1,
      0,
      15,
      3,
      1,
      4,
      r9 + 14,
      2,
      5,
      r9 + 14,
      3,
      11,
      6,
      4,
      10,
      7,
      7,
      r9 + 4,
      8,
      8,
      r9 + 5,
      9,
      9,
      r9 + 6,
      r9 + 13,
      5,
      r9 + 11,
      r9 + 12,
      4,
      13,
      12,
      6,
      r9 + 9,
      r9 + 10,
      5,
      14,
      r9 + 8,
      6,
      r9 + 7,
      r9 + 8,
      3,
      r9 + 1,
      16,
      4,
      r9 + 2,
      r9 + 3
    ]);
    bdd9 = import_util_endpoints25.BinaryDecisionDiagram.from(nodes9, root9, _data9.conditions, _data9.results);
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/endpointResolver.js
var import_util_endpoints26, import_util_endpoints27, cache9, defaultEndpointResolver9;
var init_endpointResolver9 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/endpointResolver.js"() {
    import_util_endpoints26 = __toESM(require_dist_cjs21());
    import_util_endpoints27 = __toESM(require_dist_cjs20());
    init_bdd9();
    cache9 = new import_util_endpoints27.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    defaultEndpointResolver9 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache9.get(endpointParams, () => (0, import_util_endpoints27.decideEndpoint)(bdd9, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    import_util_endpoints27.customEndpointFunctions.aws = import_util_endpoints26.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/SigninServiceException.js
var import_smithy_client86, SigninServiceException3;
var init_SigninServiceException3 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/SigninServiceException.js"() {
    import_smithy_client86 = __toESM(require_dist_cjs34());
    SigninServiceException3 = class _SigninServiceException extends import_smithy_client86.ServiceException {
      static {
        __name(this, "SigninServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _SigninServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/errors.js
var AccessDeniedException4, InternalServerException4, TooManyRequestsError3, ValidationException3;
var init_errors9 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/errors.js"() {
    init_SigninServiceException3();
    AccessDeniedException4 = class _AccessDeniedException extends SigninServiceException3 {
      static {
        __name(this, "AccessDeniedException");
      }
      name = "AccessDeniedException";
      $fault = "client";
      error;
      constructor(opts) {
        super({
          name: "AccessDeniedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AccessDeniedException.prototype);
        this.error = opts.error;
      }
    };
    InternalServerException4 = class _InternalServerException extends SigninServiceException3 {
      static {
        __name(this, "InternalServerException");
      }
      name = "InternalServerException";
      $fault = "server";
      error;
      constructor(opts) {
        super({
          name: "InternalServerException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _InternalServerException.prototype);
        this.error = opts.error;
      }
    };
    TooManyRequestsError3 = class _TooManyRequestsError extends SigninServiceException3 {
      static {
        __name(this, "TooManyRequestsError");
      }
      name = "TooManyRequestsError";
      $fault = "client";
      error;
      constructor(opts) {
        super({
          name: "TooManyRequestsError",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyRequestsError.prototype);
        this.error = opts.error;
      }
    };
    ValidationException3 = class _ValidationException extends SigninServiceException3 {
      static {
        __name(this, "ValidationException");
      }
      name = "ValidationException";
      $fault = "client";
      error;
      constructor(opts) {
        super({
          name: "ValidationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ValidationException.prototype);
        this.error = opts.error;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/schemas/schemas_0.js
var _ADE4, _AT4, _COAT3, _COATR3, _COATRB3, _COATRBr3, _COATRr3, _ISE4, _RT4, _TMRE6, _VE3, _aKI6, _aT7, _c9, _cI4, _cV4, _co4, _e9, _eI4, _gT4, _h7, _hE9, _iT4, _jN3, _m8, _rT4, _rU4, _s9, _sAK6, _sT6, _se4, _tI3, _tO3, _tT4, n09, _s_registry9, SigninServiceException$3, n0_registry9, AccessDeniedException$4, InternalServerException$4, TooManyRequestsError$3, ValidationException$3, errorTypeRegistries9, RefreshToken4, AccessToken$3, CreateOAuth2TokenRequest$3, CreateOAuth2TokenRequestBody$3, CreateOAuth2TokenResponse$3, CreateOAuth2TokenResponseBody$3, CreateOAuth2Token$3;
var init_schemas_09 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/schemas/schemas_0.js"() {
    init_schema4();
    init_errors9();
    init_SigninServiceException3();
    _ADE4 = "AccessDeniedException";
    _AT4 = "AccessToken";
    _COAT3 = "CreateOAuth2Token";
    _COATR3 = "CreateOAuth2TokenRequest";
    _COATRB3 = "CreateOAuth2TokenRequestBody";
    _COATRBr3 = "CreateOAuth2TokenResponseBody";
    _COATRr3 = "CreateOAuth2TokenResponse";
    _ISE4 = "InternalServerException";
    _RT4 = "RefreshToken";
    _TMRE6 = "TooManyRequestsError";
    _VE3 = "ValidationException";
    _aKI6 = "accessKeyId";
    _aT7 = "accessToken";
    _c9 = "client";
    _cI4 = "clientId";
    _cV4 = "codeVerifier";
    _co4 = "code";
    _e9 = "error";
    _eI4 = "expiresIn";
    _gT4 = "grantType";
    _h7 = "http";
    _hE9 = "httpError";
    _iT4 = "idToken";
    _jN3 = "jsonName";
    _m8 = "message";
    _rT4 = "refreshToken";
    _rU4 = "redirectUri";
    _s9 = "smithy.ts.sdk.synthetic.com.amazonaws.signin";
    _sAK6 = "secretAccessKey";
    _sT6 = "sessionToken";
    _se4 = "server";
    _tI3 = "tokenInput";
    _tO3 = "tokenOutput";
    _tT4 = "tokenType";
    n09 = "com.amazonaws.signin";
    _s_registry9 = TypeRegistry.for(_s9);
    SigninServiceException$3 = [-3, _s9, "SigninServiceException", 0, [], []];
    _s_registry9.registerError(SigninServiceException$3, SigninServiceException3);
    n0_registry9 = TypeRegistry.for(n09);
    AccessDeniedException$4 = [-3, n09, _ADE4, { [_e9]: _c9 }, [_e9, _m8], [0, 0], 2];
    n0_registry9.registerError(AccessDeniedException$4, AccessDeniedException4);
    InternalServerException$4 = [-3, n09, _ISE4, { [_e9]: _se4, [_hE9]: 500 }, [_e9, _m8], [0, 0], 2];
    n0_registry9.registerError(InternalServerException$4, InternalServerException4);
    TooManyRequestsError$3 = [-3, n09, _TMRE6, { [_e9]: _c9, [_hE9]: 429 }, [_e9, _m8], [0, 0], 2];
    n0_registry9.registerError(TooManyRequestsError$3, TooManyRequestsError3);
    ValidationException$3 = [-3, n09, _VE3, { [_e9]: _c9, [_hE9]: 400 }, [_e9, _m8], [0, 0], 2];
    n0_registry9.registerError(ValidationException$3, ValidationException3);
    errorTypeRegistries9 = [_s_registry9, n0_registry9];
    RefreshToken4 = [0, n09, _RT4, 8, 0];
    AccessToken$3 = [
      3,
      n09,
      _AT4,
      8,
      [_aKI6, _sAK6, _sT6],
      [
        [0, { [_jN3]: _aKI6 }],
        [0, { [_jN3]: _sAK6 }],
        [0, { [_jN3]: _sT6 }]
      ],
      3
    ];
    CreateOAuth2TokenRequest$3 = [
      3,
      n09,
      _COATR3,
      0,
      [_tI3],
      [[() => CreateOAuth2TokenRequestBody$3, 16]],
      1
    ];
    CreateOAuth2TokenRequestBody$3 = [
      3,
      n09,
      _COATRB3,
      0,
      [_cI4, _gT4, _co4, _rU4, _cV4, _rT4],
      [
        [0, { [_jN3]: _cI4 }],
        [0, { [_jN3]: _gT4 }],
        0,
        [0, { [_jN3]: _rU4 }],
        [0, { [_jN3]: _cV4 }],
        [() => RefreshToken4, { [_jN3]: _rT4 }]
      ],
      2
    ];
    CreateOAuth2TokenResponse$3 = [
      3,
      n09,
      _COATRr3,
      0,
      [_tO3],
      [[() => CreateOAuth2TokenResponseBody$3, 16]],
      1
    ];
    CreateOAuth2TokenResponseBody$3 = [
      3,
      n09,
      _COATRBr3,
      0,
      [_aT7, _tT4, _eI4, _rT4, _iT4],
      [
        [() => AccessToken$3, { [_jN3]: _aT7 }],
        [0, { [_jN3]: _tT4 }],
        [1, { [_jN3]: _eI4 }],
        [() => RefreshToken4, { [_jN3]: _rT4 }],
        [0, { [_jN3]: _iT4 }]
      ],
      4
    ];
    CreateOAuth2Token$3 = [
      9,
      n09,
      _COAT3,
      { [_h7]: ["POST", "/v1/token", 200] },
      () => CreateOAuth2TokenRequest$3,
      () => CreateOAuth2TokenResponse$3
    ];
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.shared.js
var import_smithy_client87, import_url_parser10, import_util_base6429, import_util_utf823, getRuntimeConfig17;
var init_runtimeConfig_shared9 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.shared.js"() {
    init_httpAuthSchemes5();
    init_protocols7();
    init_dist_es();
    import_smithy_client87 = __toESM(require_dist_cjs34());
    import_url_parser10 = __toESM(require_dist_cjs18());
    import_util_base6429 = __toESM(require_dist_cjs10());
    import_util_utf823 = __toESM(require_dist_cjs9());
    init_httpAuthSchemeProvider9();
    init_endpointResolver9();
    init_schemas_09();
    getRuntimeConfig17 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2023-01-01",
        base64Decoder: config2?.base64Decoder ?? import_util_base6429.fromBase64,
        base64Encoder: config2?.base64Encoder ?? import_util_base6429.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver9,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSigninHttpAuthSchemeProvider3,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer4()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        logger: config2?.logger ?? new import_smithy_client87.NoOpLogger(),
        protocol: config2?.protocol ?? AwsRestJsonProtocol5,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.signin",
          errorTypeRegistries: errorTypeRegistries9,
          version: "2023-01-01",
          serviceTarget: "Signin"
        },
        serviceId: config2?.serviceId ?? "Signin",
        urlParser: config2?.urlParser ?? import_url_parser10.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? import_util_utf823.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? import_util_utf823.toUtf8
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.js
var import_util_user_agent_node9, import_config_resolver17, import_hash_node9, import_middleware_retry17, import_node_config_provider9, import_node_http_handler9, import_smithy_client88, import_util_body_length_node9, import_util_defaults_mode_node9, import_util_retry15, getRuntimeConfig18;
var init_runtimeConfig9 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.js"() {
    init_package4();
    init_client7();
    init_httpAuthSchemes5();
    import_util_user_agent_node9 = __toESM(require_dist_cjs96());
    import_config_resolver17 = __toESM(require_dist_cjs25());
    import_hash_node9 = __toESM(require_dist_cjs44());
    import_middleware_retry17 = __toESM(require_dist_cjs92());
    import_node_config_provider9 = __toESM(require_dist_cjs29());
    import_node_http_handler9 = __toESM(require_dist_cjs13());
    import_smithy_client88 = __toESM(require_dist_cjs34());
    import_util_body_length_node9 = __toESM(require_dist_cjs45());
    import_util_defaults_mode_node9 = __toESM(require_dist_cjs46());
    import_util_retry15 = __toESM(require_dist_cjs22());
    init_runtimeConfig_shared9();
    getRuntimeConfig18 = /* @__PURE__ */ __name((config2) => {
      (0, import_smithy_client88.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, import_util_defaults_mode_node9.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(import_smithy_client88.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig17(config2);
      emitWarningIfUnsupportedVersion13(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, import_node_config_provider9.loadConfig)(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS4, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? import_util_body_length_node9.calculateBodyLength,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, import_util_user_agent_node9.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_default4.version }),
        maxAttempts: config2?.maxAttempts ?? (0, import_node_config_provider9.loadConfig)(import_middleware_retry17.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, import_node_config_provider9.loadConfig)(import_config_resolver17.NODE_REGION_CONFIG_OPTIONS, { ...import_config_resolver17.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: import_node_http_handler9.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, import_node_config_provider9.loadConfig)({
          ...import_middleware_retry17.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || import_util_retry15.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? import_hash_node9.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? import_node_http_handler9.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, import_node_config_provider9.loadConfig)(import_config_resolver17.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, import_node_config_provider9.loadConfig)(import_config_resolver17.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, import_node_config_provider9.loadConfig)(import_util_user_agent_node9.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration9, resolveHttpAuthRuntimeConfig9;
var init_httpAuthExtensionConfiguration9 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration9 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig9 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeExtensions.js
var import_region_config_resolver11, import_protocol_http29, import_smithy_client89, resolveRuntimeExtensions9;
var init_runtimeExtensions9 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeExtensions.js"() {
    import_region_config_resolver11 = __toESM(require_dist_cjs48());
    import_protocol_http29 = __toESM(require_dist_cjs2());
    import_smithy_client89 = __toESM(require_dist_cjs34());
    init_httpAuthExtensionConfiguration9();
    resolveRuntimeExtensions9 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign((0, import_region_config_resolver11.getAwsRegionExtensionConfiguration)(runtimeConfig), (0, import_smithy_client89.getDefaultExtensionConfiguration)(runtimeConfig), (0, import_protocol_http29.getHttpHandlerExtensionConfiguration)(runtimeConfig), getHttpAuthExtensionConfiguration9(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, (0, import_region_config_resolver11.resolveAwsRegionExtensionConfiguration)(extensionConfiguration), (0, import_smithy_client89.resolveDefaultRuntimeConfig)(extensionConfiguration), (0, import_protocol_http29.resolveHttpHandlerRuntimeConfig)(extensionConfiguration), resolveHttpAuthRuntimeConfig9(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/SigninClient.js
var import_middleware_host_header9, import_middleware_logger9, import_middleware_recursion_detection9, import_middleware_user_agent9, import_config_resolver18, import_middleware_content_length9, import_middleware_endpoint21, import_middleware_retry18, import_smithy_client90, SigninClient3;
var init_SigninClient3 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/SigninClient.js"() {
    import_middleware_host_header9 = __toESM(require_dist_cjs3());
    import_middleware_logger9 = __toESM(require_dist_cjs4());
    import_middleware_recursion_detection9 = __toESM(require_dist_cjs5());
    import_middleware_user_agent9 = __toESM(require_dist_cjs91());
    import_config_resolver18 = __toESM(require_dist_cjs25());
    init_dist_es();
    init_schema4();
    import_middleware_content_length9 = __toESM(require_dist_cjs26());
    import_middleware_endpoint21 = __toESM(require_dist_cjs31());
    import_middleware_retry18 = __toESM(require_dist_cjs92());
    import_smithy_client90 = __toESM(require_dist_cjs34());
    init_httpAuthSchemeProvider9();
    init_EndpointParameters9();
    init_runtimeConfig9();
    init_runtimeExtensions9();
    SigninClient3 = class extends import_smithy_client90.Client {
      static {
        __name(this, "SigninClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig18(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters9(_config_0);
        const _config_2 = (0, import_middleware_user_agent9.resolveUserAgentConfig)(_config_1);
        const _config_3 = (0, import_middleware_retry18.resolveRetryConfig)(_config_2);
        const _config_4 = (0, import_config_resolver18.resolveRegionConfig)(_config_3);
        const _config_5 = (0, import_middleware_host_header9.resolveHostHeaderConfig)(_config_4);
        const _config_6 = (0, import_middleware_endpoint21.resolveEndpointConfig)(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig9(_config_6);
        const _config_8 = resolveRuntimeExtensions9(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin(this.config));
        this.middlewareStack.use((0, import_middleware_user_agent9.getUserAgentPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_retry18.getRetryPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_content_length9.getContentLengthPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_host_header9.getHostHeaderPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_logger9.getLoggerPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_recursion_detection9.getRecursionDetectionPlugin)(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: defaultSigninHttpAuthSchemeParametersProvider3,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/CreateOAuth2TokenCommand.js
var import_middleware_endpoint22, import_smithy_client91, CreateOAuth2TokenCommand3;
var init_CreateOAuth2TokenCommand3 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/CreateOAuth2TokenCommand.js"() {
    import_middleware_endpoint22 = __toESM(require_dist_cjs31());
    import_smithy_client91 = __toESM(require_dist_cjs34());
    init_EndpointParameters9();
    init_schemas_09();
    CreateOAuth2TokenCommand3 = class extends import_smithy_client91.Command.classBuilder().ep(commonParams9).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint22.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("Signin", "CreateOAuth2Token", {}).n("SigninClient", "CreateOAuth2TokenCommand").sc(CreateOAuth2Token$3).build() {
      static {
        __name(this, "CreateOAuth2TokenCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/Signin.js
var import_smithy_client92, commands9, Signin3;
var init_Signin3 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/Signin.js"() {
    import_smithy_client92 = __toESM(require_dist_cjs34());
    init_CreateOAuth2TokenCommand3();
    init_SigninClient3();
    commands9 = {
      CreateOAuth2TokenCommand: CreateOAuth2TokenCommand3
    };
    Signin3 = class extends SigninClient3 {
      static {
        __name(this, "Signin");
      }
    };
    (0, import_smithy_client92.createAggregatedClient)(commands9, Signin3);
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/index.js
var init_commands10 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/index.js"() {
    init_CreateOAuth2TokenCommand3();
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/enums.js
var OAuth2ErrorCode3;
var init_enums4 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/enums.js"() {
    OAuth2ErrorCode3 = {
      AUTHCODE_EXPIRED: "AUTHCODE_EXPIRED",
      INSUFFICIENT_PERMISSIONS: "INSUFFICIENT_PERMISSIONS",
      INVALID_REQUEST: "INVALID_REQUEST",
      SERVER_ERROR: "server_error",
      TOKEN_EXPIRED: "TOKEN_EXPIRED",
      USER_CREDENTIALS_CHANGED: "USER_CREDENTIALS_CHANGED"
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/models_0.js
var init_models_09 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/index.js
var signin_exports3 = {};
__export(signin_exports3, {
  $Command: () => import_smithy_client91.Command,
  AccessDeniedException: () => AccessDeniedException4,
  AccessDeniedException$: () => AccessDeniedException$4,
  AccessToken$: () => AccessToken$3,
  CreateOAuth2Token$: () => CreateOAuth2Token$3,
  CreateOAuth2TokenCommand: () => CreateOAuth2TokenCommand3,
  CreateOAuth2TokenRequest$: () => CreateOAuth2TokenRequest$3,
  CreateOAuth2TokenRequestBody$: () => CreateOAuth2TokenRequestBody$3,
  CreateOAuth2TokenResponse$: () => CreateOAuth2TokenResponse$3,
  CreateOAuth2TokenResponseBody$: () => CreateOAuth2TokenResponseBody$3,
  InternalServerException: () => InternalServerException4,
  InternalServerException$: () => InternalServerException$4,
  OAuth2ErrorCode: () => OAuth2ErrorCode3,
  Signin: () => Signin3,
  SigninClient: () => SigninClient3,
  SigninServiceException: () => SigninServiceException3,
  SigninServiceException$: () => SigninServiceException$3,
  TooManyRequestsError: () => TooManyRequestsError3,
  TooManyRequestsError$: () => TooManyRequestsError$3,
  ValidationException: () => ValidationException3,
  ValidationException$: () => ValidationException$3,
  __Client: () => import_smithy_client90.Client,
  errorTypeRegistries: () => errorTypeRegistries9
});
var init_signin3 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/index.js"() {
    init_SigninClient3();
    init_Signin3();
    init_commands10();
    init_schemas_09();
    init_enums4();
    init_errors9();
    init_models_09();
    init_SigninServiceException3();
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-login/dist-cjs/index.js
var require_dist_cjs98 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-login/dist-cjs/index.js"(exports2) {
    "use strict";
    var client = (init_client7(), __toCommonJS(client_exports6));
    var propertyProvider = require_dist_cjs27();
    var sharedIniFileLoader = require_dist_cjs28();
    var protocolHttp = require_dist_cjs2();
    var node_crypto = require("node:crypto");
    var node_fs = require("node:fs");
    var node_os = require("node:os");
    var node_path = require("node:path");
    var LoginCredentialsFetcher = class _LoginCredentialsFetcher {
      static {
        __name(this, "LoginCredentialsFetcher");
      }
      profileData;
      init;
      callerClientConfig;
      static REFRESH_THRESHOLD = 5 * 60 * 1e3;
      constructor(profileData, init, callerClientConfig) {
        this.profileData = profileData;
        this.init = init;
        this.callerClientConfig = callerClientConfig;
      }
      async loadCredentials() {
        const token = await this.loadToken();
        if (!token) {
          throw new propertyProvider.CredentialsProviderError(`Failed to load a token for session ${this.loginSession}, please re-authenticate using aws login`, { tryNextLink: false, logger: this.logger });
        }
        const accessToken = token.accessToken;
        const now = Date.now();
        const expiryTime = new Date(accessToken.expiresAt).getTime();
        const timeUntilExpiry = expiryTime - now;
        if (timeUntilExpiry <= _LoginCredentialsFetcher.REFRESH_THRESHOLD) {
          return this.refresh(token);
        }
        return {
          accessKeyId: accessToken.accessKeyId,
          secretAccessKey: accessToken.secretAccessKey,
          sessionToken: accessToken.sessionToken,
          accountId: accessToken.accountId,
          expiration: new Date(accessToken.expiresAt)
        };
      }
      get logger() {
        return this.init?.logger;
      }
      get loginSession() {
        return this.profileData.login_session;
      }
      async refresh(token) {
        const { SigninClient: SigninClient10, CreateOAuth2TokenCommand: CreateOAuth2TokenCommand10 } = await Promise.resolve().then(() => (init_signin3(), signin_exports3));
        const { logger: logger5, userAgentAppId } = this.callerClientConfig ?? {};
        const isH210 = /* @__PURE__ */ __name((requestHandler2) => {
          return requestHandler2?.metadata?.handlerProtocol === "h2";
        }, "isH2");
        const requestHandler = isH210(this.callerClientConfig?.requestHandler) ? void 0 : this.callerClientConfig?.requestHandler;
        const region = this.profileData.region ?? await this.callerClientConfig?.region?.() ?? process.env.AWS_REGION;
        const client2 = new SigninClient10({
          credentials: {
            accessKeyId: "",
            secretAccessKey: ""
          },
          region,
          requestHandler,
          logger: logger5,
          userAgentAppId,
          ...this.init?.clientConfig
        });
        this.createDPoPInterceptor(client2.middlewareStack);
        const commandInput = {
          tokenInput: {
            clientId: token.clientId,
            refreshToken: token.refreshToken,
            grantType: "refresh_token"
          }
        };
        try {
          const response = await client2.send(new CreateOAuth2TokenCommand10(commandInput));
          const { accessKeyId, secretAccessKey, sessionToken } = response.tokenOutput?.accessToken ?? {};
          const { refreshToken, expiresIn } = response.tokenOutput ?? {};
          if (!accessKeyId || !secretAccessKey || !sessionToken || !refreshToken) {
            throw new propertyProvider.CredentialsProviderError("Token refresh response missing required fields", {
              logger: this.logger,
              tryNextLink: false
            });
          }
          const expiresInMs = (expiresIn ?? 900) * 1e3;
          const expiration = new Date(Date.now() + expiresInMs);
          const updatedToken = {
            ...token,
            accessToken: {
              ...token.accessToken,
              accessKeyId,
              secretAccessKey,
              sessionToken,
              expiresAt: expiration.toISOString()
            },
            refreshToken
          };
          await this.saveToken(updatedToken);
          const newAccessToken = updatedToken.accessToken;
          return {
            accessKeyId: newAccessToken.accessKeyId,
            secretAccessKey: newAccessToken.secretAccessKey,
            sessionToken: newAccessToken.sessionToken,
            accountId: newAccessToken.accountId,
            expiration
          };
        } catch (error4) {
          if (error4.name === "AccessDeniedException") {
            const errorType = error4.error;
            let message2;
            switch (errorType) {
              case "TOKEN_EXPIRED":
                message2 = "Your session has expired. Please reauthenticate.";
                break;
              case "USER_CREDENTIALS_CHANGED":
                message2 = "Unable to refresh credentials because of a change in your password. Please reauthenticate with your new password.";
                break;
              case "INSUFFICIENT_PERMISSIONS":
                message2 = "Unable to refresh credentials due to insufficient permissions. You may be missing permission for the 'CreateOAuth2Token' action.";
                break;
              default:
                message2 = `Failed to refresh token: ${String(error4)}. Please re-authenticate using \`aws login\``;
            }
            throw new propertyProvider.CredentialsProviderError(message2, { logger: this.logger, tryNextLink: false });
          }
          throw new propertyProvider.CredentialsProviderError(`Failed to refresh token: ${String(error4)}. Please re-authenticate using aws login`, { logger: this.logger });
        }
      }
      async loadToken() {
        const tokenFilePath = this.getTokenFilePath();
        try {
          let tokenData;
          try {
            tokenData = await sharedIniFileLoader.readFile(tokenFilePath, { ignoreCache: this.init?.ignoreCache });
          } catch {
            tokenData = await node_fs.promises.readFile(tokenFilePath, "utf8");
          }
          const token = JSON.parse(tokenData);
          const missingFields = ["accessToken", "clientId", "refreshToken", "dpopKey"].filter((k32) => !token[k32]);
          if (!token.accessToken?.accountId) {
            missingFields.push("accountId");
          }
          if (missingFields.length > 0) {
            throw new propertyProvider.CredentialsProviderError(`Token validation failed, missing fields: ${missingFields.join(", ")}`, {
              logger: this.logger,
              tryNextLink: false
            });
          }
          return token;
        } catch (error4) {
          throw new propertyProvider.CredentialsProviderError(`Failed to load token from ${tokenFilePath}: ${String(error4)}`, {
            logger: this.logger,
            tryNextLink: false
          });
        }
      }
      async saveToken(token) {
        const tokenFilePath = this.getTokenFilePath();
        const directory = node_path.dirname(tokenFilePath);
        try {
          await node_fs.promises.mkdir(directory, { recursive: true });
        } catch (error4) {
        }
        await node_fs.promises.writeFile(tokenFilePath, JSON.stringify(token, null, 2), "utf8");
      }
      getTokenFilePath() {
        const directory = process.env.AWS_LOGIN_CACHE_DIRECTORY ?? node_path.join(node_os.homedir(), ".aws", "login", "cache");
        const loginSessionBytes = Buffer.from(this.loginSession, "utf8");
        const loginSessionSha256 = node_crypto.createHash("sha256").update(loginSessionBytes).digest("hex");
        return node_path.join(directory, `${loginSessionSha256}.json`);
      }
      derToRawSignature(derSignature) {
        let offset = 2;
        if (derSignature[offset] !== 2) {
          throw new Error("Invalid DER signature");
        }
        offset++;
        const rLength = derSignature[offset++];
        let r32 = derSignature.subarray(offset, offset + rLength);
        offset += rLength;
        if (derSignature[offset] !== 2) {
          throw new Error("Invalid DER signature");
        }
        offset++;
        const sLength = derSignature[offset++];
        let s = derSignature.subarray(offset, offset + sLength);
        r32 = r32[0] === 0 ? r32.subarray(1) : r32;
        s = s[0] === 0 ? s.subarray(1) : s;
        const rPadded = Buffer.concat([Buffer.alloc(32 - r32.length), r32]);
        const sPadded = Buffer.concat([Buffer.alloc(32 - s.length), s]);
        return Buffer.concat([rPadded, sPadded]);
      }
      createDPoPInterceptor(middlewareStack) {
        middlewareStack.add((next) => async (args) => {
          if (protocolHttp.HttpRequest.isInstance(args.request)) {
            const request4 = args.request;
            const actualEndpoint = `${request4.protocol}//${request4.hostname}${request4.port ? `:${request4.port}` : ""}${request4.path}`;
            const dpop = await this.generateDpop(request4.method, actualEndpoint);
            request4.headers = {
              ...request4.headers,
              DPoP: dpop
            };
          }
          return next(args);
        }, {
          step: "finalizeRequest",
          name: "dpopInterceptor",
          override: true
        });
      }
      async generateDpop(method = "POST", endpoint) {
        const token = await this.loadToken();
        try {
          const privateKey = node_crypto.createPrivateKey({
            key: token.dpopKey,
            format: "pem",
            type: "sec1"
          });
          const publicKey = node_crypto.createPublicKey(privateKey);
          const publicDer = publicKey.export({ format: "der", type: "spki" });
          let pointStart = -1;
          for (let i32 = 0; i32 < publicDer.length; i32++) {
            if (publicDer[i32] === 4) {
              pointStart = i32;
              break;
            }
          }
          const x = publicDer.slice(pointStart + 1, pointStart + 33);
          const y = publicDer.slice(pointStart + 33, pointStart + 65);
          const header = {
            alg: "ES256",
            typ: "dpop+jwt",
            jwk: {
              kty: "EC",
              crv: "P-256",
              x: x.toString("base64url"),
              y: y.toString("base64url")
            }
          };
          const payload3 = {
            jti: crypto.randomUUID(),
            htm: method,
            htu: endpoint,
            iat: Math.floor(Date.now() / 1e3)
          };
          const headerB64 = Buffer.from(JSON.stringify(header)).toString("base64url");
          const payloadB64 = Buffer.from(JSON.stringify(payload3)).toString("base64url");
          const message2 = `${headerB64}.${payloadB64}`;
          const asn1Signature = node_crypto.sign("sha256", Buffer.from(message2), privateKey);
          const rawSignature = this.derToRawSignature(asn1Signature);
          const signatureB64 = rawSignature.toString("base64url");
          return `${message2}.${signatureB64}`;
        } catch (error4) {
          throw new propertyProvider.CredentialsProviderError(`Failed to generate Dpop proof: ${error4 instanceof Error ? error4.message : String(error4)}`, { logger: this.logger, tryNextLink: false });
        }
      }
    };
    var fromLoginCredentials = /* @__PURE__ */ __name((init) => async ({ callerClientConfig } = {}) => {
      init?.logger?.debug?.("@aws-sdk/credential-providers - fromLoginCredentials");
      const profiles = await sharedIniFileLoader.parseKnownFiles(init || {});
      const profileName = sharedIniFileLoader.getProfileName({
        profile: init?.profile ?? callerClientConfig?.profile
      });
      const profile = profiles[profileName];
      if (!profile?.login_session) {
        throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} does not contain login_session.`, {
          tryNextLink: true,
          logger: init?.logger
        });
      }
      const fetcher = new LoginCredentialsFetcher(profile, init, callerClientConfig);
      const credentials = await fetcher.loadCredentials();
      return client.setCredentialFeature(credentials, "CREDENTIALS_LOGIN", "AD");
    }, "fromLoginCredentials");
    exports2.fromLoginCredentials = fromLoginCredentials;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/bdd.js
var import_util_endpoints28, q3, a10, b10, c10, d10, e10, f10, g10, h10, i10, j10, k10, l6, m6, n3, o3, p3, _data10, root10, r10, nodes10, bdd10;
var init_bdd10 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/bdd.js"() {
    import_util_endpoints28 = __toESM(require_dist_cjs20());
    q3 = "ref";
    a10 = -1;
    b10 = true;
    c10 = "isSet";
    d10 = "PartitionResult";
    e10 = "booleanEquals";
    f10 = "stringEquals";
    g10 = "getAttr";
    h10 = "us-east-1";
    i10 = "sigv4";
    j10 = "sts";
    k10 = "https://sts.{Region}.{PartitionResult#dnsSuffix}";
    l6 = { [q3]: "Endpoint" };
    m6 = { [q3]: "Region" };
    n3 = { [q3]: d10 };
    o3 = {};
    p3 = [m6];
    _data10 = {
      conditions: [
        [c10, [l6]],
        [c10, p3],
        ["aws.partition", p3, d10],
        [e10, [{ [q3]: "UseFIPS" }, b10]],
        [e10, [{ [q3]: "UseDualStack" }, b10]],
        [f10, [m6, "aws-global"]],
        [e10, [{ [q3]: "UseGlobalEndpoint" }, b10]],
        [f10, [m6, "eu-central-1"]],
        [e10, [{ fn: g10, argv: [n3, "supportsDualStack"] }, b10]],
        [e10, [{ fn: g10, argv: [n3, "supportsFIPS"] }, b10]],
        [f10, [m6, "ap-south-1"]],
        [f10, [m6, "eu-north-1"]],
        [f10, [m6, "eu-west-1"]],
        [f10, [m6, "eu-west-2"]],
        [f10, [m6, "eu-west-3"]],
        [f10, [m6, "sa-east-1"]],
        [f10, [m6, h10]],
        [f10, [m6, "us-east-2"]],
        [f10, [m6, "us-west-2"]],
        [f10, [m6, "us-west-1"]],
        [f10, [m6, "ca-central-1"]],
        [f10, [m6, "ap-southeast-1"]],
        [f10, [m6, "ap-northeast-1"]],
        [f10, [m6, "ap-southeast-2"]],
        [f10, [{ fn: g10, argv: [n3, "name"] }, "aws-us-gov"]]
      ],
      results: [
        [a10],
        ["https://sts.amazonaws.com", { authSchemes: [{ name: i10, signingName: j10, signingRegion: h10 }] }],
        [k10, { authSchemes: [{ name: i10, signingName: j10, signingRegion: "{Region}" }] }],
        [a10, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a10, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [l6, o3],
        ["https://sts-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", o3],
        [a10, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://sts.{Region}.amazonaws.com", o3],
        ["https://sts-fips.{Region}.{PartitionResult#dnsSuffix}", o3],
        [a10, "FIPS is enabled but this partition does not support FIPS"],
        ["https://sts.{Region}.{PartitionResult#dualStackDnsSuffix}", o3],
        [a10, "DualStack is enabled but this partition does not support DualStack"],
        [k10, o3],
        [a10, "Invalid Configuration: Missing Region"]
      ]
    };
    root10 = 2;
    r10 = 1e8;
    nodes10 = new Int32Array([
      -1,
      1,
      -1,
      0,
      30,
      3,
      1,
      4,
      r10 + 14,
      2,
      5,
      r10 + 14,
      3,
      25,
      6,
      4,
      24,
      7,
      5,
      r10 + 1,
      8,
      6,
      9,
      r10 + 13,
      7,
      r10 + 1,
      10,
      10,
      r10 + 1,
      11,
      11,
      r10 + 1,
      12,
      12,
      r10 + 1,
      13,
      13,
      r10 + 1,
      14,
      14,
      r10 + 1,
      15,
      15,
      r10 + 1,
      16,
      16,
      r10 + 1,
      17,
      17,
      r10 + 1,
      18,
      18,
      r10 + 1,
      19,
      19,
      r10 + 1,
      20,
      20,
      r10 + 1,
      21,
      21,
      r10 + 1,
      22,
      22,
      r10 + 1,
      23,
      23,
      r10 + 1,
      r10 + 2,
      8,
      r10 + 11,
      r10 + 12,
      4,
      28,
      26,
      9,
      27,
      r10 + 10,
      24,
      r10 + 8,
      r10 + 9,
      8,
      29,
      r10 + 7,
      9,
      r10 + 6,
      r10 + 7,
      3,
      r10 + 3,
      31,
      4,
      r10 + 4,
      r10 + 5
    ]);
    bdd10 = import_util_endpoints28.BinaryDecisionDiagram.from(nodes10, root10, _data10.conditions, _data10.results);
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/endpointResolver.js
var import_util_endpoints29, import_util_endpoints30, cache10, defaultEndpointResolver10;
var init_endpointResolver10 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/endpointResolver.js"() {
    import_util_endpoints29 = __toESM(require_dist_cjs21());
    import_util_endpoints30 = __toESM(require_dist_cjs20());
    init_bdd10();
    cache10 = new import_util_endpoints30.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS", "UseGlobalEndpoint"]
    });
    defaultEndpointResolver10 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache10.get(endpointParams, () => (0, import_util_endpoints30.decideEndpoint)(bdd10, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    import_util_endpoints30.customEndpointFunctions.aws = import_util_endpoints29.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption10(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "sts",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createAwsAuthSigv4aHttpAuthOption3(authParameters) {
  return {
    schemeId: "aws.auth#sigv4a",
    signingProperties: {
      name: "sts",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption10(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var import_signature_v4_multi_region5, import_middleware_endpoint23, import_util_middleware15, createEndpointRuleSetHttpAuthSchemeParametersProvider3, _defaultSTSHttpAuthSchemeParametersProvider3, defaultSTSHttpAuthSchemeParametersProvider3, createEndpointRuleSetHttpAuthSchemeProvider3, _defaultSTSHttpAuthSchemeProvider3, defaultSTSHttpAuthSchemeProvider3, resolveStsAuthConfig3, resolveHttpAuthSchemeConfig10;
var init_httpAuthSchemeProvider10 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes5();
    import_signature_v4_multi_region5 = __toESM(require_dist_cjs55());
    import_middleware_endpoint23 = __toESM(require_dist_cjs31());
    import_util_middleware15 = __toESM(require_dist_cjs6());
    init_endpointResolver10();
    init_STSClient3();
    createEndpointRuleSetHttpAuthSchemeParametersProvider3 = /* @__PURE__ */ __name((defaultHttpAuthSchemeParametersProvider) => async (config2, context, input) => {
      if (!input) {
        throw new Error("Could not find `input` for `defaultEndpointRuleSetHttpAuthSchemeParametersProvider`");
      }
      const defaultParameters = await defaultHttpAuthSchemeParametersProvider(config2, context, input);
      const instructionsFn = (0, import_util_middleware15.getSmithyContext)(context)?.commandInstance?.constructor?.getEndpointParameterInstructions;
      if (!instructionsFn) {
        throw new Error(`getEndpointParameterInstructions() is not defined on '${context.commandName}'`);
      }
      const endpointParameters = await (0, import_middleware_endpoint23.resolveParams)(input, { getEndpointParameterInstructions: instructionsFn }, config2);
      return Object.assign(defaultParameters, endpointParameters);
    }, "createEndpointRuleSetHttpAuthSchemeParametersProvider");
    _defaultSTSHttpAuthSchemeParametersProvider3 = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, import_util_middleware15.getSmithyContext)(context).operation,
        region: await (0, import_util_middleware15.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "_defaultSTSHttpAuthSchemeParametersProvider");
    defaultSTSHttpAuthSchemeParametersProvider3 = createEndpointRuleSetHttpAuthSchemeParametersProvider3(_defaultSTSHttpAuthSchemeParametersProvider3);
    __name(createAwsAuthSigv4HttpAuthOption10, "createAwsAuthSigv4HttpAuthOption");
    __name(createAwsAuthSigv4aHttpAuthOption3, "createAwsAuthSigv4aHttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption10, "createSmithyApiNoAuthHttpAuthOption");
    createEndpointRuleSetHttpAuthSchemeProvider3 = /* @__PURE__ */ __name((defaultEndpointResolver32, defaultHttpAuthSchemeResolver, createHttpAuthOptionFunctions) => {
      const endpointRuleSetHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
        const endpoint = defaultEndpointResolver32(authParameters);
        const authSchemes = endpoint.properties?.authSchemes;
        if (!authSchemes) {
          return defaultHttpAuthSchemeResolver(authParameters);
        }
        const options = [];
        for (const scheme of authSchemes) {
          const { name: resolvedName, properties = {}, ...rest } = scheme;
          const name = resolvedName.toLowerCase();
          if (resolvedName !== name) {
            console.warn(`HttpAuthScheme has been normalized with lowercasing: '${resolvedName}' to '${name}'`);
          }
          let schemeId;
          if (name === "sigv4a") {
            schemeId = "aws.auth#sigv4a";
            const sigv4Present = authSchemes.find((s) => {
              const name2 = s.name.toLowerCase();
              return name2 !== "sigv4a" && name2.startsWith("sigv4");
            });
            if (import_signature_v4_multi_region5.SignatureV4MultiRegion.sigv4aDependency() === "none" && sigv4Present) {
              continue;
            }
          } else if (name.startsWith("sigv4")) {
            schemeId = "aws.auth#sigv4";
          } else {
            throw new Error(`Unknown HttpAuthScheme found in '@smithy.rules#endpointRuleSet': '${name}'`);
          }
          const createOption = createHttpAuthOptionFunctions[schemeId];
          if (!createOption) {
            throw new Error(`Could not find HttpAuthOption create function for '${schemeId}'`);
          }
          const option = createOption(authParameters);
          option.schemeId = schemeId;
          option.signingProperties = { ...option.signingProperties || {}, ...rest, ...properties };
          options.push(option);
        }
        return options;
      }, "endpointRuleSetHttpAuthSchemeProvider");
      return endpointRuleSetHttpAuthSchemeProvider;
    }, "createEndpointRuleSetHttpAuthSchemeProvider");
    _defaultSTSHttpAuthSchemeProvider3 = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "AssumeRoleWithWebIdentity": {
          options.push(createSmithyApiNoAuthHttpAuthOption10(authParameters));
          options.push(createAwsAuthSigv4aHttpAuthOption3(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption10(authParameters));
          options.push(createAwsAuthSigv4aHttpAuthOption3(authParameters));
        }
      }
      return options;
    }, "_defaultSTSHttpAuthSchemeProvider");
    defaultSTSHttpAuthSchemeProvider3 = createEndpointRuleSetHttpAuthSchemeProvider3(defaultEndpointResolver10, _defaultSTSHttpAuthSchemeProvider3, {
      "aws.auth#sigv4": createAwsAuthSigv4HttpAuthOption10,
      "aws.auth#sigv4a": createAwsAuthSigv4aHttpAuthOption3,
      "smithy.api#noAuth": createSmithyApiNoAuthHttpAuthOption10
    });
    resolveStsAuthConfig3 = /* @__PURE__ */ __name((input) => Object.assign(input, {
      stsClientCtor: STSClient3
    }), "resolveStsAuthConfig");
    resolveHttpAuthSchemeConfig10 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveStsAuthConfig3(config2);
      const config_1 = resolveAwsSdkSigV4Config4(config_0);
      const config_2 = resolveAwsSdkSigV4AConfig4(config_1);
      return Object.assign(config_2, {
        authSchemePreference: (0, import_util_middleware15.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/EndpointParameters.js
var resolveClientEndpointParameters10, commonParams10;
var init_EndpointParameters10 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters10 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        useGlobalEndpoint: options.useGlobalEndpoint ?? false,
        defaultSigningName: "sts"
      });
    }, "resolveClientEndpointParameters");
    commonParams10 = {
      UseGlobalEndpoint: { type: "builtInParams", name: "useGlobalEndpoint" },
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/STSServiceException.js
var import_smithy_client93, STSServiceException3;
var init_STSServiceException3 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/STSServiceException.js"() {
    import_smithy_client93 = __toESM(require_dist_cjs34());
    STSServiceException3 = class _STSServiceException extends import_smithy_client93.ServiceException {
      static {
        __name(this, "STSServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _STSServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/errors.js
var ExpiredTokenException4, MalformedPolicyDocumentException3, PackedPolicyTooLargeException3, RegionDisabledException3, IDPRejectedClaimException3, InvalidIdentityTokenException3, IDPCommunicationErrorException3;
var init_errors10 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/errors.js"() {
    init_STSServiceException3();
    ExpiredTokenException4 = class _ExpiredTokenException extends STSServiceException3 {
      static {
        __name(this, "ExpiredTokenException");
      }
      name = "ExpiredTokenException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ExpiredTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ExpiredTokenException.prototype);
      }
    };
    MalformedPolicyDocumentException3 = class _MalformedPolicyDocumentException extends STSServiceException3 {
      static {
        __name(this, "MalformedPolicyDocumentException");
      }
      name = "MalformedPolicyDocumentException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "MalformedPolicyDocumentException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _MalformedPolicyDocumentException.prototype);
      }
    };
    PackedPolicyTooLargeException3 = class _PackedPolicyTooLargeException extends STSServiceException3 {
      static {
        __name(this, "PackedPolicyTooLargeException");
      }
      name = "PackedPolicyTooLargeException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "PackedPolicyTooLargeException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _PackedPolicyTooLargeException.prototype);
      }
    };
    RegionDisabledException3 = class _RegionDisabledException extends STSServiceException3 {
      static {
        __name(this, "RegionDisabledException");
      }
      name = "RegionDisabledException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "RegionDisabledException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _RegionDisabledException.prototype);
      }
    };
    IDPRejectedClaimException3 = class _IDPRejectedClaimException extends STSServiceException3 {
      static {
        __name(this, "IDPRejectedClaimException");
      }
      name = "IDPRejectedClaimException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "IDPRejectedClaimException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _IDPRejectedClaimException.prototype);
      }
    };
    InvalidIdentityTokenException3 = class _InvalidIdentityTokenException extends STSServiceException3 {
      static {
        __name(this, "InvalidIdentityTokenException");
      }
      name = "InvalidIdentityTokenException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidIdentityTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidIdentityTokenException.prototype);
      }
    };
    IDPCommunicationErrorException3 = class _IDPCommunicationErrorException extends STSServiceException3 {
      static {
        __name(this, "IDPCommunicationErrorException");
      }
      name = "IDPCommunicationErrorException";
      $fault = "client";
      $retryable = {};
      constructor(opts) {
        super({
          name: "IDPCommunicationErrorException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _IDPCommunicationErrorException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/schemas/schemas_0.js
var _A3, _AKI3, _AR3, _ARI3, _ARR3, _ARRs3, _ARU3, _ARWWI3, _ARWWIR3, _ARWWIRs3, _Au3, _C3, _CA3, _DS3, _E3, _EI3, _ETE4, _IDPCEE3, _IDPRCE3, _IITE3, _K3, _MPDE3, _P3, _PA3, _PAr3, _PC3, _PCLT3, _PCr3, _PDT3, _PI3, _PPS3, _PPTLE3, _Pr3, _RA3, _RDE3, _RSN3, _SAK3, _SFWIT3, _SI3, _SN3, _ST3, _T3, _TC3, _TTK3, _Ta3, _V3, _WIT3, _a3, _aKST3, _aQE3, _c10, _cTT3, _e10, _hE10, _m9, _pDLT3, _s10, _tLT3, n010, _s_registry10, STSServiceException$3, n0_registry10, ExpiredTokenException$4, IDPCommunicationErrorException$3, IDPRejectedClaimException$3, InvalidIdentityTokenException$3, MalformedPolicyDocumentException$3, PackedPolicyTooLargeException$3, RegionDisabledException$3, errorTypeRegistries10, accessKeySecretType3, clientTokenType3, AssumedRoleUser$3, AssumeRoleRequest$3, AssumeRoleResponse$3, AssumeRoleWithWebIdentityRequest$3, AssumeRoleWithWebIdentityResponse$3, Credentials$3, PolicyDescriptorType$3, ProvidedContext$3, Tag$3, policyDescriptorListType3, ProvidedContextsListType3, tagKeyListType3, tagListType3, AssumeRole$3, AssumeRoleWithWebIdentity$3;
var init_schemas_010 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/schemas/schemas_0.js"() {
    init_schema4();
    init_errors10();
    init_STSServiceException3();
    _A3 = "Arn";
    _AKI3 = "AccessKeyId";
    _AR3 = "AssumeRole";
    _ARI3 = "AssumedRoleId";
    _ARR3 = "AssumeRoleRequest";
    _ARRs3 = "AssumeRoleResponse";
    _ARU3 = "AssumedRoleUser";
    _ARWWI3 = "AssumeRoleWithWebIdentity";
    _ARWWIR3 = "AssumeRoleWithWebIdentityRequest";
    _ARWWIRs3 = "AssumeRoleWithWebIdentityResponse";
    _Au3 = "Audience";
    _C3 = "Credentials";
    _CA3 = "ContextAssertion";
    _DS3 = "DurationSeconds";
    _E3 = "Expiration";
    _EI3 = "ExternalId";
    _ETE4 = "ExpiredTokenException";
    _IDPCEE3 = "IDPCommunicationErrorException";
    _IDPRCE3 = "IDPRejectedClaimException";
    _IITE3 = "InvalidIdentityTokenException";
    _K3 = "Key";
    _MPDE3 = "MalformedPolicyDocumentException";
    _P3 = "Policy";
    _PA3 = "PolicyArns";
    _PAr3 = "ProviderArn";
    _PC3 = "ProvidedContexts";
    _PCLT3 = "ProvidedContextsListType";
    _PCr3 = "ProvidedContext";
    _PDT3 = "PolicyDescriptorType";
    _PI3 = "ProviderId";
    _PPS3 = "PackedPolicySize";
    _PPTLE3 = "PackedPolicyTooLargeException";
    _Pr3 = "Provider";
    _RA3 = "RoleArn";
    _RDE3 = "RegionDisabledException";
    _RSN3 = "RoleSessionName";
    _SAK3 = "SecretAccessKey";
    _SFWIT3 = "SubjectFromWebIdentityToken";
    _SI3 = "SourceIdentity";
    _SN3 = "SerialNumber";
    _ST3 = "SessionToken";
    _T3 = "Tags";
    _TC3 = "TokenCode";
    _TTK3 = "TransitiveTagKeys";
    _Ta3 = "Tag";
    _V3 = "Value";
    _WIT3 = "WebIdentityToken";
    _a3 = "arn";
    _aKST3 = "accessKeySecretType";
    _aQE3 = "awsQueryError";
    _c10 = "client";
    _cTT3 = "clientTokenType";
    _e10 = "error";
    _hE10 = "httpError";
    _m9 = "message";
    _pDLT3 = "policyDescriptorListType";
    _s10 = "smithy.ts.sdk.synthetic.com.amazonaws.sts";
    _tLT3 = "tagListType";
    n010 = "com.amazonaws.sts";
    _s_registry10 = TypeRegistry.for(_s10);
    STSServiceException$3 = [-3, _s10, "STSServiceException", 0, [], []];
    _s_registry10.registerError(STSServiceException$3, STSServiceException3);
    n0_registry10 = TypeRegistry.for(n010);
    ExpiredTokenException$4 = [
      -3,
      n010,
      _ETE4,
      { [_aQE3]: [`ExpiredTokenException`, 400], [_e10]: _c10, [_hE10]: 400 },
      [_m9],
      [0]
    ];
    n0_registry10.registerError(ExpiredTokenException$4, ExpiredTokenException4);
    IDPCommunicationErrorException$3 = [
      -3,
      n010,
      _IDPCEE3,
      { [_aQE3]: [`IDPCommunicationError`, 400], [_e10]: _c10, [_hE10]: 400 },
      [_m9],
      [0]
    ];
    n0_registry10.registerError(IDPCommunicationErrorException$3, IDPCommunicationErrorException3);
    IDPRejectedClaimException$3 = [
      -3,
      n010,
      _IDPRCE3,
      { [_aQE3]: [`IDPRejectedClaim`, 403], [_e10]: _c10, [_hE10]: 403 },
      [_m9],
      [0]
    ];
    n0_registry10.registerError(IDPRejectedClaimException$3, IDPRejectedClaimException3);
    InvalidIdentityTokenException$3 = [
      -3,
      n010,
      _IITE3,
      { [_aQE3]: [`InvalidIdentityToken`, 400], [_e10]: _c10, [_hE10]: 400 },
      [_m9],
      [0]
    ];
    n0_registry10.registerError(InvalidIdentityTokenException$3, InvalidIdentityTokenException3);
    MalformedPolicyDocumentException$3 = [
      -3,
      n010,
      _MPDE3,
      { [_aQE3]: [`MalformedPolicyDocument`, 400], [_e10]: _c10, [_hE10]: 400 },
      [_m9],
      [0]
    ];
    n0_registry10.registerError(MalformedPolicyDocumentException$3, MalformedPolicyDocumentException3);
    PackedPolicyTooLargeException$3 = [
      -3,
      n010,
      _PPTLE3,
      { [_aQE3]: [`PackedPolicyTooLarge`, 400], [_e10]: _c10, [_hE10]: 400 },
      [_m9],
      [0]
    ];
    n0_registry10.registerError(PackedPolicyTooLargeException$3, PackedPolicyTooLargeException3);
    RegionDisabledException$3 = [
      -3,
      n010,
      _RDE3,
      { [_aQE3]: [`RegionDisabledException`, 403], [_e10]: _c10, [_hE10]: 403 },
      [_m9],
      [0]
    ];
    n0_registry10.registerError(RegionDisabledException$3, RegionDisabledException3);
    errorTypeRegistries10 = [_s_registry10, n0_registry10];
    accessKeySecretType3 = [0, n010, _aKST3, 8, 0];
    clientTokenType3 = [0, n010, _cTT3, 8, 0];
    AssumedRoleUser$3 = [3, n010, _ARU3, 0, [_ARI3, _A3], [0, 0], 2];
    AssumeRoleRequest$3 = [
      3,
      n010,
      _ARR3,
      0,
      [_RA3, _RSN3, _PA3, _P3, _DS3, _T3, _TTK3, _EI3, _SN3, _TC3, _SI3, _PC3],
      [0, 0, () => policyDescriptorListType3, 0, 1, () => tagListType3, 64 | 0, 0, 0, 0, 0, () => ProvidedContextsListType3],
      2
    ];
    AssumeRoleResponse$3 = [
      3,
      n010,
      _ARRs3,
      0,
      [_C3, _ARU3, _PPS3, _SI3],
      [[() => Credentials$3, 0], () => AssumedRoleUser$3, 1, 0]
    ];
    AssumeRoleWithWebIdentityRequest$3 = [
      3,
      n010,
      _ARWWIR3,
      0,
      [_RA3, _RSN3, _WIT3, _PI3, _PA3, _P3, _DS3],
      [0, 0, [() => clientTokenType3, 0], 0, () => policyDescriptorListType3, 0, 1],
      3
    ];
    AssumeRoleWithWebIdentityResponse$3 = [
      3,
      n010,
      _ARWWIRs3,
      0,
      [_C3, _SFWIT3, _ARU3, _PPS3, _Pr3, _Au3, _SI3],
      [[() => Credentials$3, 0], 0, () => AssumedRoleUser$3, 1, 0, 0, 0]
    ];
    Credentials$3 = [
      3,
      n010,
      _C3,
      0,
      [_AKI3, _SAK3, _ST3, _E3],
      [0, [() => accessKeySecretType3, 0], 0, 4],
      4
    ];
    PolicyDescriptorType$3 = [3, n010, _PDT3, 0, [_a3], [0]];
    ProvidedContext$3 = [3, n010, _PCr3, 0, [_PAr3, _CA3], [0, 0]];
    Tag$3 = [3, n010, _Ta3, 0, [_K3, _V3], [0, 0], 2];
    policyDescriptorListType3 = [1, n010, _pDLT3, 0, () => PolicyDescriptorType$3];
    ProvidedContextsListType3 = [1, n010, _PCLT3, 0, () => ProvidedContext$3];
    tagKeyListType3 = 64 | 0;
    tagListType3 = [1, n010, _tLT3, 0, () => Tag$3];
    AssumeRole$3 = [9, n010, _AR3, 0, () => AssumeRoleRequest$3, () => AssumeRoleResponse$3];
    AssumeRoleWithWebIdentity$3 = [
      9,
      n010,
      _ARWWI3,
      0,
      () => AssumeRoleWithWebIdentityRequest$3,
      () => AssumeRoleWithWebIdentityResponse$3
    ];
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.shared.js
var import_signature_v4_multi_region6, import_smithy_client94, import_url_parser11, import_util_base6430, import_util_utf824, getRuntimeConfig19;
var init_runtimeConfig_shared10 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.shared.js"() {
    init_httpAuthSchemes5();
    init_protocols7();
    import_signature_v4_multi_region6 = __toESM(require_dist_cjs55());
    init_dist_es();
    import_smithy_client94 = __toESM(require_dist_cjs34());
    import_url_parser11 = __toESM(require_dist_cjs18());
    import_util_base6430 = __toESM(require_dist_cjs10());
    import_util_utf824 = __toESM(require_dist_cjs9());
    init_httpAuthSchemeProvider10();
    init_endpointResolver10();
    init_schemas_010();
    getRuntimeConfig19 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2011-06-15",
        base64Decoder: config2?.base64Decoder ?? import_util_base6430.fromBase64,
        base64Encoder: config2?.base64Encoder ?? import_util_base6430.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver10,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSTSHttpAuthSchemeProvider3,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer4()
          },
          {
            schemeId: "aws.auth#sigv4a",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4a"), "identityProvider"),
            signer: new AwsSdkSigV4ASigner4()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        logger: config2?.logger ?? new import_smithy_client94.NoOpLogger(),
        protocol: config2?.protocol ?? AwsQueryProtocol4,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.sts",
          errorTypeRegistries: errorTypeRegistries10,
          xmlNamespace: "https://sts.amazonaws.com/doc/2011-06-15/",
          version: "2011-06-15",
          serviceTarget: "AWSSecurityTokenServiceV20110615"
        },
        serviceId: config2?.serviceId ?? "STS",
        signerConstructor: config2?.signerConstructor ?? import_signature_v4_multi_region6.SignatureV4MultiRegion,
        urlParser: config2?.urlParser ?? import_url_parser11.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? import_util_utf824.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? import_util_utf824.toUtf8
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.js
var import_util_user_agent_node10, import_config_resolver19, import_hash_node10, import_middleware_retry19, import_node_config_provider10, import_node_http_handler10, import_smithy_client95, import_util_body_length_node10, import_util_defaults_mode_node10, import_util_retry16, getRuntimeConfig20;
var init_runtimeConfig10 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.js"() {
    init_package4();
    init_client7();
    init_httpAuthSchemes5();
    import_util_user_agent_node10 = __toESM(require_dist_cjs96());
    import_config_resolver19 = __toESM(require_dist_cjs25());
    init_dist_es();
    import_hash_node10 = __toESM(require_dist_cjs44());
    import_middleware_retry19 = __toESM(require_dist_cjs92());
    import_node_config_provider10 = __toESM(require_dist_cjs29());
    import_node_http_handler10 = __toESM(require_dist_cjs13());
    import_smithy_client95 = __toESM(require_dist_cjs34());
    import_util_body_length_node10 = __toESM(require_dist_cjs45());
    import_util_defaults_mode_node10 = __toESM(require_dist_cjs46());
    import_util_retry16 = __toESM(require_dist_cjs22());
    init_runtimeConfig_shared10();
    getRuntimeConfig20 = /* @__PURE__ */ __name((config2) => {
      (0, import_smithy_client95.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, import_util_defaults_mode_node10.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(import_smithy_client95.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig19(config2);
      emitWarningIfUnsupportedVersion13(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, import_node_config_provider10.loadConfig)(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS4, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? import_util_body_length_node10.calculateBodyLength,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, import_util_user_agent_node10.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_default4.version }),
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4") || (async (idProps) => await config2.credentialDefaultProvider(idProps?.__config || {})()), "identityProvider"),
            signer: new AwsSdkSigV4Signer4()
          },
          {
            schemeId: "aws.auth#sigv4a",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4a"), "identityProvider"),
            signer: new AwsSdkSigV4ASigner4()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        maxAttempts: config2?.maxAttempts ?? (0, import_node_config_provider10.loadConfig)(import_middleware_retry19.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, import_node_config_provider10.loadConfig)(import_config_resolver19.NODE_REGION_CONFIG_OPTIONS, { ...import_config_resolver19.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: import_node_http_handler10.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, import_node_config_provider10.loadConfig)({
          ...import_middleware_retry19.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || import_util_retry16.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? import_hash_node10.Hash.bind(null, "sha256"),
        sigv4aSigningRegionSet: config2?.sigv4aSigningRegionSet ?? (0, import_node_config_provider10.loadConfig)(NODE_SIGV4A_CONFIG_OPTIONS4, loaderConfig),
        streamCollector: config2?.streamCollector ?? import_node_http_handler10.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, import_node_config_provider10.loadConfig)(import_config_resolver19.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, import_node_config_provider10.loadConfig)(import_config_resolver19.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, import_node_config_provider10.loadConfig)(import_util_user_agent_node10.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration10, resolveHttpAuthRuntimeConfig10;
var init_httpAuthExtensionConfiguration10 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration10 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig10 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeExtensions.js
var import_region_config_resolver12, import_protocol_http30, import_smithy_client96, resolveRuntimeExtensions10;
var init_runtimeExtensions10 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeExtensions.js"() {
    import_region_config_resolver12 = __toESM(require_dist_cjs48());
    import_protocol_http30 = __toESM(require_dist_cjs2());
    import_smithy_client96 = __toESM(require_dist_cjs34());
    init_httpAuthExtensionConfiguration10();
    resolveRuntimeExtensions10 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign((0, import_region_config_resolver12.getAwsRegionExtensionConfiguration)(runtimeConfig), (0, import_smithy_client96.getDefaultExtensionConfiguration)(runtimeConfig), (0, import_protocol_http30.getHttpHandlerExtensionConfiguration)(runtimeConfig), getHttpAuthExtensionConfiguration10(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, (0, import_region_config_resolver12.resolveAwsRegionExtensionConfiguration)(extensionConfiguration), (0, import_smithy_client96.resolveDefaultRuntimeConfig)(extensionConfiguration), (0, import_protocol_http30.resolveHttpHandlerRuntimeConfig)(extensionConfiguration), resolveHttpAuthRuntimeConfig10(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STSClient.js
var import_middleware_host_header10, import_middleware_logger10, import_middleware_recursion_detection10, import_middleware_user_agent10, import_config_resolver20, import_middleware_content_length10, import_middleware_endpoint24, import_middleware_retry20, import_smithy_client97, STSClient3;
var init_STSClient3 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STSClient.js"() {
    import_middleware_host_header10 = __toESM(require_dist_cjs3());
    import_middleware_logger10 = __toESM(require_dist_cjs4());
    import_middleware_recursion_detection10 = __toESM(require_dist_cjs5());
    import_middleware_user_agent10 = __toESM(require_dist_cjs91());
    import_config_resolver20 = __toESM(require_dist_cjs25());
    init_dist_es();
    init_schema4();
    import_middleware_content_length10 = __toESM(require_dist_cjs26());
    import_middleware_endpoint24 = __toESM(require_dist_cjs31());
    import_middleware_retry20 = __toESM(require_dist_cjs92());
    import_smithy_client97 = __toESM(require_dist_cjs34());
    init_httpAuthSchemeProvider10();
    init_EndpointParameters10();
    init_runtimeConfig10();
    init_runtimeExtensions10();
    STSClient3 = class extends import_smithy_client97.Client {
      static {
        __name(this, "STSClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig20(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters10(_config_0);
        const _config_2 = (0, import_middleware_user_agent10.resolveUserAgentConfig)(_config_1);
        const _config_3 = (0, import_middleware_retry20.resolveRetryConfig)(_config_2);
        const _config_4 = (0, import_config_resolver20.resolveRegionConfig)(_config_3);
        const _config_5 = (0, import_middleware_host_header10.resolveHostHeaderConfig)(_config_4);
        const _config_6 = (0, import_middleware_endpoint24.resolveEndpointConfig)(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig10(_config_6);
        const _config_8 = resolveRuntimeExtensions10(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin(this.config));
        this.middlewareStack.use((0, import_middleware_user_agent10.getUserAgentPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_retry20.getRetryPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_content_length10.getContentLengthPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_host_header10.getHostHeaderPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_logger10.getLoggerPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_recursion_detection10.getRecursionDetectionPlugin)(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: defaultSTSHttpAuthSchemeParametersProvider3,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials,
            "aws.auth#sigv4a": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleCommand.js
var import_middleware_endpoint25, import_smithy_client98, AssumeRoleCommand3;
var init_AssumeRoleCommand3 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleCommand.js"() {
    import_middleware_endpoint25 = __toESM(require_dist_cjs31());
    import_smithy_client98 = __toESM(require_dist_cjs34());
    init_EndpointParameters10();
    init_schemas_010();
    AssumeRoleCommand3 = class extends import_smithy_client98.Command.classBuilder().ep(commonParams10).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint25.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "AssumeRole", {}).n("STSClient", "AssumeRoleCommand").sc(AssumeRole$3).build() {
      static {
        __name(this, "AssumeRoleCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleWithWebIdentityCommand.js
var import_middleware_endpoint26, import_smithy_client99, AssumeRoleWithWebIdentityCommand3;
var init_AssumeRoleWithWebIdentityCommand3 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleWithWebIdentityCommand.js"() {
    import_middleware_endpoint26 = __toESM(require_dist_cjs31());
    import_smithy_client99 = __toESM(require_dist_cjs34());
    init_EndpointParameters10();
    init_schemas_010();
    AssumeRoleWithWebIdentityCommand3 = class extends import_smithy_client99.Command.classBuilder().ep(commonParams10).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint26.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "AssumeRoleWithWebIdentity", {}).n("STSClient", "AssumeRoleWithWebIdentityCommand").sc(AssumeRoleWithWebIdentity$3).build() {
      static {
        __name(this, "AssumeRoleWithWebIdentityCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STS.js
var import_smithy_client100, commands10, STS3;
var init_STS3 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STS.js"() {
    import_smithy_client100 = __toESM(require_dist_cjs34());
    init_AssumeRoleCommand3();
    init_AssumeRoleWithWebIdentityCommand3();
    init_STSClient3();
    commands10 = {
      AssumeRoleCommand: AssumeRoleCommand3,
      AssumeRoleWithWebIdentityCommand: AssumeRoleWithWebIdentityCommand3
    };
    STS3 = class extends STSClient3 {
      static {
        __name(this, "STS");
      }
    };
    (0, import_smithy_client100.createAggregatedClient)(commands10, STS3);
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/index.js
var init_commands11 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/index.js"() {
    init_AssumeRoleCommand3();
    init_AssumeRoleWithWebIdentityCommand3();
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/models_0.js
var init_models_010 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultStsRoleAssumers.js
var import_region_config_resolver13, getAccountIdFromAssumedRoleUser3, resolveRegion3, getDefaultRoleAssumer5, getDefaultRoleAssumerWithWebIdentity5, isH23;
var init_defaultStsRoleAssumers3 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultStsRoleAssumers.js"() {
    init_client7();
    import_region_config_resolver13 = __toESM(require_dist_cjs48());
    init_AssumeRoleCommand3();
    init_AssumeRoleWithWebIdentityCommand3();
    getAccountIdFromAssumedRoleUser3 = /* @__PURE__ */ __name((assumedRoleUser) => {
      if (typeof assumedRoleUser?.Arn === "string") {
        const arnComponents = assumedRoleUser.Arn.split(":");
        if (arnComponents.length > 4 && arnComponents[4] !== "") {
          return arnComponents[4];
        }
      }
      return void 0;
    }, "getAccountIdFromAssumedRoleUser");
    resolveRegion3 = /* @__PURE__ */ __name(async (_region, _parentRegion, credentialProviderLogger, loaderConfig = {}) => {
      const region = typeof _region === "function" ? await _region() : _region;
      const parentRegion = typeof _parentRegion === "function" ? await _parentRegion() : _parentRegion;
      let stsDefaultRegion = "";
      const resolvedRegion = region ?? parentRegion ?? (stsDefaultRegion = await (0, import_region_config_resolver13.stsRegionDefaultResolver)(loaderConfig)());
      credentialProviderLogger?.debug?.("@aws-sdk/client-sts::resolveRegion", "accepting first of:", `${region} (credential provider clientConfig)`, `${parentRegion} (contextual client)`, `${stsDefaultRegion} (STS default: AWS_REGION, profile region, or us-east-1)`);
      return resolvedRegion;
    }, "resolveRegion");
    getDefaultRoleAssumer5 = /* @__PURE__ */ __name((stsOptions, STSClient12) => {
      let stsClient;
      let closureSourceCreds;
      return async (sourceCreds, params) => {
        closureSourceCreds = sourceCreds;
        if (!stsClient) {
          const { logger: logger5 = stsOptions?.parentClientConfig?.logger, profile = stsOptions?.parentClientConfig?.profile, region, requestHandler = stsOptions?.parentClientConfig?.requestHandler, credentialProviderLogger, userAgentAppId = stsOptions?.parentClientConfig?.userAgentAppId } = stsOptions;
          const resolvedRegion = await resolveRegion3(region, stsOptions?.parentClientConfig?.region, credentialProviderLogger, {
            logger: logger5,
            profile
          });
          const isCompatibleRequestHandler = !isH23(requestHandler);
          stsClient = new STSClient12({
            ...stsOptions,
            userAgentAppId,
            profile,
            credentialDefaultProvider: /* @__PURE__ */ __name(() => async () => closureSourceCreds, "credentialDefaultProvider"),
            region: resolvedRegion,
            requestHandler: isCompatibleRequestHandler ? requestHandler : void 0,
            logger: logger5
          });
        }
        const { Credentials, AssumedRoleUser } = await stsClient.send(new AssumeRoleCommand3(params));
        if (!Credentials || !Credentials.AccessKeyId || !Credentials.SecretAccessKey) {
          throw new Error(`Invalid response from STS.assumeRole call with role ${params.RoleArn}`);
        }
        const accountId = getAccountIdFromAssumedRoleUser3(AssumedRoleUser);
        const credentials = {
          accessKeyId: Credentials.AccessKeyId,
          secretAccessKey: Credentials.SecretAccessKey,
          sessionToken: Credentials.SessionToken,
          expiration: Credentials.Expiration,
          ...Credentials.CredentialScope && { credentialScope: Credentials.CredentialScope },
          ...accountId && { accountId }
        };
        setCredentialFeature6(credentials, "CREDENTIALS_STS_ASSUME_ROLE", "i");
        return credentials;
      };
    }, "getDefaultRoleAssumer");
    getDefaultRoleAssumerWithWebIdentity5 = /* @__PURE__ */ __name((stsOptions, STSClient12) => {
      let stsClient;
      return async (params) => {
        if (!stsClient) {
          const { logger: logger5 = stsOptions?.parentClientConfig?.logger, profile = stsOptions?.parentClientConfig?.profile, region, requestHandler = stsOptions?.parentClientConfig?.requestHandler, credentialProviderLogger, userAgentAppId = stsOptions?.parentClientConfig?.userAgentAppId } = stsOptions;
          const resolvedRegion = await resolveRegion3(region, stsOptions?.parentClientConfig?.region, credentialProviderLogger, {
            logger: logger5,
            profile
          });
          const isCompatibleRequestHandler = !isH23(requestHandler);
          stsClient = new STSClient12({
            ...stsOptions,
            userAgentAppId,
            profile,
            region: resolvedRegion,
            requestHandler: isCompatibleRequestHandler ? requestHandler : void 0,
            logger: logger5
          });
        }
        const { Credentials, AssumedRoleUser } = await stsClient.send(new AssumeRoleWithWebIdentityCommand3(params));
        if (!Credentials || !Credentials.AccessKeyId || !Credentials.SecretAccessKey) {
          throw new Error(`Invalid response from STS.assumeRoleWithWebIdentity call with role ${params.RoleArn}`);
        }
        const accountId = getAccountIdFromAssumedRoleUser3(AssumedRoleUser);
        const credentials = {
          accessKeyId: Credentials.AccessKeyId,
          secretAccessKey: Credentials.SecretAccessKey,
          sessionToken: Credentials.SessionToken,
          expiration: Credentials.Expiration,
          ...Credentials.CredentialScope && { credentialScope: Credentials.CredentialScope },
          ...accountId && { accountId }
        };
        if (accountId) {
          setCredentialFeature6(credentials, "RESOLVED_ACCOUNT_ID", "T");
        }
        setCredentialFeature6(credentials, "CREDENTIALS_STS_ASSUME_ROLE_WEB_ID", "k");
        return credentials;
      };
    }, "getDefaultRoleAssumerWithWebIdentity");
    isH23 = /* @__PURE__ */ __name((requestHandler) => {
      return requestHandler?.metadata?.handlerProtocol === "h2";
    }, "isH2");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultRoleAssumers.js
var getCustomizableStsClientCtor3, getDefaultRoleAssumer6, getDefaultRoleAssumerWithWebIdentity6, decorateDefaultCredentialProvider3;
var init_defaultRoleAssumers3 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultRoleAssumers.js"() {
    init_defaultStsRoleAssumers3();
    init_STSClient3();
    getCustomizableStsClientCtor3 = /* @__PURE__ */ __name((baseCtor, customizations) => {
      if (!customizations)
        return baseCtor;
      else
        return class CustomizableSTSClient extends baseCtor {
          static {
            __name(this, "CustomizableSTSClient");
          }
          constructor(config2) {
            super(config2);
            for (const customization of customizations) {
              this.middlewareStack.use(customization);
            }
          }
        };
    }, "getCustomizableStsClientCtor");
    getDefaultRoleAssumer6 = /* @__PURE__ */ __name((stsOptions = {}, stsPlugins) => getDefaultRoleAssumer5(stsOptions, getCustomizableStsClientCtor3(STSClient3, stsPlugins)), "getDefaultRoleAssumer");
    getDefaultRoleAssumerWithWebIdentity6 = /* @__PURE__ */ __name((stsOptions = {}, stsPlugins) => getDefaultRoleAssumerWithWebIdentity5(stsOptions, getCustomizableStsClientCtor3(STSClient3, stsPlugins)), "getDefaultRoleAssumerWithWebIdentity");
    decorateDefaultCredentialProvider3 = /* @__PURE__ */ __name((provider) => (input) => provider({
      roleAssumer: getDefaultRoleAssumer6(input),
      roleAssumerWithWebIdentity: getDefaultRoleAssumerWithWebIdentity6(input),
      ...input
    }), "decorateDefaultCredentialProvider");
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/index.js
var sts_exports3 = {};
__export(sts_exports3, {
  AssumeRole$: () => AssumeRole$3,
  AssumeRoleCommand: () => AssumeRoleCommand3,
  AssumeRoleRequest$: () => AssumeRoleRequest$3,
  AssumeRoleResponse$: () => AssumeRoleResponse$3,
  AssumeRoleWithWebIdentity$: () => AssumeRoleWithWebIdentity$3,
  AssumeRoleWithWebIdentityCommand: () => AssumeRoleWithWebIdentityCommand3,
  AssumeRoleWithWebIdentityRequest$: () => AssumeRoleWithWebIdentityRequest$3,
  AssumeRoleWithWebIdentityResponse$: () => AssumeRoleWithWebIdentityResponse$3,
  AssumedRoleUser$: () => AssumedRoleUser$3,
  Credentials$: () => Credentials$3,
  ExpiredTokenException: () => ExpiredTokenException4,
  ExpiredTokenException$: () => ExpiredTokenException$4,
  IDPCommunicationErrorException: () => IDPCommunicationErrorException3,
  IDPCommunicationErrorException$: () => IDPCommunicationErrorException$3,
  IDPRejectedClaimException: () => IDPRejectedClaimException3,
  IDPRejectedClaimException$: () => IDPRejectedClaimException$3,
  InvalidIdentityTokenException: () => InvalidIdentityTokenException3,
  InvalidIdentityTokenException$: () => InvalidIdentityTokenException$3,
  MalformedPolicyDocumentException: () => MalformedPolicyDocumentException3,
  MalformedPolicyDocumentException$: () => MalformedPolicyDocumentException$3,
  PackedPolicyTooLargeException: () => PackedPolicyTooLargeException3,
  PackedPolicyTooLargeException$: () => PackedPolicyTooLargeException$3,
  PolicyDescriptorType$: () => PolicyDescriptorType$3,
  ProvidedContext$: () => ProvidedContext$3,
  RegionDisabledException: () => RegionDisabledException3,
  RegionDisabledException$: () => RegionDisabledException$3,
  STS: () => STS3,
  STSClient: () => STSClient3,
  STSServiceException: () => STSServiceException3,
  STSServiceException$: () => STSServiceException$3,
  Tag$: () => Tag$3,
  __Client: () => import_smithy_client97.Client,
  decorateDefaultCredentialProvider: () => decorateDefaultCredentialProvider3,
  errorTypeRegistries: () => errorTypeRegistries10,
  getDefaultRoleAssumer: () => getDefaultRoleAssumer6,
  getDefaultRoleAssumerWithWebIdentity: () => getDefaultRoleAssumerWithWebIdentity6
});
var init_sts3 = __esm({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/index.js"() {
    init_STSClient3();
    init_STS3();
    init_commands11();
    init_schemas_010();
    init_errors10();
    init_models_010();
    init_defaultRoleAssumers3();
    init_STSServiceException3();
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-process/dist-cjs/index.js
var require_dist_cjs99 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-process/dist-cjs/index.js"(exports2) {
    "use strict";
    var sharedIniFileLoader = require_dist_cjs28();
    var propertyProvider = require_dist_cjs27();
    var node_child_process = require("node:child_process");
    var node_util = require("node:util");
    var client = (init_client7(), __toCommonJS(client_exports6));
    var getValidatedProcessCredentials = /* @__PURE__ */ __name((profileName, data3, profiles) => {
      if (data3.Version !== 1) {
        throw Error(`Profile ${profileName} credential_process did not return Version 1.`);
      }
      if (data3.AccessKeyId === void 0 || data3.SecretAccessKey === void 0) {
        throw Error(`Profile ${profileName} credential_process returned invalid credentials.`);
      }
      if (data3.Expiration) {
        const currentTime = /* @__PURE__ */ new Date();
        const expireTime = new Date(data3.Expiration);
        if (expireTime < currentTime) {
          throw Error(`Profile ${profileName} credential_process returned expired credentials.`);
        }
      }
      let accountId = data3.AccountId;
      if (!accountId && profiles?.[profileName]?.aws_account_id) {
        accountId = profiles[profileName].aws_account_id;
      }
      const credentials = {
        accessKeyId: data3.AccessKeyId,
        secretAccessKey: data3.SecretAccessKey,
        ...data3.SessionToken && { sessionToken: data3.SessionToken },
        ...data3.Expiration && { expiration: new Date(data3.Expiration) },
        ...data3.CredentialScope && { credentialScope: data3.CredentialScope },
        ...accountId && { accountId }
      };
      client.setCredentialFeature(credentials, "CREDENTIALS_PROCESS", "w");
      return credentials;
    }, "getValidatedProcessCredentials");
    var resolveProcessCredentials = /* @__PURE__ */ __name(async (profileName, profiles, logger5) => {
      const profile = profiles[profileName];
      if (profiles[profileName]) {
        const credentialProcess = profile["credential_process"];
        if (credentialProcess !== void 0) {
          const execPromise = node_util.promisify(sharedIniFileLoader.externalDataInterceptor?.getTokenRecord?.().exec ?? node_child_process.exec);
          try {
            const { stdout } = await execPromise(credentialProcess);
            let data3;
            try {
              data3 = JSON.parse(stdout.trim());
            } catch {
              throw Error(`Profile ${profileName} credential_process returned invalid JSON.`);
            }
            return getValidatedProcessCredentials(profileName, data3, profiles);
          } catch (error4) {
            throw new propertyProvider.CredentialsProviderError(error4.message, { logger: logger5 });
          }
        } else {
          throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} did not contain credential_process.`, { logger: logger5 });
        }
      } else {
        throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} could not be found in shared credentials file.`, {
          logger: logger5
        });
      }
    }, "resolveProcessCredentials");
    var fromProcess = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/credential-provider-process - fromProcess");
      const profiles = await sharedIniFileLoader.parseKnownFiles(init);
      return resolveProcessCredentials(sharedIniFileLoader.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      }), profiles, init.logger);
    }, "fromProcess");
    exports2.fromProcess = fromProcess;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromWebToken.js
var require_fromWebToken3 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromWebToken.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __setModuleDefault2 = exports2 && exports2.__setModuleDefault || (Object.create ? (function(o10, v) {
      Object.defineProperty(o10, "default", { enumerable: true, value: v });
    }) : function(o10, v) {
      o10["default"] = v;
    });
    var __importStar2 = exports2 && exports2.__importStar || /* @__PURE__ */ (function() {
      var ownKeys2 = /* @__PURE__ */ __name(function(o10) {
        ownKeys2 = Object.getOwnPropertyNames || function(o11) {
          var ar = [];
          for (var k32 in o11) if (Object.prototype.hasOwnProperty.call(o11, k32)) ar[ar.length] = k32;
          return ar;
        };
        return ownKeys2(o10);
      }, "ownKeys");
      return function(mod) {
        if (mod && mod.__esModule) return mod;
        var result2 = {};
        if (mod != null) {
          for (var k32 = ownKeys2(mod), i32 = 0; i32 < k32.length; i32++) if (k32[i32] !== "default") __createBinding3(result2, mod, k32[i32]);
        }
        __setModuleDefault2(result2, mod);
        return result2;
      };
    })();
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromWebToken = void 0;
    var fromWebToken = /* @__PURE__ */ __name((init) => async (awsIdentityProperties) => {
      init.logger?.debug("@aws-sdk/credential-provider-web-identity - fromWebToken");
      const { roleArn, roleSessionName, webIdentityToken, providerId, policyArns, policy, durationSeconds } = init;
      let { roleAssumerWithWebIdentity } = init;
      if (!roleAssumerWithWebIdentity) {
        const { getDefaultRoleAssumerWithWebIdentity: getDefaultRoleAssumerWithWebIdentity19 } = await Promise.resolve().then(() => __importStar2((init_sts3(), __toCommonJS(sts_exports3))));
        roleAssumerWithWebIdentity = getDefaultRoleAssumerWithWebIdentity19({
          ...init.clientConfig,
          credentialProviderLogger: init.logger,
          parentClientConfig: {
            ...awsIdentityProperties?.callerClientConfig,
            ...init.parentClientConfig
          }
        }, init.clientPlugins);
      }
      return roleAssumerWithWebIdentity({
        RoleArn: roleArn,
        RoleSessionName: roleSessionName ?? `aws-sdk-js-session-${Date.now()}`,
        WebIdentityToken: webIdentityToken,
        ProviderId: providerId,
        PolicyArns: policyArns,
        Policy: policy,
        DurationSeconds: durationSeconds
      });
    }, "fromWebToken");
    exports2.fromWebToken = fromWebToken;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromTokenFile.js
var require_fromTokenFile3 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromTokenFile.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromTokenFile = void 0;
    var client_1 = (init_client7(), __toCommonJS(client_exports6));
    var property_provider_1 = require_dist_cjs27();
    var shared_ini_file_loader_1 = require_dist_cjs28();
    var node_fs_1 = require("node:fs");
    var fromWebToken_1 = require_fromWebToken3();
    var ENV_TOKEN_FILE = "AWS_WEB_IDENTITY_TOKEN_FILE";
    var ENV_ROLE_ARN = "AWS_ROLE_ARN";
    var ENV_ROLE_SESSION_NAME = "AWS_ROLE_SESSION_NAME";
    var fromTokenFile = /* @__PURE__ */ __name((init = {}) => async (awsIdentityProperties) => {
      init.logger?.debug("@aws-sdk/credential-provider-web-identity - fromTokenFile");
      const webIdentityTokenFile = init?.webIdentityTokenFile ?? process.env[ENV_TOKEN_FILE];
      const roleArn = init?.roleArn ?? process.env[ENV_ROLE_ARN];
      const roleSessionName = init?.roleSessionName ?? process.env[ENV_ROLE_SESSION_NAME];
      if (!webIdentityTokenFile || !roleArn) {
        throw new property_provider_1.CredentialsProviderError("Web identity configuration not specified", {
          logger: init.logger
        });
      }
      const credentials = await (0, fromWebToken_1.fromWebToken)({
        ...init,
        webIdentityToken: shared_ini_file_loader_1.externalDataInterceptor?.getTokenRecord?.()[webIdentityTokenFile] ?? (0, node_fs_1.readFileSync)(webIdentityTokenFile, { encoding: "ascii" }),
        roleArn,
        roleSessionName
      })(awsIdentityProperties);
      if (webIdentityTokenFile === process.env[ENV_TOKEN_FILE]) {
        (0, client_1.setCredentialFeature)(credentials, "CREDENTIALS_ENV_VARS_STS_WEB_ID_TOKEN", "h");
      }
      return credentials;
    }, "fromTokenFile");
    exports2.fromTokenFile = fromTokenFile;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/index.js
var require_dist_cjs100 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/index.js"(exports2) {
    "use strict";
    var fromTokenFile = require_fromTokenFile3();
    var fromWebToken = require_fromWebToken3();
    Object.prototype.hasOwnProperty.call(fromTokenFile, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: fromTokenFile["__proto__"]
    });
    Object.keys(fromTokenFile).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = fromTokenFile[k32];
    });
    Object.prototype.hasOwnProperty.call(fromWebToken, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: fromWebToken["__proto__"]
    });
    Object.keys(fromWebToken).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = fromWebToken[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-ini/dist-cjs/index.js
var require_dist_cjs101 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-ini/dist-cjs/index.js"(exports2) {
    "use strict";
    var sharedIniFileLoader = require_dist_cjs28();
    var propertyProvider = require_dist_cjs27();
    var client = (init_client7(), __toCommonJS(client_exports6));
    var credentialProviderLogin = require_dist_cjs98();
    var resolveCredentialSource = /* @__PURE__ */ __name((credentialSource, profileName, logger5) => {
      const sourceProvidersMap = {
        EcsContainer: /* @__PURE__ */ __name(async (options) => {
          const { fromHttp } = await Promise.resolve().then(() => __toESM(require_dist_cjs95()));
          const { fromContainerMetadata } = await Promise.resolve().then(() => __toESM(require_dist_cjs38()));
          logger5?.debug("@aws-sdk/credential-provider-ini - credential_source is EcsContainer");
          return async () => propertyProvider.chain(fromHttp(options ?? {}), fromContainerMetadata(options))().then(setNamedProvider);
        }, "EcsContainer"),
        Ec2InstanceMetadata: /* @__PURE__ */ __name(async (options) => {
          logger5?.debug("@aws-sdk/credential-provider-ini - credential_source is Ec2InstanceMetadata");
          const { fromInstanceMetadata } = await Promise.resolve().then(() => __toESM(require_dist_cjs38()));
          return async () => fromInstanceMetadata(options)().then(setNamedProvider);
        }, "Ec2InstanceMetadata"),
        Environment: /* @__PURE__ */ __name(async (options) => {
          logger5?.debug("@aws-sdk/credential-provider-ini - credential_source is Environment");
          const { fromEnv: fromEnv6 } = await Promise.resolve().then(() => __toESM(require_dist_cjs93()));
          return async () => fromEnv6(options)().then(setNamedProvider);
        }, "Environment")
      };
      if (credentialSource in sourceProvidersMap) {
        return sourceProvidersMap[credentialSource];
      } else {
        throw new propertyProvider.CredentialsProviderError(`Unsupported credential source in profile ${profileName}. Got ${credentialSource}, expected EcsContainer or Ec2InstanceMetadata or Environment.`, { logger: logger5 });
      }
    }, "resolveCredentialSource");
    var setNamedProvider = /* @__PURE__ */ __name((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_NAMED_PROVIDER", "p"), "setNamedProvider");
    var isAssumeRoleProfile = /* @__PURE__ */ __name((arg, { profile = "default", logger: logger5 } = {}) => {
      return Boolean(arg) && typeof arg === "object" && typeof arg.role_arn === "string" && ["undefined", "string"].indexOf(typeof arg.role_session_name) > -1 && ["undefined", "string"].indexOf(typeof arg.external_id) > -1 && ["undefined", "string"].indexOf(typeof arg.mfa_serial) > -1 && (isAssumeRoleWithSourceProfile(arg, { profile, logger: logger5 }) || isCredentialSourceProfile(arg, { profile, logger: logger5 }));
    }, "isAssumeRoleProfile");
    var isAssumeRoleWithSourceProfile = /* @__PURE__ */ __name((arg, { profile, logger: logger5 }) => {
      const withSourceProfile = typeof arg.source_profile === "string" && typeof arg.credential_source === "undefined";
      if (withSourceProfile) {
        logger5?.debug?.(`    ${profile} isAssumeRoleWithSourceProfile source_profile=${arg.source_profile}`);
      }
      return withSourceProfile;
    }, "isAssumeRoleWithSourceProfile");
    var isCredentialSourceProfile = /* @__PURE__ */ __name((arg, { profile, logger: logger5 }) => {
      const withProviderProfile = typeof arg.credential_source === "string" && typeof arg.source_profile === "undefined";
      if (withProviderProfile) {
        logger5?.debug?.(`    ${profile} isCredentialSourceProfile credential_source=${arg.credential_source}`);
      }
      return withProviderProfile;
    }, "isCredentialSourceProfile");
    var resolveAssumeRoleCredentials = /* @__PURE__ */ __name(async (profileName, profiles, options, callerClientConfig, visitedProfiles = {}, resolveProfileData2) => {
      options.logger?.debug("@aws-sdk/credential-provider-ini - resolveAssumeRoleCredentials (STS)");
      const profileData = profiles[profileName];
      const { source_profile, region } = profileData;
      if (!options.roleAssumer) {
        const { getDefaultRoleAssumer: getDefaultRoleAssumer19 } = await Promise.resolve().then(() => (init_sts3(), sts_exports3));
        options.roleAssumer = getDefaultRoleAssumer19({
          ...options.clientConfig,
          credentialProviderLogger: options.logger,
          parentClientConfig: {
            ...callerClientConfig,
            ...options?.parentClientConfig,
            region: region ?? options?.parentClientConfig?.region ?? callerClientConfig?.region
          }
        }, options.clientPlugins);
      }
      if (source_profile && source_profile in visitedProfiles) {
        throw new propertyProvider.CredentialsProviderError(`Detected a cycle attempting to resolve credentials for profile ${sharedIniFileLoader.getProfileName(options)}. Profiles visited: ` + Object.keys(visitedProfiles).join(", "), { logger: options.logger });
      }
      options.logger?.debug(`@aws-sdk/credential-provider-ini - finding credential resolver using ${source_profile ? `source_profile=[${source_profile}]` : `profile=[${profileName}]`}`);
      const sourceCredsProvider = source_profile ? resolveProfileData2(source_profile, profiles, options, callerClientConfig, {
        ...visitedProfiles,
        [source_profile]: true
      }, isCredentialSourceWithoutRoleArn(profiles[source_profile] ?? {})) : (await resolveCredentialSource(profileData.credential_source, profileName, options.logger)(options))();
      if (isCredentialSourceWithoutRoleArn(profileData)) {
        return sourceCredsProvider.then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SOURCE_PROFILE", "o"));
      } else {
        const params = {
          RoleArn: profileData.role_arn,
          RoleSessionName: profileData.role_session_name || `aws-sdk-js-${Date.now()}`,
          ExternalId: profileData.external_id,
          DurationSeconds: parseInt(profileData.duration_seconds || "3600", 10)
        };
        const { mfa_serial } = profileData;
        if (mfa_serial) {
          if (!options.mfaCodeProvider) {
            throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} requires multi-factor authentication, but no MFA code callback was provided.`, { logger: options.logger, tryNextLink: false });
          }
          params.SerialNumber = mfa_serial;
          params.TokenCode = await options.mfaCodeProvider(mfa_serial);
        }
        const sourceCreds = await sourceCredsProvider;
        return options.roleAssumer(sourceCreds, params).then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SOURCE_PROFILE", "o"));
      }
    }, "resolveAssumeRoleCredentials");
    var isCredentialSourceWithoutRoleArn = /* @__PURE__ */ __name((section) => {
      return !section.role_arn && !!section.credential_source;
    }, "isCredentialSourceWithoutRoleArn");
    var isLoginProfile = /* @__PURE__ */ __name((data3) => {
      return Boolean(data3 && data3.login_session);
    }, "isLoginProfile");
    var resolveLoginCredentials = /* @__PURE__ */ __name(async (profileName, options, callerClientConfig) => {
      const credentials = await credentialProviderLogin.fromLoginCredentials({
        ...options,
        profile: profileName
      })({ callerClientConfig });
      return client.setCredentialFeature(credentials, "CREDENTIALS_PROFILE_LOGIN", "AC");
    }, "resolveLoginCredentials");
    var isProcessProfile = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.credential_process === "string", "isProcessProfile");
    var resolveProcessCredentials = /* @__PURE__ */ __name(async (options, profile) => Promise.resolve().then(() => __toESM(require_dist_cjs99())).then(({ fromProcess }) => fromProcess({
      ...options,
      profile
    })().then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_PROCESS", "v"))), "resolveProcessCredentials");
    var resolveSsoCredentials = /* @__PURE__ */ __name(async (profile, profileData, options = {}, callerClientConfig) => {
      const { fromSSO } = await Promise.resolve().then(() => __toESM(require_dist_cjs97()));
      return fromSSO({
        profile,
        logger: options.logger,
        parentClientConfig: options.parentClientConfig,
        clientConfig: options.clientConfig
      })({
        callerClientConfig
      }).then((creds) => {
        if (profileData.sso_session) {
          return client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SSO", "r");
        } else {
          return client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SSO_LEGACY", "t");
        }
      });
    }, "resolveSsoCredentials");
    var isSsoProfile = /* @__PURE__ */ __name((arg) => arg && (typeof arg.sso_start_url === "string" || typeof arg.sso_account_id === "string" || typeof arg.sso_session === "string" || typeof arg.sso_region === "string" || typeof arg.sso_role_name === "string"), "isSsoProfile");
    var isStaticCredsProfile = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.aws_access_key_id === "string" && typeof arg.aws_secret_access_key === "string" && ["undefined", "string"].indexOf(typeof arg.aws_session_token) > -1 && ["undefined", "string"].indexOf(typeof arg.aws_account_id) > -1, "isStaticCredsProfile");
    var resolveStaticCredentials = /* @__PURE__ */ __name(async (profile, options) => {
      options?.logger?.debug("@aws-sdk/credential-provider-ini - resolveStaticCredentials");
      const credentials = {
        accessKeyId: profile.aws_access_key_id,
        secretAccessKey: profile.aws_secret_access_key,
        sessionToken: profile.aws_session_token,
        ...profile.aws_credential_scope && { credentialScope: profile.aws_credential_scope },
        ...profile.aws_account_id && { accountId: profile.aws_account_id }
      };
      return client.setCredentialFeature(credentials, "CREDENTIALS_PROFILE", "n");
    }, "resolveStaticCredentials");
    var isWebIdentityProfile = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.web_identity_token_file === "string" && typeof arg.role_arn === "string" && ["undefined", "string"].indexOf(typeof arg.role_session_name) > -1, "isWebIdentityProfile");
    var resolveWebIdentityCredentials = /* @__PURE__ */ __name(async (profile, options, callerClientConfig) => Promise.resolve().then(() => __toESM(require_dist_cjs100())).then(({ fromTokenFile }) => fromTokenFile({
      webIdentityTokenFile: profile.web_identity_token_file,
      roleArn: profile.role_arn,
      roleSessionName: profile.role_session_name,
      roleAssumerWithWebIdentity: options.roleAssumerWithWebIdentity,
      logger: options.logger,
      parentClientConfig: options.parentClientConfig
    })({
      callerClientConfig
    }).then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_STS_WEB_ID_TOKEN", "q"))), "resolveWebIdentityCredentials");
    var resolveProfileData = /* @__PURE__ */ __name(async (profileName, profiles, options, callerClientConfig, visitedProfiles = {}, isAssumeRoleRecursiveCall = false) => {
      const data3 = profiles[profileName];
      if (Object.keys(visitedProfiles).length > 0 && isStaticCredsProfile(data3)) {
        return resolveStaticCredentials(data3, options);
      }
      if (isAssumeRoleRecursiveCall || isAssumeRoleProfile(data3, { profile: profileName, logger: options.logger })) {
        return resolveAssumeRoleCredentials(profileName, profiles, options, callerClientConfig, visitedProfiles, resolveProfileData);
      }
      if (isStaticCredsProfile(data3)) {
        return resolveStaticCredentials(data3, options);
      }
      if (isWebIdentityProfile(data3)) {
        return resolveWebIdentityCredentials(data3, options, callerClientConfig);
      }
      if (isProcessProfile(data3)) {
        return resolveProcessCredentials(options, profileName);
      }
      if (isSsoProfile(data3)) {
        return await resolveSsoCredentials(profileName, data3, options, callerClientConfig);
      }
      if (isLoginProfile(data3)) {
        return resolveLoginCredentials(profileName, options, callerClientConfig);
      }
      throw new propertyProvider.CredentialsProviderError(`Could not resolve credentials using profile: [${profileName}] in configuration/credentials file(s).`, { logger: options.logger });
    }, "resolveProfileData");
    var fromIni2 = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/credential-provider-ini - fromIni");
      const profiles = await sharedIniFileLoader.parseKnownFiles(init);
      return resolveProfileData(sharedIniFileLoader.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      }), profiles, init, callerClientConfig);
    }, "fromIni");
    exports2.fromIni = fromIni2;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-node/dist-cjs/index.js
var require_dist_cjs102 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/node_modules/@aws-sdk/credential-provider-node/dist-cjs/index.js"(exports2) {
    "use strict";
    var credentialProviderEnv = require_dist_cjs93();
    var propertyProvider = require_dist_cjs27();
    var sharedIniFileLoader = require_dist_cjs28();
    var ENV_IMDS_DISABLED3 = "AWS_EC2_METADATA_DISABLED";
    var remoteProvider = /* @__PURE__ */ __name(async (init) => {
      const { ENV_CMDS_FULL_URI, ENV_CMDS_RELATIVE_URI, fromContainerMetadata, fromInstanceMetadata } = await Promise.resolve().then(() => __toESM(require_dist_cjs38()));
      if (process.env[ENV_CMDS_RELATIVE_URI] || process.env[ENV_CMDS_FULL_URI]) {
        init.logger?.debug("@aws-sdk/credential-provider-node - remoteProvider::fromHttp/fromContainerMetadata");
        const { fromHttp } = await Promise.resolve().then(() => __toESM(require_dist_cjs95()));
        return propertyProvider.chain(fromHttp(init), fromContainerMetadata(init));
      }
      if (process.env[ENV_IMDS_DISABLED3] && process.env[ENV_IMDS_DISABLED3] !== "false") {
        return async () => {
          throw new propertyProvider.CredentialsProviderError("EC2 Instance Metadata Service access disabled", { logger: init.logger });
        };
      }
      init.logger?.debug("@aws-sdk/credential-provider-node - remoteProvider::fromInstanceMetadata");
      return fromInstanceMetadata(init);
    }, "remoteProvider");
    function memoizeChain(providers, treatAsExpired) {
      const chain5 = internalCreateChain(providers);
      let activeLock;
      let passiveLock;
      let credentials;
      const provider = /* @__PURE__ */ __name(async (options) => {
        if (options?.forceRefresh) {
          return await chain5(options);
        }
        if (credentials?.expiration) {
          if (credentials?.expiration?.getTime() < Date.now()) {
            credentials = void 0;
          }
        }
        if (activeLock) {
          await activeLock;
        } else if (!credentials || treatAsExpired?.(credentials)) {
          if (credentials) {
            if (!passiveLock) {
              passiveLock = chain5(options).then((c32) => {
                credentials = c32;
              }).finally(() => {
                passiveLock = void 0;
              });
            }
          } else {
            activeLock = chain5(options).then((c32) => {
              credentials = c32;
            }).finally(() => {
              activeLock = void 0;
            });
            return provider(options);
          }
        }
        return credentials;
      }, "provider");
      return provider;
    }
    __name(memoizeChain, "memoizeChain");
    var internalCreateChain = /* @__PURE__ */ __name((providers) => async (awsIdentityProperties) => {
      let lastProviderError;
      for (const provider of providers) {
        try {
          return await provider(awsIdentityProperties);
        } catch (err) {
          lastProviderError = err;
          if (err?.tryNextLink) {
            continue;
          }
          throw err;
        }
      }
      throw lastProviderError;
    }, "internalCreateChain");
    var multipleCredentialSourceWarningEmitted = false;
    var defaultProvider = /* @__PURE__ */ __name((init = {}) => memoizeChain([
      async () => {
        const profile = init.profile ?? process.env[sharedIniFileLoader.ENV_PROFILE];
        if (profile) {
          const envStaticCredentialsAreSet = process.env[credentialProviderEnv.ENV_KEY] && process.env[credentialProviderEnv.ENV_SECRET];
          if (envStaticCredentialsAreSet) {
            if (!multipleCredentialSourceWarningEmitted) {
              const warnFn = init.logger?.warn && init.logger?.constructor?.name !== "NoOpLogger" ? init.logger.warn.bind(init.logger) : console.warn;
              warnFn(`@aws-sdk/credential-provider-node - defaultProvider::fromEnv WARNING:
    Multiple credential sources detected: 
    Both AWS_PROFILE and the pair AWS_ACCESS_KEY_ID/AWS_SECRET_ACCESS_KEY static credentials are set.
    This SDK will proceed with the AWS_PROFILE value.
    
    However, a future version may change this behavior to prefer the ENV static credentials.
    Please ensure that your environment only sets either the AWS_PROFILE or the
    AWS_ACCESS_KEY_ID/AWS_SECRET_ACCESS_KEY pair.
`);
              multipleCredentialSourceWarningEmitted = true;
            }
          }
          throw new propertyProvider.CredentialsProviderError("AWS_PROFILE is set, skipping fromEnv provider.", {
            logger: init.logger,
            tryNextLink: true
          });
        }
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromEnv");
        return credentialProviderEnv.fromEnv(init)();
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromSSO");
        const { ssoStartUrl, ssoAccountId, ssoRegion, ssoRoleName, ssoSession } = init;
        if (!ssoStartUrl && !ssoAccountId && !ssoRegion && !ssoRoleName && !ssoSession) {
          throw new propertyProvider.CredentialsProviderError("Skipping SSO provider in default chain (inputs do not include SSO fields).", { logger: init.logger });
        }
        const { fromSSO } = await Promise.resolve().then(() => __toESM(require_dist_cjs97()));
        return fromSSO(init)(awsIdentityProperties);
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromIni");
        const { fromIni: fromIni2 } = await Promise.resolve().then(() => __toESM(require_dist_cjs101()));
        return fromIni2(init)(awsIdentityProperties);
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromProcess");
        const { fromProcess } = await Promise.resolve().then(() => __toESM(require_dist_cjs99()));
        return fromProcess(init)(awsIdentityProperties);
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromTokenFile");
        const { fromTokenFile } = await Promise.resolve().then(() => __toESM(require_dist_cjs100()));
        return fromTokenFile(init)(awsIdentityProperties);
      },
      async () => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::remoteProvider");
        return (await remoteProvider(init))();
      },
      async () => {
        throw new propertyProvider.CredentialsProviderError("Could not load credentials from any providers", {
          tryNextLink: false,
          logger: init.logger
        });
      }
    ], credentialsTreatedAsExpired), "defaultProvider");
    var credentialsWillNeedRefresh = /* @__PURE__ */ __name((credentials) => credentials?.expiration !== void 0, "credentialsWillNeedRefresh");
    var credentialsTreatedAsExpired = /* @__PURE__ */ __name((credentials) => credentials?.expiration !== void 0 && credentials.expiration.getTime() - Date.now() < 3e5, "credentialsTreatedAsExpired");
    exports2.credentialsTreatedAsExpired = credentialsTreatedAsExpired;
    exports2.credentialsWillNeedRefresh = credentialsWillNeedRefresh;
    exports2.defaultProvider = defaultProvider;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/dist-cjs/endpoint/bdd.js
var require_bdd3 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/dist-cjs/endpoint/bdd.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.bdd = void 0;
    var util_endpoints_1 = require_dist_cjs20();
    var m20 = "ref";
    var a32 = -1;
    var b32 = true;
    var c32 = "isSet";
    var d32 = "PartitionResult";
    var e32 = "booleanEquals";
    var f32 = "getAttr";
    var g32 = "stringEquals";
    var h32 = { [m20]: "Endpoint" };
    var i32 = { [m20]: d32 };
    var j32 = { "fn": f32, "argv": [i32, "name"] };
    var k32 = {};
    var l20 = [{ [m20]: "Region" }];
    var _data32 = {
      conditions: [
        [c32, [h32]],
        [c32, l20],
        ["aws.partition", l20, d32],
        [e32, [{ [m20]: "UseFIPS" }, b32]],
        [e32, [{ [m20]: "UseDualStack" }, b32]],
        [e32, [{ fn: f32, argv: [i32, "supportsDualStack"] }, b32]],
        [e32, [{ fn: f32, argv: [i32, "supportsFIPS"] }, b32]],
        [g32, [j32, "aws"]],
        [g32, [j32, "aws-cn"]],
        [g32, [j32, "aws-us-gov"]]
      ],
      results: [
        [a32],
        [a32, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a32, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [h32, k32],
        ["https://secretsmanager-fips.{Region}.amazonaws.com", k32],
        ["https://secretsmanager-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", k32],
        [a32, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://secretsmanager-fips.{Region}.{PartitionResult#dnsSuffix}", k32],
        [a32, "FIPS is enabled but this partition does not support FIPS"],
        ["https://secretsmanager.{Region}.amazonaws.com", k32],
        ["https://secretsmanager.{Region}.amazonaws.com.cn", k32],
        ["https://secretsmanager.{Region}.{PartitionResult#dualStackDnsSuffix}", k32],
        [a32, "DualStack is enabled but this partition does not support DualStack"],
        ["https://secretsmanager.{Region}.{PartitionResult#dnsSuffix}", k32],
        [a32, "Invalid Configuration: Missing Region"]
      ]
    };
    var root32 = 2;
    var r32 = 1e8;
    var nodes32 = new Int32Array([
      -1,
      1,
      -1,
      0,
      17,
      3,
      1,
      4,
      r32 + 14,
      2,
      5,
      r32 + 14,
      3,
      11,
      6,
      4,
      7,
      r32 + 13,
      5,
      8,
      r32 + 12,
      7,
      r32 + 9,
      9,
      8,
      r32 + 10,
      10,
      9,
      r32 + 9,
      r32 + 11,
      4,
      13,
      12,
      6,
      r32 + 7,
      r32 + 8,
      5,
      14,
      r32 + 6,
      6,
      15,
      r32 + 6,
      7,
      r32 + 4,
      16,
      9,
      r32 + 4,
      r32 + 5,
      3,
      r32 + 1,
      18,
      4,
      r32 + 2,
      r32 + 3
    ]);
    exports2.bdd = util_endpoints_1.BinaryDecisionDiagram.from(nodes32, root32, _data32.conditions, _data32.results);
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/dist-cjs/endpoint/endpointResolver.js
var require_endpointResolver3 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/dist-cjs/endpoint/endpointResolver.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.defaultEndpointResolver = void 0;
    var util_endpoints_1 = require_dist_cjs21();
    var util_endpoints_2 = require_dist_cjs20();
    var bdd_1 = require_bdd3();
    var cache32 = new util_endpoints_2.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    var defaultEndpointResolver32 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache32.get(endpointParams, () => (0, util_endpoints_2.decideEndpoint)(bdd_1.bdd, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    exports2.defaultEndpointResolver = defaultEndpointResolver32;
    util_endpoints_2.customEndpointFunctions.aws = util_endpoints_1.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/dist-cjs/models/SecretsManagerServiceException.js
var require_SecretsManagerServiceException = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/dist-cjs/models/SecretsManagerServiceException.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.SecretsManagerServiceException = exports2.__ServiceException = void 0;
    var smithy_client_1 = require_dist_cjs34();
    Object.defineProperty(exports2, "__ServiceException", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return smithy_client_1.ServiceException;
    }, "get") });
    var SecretsManagerServiceException = class _SecretsManagerServiceException extends smithy_client_1.ServiceException {
      static {
        __name(this, "SecretsManagerServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _SecretsManagerServiceException.prototype);
      }
    };
    exports2.SecretsManagerServiceException = SecretsManagerServiceException;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/dist-cjs/models/errors.js
var require_errors3 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/dist-cjs/models/errors.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.PublicPolicyException = exports2.ResourceExistsException = exports2.PreconditionNotMetException = exports2.MalformedPolicyDocumentException = exports2.LimitExceededException = exports2.EncryptionFailure = exports2.ResourceNotFoundException = exports2.InvalidRequestException = exports2.InvalidParameterException = exports2.InvalidNextTokenException = exports2.InternalServiceError = exports2.DecryptionFailure = void 0;
    var SecretsManagerServiceException_1 = require_SecretsManagerServiceException();
    var DecryptionFailure = class _DecryptionFailure extends SecretsManagerServiceException_1.SecretsManagerServiceException {
      static {
        __name(this, "DecryptionFailure");
      }
      name = "DecryptionFailure";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "DecryptionFailure",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DecryptionFailure.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.DecryptionFailure = DecryptionFailure;
    var InternalServiceError = class _InternalServiceError extends SecretsManagerServiceException_1.SecretsManagerServiceException {
      static {
        __name(this, "InternalServiceError");
      }
      name = "InternalServiceError";
      $fault = "server";
      Message;
      constructor(opts) {
        super({
          name: "InternalServiceError",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _InternalServiceError.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InternalServiceError = InternalServiceError;
    var InvalidNextTokenException = class _InvalidNextTokenException extends SecretsManagerServiceException_1.SecretsManagerServiceException {
      static {
        __name(this, "InvalidNextTokenException");
      }
      name = "InvalidNextTokenException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidNextTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidNextTokenException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidNextTokenException = InvalidNextTokenException;
    var InvalidParameterException2 = class _InvalidParameterException extends SecretsManagerServiceException_1.SecretsManagerServiceException {
      static {
        __name(this, "InvalidParameterException");
      }
      name = "InvalidParameterException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidParameterException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidParameterException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidParameterException = InvalidParameterException2;
    var InvalidRequestException13 = class _InvalidRequestException extends SecretsManagerServiceException_1.SecretsManagerServiceException {
      static {
        __name(this, "InvalidRequestException");
      }
      name = "InvalidRequestException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidRequestException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidRequestException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidRequestException = InvalidRequestException13;
    var ResourceNotFoundException12 = class _ResourceNotFoundException extends SecretsManagerServiceException_1.SecretsManagerServiceException {
      static {
        __name(this, "ResourceNotFoundException");
      }
      name = "ResourceNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "ResourceNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ResourceNotFoundException = ResourceNotFoundException12;
    var EncryptionFailure = class _EncryptionFailure extends SecretsManagerServiceException_1.SecretsManagerServiceException {
      static {
        __name(this, "EncryptionFailure");
      }
      name = "EncryptionFailure";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "EncryptionFailure",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _EncryptionFailure.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.EncryptionFailure = EncryptionFailure;
    var LimitExceededException2 = class _LimitExceededException extends SecretsManagerServiceException_1.SecretsManagerServiceException {
      static {
        __name(this, "LimitExceededException");
      }
      name = "LimitExceededException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "LimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _LimitExceededException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.LimitExceededException = LimitExceededException2;
    var MalformedPolicyDocumentException10 = class _MalformedPolicyDocumentException extends SecretsManagerServiceException_1.SecretsManagerServiceException {
      static {
        __name(this, "MalformedPolicyDocumentException");
      }
      name = "MalformedPolicyDocumentException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "MalformedPolicyDocumentException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _MalformedPolicyDocumentException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.MalformedPolicyDocumentException = MalformedPolicyDocumentException10;
    var PreconditionNotMetException = class _PreconditionNotMetException extends SecretsManagerServiceException_1.SecretsManagerServiceException {
      static {
        __name(this, "PreconditionNotMetException");
      }
      name = "PreconditionNotMetException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "PreconditionNotMetException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _PreconditionNotMetException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.PreconditionNotMetException = PreconditionNotMetException;
    var ResourceExistsException = class _ResourceExistsException extends SecretsManagerServiceException_1.SecretsManagerServiceException {
      static {
        __name(this, "ResourceExistsException");
      }
      name = "ResourceExistsException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "ResourceExistsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceExistsException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ResourceExistsException = ResourceExistsException;
    var PublicPolicyException = class _PublicPolicyException extends SecretsManagerServiceException_1.SecretsManagerServiceException {
      static {
        __name(this, "PublicPolicyException");
      }
      name = "PublicPolicyException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "PublicPolicyException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _PublicPolicyException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.PublicPolicyException = PublicPolicyException;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/dist-cjs/schemas/schemas_0.js
var require_schemas_03 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/dist-cjs/schemas/schemas_0.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.RestoreSecretRequest$ = exports2.ReplicationStatusType$ = exports2.ReplicateSecretToRegionsResponse$ = exports2.ReplicateSecretToRegionsRequest$ = exports2.ReplicaRegionType$ = exports2.RemoveRegionsFromReplicationResponse$ = exports2.RemoveRegionsFromReplicationRequest$ = exports2.PutSecretValueResponse$ = exports2.PutSecretValueRequest$ = exports2.PutResourcePolicyResponse$ = exports2.PutResourcePolicyRequest$ = exports2.ListSecretVersionIdsResponse$ = exports2.ListSecretVersionIdsRequest$ = exports2.ListSecretsResponse$ = exports2.ListSecretsRequest$ = exports2.GetSecretValueResponse$ = exports2.GetSecretValueRequest$ = exports2.GetResourcePolicyResponse$ = exports2.GetResourcePolicyRequest$ = exports2.GetRandomPasswordResponse$ = exports2.GetRandomPasswordRequest$ = exports2.Filter$ = exports2.ExternalSecretRotationMetadataItem$ = exports2.DescribeSecretResponse$ = exports2.DescribeSecretRequest$ = exports2.DeleteSecretResponse$ = exports2.DeleteSecretRequest$ = exports2.DeleteResourcePolicyResponse$ = exports2.DeleteResourcePolicyRequest$ = exports2.CreateSecretResponse$ = exports2.CreateSecretRequest$ = exports2.CancelRotateSecretResponse$ = exports2.CancelRotateSecretRequest$ = exports2.BatchGetSecretValueResponse$ = exports2.BatchGetSecretValueRequest$ = exports2.APIErrorType$ = exports2.errorTypeRegistries = exports2.ResourceNotFoundException$ = exports2.ResourceExistsException$ = exports2.PublicPolicyException$ = exports2.PreconditionNotMetException$ = exports2.MalformedPolicyDocumentException$ = exports2.LimitExceededException$ = exports2.InvalidRequestException$ = exports2.InvalidParameterException$ = exports2.InvalidNextTokenException$ = exports2.InternalServiceError$ = exports2.EncryptionFailure$ = exports2.DecryptionFailure$ = exports2.SecretsManagerServiceException$ = void 0;
    exports2.ValidateResourcePolicy$ = exports2.UpdateSecretVersionStage$ = exports2.UpdateSecret$ = exports2.UntagResource$ = exports2.TagResource$ = exports2.StopReplicationToReplica$ = exports2.RotateSecret$ = exports2.RestoreSecret$ = exports2.ReplicateSecretToRegions$ = exports2.RemoveRegionsFromReplication$ = exports2.PutSecretValue$ = exports2.PutResourcePolicy$ = exports2.ListSecretVersionIds$ = exports2.ListSecrets$ = exports2.GetSecretValue$ = exports2.GetResourcePolicy$ = exports2.GetRandomPassword$ = exports2.DescribeSecret$ = exports2.DeleteSecret$ = exports2.DeleteResourcePolicy$ = exports2.CreateSecret$ = exports2.CancelRotateSecret$ = exports2.BatchGetSecretValue$ = exports2.ValidationErrorsEntry$ = exports2.ValidateResourcePolicyResponse$ = exports2.ValidateResourcePolicyRequest$ = exports2.UpdateSecretVersionStageResponse$ = exports2.UpdateSecretVersionStageRequest$ = exports2.UpdateSecretResponse$ = exports2.UpdateSecretRequest$ = exports2.UntagResourceRequest$ = exports2.TagResourceRequest$ = exports2.Tag$ = exports2.StopReplicationToReplicaResponse$ = exports2.StopReplicationToReplicaRequest$ = exports2.SecretVersionsListEntry$ = exports2.SecretValueEntry$ = exports2.SecretListEntry$ = exports2.RotationRulesType$ = exports2.RotateSecretResponse$ = exports2.RotateSecretRequest$ = exports2.RestoreSecretResponse$ = void 0;
    var _AAD = "AutomaticallyAfterDays";
    var _APIELT = "APIErrorListType";
    var _APIET = "APIErrorType";
    var _ARN = "ARN";
    var _ARR10 = "AddReplicaRegions";
    var _ARRLT = "AddReplicaRegionListType";
    var _BGSV = "BatchGetSecretValue";
    var _BGSVR = "BatchGetSecretValueRequest";
    var _BGSVRa = "BatchGetSecretValueResponse";
    var _BPP = "BlockPublicPolicy";
    var _CD = "CreatedDate";
    var _CN = "CheckName";
    var _CRS = "CancelRotateSecret";
    var _CRSR = "CancelRotateSecretRequest";
    var _CRSRa = "CancelRotateSecretResponse";
    var _CRT = "ClientRequestToken";
    var _CS4 = "CreateSecret";
    var _CSR = "CreateSecretRequest";
    var _CSRr = "CreateSecretResponse";
    var _D = "Description";
    var _DD = "DeletionDate";
    var _DDe = "DeletedDate";
    var _DF = "DecryptionFailure";
    var _DRP = "DeleteResourcePolicy";
    var _DRPR = "DeleteResourcePolicyRequest";
    var _DRPRe = "DeleteResourcePolicyResponse";
    var _DS10 = "DeleteSecret";
    var _DSR = "DeleteSecretRequest";
    var _DSRe = "DeleteSecretResponse";
    var _DSRes = "DescribeSecretRequest";
    var _DSResc = "DescribeSecretResponse";
    var _DSe = "DescribeSecret";
    var _Du = "Duration";
    var _E11 = "Errors";
    var _EC = "ErrorCode";
    var _ECx = "ExcludeCharacters";
    var _EF = "EncryptionFailure";
    var _EL = "ExcludeLowercase";
    var _EM = "ErrorMessage";
    var _EN = "ExcludeNumbers";
    var _EP = "ExcludePunctuation";
    var _ESRM = "ExternalSecretRotationMetadata";
    var _ESRMI = "ExternalSecretRotationMetadataItem";
    var _ESRMT = "ExternalSecretRotationMetadataType";
    var _ESRRA = "ExternalSecretRotationRoleArn";
    var _EU = "ExcludeUppercase";
    var _F = "Filters";
    var _FDWR = "ForceDeleteWithoutRecovery";
    var _FLT = "FiltersListType";
    var _FORS = "ForceOverwriteReplicaSecret";
    var _Fi = "Filter";
    var _GRP = "GetRandomPassword";
    var _GRPR = "GetRandomPasswordRequest";
    var _GRPRe = "GetRandomPasswordResponse";
    var _GRPRet = "GetResourcePolicyRequest";
    var _GRPRete = "GetResourcePolicyResponse";
    var _GRPe = "GetResourcePolicy";
    var _GSV = "GetSecretValue";
    var _GSVR = "GetSecretValueRequest";
    var _GSVRe = "GetSecretValueResponse";
    var _ID = "IncludeDeprecated";
    var _INTE = "InvalidNextTokenException";
    var _IPD = "IncludePlannedDeletion";
    var _IPE2 = "InvalidParameterException";
    var _IRE13 = "InvalidRequestException";
    var _IS = "IncludeSpace";
    var _ISE13 = "InternalServiceError";
    var _K10 = "Key";
    var _KKI = "KmsKeyId";
    var _KKIm = "KmsKeyIds";
    var _LAD = "LastAccessedDate";
    var _LCD = "LastChangedDate";
    var _LEE2 = "LimitExceededException";
    var _LRD = "LastRotatedDate";
    var _LS = "ListSecrets";
    var _LSR = "ListSecretsRequest";
    var _LSRi = "ListSecretsResponse";
    var _LSVI = "ListSecretVersionIds";
    var _LSVIR = "ListSecretVersionIdsRequest";
    var _LSVIRi = "ListSecretVersionIdsResponse";
    var _M = "Message";
    var _MPDE10 = "MalformedPolicyDocumentException";
    var _MR = "MaxResults";
    var _MTVI = "MoveToVersionId";
    var _N = "Name";
    var _NRD = "NextRotationDate";
    var _NT = "NextToken";
    var _OS = "OwningService";
    var _PL = "PasswordLength";
    var _PNME = "PreconditionNotMetException";
    var _PPE = "PublicPolicyException";
    var _PR = "PrimaryRegion";
    var _PRP = "PutResourcePolicy";
    var _PRPR = "PutResourcePolicyRequest";
    var _PRPRu = "PutResourcePolicyResponse";
    var _PSV = "PutSecretValue";
    var _PSVR = "PutSecretValueRequest";
    var _PSVRu = "PutSecretValueResponse";
    var _PVP = "PolicyValidationPassed";
    var _R = "Region";
    var _RE = "RotationEnabled";
    var _REE = "ResourceExistsException";
    var _REIT = "RequireEachIncludedType";
    var _RFVI = "RemoveFromVersionId";
    var _RI = "RotateImmediately";
    var _RLARN = "RotationLambdaARN";
    var _RNFE11 = "ResourceNotFoundException";
    var _RP = "RandomPassword";
    var _RPT = "RandomPasswordType";
    var _RPe = "ResourcePolicy";
    var _RR = "RotationRules";
    var _RRFR = "RemoveRegionsFromReplication";
    var _RRFRR = "RemoveRegionsFromReplicationRequest";
    var _RRFRRe = "RemoveRegionsFromReplicationResponse";
    var _RRR = "RemoveReplicaRegions";
    var _RRT = "ReplicaRegionType";
    var _RRTo = "RotationRulesType";
    var _RS = "ReplicationStatus";
    var _RSLT = "ReplicationStatusListType";
    var _RSR = "RestoreSecretRequest";
    var _RSRe = "RestoreSecretResponse";
    var _RSRo = "RotateSecretRequest";
    var _RSRot = "RotateSecretResponse";
    var _RST = "ReplicationStatusType";
    var _RSTR = "ReplicateSecretToRegions";
    var _RSTRR = "ReplicateSecretToRegionsRequest";
    var _RSTRRe = "ReplicateSecretToRegionsResponse";
    var _RSe = "RestoreSecret";
    var _RSo = "RotateSecret";
    var _RT13 = "RotationToken";
    var _RTT = "RotationTokenType";
    var _RWID = "RecoveryWindowInDays";
    var _S = "Status";
    var _SB = "SecretBinary";
    var _SBT = "SecretBinaryType";
    var _SBo = "SortBy";
    var _SE = "ScheduleExpression";
    var _SI10 = "SecretId";
    var _SIL = "SecretIdList";
    var _SL = "SecretList";
    var _SLE = "SecretListEntry";
    var _SLT = "SecretListType";
    var _SM = "StatusMessage";
    var _SO = "SortOrder";
    var _SRTR = "StopReplicationToReplica";
    var _SRTRR = "StopReplicationToReplicaRequest";
    var _SRTRRt = "StopReplicationToReplicaResponse";
    var _SS = "SecretString";
    var _SST = "SecretStringType";
    var _SV = "SecretValues";
    var _SVE = "SecretValueEntry";
    var _SVLE = "SecretVersionsListEntry";
    var _SVLT = "SecretVersionsListType";
    var _SVT = "SecretValuesType";
    var _SVTS = "SecretVersionsToStages";
    var _SVTSMT = "SecretVersionsToStagesMapType";
    var _T10 = "Tags";
    var _TK = "TagKeys";
    var _TLT = "TagListType";
    var _TR = "TagResource";
    var _TRR = "TagResourceRequest";
    var _Ta10 = "Tag";
    var _Ty = "Type";
    var _UR = "UntagResource";
    var _URR = "UntagResourceRequest";
    var _US = "UpdateSecret";
    var _USR = "UpdateSecretRequest";
    var _USRp = "UpdateSecretResponse";
    var _USVS = "UpdateSecretVersionStage";
    var _USVSR = "UpdateSecretVersionStageRequest";
    var _USVSRp = "UpdateSecretVersionStageResponse";
    var _V10 = "Value";
    var _VE10 = "ValidationErrors";
    var _VEE = "ValidationErrorsEntry";
    var _VET = "ValidationErrorsType";
    var _VI = "VersionId";
    var _VITS = "VersionIdsToStages";
    var _VRP = "ValidateResourcePolicy";
    var _VRPR = "ValidateResourcePolicyRequest";
    var _VRPRa = "ValidateResourcePolicyResponse";
    var _VS = "VersionStage";
    var _VSe = "VersionStages";
    var _Va = "Values";
    var _Ve = "Versions";
    var _c32 = "client";
    var _e32 = "error";
    var _s32 = "smithy.ts.sdk.synthetic.com.amazonaws.secretsmanager";
    var _se14 = "server";
    var n032 = "com.amazonaws.secretsmanager";
    var schema_1 = (init_schema4(), __toCommonJS(schema_exports));
    var errors_1 = require_errors3();
    var SecretsManagerServiceException_1 = require_SecretsManagerServiceException();
    var _s_registry32 = schema_1.TypeRegistry.for(_s32);
    exports2.SecretsManagerServiceException$ = [-3, _s32, "SecretsManagerServiceException", 0, [], []];
    _s_registry32.registerError(exports2.SecretsManagerServiceException$, SecretsManagerServiceException_1.SecretsManagerServiceException);
    var n0_registry32 = schema_1.TypeRegistry.for(n032);
    exports2.DecryptionFailure$ = [
      -3,
      n032,
      _DF,
      { [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.DecryptionFailure$, errors_1.DecryptionFailure);
    exports2.EncryptionFailure$ = [
      -3,
      n032,
      _EF,
      { [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.EncryptionFailure$, errors_1.EncryptionFailure);
    exports2.InternalServiceError$ = [
      -3,
      n032,
      _ISE13,
      { [_e32]: _se14 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InternalServiceError$, errors_1.InternalServiceError);
    exports2.InvalidNextTokenException$ = [
      -3,
      n032,
      _INTE,
      { [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidNextTokenException$, errors_1.InvalidNextTokenException);
    exports2.InvalidParameterException$ = [
      -3,
      n032,
      _IPE2,
      { [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidParameterException$, errors_1.InvalidParameterException);
    exports2.InvalidRequestException$ = [
      -3,
      n032,
      _IRE13,
      { [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidRequestException$, errors_1.InvalidRequestException);
    exports2.LimitExceededException$ = [
      -3,
      n032,
      _LEE2,
      { [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.LimitExceededException$, errors_1.LimitExceededException);
    exports2.MalformedPolicyDocumentException$ = [
      -3,
      n032,
      _MPDE10,
      { [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.MalformedPolicyDocumentException$, errors_1.MalformedPolicyDocumentException);
    exports2.PreconditionNotMetException$ = [
      -3,
      n032,
      _PNME,
      { [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.PreconditionNotMetException$, errors_1.PreconditionNotMetException);
    exports2.PublicPolicyException$ = [
      -3,
      n032,
      _PPE,
      { [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.PublicPolicyException$, errors_1.PublicPolicyException);
    exports2.ResourceExistsException$ = [
      -3,
      n032,
      _REE,
      { [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ResourceExistsException$, errors_1.ResourceExistsException);
    exports2.ResourceNotFoundException$ = [
      -3,
      n032,
      _RNFE11,
      { [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ResourceNotFoundException$, errors_1.ResourceNotFoundException);
    exports2.errorTypeRegistries = [
      _s_registry32,
      n0_registry32
    ];
    var RandomPasswordType = [0, n032, _RPT, 8, 0];
    var RotationTokenType = [0, n032, _RTT, 8, 0];
    var SecretBinaryType = [0, n032, _SBT, 8, 21];
    var SecretStringType = [0, n032, _SST, 8, 0];
    exports2.APIErrorType$ = [
      3,
      n032,
      _APIET,
      0,
      [_SI10, _EC, _M],
      [0, 0, 0]
    ];
    exports2.BatchGetSecretValueRequest$ = [
      3,
      n032,
      _BGSVR,
      0,
      [_SIL, _F, _MR, _NT],
      [64 | 0, () => FiltersListType, 1, 0]
    ];
    exports2.BatchGetSecretValueResponse$ = [
      3,
      n032,
      _BGSVRa,
      0,
      [_SV, _NT, _E11],
      [[() => SecretValuesType, 0], 0, () => APIErrorListType]
    ];
    exports2.CancelRotateSecretRequest$ = [
      3,
      n032,
      _CRSR,
      0,
      [_SI10],
      [0],
      1
    ];
    exports2.CancelRotateSecretResponse$ = [
      3,
      n032,
      _CRSRa,
      0,
      [_ARN, _N, _VI],
      [0, 0, 0]
    ];
    exports2.CreateSecretRequest$ = [
      3,
      n032,
      _CSR,
      0,
      [_N, _CRT, _D, _KKI, _SB, _SS, _T10, _ARR10, _FORS, _Ty],
      [0, [0, 4], 0, 0, [() => SecretBinaryType, 0], [() => SecretStringType, 0], () => TagListType, () => AddReplicaRegionListType, 2, 0],
      1
    ];
    exports2.CreateSecretResponse$ = [
      3,
      n032,
      _CSRr,
      0,
      [_ARN, _N, _VI, _RS],
      [0, 0, 0, () => ReplicationStatusListType]
    ];
    exports2.DeleteResourcePolicyRequest$ = [
      3,
      n032,
      _DRPR,
      0,
      [_SI10],
      [0],
      1
    ];
    exports2.DeleteResourcePolicyResponse$ = [
      3,
      n032,
      _DRPRe,
      0,
      [_ARN, _N],
      [0, 0]
    ];
    exports2.DeleteSecretRequest$ = [
      3,
      n032,
      _DSR,
      0,
      [_SI10, _RWID, _FDWR],
      [0, 1, 2],
      1
    ];
    exports2.DeleteSecretResponse$ = [
      3,
      n032,
      _DSRe,
      0,
      [_ARN, _N, _DD],
      [0, 0, 4]
    ];
    exports2.DescribeSecretRequest$ = [
      3,
      n032,
      _DSRes,
      0,
      [_SI10],
      [0],
      1
    ];
    exports2.DescribeSecretResponse$ = [
      3,
      n032,
      _DSResc,
      0,
      [_ARN, _N, _Ty, _D, _KKI, _RE, _RLARN, _RR, _ESRM, _ESRRA, _LRD, _LCD, _LAD, _DDe, _NRD, _T10, _VITS, _OS, _CD, _PR, _RS],
      [0, 0, 0, 0, 0, 2, 0, () => exports2.RotationRulesType$, () => ExternalSecretRotationMetadataType, 0, 4, 4, 4, 4, 4, () => TagListType, [2, n032, _SVTSMT, 0, 0, 64 | 0], 0, 4, 0, () => ReplicationStatusListType]
    ];
    exports2.ExternalSecretRotationMetadataItem$ = [
      3,
      n032,
      _ESRMI,
      0,
      [_K10, _V10],
      [0, 0]
    ];
    exports2.Filter$ = [
      3,
      n032,
      _Fi,
      0,
      [_K10, _Va],
      [0, 64 | 0]
    ];
    exports2.GetRandomPasswordRequest$ = [
      3,
      n032,
      _GRPR,
      0,
      [_PL, _ECx, _EN, _EP, _EU, _EL, _IS, _REIT],
      [1, 0, 2, 2, 2, 2, 2, 2]
    ];
    exports2.GetRandomPasswordResponse$ = [
      3,
      n032,
      _GRPRe,
      0,
      [_RP],
      [[() => RandomPasswordType, 0]]
    ];
    exports2.GetResourcePolicyRequest$ = [
      3,
      n032,
      _GRPRet,
      0,
      [_SI10],
      [0],
      1
    ];
    exports2.GetResourcePolicyResponse$ = [
      3,
      n032,
      _GRPRete,
      0,
      [_ARN, _N, _RPe],
      [0, 0, 0]
    ];
    exports2.GetSecretValueRequest$ = [
      3,
      n032,
      _GSVR,
      0,
      [_SI10, _VI, _VS],
      [0, 0, 0],
      1
    ];
    exports2.GetSecretValueResponse$ = [
      3,
      n032,
      _GSVRe,
      0,
      [_ARN, _N, _VI, _SB, _SS, _VSe, _CD],
      [0, 0, 0, [() => SecretBinaryType, 0], [() => SecretStringType, 0], 64 | 0, 4]
    ];
    exports2.ListSecretsRequest$ = [
      3,
      n032,
      _LSR,
      0,
      [_IPD, _MR, _NT, _F, _SO, _SBo],
      [2, 1, 0, () => FiltersListType, 0, 0]
    ];
    exports2.ListSecretsResponse$ = [
      3,
      n032,
      _LSRi,
      0,
      [_SL, _NT],
      [() => SecretListType, 0]
    ];
    exports2.ListSecretVersionIdsRequest$ = [
      3,
      n032,
      _LSVIR,
      0,
      [_SI10, _MR, _NT, _ID],
      [0, 1, 0, 2],
      1
    ];
    exports2.ListSecretVersionIdsResponse$ = [
      3,
      n032,
      _LSVIRi,
      0,
      [_Ve, _NT, _ARN, _N],
      [() => SecretVersionsListType, 0, 0, 0]
    ];
    exports2.PutResourcePolicyRequest$ = [
      3,
      n032,
      _PRPR,
      0,
      [_SI10, _RPe, _BPP],
      [0, 0, 2],
      2
    ];
    exports2.PutResourcePolicyResponse$ = [
      3,
      n032,
      _PRPRu,
      0,
      [_ARN, _N],
      [0, 0]
    ];
    exports2.PutSecretValueRequest$ = [
      3,
      n032,
      _PSVR,
      0,
      [_SI10, _CRT, _SB, _SS, _VSe, _RT13],
      [0, [0, 4], [() => SecretBinaryType, 0], [() => SecretStringType, 0], 64 | 0, [() => RotationTokenType, 0]],
      1
    ];
    exports2.PutSecretValueResponse$ = [
      3,
      n032,
      _PSVRu,
      0,
      [_ARN, _N, _VI, _VSe],
      [0, 0, 0, 64 | 0]
    ];
    exports2.RemoveRegionsFromReplicationRequest$ = [
      3,
      n032,
      _RRFRR,
      0,
      [_SI10, _RRR],
      [0, 64 | 0],
      2
    ];
    exports2.RemoveRegionsFromReplicationResponse$ = [
      3,
      n032,
      _RRFRRe,
      0,
      [_ARN, _RS],
      [0, () => ReplicationStatusListType]
    ];
    exports2.ReplicaRegionType$ = [
      3,
      n032,
      _RRT,
      0,
      [_R, _KKI],
      [0, 0]
    ];
    exports2.ReplicateSecretToRegionsRequest$ = [
      3,
      n032,
      _RSTRR,
      0,
      [_SI10, _ARR10, _FORS],
      [0, () => AddReplicaRegionListType, 2],
      2
    ];
    exports2.ReplicateSecretToRegionsResponse$ = [
      3,
      n032,
      _RSTRRe,
      0,
      [_ARN, _RS],
      [0, () => ReplicationStatusListType]
    ];
    exports2.ReplicationStatusType$ = [
      3,
      n032,
      _RST,
      0,
      [_R, _KKI, _S, _SM, _LAD],
      [0, 0, 0, 0, 4]
    ];
    exports2.RestoreSecretRequest$ = [
      3,
      n032,
      _RSR,
      0,
      [_SI10],
      [0],
      1
    ];
    exports2.RestoreSecretResponse$ = [
      3,
      n032,
      _RSRe,
      0,
      [_ARN, _N],
      [0, 0]
    ];
    exports2.RotateSecretRequest$ = [
      3,
      n032,
      _RSRo,
      0,
      [_SI10, _CRT, _RLARN, _RR, _ESRM, _ESRRA, _RI],
      [0, [0, 4], 0, () => exports2.RotationRulesType$, () => ExternalSecretRotationMetadataType, 0, 2],
      1
    ];
    exports2.RotateSecretResponse$ = [
      3,
      n032,
      _RSRot,
      0,
      [_ARN, _N, _VI],
      [0, 0, 0]
    ];
    exports2.RotationRulesType$ = [
      3,
      n032,
      _RRTo,
      0,
      [_AAD, _Du, _SE],
      [1, 0, 0]
    ];
    exports2.SecretListEntry$ = [
      3,
      n032,
      _SLE,
      0,
      [_ARN, _N, _Ty, _D, _KKI, _RE, _RLARN, _RR, _ESRM, _ESRRA, _LRD, _LCD, _LAD, _DDe, _NRD, _T10, _SVTS, _OS, _CD, _PR],
      [0, 0, 0, 0, 0, 2, 0, () => exports2.RotationRulesType$, () => ExternalSecretRotationMetadataType, 0, 4, 4, 4, 4, 4, () => TagListType, [2, n032, _SVTSMT, 0, 0, 64 | 0], 0, 4, 0]
    ];
    exports2.SecretValueEntry$ = [
      3,
      n032,
      _SVE,
      0,
      [_ARN, _N, _VI, _SB, _SS, _VSe, _CD],
      [0, 0, 0, [() => SecretBinaryType, 0], [() => SecretStringType, 0], 64 | 0, 4]
    ];
    exports2.SecretVersionsListEntry$ = [
      3,
      n032,
      _SVLE,
      0,
      [_VI, _VSe, _LAD, _CD, _KKIm],
      [0, 64 | 0, 4, 4, 64 | 0]
    ];
    exports2.StopReplicationToReplicaRequest$ = [
      3,
      n032,
      _SRTRR,
      0,
      [_SI10],
      [0],
      1
    ];
    exports2.StopReplicationToReplicaResponse$ = [
      3,
      n032,
      _SRTRRt,
      0,
      [_ARN],
      [0]
    ];
    exports2.Tag$ = [
      3,
      n032,
      _Ta10,
      0,
      [_K10, _V10],
      [0, 0]
    ];
    exports2.TagResourceRequest$ = [
      3,
      n032,
      _TRR,
      0,
      [_SI10, _T10],
      [0, () => TagListType],
      2
    ];
    exports2.UntagResourceRequest$ = [
      3,
      n032,
      _URR,
      0,
      [_SI10, _TK],
      [0, 64 | 0],
      2
    ];
    exports2.UpdateSecretRequest$ = [
      3,
      n032,
      _USR,
      0,
      [_SI10, _CRT, _D, _KKI, _SB, _SS, _Ty],
      [0, [0, 4], 0, 0, [() => SecretBinaryType, 0], [() => SecretStringType, 0], 0],
      1
    ];
    exports2.UpdateSecretResponse$ = [
      3,
      n032,
      _USRp,
      0,
      [_ARN, _N, _VI],
      [0, 0, 0]
    ];
    exports2.UpdateSecretVersionStageRequest$ = [
      3,
      n032,
      _USVSR,
      0,
      [_SI10, _VS, _RFVI, _MTVI],
      [0, 0, 0, 0],
      2
    ];
    exports2.UpdateSecretVersionStageResponse$ = [
      3,
      n032,
      _USVSRp,
      0,
      [_ARN, _N],
      [0, 0]
    ];
    exports2.ValidateResourcePolicyRequest$ = [
      3,
      n032,
      _VRPR,
      0,
      [_RPe, _SI10],
      [0, 0],
      1
    ];
    exports2.ValidateResourcePolicyResponse$ = [
      3,
      n032,
      _VRPRa,
      0,
      [_PVP, _VE10],
      [2, () => ValidationErrorsType]
    ];
    exports2.ValidationErrorsEntry$ = [
      3,
      n032,
      _VEE,
      0,
      [_CN, _EM],
      [0, 0]
    ];
    var __Unit = "unit";
    var AddReplicaRegionListType = [
      1,
      n032,
      _ARRLT,
      0,
      () => exports2.ReplicaRegionType$
    ];
    var APIErrorListType = [
      1,
      n032,
      _APIELT,
      0,
      () => exports2.APIErrorType$
    ];
    var ExternalSecretRotationMetadataType = [
      1,
      n032,
      _ESRMT,
      0,
      () => exports2.ExternalSecretRotationMetadataItem$
    ];
    var FiltersListType = [
      1,
      n032,
      _FLT,
      0,
      () => exports2.Filter$
    ];
    var FilterValuesStringList = 64 | 0;
    var KmsKeyIdListType = 64 | 0;
    var RemoveReplicaRegionListType = 64 | 0;
    var ReplicationStatusListType = [
      1,
      n032,
      _RSLT,
      0,
      () => exports2.ReplicationStatusType$
    ];
    var SecretIdListType = 64 | 0;
    var SecretListType = [
      1,
      n032,
      _SLT,
      0,
      () => exports2.SecretListEntry$
    ];
    var SecretValuesType = [
      1,
      n032,
      _SVT,
      0,
      [
        () => exports2.SecretValueEntry$,
        0
      ]
    ];
    var SecretVersionsListType = [
      1,
      n032,
      _SVLT,
      0,
      () => exports2.SecretVersionsListEntry$
    ];
    var SecretVersionStagesType = 64 | 0;
    var TagKeyListType = 64 | 0;
    var TagListType = [
      1,
      n032,
      _TLT,
      0,
      () => exports2.Tag$
    ];
    var ValidationErrorsType = [
      1,
      n032,
      _VET,
      0,
      () => exports2.ValidationErrorsEntry$
    ];
    var SecretVersionsToStagesMapType = [
      2,
      n032,
      _SVTSMT,
      0,
      0,
      64 | 0
    ];
    exports2.BatchGetSecretValue$ = [
      9,
      n032,
      _BGSV,
      0,
      () => exports2.BatchGetSecretValueRequest$,
      () => exports2.BatchGetSecretValueResponse$
    ];
    exports2.CancelRotateSecret$ = [
      9,
      n032,
      _CRS,
      0,
      () => exports2.CancelRotateSecretRequest$,
      () => exports2.CancelRotateSecretResponse$
    ];
    exports2.CreateSecret$ = [
      9,
      n032,
      _CS4,
      0,
      () => exports2.CreateSecretRequest$,
      () => exports2.CreateSecretResponse$
    ];
    exports2.DeleteResourcePolicy$ = [
      9,
      n032,
      _DRP,
      0,
      () => exports2.DeleteResourcePolicyRequest$,
      () => exports2.DeleteResourcePolicyResponse$
    ];
    exports2.DeleteSecret$ = [
      9,
      n032,
      _DS10,
      0,
      () => exports2.DeleteSecretRequest$,
      () => exports2.DeleteSecretResponse$
    ];
    exports2.DescribeSecret$ = [
      9,
      n032,
      _DSe,
      0,
      () => exports2.DescribeSecretRequest$,
      () => exports2.DescribeSecretResponse$
    ];
    exports2.GetRandomPassword$ = [
      9,
      n032,
      _GRP,
      0,
      () => exports2.GetRandomPasswordRequest$,
      () => exports2.GetRandomPasswordResponse$
    ];
    exports2.GetResourcePolicy$ = [
      9,
      n032,
      _GRPe,
      0,
      () => exports2.GetResourcePolicyRequest$,
      () => exports2.GetResourcePolicyResponse$
    ];
    exports2.GetSecretValue$ = [
      9,
      n032,
      _GSV,
      0,
      () => exports2.GetSecretValueRequest$,
      () => exports2.GetSecretValueResponse$
    ];
    exports2.ListSecrets$ = [
      9,
      n032,
      _LS,
      0,
      () => exports2.ListSecretsRequest$,
      () => exports2.ListSecretsResponse$
    ];
    exports2.ListSecretVersionIds$ = [
      9,
      n032,
      _LSVI,
      0,
      () => exports2.ListSecretVersionIdsRequest$,
      () => exports2.ListSecretVersionIdsResponse$
    ];
    exports2.PutResourcePolicy$ = [
      9,
      n032,
      _PRP,
      0,
      () => exports2.PutResourcePolicyRequest$,
      () => exports2.PutResourcePolicyResponse$
    ];
    exports2.PutSecretValue$ = [
      9,
      n032,
      _PSV,
      0,
      () => exports2.PutSecretValueRequest$,
      () => exports2.PutSecretValueResponse$
    ];
    exports2.RemoveRegionsFromReplication$ = [
      9,
      n032,
      _RRFR,
      0,
      () => exports2.RemoveRegionsFromReplicationRequest$,
      () => exports2.RemoveRegionsFromReplicationResponse$
    ];
    exports2.ReplicateSecretToRegions$ = [
      9,
      n032,
      _RSTR,
      0,
      () => exports2.ReplicateSecretToRegionsRequest$,
      () => exports2.ReplicateSecretToRegionsResponse$
    ];
    exports2.RestoreSecret$ = [
      9,
      n032,
      _RSe,
      0,
      () => exports2.RestoreSecretRequest$,
      () => exports2.RestoreSecretResponse$
    ];
    exports2.RotateSecret$ = [
      9,
      n032,
      _RSo,
      0,
      () => exports2.RotateSecretRequest$,
      () => exports2.RotateSecretResponse$
    ];
    exports2.StopReplicationToReplica$ = [
      9,
      n032,
      _SRTR,
      0,
      () => exports2.StopReplicationToReplicaRequest$,
      () => exports2.StopReplicationToReplicaResponse$
    ];
    exports2.TagResource$ = [
      9,
      n032,
      _TR,
      0,
      () => exports2.TagResourceRequest$,
      () => __Unit
    ];
    exports2.UntagResource$ = [
      9,
      n032,
      _UR,
      0,
      () => exports2.UntagResourceRequest$,
      () => __Unit
    ];
    exports2.UpdateSecret$ = [
      9,
      n032,
      _US,
      0,
      () => exports2.UpdateSecretRequest$,
      () => exports2.UpdateSecretResponse$
    ];
    exports2.UpdateSecretVersionStage$ = [
      9,
      n032,
      _USVS,
      0,
      () => exports2.UpdateSecretVersionStageRequest$,
      () => exports2.UpdateSecretVersionStageResponse$
    ];
    exports2.ValidateResourcePolicy$ = [
      9,
      n032,
      _VRP,
      0,
      () => exports2.ValidateResourcePolicyRequest$,
      () => exports2.ValidateResourcePolicyResponse$
    ];
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/dist-cjs/runtimeConfig.shared.js
var require_runtimeConfig_shared3 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/dist-cjs/runtimeConfig.shared.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes5(), __toCommonJS(httpAuthSchemes_exports4));
    var protocols_1 = (init_protocols7(), __toCommonJS(protocols_exports4));
    var smithy_client_1 = require_dist_cjs34();
    var url_parser_1 = require_dist_cjs18();
    var util_base64_1 = require_dist_cjs10();
    var util_utf8_1 = require_dist_cjs9();
    var httpAuthSchemeProvider_1 = require_httpAuthSchemeProvider3();
    var endpointResolver_1 = require_endpointResolver3();
    var schemas_0_1 = require_schemas_03();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2017-10-17",
        base64Decoder: config2?.base64Decoder ?? util_base64_1.fromBase64,
        base64Encoder: config2?.base64Encoder ?? util_base64_1.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? endpointResolver_1.defaultEndpointResolver,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? httpAuthSchemeProvider_1.defaultSecretsManagerHttpAuthSchemeProvider,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new httpAuthSchemes_1.AwsSdkSigV4Signer()
          }
        ],
        logger: config2?.logger ?? new smithy_client_1.NoOpLogger(),
        protocol: config2?.protocol ?? protocols_1.AwsJson1_1Protocol,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.secretsmanager",
          errorTypeRegistries: schemas_0_1.errorTypeRegistries,
          version: "2017-10-17",
          serviceTarget: "secretsmanager"
        },
        serviceId: config2?.serviceId ?? "Secrets Manager",
        urlParser: config2?.urlParser ?? url_parser_1.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? util_utf8_1.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? util_utf8_1.toUtf8
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/dist-cjs/runtimeConfig.js
var require_runtimeConfig3 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/dist-cjs/runtimeConfig.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var package_json_1 = tslib_1.__importDefault(require_package3());
    var client_1 = (init_client7(), __toCommonJS(client_exports6));
    var httpAuthSchemes_1 = (init_httpAuthSchemes5(), __toCommonJS(httpAuthSchemes_exports4));
    var credential_provider_node_1 = require_dist_cjs102();
    var util_user_agent_node_1 = require_dist_cjs96();
    var config_resolver_1 = require_dist_cjs25();
    var hash_node_1 = require_dist_cjs44();
    var middleware_retry_1 = require_dist_cjs92();
    var node_config_provider_1 = require_dist_cjs29();
    var node_http_handler_1 = require_dist_cjs13();
    var smithy_client_1 = require_dist_cjs34();
    var util_body_length_node_1 = require_dist_cjs45();
    var util_defaults_mode_node_1 = require_dist_cjs46();
    var util_retry_1 = require_dist_cjs22();
    var runtimeConfig_shared_1 = require_runtimeConfig_shared3();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      (0, smithy_client_1.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, util_defaults_mode_node_1.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(smithy_client_1.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = (0, runtimeConfig_shared_1.getRuntimeConfig)(config2);
      (0, client_1.emitWarningIfUnsupportedVersion)(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, node_config_provider_1.loadConfig)(httpAuthSchemes_1.NODE_AUTH_SCHEME_PREFERENCE_OPTIONS, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? util_body_length_node_1.calculateBodyLength,
        credentialDefaultProvider: config2?.credentialDefaultProvider ?? credential_provider_node_1.defaultProvider,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, util_user_agent_node_1.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_json_1.default.version }),
        maxAttempts: config2?.maxAttempts ?? (0, node_config_provider_1.loadConfig)(middleware_retry_1.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_REGION_CONFIG_OPTIONS, { ...config_resolver_1.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: node_http_handler_1.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, node_config_provider_1.loadConfig)({
          ...middleware_retry_1.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || util_retry_1.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? hash_node_1.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? node_http_handler_1.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, node_config_provider_1.loadConfig)(util_user_agent_node_1.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-secrets-manager/dist-cjs/index.js
var require_dist_cjs103 = __commonJS({
  "../../node_modules/@aws-sdk/client-secrets-manager/dist-cjs/index.js"(exports2) {
    "use strict";
    var middlewareHostHeader = require_dist_cjs3();
    var middlewareLogger = require_dist_cjs4();
    var middlewareRecursionDetection = require_dist_cjs5();
    var middlewareUserAgent = require_dist_cjs91();
    var configResolver = require_dist_cjs25();
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var schema = (init_schema4(), __toCommonJS(schema_exports));
    var middlewareContentLength = require_dist_cjs26();
    var middlewareEndpoint = require_dist_cjs31();
    var middlewareRetry = require_dist_cjs92();
    var smithyClient = require_dist_cjs34();
    var httpAuthSchemeProvider = require_httpAuthSchemeProvider3();
    var runtimeConfig = require_runtimeConfig3();
    var regionConfigResolver = require_dist_cjs48();
    var protocolHttp = require_dist_cjs2();
    var schemas_0 = require_schemas_03();
    var errors = require_errors3();
    var SecretsManagerServiceException = require_SecretsManagerServiceException();
    var resolveClientEndpointParameters32 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "secretsmanager"
      });
    }, "resolveClientEndpointParameters");
    var commonParams32 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
    var getHttpAuthExtensionConfiguration32 = /* @__PURE__ */ __name((runtimeConfig2) => {
      const _httpAuthSchemes = runtimeConfig2.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig2.httpAuthSchemeProvider;
      let _credentials = runtimeConfig2.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider2) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider2;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    var resolveHttpAuthRuntimeConfig32 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
    var resolveRuntimeExtensions32 = /* @__PURE__ */ __name((runtimeConfig2, extensions) => {
      const extensionConfiguration = Object.assign(regionConfigResolver.getAwsRegionExtensionConfiguration(runtimeConfig2), smithyClient.getDefaultExtensionConfiguration(runtimeConfig2), protocolHttp.getHttpHandlerExtensionConfiguration(runtimeConfig2), getHttpAuthExtensionConfiguration32(runtimeConfig2));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig2, regionConfigResolver.resolveAwsRegionExtensionConfiguration(extensionConfiguration), smithyClient.resolveDefaultRuntimeConfig(extensionConfiguration), protocolHttp.resolveHttpHandlerRuntimeConfig(extensionConfiguration), resolveHttpAuthRuntimeConfig32(extensionConfiguration));
    }, "resolveRuntimeExtensions");
    var SecretsManagerClient3 = class extends smithyClient.Client {
      static {
        __name(this, "SecretsManagerClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = runtimeConfig.getRuntimeConfig(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters32(_config_0);
        const _config_2 = middlewareUserAgent.resolveUserAgentConfig(_config_1);
        const _config_3 = middlewareRetry.resolveRetryConfig(_config_2);
        const _config_4 = configResolver.resolveRegionConfig(_config_3);
        const _config_5 = middlewareHostHeader.resolveHostHeaderConfig(_config_4);
        const _config_6 = middlewareEndpoint.resolveEndpointConfig(_config_5);
        const _config_7 = httpAuthSchemeProvider.resolveHttpAuthSchemeConfig(_config_6);
        const _config_8 = resolveRuntimeExtensions32(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(schema.getSchemaSerdePlugin(this.config));
        this.middlewareStack.use(middlewareUserAgent.getUserAgentPlugin(this.config));
        this.middlewareStack.use(middlewareRetry.getRetryPlugin(this.config));
        this.middlewareStack.use(middlewareContentLength.getContentLengthPlugin(this.config));
        this.middlewareStack.use(middlewareHostHeader.getHostHeaderPlugin(this.config));
        this.middlewareStack.use(middlewareLogger.getLoggerPlugin(this.config));
        this.middlewareStack.use(middlewareRecursionDetection.getRecursionDetectionPlugin(this.config));
        this.middlewareStack.use(core.getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: httpAuthSchemeProvider.defaultSecretsManagerHttpAuthSchemeParametersProvider,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new core.DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(core.getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
    var BatchGetSecretValueCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("secretsmanager", "BatchGetSecretValue", {}).n("SecretsManagerClient", "BatchGetSecretValueCommand").sc(schemas_0.BatchGetSecretValue$).build() {
      static {
        __name(this, "BatchGetSecretValueCommand");
      }
    };
    var CancelRotateSecretCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("secretsmanager", "CancelRotateSecret", {}).n("SecretsManagerClient", "CancelRotateSecretCommand").sc(schemas_0.CancelRotateSecret$).build() {
      static {
        __name(this, "CancelRotateSecretCommand");
      }
    };
    var CreateSecretCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("secretsmanager", "CreateSecret", {}).n("SecretsManagerClient", "CreateSecretCommand").sc(schemas_0.CreateSecret$).build() {
      static {
        __name(this, "CreateSecretCommand");
      }
    };
    var DeleteResourcePolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("secretsmanager", "DeleteResourcePolicy", {}).n("SecretsManagerClient", "DeleteResourcePolicyCommand").sc(schemas_0.DeleteResourcePolicy$).build() {
      static {
        __name(this, "DeleteResourcePolicyCommand");
      }
    };
    var DeleteSecretCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("secretsmanager", "DeleteSecret", {}).n("SecretsManagerClient", "DeleteSecretCommand").sc(schemas_0.DeleteSecret$).build() {
      static {
        __name(this, "DeleteSecretCommand");
      }
    };
    var DescribeSecretCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("secretsmanager", "DescribeSecret", {}).n("SecretsManagerClient", "DescribeSecretCommand").sc(schemas_0.DescribeSecret$).build() {
      static {
        __name(this, "DescribeSecretCommand");
      }
    };
    var GetRandomPasswordCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("secretsmanager", "GetRandomPassword", {}).n("SecretsManagerClient", "GetRandomPasswordCommand").sc(schemas_0.GetRandomPassword$).build() {
      static {
        __name(this, "GetRandomPasswordCommand");
      }
    };
    var GetResourcePolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("secretsmanager", "GetResourcePolicy", {}).n("SecretsManagerClient", "GetResourcePolicyCommand").sc(schemas_0.GetResourcePolicy$).build() {
      static {
        __name(this, "GetResourcePolicyCommand");
      }
    };
    var GetSecretValueCommand3 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("secretsmanager", "GetSecretValue", {}).n("SecretsManagerClient", "GetSecretValueCommand").sc(schemas_0.GetSecretValue$).build() {
      static {
        __name(this, "GetSecretValueCommand");
      }
    };
    var ListSecretsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("secretsmanager", "ListSecrets", {}).n("SecretsManagerClient", "ListSecretsCommand").sc(schemas_0.ListSecrets$).build() {
      static {
        __name(this, "ListSecretsCommand");
      }
    };
    var ListSecretVersionIdsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("secretsmanager", "ListSecretVersionIds", {}).n("SecretsManagerClient", "ListSecretVersionIdsCommand").sc(schemas_0.ListSecretVersionIds$).build() {
      static {
        __name(this, "ListSecretVersionIdsCommand");
      }
    };
    var PutResourcePolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("secretsmanager", "PutResourcePolicy", {}).n("SecretsManagerClient", "PutResourcePolicyCommand").sc(schemas_0.PutResourcePolicy$).build() {
      static {
        __name(this, "PutResourcePolicyCommand");
      }
    };
    var PutSecretValueCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("secretsmanager", "PutSecretValue", {}).n("SecretsManagerClient", "PutSecretValueCommand").sc(schemas_0.PutSecretValue$).build() {
      static {
        __name(this, "PutSecretValueCommand");
      }
    };
    var RemoveRegionsFromReplicationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("secretsmanager", "RemoveRegionsFromReplication", {}).n("SecretsManagerClient", "RemoveRegionsFromReplicationCommand").sc(schemas_0.RemoveRegionsFromReplication$).build() {
      static {
        __name(this, "RemoveRegionsFromReplicationCommand");
      }
    };
    var ReplicateSecretToRegionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("secretsmanager", "ReplicateSecretToRegions", {}).n("SecretsManagerClient", "ReplicateSecretToRegionsCommand").sc(schemas_0.ReplicateSecretToRegions$).build() {
      static {
        __name(this, "ReplicateSecretToRegionsCommand");
      }
    };
    var RestoreSecretCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("secretsmanager", "RestoreSecret", {}).n("SecretsManagerClient", "RestoreSecretCommand").sc(schemas_0.RestoreSecret$).build() {
      static {
        __name(this, "RestoreSecretCommand");
      }
    };
    var RotateSecretCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("secretsmanager", "RotateSecret", {}).n("SecretsManagerClient", "RotateSecretCommand").sc(schemas_0.RotateSecret$).build() {
      static {
        __name(this, "RotateSecretCommand");
      }
    };
    var StopReplicationToReplicaCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("secretsmanager", "StopReplicationToReplica", {}).n("SecretsManagerClient", "StopReplicationToReplicaCommand").sc(schemas_0.StopReplicationToReplica$).build() {
      static {
        __name(this, "StopReplicationToReplicaCommand");
      }
    };
    var TagResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("secretsmanager", "TagResource", {}).n("SecretsManagerClient", "TagResourceCommand").sc(schemas_0.TagResource$).build() {
      static {
        __name(this, "TagResourceCommand");
      }
    };
    var UntagResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("secretsmanager", "UntagResource", {}).n("SecretsManagerClient", "UntagResourceCommand").sc(schemas_0.UntagResource$).build() {
      static {
        __name(this, "UntagResourceCommand");
      }
    };
    var UpdateSecretCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("secretsmanager", "UpdateSecret", {}).n("SecretsManagerClient", "UpdateSecretCommand").sc(schemas_0.UpdateSecret$).build() {
      static {
        __name(this, "UpdateSecretCommand");
      }
    };
    var UpdateSecretVersionStageCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("secretsmanager", "UpdateSecretVersionStage", {}).n("SecretsManagerClient", "UpdateSecretVersionStageCommand").sc(schemas_0.UpdateSecretVersionStage$).build() {
      static {
        __name(this, "UpdateSecretVersionStageCommand");
      }
    };
    var ValidateResourcePolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("secretsmanager", "ValidateResourcePolicy", {}).n("SecretsManagerClient", "ValidateResourcePolicyCommand").sc(schemas_0.ValidateResourcePolicy$).build() {
      static {
        __name(this, "ValidateResourcePolicyCommand");
      }
    };
    var paginateBatchGetSecretValue = core.createPaginator(SecretsManagerClient3, BatchGetSecretValueCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListSecrets = core.createPaginator(SecretsManagerClient3, ListSecretsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListSecretVersionIds = core.createPaginator(SecretsManagerClient3, ListSecretVersionIdsCommand, "NextToken", "NextToken", "MaxResults");
    var commands32 = {
      BatchGetSecretValueCommand,
      CancelRotateSecretCommand,
      CreateSecretCommand,
      DeleteResourcePolicyCommand,
      DeleteSecretCommand,
      DescribeSecretCommand,
      GetRandomPasswordCommand,
      GetResourcePolicyCommand,
      GetSecretValueCommand: GetSecretValueCommand3,
      ListSecretsCommand,
      ListSecretVersionIdsCommand,
      PutResourcePolicyCommand,
      PutSecretValueCommand,
      RemoveRegionsFromReplicationCommand,
      ReplicateSecretToRegionsCommand,
      RestoreSecretCommand,
      RotateSecretCommand,
      StopReplicationToReplicaCommand,
      TagResourceCommand,
      UntagResourceCommand,
      UpdateSecretCommand,
      UpdateSecretVersionStageCommand,
      ValidateResourcePolicyCommand
    };
    var paginators = {
      paginateBatchGetSecretValue,
      paginateListSecrets,
      paginateListSecretVersionIds
    };
    var SecretsManager = class extends SecretsManagerClient3 {
      static {
        __name(this, "SecretsManager");
      }
    };
    smithyClient.createAggregatedClient(commands32, SecretsManager, { paginators });
    var FilterNameStringType = {
      all: "all",
      description: "description",
      name: "name",
      owning_service: "owning-service",
      primary_region: "primary-region",
      tag_key: "tag-key",
      tag_value: "tag-value"
    };
    var StatusType = {
      Failed: "Failed",
      InProgress: "InProgress",
      InSync: "InSync"
    };
    var SortByType = {
      created_date: "created-date",
      last_accessed_date: "last-accessed-date",
      last_changed_date: "last-changed-date",
      name: "name"
    };
    var SortOrderType = {
      asc: "asc",
      desc: "desc"
    };
    exports2.$Command = smithyClient.Command;
    exports2.__Client = smithyClient.Client;
    exports2.SecretsManagerServiceException = SecretsManagerServiceException.SecretsManagerServiceException;
    exports2.BatchGetSecretValueCommand = BatchGetSecretValueCommand;
    exports2.CancelRotateSecretCommand = CancelRotateSecretCommand;
    exports2.CreateSecretCommand = CreateSecretCommand;
    exports2.DeleteResourcePolicyCommand = DeleteResourcePolicyCommand;
    exports2.DeleteSecretCommand = DeleteSecretCommand;
    exports2.DescribeSecretCommand = DescribeSecretCommand;
    exports2.FilterNameStringType = FilterNameStringType;
    exports2.GetRandomPasswordCommand = GetRandomPasswordCommand;
    exports2.GetResourcePolicyCommand = GetResourcePolicyCommand;
    exports2.GetSecretValueCommand = GetSecretValueCommand3;
    exports2.ListSecretVersionIdsCommand = ListSecretVersionIdsCommand;
    exports2.ListSecretsCommand = ListSecretsCommand;
    exports2.PutResourcePolicyCommand = PutResourcePolicyCommand;
    exports2.PutSecretValueCommand = PutSecretValueCommand;
    exports2.RemoveRegionsFromReplicationCommand = RemoveRegionsFromReplicationCommand;
    exports2.ReplicateSecretToRegionsCommand = ReplicateSecretToRegionsCommand;
    exports2.RestoreSecretCommand = RestoreSecretCommand;
    exports2.RotateSecretCommand = RotateSecretCommand;
    exports2.SecretsManager = SecretsManager;
    exports2.SecretsManagerClient = SecretsManagerClient3;
    exports2.SortByType = SortByType;
    exports2.SortOrderType = SortOrderType;
    exports2.StatusType = StatusType;
    exports2.StopReplicationToReplicaCommand = StopReplicationToReplicaCommand;
    exports2.TagResourceCommand = TagResourceCommand;
    exports2.UntagResourceCommand = UntagResourceCommand;
    exports2.UpdateSecretCommand = UpdateSecretCommand;
    exports2.UpdateSecretVersionStageCommand = UpdateSecretVersionStageCommand;
    exports2.ValidateResourcePolicyCommand = ValidateResourcePolicyCommand;
    exports2.paginateBatchGetSecretValue = paginateBatchGetSecretValue;
    exports2.paginateListSecretVersionIds = paginateListSecretVersionIds;
    exports2.paginateListSecrets = paginateListSecrets;
    Object.prototype.hasOwnProperty.call(schemas_0, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: schemas_0["__proto__"]
    });
    Object.keys(schemas_0).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = schemas_0[k32];
    });
    Object.prototype.hasOwnProperty.call(errors, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: errors["__proto__"]
    });
    Object.keys(errors).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = errors[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/client/emitWarningIfUnsupportedVersion.js
var state7, emitWarningIfUnsupportedVersion17;
var init_emitWarningIfUnsupportedVersion7 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/client/emitWarningIfUnsupportedVersion.js"() {
    state7 = {
      warningEmitted: false
    };
    emitWarningIfUnsupportedVersion17 = /* @__PURE__ */ __name((version) => {
      if (version && !state7.warningEmitted && parseInt(version.substring(1, version.indexOf("."))) < 20) {
        state7.warningEmitted = true;
        process.emitWarning(`NodeDeprecationWarning: The AWS SDK for JavaScript (v3) will
no longer support Node.js ${version} in January 2026.

To continue receiving updates to AWS services, bug fixes, and security
updates please upgrade to a supported Node.js LTS version.

More information can be found at: https://a.co/c895JFp`);
      }
    }, "emitWarningIfUnsupportedVersion");
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/client/longPollMiddleware.js
var longPollMiddleware7, longPollMiddlewareOptions7, getLongPollPlugin7;
var init_longPollMiddleware7 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/client/longPollMiddleware.js"() {
    longPollMiddleware7 = /* @__PURE__ */ __name(() => (next, context) => async (args) => {
      context.__retryLongPoll = true;
      return next(args);
    }, "longPollMiddleware");
    longPollMiddlewareOptions7 = {
      name: "longPollMiddleware",
      tags: ["RETRY"],
      step: "initialize",
      override: true
    };
    getLongPollPlugin7 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(longPollMiddleware7(), longPollMiddlewareOptions7);
      }, "applyToStack")
    }), "getLongPollPlugin");
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/client/setCredentialFeature.js
function setCredentialFeature7(credentials, feature, value) {
  if (!credentials.$source) {
    credentials.$source = {};
  }
  credentials.$source[feature] = value;
  return credentials;
}
var init_setCredentialFeature7 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/client/setCredentialFeature.js"() {
    __name(setCredentialFeature7, "setCredentialFeature");
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/client/setFeature.js
function setFeature8(context, feature, value) {
  if (!context.__aws_sdk_context) {
    context.__aws_sdk_context = {
      features: {}
    };
  } else if (!context.__aws_sdk_context.features) {
    context.__aws_sdk_context.features = {};
  }
  context.__aws_sdk_context.features[feature] = value;
}
var import_util_retry17;
var init_setFeature8 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/client/setFeature.js"() {
    import_util_retry17 = __toESM(require_dist_cjs22());
    import_util_retry17.Retry.v2026 ||= typeof process === "object" && process.env?.AWS_NEW_RETRIES_2026 === "true";
    __name(setFeature8, "setFeature");
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/client/setTokenFeature.js
function setTokenFeature7(token, feature, value) {
  if (!token.$source) {
    token.$source = {};
  }
  token.$source[feature] = value;
  return token;
}
var init_setTokenFeature7 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/client/setTokenFeature.js"() {
    __name(setTokenFeature7, "setTokenFeature");
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/client/index.js
var client_exports7 = {};
__export(client_exports7, {
  emitWarningIfUnsupportedVersion: () => emitWarningIfUnsupportedVersion17,
  getLongPollPlugin: () => getLongPollPlugin7,
  setCredentialFeature: () => setCredentialFeature7,
  setFeature: () => setFeature8,
  setTokenFeature: () => setTokenFeature7,
  state: () => state7
});
var init_client8 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/client/index.js"() {
    init_emitWarningIfUnsupportedVersion7();
    init_longPollMiddleware7();
    init_setCredentialFeature7();
    init_setFeature8();
    init_setTokenFeature7();
  }
});

// ../../node_modules/@aws-sdk/middleware-user-agent/dist-cjs/index.js
var require_dist_cjs104 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-user-agent/dist-cjs/index.js"(exports2) {
    "use strict";
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var utilEndpoints = require_dist_cjs21();
    var protocolHttp = require_dist_cjs2();
    var client = (init_client8(), __toCommonJS(client_exports7));
    var utilRetry = require_dist_cjs22();
    var DEFAULT_UA_APP_ID2 = void 0;
    function isValidUserAgentAppId2(appId) {
      if (appId === void 0) {
        return true;
      }
      return typeof appId === "string" && appId.length <= 50;
    }
    __name(isValidUserAgentAppId2, "isValidUserAgentAppId");
    function resolveUserAgentConfig29(input) {
      const normalizedAppIdProvider = core.normalizeProvider(input.userAgentAppId ?? DEFAULT_UA_APP_ID2);
      const { customUserAgent } = input;
      return Object.assign(input, {
        customUserAgent: typeof customUserAgent === "string" ? [[customUserAgent]] : customUserAgent,
        userAgentAppId: /* @__PURE__ */ __name(async () => {
          const appId = await normalizedAppIdProvider();
          if (!isValidUserAgentAppId2(appId)) {
            const logger5 = input.logger?.constructor?.name === "NoOpLogger" || !input.logger ? console : input.logger;
            if (typeof appId !== "string") {
              logger5?.warn("userAgentAppId must be a string or undefined.");
            } else if (appId.length > 50) {
              logger5?.warn("The provided userAgentAppId exceeds the maximum length of 50 characters.");
            }
          }
          return appId;
        }, "userAgentAppId")
      });
    }
    __name(resolveUserAgentConfig29, "resolveUserAgentConfig");
    var ACCOUNT_ID_ENDPOINT_REGEX2 = /\d{12}\.ddb/;
    async function checkFeatures2(context, config2, args) {
      const request4 = args.request;
      if (request4?.headers?.["smithy-protocol"] === "rpc-v2-cbor") {
        client.setFeature(context, "PROTOCOL_RPC_V2_CBOR", "M");
      }
      if (typeof config2.retryStrategy === "function") {
        const retryStrategy = await config2.retryStrategy();
        if (typeof retryStrategy.mode === "string") {
          switch (retryStrategy.mode) {
            case utilRetry.RETRY_MODES.ADAPTIVE:
              client.setFeature(context, "RETRY_MODE_ADAPTIVE", "F");
              break;
            case utilRetry.RETRY_MODES.STANDARD:
              client.setFeature(context, "RETRY_MODE_STANDARD", "E");
              break;
          }
        }
      }
      if (typeof config2.accountIdEndpointMode === "function") {
        const endpointV2 = context.endpointV2;
        if (String(endpointV2?.url?.hostname).match(ACCOUNT_ID_ENDPOINT_REGEX2)) {
          client.setFeature(context, "ACCOUNT_ID_ENDPOINT", "O");
        }
        switch (await config2.accountIdEndpointMode?.()) {
          case "disabled":
            client.setFeature(context, "ACCOUNT_ID_MODE_DISABLED", "Q");
            break;
          case "preferred":
            client.setFeature(context, "ACCOUNT_ID_MODE_PREFERRED", "P");
            break;
          case "required":
            client.setFeature(context, "ACCOUNT_ID_MODE_REQUIRED", "R");
            break;
        }
      }
      const identity = context.__smithy_context?.selectedHttpAuthScheme?.identity;
      if (identity?.$source) {
        const credentials = identity;
        if (credentials.accountId) {
          client.setFeature(context, "RESOLVED_ACCOUNT_ID", "T");
        }
        for (const [key, value] of Object.entries(credentials.$source ?? {})) {
          client.setFeature(context, key, value);
        }
      }
    }
    __name(checkFeatures2, "checkFeatures");
    var USER_AGENT3 = "user-agent";
    var X_AMZ_USER_AGENT2 = "x-amz-user-agent";
    var SPACE2 = " ";
    var UA_NAME_SEPARATOR2 = "/";
    var UA_NAME_ESCAPE_REGEX2 = /[^!$%&'*+\-.^_`|~\w]/g;
    var UA_VALUE_ESCAPE_REGEX2 = /[^!$%&'*+\-.^_`|~\w#]/g;
    var UA_ESCAPE_CHAR2 = "-";
    var BYTE_LIMIT2 = 1024;
    function encodeFeatures2(features) {
      let buffer = "";
      for (const key in features) {
        const val = features[key];
        if (buffer.length + val.length + 1 <= BYTE_LIMIT2) {
          if (buffer.length) {
            buffer += "," + val;
          } else {
            buffer += val;
          }
          continue;
        }
        break;
      }
      return buffer;
    }
    __name(encodeFeatures2, "encodeFeatures");
    var userAgentMiddleware2 = /* @__PURE__ */ __name((options) => (next, context) => async (args) => {
      const { request: request4 } = args;
      if (!protocolHttp.HttpRequest.isInstance(request4)) {
        return next(args);
      }
      const { headers } = request4;
      const userAgent = context?.userAgent?.map(escapeUserAgent2) || [];
      const defaultUserAgent2 = (await options.defaultUserAgentProvider()).map(escapeUserAgent2);
      await checkFeatures2(context, options, args);
      const awsContext = context;
      defaultUserAgent2.push(`m/${encodeFeatures2(Object.assign({}, context.__smithy_context?.features, awsContext.__aws_sdk_context?.features))}`);
      const customUserAgent = options?.customUserAgent?.map(escapeUserAgent2) || [];
      const appId = await options.userAgentAppId();
      if (appId) {
        defaultUserAgent2.push(escapeUserAgent2([`app`, `${appId}`]));
      }
      const prefix = utilEndpoints.getUserAgentPrefix();
      const sdkUserAgentValue = (prefix ? [prefix] : []).concat([...defaultUserAgent2, ...userAgent, ...customUserAgent]).join(SPACE2);
      const normalUAValue = [
        ...defaultUserAgent2.filter((section) => section.startsWith("aws-sdk-")),
        ...customUserAgent
      ].join(SPACE2);
      if (options.runtime !== "browser") {
        if (normalUAValue) {
          headers[X_AMZ_USER_AGENT2] = headers[X_AMZ_USER_AGENT2] ? `${headers[USER_AGENT3]} ${normalUAValue}` : normalUAValue;
        }
        headers[USER_AGENT3] = sdkUserAgentValue;
      } else {
        headers[X_AMZ_USER_AGENT2] = sdkUserAgentValue;
      }
      return next({
        ...args,
        request: request4
      });
    }, "userAgentMiddleware");
    var escapeUserAgent2 = /* @__PURE__ */ __name((userAgentPair) => {
      const name = userAgentPair[0].split(UA_NAME_SEPARATOR2).map((part) => part.replace(UA_NAME_ESCAPE_REGEX2, UA_ESCAPE_CHAR2)).join(UA_NAME_SEPARATOR2);
      const version = userAgentPair[1]?.replace(UA_VALUE_ESCAPE_REGEX2, UA_ESCAPE_CHAR2);
      const prefixSeparatorIndex = name.indexOf(UA_NAME_SEPARATOR2);
      const prefix = name.substring(0, prefixSeparatorIndex);
      let uaName = name.substring(prefixSeparatorIndex + 1);
      if (prefix === "api") {
        uaName = uaName.toLowerCase();
      }
      return [prefix, uaName, version].filter((item) => item && item.length > 0).reduce((acc, item, index) => {
        switch (index) {
          case 0:
            return item;
          case 1:
            return `${acc}/${item}`;
          default:
            return `${acc}#${item}`;
        }
      }, "");
    }, "escapeUserAgent");
    var getUserAgentMiddlewareOptions2 = {
      name: "getUserAgentMiddleware",
      step: "build",
      priority: "low",
      tags: ["SET_USER_AGENT", "USER_AGENT"],
      override: true
    };
    var getUserAgentPlugin29 = /* @__PURE__ */ __name((config2) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(userAgentMiddleware2(config2), getUserAgentMiddlewareOptions2);
      }, "applyToStack")
    }), "getUserAgentPlugin");
    exports2.DEFAULT_UA_APP_ID = DEFAULT_UA_APP_ID2;
    exports2.getUserAgentMiddlewareOptions = getUserAgentMiddlewareOptions2;
    exports2.getUserAgentPlugin = getUserAgentPlugin29;
    exports2.resolveUserAgentConfig = resolveUserAgentConfig29;
    exports2.userAgentMiddleware = userAgentMiddleware2;
  }
});

// ../../node_modules/@smithy/middleware-retry/node_modules/@smithy/service-error-classification/dist-cjs/index.js
var require_dist_cjs105 = __commonJS({
  "../../node_modules/@smithy/middleware-retry/node_modules/@smithy/service-error-classification/dist-cjs/index.js"(exports2) {
    "use strict";
    var CLOCK_SKEW_ERROR_CODES3 = [
      "AuthFailure",
      "InvalidSignatureException",
      "RequestExpired",
      "RequestInTheFuture",
      "RequestTimeTooSkewed",
      "SignatureDoesNotMatch"
    ];
    var THROTTLING_ERROR_CODES3 = [
      "BandwidthLimitExceeded",
      "EC2ThrottledException",
      "LimitExceededException",
      "PriorRequestNotComplete",
      "ProvisionedThroughputExceededException",
      "RequestLimitExceeded",
      "RequestThrottled",
      "RequestThrottledException",
      "SlowDown",
      "ThrottledException",
      "Throttling",
      "ThrottlingException",
      "TooManyRequestsException",
      "TransactionInProgressException"
    ];
    var TRANSIENT_ERROR_CODES3 = ["TimeoutError", "RequestTimeout", "RequestTimeoutException"];
    var TRANSIENT_ERROR_STATUS_CODES3 = [500, 502, 503, 504];
    var NODEJS_TIMEOUT_ERROR_CODES3 = ["ECONNRESET", "ECONNREFUSED", "EPIPE", "ETIMEDOUT"];
    var NODEJS_NETWORK_ERROR_CODES3 = ["EHOSTUNREACH", "ENETUNREACH", "ENOTFOUND"];
    var isRetryableByTrait3 = /* @__PURE__ */ __name((error4) => error4?.$retryable !== void 0, "isRetryableByTrait");
    var isClockSkewError3 = /* @__PURE__ */ __name((error4) => CLOCK_SKEW_ERROR_CODES3.includes(error4.name), "isClockSkewError");
    var isClockSkewCorrectedError3 = /* @__PURE__ */ __name((error4) => error4.$metadata?.clockSkewCorrected, "isClockSkewCorrectedError");
    var isBrowserNetworkError3 = /* @__PURE__ */ __name((error4) => {
      const errorMessages = /* @__PURE__ */ new Set([
        "Failed to fetch",
        "NetworkError when attempting to fetch resource",
        "The Internet connection appears to be offline",
        "Load failed",
        "Network request failed"
      ]);
      const isValid = error4 && error4 instanceof TypeError;
      if (!isValid) {
        return false;
      }
      return errorMessages.has(error4.message);
    }, "isBrowserNetworkError");
    var isThrottlingError3 = /* @__PURE__ */ __name((error4) => error4.$metadata?.httpStatusCode === 429 || THROTTLING_ERROR_CODES3.includes(error4.name) || error4.$retryable?.throttling == true, "isThrottlingError");
    var isTransientError3 = /* @__PURE__ */ __name((error4, depth = 0) => isRetryableByTrait3(error4) || isClockSkewCorrectedError3(error4) || TRANSIENT_ERROR_CODES3.includes(error4.name) || NODEJS_TIMEOUT_ERROR_CODES3.includes(error4?.code || "") || NODEJS_NETWORK_ERROR_CODES3.includes(error4?.code || "") || TRANSIENT_ERROR_STATUS_CODES3.includes(error4.$metadata?.httpStatusCode || 0) || isBrowserNetworkError3(error4) || isNodeJsHttp2TransientError3(error4) || error4.cause !== void 0 && depth <= 10 && isTransientError3(error4.cause, depth + 1), "isTransientError");
    var isServerError3 = /* @__PURE__ */ __name((error4) => {
      if (error4.$metadata?.httpStatusCode !== void 0) {
        const statusCode = error4.$metadata.httpStatusCode;
        if (500 <= statusCode && statusCode <= 599 && !isTransientError3(error4)) {
          return true;
        }
        return false;
      }
      return false;
    }, "isServerError");
    function isNodeJsHttp2TransientError3(error4) {
      return error4.code === "ERR_HTTP2_STREAM_ERROR" && error4.message.includes("NGHTTP2_REFUSED_STREAM");
    }
    __name(isNodeJsHttp2TransientError3, "isNodeJsHttp2TransientError");
    exports2.isBrowserNetworkError = isBrowserNetworkError3;
    exports2.isClockSkewCorrectedError = isClockSkewCorrectedError3;
    exports2.isClockSkewError = isClockSkewError3;
    exports2.isNodeJsHttp2TransientError = isNodeJsHttp2TransientError3;
    exports2.isRetryableByTrait = isRetryableByTrait3;
    exports2.isServerError = isServerError3;
    exports2.isThrottlingError = isThrottlingError3;
    exports2.isTransientError = isTransientError3;
  }
});

// ../../node_modules/@smithy/middleware-retry/dist-cjs/isStreamingPayload/isStreamingPayload.js
var require_isStreamingPayload5 = __commonJS({
  "../../node_modules/@smithy/middleware-retry/dist-cjs/isStreamingPayload/isStreamingPayload.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isStreamingPayload = void 0;
    var stream_1 = require("stream");
    var isStreamingPayload3 = /* @__PURE__ */ __name((request4) => request4?.body instanceof stream_1.Readable || typeof ReadableStream !== "undefined" && request4?.body instanceof ReadableStream, "isStreamingPayload");
    exports2.isStreamingPayload = isStreamingPayload3;
  }
});

// ../../node_modules/@smithy/middleware-retry/dist-cjs/index.js
var require_dist_cjs106 = __commonJS({
  "../../node_modules/@smithy/middleware-retry/dist-cjs/index.js"(exports2) {
    "use strict";
    var utilRetry = require_dist_cjs22();
    var protocolHttp = require_dist_cjs2();
    var serviceErrorClassification = require_dist_cjs105();
    var uuid = require_dist_cjs19();
    var utilMiddleware = require_dist_cjs6();
    var smithyClient = require_dist_cjs34();
    var isStreamingPayload3 = require_isStreamingPayload5();
    var serde = (init_serde(), __toCommonJS(serde_exports));
    var asSdkError3 = /* @__PURE__ */ __name((error4) => {
      if (error4 instanceof Error)
        return error4;
      if (error4 instanceof Object)
        return Object.assign(new Error(), error4);
      if (typeof error4 === "string")
        return new Error(error4);
      return new Error(`AWS SDK error wrapper for ${error4}`);
    }, "asSdkError");
    var getDefaultRetryQuota3 = /* @__PURE__ */ __name((initialRetryTokens, options) => {
      const MAX_CAPACITY = initialRetryTokens;
      const noRetryIncrement = utilRetry.NO_RETRY_INCREMENT;
      const retryCost = utilRetry.RETRY_COST;
      const timeoutRetryCost = utilRetry.TIMEOUT_RETRY_COST;
      let availableCapacity = initialRetryTokens;
      const getCapacityAmount = /* @__PURE__ */ __name((error4) => error4.name === "TimeoutError" ? timeoutRetryCost : retryCost, "getCapacityAmount");
      const hasRetryTokens = /* @__PURE__ */ __name((error4) => getCapacityAmount(error4) <= availableCapacity, "hasRetryTokens");
      const retrieveRetryTokens = /* @__PURE__ */ __name((error4) => {
        if (!hasRetryTokens(error4)) {
          throw new Error("No retry token available");
        }
        const capacityAmount = getCapacityAmount(error4);
        availableCapacity -= capacityAmount;
        return capacityAmount;
      }, "retrieveRetryTokens");
      const releaseRetryTokens = /* @__PURE__ */ __name((capacityReleaseAmount) => {
        availableCapacity += capacityReleaseAmount ?? noRetryIncrement;
        availableCapacity = Math.min(availableCapacity, MAX_CAPACITY);
      }, "releaseRetryTokens");
      return Object.freeze({
        hasRetryTokens,
        retrieveRetryTokens,
        releaseRetryTokens
      });
    }, "getDefaultRetryQuota");
    var defaultDelayDecider3 = /* @__PURE__ */ __name((delayBase, attempts) => Math.floor(Math.min(utilRetry.MAXIMUM_RETRY_DELAY, Math.random() * 2 ** attempts * delayBase)), "defaultDelayDecider");
    var defaultRetryDecider3 = /* @__PURE__ */ __name((error4) => {
      if (!error4) {
        return false;
      }
      return serviceErrorClassification.isRetryableByTrait(error4) || serviceErrorClassification.isClockSkewError(error4) || serviceErrorClassification.isThrottlingError(error4) || serviceErrorClassification.isTransientError(error4);
    }, "defaultRetryDecider");
    var StandardRetryStrategy5 = class {
      static {
        __name(this, "StandardRetryStrategy");
      }
      maxAttemptsProvider;
      retryDecider;
      delayDecider;
      retryQuota;
      mode = utilRetry.RETRY_MODES.STANDARD;
      constructor(maxAttemptsProvider, options) {
        this.maxAttemptsProvider = maxAttemptsProvider;
        this.retryDecider = options?.retryDecider ?? defaultRetryDecider3;
        this.delayDecider = options?.delayDecider ?? defaultDelayDecider3;
        this.retryQuota = options?.retryQuota ?? getDefaultRetryQuota3(utilRetry.INITIAL_RETRY_TOKENS);
      }
      shouldRetry(error4, attempts, maxAttempts) {
        return attempts < maxAttempts && this.retryDecider(error4) && this.retryQuota.hasRetryTokens(error4);
      }
      async getMaxAttempts() {
        let maxAttempts;
        try {
          maxAttempts = await this.maxAttemptsProvider();
        } catch (error4) {
          maxAttempts = utilRetry.DEFAULT_MAX_ATTEMPTS;
        }
        return maxAttempts;
      }
      async retry(next, args, options) {
        let retryTokenAmount;
        let attempts = 0;
        let totalDelay = 0;
        const maxAttempts = await this.getMaxAttempts();
        const { request: request4 } = args;
        if (protocolHttp.HttpRequest.isInstance(request4)) {
          request4.headers[utilRetry.INVOCATION_ID_HEADER] = uuid.v4();
        }
        while (true) {
          try {
            if (protocolHttp.HttpRequest.isInstance(request4)) {
              request4.headers[utilRetry.REQUEST_HEADER] = `attempt=${attempts + 1}; max=${maxAttempts}`;
            }
            if (options?.beforeRequest) {
              await options.beforeRequest();
            }
            const { response, output } = await next(args);
            if (options?.afterRequest) {
              options.afterRequest(response);
            }
            this.retryQuota.releaseRetryTokens(retryTokenAmount);
            output.$metadata.attempts = attempts + 1;
            output.$metadata.totalRetryDelay = totalDelay;
            return { response, output };
          } catch (e32) {
            const err = asSdkError3(e32);
            attempts++;
            if (this.shouldRetry(err, attempts, maxAttempts)) {
              retryTokenAmount = this.retryQuota.retrieveRetryTokens(err);
              const delayFromDecider = this.delayDecider(serviceErrorClassification.isThrottlingError(err) ? utilRetry.THROTTLING_RETRY_DELAY_BASE : utilRetry.DEFAULT_RETRY_DELAY_BASE, attempts);
              const delayFromResponse = getDelayFromRetryAfterHeader3(err.$response);
              const delay = Math.max(delayFromResponse || 0, delayFromDecider);
              totalDelay += delay;
              await new Promise((resolve13) => setTimeout(resolve13, delay));
              continue;
            }
            if (!err.$metadata) {
              err.$metadata = {};
            }
            err.$metadata.attempts = attempts;
            err.$metadata.totalRetryDelay = totalDelay;
            throw err;
          }
        }
      }
    };
    var getDelayFromRetryAfterHeader3 = /* @__PURE__ */ __name((response) => {
      if (!protocolHttp.HttpResponse.isInstance(response))
        return;
      const retryAfterHeaderName = Object.keys(response.headers).find((key) => key.toLowerCase() === "retry-after");
      if (!retryAfterHeaderName)
        return;
      const retryAfter = response.headers[retryAfterHeaderName];
      const retryAfterSeconds = Number(retryAfter);
      if (!Number.isNaN(retryAfterSeconds))
        return retryAfterSeconds * 1e3;
      const retryAfterDate = new Date(retryAfter);
      return retryAfterDate.getTime() - Date.now();
    }, "getDelayFromRetryAfterHeader");
    var AdaptiveRetryStrategy5 = class extends StandardRetryStrategy5 {
      static {
        __name(this, "AdaptiveRetryStrategy");
      }
      rateLimiter;
      constructor(maxAttemptsProvider, options) {
        const { rateLimiter, ...superOptions } = options ?? {};
        super(maxAttemptsProvider, superOptions);
        this.rateLimiter = rateLimiter ?? new utilRetry.DefaultRateLimiter();
        this.mode = utilRetry.RETRY_MODES.ADAPTIVE;
      }
      async retry(next, args) {
        return super.retry(next, args, {
          beforeRequest: /* @__PURE__ */ __name(async () => {
            return this.rateLimiter.getSendToken();
          }, "beforeRequest"),
          afterRequest: /* @__PURE__ */ __name((response) => {
            this.rateLimiter.updateClientSendingRate(response);
          }, "afterRequest")
        });
      }
    };
    var ENV_MAX_ATTEMPTS3 = "AWS_MAX_ATTEMPTS";
    var CONFIG_MAX_ATTEMPTS3 = "max_attempts";
    var NODE_MAX_ATTEMPT_CONFIG_OPTIONS30 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => {
        const value = env3[ENV_MAX_ATTEMPTS3];
        if (!value)
          return void 0;
        const maxAttempt = parseInt(value);
        if (Number.isNaN(maxAttempt)) {
          throw new Error(`Environment variable ${ENV_MAX_ATTEMPTS3} mast be a number, got "${value}"`);
        }
        return maxAttempt;
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => {
        const value = profile[CONFIG_MAX_ATTEMPTS3];
        if (!value)
          return void 0;
        const maxAttempt = parseInt(value);
        if (Number.isNaN(maxAttempt)) {
          throw new Error(`Shared config file entry ${CONFIG_MAX_ATTEMPTS3} mast be a number, got "${value}"`);
        }
        return maxAttempt;
      }, "configFileSelector"),
      default: utilRetry.DEFAULT_MAX_ATTEMPTS
    };
    var resolveRetryConfig30 = /* @__PURE__ */ __name((input) => {
      const { retryStrategy, retryMode } = input;
      const maxAttempts = utilMiddleware.normalizeProvider(input.maxAttempts ?? utilRetry.DEFAULT_MAX_ATTEMPTS);
      let controller = retryStrategy ? Promise.resolve(retryStrategy) : void 0;
      const getDefault = /* @__PURE__ */ __name(async () => await utilMiddleware.normalizeProvider(retryMode)() === utilRetry.RETRY_MODES.ADAPTIVE ? new utilRetry.AdaptiveRetryStrategy(maxAttempts) : new utilRetry.StandardRetryStrategy(maxAttempts), "getDefault");
      return Object.assign(input, {
        maxAttempts,
        retryStrategy: /* @__PURE__ */ __name(() => controller ??= getDefault(), "retryStrategy")
      });
    }, "resolveRetryConfig");
    var ENV_RETRY_MODE3 = "AWS_RETRY_MODE";
    var CONFIG_RETRY_MODE3 = "retry_mode";
    var NODE_RETRY_MODE_CONFIG_OPTIONS30 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[ENV_RETRY_MODE3], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[CONFIG_RETRY_MODE3], "configFileSelector"),
      default: utilRetry.DEFAULT_RETRY_MODE
    };
    var omitRetryHeadersMiddleware3 = /* @__PURE__ */ __name(() => (next) => async (args) => {
      const { request: request4 } = args;
      if (protocolHttp.HttpRequest.isInstance(request4)) {
        delete request4.headers[utilRetry.INVOCATION_ID_HEADER];
        delete request4.headers[utilRetry.REQUEST_HEADER];
      }
      return next(args);
    }, "omitRetryHeadersMiddleware");
    var omitRetryHeadersMiddlewareOptions3 = {
      name: "omitRetryHeadersMiddleware",
      tags: ["RETRY", "HEADERS", "OMIT_RETRY_HEADERS"],
      relation: "before",
      toMiddleware: "awsAuthMiddleware",
      override: true
    };
    var getOmitRetryHeadersPlugin3 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.addRelativeTo(omitRetryHeadersMiddleware3(), omitRetryHeadersMiddlewareOptions3);
      }, "applyToStack")
    }), "getOmitRetryHeadersPlugin");
    function parseRetryAfterHeader3(response, logger5) {
      if (!protocolHttp.HttpResponse.isInstance(response)) {
        return;
      }
      for (const header of Object.keys(response.headers)) {
        const h32 = header.toLowerCase();
        if (h32 === "retry-after") {
          const retryAfter = response.headers[header];
          let retryAfterSeconds = NaN;
          if (retryAfter.endsWith("GMT")) {
            try {
              const date7 = serde.parseRfc7231DateTime(retryAfter);
              retryAfterSeconds = (date7.getTime() - Date.now()) / 1e3;
            } catch (e32) {
              logger5?.trace?.("Failed to parse retry-after header");
              logger5?.trace?.(e32);
            }
          } else if (retryAfter.match(/ GMT, ((\d+)|(\d+\.\d+))$/)) {
            retryAfterSeconds = Number(retryAfter.match(/ GMT, ([\d.]+)$/)?.[1]);
          } else if (retryAfter.match(/^((\d+)|(\d+\.\d+))$/)) {
            retryAfterSeconds = Number(retryAfter);
          } else if (Date.parse(retryAfter) >= Date.now()) {
            retryAfterSeconds = (Date.parse(retryAfter) - Date.now()) / 1e3;
          }
          if (isNaN(retryAfterSeconds)) {
            return;
          }
          return new Date(Date.now() + retryAfterSeconds * 1e3);
        } else if (h32 === "x-amz-retry-after") {
          const v = response.headers[header];
          const backoffMilliseconds = Number(v);
          if (isNaN(backoffMilliseconds)) {
            logger5?.trace?.(`Failed to parse x-amz-retry-after=${v}`);
            return;
          }
          return new Date(Date.now() + backoffMilliseconds);
        }
      }
    }
    __name(parseRetryAfterHeader3, "parseRetryAfterHeader");
    function getRetryAfterHint3(response, logger5) {
      return parseRetryAfterHeader3(response, logger5);
    }
    __name(getRetryAfterHint3, "getRetryAfterHint");
    var retryMiddleware3 = /* @__PURE__ */ __name((options) => (next, context) => async (args) => {
      let retryStrategy = await options.retryStrategy();
      const maxAttempts = await options.maxAttempts();
      if (isRetryStrategyV23(retryStrategy)) {
        retryStrategy = retryStrategy;
        let retryToken = await retryStrategy.acquireInitialRetryToken((context["partition_id"] ?? "") + (context.__retryLongPoll ? ":longpoll" : ""));
        let lastError = new Error();
        let attempts = 0;
        let totalRetryDelay = 0;
        const { request: request4 } = args;
        const isRequest = protocolHttp.HttpRequest.isInstance(request4);
        if (isRequest) {
          request4.headers[utilRetry.INVOCATION_ID_HEADER] = uuid.v4();
        }
        while (true) {
          try {
            if (isRequest) {
              request4.headers[utilRetry.REQUEST_HEADER] = `attempt=${attempts + 1}; max=${maxAttempts}`;
            }
            const { response, output } = await next(args);
            retryStrategy.recordSuccess(retryToken);
            output.$metadata.attempts = attempts + 1;
            output.$metadata.totalRetryDelay = totalRetryDelay;
            return { response, output };
          } catch (e32) {
            const retryErrorInfo = getRetryErrorInfo3(e32, options.logger);
            lastError = asSdkError3(e32);
            if (isRequest && isStreamingPayload3.isStreamingPayload(request4)) {
              (context.logger instanceof smithyClient.NoOpLogger ? console : context.logger)?.warn("An error was encountered in a non-retryable streaming request.");
              throw lastError;
            }
            try {
              retryToken = await retryStrategy.refreshRetryTokenForRetry(retryToken, retryErrorInfo);
            } catch (refreshError) {
              if (typeof refreshError.$backoff === "number") {
                await cooldown3(refreshError.$backoff);
              }
              if (!lastError.$metadata) {
                lastError.$metadata = {};
              }
              lastError.$metadata.attempts = attempts + 1;
              lastError.$metadata.totalRetryDelay = totalRetryDelay;
              throw lastError;
            }
            attempts = retryToken.getRetryCount();
            const delay = retryToken.getRetryDelay();
            totalRetryDelay += delay;
            await cooldown3(delay);
          }
        }
      } else {
        retryStrategy = retryStrategy;
        if (retryStrategy?.mode) {
          context.userAgent = [...context.userAgent || [], ["cfg/retry-mode", retryStrategy.mode]];
        }
        return retryStrategy.retry(next, args);
      }
    }, "retryMiddleware");
    var cooldown3 = /* @__PURE__ */ __name((ms) => new Promise((resolve13) => setTimeout(resolve13, ms)), "cooldown");
    var isRetryStrategyV23 = /* @__PURE__ */ __name((retryStrategy) => typeof retryStrategy.acquireInitialRetryToken !== "undefined" && typeof retryStrategy.refreshRetryTokenForRetry !== "undefined" && typeof retryStrategy.recordSuccess !== "undefined", "isRetryStrategyV2");
    var getRetryErrorInfo3 = /* @__PURE__ */ __name((error4, logger5) => {
      const errorInfo = {
        error: error4,
        errorType: getRetryErrorType3(error4)
      };
      const retryAfterHint = parseRetryAfterHeader3(error4.$response, logger5);
      if (retryAfterHint) {
        errorInfo.retryAfterHint = retryAfterHint;
      }
      return errorInfo;
    }, "getRetryErrorInfo");
    var getRetryErrorType3 = /* @__PURE__ */ __name((error4) => {
      if (serviceErrorClassification.isThrottlingError(error4))
        return "THROTTLING";
      if (serviceErrorClassification.isTransientError(error4))
        return "TRANSIENT";
      if (serviceErrorClassification.isServerError(error4))
        return "SERVER_ERROR";
      return "CLIENT_ERROR";
    }, "getRetryErrorType");
    var retryMiddlewareOptions3 = {
      name: "retryMiddleware",
      tags: ["RETRY"],
      step: "finalizeRequest",
      priority: "high",
      override: true
    };
    var getRetryPlugin30 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(retryMiddleware3(options), retryMiddlewareOptions3);
      }, "applyToStack")
    }), "getRetryPlugin");
    exports2.AdaptiveRetryStrategy = AdaptiveRetryStrategy5;
    exports2.CONFIG_MAX_ATTEMPTS = CONFIG_MAX_ATTEMPTS3;
    exports2.CONFIG_RETRY_MODE = CONFIG_RETRY_MODE3;
    exports2.ENV_MAX_ATTEMPTS = ENV_MAX_ATTEMPTS3;
    exports2.ENV_RETRY_MODE = ENV_RETRY_MODE3;
    exports2.NODE_MAX_ATTEMPT_CONFIG_OPTIONS = NODE_MAX_ATTEMPT_CONFIG_OPTIONS30;
    exports2.NODE_RETRY_MODE_CONFIG_OPTIONS = NODE_RETRY_MODE_CONFIG_OPTIONS30;
    exports2.StandardRetryStrategy = StandardRetryStrategy5;
    exports2.defaultDelayDecider = defaultDelayDecider3;
    exports2.defaultRetryDecider = defaultRetryDecider3;
    exports2.getOmitRetryHeadersPlugin = getOmitRetryHeadersPlugin3;
    exports2.getRetryAfterHint = getRetryAfterHint3;
    exports2.getRetryPlugin = getRetryPlugin30;
    exports2.omitRetryHeadersMiddleware = omitRetryHeadersMiddleware3;
    exports2.omitRetryHeadersMiddlewareOptions = omitRetryHeadersMiddlewareOptions3;
    exports2.resolveRetryConfig = resolveRetryConfig30;
    exports2.retryMiddleware = retryMiddleware3;
    exports2.retryMiddlewareOptions = retryMiddlewareOptions3;
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getDateHeader.js
var import_protocol_http31, getDateHeader5;
var init_getDateHeader5 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getDateHeader.js"() {
    import_protocol_http31 = __toESM(require_dist_cjs2());
    getDateHeader5 = /* @__PURE__ */ __name((response) => import_protocol_http31.HttpResponse.isInstance(response) ? response.headers?.date ?? response.headers?.Date : void 0, "getDateHeader");
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getSkewCorrectedDate.js
var getSkewCorrectedDate5;
var init_getSkewCorrectedDate5 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getSkewCorrectedDate.js"() {
    getSkewCorrectedDate5 = /* @__PURE__ */ __name((systemClockOffset) => new Date(Date.now() + systemClockOffset), "getSkewCorrectedDate");
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/isClockSkewed.js
var isClockSkewed5;
var init_isClockSkewed5 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/isClockSkewed.js"() {
    init_getSkewCorrectedDate5();
    isClockSkewed5 = /* @__PURE__ */ __name((clockTime, systemClockOffset) => Math.abs(getSkewCorrectedDate5(systemClockOffset).getTime() - clockTime) >= 3e5, "isClockSkewed");
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getUpdatedSystemClockOffset.js
var getUpdatedSystemClockOffset5;
var init_getUpdatedSystemClockOffset5 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getUpdatedSystemClockOffset.js"() {
    init_isClockSkewed5();
    getUpdatedSystemClockOffset5 = /* @__PURE__ */ __name((clockTime, currentSystemClockOffset) => {
      const clockTimeInMs = Date.parse(clockTime);
      if (isClockSkewed5(clockTimeInMs, currentSystemClockOffset)) {
        return clockTimeInMs - Date.now();
      }
      return currentSystemClockOffset;
    }, "getUpdatedSystemClockOffset");
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/index.js
var init_utils5 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/index.js"() {
    init_getDateHeader5();
    init_getSkewCorrectedDate5();
    init_getUpdatedSystemClockOffset5();
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4Signer.js
var import_protocol_http32, throwSigningPropertyError5, validateSigningProperties5, AwsSdkSigV4Signer5, AWSSDKSigV4Signer5;
var init_AwsSdkSigV4Signer5 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4Signer.js"() {
    import_protocol_http32 = __toESM(require_dist_cjs2());
    init_utils5();
    throwSigningPropertyError5 = /* @__PURE__ */ __name((name, property) => {
      if (!property) {
        throw new Error(`Property \`${name}\` is not resolved for AWS SDK SigV4Auth`);
      }
      return property;
    }, "throwSigningPropertyError");
    validateSigningProperties5 = /* @__PURE__ */ __name(async (signingProperties) => {
      const context = throwSigningPropertyError5("context", signingProperties.context);
      const config2 = throwSigningPropertyError5("config", signingProperties.config);
      const authScheme = context.endpointV2?.properties?.authSchemes?.[0];
      const signerFunction = throwSigningPropertyError5("signer", config2.signer);
      const signer = await signerFunction(authScheme);
      const signingRegion = signingProperties?.signingRegion;
      const signingRegionSet = signingProperties?.signingRegionSet;
      const signingName = signingProperties?.signingName;
      return {
        config: config2,
        signer,
        signingRegion,
        signingRegionSet,
        signingName
      };
    }, "validateSigningProperties");
    AwsSdkSigV4Signer5 = class {
      static {
        __name(this, "AwsSdkSigV4Signer");
      }
      async sign(httpRequest, identity, signingProperties) {
        if (!import_protocol_http32.HttpRequest.isInstance(httpRequest)) {
          throw new Error("The request is not an instance of `HttpRequest` and cannot be signed");
        }
        const validatedProps = await validateSigningProperties5(signingProperties);
        const { config: config2, signer } = validatedProps;
        let { signingRegion, signingName } = validatedProps;
        const handlerExecutionContext = signingProperties.context;
        if (handlerExecutionContext?.authSchemes?.length ?? 0 > 1) {
          const [first, second] = handlerExecutionContext.authSchemes;
          if (first?.name === "sigv4a" && second?.name === "sigv4") {
            signingRegion = second?.signingRegion ?? signingRegion;
            signingName = second?.signingName ?? signingName;
          }
        }
        const signedRequest = await signer.sign(httpRequest, {
          signingDate: getSkewCorrectedDate5(config2.systemClockOffset),
          signingRegion,
          signingService: signingName
        });
        return signedRequest;
      }
      errorHandler(signingProperties) {
        return (error4) => {
          const serverTime = error4.ServerTime ?? getDateHeader5(error4.$response);
          if (serverTime) {
            const config2 = throwSigningPropertyError5("config", signingProperties.config);
            const initialSystemClockOffset = config2.systemClockOffset;
            config2.systemClockOffset = getUpdatedSystemClockOffset5(serverTime, config2.systemClockOffset);
            const clockSkewCorrected = config2.systemClockOffset !== initialSystemClockOffset;
            if (clockSkewCorrected && error4.$metadata) {
              error4.$metadata.clockSkewCorrected = true;
            }
          }
          throw error4;
        };
      }
      successHandler(httpResponse, signingProperties) {
        const dateHeader = getDateHeader5(httpResponse);
        if (dateHeader) {
          const config2 = throwSigningPropertyError5("config", signingProperties.config);
          config2.systemClockOffset = getUpdatedSystemClockOffset5(dateHeader, config2.systemClockOffset);
        }
      }
    };
    AWSSDKSigV4Signer5 = AwsSdkSigV4Signer5;
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4ASigner.js
var import_protocol_http33, AwsSdkSigV4ASigner5;
var init_AwsSdkSigV4ASigner5 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4ASigner.js"() {
    import_protocol_http33 = __toESM(require_dist_cjs2());
    init_utils5();
    init_AwsSdkSigV4Signer5();
    AwsSdkSigV4ASigner5 = class extends AwsSdkSigV4Signer5 {
      static {
        __name(this, "AwsSdkSigV4ASigner");
      }
      async sign(httpRequest, identity, signingProperties) {
        if (!import_protocol_http33.HttpRequest.isInstance(httpRequest)) {
          throw new Error("The request is not an instance of `HttpRequest` and cannot be signed");
        }
        const { config: config2, signer, signingRegion, signingRegionSet, signingName } = await validateSigningProperties5(signingProperties);
        const configResolvedSigningRegionSet = await config2.sigv4aSigningRegionSet?.();
        const multiRegionOverride = (configResolvedSigningRegionSet ?? signingRegionSet ?? [signingRegion]).join(",");
        const signedRequest = await signer.sign(httpRequest, {
          signingDate: getSkewCorrectedDate5(config2.systemClockOffset),
          signingRegion: multiRegionOverride,
          signingService: signingName
        });
        return signedRequest;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getArrayForCommaSeparatedString.js
var getArrayForCommaSeparatedString5;
var init_getArrayForCommaSeparatedString5 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getArrayForCommaSeparatedString.js"() {
    getArrayForCommaSeparatedString5 = /* @__PURE__ */ __name((str) => typeof str === "string" && str.length > 0 ? str.split(",").map((item) => item.trim()) : [], "getArrayForCommaSeparatedString");
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getBearerTokenEnvKey.js
var getBearerTokenEnvKey5;
var init_getBearerTokenEnvKey5 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getBearerTokenEnvKey.js"() {
    getBearerTokenEnvKey5 = /* @__PURE__ */ __name((signingName) => `AWS_BEARER_TOKEN_${signingName.replace(/[\s-]/g, "_").toUpperCase()}`, "getBearerTokenEnvKey");
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/NODE_AUTH_SCHEME_PREFERENCE_OPTIONS.js
var NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY5, NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY5, NODE_AUTH_SCHEME_PREFERENCE_OPTIONS5;
var init_NODE_AUTH_SCHEME_PREFERENCE_OPTIONS5 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/NODE_AUTH_SCHEME_PREFERENCE_OPTIONS.js"() {
    init_getArrayForCommaSeparatedString5();
    init_getBearerTokenEnvKey5();
    NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY5 = "AWS_AUTH_SCHEME_PREFERENCE";
    NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY5 = "auth_scheme_preference";
    NODE_AUTH_SCHEME_PREFERENCE_OPTIONS5 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3, options) => {
        if (options?.signingName) {
          const bearerTokenKey = getBearerTokenEnvKey5(options.signingName);
          if (bearerTokenKey in env3)
            return ["httpBearerAuth"];
        }
        if (!(NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY5 in env3))
          return void 0;
        return getArrayForCommaSeparatedString5(env3[NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY5]);
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => {
        if (!(NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY5 in profile))
          return void 0;
        return getArrayForCommaSeparatedString5(profile[NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY5]);
      }, "configFileSelector"),
      default: []
    };
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4AConfig.js
var import_property_provider5, resolveAwsSdkSigV4AConfig5, NODE_SIGV4A_CONFIG_OPTIONS5;
var init_resolveAwsSdkSigV4AConfig5 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4AConfig.js"() {
    init_dist_es();
    import_property_provider5 = __toESM(require_dist_cjs27());
    resolveAwsSdkSigV4AConfig5 = /* @__PURE__ */ __name((config2) => {
      config2.sigv4aSigningRegionSet = normalizeProvider(config2.sigv4aSigningRegionSet);
      return config2;
    }, "resolveAwsSdkSigV4AConfig");
    NODE_SIGV4A_CONFIG_OPTIONS5 = {
      environmentVariableSelector(env3) {
        if (env3.AWS_SIGV4A_SIGNING_REGION_SET) {
          return env3.AWS_SIGV4A_SIGNING_REGION_SET.split(",").map((_) => _.trim());
        }
        throw new import_property_provider5.ProviderError("AWS_SIGV4A_SIGNING_REGION_SET not set in env.", {
          tryNextLink: true
        });
      },
      configFileSelector(profile) {
        if (profile.sigv4a_signing_region_set) {
          return (profile.sigv4a_signing_region_set ?? "").split(",").map((_) => _.trim());
        }
        throw new import_property_provider5.ProviderError("sigv4a_signing_region_set not set in profile.", {
          tryNextLink: true
        });
      },
      default: void 0
    };
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4Config.js
function normalizeCredentialProvider5(config2, { credentials, credentialDefaultProvider }) {
  let credentialsProvider;
  if (credentials) {
    if (!credentials?.memoized) {
      credentialsProvider = memoizeIdentityProvider(credentials, isIdentityExpired, doesIdentityRequireRefresh);
    } else {
      credentialsProvider = credentials;
    }
  } else {
    if (credentialDefaultProvider) {
      credentialsProvider = normalizeProvider(credentialDefaultProvider(Object.assign({}, config2, {
        parentClientConfig: config2
      })));
    } else {
      credentialsProvider = /* @__PURE__ */ __name(async () => {
        throw new Error("@aws-sdk/core::resolveAwsSdkSigV4Config - `credentials` not provided and no credentialDefaultProvider was configured.");
      }, "credentialsProvider");
    }
  }
  credentialsProvider.memoized = true;
  return credentialsProvider;
}
function bindCallerConfig5(config2, credentialsProvider) {
  if (credentialsProvider.configBound) {
    return credentialsProvider;
  }
  const fn = /* @__PURE__ */ __name(async (options) => credentialsProvider({ ...options, callerClientConfig: config2 }), "fn");
  fn.memoized = credentialsProvider.memoized;
  fn.configBound = true;
  return fn;
}
var import_signature_v45, resolveAwsSdkSigV4Config5, resolveAWSSDKSigV4Config5;
var init_resolveAwsSdkSigV4Config5 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4Config.js"() {
    init_client8();
    init_dist_es();
    import_signature_v45 = __toESM(require_dist_cjs36());
    resolveAwsSdkSigV4Config5 = /* @__PURE__ */ __name((config2) => {
      let inputCredentials = config2.credentials;
      let isUserSupplied = !!config2.credentials;
      let resolvedCredentials = void 0;
      Object.defineProperty(config2, "credentials", {
        set(credentials) {
          if (credentials && credentials !== inputCredentials && credentials !== resolvedCredentials) {
            isUserSupplied = true;
          }
          inputCredentials = credentials;
          const memoizedProvider = normalizeCredentialProvider5(config2, {
            credentials: inputCredentials,
            credentialDefaultProvider: config2.credentialDefaultProvider
          });
          const boundProvider = bindCallerConfig5(config2, memoizedProvider);
          if (isUserSupplied && !boundProvider.attributed) {
            const isCredentialObject = typeof inputCredentials === "object" && inputCredentials !== null;
            resolvedCredentials = /* @__PURE__ */ __name(async (options) => {
              const creds = await boundProvider(options);
              const attributedCreds = creds;
              if (isCredentialObject && (!attributedCreds.$source || Object.keys(attributedCreds.$source).length === 0)) {
                return setCredentialFeature7(attributedCreds, "CREDENTIALS_CODE", "e");
              }
              return attributedCreds;
            }, "resolvedCredentials");
            resolvedCredentials.memoized = boundProvider.memoized;
            resolvedCredentials.configBound = boundProvider.configBound;
            resolvedCredentials.attributed = true;
          } else {
            resolvedCredentials = boundProvider;
          }
        },
        get() {
          return resolvedCredentials;
        },
        enumerable: true,
        configurable: true
      });
      config2.credentials = inputCredentials;
      const { signingEscapePath = true, systemClockOffset = config2.systemClockOffset || 0, sha256 } = config2;
      let signer;
      if (config2.signer) {
        signer = normalizeProvider(config2.signer);
      } else if (config2.regionInfoProvider) {
        signer = /* @__PURE__ */ __name(() => normalizeProvider(config2.region)().then(async (region) => [
          await config2.regionInfoProvider(region, {
            useFipsEndpoint: await config2.useFipsEndpoint(),
            useDualstackEndpoint: await config2.useDualstackEndpoint()
          }) || {},
          region
        ]).then(([regionInfo, region]) => {
          const { signingRegion, signingService } = regionInfo;
          config2.signingRegion = config2.signingRegion || signingRegion || region;
          config2.signingName = config2.signingName || signingService || config2.serviceId;
          const params = {
            ...config2,
            credentials: config2.credentials,
            region: config2.signingRegion,
            service: config2.signingName,
            sha256,
            uriEscapePath: signingEscapePath
          };
          const SignerCtor = config2.signerConstructor || import_signature_v45.SignatureV4;
          return new SignerCtor(params);
        }), "signer");
      } else {
        signer = /* @__PURE__ */ __name(async (authScheme) => {
          authScheme = Object.assign({}, {
            name: "sigv4",
            signingName: config2.signingName || config2.defaultSigningName,
            signingRegion: await normalizeProvider(config2.region)(),
            properties: {}
          }, authScheme);
          const signingRegion = authScheme.signingRegion;
          const signingService = authScheme.signingName;
          config2.signingRegion = config2.signingRegion || signingRegion;
          config2.signingName = config2.signingName || signingService || config2.serviceId;
          const params = {
            ...config2,
            credentials: config2.credentials,
            region: config2.signingRegion,
            service: config2.signingName,
            sha256,
            uriEscapePath: signingEscapePath
          };
          const SignerCtor = config2.signerConstructor || import_signature_v45.SignatureV4;
          return new SignerCtor(params);
        }, "signer");
      }
      const resolvedConfig = Object.assign(config2, {
        systemClockOffset,
        signingEscapePath,
        signer
      });
      return resolvedConfig;
    }, "resolveAwsSdkSigV4Config");
    resolveAWSSDKSigV4Config5 = resolveAwsSdkSigV4Config5;
    __name(normalizeCredentialProvider5, "normalizeCredentialProvider");
    __name(bindCallerConfig5, "bindCallerConfig");
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/index.js
var init_aws_sdk5 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/index.js"() {
    init_AwsSdkSigV4Signer5();
    init_AwsSdkSigV4ASigner5();
    init_NODE_AUTH_SCHEME_PREFERENCE_OPTIONS5();
    init_resolveAwsSdkSigV4AConfig5();
    init_resolveAwsSdkSigV4Config5();
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/index.js
var httpAuthSchemes_exports5 = {};
__export(httpAuthSchemes_exports5, {
  AWSSDKSigV4Signer: () => AWSSDKSigV4Signer5,
  AwsSdkSigV4ASigner: () => AwsSdkSigV4ASigner5,
  AwsSdkSigV4Signer: () => AwsSdkSigV4Signer5,
  NODE_AUTH_SCHEME_PREFERENCE_OPTIONS: () => NODE_AUTH_SCHEME_PREFERENCE_OPTIONS5,
  NODE_SIGV4A_CONFIG_OPTIONS: () => NODE_SIGV4A_CONFIG_OPTIONS5,
  getBearerTokenEnvKey: () => getBearerTokenEnvKey5,
  resolveAWSSDKSigV4Config: () => resolveAWSSDKSigV4Config5,
  resolveAwsSdkSigV4AConfig: () => resolveAwsSdkSigV4AConfig5,
  resolveAwsSdkSigV4Config: () => resolveAwsSdkSigV4Config5,
  validateSigningProperties: () => validateSigningProperties5
});
var init_httpAuthSchemes6 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/index.js"() {
    init_aws_sdk5();
    init_getBearerTokenEnvKey5();
  }
});

// ../../node_modules/@aws-sdk/client-sts/node_modules/@aws-sdk/middleware-sdk-s3/dist-cjs/toStream.js
var require_toStream2 = __commonJS({
  "../../node_modules/@aws-sdk/client-sts/node_modules/@aws-sdk/middleware-sdk-s3/dist-cjs/toStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.toStream = toStream;
    var node_stream_1 = require("node:stream");
    function toStream(bytes) {
      return node_stream_1.Readable.from(Buffer.from(bytes));
    }
    __name(toStream, "toStream");
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/ProtocolLib.js
var import_smithy_client101, ProtocolLib6;
var init_ProtocolLib6 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/ProtocolLib.js"() {
    init_schema4();
    import_smithy_client101 = __toESM(require_dist_cjs34());
    ProtocolLib6 = class {
      static {
        __name(this, "ProtocolLib");
      }
      queryCompat;
      errorRegistry;
      constructor(queryCompat = false) {
        this.queryCompat = queryCompat;
      }
      resolveRestContentType(defaultContentType, inputSchema) {
        const members = inputSchema.getMemberSchemas();
        const httpPayloadMember = Object.values(members).find((m20) => {
          return !!m20.getMergedTraits().httpPayload;
        });
        if (httpPayloadMember) {
          const mediaType = httpPayloadMember.getMergedTraits().mediaType;
          if (mediaType) {
            return mediaType;
          } else if (httpPayloadMember.isStringSchema()) {
            return "text/plain";
          } else if (httpPayloadMember.isBlobSchema()) {
            return "application/octet-stream";
          } else {
            return defaultContentType;
          }
        } else if (!inputSchema.isUnitSchema()) {
          const hasBody = Object.values(members).find((m20) => {
            const { httpQuery, httpQueryParams, httpHeader, httpLabel, httpPrefixHeaders } = m20.getMergedTraits();
            const noPrefixHeaders = httpPrefixHeaders === void 0;
            return !httpQuery && !httpQueryParams && !httpHeader && !httpLabel && noPrefixHeaders;
          });
          if (hasBody) {
            return defaultContentType;
          }
        }
      }
      async getErrorSchemaOrThrowBaseException(errorIdentifier, defaultNamespace, response, dataObject, metadata, getErrorSchema) {
        let errorName = errorIdentifier;
        if (errorIdentifier.includes("#")) {
          [, errorName] = errorIdentifier.split("#");
        }
        const errorMetadata = {
          $metadata: metadata,
          $fault: response.statusCode < 500 ? "client" : "server"
        };
        if (!this.errorRegistry) {
          throw new Error("@aws-sdk/core/protocols - error handler not initialized.");
        }
        try {
          const errorSchema = getErrorSchema?.(this.errorRegistry, errorName) ?? this.errorRegistry.getSchema(errorIdentifier);
          return { errorSchema, errorMetadata };
        } catch (e32) {
          dataObject.message = dataObject.message ?? dataObject.Message ?? "UnknownError";
          const synthetic = this.errorRegistry;
          const baseExceptionSchema = synthetic.getBaseException();
          if (baseExceptionSchema) {
            const ErrorCtor = synthetic.getErrorCtor(baseExceptionSchema) ?? Error;
            throw this.decorateServiceException(Object.assign(new ErrorCtor({ name: errorName }), errorMetadata), dataObject);
          }
          const d32 = dataObject;
          const message2 = d32?.message ?? d32?.Message ?? d32?.Error?.Message ?? d32?.Error?.message;
          throw this.decorateServiceException(Object.assign(new Error(message2), {
            name: errorName
          }, errorMetadata), dataObject);
        }
      }
      compose(composite, errorIdentifier, defaultNamespace) {
        let namespace = defaultNamespace;
        if (errorIdentifier.includes("#")) {
          [namespace] = errorIdentifier.split("#");
        }
        const staticRegistry = TypeRegistry.for(namespace);
        const defaultSyntheticRegistry = TypeRegistry.for("smithy.ts.sdk.synthetic." + defaultNamespace);
        composite.copyFrom(staticRegistry);
        composite.copyFrom(defaultSyntheticRegistry);
        this.errorRegistry = composite;
      }
      decorateServiceException(exception, additions = {}) {
        if (this.queryCompat) {
          const msg = exception.Message ?? additions.Message;
          const error4 = (0, import_smithy_client101.decorateServiceException)(exception, additions);
          if (msg) {
            error4.message = msg;
          }
          const errorObj = error4.Error ?? {};
          errorObj.Type = error4.Error?.Type;
          errorObj.Code = error4.Error?.Code;
          errorObj.Message = error4.Error?.message ?? error4.Error?.Message ?? msg;
          error4.Error = errorObj;
          const reqId = error4.$metadata.requestId;
          if (reqId) {
            error4.RequestId = reqId;
          }
          return error4;
        }
        return (0, import_smithy_client101.decorateServiceException)(exception, additions);
      }
      setQueryCompatError(output, response) {
        const queryErrorHeader = response.headers?.["x-amzn-query-error"];
        if (output !== void 0 && queryErrorHeader != null) {
          const [Code, Type] = queryErrorHeader.split(";");
          const keys = Object.keys(output);
          const Error2 = {
            Code,
            Type
          };
          output.Code = Code;
          output.Type = Type;
          for (let i32 = 0; i32 < keys.length; i32++) {
            const k32 = keys[i32];
            Error2[k32 === "message" ? "Message" : k32] = output[k32];
          }
          delete Error2.__type;
          output.Error = Error2;
        }
      }
      queryCompatOutput(queryCompatErrorData, errorData) {
        if (queryCompatErrorData.Error) {
          errorData.Error = queryCompatErrorData.Error;
        }
        if (queryCompatErrorData.Type) {
          errorData.Type = queryCompatErrorData.Type;
        }
        if (queryCompatErrorData.Code) {
          errorData.Code = queryCompatErrorData.Code;
        }
      }
      findQueryCompatibleError(registry, errorName) {
        try {
          return registry.getSchema(errorName);
        } catch (e32) {
          return registry.find((schema) => NormalizedSchema.of(schema).getMergedTraits().awsQueryError?.[0] === errorName);
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/cbor/AwsSmithyRpcV2CborProtocol.js
var AwsSmithyRpcV2CborProtocol4;
var init_AwsSmithyRpcV2CborProtocol6 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/cbor/AwsSmithyRpcV2CborProtocol.js"() {
    init_cbor2();
    init_schema4();
    init_ProtocolLib6();
    AwsSmithyRpcV2CborProtocol4 = class extends SmithyRpcV2CborProtocol {
      static {
        __name(this, "AwsSmithyRpcV2CborProtocol");
      }
      awsQueryCompatible;
      mixin;
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, awsQueryCompatible }) {
        super({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32 });
        this.awsQueryCompatible = !!awsQueryCompatible;
        this.mixin = new ProtocolLib6(this.awsQueryCompatible);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        if (this.awsQueryCompatible) {
          request4.headers["x-amzn-query-mode"] = "true";
        }
        return request4;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        if (this.awsQueryCompatible) {
          this.mixin.setQueryCompatError(dataObject, response);
        }
        const errorName = (() => {
          const compatHeader = response.headers["x-amzn-query-error"];
          if (compatHeader && this.awsQueryCompatible) {
            return compatHeader.split(";")[0];
          }
          return loadSmithyRpcV2CborErrorCode(response, dataObject) ?? "Unknown";
        })();
        this.mixin.compose(this.compositeErrorRegistry, errorName, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorName, this.options.defaultNamespace, response, dataObject, metadata, this.awsQueryCompatible ? this.mixin.findQueryCompatibleError : void 0);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        const output = {};
        for (const [name, member7] of ns.structIterator()) {
          if (dataObject[name] != null) {
            output[name] = this.deserializer.readValue(member7, dataObject[name]);
          }
        }
        if (this.awsQueryCompatible) {
          this.mixin.queryCompatOutput(dataObject, output);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/coercing-serializers.js
var _toStr4, _toBool4, _toNum4;
var init_coercing_serializers6 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/coercing-serializers.js"() {
    _toStr4 = /* @__PURE__ */ __name((val) => {
      if (val == null) {
        return val;
      }
      if (typeof val === "number" || typeof val === "bigint") {
        const warning2 = new Error(`Received number ${val} where a string was expected.`);
        warning2.name = "Warning";
        console.warn(warning2);
        return String(val);
      }
      if (typeof val === "boolean") {
        const warning2 = new Error(`Received boolean ${val} where a string was expected.`);
        warning2.name = "Warning";
        console.warn(warning2);
        return String(val);
      }
      return val;
    }, "_toStr");
    _toBool4 = /* @__PURE__ */ __name((val) => {
      if (val == null) {
        return val;
      }
      if (typeof val === "number") {
      }
      if (typeof val === "string") {
        const lowercase = val.toLowerCase();
        if (val !== "" && lowercase !== "false" && lowercase !== "true") {
          const warning2 = new Error(`Received string "${val}" where a boolean was expected.`);
          warning2.name = "Warning";
          console.warn(warning2);
        }
        return val !== "" && lowercase !== "false";
      }
      return val;
    }, "_toBool");
    _toNum4 = /* @__PURE__ */ __name((val) => {
      if (val == null) {
        return val;
      }
      if (typeof val === "boolean") {
      }
      if (typeof val === "string") {
        const num = Number(val);
        if (num.toString() !== val) {
          const warning2 = new Error(`Received string "${val}" where a number was expected.`);
          warning2.name = "Warning";
          console.warn(warning2);
          return val;
        }
        return num;
      }
      return val;
    }, "_toNum");
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/ConfigurableSerdeContext.js
var SerdeContextConfig6;
var init_ConfigurableSerdeContext6 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/ConfigurableSerdeContext.js"() {
    SerdeContextConfig6 = class {
      static {
        __name(this, "SerdeContextConfig");
      }
      serdeContext;
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/UnionSerde.js
var UnionSerde6;
var init_UnionSerde6 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/UnionSerde.js"() {
    UnionSerde6 = class {
      static {
        __name(this, "UnionSerde");
      }
      from;
      to;
      keys;
      constructor(from, to) {
        this.from = from;
        this.to = to;
        const keys = Object.keys(this.from);
        const set = new Set(keys);
        set.delete("__type");
        this.keys = set;
      }
      mark(key) {
        this.keys.delete(key);
      }
      hasUnknown() {
        return this.keys.size === 1 && Object.keys(this.to).length === 0;
      }
      writeUnknown() {
        if (this.hasUnknown()) {
          const k32 = this.keys.values().next().value;
          const v = this.from[k32];
          this.to.$unknown = [k32, v];
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReviver.js
function jsonReviver6(key, value, context) {
  if (context?.source) {
    const numericString = context.source;
    if (typeof value === "number") {
      if (value > Number.MAX_SAFE_INTEGER || value < Number.MIN_SAFE_INTEGER || numericString !== String(value)) {
        const isFractional = numericString.includes(".");
        if (isFractional) {
          return new NumericValue(numericString, "bigDecimal");
        } else {
          return BigInt(numericString);
        }
      }
    }
  }
  return value;
}
var init_jsonReviver6 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReviver.js"() {
    init_serde();
    __name(jsonReviver6, "jsonReviver");
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/common.js
var import_smithy_client102, import_util_utf825, collectBodyString6;
var init_common7 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/common.js"() {
    import_smithy_client102 = __toESM(require_dist_cjs34());
    import_util_utf825 = __toESM(require_dist_cjs9());
    collectBodyString6 = /* @__PURE__ */ __name((streamBody, context) => (0, import_smithy_client102.collectBody)(streamBody, context).then((body) => (context?.utf8Encoder ?? import_util_utf825.toUtf8)(body)), "collectBodyString");
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/parseJsonBody.js
var parseJsonBody6, parseJsonErrorBody4, findKey6, sanitizeErrorCode6, loadRestJsonErrorCode6;
var init_parseJsonBody6 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/parseJsonBody.js"() {
    init_common7();
    parseJsonBody6 = /* @__PURE__ */ __name((streamBody, context) => collectBodyString6(streamBody, context).then((encoded) => {
      if (encoded.length) {
        try {
          return JSON.parse(encoded);
        } catch (e32) {
          if (e32?.name === "SyntaxError") {
            Object.defineProperty(e32, "$responseBodyText", {
              value: encoded
            });
          }
          throw e32;
        }
      }
      return {};
    }), "parseJsonBody");
    parseJsonErrorBody4 = /* @__PURE__ */ __name(async (errorBody, context) => {
      const value = await parseJsonBody6(errorBody, context);
      value.message = value.message ?? value.Message;
      return value;
    }, "parseJsonErrorBody");
    findKey6 = /* @__PURE__ */ __name((object, key) => Object.keys(object).find((k32) => k32.toLowerCase() === key.toLowerCase()), "findKey");
    sanitizeErrorCode6 = /* @__PURE__ */ __name((rawValue) => {
      let cleanValue = rawValue;
      if (typeof cleanValue === "number") {
        cleanValue = cleanValue.toString();
      }
      if (cleanValue.indexOf(",") >= 0) {
        cleanValue = cleanValue.split(",")[0];
      }
      if (cleanValue.indexOf(":") >= 0) {
        cleanValue = cleanValue.split(":")[0];
      }
      if (cleanValue.indexOf("#") >= 0) {
        cleanValue = cleanValue.split("#")[1];
      }
      return cleanValue;
    }, "sanitizeErrorCode");
    loadRestJsonErrorCode6 = /* @__PURE__ */ __name((output, data3) => {
      const headerKey = findKey6(output.headers, "x-amzn-errortype");
      if (headerKey !== void 0) {
        return sanitizeErrorCode6(output.headers[headerKey]);
      }
      if (data3 && typeof data3 === "object") {
        const codeKey = findKey6(data3, "code");
        if (codeKey && data3[codeKey] !== void 0) {
          return sanitizeErrorCode6(data3[codeKey]);
        }
        if (data3["__type"] !== void 0) {
          return sanitizeErrorCode6(data3["__type"]);
        }
      }
    }, "loadRestJsonErrorCode");
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeDeserializer.js
var import_util_base6431, JsonShapeDeserializer6;
var init_JsonShapeDeserializer6 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeDeserializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_util_base6431 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext6();
    init_UnionSerde6();
    init_jsonReviver6();
    init_parseJsonBody6();
    JsonShapeDeserializer6 = class extends SerdeContextConfig6 {
      static {
        __name(this, "JsonShapeDeserializer");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      async read(schema, data3) {
        return this._read(schema, typeof data3 === "string" ? JSON.parse(data3, jsonReviver6) : await parseJsonBody6(data3, this.serdeContext));
      }
      readObject(schema, data3) {
        return this._read(schema, data3);
      }
      _read(schema, value) {
        const isObject3 = value !== null && typeof value === "object";
        const ns = NormalizedSchema.of(schema);
        if (isObject3) {
          if (ns.isStructSchema()) {
            const record = value;
            const union = ns.isUnionSchema();
            const out = {};
            let nameMap = void 0;
            const { jsonName } = this.settings;
            if (jsonName) {
              nameMap = {};
            }
            let unionSerde;
            if (union) {
              unionSerde = new UnionSerde6(record, out);
            }
            for (const [memberName, memberSchema] of ns.structIterator()) {
              let fromKey = memberName;
              if (jsonName) {
                fromKey = memberSchema.getMergedTraits().jsonName ?? fromKey;
                nameMap[fromKey] = memberName;
              }
              if (union) {
                unionSerde.mark(fromKey);
              }
              if (record[fromKey] != null) {
                out[memberName] = this._read(memberSchema, record[fromKey]);
              }
            }
            if (union) {
              unionSerde.writeUnknown();
            } else if (typeof record.__type === "string") {
              for (const k32 in record) {
                const v = record[k32];
                const t = jsonName ? nameMap[k32] ?? k32 : k32;
                if (!(t in out)) {
                  out[t] = v;
                }
              }
            }
            return out;
          }
          if (Array.isArray(value) && ns.isListSchema()) {
            const listMember = ns.getValueSchema();
            const out = [];
            for (const item of value) {
              out.push(this._read(listMember, item));
            }
            return out;
          }
          if (ns.isMapSchema()) {
            const mapMember = ns.getValueSchema();
            const out = {};
            for (const _k in value) {
              out[_k] = this._read(mapMember, value[_k]);
            }
            return out;
          }
        }
        if (ns.isBlobSchema() && typeof value === "string") {
          return (0, import_util_base6431.fromBase64)(value);
        }
        const mediaType = ns.getMergedTraits().mediaType;
        if (ns.isStringSchema() && typeof value === "string" && mediaType) {
          const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
          if (isJson) {
            return LazyJsonString.from(value);
          }
          return value;
        }
        if (ns.isTimestampSchema() && value != null) {
          const format32 = determineTimestampFormat(ns, this.settings);
          switch (format32) {
            case 5:
              return parseRfc3339DateTimeWithOffset(value);
            case 6:
              return parseRfc7231DateTime(value);
            case 7:
              return parseEpochTimestamp(value);
            default:
              console.warn("Missing timestamp format, parsing value with Date constructor:", value);
              return new Date(value);
          }
        }
        if (ns.isBigIntegerSchema() && (typeof value === "number" || typeof value === "string")) {
          return BigInt(value);
        }
        if (ns.isBigDecimalSchema() && value != void 0) {
          if (value instanceof NumericValue) {
            return value;
          }
          const untyped = value;
          if (untyped.type === "bigDecimal" && "string" in untyped) {
            return new NumericValue(untyped.string, untyped.type);
          }
          return new NumericValue(String(value), "bigDecimal");
        }
        if (ns.isNumericSchema() && typeof value === "string") {
          switch (value) {
            case "Infinity":
              return Infinity;
            case "-Infinity":
              return -Infinity;
            case "NaN":
              return NaN;
          }
          return value;
        }
        if (ns.isDocumentSchema()) {
          if (isObject3) {
            const out = Array.isArray(value) ? [] : {};
            for (const k32 in value) {
              const v = value[k32];
              if (v instanceof NumericValue) {
                out[k32] = v;
              } else {
                out[k32] = this._read(ns, v);
              }
            }
            return out;
          } else {
            return structuredClone(value);
          }
        }
        return value;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReplacer.js
var NUMERIC_CONTROL_CHAR6, JsonReplacer6;
var init_jsonReplacer6 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReplacer.js"() {
    init_serde();
    NUMERIC_CONTROL_CHAR6 = String.fromCharCode(925);
    JsonReplacer6 = class {
      static {
        __name(this, "JsonReplacer");
      }
      values = /* @__PURE__ */ new Map();
      counter = 0;
      stage = 0;
      createReplacer() {
        if (this.stage === 1) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer already created.");
        }
        if (this.stage === 2) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer exhausted.");
        }
        this.stage = 1;
        return (key, value) => {
          if (value instanceof NumericValue) {
            const v = `${NUMERIC_CONTROL_CHAR6 + "nv" + this.counter++}_` + value.string;
            this.values.set(`"${v}"`, value.string);
            return v;
          }
          if (typeof value === "bigint") {
            const s = value.toString();
            const v = `${NUMERIC_CONTROL_CHAR6 + "b" + this.counter++}_` + s;
            this.values.set(`"${v}"`, s);
            return v;
          }
          return value;
        };
      }
      replaceInJson(json) {
        if (this.stage === 0) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer not created yet.");
        }
        if (this.stage === 2) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer exhausted.");
        }
        this.stage = 2;
        if (this.counter === 0) {
          return json;
        }
        for (const [key, value] of this.values) {
          json = json.replace(key, value);
        }
        return json;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeSerializer.js
var import_util_base6432, JsonShapeSerializer6;
var init_JsonShapeSerializer6 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeSerializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_util_base6432 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext6();
    init_jsonReplacer6();
    JsonShapeSerializer6 = class extends SerdeContextConfig6 {
      static {
        __name(this, "JsonShapeSerializer");
      }
      settings;
      buffer;
      useReplacer = false;
      rootSchema;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value) {
        this.rootSchema = NormalizedSchema.of(schema);
        this.buffer = this._write(this.rootSchema, value);
      }
      flush() {
        const { rootSchema, useReplacer } = this;
        this.rootSchema = void 0;
        this.useReplacer = false;
        if (rootSchema?.isStructSchema() || rootSchema?.isDocumentSchema()) {
          if (!useReplacer) {
            return JSON.stringify(this.buffer);
          }
          const replacer = new JsonReplacer6();
          return replacer.replaceInJson(JSON.stringify(this.buffer, replacer.createReplacer(), 0));
        }
        return this.buffer;
      }
      writeDiscriminatedDocument(schema, value) {
        this.write(schema, value);
        if (typeof this.buffer === "object") {
          this.buffer.__type = NormalizedSchema.of(schema).getName(true);
        }
      }
      _write(schema, value, container) {
        const isObject3 = value !== null && typeof value === "object";
        const ns = NormalizedSchema.of(schema);
        if (isObject3) {
          if (ns.isStructSchema()) {
            const record = value;
            const out = {};
            const { jsonName } = this.settings;
            let nameMap = void 0;
            if (jsonName) {
              nameMap = {};
            }
            let outCount = 0;
            for (const [memberName, memberSchema] of ns.structIterator()) {
              const serializableValue = this._write(memberSchema, record[memberName], ns);
              if (serializableValue !== void 0) {
                let targetKey = memberName;
                if (jsonName) {
                  targetKey = memberSchema.getMergedTraits().jsonName ?? memberName;
                  nameMap[memberName] = targetKey;
                }
                out[targetKey] = serializableValue;
                outCount++;
              }
            }
            if (ns.isUnionSchema() && outCount === 0) {
              const { $unknown } = record;
              if (Array.isArray($unknown)) {
                const [k32, v] = $unknown;
                out[k32] = this._write(15, v);
              }
            } else if (typeof record.__type === "string") {
              for (const k32 in record) {
                const v = record[k32];
                const targetKey = jsonName ? nameMap[k32] ?? k32 : k32;
                if (!(targetKey in out)) {
                  out[targetKey] = this._write(15, v);
                }
              }
            }
            return out;
          }
          if (Array.isArray(value) && ns.isListSchema()) {
            const listMember = ns.getValueSchema();
            const out = [];
            const sparse = !!ns.getMergedTraits().sparse;
            for (const item of value) {
              if (sparse || item != null) {
                out.push(this._write(listMember, item));
              }
            }
            return out;
          }
          if (ns.isMapSchema()) {
            const mapMember = ns.getValueSchema();
            const out = {};
            const sparse = !!ns.getMergedTraits().sparse;
            for (const _k in value) {
              const _v = value[_k];
              if (sparse || _v != null) {
                out[_k] = this._write(mapMember, _v);
              }
            }
            return out;
          }
          if (value instanceof Uint8Array && (ns.isBlobSchema() || ns.isDocumentSchema())) {
            if (ns === this.rootSchema) {
              return value;
            }
            return (this.serdeContext?.base64Encoder ?? import_util_base6432.toBase64)(value);
          }
          if (value instanceof Date && (ns.isTimestampSchema() || ns.isDocumentSchema())) {
            const format32 = determineTimestampFormat(ns, this.settings);
            switch (format32) {
              case 5:
                return value.toISOString().replace(".000Z", "Z");
              case 6:
                return dateToUtcString(value);
              case 7:
                return value.getTime() / 1e3;
              default:
                console.warn("Missing timestamp format, using epoch seconds", value);
                return value.getTime() / 1e3;
            }
          }
          if (value instanceof NumericValue) {
            this.useReplacer = true;
          }
        }
        if (value === null && container?.isStructSchema()) {
          return void 0;
        }
        if (ns.isStringSchema()) {
          if (typeof value === "undefined" && ns.isIdempotencyToken()) {
            return (0, import_uuid.v4)();
          }
          const mediaType = ns.getMergedTraits().mediaType;
          if (value != null && mediaType) {
            const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
            if (isJson) {
              return LazyJsonString.from(value);
            }
          }
          return value;
        }
        if (typeof value === "number" && ns.isNumericSchema()) {
          if (Math.abs(value) === Infinity || isNaN(value)) {
            return String(value);
          }
          return value;
        }
        if (typeof value === "string" && ns.isBlobSchema()) {
          if (ns === this.rootSchema) {
            return value;
          }
          return (this.serdeContext?.base64Encoder ?? import_util_base6432.toBase64)(value);
        }
        if (typeof value === "bigint") {
          this.useReplacer = true;
        }
        if (ns.isDocumentSchema()) {
          if (isObject3) {
            const out = Array.isArray(value) ? [] : {};
            for (const k32 in value) {
              const v = value[k32];
              if (v instanceof NumericValue) {
                this.useReplacer = true;
                out[k32] = v;
              } else {
                out[k32] = this._write(ns, v);
              }
            }
            return out;
          } else {
            return structuredClone(value);
          }
        }
        return value;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonCodec.js
var JsonCodec6;
var init_JsonCodec6 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonCodec.js"() {
    init_ConfigurableSerdeContext6();
    init_JsonShapeDeserializer6();
    init_JsonShapeSerializer6();
    JsonCodec6 = class extends SerdeContextConfig6 {
      static {
        __name(this, "JsonCodec");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      createSerializer() {
        const serializer = new JsonShapeSerializer6(this.settings);
        serializer.setSerdeContext(this.serdeContext);
        return serializer;
      }
      createDeserializer() {
        const deserializer = new JsonShapeDeserializer6(this.settings);
        deserializer.setSerdeContext(this.serdeContext);
        return deserializer;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJsonRpcProtocol.js
var AwsJsonRpcProtocol4;
var init_AwsJsonRpcProtocol6 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJsonRpcProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib6();
    init_JsonCodec6();
    init_parseJsonBody6();
    AwsJsonRpcProtocol4 = class extends RpcProtocol {
      static {
        __name(this, "AwsJsonRpcProtocol");
      }
      serializer;
      deserializer;
      serviceTarget;
      codec;
      mixin;
      awsQueryCompatible;
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, serviceTarget, awsQueryCompatible, jsonCodec }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32
        });
        this.serviceTarget = serviceTarget;
        this.codec = jsonCodec ?? new JsonCodec6({
          timestampFormat: {
            useTrait: true,
            default: 7
          },
          jsonName: false
        });
        this.serializer = this.codec.createSerializer();
        this.deserializer = this.codec.createDeserializer();
        this.awsQueryCompatible = !!awsQueryCompatible;
        this.mixin = new ProtocolLib6(this.awsQueryCompatible);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        if (!request4.path.endsWith("/")) {
          request4.path += "/";
        }
        request4.headers["content-type"] = `application/x-amz-json-${this.getJsonRpcVersion()}`;
        request4.headers["x-amz-target"] = `${this.serviceTarget}.${operationSchema.name}`;
        if (this.awsQueryCompatible) {
          request4.headers["x-amzn-query-mode"] = "true";
        }
        if (deref(operationSchema.input) === "unit" || !request4.body) {
          request4.body = "{}";
        }
        return request4;
      }
      getPayloadCodec() {
        return this.codec;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        if (this.awsQueryCompatible) {
          this.mixin.setQueryCompatError(dataObject, response);
        }
        const errorIdentifier = loadRestJsonErrorCode6(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata, this.awsQueryCompatible ? this.mixin.findQueryCompatibleError : void 0);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          if (dataObject[name] != null) {
            output[name] = errorDeserializer.readObject(member7, dataObject[name]);
          }
        }
        if (this.awsQueryCompatible) {
          this.mixin.queryCompatOutput(dataObject, output);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_0Protocol.js
var AwsJson1_0Protocol4;
var init_AwsJson1_0Protocol6 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_0Protocol.js"() {
    init_AwsJsonRpcProtocol6();
    AwsJson1_0Protocol4 = class extends AwsJsonRpcProtocol4 {
      static {
        __name(this, "AwsJson1_0Protocol");
      }
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, serviceTarget, awsQueryCompatible, jsonCodec }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32,
          serviceTarget,
          awsQueryCompatible,
          jsonCodec
        });
      }
      getShapeId() {
        return "aws.protocols#awsJson1_0";
      }
      getJsonRpcVersion() {
        return "1.0";
      }
      getDefaultContentType() {
        return "application/x-amz-json-1.0";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_1Protocol.js
var AwsJson1_1Protocol4;
var init_AwsJson1_1Protocol6 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_1Protocol.js"() {
    init_AwsJsonRpcProtocol6();
    AwsJson1_1Protocol4 = class extends AwsJsonRpcProtocol4 {
      static {
        __name(this, "AwsJson1_1Protocol");
      }
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, serviceTarget, awsQueryCompatible, jsonCodec }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32,
          serviceTarget,
          awsQueryCompatible,
          jsonCodec
        });
      }
      getShapeId() {
        return "aws.protocols#awsJson1_1";
      }
      getJsonRpcVersion() {
        return "1.1";
      }
      getDefaultContentType() {
        return "application/x-amz-json-1.1";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsRestJsonProtocol.js
var AwsRestJsonProtocol6;
var init_AwsRestJsonProtocol6 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsRestJsonProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib6();
    init_JsonCodec6();
    init_parseJsonBody6();
    AwsRestJsonProtocol6 = class extends HttpBindingProtocol {
      static {
        __name(this, "AwsRestJsonProtocol");
      }
      serializer;
      deserializer;
      codec;
      mixin = new ProtocolLib6();
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32 }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32
        });
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 7
          },
          httpBindings: true,
          jsonName: true
        };
        this.codec = new JsonCodec6(settings);
        this.serializer = new HttpInterceptingShapeSerializer(this.codec.createSerializer(), settings);
        this.deserializer = new HttpInterceptingShapeDeserializer(this.codec.createDeserializer(), settings);
      }
      getShapeId() {
        return "aws.protocols#restJson1";
      }
      getPayloadCodec() {
        return this.codec;
      }
      setSerdeContext(serdeContext) {
        this.codec.setSerdeContext(serdeContext);
        super.setSerdeContext(serdeContext);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        const inputSchema = NormalizedSchema.of(operationSchema.input);
        if (!request4.headers["content-type"]) {
          const contentType = this.mixin.resolveRestContentType(this.getDefaultContentType(), inputSchema);
          if (contentType) {
            request4.headers["content-type"] = contentType;
          }
        }
        if (request4.body == null && request4.headers["content-type"] === this.getDefaultContentType()) {
          request4.body = "{}";
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        const output = await super.deserializeResponse(operationSchema, context, response);
        const outputSchema = NormalizedSchema.of(operationSchema.output);
        for (const [name, member7] of outputSchema.structIterator()) {
          if (member7.getMemberTraits().httpPayload && !(name in output)) {
            output[name] = null;
          }
        }
        return output;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = loadRestJsonErrorCode6(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        await this.deserializeHttpMessage(errorSchema, context, response, dataObject);
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().jsonName ?? name;
          output[name] = errorDeserializer.readObject(member7, dataObject[target]);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      getDefaultContentType() {
        return "application/json";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/awsExpectUnion.js
var import_smithy_client103, awsExpectUnion4;
var init_awsExpectUnion6 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/awsExpectUnion.js"() {
    import_smithy_client103 = __toESM(require_dist_cjs34());
    awsExpectUnion4 = /* @__PURE__ */ __name((value) => {
      if (value == null) {
        return void 0;
      }
      if (typeof value === "object" && "__type" in value) {
        delete value.__type;
      }
      return (0, import_smithy_client103.expectUnion)(value);
    }, "awsExpectUnion");
  }
});

// ../../node_modules/@aws-sdk/core/node_modules/fast-xml-parser/lib/fxp.cjs
var require_fxp2 = __commonJS({
  "../../node_modules/@aws-sdk/core/node_modules/fast-xml-parser/lib/fxp.cjs"(exports2, module2) {
    (() => {
      "use strict";
      var t = { d: /* @__PURE__ */ __name((e33, n11) => {
        for (var i33 in n11) t.o(n11, i33) && !t.o(e33, i33) && Object.defineProperty(e33, i33, { enumerable: true, get: n11[i33] });
      }, "d"), o: /* @__PURE__ */ __name((t2, e33) => Object.prototype.hasOwnProperty.call(t2, e33), "o"), r: /* @__PURE__ */ __name((t2) => {
        "undefined" != typeof Symbol && Symbol.toStringTag && Object.defineProperty(t2, Symbol.toStringTag, { value: "Module" }), Object.defineProperty(t2, "__esModule", { value: true });
      }, "r") }, e32 = {};
      t.r(e32), t.d(e32, { XMLBuilder: /* @__PURE__ */ __name(() => Bt, "XMLBuilder"), XMLParser: /* @__PURE__ */ __name(() => Tt, "XMLParser"), XMLValidator: /* @__PURE__ */ __name(() => Ut, "XMLValidator") });
      const n10 = ":A-Za-z_\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD", i32 = new RegExp("^[" + n10 + "][" + n10 + "\\-.\\d\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$");
      function s(t2, e33) {
        const n11 = [];
        let i33 = e33.exec(t2);
        for (; i33; ) {
          const s2 = [];
          s2.startIndex = e33.lastIndex - i33[0].length;
          const r33 = i33.length;
          for (let t3 = 0; t3 < r33; t3++) s2.push(i33[t3]);
          n11.push(s2), i33 = e33.exec(t2);
        }
        return n11;
      }
      __name(s, "s");
      const r32 = /* @__PURE__ */ __name(function(t2) {
        return !(null == i32.exec(t2));
      }, "r"), o10 = ["hasOwnProperty", "toString", "valueOf", "__defineGetter__", "__defineSetter__", "__lookupGetter__", "__lookupSetter__"], a32 = ["__proto__", "constructor", "prototype"], h32 = { allowBooleanAttributes: false, unpairedTags: [] };
      function l20(t2, e33) {
        e33 = Object.assign({}, h32, e33);
        const n11 = [];
        let i33 = false, s2 = false;
        "\uFEFF" === t2[0] && (t2 = t2.substr(1));
        for (let r33 = 0; r33 < t2.length; r33++) if ("<" === t2[r33] && "?" === t2[r33 + 1]) {
          if (r33 += 2, r33 = p10(t2, r33), r33.err) return r33;
        } else {
          if ("<" !== t2[r33]) {
            if (u(t2[r33])) continue;
            return b32("InvalidChar", "char '" + t2[r33] + "' is not expected.", w(t2, r33));
          }
          {
            let o11 = r33;
            if (r33++, "!" === t2[r33]) {
              r33 = c32(t2, r33);
              continue;
            }
            {
              let a33 = false;
              "/" === t2[r33] && (a33 = true, r33++);
              let h33 = "";
              for (; r33 < t2.length && ">" !== t2[r33] && " " !== t2[r33] && "	" !== t2[r33] && "\n" !== t2[r33] && "\r" !== t2[r33]; r33++) h33 += t2[r33];
              if (h33 = h33.trim(), "/" === h33[h33.length - 1] && (h33 = h33.substring(0, h33.length - 1), r33--), !E(h33)) {
                let e34;
                return e34 = 0 === h33.trim().length ? "Invalid space after '<'." : "Tag '" + h33 + "' is an invalid name.", b32("InvalidTag", e34, w(t2, r33));
              }
              const l21 = g32(t2, r33);
              if (false === l21) return b32("InvalidAttr", "Attributes for '" + h33 + "' have open quote.", w(t2, r33));
              let d33 = l21.value;
              if (r33 = l21.index, "/" === d33[d33.length - 1]) {
                const n12 = r33 - d33.length;
                d33 = d33.substring(0, d33.length - 1);
                const s3 = x(d33, e33);
                if (true !== s3) return b32(s3.err.code, s3.err.msg, w(t2, n12 + s3.err.line));
                i33 = true;
              } else if (a33) {
                if (!l21.tagClosed) return b32("InvalidTag", "Closing tag '" + h33 + "' doesn't have proper closing.", w(t2, r33));
                if (d33.trim().length > 0) return b32("InvalidTag", "Closing tag '" + h33 + "' can't have attributes or invalid starting.", w(t2, o11));
                if (0 === n11.length) return b32("InvalidTag", "Closing tag '" + h33 + "' has not been opened.", w(t2, o11));
                {
                  const e34 = n11.pop();
                  if (h33 !== e34.tagName) {
                    let n12 = w(t2, e34.tagStartPos);
                    return b32("InvalidTag", "Expected closing tag '" + e34.tagName + "' (opened in line " + n12.line + ", col " + n12.col + ") instead of closing tag '" + h33 + "'.", w(t2, o11));
                  }
                  0 == n11.length && (s2 = true);
                }
              } else {
                const a34 = x(d33, e33);
                if (true !== a34) return b32(a34.err.code, a34.err.msg, w(t2, r33 - d33.length + a34.err.line));
                if (true === s2) return b32("InvalidXml", "Multiple possible root nodes found.", w(t2, r33));
                -1 !== e33.unpairedTags.indexOf(h33) || n11.push({ tagName: h33, tagStartPos: o11 }), i33 = true;
              }
              for (r33++; r33 < t2.length; r33++) if ("<" === t2[r33]) {
                if ("!" === t2[r33 + 1]) {
                  r33++, r33 = c32(t2, r33);
                  continue;
                }
                if ("?" !== t2[r33 + 1]) break;
                if (r33 = p10(t2, ++r33), r33.err) return r33;
              } else if ("&" === t2[r33]) {
                const e34 = N(t2, r33);
                if (-1 == e34) return b32("InvalidChar", "char '&' is not expected.", w(t2, r33));
                r33 = e34;
              } else if (true === s2 && !u(t2[r33])) return b32("InvalidXml", "Extra text at the end", w(t2, r33));
              "<" === t2[r33] && r33--;
            }
          }
        }
        return i33 ? 1 == n11.length ? b32("InvalidTag", "Unclosed tag '" + n11[0].tagName + "'.", w(t2, n11[0].tagStartPos)) : !(n11.length > 0) || b32("InvalidXml", "Invalid '" + JSON.stringify(n11.map((t3) => t3.tagName), null, 4).replace(/\r?\n/g, "") + "' found.", { line: 1, col: 1 }) : b32("InvalidXml", "Start tag expected.", 1);
      }
      __name(l20, "l");
      function u(t2) {
        return " " === t2 || "	" === t2 || "\n" === t2 || "\r" === t2;
      }
      __name(u, "u");
      function p10(t2, e33) {
        const n11 = e33;
        for (; e33 < t2.length; e33++) if ("?" == t2[e33] || " " == t2[e33]) {
          const i33 = t2.substr(n11, e33 - n11);
          if (e33 > 5 && "xml" === i33) return b32("InvalidXml", "XML declaration allowed only at the start of the document.", w(t2, e33));
          if ("?" == t2[e33] && ">" == t2[e33 + 1]) {
            e33++;
            break;
          }
          continue;
        }
        return e33;
      }
      __name(p10, "p");
      function c32(t2, e33) {
        if (t2.length > e33 + 5 && "-" === t2[e33 + 1] && "-" === t2[e33 + 2]) {
          for (e33 += 3; e33 < t2.length; e33++) if ("-" === t2[e33] && "-" === t2[e33 + 1] && ">" === t2[e33 + 2]) {
            e33 += 2;
            break;
          }
        } else if (t2.length > e33 + 8 && "D" === t2[e33 + 1] && "O" === t2[e33 + 2] && "C" === t2[e33 + 3] && "T" === t2[e33 + 4] && "Y" === t2[e33 + 5] && "P" === t2[e33 + 6] && "E" === t2[e33 + 7]) {
          let n11 = 1;
          for (e33 += 8; e33 < t2.length; e33++) if ("<" === t2[e33]) n11++;
          else if (">" === t2[e33] && (n11--, 0 === n11)) break;
        } else if (t2.length > e33 + 9 && "[" === t2[e33 + 1] && "C" === t2[e33 + 2] && "D" === t2[e33 + 3] && "A" === t2[e33 + 4] && "T" === t2[e33 + 5] && "A" === t2[e33 + 6] && "[" === t2[e33 + 7]) {
          for (e33 += 8; e33 < t2.length; e33++) if ("]" === t2[e33] && "]" === t2[e33 + 1] && ">" === t2[e33 + 2]) {
            e33 += 2;
            break;
          }
        }
        return e33;
      }
      __name(c32, "c");
      const d32 = '"', f32 = "'";
      function g32(t2, e33) {
        let n11 = "", i33 = "", s2 = false;
        for (; e33 < t2.length; e33++) {
          if (t2[e33] === d32 || t2[e33] === f32) "" === i33 ? i33 = t2[e33] : i33 !== t2[e33] || (i33 = "");
          else if (">" === t2[e33] && "" === i33) {
            s2 = true;
            break;
          }
          n11 += t2[e33];
        }
        return "" === i33 && { value: n11, index: e33, tagClosed: s2 };
      }
      __name(g32, "g");
      const m20 = new RegExp(`(\\s*)([^\\s=]+)(\\s*=)?(\\s*(['"])(([\\s\\S])*?)\\5)?`, "g");
      function x(t2, e33) {
        const n11 = s(t2, m20), i33 = {};
        for (let t3 = 0; t3 < n11.length; t3++) {
          if (0 === n11[t3][1].length) return b32("InvalidAttr", "Attribute '" + n11[t3][2] + "' has no space in starting.", v(n11[t3]));
          if (void 0 !== n11[t3][3] && void 0 === n11[t3][4]) return b32("InvalidAttr", "Attribute '" + n11[t3][2] + "' is without value.", v(n11[t3]));
          if (void 0 === n11[t3][3] && !e33.allowBooleanAttributes) return b32("InvalidAttr", "boolean attribute '" + n11[t3][2] + "' is not allowed.", v(n11[t3]));
          const s2 = n11[t3][2];
          if (!y(s2)) return b32("InvalidAttr", "Attribute '" + s2 + "' is an invalid name.", v(n11[t3]));
          if (Object.prototype.hasOwnProperty.call(i33, s2)) return b32("InvalidAttr", "Attribute '" + s2 + "' is repeated.", v(n11[t3]));
          i33[s2] = 1;
        }
        return true;
      }
      __name(x, "x");
      function N(t2, e33) {
        if (";" === t2[++e33]) return -1;
        if ("#" === t2[e33]) return (function(t3, e34) {
          let n12 = /\d/;
          for ("x" === t3[e34] && (e34++, n12 = /[\da-fA-F]/); e34 < t3.length; e34++) {
            if (";" === t3[e34]) return e34;
            if (!t3[e34].match(n12)) break;
          }
          return -1;
        })(t2, ++e33);
        let n11 = 0;
        for (; e33 < t2.length; e33++, n11++) if (!(t2[e33].match(/\w/) && n11 < 20)) {
          if (";" === t2[e33]) break;
          return -1;
        }
        return e33;
      }
      __name(N, "N");
      function b32(t2, e33, n11) {
        return { err: { code: t2, msg: e33, line: n11.line || n11, col: n11.col } };
      }
      __name(b32, "b");
      function y(t2) {
        return r32(t2);
      }
      __name(y, "y");
      function E(t2) {
        return r32(t2);
      }
      __name(E, "E");
      function w(t2, e33) {
        const n11 = t2.substring(0, e33).split(/\r?\n/);
        return { line: n11.length, col: n11[n11.length - 1].length + 1 };
      }
      __name(w, "w");
      function v(t2) {
        return t2.startIndex + t2[1].length;
      }
      __name(v, "v");
      const S = /* @__PURE__ */ __name((t2) => o10.includes(t2) ? "__" + t2 : t2, "S"), _ = { preserveOrder: false, attributeNamePrefix: "@_", attributesGroupName: false, textNodeName: "#text", ignoreAttributes: true, removeNSPrefix: false, allowBooleanAttributes: false, parseTagValue: true, parseAttributeValue: false, trimValues: true, cdataPropName: false, numberParseOptions: { hex: true, leadingZeros: true, eNotation: true }, tagValueProcessor: /* @__PURE__ */ __name(function(t2, e33) {
        return e33;
      }, "tagValueProcessor"), attributeValueProcessor: /* @__PURE__ */ __name(function(t2, e33) {
        return e33;
      }, "attributeValueProcessor"), stopNodes: [], alwaysCreateTextNode: false, isArray: /* @__PURE__ */ __name(() => false, "isArray"), commentPropName: false, unpairedTags: [], processEntities: true, htmlEntities: false, entityDecoder: null, ignoreDeclaration: false, ignorePiTags: false, transformTagName: false, transformAttributeName: false, updateTag: /* @__PURE__ */ __name(function(t2, e33, n11) {
        return t2;
      }, "updateTag"), captureMetaData: false, maxNestedTags: 100, strictReservedNames: true, jPath: true, onDangerousProperty: S };
      function A(t2, e33) {
        if ("string" != typeof t2) return;
        const n11 = t2.toLowerCase();
        if (o10.some((t3) => n11 === t3.toLowerCase())) throw new Error(`[SECURITY] Invalid ${e33}: "${t2}" is a reserved JavaScript keyword that could cause prototype pollution`);
        if (a32.some((t3) => n11 === t3.toLowerCase())) throw new Error(`[SECURITY] Invalid ${e33}: "${t2}" is a reserved JavaScript keyword that could cause prototype pollution`);
      }
      __name(A, "A");
      function T(t2, e33) {
        return "boolean" == typeof t2 ? { enabled: t2, maxEntitySize: 1e4, maxExpansionDepth: 1e4, maxTotalExpansions: 1 / 0, maxExpandedLength: 1e5, maxEntityCount: 1e3, allowedTags: null, tagFilter: null, appliesTo: "all" } : "object" == typeof t2 && null !== t2 ? { enabled: false !== t2.enabled, maxEntitySize: Math.max(1, t2.maxEntitySize ?? 1e4), maxExpansionDepth: Math.max(1, t2.maxExpansionDepth ?? 1e4), maxTotalExpansions: Math.max(1, t2.maxTotalExpansions ?? 1 / 0), maxExpandedLength: Math.max(1, t2.maxExpandedLength ?? 1e5), maxEntityCount: Math.max(1, t2.maxEntityCount ?? 1e3), allowedTags: t2.allowedTags ?? null, tagFilter: t2.tagFilter ?? null, appliesTo: t2.appliesTo ?? "all" } : T(true);
      }
      __name(T, "T");
      const C = /* @__PURE__ */ __name(function(t2) {
        const e33 = Object.assign({}, _, t2), n11 = [{ value: e33.attributeNamePrefix, name: "attributeNamePrefix" }, { value: e33.attributesGroupName, name: "attributesGroupName" }, { value: e33.textNodeName, name: "textNodeName" }, { value: e33.cdataPropName, name: "cdataPropName" }, { value: e33.commentPropName, name: "commentPropName" }];
        for (const { value: t3, name: e34 } of n11) t3 && A(t3, e34);
        return null === e33.onDangerousProperty && (e33.onDangerousProperty = S), e33.processEntities = T(e33.processEntities, e33.htmlEntities), e33.unpairedTagsSet = new Set(e33.unpairedTags), e33.stopNodes && Array.isArray(e33.stopNodes) && (e33.stopNodes = e33.stopNodes.map((t3) => "string" == typeof t3 && t3.startsWith("*.") ? ".." + t3.substring(2) : t3)), e33;
      }, "C");
      let P;
      P = "function" != typeof Symbol ? "@@xmlMetadata" : /* @__PURE__ */ Symbol("XML Node Metadata");
      class O {
        static {
          __name(this, "O");
        }
        constructor(t2) {
          this.tagname = t2, this.child = [], this[":@"] = /* @__PURE__ */ Object.create(null);
        }
        add(t2, e33) {
          "__proto__" === t2 && (t2 = "#__proto__"), this.child.push({ [t2]: e33 });
        }
        addChild(t2, e33) {
          "__proto__" === t2.tagname && (t2.tagname = "#__proto__"), t2[":@"] && Object.keys(t2[":@"]).length > 0 ? this.child.push({ [t2.tagname]: t2.child, ":@": t2[":@"] }) : this.child.push({ [t2.tagname]: t2.child }), void 0 !== e33 && (this.child[this.child.length - 1][P] = { startIndex: e33 });
        }
        static getMetaDataSymbol() {
          return P;
        }
      }
      class $ {
        static {
          __name(this, "$");
        }
        constructor(t2) {
          this.suppressValidationErr = !t2, this.options = t2;
        }
        readDocType(t2, e33) {
          const n11 = /* @__PURE__ */ Object.create(null);
          let i33 = 0;
          if ("O" !== t2[e33 + 3] || "C" !== t2[e33 + 4] || "T" !== t2[e33 + 5] || "Y" !== t2[e33 + 6] || "P" !== t2[e33 + 7] || "E" !== t2[e33 + 8]) throw new Error("Invalid Tag instead of DOCTYPE");
          {
            e33 += 9;
            let s2 = 1, r33 = false, o11 = false, a33 = "";
            for (; e33 < t2.length; e33++) if ("<" !== t2[e33] || o11) if (">" === t2[e33]) {
              if (o11 ? "-" === t2[e33 - 1] && "-" === t2[e33 - 2] && (o11 = false, s2--) : s2--, 0 === s2) break;
            } else "[" === t2[e33] ? r33 = true : a33 += t2[e33];
            else {
              if (r33 && D(t2, "!ENTITY", e33)) {
                let s3, r34;
                if (e33 += 7, [s3, r34, e33] = this.readEntityExp(t2, e33 + 1, this.suppressValidationErr), -1 === r34.indexOf("&")) {
                  if (false !== this.options.enabled && null != this.options.maxEntityCount && i33 >= this.options.maxEntityCount) throw new Error(`Entity count (${i33 + 1}) exceeds maximum allowed (${this.options.maxEntityCount})`);
                  n11[s3] = r34, i33++;
                }
              } else if (r33 && D(t2, "!ELEMENT", e33)) {
                e33 += 8;
                const { index: n12 } = this.readElementExp(t2, e33 + 1);
                e33 = n12;
              } else if (r33 && D(t2, "!ATTLIST", e33)) e33 += 8;
              else if (r33 && D(t2, "!NOTATION", e33)) {
                e33 += 9;
                const { index: n12 } = this.readNotationExp(t2, e33 + 1, this.suppressValidationErr);
                e33 = n12;
              } else {
                if (!D(t2, "!--", e33)) throw new Error("Invalid DOCTYPE");
                o11 = true;
              }
              s2++, a33 = "";
            }
            if (0 !== s2) throw new Error("Unclosed DOCTYPE");
          }
          return { entities: n11, i: e33 };
        }
        readEntityExp(t2, e33) {
          const n11 = e33 = I(t2, e33);
          for (; e33 < t2.length && !/\s/.test(t2[e33]) && '"' !== t2[e33] && "'" !== t2[e33]; ) e33++;
          let i33 = t2.substring(n11, e33);
          if (M(i33), e33 = I(t2, e33), !this.suppressValidationErr) {
            if ("SYSTEM" === t2.substring(e33, e33 + 6).toUpperCase()) throw new Error("External entities are not supported");
            if ("%" === t2[e33]) throw new Error("Parameter entities are not supported");
          }
          let s2 = "";
          if ([e33, s2] = this.readIdentifierVal(t2, e33, "entity"), false !== this.options.enabled && null != this.options.maxEntitySize && s2.length > this.options.maxEntitySize) throw new Error(`Entity "${i33}" size (${s2.length}) exceeds maximum allowed size (${this.options.maxEntitySize})`);
          return [i33, s2, --e33];
        }
        readNotationExp(t2, e33) {
          const n11 = e33 = I(t2, e33);
          for (; e33 < t2.length && !/\s/.test(t2[e33]); ) e33++;
          let i33 = t2.substring(n11, e33);
          !this.suppressValidationErr && M(i33), e33 = I(t2, e33);
          const s2 = t2.substring(e33, e33 + 6).toUpperCase();
          if (!this.suppressValidationErr && "SYSTEM" !== s2 && "PUBLIC" !== s2) throw new Error(`Expected SYSTEM or PUBLIC, found "${s2}"`);
          e33 += s2.length, e33 = I(t2, e33);
          let r33 = null, o11 = null;
          if ("PUBLIC" === s2) [e33, r33] = this.readIdentifierVal(t2, e33, "publicIdentifier"), '"' !== t2[e33 = I(t2, e33)] && "'" !== t2[e33] || ([e33, o11] = this.readIdentifierVal(t2, e33, "systemIdentifier"));
          else if ("SYSTEM" === s2 && ([e33, o11] = this.readIdentifierVal(t2, e33, "systemIdentifier"), !this.suppressValidationErr && !o11)) throw new Error("Missing mandatory system identifier for SYSTEM notation");
          return { notationName: i33, publicIdentifier: r33, systemIdentifier: o11, index: --e33 };
        }
        readIdentifierVal(t2, e33, n11) {
          let i33 = "";
          const s2 = t2[e33];
          if ('"' !== s2 && "'" !== s2) throw new Error(`Expected quoted string, found "${s2}"`);
          const r33 = ++e33;
          for (; e33 < t2.length && t2[e33] !== s2; ) e33++;
          if (i33 = t2.substring(r33, e33), t2[e33] !== s2) throw new Error(`Unterminated ${n11} value`);
          return [++e33, i33];
        }
        readElementExp(t2, e33) {
          const n11 = e33 = I(t2, e33);
          for (; e33 < t2.length && !/\s/.test(t2[e33]); ) e33++;
          let i33 = t2.substring(n11, e33);
          if (!this.suppressValidationErr && !r32(i33)) throw new Error(`Invalid element name: "${i33}"`);
          let s2 = "";
          if ("E" === t2[e33 = I(t2, e33)] && D(t2, "MPTY", e33)) e33 += 4;
          else if ("A" === t2[e33] && D(t2, "NY", e33)) e33 += 2;
          else if ("(" === t2[e33]) {
            const n12 = ++e33;
            for (; e33 < t2.length && ")" !== t2[e33]; ) e33++;
            if (s2 = t2.substring(n12, e33), ")" !== t2[e33]) throw new Error("Unterminated content model");
          } else if (!this.suppressValidationErr) throw new Error(`Invalid Element Expression, found "${t2[e33]}"`);
          return { elementName: i33, contentModel: s2.trim(), index: e33 };
        }
        readAttlistExp(t2, e33) {
          let n11 = e33 = I(t2, e33);
          for (; e33 < t2.length && !/\s/.test(t2[e33]); ) e33++;
          let i33 = t2.substring(n11, e33);
          for (M(i33), n11 = e33 = I(t2, e33); e33 < t2.length && !/\s/.test(t2[e33]); ) e33++;
          let s2 = t2.substring(n11, e33);
          if (!M(s2)) throw new Error(`Invalid attribute name: "${s2}"`);
          e33 = I(t2, e33);
          let r33 = "";
          if ("NOTATION" === t2.substring(e33, e33 + 8).toUpperCase()) {
            if (r33 = "NOTATION", "(" !== t2[e33 = I(t2, e33 += 8)]) throw new Error(`Expected '(', found "${t2[e33]}"`);
            e33++;
            let n12 = [];
            for (; e33 < t2.length && ")" !== t2[e33]; ) {
              const i34 = e33;
              for (; e33 < t2.length && "|" !== t2[e33] && ")" !== t2[e33]; ) e33++;
              let s3 = t2.substring(i34, e33);
              if (s3 = s3.trim(), !M(s3)) throw new Error(`Invalid notation name: "${s3}"`);
              n12.push(s3), "|" === t2[e33] && (e33++, e33 = I(t2, e33));
            }
            if (")" !== t2[e33]) throw new Error("Unterminated list of notations");
            e33++, r33 += " (" + n12.join("|") + ")";
          } else {
            const n12 = e33;
            for (; e33 < t2.length && !/\s/.test(t2[e33]); ) e33++;
            r33 += t2.substring(n12, e33);
            const i34 = ["CDATA", "ID", "IDREF", "IDREFS", "ENTITY", "ENTITIES", "NMTOKEN", "NMTOKENS"];
            if (!this.suppressValidationErr && !i34.includes(r33.toUpperCase())) throw new Error(`Invalid attribute type: "${r33}"`);
          }
          e33 = I(t2, e33);
          let o11 = "";
          return "#REQUIRED" === t2.substring(e33, e33 + 8).toUpperCase() ? (o11 = "#REQUIRED", e33 += 8) : "#IMPLIED" === t2.substring(e33, e33 + 7).toUpperCase() ? (o11 = "#IMPLIED", e33 += 7) : [e33, o11] = this.readIdentifierVal(t2, e33, "ATTLIST"), { elementName: i33, attributeName: s2, attributeType: r33, defaultValue: o11, index: e33 };
        }
      }
      const I = /* @__PURE__ */ __name((t2, e33) => {
        for (; e33 < t2.length && /\s/.test(t2[e33]); ) e33++;
        return e33;
      }, "I");
      function D(t2, e33, n11) {
        for (let i33 = 0; i33 < e33.length; i33++) if (e33[i33] !== t2[n11 + i33 + 1]) return false;
        return true;
      }
      __name(D, "D");
      function M(t2) {
        if (r32(t2)) return t2;
        throw new Error(`Invalid entity name ${t2}`);
      }
      __name(M, "M");
      const j32 = /^[-+]?0x[a-fA-F0-9]+$/, V = /^([\-\+])?(0*)([0-9]*(\.[0-9]*)?)$/, L = { hex: true, leadingZeros: true, decimalPoint: ".", eNotation: true, infinity: "original" };
      const k32 = /^([-+])?(0*)(\d*(\.\d*)?[eE][-\+]?\d+)$/;
      class F {
        static {
          __name(this, "F");
        }
        constructor(t2) {
          this._matcher = t2;
        }
        get separator() {
          return this._matcher.separator;
        }
        getCurrentTag() {
          const t2 = this._matcher.path;
          return t2.length > 0 ? t2[t2.length - 1].tag : void 0;
        }
        getCurrentNamespace() {
          const t2 = this._matcher.path;
          return t2.length > 0 ? t2[t2.length - 1].namespace : void 0;
        }
        getAttrValue(t2) {
          const e33 = this._matcher.path;
          if (0 !== e33.length) return e33[e33.length - 1].values?.[t2];
        }
        hasAttr(t2) {
          const e33 = this._matcher.path;
          if (0 === e33.length) return false;
          const n11 = e33[e33.length - 1];
          return void 0 !== n11.values && t2 in n11.values;
        }
        getPosition() {
          const t2 = this._matcher.path;
          return 0 === t2.length ? -1 : t2[t2.length - 1].position ?? 0;
        }
        getCounter() {
          const t2 = this._matcher.path;
          return 0 === t2.length ? -1 : t2[t2.length - 1].counter ?? 0;
        }
        getIndex() {
          return this.getPosition();
        }
        getDepth() {
          return this._matcher.path.length;
        }
        toString(t2, e33 = true) {
          return this._matcher.toString(t2, e33);
        }
        toArray() {
          return this._matcher.path.map((t2) => t2.tag);
        }
        matches(t2) {
          return this._matcher.matches(t2);
        }
        matchesAny(t2) {
          return t2.matchesAny(this._matcher);
        }
      }
      class R {
        static {
          __name(this, "R");
        }
        constructor(t2 = {}) {
          this.separator = t2.separator || ".", this.path = [], this.siblingStacks = [], this._pathStringCache = null, this._view = new F(this);
        }
        push(t2, e33 = null, n11 = null) {
          this._pathStringCache = null, this.path.length > 0 && (this.path[this.path.length - 1].values = void 0);
          const i33 = this.path.length;
          this.siblingStacks[i33] || (this.siblingStacks[i33] = /* @__PURE__ */ new Map());
          const s2 = this.siblingStacks[i33], r33 = n11 ? `${n11}:${t2}` : t2, o11 = s2.get(r33) || 0;
          let a33 = 0;
          for (const t3 of s2.values()) a33 += t3;
          s2.set(r33, o11 + 1);
          const h33 = { tag: t2, position: a33, counter: o11 };
          null != n11 && (h33.namespace = n11), null != e33 && (h33.values = e33), this.path.push(h33);
        }
        pop() {
          if (0 === this.path.length) return;
          this._pathStringCache = null;
          const t2 = this.path.pop();
          return this.siblingStacks.length > this.path.length + 1 && (this.siblingStacks.length = this.path.length + 1), t2;
        }
        updateCurrent(t2) {
          if (this.path.length > 0) {
            const e33 = this.path[this.path.length - 1];
            null != t2 && (e33.values = t2);
          }
        }
        getCurrentTag() {
          return this.path.length > 0 ? this.path[this.path.length - 1].tag : void 0;
        }
        getCurrentNamespace() {
          return this.path.length > 0 ? this.path[this.path.length - 1].namespace : void 0;
        }
        getAttrValue(t2) {
          if (0 !== this.path.length) return this.path[this.path.length - 1].values?.[t2];
        }
        hasAttr(t2) {
          if (0 === this.path.length) return false;
          const e33 = this.path[this.path.length - 1];
          return void 0 !== e33.values && t2 in e33.values;
        }
        getPosition() {
          return 0 === this.path.length ? -1 : this.path[this.path.length - 1].position ?? 0;
        }
        getCounter() {
          return 0 === this.path.length ? -1 : this.path[this.path.length - 1].counter ?? 0;
        }
        getIndex() {
          return this.getPosition();
        }
        getDepth() {
          return this.path.length;
        }
        toString(t2, e33 = true) {
          const n11 = t2 || this.separator;
          if (n11 === this.separator && true === e33) {
            if (null !== this._pathStringCache) return this._pathStringCache;
            const t3 = this.path.map((t4) => t4.namespace ? `${t4.namespace}:${t4.tag}` : t4.tag).join(n11);
            return this._pathStringCache = t3, t3;
          }
          return this.path.map((t3) => e33 && t3.namespace ? `${t3.namespace}:${t3.tag}` : t3.tag).join(n11);
        }
        toArray() {
          return this.path.map((t2) => t2.tag);
        }
        reset() {
          this._pathStringCache = null, this.path = [], this.siblingStacks = [];
        }
        matches(t2) {
          const e33 = t2.segments;
          return 0 !== e33.length && (t2.hasDeepWildcard() ? this._matchWithDeepWildcard(e33) : this._matchSimple(e33));
        }
        _matchSimple(t2) {
          if (this.path.length !== t2.length) return false;
          for (let e33 = 0; e33 < t2.length; e33++) if (!this._matchSegment(t2[e33], this.path[e33], e33 === this.path.length - 1)) return false;
          return true;
        }
        _matchWithDeepWildcard(t2) {
          let e33 = this.path.length - 1, n11 = t2.length - 1;
          for (; n11 >= 0 && e33 >= 0; ) {
            const i33 = t2[n11];
            if ("deep-wildcard" === i33.type) {
              if (n11--, n11 < 0) return true;
              const i34 = t2[n11];
              let s2 = false;
              for (let t3 = e33; t3 >= 0; t3--) if (this._matchSegment(i34, this.path[t3], t3 === this.path.length - 1)) {
                e33 = t3 - 1, n11--, s2 = true;
                break;
              }
              if (!s2) return false;
            } else {
              if (!this._matchSegment(i33, this.path[e33], e33 === this.path.length - 1)) return false;
              e33--, n11--;
            }
          }
          return n11 < 0;
        }
        _matchSegment(t2, e33, n11) {
          if ("*" !== t2.tag && t2.tag !== e33.tag) return false;
          if (void 0 !== t2.namespace && "*" !== t2.namespace && t2.namespace !== e33.namespace) return false;
          if (void 0 !== t2.attrName) {
            if (!n11) return false;
            if (!e33.values || !(t2.attrName in e33.values)) return false;
            if (void 0 !== t2.attrValue && String(e33.values[t2.attrName]) !== String(t2.attrValue)) return false;
          }
          if (void 0 !== t2.position) {
            if (!n11) return false;
            const i33 = e33.counter ?? 0;
            if ("first" === t2.position && 0 !== i33) return false;
            if ("odd" === t2.position && i33 % 2 != 1) return false;
            if ("even" === t2.position && i33 % 2 != 0) return false;
            if ("nth" === t2.position && i33 !== t2.positionValue) return false;
          }
          return true;
        }
        matchesAny(t2) {
          return t2.matchesAny(this);
        }
        snapshot() {
          return { path: this.path.map((t2) => ({ ...t2 })), siblingStacks: this.siblingStacks.map((t2) => new Map(t2)) };
        }
        restore(t2) {
          this._pathStringCache = null, this.path = t2.path.map((t3) => ({ ...t3 })), this.siblingStacks = t2.siblingStacks.map((t3) => new Map(t3));
        }
        readOnly() {
          return this._view;
        }
      }
      class G {
        static {
          __name(this, "G");
        }
        constructor(t2, e33 = {}, n11) {
          this.pattern = t2, this.separator = e33.separator || ".", this.segments = this._parse(t2), this.data = n11, this._hasDeepWildcard = this.segments.some((t3) => "deep-wildcard" === t3.type), this._hasAttributeCondition = this.segments.some((t3) => void 0 !== t3.attrName), this._hasPositionSelector = this.segments.some((t3) => void 0 !== t3.position);
        }
        _parse(t2) {
          const e33 = [];
          let n11 = 0, i33 = "";
          for (; n11 < t2.length; ) t2[n11] === this.separator ? n11 + 1 < t2.length && t2[n11 + 1] === this.separator ? (i33.trim() && (e33.push(this._parseSegment(i33.trim())), i33 = ""), e33.push({ type: "deep-wildcard" }), n11 += 2) : (i33.trim() && e33.push(this._parseSegment(i33.trim())), i33 = "", n11++) : (i33 += t2[n11], n11++);
          return i33.trim() && e33.push(this._parseSegment(i33.trim())), e33;
        }
        _parseSegment(t2) {
          const e33 = { type: "tag" };
          let n11 = null, i33 = t2;
          const s2 = t2.match(/^([^\[]+)(\[[^\]]*\])(.*)$/);
          if (s2 && (i33 = s2[1] + s2[3], s2[2])) {
            const t3 = s2[2].slice(1, -1);
            t3 && (n11 = t3);
          }
          let r33, o11, a33 = i33;
          if (i33.includes("::")) {
            const e34 = i33.indexOf("::");
            if (r33 = i33.substring(0, e34).trim(), a33 = i33.substring(e34 + 2).trim(), !r33) throw new Error(`Invalid namespace in pattern: ${t2}`);
          }
          let h33 = null;
          if (a33.includes(":")) {
            const t3 = a33.lastIndexOf(":"), e34 = a33.substring(0, t3).trim(), n12 = a33.substring(t3 + 1).trim();
            ["first", "last", "odd", "even"].includes(n12) || /^nth\(\d+\)$/.test(n12) ? (o11 = e34, h33 = n12) : o11 = a33;
          } else o11 = a33;
          if (!o11) throw new Error(`Invalid segment pattern: ${t2}`);
          if (e33.tag = o11, r33 && (e33.namespace = r33), n11) if (n11.includes("=")) {
            const t3 = n11.indexOf("=");
            e33.attrName = n11.substring(0, t3).trim(), e33.attrValue = n11.substring(t3 + 1).trim();
          } else e33.attrName = n11.trim();
          if (h33) {
            const t3 = h33.match(/^nth\((\d+)\)$/);
            t3 ? (e33.position = "nth", e33.positionValue = parseInt(t3[1], 10)) : e33.position = h33;
          }
          return e33;
        }
        get length() {
          return this.segments.length;
        }
        hasDeepWildcard() {
          return this._hasDeepWildcard;
        }
        hasAttributeCondition() {
          return this._hasAttributeCondition;
        }
        hasPositionSelector() {
          return this._hasPositionSelector;
        }
        toString() {
          return this.pattern;
        }
      }
      class B {
        static {
          __name(this, "B");
        }
        constructor() {
          this._byDepthAndTag = /* @__PURE__ */ new Map(), this._wildcardByDepth = /* @__PURE__ */ new Map(), this._deepWildcards = [], this._patterns = /* @__PURE__ */ new Set(), this._sealed = false;
        }
        add(t2) {
          if (this._sealed) throw new TypeError("ExpressionSet is sealed. Create a new ExpressionSet to add more expressions.");
          if (this._patterns.has(t2.pattern)) return this;
          if (this._patterns.add(t2.pattern), t2.hasDeepWildcard()) return this._deepWildcards.push(t2), this;
          const e33 = t2.length, n11 = t2.segments[t2.segments.length - 1], i33 = n11?.tag;
          if (i33 && "*" !== i33) {
            const n12 = `${e33}:${i33}`;
            this._byDepthAndTag.has(n12) || this._byDepthAndTag.set(n12, []), this._byDepthAndTag.get(n12).push(t2);
          } else this._wildcardByDepth.has(e33) || this._wildcardByDepth.set(e33, []), this._wildcardByDepth.get(e33).push(t2);
          return this;
        }
        addAll(t2) {
          for (const e33 of t2) this.add(e33);
          return this;
        }
        has(t2) {
          return this._patterns.has(t2.pattern);
        }
        get size() {
          return this._patterns.size;
        }
        seal() {
          return this._sealed = true, this;
        }
        get isSealed() {
          return this._sealed;
        }
        matchesAny(t2) {
          return null !== this.findMatch(t2);
        }
        findMatch(t2) {
          const e33 = t2.getDepth(), n11 = `${e33}:${t2.getCurrentTag()}`, i33 = this._byDepthAndTag.get(n11);
          if (i33) {
            for (let e34 = 0; e34 < i33.length; e34++) if (t2.matches(i33[e34])) return i33[e34];
          }
          const s2 = this._wildcardByDepth.get(e33);
          if (s2) {
            for (let e34 = 0; e34 < s2.length; e34++) if (t2.matches(s2[e34])) return s2[e34];
          }
          for (let e34 = 0; e34 < this._deepWildcards.length; e34++) if (t2.matches(this._deepWildcards[e34])) return this._deepWildcards[e34];
          return null;
        }
      }
      const U = { cent: "\xA2", pound: "\xA3", curren: "\xA4", yen: "\xA5", euro: "\u20AC", dollar: "$", euro: "\u20AC", fnof: "\u0192", inr: "\u20B9", af: "\u060B", birr: "\u1265\u122D", peso: "\u20B1", rub: "\u20BD", won: "\u20A9", yuan: "\xA5", cedil: "\xB8" }, W = { amp: "&", apos: "'", gt: ">", lt: "<", quot: '"' }, X = { nbsp: "\xA0", copy: "\xA9", reg: "\xAE", trade: "\u2122", mdash: "\u2014", ndash: "\u2013", hellip: "\u2026", laquo: "\xAB", raquo: "\xBB", lsquo: "\u2018", rsquo: "\u2019", ldquo: "\u201C", rdquo: "\u201D", bull: "\u2022", para: "\xB6", sect: "\xA7", deg: "\xB0", frac12: "\xBD", frac14: "\xBC", frac34: "\xBE" }, Y = new Set("!?\\\\/[]$%{}^&*()<>|+");
      function z(t2) {
        if ("#" === t2[0]) throw new Error(`[EntityReplacer] Invalid character '#' in entity name: "${t2}"`);
        for (const e33 of t2) if (Y.has(e33)) throw new Error(`[EntityReplacer] Invalid character '${e33}' in entity name: "${t2}"`);
        return t2;
      }
      __name(z, "z");
      function q10(...t2) {
        const e33 = /* @__PURE__ */ Object.create(null);
        for (const n11 of t2) if (n11) for (const t3 of Object.keys(n11)) {
          const i33 = n11[t3];
          if ("string" == typeof i33) e33[t3] = i33;
          else if (i33 && "object" == typeof i33 && void 0 !== i33.val) {
            const n12 = i33.val;
            "string" == typeof n12 && (e33[t3] = n12);
          }
        }
        return e33;
      }
      __name(q10, "q");
      const Z = "external", J = "base", K = "all", Q = Object.freeze({ allow: 0, leave: 1, remove: 2, throw: 3 }), H = /* @__PURE__ */ new Set([9, 10, 13]);
      class tt {
        static {
          __name(this, "tt");
        }
        constructor(t2 = {}) {
          var e33;
          this._limit = t2.limit || {}, this._maxTotalExpansions = this._limit.maxTotalExpansions || 0, this._maxExpandedLength = this._limit.maxExpandedLength || 0, this._postCheck = "function" == typeof t2.postCheck ? t2.postCheck : (t3) => t3, this._limitTiers = (e33 = this._limit.applyLimitsTo ?? Z) && e33 !== Z ? e33 === K ? /* @__PURE__ */ new Set([K]) : e33 === J ? /* @__PURE__ */ new Set([J]) : Array.isArray(e33) ? new Set(e33) : /* @__PURE__ */ new Set([Z]) : /* @__PURE__ */ new Set([Z]), this._numericAllowed = t2.numericAllowed ?? true, this._baseMap = q10(W, t2.namedEntities || null), this._externalMap = /* @__PURE__ */ Object.create(null), this._inputMap = /* @__PURE__ */ Object.create(null), this._totalExpansions = 0, this._expandedLength = 0, this._removeSet = new Set(t2.remove && Array.isArray(t2.remove) ? t2.remove : []), this._leaveSet = new Set(t2.leave && Array.isArray(t2.leave) ? t2.leave : []);
          const n11 = (function(t3) {
            if (!t3) return { xmlVersion: 1, onLevel: Q.allow, nullLevel: Q.remove };
            const e34 = 1.1 === t3.xmlVersion ? 1.1 : 1, n12 = Q[t3.onNCR] ?? Q.allow, i33 = Q[t3.nullNCR] ?? Q.remove;
            return { xmlVersion: e34, onLevel: n12, nullLevel: Math.max(i33, Q.remove) };
          })(t2.ncr);
          this._ncrXmlVersion = n11.xmlVersion, this._ncrOnLevel = n11.onLevel, this._ncrNullLevel = n11.nullLevel;
        }
        setExternalEntities(t2) {
          if (t2) for (const e33 of Object.keys(t2)) z(e33);
          this._externalMap = q10(t2);
        }
        addExternalEntity(t2, e33) {
          z(t2), "string" == typeof e33 && -1 === e33.indexOf("&") && (this._externalMap[t2] = e33);
        }
        addInputEntities(t2) {
          this._totalExpansions = 0, this._expandedLength = 0, this._inputMap = q10(t2);
        }
        reset() {
          return this._inputMap = /* @__PURE__ */ Object.create(null), this._totalExpansions = 0, this._expandedLength = 0, this;
        }
        setXmlVersion(t2) {
          this._ncrXmlVersion = 1.1 === t2 ? 1.1 : 1;
        }
        decode(t2) {
          if ("string" != typeof t2 || 0 === t2.length) return t2;
          const e33 = t2, n11 = [], i33 = t2.length;
          let s2 = 0, r33 = 0;
          const o11 = this._maxTotalExpansions > 0, a33 = this._maxExpandedLength > 0, h33 = o11 || a33;
          for (; r33 < i33; ) {
            if (38 !== t2.charCodeAt(r33)) {
              r33++;
              continue;
            }
            let e34 = r33 + 1;
            for (; e34 < i33 && 59 !== t2.charCodeAt(e34) && e34 - r33 <= 32; ) e34++;
            if (e34 >= i33 || 59 !== t2.charCodeAt(e34)) {
              r33++;
              continue;
            }
            const l22 = t2.slice(r33 + 1, e34);
            if (0 === l22.length) {
              r33++;
              continue;
            }
            let u2, p11;
            if (this._removeSet.has(l22)) u2 = "", void 0 === p11 && (p11 = Z);
            else {
              if (this._leaveSet.has(l22)) {
                r33++;
                continue;
              }
              if (35 === l22.charCodeAt(0)) {
                const t3 = this._resolveNCR(l22);
                if (void 0 === t3) {
                  r33++;
                  continue;
                }
                u2 = t3, p11 = J;
              } else {
                const t3 = this._resolveName(l22);
                u2 = t3?.value, p11 = t3?.tier;
              }
            }
            if (void 0 !== u2) {
              if (r33 > s2 && n11.push(t2.slice(s2, r33)), n11.push(u2), s2 = e34 + 1, r33 = s2, h33 && this._tierCounts(p11)) {
                if (o11 && (this._totalExpansions++, this._totalExpansions > this._maxTotalExpansions)) throw new Error(`[EntityReplacer] Entity expansion count limit exceeded: ${this._totalExpansions} > ${this._maxTotalExpansions}`);
                if (a33) {
                  const t3 = u2.length - (l22.length + 2);
                  if (t3 > 0 && (this._expandedLength += t3, this._expandedLength > this._maxExpandedLength)) throw new Error(`[EntityReplacer] Expanded content length limit exceeded: ${this._expandedLength} > ${this._maxExpandedLength}`);
                }
              }
            } else r33++;
          }
          s2 < i33 && n11.push(t2.slice(s2));
          const l21 = 0 === n11.length ? t2 : n11.join("");
          return this._postCheck(l21, e33);
        }
        _tierCounts(t2) {
          return !!this._limitTiers.has(K) || this._limitTiers.has(t2);
        }
        _resolveName(t2) {
          return t2 in this._inputMap ? { value: this._inputMap[t2], tier: Z } : t2 in this._externalMap ? { value: this._externalMap[t2], tier: Z } : t2 in this._baseMap ? { value: this._baseMap[t2], tier: J } : void 0;
        }
        _classifyNCR(t2) {
          return 0 === t2 ? this._ncrNullLevel : t2 >= 55296 && t2 <= 57343 || 1 === this._ncrXmlVersion && t2 >= 1 && t2 <= 31 && !H.has(t2) ? Q.remove : -1;
        }
        _applyNCRAction(t2, e33, n11) {
          switch (t2) {
            case Q.allow:
              return String.fromCodePoint(n11);
            case Q.remove:
              return "";
            case Q.leave:
              return;
            case Q.throw:
              throw new Error(`[EntityDecoder] Prohibited numeric character reference &${e33}; (U+${n11.toString(16).toUpperCase().padStart(4, "0")})`);
            default:
              return String.fromCodePoint(n11);
          }
        }
        _resolveNCR(t2) {
          const e33 = t2.charCodeAt(1);
          let n11;
          if (n11 = 120 === e33 || 88 === e33 ? parseInt(t2.slice(2), 16) : parseInt(t2.slice(1), 10), Number.isNaN(n11) || n11 < 0 || n11 > 1114111) return;
          const i33 = this._classifyNCR(n11);
          if (!this._numericAllowed && i33 < Q.remove) return;
          const s2 = -1 === i33 ? this._ncrOnLevel : Math.max(this._ncrOnLevel, i33);
          return this._applyNCRAction(s2, t2, n11);
        }
      }
      function et(t2, e33) {
        if (!t2) return {};
        const n11 = e33.attributesGroupName ? t2[e33.attributesGroupName] : t2;
        if (!n11) return {};
        const i33 = {};
        for (const t3 in n11) t3.startsWith(e33.attributeNamePrefix) ? i33[t3.substring(e33.attributeNamePrefix.length)] = n11[t3] : i33[t3] = n11[t3];
        return i33;
      }
      __name(et, "et");
      function nt(t2) {
        if (!t2 || "string" != typeof t2) return;
        const e33 = t2.indexOf(":");
        if (-1 !== e33 && e33 > 0) {
          const n11 = t2.substring(0, e33);
          if ("xmlns" !== n11) return n11;
        }
      }
      __name(nt, "nt");
      class it {
        static {
          __name(this, "it");
        }
        constructor(t2) {
          var e33;
          this.options = t2, this.currentNode = null, this.tagsNodeStack = [], this.parseXml = ht, this.parseTextData = st, this.resolveNameSpace = rt, this.buildAttributesMap = at, this.isItStopNode = ct, this.replaceEntitiesValue = ut, this.readStopNodeData = mt, this.saveTextToParentTag = pt, this.addChild = lt, this.ignoreAttributesFn = "function" == typeof (e33 = this.options.ignoreAttributes) ? e33 : Array.isArray(e33) ? (t3) => {
            for (const n12 of e33) {
              if ("string" == typeof n12 && t3 === n12) return true;
              if (n12 instanceof RegExp && n12.test(t3)) return true;
            }
          } : () => false, this.entityExpansionCount = 0, this.currentExpandedLength = 0;
          let n11 = { ...W };
          this.options.entityDecoder ? this.entityDecoder = this.options.entityDecoder : ("object" == typeof this.options.htmlEntities ? n11 = this.options.htmlEntities : true === this.options.htmlEntities && (n11 = { ...X, ...U }), this.entityDecoder = new tt({ namedEntities: n11, numericAllowed: this.options.htmlEntities, limit: { maxTotalExpansions: this.options.processEntities.maxTotalExpansions, maxExpandedLength: this.options.processEntities.maxExpandedLength, applyLimitsTo: this.options.processEntities.appliesTo } })), this.matcher = new R(), this.readonlyMatcher = this.matcher.readOnly(), this.isCurrentNodeStopNode = false, this.stopNodeExpressionsSet = new B();
          const i33 = this.options.stopNodes;
          if (i33 && i33.length > 0) {
            for (let t3 = 0; t3 < i33.length; t3++) {
              const e34 = i33[t3];
              "string" == typeof e34 ? this.stopNodeExpressionsSet.add(new G(e34)) : e34 instanceof G && this.stopNodeExpressionsSet.add(e34);
            }
            this.stopNodeExpressionsSet.seal();
          }
        }
      }
      function st(t2, e33, n11, i33, s2, r33, o11) {
        const a33 = this.options;
        if (void 0 !== t2 && (a33.trimValues && !i33 && (t2 = t2.trim()), t2.length > 0)) {
          o11 || (t2 = this.replaceEntitiesValue(t2, e33, n11));
          const i34 = a33.jPath ? n11.toString() : n11, h33 = a33.tagValueProcessor(e33, t2, i34, s2, r33);
          return null == h33 ? t2 : typeof h33 != typeof t2 || h33 !== t2 ? h33 : a33.trimValues || t2.trim() === t2 ? xt(t2, a33.parseTagValue, a33.numberParseOptions) : t2;
        }
      }
      __name(st, "st");
      function rt(t2) {
        if (this.options.removeNSPrefix) {
          const e33 = t2.split(":"), n11 = "/" === t2.charAt(0) ? "/" : "";
          if ("xmlns" === e33[0]) return "";
          2 === e33.length && (t2 = n11 + e33[1]);
        }
        return t2;
      }
      __name(rt, "rt");
      const ot = new RegExp(`([^\\s=]+)\\s*(=\\s*(['"])([\\s\\S]*?)\\3)?`, "gm");
      function at(t2, e33, n11, i33 = false) {
        const r33 = this.options;
        if (true === i33 || true !== r33.ignoreAttributes && "string" == typeof t2) {
          const i34 = s(t2, ot), o11 = i34.length, a33 = {}, h33 = new Array(o11);
          let l21 = false;
          const u2 = {};
          for (let t3 = 0; t3 < o11; t3++) {
            const e34 = this.resolveNameSpace(i34[t3][1]), s2 = i34[t3][4];
            if (e34.length && void 0 !== s2) {
              let i35 = s2;
              r33.trimValues && (i35 = i35.trim()), i35 = this.replaceEntitiesValue(i35, n11, this.readonlyMatcher), h33[t3] = i35, u2[e34] = i35, l21 = true;
            }
          }
          l21 && "object" == typeof e33 && e33.updateCurrent && e33.updateCurrent(u2);
          const p11 = r33.jPath ? e33.toString() : this.readonlyMatcher;
          let c33 = false;
          for (let t3 = 0; t3 < o11; t3++) {
            const e34 = this.resolveNameSpace(i34[t3][1]);
            if (this.ignoreAttributesFn(e34, p11)) continue;
            let n12 = r33.attributeNamePrefix + e34;
            if (e34.length) if (r33.transformAttributeName && (n12 = r33.transformAttributeName(n12)), n12 = bt(n12, r33), void 0 !== i34[t3][4]) {
              const i35 = h33[t3], s2 = r33.attributeValueProcessor(e34, i35, p11);
              a33[n12] = null == s2 ? i35 : typeof s2 != typeof i35 || s2 !== i35 ? s2 : xt(i35, r33.parseAttributeValue, r33.numberParseOptions), c33 = true;
            } else r33.allowBooleanAttributes && (a33[n12] = true, c33 = true);
          }
          if (!c33) return;
          if (r33.attributesGroupName) {
            const t3 = {};
            return t3[r33.attributesGroupName] = a33, t3;
          }
          return a33;
        }
      }
      __name(at, "at");
      const ht = /* @__PURE__ */ __name(function(t2) {
        t2 = t2.replace(/\r\n?/g, "\n");
        const e33 = new O("!xml");
        let n11 = e33, i33 = "";
        this.matcher.reset(), this.entityDecoder.reset(), this.entityExpansionCount = 0, this.currentExpandedLength = 0;
        const s2 = this.options, r33 = new $(s2.processEntities), o11 = t2.length;
        for (let a33 = 0; a33 < o11; a33++) if ("<" === t2[a33]) {
          const h33 = t2.charCodeAt(a33 + 1);
          if (47 === h33) {
            const e34 = dt(t2, ">", a33, "Closing Tag is not closed.");
            let r34 = t2.substring(a33 + 2, e34).trim();
            if (s2.removeNSPrefix) {
              const t3 = r34.indexOf(":");
              -1 !== t3 && (r34 = r34.substr(t3 + 1));
            }
            r34 = Nt(s2.transformTagName, r34, "", s2).tagName, n11 && (i33 = this.saveTextToParentTag(i33, n11, this.readonlyMatcher));
            const o12 = this.matcher.getCurrentTag();
            if (r34 && s2.unpairedTagsSet.has(r34)) throw new Error(`Unpaired tag can not be used as closing tag: </${r34}>`);
            o12 && s2.unpairedTagsSet.has(o12) && (this.matcher.pop(), this.tagsNodeStack.pop()), this.matcher.pop(), this.isCurrentNodeStopNode = false, n11 = this.tagsNodeStack.pop(), i33 = "", a33 = e34;
          } else if (63 === h33) {
            let e34 = gt(t2, a33, false, "?>");
            if (!e34) throw new Error("Pi Tag is not closed.");
            i33 = this.saveTextToParentTag(i33, n11, this.readonlyMatcher);
            const r34 = this.buildAttributesMap(e34.tagExp, this.matcher, e34.tagName, true);
            if (r34) {
              const t3 = r34[this.options.attributeNamePrefix + "version"];
              this.entityDecoder.setXmlVersion(Number(t3) || 1);
            }
            if (s2.ignoreDeclaration && "?xml" === e34.tagName || s2.ignorePiTags) ;
            else {
              const t3 = new O(e34.tagName);
              t3.add(s2.textNodeName, ""), e34.tagName !== e34.tagExp && e34.attrExpPresent && true !== s2.ignoreAttributes && (t3[":@"] = r34), this.addChild(n11, t3, this.readonlyMatcher, a33);
            }
            a33 = e34.closeIndex + 1;
          } else if (33 === h33 && 45 === t2.charCodeAt(a33 + 2) && 45 === t2.charCodeAt(a33 + 3)) {
            const e34 = dt(t2, "-->", a33 + 4, "Comment is not closed.");
            if (s2.commentPropName) {
              const r34 = t2.substring(a33 + 4, e34 - 2);
              i33 = this.saveTextToParentTag(i33, n11, this.readonlyMatcher), n11.add(s2.commentPropName, [{ [s2.textNodeName]: r34 }]);
            }
            a33 = e34;
          } else if (33 === h33 && 68 === t2.charCodeAt(a33 + 2)) {
            const e34 = r33.readDocType(t2, a33);
            this.entityDecoder.addInputEntities(e34.entities), a33 = e34.i;
          } else if (33 === h33 && 91 === t2.charCodeAt(a33 + 2)) {
            const e34 = dt(t2, "]]>", a33, "CDATA is not closed.") - 2, r34 = t2.substring(a33 + 9, e34);
            i33 = this.saveTextToParentTag(i33, n11, this.readonlyMatcher);
            let o12 = this.parseTextData(r34, n11.tagname, this.readonlyMatcher, true, false, true, true);
            null == o12 && (o12 = ""), s2.cdataPropName ? n11.add(s2.cdataPropName, [{ [s2.textNodeName]: r34 }]) : n11.add(s2.textNodeName, o12), a33 = e34 + 2;
          } else {
            let r34 = gt(t2, a33, s2.removeNSPrefix);
            if (!r34) {
              const e34 = t2.substring(Math.max(0, a33 - 50), Math.min(o11, a33 + 50));
              throw new Error(`readTagExp returned undefined at position ${a33}. Context: "${e34}"`);
            }
            let h34 = r34.tagName;
            const l21 = r34.rawTagName;
            let u2 = r34.tagExp, p11 = r34.attrExpPresent, c33 = r34.closeIndex;
            if ({ tagName: h34, tagExp: u2 } = Nt(s2.transformTagName, h34, u2, s2), s2.strictReservedNames && (h34 === s2.commentPropName || h34 === s2.cdataPropName || h34 === s2.textNodeName || h34 === s2.attributesGroupName)) throw new Error(`Invalid tag name: ${h34}`);
            n11 && i33 && "!xml" !== n11.tagname && (i33 = this.saveTextToParentTag(i33, n11, this.readonlyMatcher, false));
            const d33 = n11;
            d33 && s2.unpairedTagsSet.has(d33.tagname) && (n11 = this.tagsNodeStack.pop(), this.matcher.pop());
            let f33 = false;
            u2.length > 0 && u2.lastIndexOf("/") === u2.length - 1 && (f33 = true, "/" === h34[h34.length - 1] ? (h34 = h34.substr(0, h34.length - 1), u2 = h34) : u2 = u2.substr(0, u2.length - 1), p11 = h34 !== u2);
            let g33, m21 = null, x2 = {};
            g33 = nt(l21), h34 !== e33.tagname && this.matcher.push(h34, {}, g33), h34 !== u2 && p11 && (m21 = this.buildAttributesMap(u2, this.matcher, h34), m21 && (x2 = et(m21, s2))), h34 !== e33.tagname && (this.isCurrentNodeStopNode = this.isItStopNode());
            const N2 = a33;
            if (this.isCurrentNodeStopNode) {
              let e34 = "";
              if (f33) a33 = r34.closeIndex;
              else if (s2.unpairedTagsSet.has(h34)) a33 = r34.closeIndex;
              else {
                const n12 = this.readStopNodeData(t2, l21, c33 + 1);
                if (!n12) throw new Error(`Unexpected end of ${l21}`);
                a33 = n12.i, e34 = n12.tagContent;
              }
              const i34 = new O(h34);
              m21 && (i34[":@"] = m21), i34.add(s2.textNodeName, e34), this.matcher.pop(), this.isCurrentNodeStopNode = false, this.addChild(n11, i34, this.readonlyMatcher, N2);
            } else {
              if (f33) {
                ({ tagName: h34, tagExp: u2 } = Nt(s2.transformTagName, h34, u2, s2));
                const t3 = new O(h34);
                m21 && (t3[":@"] = m21), this.addChild(n11, t3, this.readonlyMatcher, N2), this.matcher.pop(), this.isCurrentNodeStopNode = false;
              } else {
                if (s2.unpairedTagsSet.has(h34)) {
                  const t3 = new O(h34);
                  m21 && (t3[":@"] = m21), this.addChild(n11, t3, this.readonlyMatcher, N2), this.matcher.pop(), this.isCurrentNodeStopNode = false, a33 = r34.closeIndex;
                  continue;
                }
                {
                  const t3 = new O(h34);
                  if (this.tagsNodeStack.length > s2.maxNestedTags) throw new Error("Maximum nested tags exceeded");
                  this.tagsNodeStack.push(n11), m21 && (t3[":@"] = m21), this.addChild(n11, t3, this.readonlyMatcher, N2), n11 = t3;
                }
              }
              i33 = "", a33 = c33;
            }
          }
        } else i33 += t2[a33];
        return e33.child;
      }, "ht");
      function lt(t2, e33, n11, i33) {
        this.options.captureMetaData || (i33 = void 0);
        const s2 = this.options.jPath ? n11.toString() : n11, r33 = this.options.updateTag(e33.tagname, s2, e33[":@"]);
        false === r33 || ("string" == typeof r33 ? (e33.tagname = r33, t2.addChild(e33, i33)) : t2.addChild(e33, i33));
      }
      __name(lt, "lt");
      function ut(t2, e33, n11) {
        const i33 = this.options.processEntities;
        if (!i33 || !i33.enabled) return t2;
        if (i33.allowedTags) {
          const s2 = this.options.jPath ? n11.toString() : n11;
          if (!(Array.isArray(i33.allowedTags) ? i33.allowedTags.includes(e33) : i33.allowedTags(e33, s2))) return t2;
        }
        if (i33.tagFilter) {
          const s2 = this.options.jPath ? n11.toString() : n11;
          if (!i33.tagFilter(e33, s2)) return t2;
        }
        return this.entityDecoder.decode(t2);
      }
      __name(ut, "ut");
      function pt(t2, e33, n11, i33) {
        return t2 && (void 0 === i33 && (i33 = 0 === e33.child.length), void 0 !== (t2 = this.parseTextData(t2, e33.tagname, n11, false, !!e33[":@"] && 0 !== Object.keys(e33[":@"]).length, i33)) && "" !== t2 && e33.add(this.options.textNodeName, t2), t2 = ""), t2;
      }
      __name(pt, "pt");
      function ct() {
        return 0 !== this.stopNodeExpressionsSet.size && this.matcher.matchesAny(this.stopNodeExpressionsSet);
      }
      __name(ct, "ct");
      function dt(t2, e33, n11, i33) {
        const s2 = t2.indexOf(e33, n11);
        if (-1 === s2) throw new Error(i33);
        return s2 + e33.length - 1;
      }
      __name(dt, "dt");
      function ft(t2, e33, n11, i33) {
        const s2 = t2.indexOf(e33, n11);
        if (-1 === s2) throw new Error(i33);
        return s2;
      }
      __name(ft, "ft");
      function gt(t2, e33, n11, i33 = ">") {
        const s2 = (function(t3, e34, n12 = ">") {
          let i34 = 0;
          const s3 = [], r34 = t3.length, o12 = n12.charCodeAt(0), a34 = n12.length > 1 ? n12.charCodeAt(1) : -1;
          for (let n13 = e34; n13 < r34; n13++) {
            const e35 = t3.charCodeAt(n13);
            if (i34) e35 === i34 && (i34 = 0);
            else if (34 === e35 || 39 === e35) i34 = e35;
            else if (e35 === o12) {
              if (-1 === a34) return { data: String.fromCharCode(...s3), index: n13 };
              if (t3.charCodeAt(n13 + 1) === a34) return { data: String.fromCharCode(...s3), index: n13 };
            } else if (9 === e35) {
              s3.push(32);
              continue;
            }
            s3.push(e35);
          }
        })(t2, e33 + 1, i33);
        if (!s2) return;
        let r33 = s2.data;
        const o11 = s2.index, a33 = r33.search(/\s/);
        let h33 = r33, l21 = true;
        -1 !== a33 && (h33 = r33.substring(0, a33), r33 = r33.substring(a33 + 1).trimStart());
        const u2 = h33;
        if (n11) {
          const t3 = h33.indexOf(":");
          -1 !== t3 && (h33 = h33.substr(t3 + 1), l21 = h33 !== s2.data.substr(t3 + 1));
        }
        return { tagName: h33, tagExp: r33, closeIndex: o11, attrExpPresent: l21, rawTagName: u2 };
      }
      __name(gt, "gt");
      function mt(t2, e33, n11) {
        const i33 = n11;
        let s2 = 1;
        const r33 = t2.length;
        for (; n11 < r33; n11++) if ("<" === t2[n11]) {
          const r34 = t2.charCodeAt(n11 + 1);
          if (47 === r34) {
            const r35 = ft(t2, ">", n11, `${e33} is not closed`);
            if (t2.substring(n11 + 2, r35).trim() === e33 && (s2--, 0 === s2)) return { tagContent: t2.substring(i33, n11), i: r35 };
            n11 = r35;
          } else if (63 === r34) n11 = dt(t2, "?>", n11 + 1, "StopNode is not closed.");
          else if (33 === r34 && 45 === t2.charCodeAt(n11 + 2) && 45 === t2.charCodeAt(n11 + 3)) n11 = dt(t2, "-->", n11 + 3, "StopNode is not closed.");
          else if (33 === r34 && 91 === t2.charCodeAt(n11 + 2)) n11 = dt(t2, "]]>", n11, "StopNode is not closed.") - 2;
          else {
            const i34 = gt(t2, n11, ">");
            i34 && ((i34 && i34.tagName) === e33 && "/" !== i34.tagExp[i34.tagExp.length - 1] && s2++, n11 = i34.closeIndex);
          }
        }
      }
      __name(mt, "mt");
      function xt(t2, e33, n11) {
        if (e33 && "string" == typeof t2) {
          const e34 = t2.trim();
          return "true" === e34 || "false" !== e34 && (function(t3, e35 = {}) {
            if (e35 = Object.assign({}, L, e35), !t3 || "string" != typeof t3) return t3;
            let n12 = t3.trim();
            if (0 === n12.length) return t3;
            if (void 0 !== e35.skipLike && e35.skipLike.test(n12)) return t3;
            if ("0" === n12) return 0;
            if (e35.hex && j32.test(n12)) return (function(t4) {
              if (parseInt) return parseInt(t4, 16);
              if (Number.parseInt) return Number.parseInt(t4, 16);
              if (window && window.parseInt) return window.parseInt(t4, 16);
              throw new Error("parseInt, Number.parseInt, window.parseInt are not supported");
            })(n12);
            if (isFinite(n12)) {
              if (n12.includes("e") || n12.includes("E")) return (function(t4, e36, n13) {
                if (!n13.eNotation) return t4;
                const i34 = e36.match(k32);
                if (i34) {
                  let s2 = i34[1] || "";
                  const r33 = -1 === i34[3].indexOf("e") ? "E" : "e", o11 = i34[2], a33 = s2 ? t4[o11.length + 1] === r33 : t4[o11.length] === r33;
                  return o11.length > 1 && a33 ? t4 : (1 !== o11.length || !i34[3].startsWith(`.${r33}`) && i34[3][0] !== r33) && o11.length > 0 ? n13.leadingZeros && !a33 ? (e36 = (i34[1] || "") + i34[3], Number(e36)) : t4 : Number(e36);
                }
                return t4;
              })(t3, n12, e35);
              {
                const s2 = V.exec(n12);
                if (s2) {
                  const r33 = s2[1] || "", o11 = s2[2];
                  let a33 = (i33 = s2[3]) && -1 !== i33.indexOf(".") ? ("." === (i33 = i33.replace(/0+$/, "")) ? i33 = "0" : "." === i33[0] ? i33 = "0" + i33 : "." === i33[i33.length - 1] && (i33 = i33.substring(0, i33.length - 1)), i33) : i33;
                  const h33 = r33 ? "." === t3[o11.length + 1] : "." === t3[o11.length];
                  if (!e35.leadingZeros && (o11.length > 1 || 1 === o11.length && !h33)) return t3;
                  {
                    const i34 = Number(n12), s3 = String(i34);
                    if (0 === i34) return i34;
                    if (-1 !== s3.search(/[eE]/)) return e35.eNotation ? i34 : t3;
                    if (-1 !== n12.indexOf(".")) return "0" === s3 || s3 === a33 || s3 === `${r33}${a33}` ? i34 : t3;
                    let h34 = o11 ? a33 : n12;
                    return o11 ? h34 === s3 || r33 + h34 === s3 ? i34 : t3 : h34 === s3 || h34 === r33 + s3 ? i34 : t3;
                  }
                }
                return t3;
              }
            }
            var i33;
            return (function(t4, e36, n13) {
              const i34 = e36 === 1 / 0;
              switch (n13.infinity.toLowerCase()) {
                case "null":
                  return null;
                case "infinity":
                  return e36;
                case "string":
                  return i34 ? "Infinity" : "-Infinity";
                default:
                  return t4;
              }
            })(t3, Number(n12), e35);
          })(t2, n11);
        }
        return void 0 !== t2 ? t2 : "";
      }
      __name(xt, "xt");
      function Nt(t2, e33, n11, i33) {
        if (t2) {
          const i34 = t2(e33);
          n11 === e33 && (n11 = i34), e33 = i34;
        }
        return { tagName: e33 = bt(e33, i33), tagExp: n11 };
      }
      __name(Nt, "Nt");
      function bt(t2, e33) {
        if (a32.includes(t2)) throw new Error(`[SECURITY] Invalid name: "${t2}" is a reserved JavaScript keyword that could cause prototype pollution`);
        return o10.includes(t2) ? e33.onDangerousProperty(t2) : t2;
      }
      __name(bt, "bt");
      const yt = O.getMetaDataSymbol();
      function Et(t2, e33) {
        if (!t2 || "object" != typeof t2) return {};
        if (!e33) return t2;
        const n11 = {};
        for (const i33 in t2) i33.startsWith(e33) ? n11[i33.substring(e33.length)] = t2[i33] : n11[i33] = t2[i33];
        return n11;
      }
      __name(Et, "Et");
      function wt(t2, e33, n11, i33) {
        return vt(t2, e33, n11, i33);
      }
      __name(wt, "wt");
      function vt(t2, e33, n11, i33) {
        let s2;
        const r33 = {};
        for (let o11 = 0; o11 < t2.length; o11++) {
          const a33 = t2[o11], h33 = St(a33);
          if (void 0 !== h33 && h33 !== e33.textNodeName) {
            const t3 = Et(a33[":@"] || {}, e33.attributeNamePrefix);
            n11.push(h33, t3);
          }
          if (h33 === e33.textNodeName) void 0 === s2 ? s2 = a33[h33] : s2 += "" + a33[h33];
          else {
            if (void 0 === h33) continue;
            if (a33[h33]) {
              let t3 = vt(a33[h33], e33, n11, i33);
              const s3 = At(t3, e33);
              if (a33[":@"] ? _t(t3, a33[":@"], i33, e33) : 1 !== Object.keys(t3).length || void 0 === t3[e33.textNodeName] || e33.alwaysCreateTextNode ? 0 === Object.keys(t3).length && (e33.alwaysCreateTextNode ? t3[e33.textNodeName] = "" : t3 = "") : t3 = t3[e33.textNodeName], void 0 !== a33[yt] && "object" == typeof t3 && null !== t3 && (t3[yt] = a33[yt]), void 0 !== r33[h33] && Object.prototype.hasOwnProperty.call(r33, h33)) Array.isArray(r33[h33]) || (r33[h33] = [r33[h33]]), r33[h33].push(t3);
              else {
                const n12 = e33.jPath ? i33.toString() : i33;
                e33.isArray(h33, n12, s3) ? r33[h33] = [t3] : r33[h33] = t3;
              }
              void 0 !== h33 && h33 !== e33.textNodeName && n11.pop();
            }
          }
        }
        return "string" == typeof s2 ? s2.length > 0 && (r33[e33.textNodeName] = s2) : void 0 !== s2 && (r33[e33.textNodeName] = s2), r33;
      }
      __name(vt, "vt");
      function St(t2) {
        const e33 = Object.keys(t2);
        for (let t3 = 0; t3 < e33.length; t3++) {
          const n11 = e33[t3];
          if (":@" !== n11) return n11;
        }
      }
      __name(St, "St");
      function _t(t2, e33, n11, i33) {
        if (e33) {
          const s2 = Object.keys(e33), r33 = s2.length;
          for (let o11 = 0; o11 < r33; o11++) {
            const r34 = s2[o11], a33 = r34.startsWith(i33.attributeNamePrefix) ? r34.substring(i33.attributeNamePrefix.length) : r34, h33 = i33.jPath ? n11.toString() + "." + a33 : n11;
            i33.isArray(r34, h33, true, true) ? t2[r34] = [e33[r34]] : t2[r34] = e33[r34];
          }
        }
      }
      __name(_t, "_t");
      function At(t2, e33) {
        const { textNodeName: n11 } = e33, i33 = Object.keys(t2).length;
        return 0 === i33 || !(1 !== i33 || !t2[n11] && "boolean" != typeof t2[n11] && 0 !== t2[n11]);
      }
      __name(At, "At");
      class Tt {
        static {
          __name(this, "Tt");
        }
        constructor(t2) {
          this.externalEntities = {}, this.options = C(t2);
        }
        parse(t2, e33) {
          if ("string" != typeof t2 && t2.toString) t2 = t2.toString();
          else if ("string" != typeof t2) throw new Error("XML data is accepted in String or Bytes[] form.");
          if (e33) {
            true === e33 && (e33 = {});
            const n12 = l20(t2, e33);
            if (true !== n12) throw Error(`${n12.err.msg}:${n12.err.line}:${n12.err.col}`);
          }
          const n11 = new it(this.options);
          n11.entityDecoder.setExternalEntities(this.externalEntities);
          const i33 = n11.parseXml(t2);
          return this.options.preserveOrder || void 0 === i33 ? i33 : wt(i33, this.options, n11.matcher, n11.readonlyMatcher);
        }
        addEntity(t2, e33) {
          if (-1 !== e33.indexOf("&")) throw new Error("Entity value can't have '&'");
          if (-1 !== t2.indexOf("&") || -1 !== t2.indexOf(";")) throw new Error("An entity must be set without '&' and ';'. Eg. use '#xD' for '&#xD;'");
          if ("&" === e33) throw new Error("An entity with value '&' is not permitted");
          this.externalEntities[t2] = e33;
        }
        static getMetaDataSymbol() {
          return O.getMetaDataSymbol();
        }
      }
      function Ct(t2, e33) {
        let n11 = "";
        e33.format && e33.indentBy.length > 0 && (n11 = "\n");
        const i33 = [];
        if (e33.stopNodes && Array.isArray(e33.stopNodes)) for (let t3 = 0; t3 < e33.stopNodes.length; t3++) {
          const n12 = e33.stopNodes[t3];
          "string" == typeof n12 ? i33.push(new G(n12)) : n12 instanceof G && i33.push(n12);
        }
        return Pt(t2, e33, n11, new R(), i33);
      }
      __name(Ct, "Ct");
      function Pt(t2, e33, n11, i33, s2) {
        let r33 = "", o11 = false;
        if (e33.maxNestedTags && i33.getDepth() > e33.maxNestedTags) throw new Error("Maximum nested tags exceeded");
        if (!Array.isArray(t2)) {
          if (null != t2) {
            let n12 = t2.toString();
            return n12 = Vt(n12, e33), n12;
          }
          return "";
        }
        for (let a33 = 0; a33 < t2.length; a33++) {
          const h33 = t2[a33], l21 = Dt(h33);
          if (void 0 === l21) continue;
          const u2 = Ot(h33[":@"], e33);
          i33.push(l21, u2);
          const p11 = jt(i33, s2);
          if (l21 === e33.textNodeName) {
            let t3 = h33[l21];
            p11 || (t3 = e33.tagValueProcessor(l21, t3), t3 = Vt(t3, e33)), o11 && (r33 += n11), r33 += t3, o11 = false, i33.pop();
            continue;
          }
          if (l21 === e33.cdataPropName) {
            o11 && (r33 += n11);
            const t3 = h33[l21][0][e33.textNodeName];
            r33 += `<![CDATA[${String(t3).replace(/\]\]>/g, "]]]]><![CDATA[>")}]]>`, o11 = false, i33.pop();
            continue;
          }
          if (l21 === e33.commentPropName) {
            const t3 = h33[l21][0][e33.textNodeName];
            r33 += n11 + `<!--${String(t3).replace(/--/g, "- -").replace(/-$/, "- ")}-->`, o11 = true, i33.pop();
            continue;
          }
          if ("?" === l21[0]) {
            const t3 = Mt(h33[":@"], e33, p11), s3 = "?xml" === l21 ? "" : n11;
            let a34 = h33[l21][0][e33.textNodeName];
            a34 = 0 !== a34.length ? " " + a34 : "", r33 += s3 + `<${l21}${a34}${t3}?>`, o11 = true, i33.pop();
            continue;
          }
          let c33 = n11;
          "" !== c33 && (c33 += e33.indentBy);
          const d33 = n11 + `<${l21}${Mt(h33[":@"], e33, p11)}`;
          let f33;
          f33 = p11 ? $t(h33[l21], e33) : Pt(h33[l21], e33, c33, i33, s2), -1 !== e33.unpairedTags.indexOf(l21) ? e33.suppressUnpairedNode ? r33 += d33 + ">" : r33 += d33 + "/>" : f33 && 0 !== f33.length || !e33.suppressEmptyNode ? f33 && f33.endsWith(">") ? r33 += d33 + `>${f33}${n11}</${l21}>` : (r33 += d33 + ">", f33 && "" !== n11 && (f33.includes("/>") || f33.includes("</")) ? r33 += n11 + e33.indentBy + f33 + n11 : r33 += f33, r33 += `</${l21}>`) : r33 += d33 + "/>", o11 = true, i33.pop();
        }
        return r33;
      }
      __name(Pt, "Pt");
      function Ot(t2, e33) {
        if (!t2 || e33.ignoreAttributes) return null;
        const n11 = {};
        let i33 = false;
        for (let s2 in t2) Object.prototype.hasOwnProperty.call(t2, s2) && (n11[s2.startsWith(e33.attributeNamePrefix) ? s2.substr(e33.attributeNamePrefix.length) : s2] = t2[s2], i33 = true);
        return i33 ? n11 : null;
      }
      __name(Ot, "Ot");
      function $t(t2, e33) {
        if (!Array.isArray(t2)) return null != t2 ? t2.toString() : "";
        let n11 = "";
        for (let i33 = 0; i33 < t2.length; i33++) {
          const s2 = t2[i33], r33 = Dt(s2);
          if (r33 === e33.textNodeName) n11 += s2[r33];
          else if (r33 === e33.cdataPropName) n11 += s2[r33][0][e33.textNodeName];
          else if (r33 === e33.commentPropName) n11 += s2[r33][0][e33.textNodeName];
          else {
            if (r33 && "?" === r33[0]) continue;
            if (r33) {
              const t3 = It(s2[":@"], e33), i34 = $t(s2[r33], e33);
              i34 && 0 !== i34.length ? n11 += `<${r33}${t3}>${i34}</${r33}>` : n11 += `<${r33}${t3}/>`;
            }
          }
        }
        return n11;
      }
      __name($t, "$t");
      function It(t2, e33) {
        let n11 = "";
        if (t2 && !e33.ignoreAttributes) for (let i33 in t2) {
          if (!Object.prototype.hasOwnProperty.call(t2, i33)) continue;
          let s2 = t2[i33];
          true === s2 && e33.suppressBooleanAttributes ? n11 += ` ${i33.substr(e33.attributeNamePrefix.length)}` : n11 += ` ${i33.substr(e33.attributeNamePrefix.length)}="${s2}"`;
        }
        return n11;
      }
      __name(It, "It");
      function Dt(t2) {
        const e33 = Object.keys(t2);
        for (let n11 = 0; n11 < e33.length; n11++) {
          const i33 = e33[n11];
          if (Object.prototype.hasOwnProperty.call(t2, i33) && ":@" !== i33) return i33;
        }
      }
      __name(Dt, "Dt");
      function Mt(t2, e33, n11) {
        let i33 = "";
        if (t2 && !e33.ignoreAttributes) for (let s2 in t2) {
          if (!Object.prototype.hasOwnProperty.call(t2, s2)) continue;
          let r33;
          n11 ? r33 = t2[s2] : (r33 = e33.attributeValueProcessor(s2, t2[s2]), r33 = Vt(r33, e33)), true === r33 && e33.suppressBooleanAttributes ? i33 += ` ${s2.substr(e33.attributeNamePrefix.length)}` : i33 += ` ${s2.substr(e33.attributeNamePrefix.length)}="${r33}"`;
        }
        return i33;
      }
      __name(Mt, "Mt");
      function jt(t2, e33) {
        if (!e33 || 0 === e33.length) return false;
        for (let n11 = 0; n11 < e33.length; n11++) if (t2.matches(e33[n11])) return true;
        return false;
      }
      __name(jt, "jt");
      function Vt(t2, e33) {
        if (t2 && t2.length > 0 && e33.processEntities) for (let n11 = 0; n11 < e33.entities.length; n11++) {
          const i33 = e33.entities[n11];
          t2 = t2.replace(i33.regex, i33.val);
        }
        return t2;
      }
      __name(Vt, "Vt");
      const Lt = { attributeNamePrefix: "@_", attributesGroupName: false, textNodeName: "#text", ignoreAttributes: true, cdataPropName: false, format: false, indentBy: "  ", suppressEmptyNode: false, suppressUnpairedNode: true, suppressBooleanAttributes: true, tagValueProcessor: /* @__PURE__ */ __name(function(t2, e33) {
        return e33;
      }, "tagValueProcessor"), attributeValueProcessor: /* @__PURE__ */ __name(function(t2, e33) {
        return e33;
      }, "attributeValueProcessor"), preserveOrder: false, commentPropName: false, unpairedTags: [], entities: [{ regex: new RegExp("&", "g"), val: "&amp;" }, { regex: new RegExp(">", "g"), val: "&gt;" }, { regex: new RegExp("<", "g"), val: "&lt;" }, { regex: new RegExp("'", "g"), val: "&apos;" }, { regex: new RegExp('"', "g"), val: "&quot;" }], processEntities: true, stopNodes: [], oneListGroup: false, maxNestedTags: 100, jPath: true };
      function kt(t2) {
        if (this.options = Object.assign({}, Lt, t2), this.options.stopNodes && Array.isArray(this.options.stopNodes) && (this.options.stopNodes = this.options.stopNodes.map((t3) => "string" == typeof t3 && t3.startsWith("*.") ? ".." + t3.substring(2) : t3)), this.stopNodeExpressions = [], this.options.stopNodes && Array.isArray(this.options.stopNodes)) for (let t3 = 0; t3 < this.options.stopNodes.length; t3++) {
          const e34 = this.options.stopNodes[t3];
          "string" == typeof e34 ? this.stopNodeExpressions.push(new G(e34)) : e34 instanceof G && this.stopNodeExpressions.push(e34);
        }
        var e33;
        true === this.options.ignoreAttributes || this.options.attributesGroupName ? this.isAttribute = function() {
          return false;
        } : (this.ignoreAttributesFn = "function" == typeof (e33 = this.options.ignoreAttributes) ? e33 : Array.isArray(e33) ? (t3) => {
          for (const n11 of e33) {
            if ("string" == typeof n11 && t3 === n11) return true;
            if (n11 instanceof RegExp && n11.test(t3)) return true;
          }
        } : () => false, this.attrPrefixLen = this.options.attributeNamePrefix.length, this.isAttribute = Gt), this.processTextOrObjNode = Ft, this.options.format ? (this.indentate = Rt, this.tagEndChar = ">\n", this.newLine = "\n") : (this.indentate = function() {
          return "";
        }, this.tagEndChar = ">", this.newLine = "");
      }
      __name(kt, "kt");
      function Ft(t2, e33, n11, i33) {
        const s2 = this.extractAttributes(t2);
        if (i33.push(e33, s2), this.checkStopNode(i33)) {
          const s3 = this.buildRawContent(t2), r34 = this.buildAttributesForStopNode(t2);
          return i33.pop(), this.buildObjectNode(s3, e33, r34, n11);
        }
        const r33 = this.j2x(t2, n11 + 1, i33);
        return i33.pop(), void 0 !== t2[this.options.textNodeName] && 1 === Object.keys(t2).length ? this.buildTextValNode(t2[this.options.textNodeName], e33, r33.attrStr, n11, i33) : this.buildObjectNode(r33.val, e33, r33.attrStr, n11);
      }
      __name(Ft, "Ft");
      function Rt(t2) {
        return this.options.indentBy.repeat(t2);
      }
      __name(Rt, "Rt");
      function Gt(t2) {
        return !(!t2.startsWith(this.options.attributeNamePrefix) || t2 === this.options.textNodeName) && t2.substr(this.attrPrefixLen);
      }
      __name(Gt, "Gt");
      kt.prototype.build = function(t2) {
        if (this.options.preserveOrder) return Ct(t2, this.options);
        {
          Array.isArray(t2) && this.options.arrayNodeName && this.options.arrayNodeName.length > 1 && (t2 = { [this.options.arrayNodeName]: t2 });
          const e33 = new R();
          return this.j2x(t2, 0, e33).val;
        }
      }, kt.prototype.j2x = function(t2, e33, n11) {
        let i33 = "", s2 = "";
        if (this.options.maxNestedTags && n11.getDepth() >= this.options.maxNestedTags) throw new Error("Maximum nested tags exceeded");
        const r33 = this.options.jPath ? n11.toString() : n11, o11 = this.checkStopNode(n11);
        for (let a33 in t2) if (Object.prototype.hasOwnProperty.call(t2, a33)) if (void 0 === t2[a33]) this.isAttribute(a33) && (s2 += "");
        else if (null === t2[a33]) this.isAttribute(a33) || a33 === this.options.cdataPropName ? s2 += "" : "?" === a33[0] ? s2 += this.indentate(e33) + "<" + a33 + "?" + this.tagEndChar : s2 += this.indentate(e33) + "<" + a33 + "/" + this.tagEndChar;
        else if (t2[a33] instanceof Date) s2 += this.buildTextValNode(t2[a33], a33, "", e33, n11);
        else if ("object" != typeof t2[a33]) {
          const h33 = this.isAttribute(a33);
          if (h33 && !this.ignoreAttributesFn(h33, r33)) i33 += this.buildAttrPairStr(h33, "" + t2[a33], o11);
          else if (!h33) if (a33 === this.options.textNodeName) {
            let e34 = this.options.tagValueProcessor(a33, "" + t2[a33]);
            s2 += this.replaceEntitiesValue(e34);
          } else {
            n11.push(a33);
            const i34 = this.checkStopNode(n11);
            if (n11.pop(), i34) {
              const n12 = "" + t2[a33];
              s2 += "" === n12 ? this.indentate(e33) + "<" + a33 + this.closeTag(a33) + this.tagEndChar : this.indentate(e33) + "<" + a33 + ">" + n12 + "</" + a33 + this.tagEndChar;
            } else s2 += this.buildTextValNode(t2[a33], a33, "", e33, n11);
          }
        } else if (Array.isArray(t2[a33])) {
          const i34 = t2[a33].length;
          let r34 = "", o12 = "";
          for (let h33 = 0; h33 < i34; h33++) {
            const i35 = t2[a33][h33];
            if (void 0 === i35) ;
            else if (null === i35) "?" === a33[0] ? s2 += this.indentate(e33) + "<" + a33 + "?" + this.tagEndChar : s2 += this.indentate(e33) + "<" + a33 + "/" + this.tagEndChar;
            else if ("object" == typeof i35) if (this.options.oneListGroup) {
              n11.push(a33);
              const t3 = this.j2x(i35, e33 + 1, n11);
              n11.pop(), r34 += t3.val, this.options.attributesGroupName && i35.hasOwnProperty(this.options.attributesGroupName) && (o12 += t3.attrStr);
            } else r34 += this.processTextOrObjNode(i35, a33, e33, n11);
            else if (this.options.oneListGroup) {
              let t3 = this.options.tagValueProcessor(a33, i35);
              t3 = this.replaceEntitiesValue(t3), r34 += t3;
            } else {
              n11.push(a33);
              const t3 = this.checkStopNode(n11);
              if (n11.pop(), t3) {
                const t4 = "" + i35;
                r34 += "" === t4 ? this.indentate(e33) + "<" + a33 + this.closeTag(a33) + this.tagEndChar : this.indentate(e33) + "<" + a33 + ">" + t4 + "</" + a33 + this.tagEndChar;
              } else r34 += this.buildTextValNode(i35, a33, "", e33, n11);
            }
          }
          this.options.oneListGroup && (r34 = this.buildObjectNode(r34, a33, o12, e33)), s2 += r34;
        } else if (this.options.attributesGroupName && a33 === this.options.attributesGroupName) {
          const e34 = Object.keys(t2[a33]), n12 = e34.length;
          for (let s3 = 0; s3 < n12; s3++) i33 += this.buildAttrPairStr(e34[s3], "" + t2[a33][e34[s3]], o11);
        } else s2 += this.processTextOrObjNode(t2[a33], a33, e33, n11);
        return { attrStr: i33, val: s2 };
      }, kt.prototype.buildAttrPairStr = function(t2, e33, n11) {
        return n11 || (e33 = this.options.attributeValueProcessor(t2, "" + e33), e33 = this.replaceEntitiesValue(e33)), this.options.suppressBooleanAttributes && "true" === e33 ? " " + t2 : " " + t2 + '="' + e33 + '"';
      }, kt.prototype.extractAttributes = function(t2) {
        if (!t2 || "object" != typeof t2) return null;
        const e33 = {};
        let n11 = false;
        if (this.options.attributesGroupName && t2[this.options.attributesGroupName]) {
          const i33 = t2[this.options.attributesGroupName];
          for (let t3 in i33) Object.prototype.hasOwnProperty.call(i33, t3) && (e33[t3.startsWith(this.options.attributeNamePrefix) ? t3.substring(this.options.attributeNamePrefix.length) : t3] = i33[t3], n11 = true);
        } else for (let i33 in t2) {
          if (!Object.prototype.hasOwnProperty.call(t2, i33)) continue;
          const s2 = this.isAttribute(i33);
          s2 && (e33[s2] = t2[i33], n11 = true);
        }
        return n11 ? e33 : null;
      }, kt.prototype.buildRawContent = function(t2) {
        if ("string" == typeof t2) return t2;
        if ("object" != typeof t2 || null === t2) return String(t2);
        if (void 0 !== t2[this.options.textNodeName]) return t2[this.options.textNodeName];
        let e33 = "";
        for (let n11 in t2) {
          if (!Object.prototype.hasOwnProperty.call(t2, n11)) continue;
          if (this.isAttribute(n11)) continue;
          if (this.options.attributesGroupName && n11 === this.options.attributesGroupName) continue;
          const i33 = t2[n11];
          if (n11 === this.options.textNodeName) e33 += i33;
          else if (Array.isArray(i33)) {
            for (let t3 of i33) if ("string" == typeof t3 || "number" == typeof t3) e33 += `<${n11}>${t3}</${n11}>`;
            else if ("object" == typeof t3 && null !== t3) {
              const i34 = this.buildRawContent(t3), s2 = this.buildAttributesForStopNode(t3);
              e33 += "" === i34 ? `<${n11}${s2}/>` : `<${n11}${s2}>${i34}</${n11}>`;
            }
          } else if ("object" == typeof i33 && null !== i33) {
            const t3 = this.buildRawContent(i33), s2 = this.buildAttributesForStopNode(i33);
            e33 += "" === t3 ? `<${n11}${s2}/>` : `<${n11}${s2}>${t3}</${n11}>`;
          } else e33 += `<${n11}>${i33}</${n11}>`;
        }
        return e33;
      }, kt.prototype.buildAttributesForStopNode = function(t2) {
        if (!t2 || "object" != typeof t2) return "";
        let e33 = "";
        if (this.options.attributesGroupName && t2[this.options.attributesGroupName]) {
          const n11 = t2[this.options.attributesGroupName];
          for (let t3 in n11) {
            if (!Object.prototype.hasOwnProperty.call(n11, t3)) continue;
            const i33 = t3.startsWith(this.options.attributeNamePrefix) ? t3.substring(this.options.attributeNamePrefix.length) : t3, s2 = n11[t3];
            true === s2 && this.options.suppressBooleanAttributes ? e33 += " " + i33 : e33 += " " + i33 + '="' + s2 + '"';
          }
        } else for (let n11 in t2) {
          if (!Object.prototype.hasOwnProperty.call(t2, n11)) continue;
          const i33 = this.isAttribute(n11);
          if (i33) {
            const s2 = t2[n11];
            true === s2 && this.options.suppressBooleanAttributes ? e33 += " " + i33 : e33 += " " + i33 + '="' + s2 + '"';
          }
        }
        return e33;
      }, kt.prototype.buildObjectNode = function(t2, e33, n11, i33) {
        if ("" === t2) return "?" === e33[0] ? this.indentate(i33) + "<" + e33 + n11 + "?" + this.tagEndChar : this.indentate(i33) + "<" + e33 + n11 + this.closeTag(e33) + this.tagEndChar;
        {
          let s2 = "</" + e33 + this.tagEndChar, r33 = "";
          return "?" === e33[0] && (r33 = "?", s2 = ""), !n11 && "" !== n11 || -1 !== t2.indexOf("<") ? false !== this.options.commentPropName && e33 === this.options.commentPropName && 0 === r33.length ? this.indentate(i33) + `<!--${t2}-->` + this.newLine : this.indentate(i33) + "<" + e33 + n11 + r33 + this.tagEndChar + t2 + this.indentate(i33) + s2 : this.indentate(i33) + "<" + e33 + n11 + r33 + ">" + t2 + s2;
        }
      }, kt.prototype.closeTag = function(t2) {
        let e33 = "";
        return -1 !== this.options.unpairedTags.indexOf(t2) ? this.options.suppressUnpairedNode || (e33 = "/") : e33 = this.options.suppressEmptyNode ? "/" : `></${t2}`, e33;
      }, kt.prototype.checkStopNode = function(t2) {
        if (!this.stopNodeExpressions || 0 === this.stopNodeExpressions.length) return false;
        for (let e33 = 0; e33 < this.stopNodeExpressions.length; e33++) if (t2.matches(this.stopNodeExpressions[e33])) return true;
        return false;
      }, kt.prototype.buildTextValNode = function(t2, e33, n11, i33, s2) {
        if (false !== this.options.cdataPropName && e33 === this.options.cdataPropName) {
          const e34 = String(t2).replace(/\]\]>/g, "]]]]><![CDATA[>");
          return this.indentate(i33) + `<![CDATA[${e34}]]>` + this.newLine;
        }
        if (false !== this.options.commentPropName && e33 === this.options.commentPropName) {
          const e34 = String(t2).replace(/--/g, "- -").replace(/-$/, "- ");
          return this.indentate(i33) + `<!--${e34}-->` + this.newLine;
        }
        if ("?" === e33[0]) return this.indentate(i33) + "<" + e33 + n11 + "?" + this.tagEndChar;
        {
          let s3 = this.options.tagValueProcessor(e33, t2);
          return s3 = this.replaceEntitiesValue(s3), "" === s3 ? this.indentate(i33) + "<" + e33 + n11 + this.closeTag(e33) + this.tagEndChar : this.indentate(i33) + "<" + e33 + n11 + ">" + s3 + "</" + e33 + this.tagEndChar;
        }
      }, kt.prototype.replaceEntitiesValue = function(t2) {
        if (t2 && t2.length > 0 && this.options.processEntities) for (let e33 = 0; e33 < this.options.entities.length; e33++) {
          const n11 = this.options.entities[e33];
          t2 = t2.replace(n11.regex, n11.val);
        }
        return t2;
      };
      const Bt = kt, Ut = { validate: l20 };
      module2.exports = e32;
    })();
  }
});

// ../../node_modules/@aws-sdk/core/node_modules/@aws-sdk/xml-builder/dist-cjs/xml-parser.js
var require_xml_parser2 = __commonJS({
  "../../node_modules/@aws-sdk/core/node_modules/@aws-sdk/xml-builder/dist-cjs/xml-parser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.parseXML = parseXML20;
    var fast_xml_parser_1 = require_fxp2();
    var parser = new fast_xml_parser_1.XMLParser({
      attributeNamePrefix: "",
      processEntities: {
        enabled: true,
        maxTotalExpansions: Infinity
      },
      htmlEntities: true,
      ignoreAttributes: false,
      ignoreDeclaration: true,
      parseTagValue: false,
      trimValues: false,
      tagValueProcessor: /* @__PURE__ */ __name((_, val) => val.trim() === "" && val.includes("\n") ? "" : void 0, "tagValueProcessor"),
      maxNestedTags: Infinity
    });
    function parseXML20(xmlString) {
      return parser.parse(xmlString, true);
    }
    __name(parseXML20, "parseXML");
  }
});

// ../../node_modules/@aws-sdk/core/node_modules/@aws-sdk/xml-builder/dist-cjs/index.js
var require_dist_cjs107 = __commonJS({
  "../../node_modules/@aws-sdk/core/node_modules/@aws-sdk/xml-builder/dist-cjs/index.js"(exports2) {
    "use strict";
    var xmlParser = require_xml_parser2();
    var ATTR_ESCAPE_RE = /[&<>"]/g;
    var ATTR_ESCAPE_MAP = {
      "&": "&amp;",
      "<": "&lt;",
      ">": "&gt;",
      '"': "&quot;"
    };
    function escapeAttribute(value) {
      return value.replace(ATTR_ESCAPE_RE, (ch) => ATTR_ESCAPE_MAP[ch]);
    }
    __name(escapeAttribute, "escapeAttribute");
    var ELEMENT_ESCAPE_RE = /[&"'<>\r\n\u0085\u2028]/g;
    var ELEMENT_ESCAPE_MAP = {
      "&": "&amp;",
      '"': "&quot;",
      "'": "&apos;",
      "<": "&lt;",
      ">": "&gt;",
      "\r": "&#x0D;",
      "\n": "&#x0A;",
      "\x85": "&#x85;",
      "\u2028": "&#x2028;"
    };
    function escapeElement(value) {
      return value.replace(ELEMENT_ESCAPE_RE, (ch) => ELEMENT_ESCAPE_MAP[ch]);
    }
    __name(escapeElement, "escapeElement");
    var XmlText10 = class {
      static {
        __name(this, "XmlText");
      }
      value;
      constructor(value) {
        this.value = value;
      }
      toString() {
        return escapeElement("" + this.value);
      }
    };
    var XmlNode10 = class _XmlNode {
      static {
        __name(this, "XmlNode");
      }
      name;
      children;
      attributes = {};
      static of(name, childText, withName) {
        const node = new _XmlNode(name);
        if (childText !== void 0) {
          node.addChildNode(new XmlText10(childText));
        }
        if (withName !== void 0) {
          node.withName(withName);
        }
        return node;
      }
      constructor(name, children = []) {
        this.name = name;
        this.children = children;
      }
      withName(name) {
        this.name = name;
        return this;
      }
      addAttribute(name, value) {
        this.attributes[name] = value;
        return this;
      }
      addChildNode(child) {
        this.children.push(child);
        return this;
      }
      removeAttribute(name) {
        delete this.attributes[name];
        return this;
      }
      n(name) {
        this.name = name;
        return this;
      }
      c(child) {
        this.children.push(child);
        return this;
      }
      a(name, value) {
        if (value != null) {
          this.attributes[name] = value;
        }
        return this;
      }
      cc(input, field, withName = field) {
        if (input[field] != null) {
          const node = _XmlNode.of(field, input[field]).withName(withName);
          this.c(node);
        }
      }
      l(input, listName, memberName, valueProvider) {
        if (input[listName] != null) {
          const nodes32 = valueProvider();
          nodes32.map((node) => {
            node.withName(memberName);
            this.c(node);
          });
        }
      }
      lc(input, listName, memberName, valueProvider) {
        if (input[listName] != null) {
          const nodes32 = valueProvider();
          const containerNode = new _XmlNode(memberName);
          nodes32.map((node) => {
            containerNode.c(node);
          });
          this.c(containerNode);
        }
      }
      toString() {
        const hasChildren = Boolean(this.children.length);
        let xmlText = `<${this.name}`;
        const attributes = this.attributes;
        for (const attributeName of Object.keys(attributes)) {
          const attribute = attributes[attributeName];
          if (attribute != null) {
            xmlText += ` ${attributeName}="${escapeAttribute("" + attribute)}"`;
          }
        }
        return xmlText += !hasChildren ? "/>" : `>${this.children.map((c32) => c32.toString()).join("")}</${this.name}>`;
      }
    };
    exports2.parseXML = xmlParser.parseXML;
    exports2.XmlNode = XmlNode10;
    exports2.XmlText = XmlText10;
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeDeserializer.js
var import_xml_builder11, import_smithy_client104, import_util_utf826, XmlShapeDeserializer5;
var init_XmlShapeDeserializer6 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeDeserializer.js"() {
    import_xml_builder11 = __toESM(require_dist_cjs107());
    init_protocols();
    init_schema4();
    import_smithy_client104 = __toESM(require_dist_cjs34());
    import_util_utf826 = __toESM(require_dist_cjs9());
    init_ConfigurableSerdeContext6();
    init_UnionSerde6();
    XmlShapeDeserializer5 = class extends SerdeContextConfig6 {
      static {
        __name(this, "XmlShapeDeserializer");
      }
      settings;
      stringDeserializer;
      constructor(settings) {
        super();
        this.settings = settings;
        this.stringDeserializer = new FromStringShapeDeserializer(settings);
      }
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
        this.stringDeserializer.setSerdeContext(serdeContext);
      }
      read(schema, bytes, key) {
        const ns = NormalizedSchema.of(schema);
        const memberSchemas = ns.getMemberSchemas();
        const isEventPayload = ns.isStructSchema() && ns.isMemberSchema() && !!Object.values(memberSchemas).find((memberNs) => {
          return !!memberNs.getMemberTraits().eventPayload;
        });
        if (isEventPayload) {
          const output = {};
          const memberName = Object.keys(memberSchemas)[0];
          const eventMemberSchema = memberSchemas[memberName];
          if (eventMemberSchema.isBlobSchema()) {
            output[memberName] = bytes;
          } else {
            output[memberName] = this.read(memberSchemas[memberName], bytes);
          }
          return output;
        }
        const xmlString = (this.serdeContext?.utf8Encoder ?? import_util_utf826.toUtf8)(bytes);
        const parsedObject = this.parseXml(xmlString);
        return this.readSchema(schema, key ? parsedObject[key] : parsedObject);
      }
      readSchema(_schema, value) {
        const ns = NormalizedSchema.of(_schema);
        if (ns.isUnitSchema()) {
          return;
        }
        const traits = ns.getMergedTraits();
        if (ns.isListSchema() && !Array.isArray(value)) {
          return this.readSchema(ns, [value]);
        }
        if (value == null) {
          return value;
        }
        if (typeof value === "object") {
          const flat = !!traits.xmlFlattened;
          if (ns.isListSchema()) {
            const listValue = ns.getValueSchema();
            const buffer2 = [];
            const sourceKey = listValue.getMergedTraits().xmlName ?? "member";
            const source = flat ? value : (value[0] ?? value)[sourceKey];
            if (source == null) {
              return buffer2;
            }
            const sourceArray = Array.isArray(source) ? source : [source];
            for (const v of sourceArray) {
              buffer2.push(this.readSchema(listValue, v));
            }
            return buffer2;
          }
          const buffer = {};
          if (ns.isMapSchema()) {
            const keyNs = ns.getKeySchema();
            const memberNs = ns.getValueSchema();
            let entries;
            if (flat) {
              entries = Array.isArray(value) ? value : [value];
            } else {
              entries = Array.isArray(value.entry) ? value.entry : [value.entry];
            }
            const keyProperty = keyNs.getMergedTraits().xmlName ?? "key";
            const valueProperty = memberNs.getMergedTraits().xmlName ?? "value";
            for (const entry of entries) {
              const key = entry[keyProperty];
              const value2 = entry[valueProperty];
              buffer[key] = this.readSchema(memberNs, value2);
            }
            return buffer;
          }
          if (ns.isStructSchema()) {
            const union = ns.isUnionSchema();
            let unionSerde;
            if (union) {
              unionSerde = new UnionSerde6(value, buffer);
            }
            for (const [memberName, memberSchema] of ns.structIterator()) {
              const memberTraits = memberSchema.getMergedTraits();
              const xmlObjectKey = !memberTraits.httpPayload ? memberSchema.getMemberTraits().xmlName ?? memberName : memberTraits.xmlName ?? memberSchema.getName();
              if (union) {
                unionSerde.mark(xmlObjectKey);
              }
              if (value[xmlObjectKey] != null) {
                buffer[memberName] = this.readSchema(memberSchema, value[xmlObjectKey]);
              }
            }
            if (union) {
              unionSerde.writeUnknown();
            }
            return buffer;
          }
          if (ns.isDocumentSchema()) {
            return value;
          }
          throw new Error(`@aws-sdk/core/protocols - xml deserializer unhandled schema type for ${ns.getName(true)}`);
        }
        if (ns.isListSchema()) {
          return [];
        }
        if (ns.isMapSchema() || ns.isStructSchema()) {
          return {};
        }
        return this.stringDeserializer.read(ns, value);
      }
      parseXml(xml) {
        if (xml.length) {
          let parsedObj;
          try {
            parsedObj = (0, import_xml_builder11.parseXML)(xml);
          } catch (e32) {
            if (e32 && typeof e32 === "object") {
              Object.defineProperty(e32, "$responseBodyText", {
                value: xml
              });
            }
            throw e32;
          }
          const textNodeName = "#text";
          const key = Object.keys(parsedObj)[0];
          const parsedObjToReturn = parsedObj[key];
          if (parsedObjToReturn[textNodeName]) {
            parsedObjToReturn[key] = parsedObjToReturn[textNodeName];
            delete parsedObjToReturn[textNodeName];
          }
          return (0, import_smithy_client104.getValueFromTextNode)(parsedObjToReturn);
        }
        return {};
      }
    };
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QueryShapeSerializer.js
var import_smithy_client105, import_util_base6433, QueryShapeSerializer5;
var init_QueryShapeSerializer6 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QueryShapeSerializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_smithy_client105 = __toESM(require_dist_cjs34());
    import_util_base6433 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext6();
    QueryShapeSerializer5 = class extends SerdeContextConfig6 {
      static {
        __name(this, "QueryShapeSerializer");
      }
      settings;
      buffer;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value, prefix = "") {
        if (this.buffer === void 0) {
          this.buffer = "";
        }
        const ns = NormalizedSchema.of(schema);
        if (prefix && !prefix.endsWith(".")) {
          prefix += ".";
        }
        if (ns.isBlobSchema()) {
          if (typeof value === "string" || value instanceof Uint8Array) {
            this.writeKey(prefix);
            this.writeValue((this.serdeContext?.base64Encoder ?? import_util_base6433.toBase64)(value));
          }
        } else if (ns.isBooleanSchema() || ns.isNumericSchema() || ns.isStringSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(String(value));
          } else if (ns.isIdempotencyToken()) {
            this.writeKey(prefix);
            this.writeValue((0, import_uuid.v4)());
          }
        } else if (ns.isBigIntegerSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(String(value));
          }
        } else if (ns.isBigDecimalSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(value instanceof NumericValue ? value.string : String(value));
          }
        } else if (ns.isTimestampSchema()) {
          if (value instanceof Date) {
            this.writeKey(prefix);
            const format32 = determineTimestampFormat(ns, this.settings);
            switch (format32) {
              case 5:
                this.writeValue(value.toISOString().replace(".000Z", "Z"));
                break;
              case 6:
                this.writeValue((0, import_smithy_client105.dateToUtcString)(value));
                break;
              case 7:
                this.writeValue(String(value.getTime() / 1e3));
                break;
            }
          }
        } else if (ns.isDocumentSchema()) {
          if (Array.isArray(value)) {
            this.write(64 | 15, value, prefix);
          } else if (value instanceof Date) {
            this.write(4, value, prefix);
          } else if (value instanceof Uint8Array) {
            this.write(21, value, prefix);
          } else if (value && typeof value === "object") {
            this.write(128 | 15, value, prefix);
          } else {
            this.writeKey(prefix);
            this.writeValue(String(value));
          }
        } else if (ns.isListSchema()) {
          if (Array.isArray(value)) {
            if (value.length === 0) {
              if (this.settings.serializeEmptyLists) {
                this.writeKey(prefix);
                this.writeValue("");
              }
            } else {
              const member7 = ns.getValueSchema();
              const flat = this.settings.flattenLists || ns.getMergedTraits().xmlFlattened;
              let i32 = 1;
              for (const item of value) {
                if (item == null) {
                  continue;
                }
                const traits = member7.getMergedTraits();
                const suffix = this.getKey("member", traits.xmlName, traits.ec2QueryName);
                const key = flat ? `${prefix}${i32}` : `${prefix}${suffix}.${i32}`;
                this.write(member7, item, key);
                ++i32;
              }
            }
          }
        } else if (ns.isMapSchema()) {
          if (value && typeof value === "object") {
            const keySchema = ns.getKeySchema();
            const memberSchema = ns.getValueSchema();
            const flat = ns.getMergedTraits().xmlFlattened;
            let i32 = 1;
            for (const k32 in value) {
              const v = value[k32];
              if (v == null) {
                continue;
              }
              const keyTraits = keySchema.getMergedTraits();
              const keySuffix = this.getKey("key", keyTraits.xmlName, keyTraits.ec2QueryName);
              const key = flat ? `${prefix}${i32}.${keySuffix}` : `${prefix}entry.${i32}.${keySuffix}`;
              const valTraits = memberSchema.getMergedTraits();
              const valueSuffix = this.getKey("value", valTraits.xmlName, valTraits.ec2QueryName);
              const valueKey = flat ? `${prefix}${i32}.${valueSuffix}` : `${prefix}entry.${i32}.${valueSuffix}`;
              this.write(keySchema, k32, key);
              this.write(memberSchema, v, valueKey);
              ++i32;
            }
          }
        } else if (ns.isStructSchema()) {
          if (value && typeof value === "object") {
            let didWriteMember = false;
            for (const [memberName, member7] of ns.structIterator()) {
              if (value[memberName] == null && !member7.isIdempotencyToken()) {
                continue;
              }
              const traits = member7.getMergedTraits();
              const suffix = this.getKey(memberName, traits.xmlName, traits.ec2QueryName, "struct");
              const key = `${prefix}${suffix}`;
              this.write(member7, value[memberName], key);
              didWriteMember = true;
            }
            if (!didWriteMember && ns.isUnionSchema()) {
              const { $unknown } = value;
              if (Array.isArray($unknown)) {
                const [k32, v] = $unknown;
                const key = `${prefix}${k32}`;
                this.write(15, v, key);
              }
            }
          }
        } else if (ns.isUnitSchema()) {
        } else {
          throw new Error(`@aws-sdk/core/protocols - QuerySerializer unrecognized schema type ${ns.getName(true)}`);
        }
      }
      flush() {
        if (this.buffer === void 0) {
          throw new Error("@aws-sdk/core/protocols - QuerySerializer cannot flush with nothing written to buffer.");
        }
        const str = this.buffer;
        delete this.buffer;
        return str;
      }
      getKey(memberName, xmlName, ec2QueryName, keySource) {
        const { ec2, capitalizeKeys } = this.settings;
        if (ec2 && ec2QueryName) {
          return ec2QueryName;
        }
        const key = xmlName ?? memberName;
        if (capitalizeKeys && keySource === "struct") {
          return key[0].toUpperCase() + key.slice(1);
        }
        return key;
      }
      writeKey(key) {
        if (key.endsWith(".")) {
          key = key.slice(0, key.length - 1);
        }
        this.buffer += `&${extendedEncodeURIComponent(key)}=`;
      }
      writeValue(value) {
        this.buffer += extendedEncodeURIComponent(value);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsQueryProtocol.js
var AwsQueryProtocol5;
var init_AwsQueryProtocol6 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsQueryProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib6();
    init_XmlShapeDeserializer6();
    init_QueryShapeSerializer6();
    AwsQueryProtocol5 = class extends RpcProtocol {
      static {
        __name(this, "AwsQueryProtocol");
      }
      options;
      serializer;
      deserializer;
      mixin = new ProtocolLib6();
      constructor(options) {
        super({
          defaultNamespace: options.defaultNamespace,
          errorTypeRegistries: options.errorTypeRegistries
        });
        this.options = options;
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 5
          },
          httpBindings: false,
          xmlNamespace: options.xmlNamespace,
          serviceNamespace: options.defaultNamespace,
          serializeEmptyLists: true
        };
        this.serializer = new QueryShapeSerializer5(settings);
        this.deserializer = new XmlShapeDeserializer5(settings);
      }
      getShapeId() {
        return "aws.protocols#awsQuery";
      }
      setSerdeContext(serdeContext) {
        this.serializer.setSerdeContext(serdeContext);
        this.deserializer.setSerdeContext(serdeContext);
      }
      getPayloadCodec() {
        throw new Error("AWSQuery protocol has no payload codec.");
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        if (!request4.path.endsWith("/")) {
          request4.path += "/";
        }
        request4.headers["content-type"] = "application/x-www-form-urlencoded";
        if (deref(operationSchema.input) === "unit" || !request4.body) {
          request4.body = "";
        }
        const action = operationSchema.name.split("#")[1] ?? operationSchema.name;
        request4.body = `Action=${action}&Version=${this.options.version}` + request4.body;
        if (request4.body.endsWith("&")) {
          request4.body = request4.body.slice(-1);
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        const deserializer = this.deserializer;
        const ns = NormalizedSchema.of(operationSchema.output);
        const dataObject = {};
        if (response.statusCode >= 300) {
          const bytes2 = await collectBody(response.body, context);
          if (bytes2.byteLength > 0) {
            Object.assign(dataObject, await deserializer.read(15, bytes2));
          }
          await this.handleError(operationSchema, context, response, dataObject, this.deserializeMetadata(response));
        }
        for (const header in response.headers) {
          const value = response.headers[header];
          delete response.headers[header];
          response.headers[header.toLowerCase()] = value;
        }
        const shortName = operationSchema.name.split("#")[1] ?? operationSchema.name;
        const awsQueryResultKey = ns.isStructSchema() && this.useNestedResult() ? shortName + "Result" : void 0;
        const bytes = await collectBody(response.body, context);
        if (bytes.byteLength > 0) {
          Object.assign(dataObject, await deserializer.read(ns, bytes, awsQueryResultKey));
        }
        dataObject.$metadata = this.deserializeMetadata(response);
        return dataObject;
      }
      useNestedResult() {
        return true;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = this.loadQueryErrorCode(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const errorData = this.loadQueryError(dataObject) ?? {};
        const message2 = this.loadQueryErrorMessage(dataObject);
        errorData.message = message2;
        errorData.Error = {
          Type: errorData.Type,
          Code: errorData.Code,
          Message: message2
        };
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, errorData, metadata, this.mixin.findQueryCompatibleError);
        const ns = NormalizedSchema.of(errorSchema);
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        const output = {
          Type: errorData.Error.Type,
          Code: errorData.Error.Code,
          Error: errorData.Error
        };
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().xmlName ?? name;
          const value = errorData[target] ?? dataObject[target];
          output[name] = this.deserializer.readSchema(member7, value);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      loadQueryErrorCode(output, data3) {
        const code = (data3.Errors?.[0]?.Error ?? data3.Errors?.Error ?? data3.Error)?.Code;
        if (code !== void 0) {
          return code;
        }
        if (output.statusCode == 404) {
          return "NotFound";
        }
      }
      loadQueryError(data3) {
        return data3.Errors?.[0]?.Error ?? data3.Errors?.Error ?? data3.Error;
      }
      loadQueryErrorMessage(data3) {
        const errorData = this.loadQueryError(data3);
        return errorData?.message ?? errorData?.Message ?? data3.message ?? data3.Message ?? "Unknown";
      }
      getDefaultContentType() {
        return "application/x-www-form-urlencoded";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsEc2QueryProtocol.js
var AwsEc2QueryProtocol4;
var init_AwsEc2QueryProtocol6 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsEc2QueryProtocol.js"() {
    init_AwsQueryProtocol6();
    AwsEc2QueryProtocol4 = class extends AwsQueryProtocol5 {
      static {
        __name(this, "AwsEc2QueryProtocol");
      }
      options;
      constructor(options) {
        super(options);
        this.options = options;
        const ec2Settings = {
          capitalizeKeys: true,
          flattenLists: true,
          serializeEmptyLists: false,
          ec2: true
        };
        Object.assign(this.serializer.settings, ec2Settings);
      }
      getShapeId() {
        return "aws.protocols#ec2Query";
      }
      useNestedResult() {
        return false;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QuerySerializerSettings.js
var init_QuerySerializerSettings6 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QuerySerializerSettings.js"() {
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/parseXmlBody.js
var import_xml_builder12, import_smithy_client106, parseXmlBody4, parseXmlErrorBody4, loadRestXmlErrorCode4;
var init_parseXmlBody6 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/parseXmlBody.js"() {
    import_xml_builder12 = __toESM(require_dist_cjs107());
    import_smithy_client106 = __toESM(require_dist_cjs34());
    init_common7();
    parseXmlBody4 = /* @__PURE__ */ __name((streamBody, context) => collectBodyString6(streamBody, context).then((encoded) => {
      if (encoded.length) {
        let parsedObj;
        try {
          parsedObj = (0, import_xml_builder12.parseXML)(encoded);
        } catch (e32) {
          if (e32 && typeof e32 === "object") {
            Object.defineProperty(e32, "$responseBodyText", {
              value: encoded
            });
          }
          throw e32;
        }
        const textNodeName = "#text";
        const key = Object.keys(parsedObj)[0];
        const parsedObjToReturn = parsedObj[key];
        if (parsedObjToReturn[textNodeName]) {
          parsedObjToReturn[key] = parsedObjToReturn[textNodeName];
          delete parsedObjToReturn[textNodeName];
        }
        return (0, import_smithy_client106.getValueFromTextNode)(parsedObjToReturn);
      }
      return {};
    }), "parseXmlBody");
    parseXmlErrorBody4 = /* @__PURE__ */ __name(async (errorBody, context) => {
      const value = await parseXmlBody4(errorBody, context);
      if (value.Error) {
        value.Error.message = value.Error.message ?? value.Error.Message;
      }
      return value;
    }, "parseXmlErrorBody");
    loadRestXmlErrorCode4 = /* @__PURE__ */ __name((output, data3) => {
      if (data3?.Error?.Code !== void 0) {
        return data3.Error.Code;
      }
      if (data3?.Code !== void 0) {
        return data3.Code;
      }
      if (output.statusCode == 404) {
        return "NotFound";
      }
    }, "loadRestXmlErrorCode");
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeSerializer.js
var import_xml_builder13, import_smithy_client107, import_util_base6434, XmlShapeSerializer4;
var init_XmlShapeSerializer6 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeSerializer.js"() {
    import_xml_builder13 = __toESM(require_dist_cjs107());
    init_protocols();
    init_schema4();
    init_serde();
    import_smithy_client107 = __toESM(require_dist_cjs34());
    import_util_base6434 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext6();
    XmlShapeSerializer4 = class extends SerdeContextConfig6 {
      static {
        __name(this, "XmlShapeSerializer");
      }
      settings;
      stringBuffer;
      byteBuffer;
      buffer;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value) {
        const ns = NormalizedSchema.of(schema);
        if (ns.isStringSchema() && typeof value === "string") {
          this.stringBuffer = value;
        } else if (ns.isBlobSchema()) {
          this.byteBuffer = "byteLength" in value ? value : (this.serdeContext?.base64Decoder ?? import_util_base6434.fromBase64)(value);
        } else {
          this.buffer = this.writeStruct(ns, value, void 0);
          const traits = ns.getMergedTraits();
          if (traits.httpPayload && !traits.xmlName) {
            this.buffer.withName(ns.getName());
          }
        }
      }
      flush() {
        if (this.byteBuffer !== void 0) {
          const bytes = this.byteBuffer;
          delete this.byteBuffer;
          return bytes;
        }
        if (this.stringBuffer !== void 0) {
          const str = this.stringBuffer;
          delete this.stringBuffer;
          return str;
        }
        const buffer = this.buffer;
        if (this.settings.xmlNamespace) {
          if (!buffer?.attributes?.["xmlns"]) {
            buffer.addAttribute("xmlns", this.settings.xmlNamespace);
          }
        }
        delete this.buffer;
        return buffer.toString();
      }
      writeStruct(ns, value, parentXmlns) {
        const traits = ns.getMergedTraits();
        const name = ns.isMemberSchema() && !traits.httpPayload ? ns.getMemberTraits().xmlName ?? ns.getMemberName() : traits.xmlName ?? ns.getName();
        if (!name || !ns.isStructSchema()) {
          throw new Error(`@aws-sdk/core/protocols - xml serializer, cannot write struct with empty name or non-struct, schema=${ns.getName(true)}.`);
        }
        const structXmlNode = import_xml_builder13.XmlNode.of(name);
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(ns, parentXmlns);
        for (const [memberName, memberSchema] of ns.structIterator()) {
          const val = value[memberName];
          if (val != null || memberSchema.isIdempotencyToken()) {
            if (memberSchema.getMergedTraits().xmlAttribute) {
              structXmlNode.addAttribute(memberSchema.getMergedTraits().xmlName ?? memberName, this.writeSimple(memberSchema, val));
              continue;
            }
            if (memberSchema.isListSchema()) {
              this.writeList(memberSchema, val, structXmlNode, xmlns);
            } else if (memberSchema.isMapSchema()) {
              this.writeMap(memberSchema, val, structXmlNode, xmlns);
            } else if (memberSchema.isStructSchema()) {
              structXmlNode.addChildNode(this.writeStruct(memberSchema, val, xmlns));
            } else {
              const memberNode = import_xml_builder13.XmlNode.of(memberSchema.getMergedTraits().xmlName ?? memberSchema.getMemberName());
              this.writeSimpleInto(memberSchema, val, memberNode, xmlns);
              structXmlNode.addChildNode(memberNode);
            }
          }
        }
        const { $unknown } = value;
        if ($unknown && ns.isUnionSchema() && Array.isArray($unknown) && Object.keys(value).length === 1) {
          const [k32, v] = $unknown;
          const node = import_xml_builder13.XmlNode.of(k32);
          if (typeof v !== "string") {
            if (value instanceof import_xml_builder13.XmlNode || value instanceof import_xml_builder13.XmlText) {
              structXmlNode.addChildNode(value);
            } else {
              throw new Error(`@aws-sdk - $unknown union member in XML requires value of type string, @aws-sdk/xml-builder::XmlNode or XmlText.`);
            }
          }
          this.writeSimpleInto(0, v, node, xmlns);
          structXmlNode.addChildNode(node);
        }
        if (xmlns) {
          structXmlNode.addAttribute(xmlnsAttr, xmlns);
        }
        return structXmlNode;
      }
      writeList(listMember, array, container, parentXmlns) {
        if (!listMember.isMemberSchema()) {
          throw new Error(`@aws-sdk/core/protocols - xml serializer, cannot write non-member list: ${listMember.getName(true)}`);
        }
        const listTraits = listMember.getMergedTraits();
        const listValueSchema = listMember.getValueSchema();
        const listValueTraits = listValueSchema.getMergedTraits();
        const sparse = !!listValueTraits.sparse;
        const flat = !!listTraits.xmlFlattened;
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(listMember, parentXmlns);
        const writeItem = /* @__PURE__ */ __name((container2, value) => {
          if (listValueSchema.isListSchema()) {
            this.writeList(listValueSchema, Array.isArray(value) ? value : [value], container2, xmlns);
          } else if (listValueSchema.isMapSchema()) {
            this.writeMap(listValueSchema, value, container2, xmlns);
          } else if (listValueSchema.isStructSchema()) {
            const struct3 = this.writeStruct(listValueSchema, value, xmlns);
            container2.addChildNode(struct3.withName(flat ? listTraits.xmlName ?? listMember.getMemberName() : listValueTraits.xmlName ?? "member"));
          } else {
            const listItemNode = import_xml_builder13.XmlNode.of(flat ? listTraits.xmlName ?? listMember.getMemberName() : listValueTraits.xmlName ?? "member");
            this.writeSimpleInto(listValueSchema, value, listItemNode, xmlns);
            container2.addChildNode(listItemNode);
          }
        }, "writeItem");
        if (flat) {
          for (const value of array) {
            if (sparse || value != null) {
              writeItem(container, value);
            }
          }
        } else {
          const listNode = import_xml_builder13.XmlNode.of(listTraits.xmlName ?? listMember.getMemberName());
          if (xmlns) {
            listNode.addAttribute(xmlnsAttr, xmlns);
          }
          for (const value of array) {
            if (sparse || value != null) {
              writeItem(listNode, value);
            }
          }
          container.addChildNode(listNode);
        }
      }
      writeMap(mapMember, map5, container, parentXmlns, containerIsMap = false) {
        if (!mapMember.isMemberSchema()) {
          throw new Error(`@aws-sdk/core/protocols - xml serializer, cannot write non-member map: ${mapMember.getName(true)}`);
        }
        const mapTraits = mapMember.getMergedTraits();
        const mapKeySchema = mapMember.getKeySchema();
        const mapKeyTraits = mapKeySchema.getMergedTraits();
        const keyTag = mapKeyTraits.xmlName ?? "key";
        const mapValueSchema = mapMember.getValueSchema();
        const mapValueTraits = mapValueSchema.getMergedTraits();
        const valueTag = mapValueTraits.xmlName ?? "value";
        const sparse = !!mapValueTraits.sparse;
        const flat = !!mapTraits.xmlFlattened;
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(mapMember, parentXmlns);
        const addKeyValue = /* @__PURE__ */ __name((entry, key, val) => {
          const keyNode = import_xml_builder13.XmlNode.of(keyTag, key);
          const [keyXmlnsAttr, keyXmlns] = this.getXmlnsAttribute(mapKeySchema, xmlns);
          if (keyXmlns) {
            keyNode.addAttribute(keyXmlnsAttr, keyXmlns);
          }
          entry.addChildNode(keyNode);
          let valueNode = import_xml_builder13.XmlNode.of(valueTag);
          if (mapValueSchema.isListSchema()) {
            this.writeList(mapValueSchema, val, valueNode, xmlns);
          } else if (mapValueSchema.isMapSchema()) {
            this.writeMap(mapValueSchema, val, valueNode, xmlns, true);
          } else if (mapValueSchema.isStructSchema()) {
            valueNode = this.writeStruct(mapValueSchema, val, xmlns);
          } else {
            this.writeSimpleInto(mapValueSchema, val, valueNode, xmlns);
          }
          entry.addChildNode(valueNode);
        }, "addKeyValue");
        if (flat) {
          for (const key in map5) {
            const val = map5[key];
            if (sparse || val != null) {
              const entry = import_xml_builder13.XmlNode.of(mapTraits.xmlName ?? mapMember.getMemberName());
              addKeyValue(entry, key, val);
              container.addChildNode(entry);
            }
          }
        } else {
          let mapNode;
          if (!containerIsMap) {
            mapNode = import_xml_builder13.XmlNode.of(mapTraits.xmlName ?? mapMember.getMemberName());
            if (xmlns) {
              mapNode.addAttribute(xmlnsAttr, xmlns);
            }
            container.addChildNode(mapNode);
          }
          for (const key in map5) {
            const val = map5[key];
            if (sparse || val != null) {
              const entry = import_xml_builder13.XmlNode.of("entry");
              addKeyValue(entry, key, val);
              (containerIsMap ? container : mapNode).addChildNode(entry);
            }
          }
        }
      }
      writeSimple(_schema, value) {
        if (null === value) {
          throw new Error("@aws-sdk/core/protocols - (XML serializer) cannot write null value.");
        }
        const ns = NormalizedSchema.of(_schema);
        let nodeContents = null;
        if (value && typeof value === "object") {
          if (ns.isBlobSchema()) {
            nodeContents = (this.serdeContext?.base64Encoder ?? import_util_base6434.toBase64)(value);
          } else if (ns.isTimestampSchema() && value instanceof Date) {
            const format32 = determineTimestampFormat(ns, this.settings);
            switch (format32) {
              case 5:
                nodeContents = value.toISOString().replace(".000Z", "Z");
                break;
              case 6:
                nodeContents = (0, import_smithy_client107.dateToUtcString)(value);
                break;
              case 7:
                nodeContents = String(value.getTime() / 1e3);
                break;
              default:
                console.warn("Missing timestamp format, using http date", value);
                nodeContents = (0, import_smithy_client107.dateToUtcString)(value);
                break;
            }
          } else if (ns.isBigDecimalSchema() && value) {
            if (value instanceof NumericValue) {
              return value.string;
            }
            return String(value);
          } else if (ns.isMapSchema() || ns.isListSchema()) {
            throw new Error("@aws-sdk/core/protocols - xml serializer, cannot call _write() on List/Map schema, call writeList or writeMap() instead.");
          } else {
            throw new Error(`@aws-sdk/core/protocols - xml serializer, unhandled schema type for object value and schema: ${ns.getName(true)}`);
          }
        }
        if (ns.isBooleanSchema() || ns.isNumericSchema() || ns.isBigIntegerSchema() || ns.isBigDecimalSchema()) {
          nodeContents = String(value);
        }
        if (ns.isStringSchema()) {
          if (value === void 0 && ns.isIdempotencyToken()) {
            nodeContents = (0, import_uuid.v4)();
          } else {
            nodeContents = String(value);
          }
        }
        if (nodeContents === null) {
          throw new Error(`Unhandled schema-value pair ${ns.getName(true)}=${value}`);
        }
        return nodeContents;
      }
      writeSimpleInto(_schema, value, into, parentXmlns) {
        const nodeContents = this.writeSimple(_schema, value);
        const ns = NormalizedSchema.of(_schema);
        const content = new import_xml_builder13.XmlText(nodeContents);
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(ns, parentXmlns);
        if (xmlns) {
          into.addAttribute(xmlnsAttr, xmlns);
        }
        into.addChildNode(content);
      }
      getXmlnsAttribute(ns, parentXmlns) {
        const traits = ns.getMergedTraits();
        const [prefix, xmlns] = traits.xmlNamespace ?? [];
        if (xmlns && xmlns !== parentXmlns) {
          return [prefix ? `xmlns:${prefix}` : "xmlns", xmlns];
        }
        return [void 0, void 0];
      }
    };
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlCodec.js
var XmlCodec4;
var init_XmlCodec6 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlCodec.js"() {
    init_ConfigurableSerdeContext6();
    init_XmlShapeDeserializer6();
    init_XmlShapeSerializer6();
    XmlCodec4 = class extends SerdeContextConfig6 {
      static {
        __name(this, "XmlCodec");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      createSerializer() {
        const serializer = new XmlShapeSerializer4(this.settings);
        serializer.setSerdeContext(this.serdeContext);
        return serializer;
      }
      createDeserializer() {
        const deserializer = new XmlShapeDeserializer5(this.settings);
        deserializer.setSerdeContext(this.serdeContext);
        return deserializer;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/AwsRestXmlProtocol.js
var AwsRestXmlProtocol4;
var init_AwsRestXmlProtocol6 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/AwsRestXmlProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib6();
    init_parseXmlBody6();
    init_XmlCodec6();
    AwsRestXmlProtocol4 = class extends HttpBindingProtocol {
      static {
        __name(this, "AwsRestXmlProtocol");
      }
      codec;
      serializer;
      deserializer;
      mixin = new ProtocolLib6();
      constructor(options) {
        super(options);
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 5
          },
          httpBindings: true,
          xmlNamespace: options.xmlNamespace,
          serviceNamespace: options.defaultNamespace
        };
        this.codec = new XmlCodec4(settings);
        this.serializer = new HttpInterceptingShapeSerializer(this.codec.createSerializer(), settings);
        this.deserializer = new HttpInterceptingShapeDeserializer(this.codec.createDeserializer(), settings);
      }
      getPayloadCodec() {
        return this.codec;
      }
      getShapeId() {
        return "aws.protocols#restXml";
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        const inputSchema = NormalizedSchema.of(operationSchema.input);
        if (!request4.headers["content-type"]) {
          const contentType = this.mixin.resolveRestContentType(this.getDefaultContentType(), inputSchema);
          if (contentType) {
            request4.headers["content-type"] = contentType;
          }
        }
        if (typeof request4.body === "string" && request4.headers["content-type"] === this.getDefaultContentType() && !request4.body.startsWith("<?xml ") && !this.hasUnstructuredPayloadBinding(inputSchema)) {
          request4.body = '<?xml version="1.0" encoding="UTF-8"?>' + request4.body;
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        return super.deserializeResponse(operationSchema, context, response);
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = loadRestXmlErrorCode4(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        if (dataObject.Error && typeof dataObject.Error === "object") {
          for (const key of Object.keys(dataObject.Error)) {
            dataObject[key] = dataObject.Error[key];
            if (key.toLowerCase() === "message") {
              dataObject.message = dataObject.Error[key];
            }
          }
        }
        if (dataObject.RequestId && !metadata.requestId) {
          metadata.requestId = dataObject.RequestId;
        }
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.Error?.message ?? dataObject.Error?.Message ?? dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        await this.deserializeHttpMessage(errorSchema, context, response, dataObject);
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().xmlName ?? name;
          const value = dataObject.Error?.[target] ?? dataObject[target];
          output[name] = errorDeserializer.readSchema(member7, value);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      getDefaultContentType() {
        return "application/xml";
      }
      hasUnstructuredPayloadBinding(ns) {
        for (const [, member7] of ns.structIterator()) {
          if (member7.getMergedTraits().httpPayload) {
            return !(member7.isStructSchema() || member7.isMapSchema() || member7.isListSchema());
          }
        }
        return false;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/index.js
var protocols_exports5 = {};
__export(protocols_exports5, {
  AwsEc2QueryProtocol: () => AwsEc2QueryProtocol4,
  AwsJson1_0Protocol: () => AwsJson1_0Protocol4,
  AwsJson1_1Protocol: () => AwsJson1_1Protocol4,
  AwsJsonRpcProtocol: () => AwsJsonRpcProtocol4,
  AwsQueryProtocol: () => AwsQueryProtocol5,
  AwsRestJsonProtocol: () => AwsRestJsonProtocol6,
  AwsRestXmlProtocol: () => AwsRestXmlProtocol4,
  AwsSmithyRpcV2CborProtocol: () => AwsSmithyRpcV2CborProtocol4,
  JsonCodec: () => JsonCodec6,
  JsonShapeDeserializer: () => JsonShapeDeserializer6,
  JsonShapeSerializer: () => JsonShapeSerializer6,
  QueryShapeSerializer: () => QueryShapeSerializer5,
  XmlCodec: () => XmlCodec4,
  XmlShapeDeserializer: () => XmlShapeDeserializer5,
  XmlShapeSerializer: () => XmlShapeSerializer4,
  _toBool: () => _toBool4,
  _toNum: () => _toNum4,
  _toStr: () => _toStr4,
  awsExpectUnion: () => awsExpectUnion4,
  loadRestJsonErrorCode: () => loadRestJsonErrorCode6,
  loadRestXmlErrorCode: () => loadRestXmlErrorCode4,
  parseJsonBody: () => parseJsonBody6,
  parseJsonErrorBody: () => parseJsonErrorBody4,
  parseXmlBody: () => parseXmlBody4,
  parseXmlErrorBody: () => parseXmlErrorBody4
});
var init_protocols8 = __esm({
  "../../node_modules/@aws-sdk/core/dist-es/submodules/protocols/index.js"() {
    init_AwsSmithyRpcV2CborProtocol6();
    init_coercing_serializers6();
    init_AwsJson1_0Protocol6();
    init_AwsJson1_1Protocol6();
    init_AwsJsonRpcProtocol6();
    init_AwsRestJsonProtocol6();
    init_JsonCodec6();
    init_JsonShapeDeserializer6();
    init_JsonShapeSerializer6();
    init_awsExpectUnion6();
    init_parseJsonBody6();
    init_AwsEc2QueryProtocol6();
    init_AwsQueryProtocol6();
    init_QuerySerializerSettings6();
    init_QueryShapeSerializer6();
    init_AwsRestXmlProtocol6();
    init_XmlCodec6();
    init_XmlShapeDeserializer6();
    init_XmlShapeSerializer6();
    init_parseXmlBody6();
  }
});

// ../../node_modules/@aws-sdk/client-sts/node_modules/@aws-sdk/middleware-sdk-s3/dist-cjs/index.js
var require_dist_cjs108 = __commonJS({
  "../../node_modules/@aws-sdk/client-sts/node_modules/@aws-sdk/middleware-sdk-s3/dist-cjs/index.js"(exports2) {
    "use strict";
    var protocolHttp = require_dist_cjs2();
    var smithyClient = require_dist_cjs34();
    var toStream = require_toStream2();
    var utilArnParser = require_dist_cjs53();
    var protocols = (init_protocols8(), __toCommonJS(protocols_exports5));
    var schema = (init_schema4(), __toCommonJS(schema_exports));
    var signatureV4 = require_dist_cjs36();
    var utilConfigProvider = require_dist_cjs24();
    var client = (init_client8(), __toCommonJS(client_exports7));
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var utilMiddleware = require_dist_cjs6();
    var CONTENT_LENGTH_HEADER6 = "content-length";
    var DECODED_CONTENT_LENGTH_HEADER = "x-amz-decoded-content-length";
    function checkContentLengthHeader() {
      return (next, context) => async (args) => {
        const { request: request4 } = args;
        if (protocolHttp.HttpRequest.isInstance(request4)) {
          if (!(CONTENT_LENGTH_HEADER6 in request4.headers) && !(DECODED_CONTENT_LENGTH_HEADER in request4.headers)) {
            const message2 = `Are you using a Stream of unknown length as the Body of a PutObject request? Consider using Upload instead from @aws-sdk/lib-storage.`;
            if (typeof context?.logger?.warn === "function" && !(context.logger instanceof smithyClient.NoOpLogger)) {
              context.logger.warn(message2);
            } else {
              console.warn(message2);
            }
          }
        }
        return next({ ...args });
      };
    }
    __name(checkContentLengthHeader, "checkContentLengthHeader");
    var checkContentLengthHeaderMiddlewareOptions = {
      step: "finalizeRequest",
      tags: ["CHECK_CONTENT_LENGTH_HEADER"],
      name: "getCheckContentLengthHeaderPlugin",
      override: true
    };
    var getCheckContentLengthHeaderPlugin = /* @__PURE__ */ __name((unused) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(checkContentLengthHeader(), checkContentLengthHeaderMiddlewareOptions);
      }, "applyToStack")
    }), "getCheckContentLengthHeaderPlugin");
    var regionRedirectEndpointMiddleware = /* @__PURE__ */ __name((config2) => {
      return (next, context) => async (args) => {
        const originalRegion = await config2.region();
        const regionProviderRef = config2.region;
        let unlock = /* @__PURE__ */ __name(() => {
        }, "unlock");
        if (context.__s3RegionRedirect) {
          Object.defineProperty(config2, "region", {
            writable: false,
            value: /* @__PURE__ */ __name(async () => {
              return context.__s3RegionRedirect;
            }, "value")
          });
          unlock = /* @__PURE__ */ __name(() => Object.defineProperty(config2, "region", {
            writable: true,
            value: regionProviderRef
          }), "unlock");
        }
        try {
          const result2 = await next(args);
          if (context.__s3RegionRedirect) {
            unlock();
            const region = await config2.region();
            if (originalRegion !== region) {
              throw new Error("Region was not restored following S3 region redirect.");
            }
          }
          return result2;
        } catch (e32) {
          unlock();
          throw e32;
        }
      };
    }, "regionRedirectEndpointMiddleware");
    var regionRedirectEndpointMiddlewareOptions = {
      tags: ["REGION_REDIRECT", "S3"],
      name: "regionRedirectEndpointMiddleware",
      override: true,
      relation: "before",
      toMiddleware: "endpointV2Middleware"
    };
    function regionRedirectMiddleware(clientConfig) {
      return (next, context) => async (args) => {
        try {
          return await next(args);
        } catch (err) {
          if (clientConfig.followRegionRedirects) {
            const statusCode = err?.$metadata?.httpStatusCode;
            const isHeadBucket = context.commandName === "HeadBucketCommand";
            const bucketRegionHeader = err?.$response?.headers?.["x-amz-bucket-region"];
            if (bucketRegionHeader) {
              if (statusCode === 301 || statusCode === 400 && (err?.name === "IllegalLocationConstraintException" || isHeadBucket)) {
                try {
                  const actualRegion = bucketRegionHeader;
                  context.logger?.debug(`Redirecting from ${await clientConfig.region()} to ${actualRegion}`);
                  context.__s3RegionRedirect = actualRegion;
                } catch (e32) {
                  throw new Error("Region redirect failed: " + e32);
                }
                return next(args);
              }
            }
          }
          throw err;
        }
      };
    }
    __name(regionRedirectMiddleware, "regionRedirectMiddleware");
    var regionRedirectMiddlewareOptions = {
      step: "initialize",
      tags: ["REGION_REDIRECT", "S3"],
      name: "regionRedirectMiddleware",
      override: true
    };
    var getRegionRedirectMiddlewarePlugin = /* @__PURE__ */ __name((clientConfig) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(regionRedirectMiddleware(clientConfig), regionRedirectMiddlewareOptions);
        clientStack.addRelativeTo(regionRedirectEndpointMiddleware(clientConfig), regionRedirectEndpointMiddlewareOptions);
      }, "applyToStack")
    }), "getRegionRedirectMiddlewarePlugin");
    var s3ExpiresMiddleware = /* @__PURE__ */ __name((config2) => {
      return (next, context) => async (args) => {
        const result2 = await next(args);
        const { response } = result2;
        if (protocolHttp.HttpResponse.isInstance(response)) {
          if (response.headers.expires) {
            response.headers.expiresstring = response.headers.expires;
            try {
              smithyClient.parseRfc7231DateTime(response.headers.expires);
            } catch (e32) {
              context.logger?.warn(`AWS SDK Warning for ${context.clientName}::${context.commandName} response parsing (${response.headers.expires}): ${e32}`);
              delete response.headers.expires;
            }
          }
        }
        return result2;
      };
    }, "s3ExpiresMiddleware");
    var s3ExpiresMiddlewareOptions = {
      tags: ["S3"],
      name: "s3ExpiresMiddleware",
      override: true,
      relation: "after",
      toMiddleware: "deserializerMiddleware"
    };
    var getS3ExpiresMiddlewarePlugin = /* @__PURE__ */ __name((clientConfig) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.addRelativeTo(s3ExpiresMiddleware(), s3ExpiresMiddlewareOptions);
      }, "applyToStack")
    }), "getS3ExpiresMiddlewarePlugin");
    var S3ExpressIdentityCache = class _S3ExpressIdentityCache {
      static {
        __name(this, "S3ExpressIdentityCache");
      }
      data;
      lastPurgeTime = Date.now();
      static EXPIRED_CREDENTIAL_PURGE_INTERVAL_MS = 3e4;
      constructor(data3 = {}) {
        this.data = data3;
      }
      get(key) {
        const entry = this.data[key];
        if (!entry) {
          return;
        }
        return entry;
      }
      set(key, entry) {
        this.data[key] = entry;
        return entry;
      }
      delete(key) {
        delete this.data[key];
      }
      async purgeExpired() {
        const now = Date.now();
        if (this.lastPurgeTime + _S3ExpressIdentityCache.EXPIRED_CREDENTIAL_PURGE_INTERVAL_MS > now) {
          return;
        }
        for (const key in this.data) {
          const entry = this.data[key];
          if (!entry.isRefreshing) {
            const credential = await entry.identity;
            if (credential.expiration) {
              if (credential.expiration.getTime() < now) {
                delete this.data[key];
              }
            }
          }
        }
      }
    };
    var S3ExpressIdentityCacheEntry = class {
      static {
        __name(this, "S3ExpressIdentityCacheEntry");
      }
      _identity;
      isRefreshing;
      accessed;
      constructor(_identity, isRefreshing = false, accessed = Date.now()) {
        this._identity = _identity;
        this.isRefreshing = isRefreshing;
        this.accessed = accessed;
      }
      get identity() {
        this.accessed = Date.now();
        return this._identity;
      }
    };
    var S3ExpressIdentityProviderImpl = class _S3ExpressIdentityProviderImpl {
      static {
        __name(this, "S3ExpressIdentityProviderImpl");
      }
      createSessionFn;
      cache;
      static REFRESH_WINDOW_MS = 6e4;
      constructor(createSessionFn, cache32 = new S3ExpressIdentityCache()) {
        this.createSessionFn = createSessionFn;
        this.cache = cache32;
      }
      async getS3ExpressIdentity(awsIdentity, identityProperties) {
        const key = identityProperties.Bucket;
        const { cache: cache32 } = this;
        const entry = cache32.get(key);
        if (entry) {
          return entry.identity.then((identity) => {
            const isExpired = (identity.expiration?.getTime() ?? 0) < Date.now();
            if (isExpired) {
              return cache32.set(key, new S3ExpressIdentityCacheEntry(this.getIdentity(key))).identity;
            }
            const isExpiringSoon = (identity.expiration?.getTime() ?? 0) < Date.now() + _S3ExpressIdentityProviderImpl.REFRESH_WINDOW_MS;
            if (isExpiringSoon && !entry.isRefreshing) {
              entry.isRefreshing = true;
              this.getIdentity(key).then((id) => {
                cache32.set(key, new S3ExpressIdentityCacheEntry(Promise.resolve(id)));
              });
            }
            return identity;
          });
        }
        return cache32.set(key, new S3ExpressIdentityCacheEntry(this.getIdentity(key))).identity;
      }
      async getIdentity(key) {
        await this.cache.purgeExpired().catch((error4) => {
          console.warn("Error while clearing expired entries in S3ExpressIdentityCache: \n" + error4);
        });
        const session = await this.createSessionFn(key);
        if (!session.Credentials?.AccessKeyId || !session.Credentials?.SecretAccessKey) {
          throw new Error("s3#createSession response credential missing AccessKeyId or SecretAccessKey.");
        }
        const identity = {
          accessKeyId: session.Credentials.AccessKeyId,
          secretAccessKey: session.Credentials.SecretAccessKey,
          sessionToken: session.Credentials.SessionToken,
          expiration: session.Credentials.Expiration ? new Date(session.Credentials.Expiration) : void 0
        };
        return identity;
      }
    };
    var S3_EXPRESS_BUCKET_TYPE = "Directory";
    var S3_EXPRESS_BACKEND = "S3Express";
    var S3_EXPRESS_AUTH_SCHEME = "sigv4-s3express";
    var SESSION_TOKEN_QUERY_PARAM = "X-Amz-S3session-Token";
    var SESSION_TOKEN_HEADER = SESSION_TOKEN_QUERY_PARAM.toLowerCase();
    var NODE_DISABLE_S3_EXPRESS_SESSION_AUTH_ENV_NAME = "AWS_S3_DISABLE_EXPRESS_SESSION_AUTH";
    var NODE_DISABLE_S3_EXPRESS_SESSION_AUTH_INI_NAME = "s3_disable_express_session_auth";
    var NODE_DISABLE_S3_EXPRESS_SESSION_AUTH_OPTIONS = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => utilConfigProvider.booleanSelector(env3, NODE_DISABLE_S3_EXPRESS_SESSION_AUTH_ENV_NAME, utilConfigProvider.SelectorType.ENV), "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => utilConfigProvider.booleanSelector(profile, NODE_DISABLE_S3_EXPRESS_SESSION_AUTH_INI_NAME, utilConfigProvider.SelectorType.CONFIG), "configFileSelector"),
      default: false
    };
    var SignatureV4S3Express = class extends signatureV4.SignatureV4 {
      static {
        __name(this, "SignatureV4S3Express");
      }
      async signWithCredentials(requestToSign, credentials, options) {
        const credentialsWithoutSessionToken = getCredentialsWithoutSessionToken(credentials);
        requestToSign.headers[SESSION_TOKEN_HEADER] = credentials.sessionToken;
        const privateAccess = this;
        setSingleOverride(privateAccess, credentialsWithoutSessionToken);
        return privateAccess.signRequest(requestToSign, options ?? {});
      }
      async presignWithCredentials(requestToSign, credentials, options) {
        const credentialsWithoutSessionToken = getCredentialsWithoutSessionToken(credentials);
        delete requestToSign.headers[SESSION_TOKEN_HEADER];
        requestToSign.headers[SESSION_TOKEN_QUERY_PARAM] = credentials.sessionToken;
        requestToSign.query = requestToSign.query ?? {};
        requestToSign.query[SESSION_TOKEN_QUERY_PARAM] = credentials.sessionToken;
        const privateAccess = this;
        setSingleOverride(privateAccess, credentialsWithoutSessionToken);
        return this.presign(requestToSign, options);
      }
    };
    function getCredentialsWithoutSessionToken(credentials) {
      const credentialsWithoutSessionToken = {
        accessKeyId: credentials.accessKeyId,
        secretAccessKey: credentials.secretAccessKey,
        expiration: credentials.expiration
      };
      return credentialsWithoutSessionToken;
    }
    __name(getCredentialsWithoutSessionToken, "getCredentialsWithoutSessionToken");
    function setSingleOverride(privateAccess, credentialsWithoutSessionToken) {
      const id = setTimeout(() => {
        throw new Error("SignatureV4S3Express credential override was created but not called.");
      }, 10);
      const currentCredentialProvider = privateAccess.credentialProvider;
      const overrideCredentialsProviderOnce = /* @__PURE__ */ __name(() => {
        clearTimeout(id);
        privateAccess.credentialProvider = currentCredentialProvider;
        return Promise.resolve(credentialsWithoutSessionToken);
      }, "overrideCredentialsProviderOnce");
      privateAccess.credentialProvider = overrideCredentialsProviderOnce;
    }
    __name(setSingleOverride, "setSingleOverride");
    var s3ExpressMiddleware = /* @__PURE__ */ __name((options) => {
      return (next, context) => async (args) => {
        if (context.endpointV2) {
          const endpoint = context.endpointV2;
          const isS3ExpressAuth = endpoint.properties?.authSchemes?.[0]?.name === S3_EXPRESS_AUTH_SCHEME;
          const isS3ExpressBucket = endpoint.properties?.backend === S3_EXPRESS_BACKEND || endpoint.properties?.bucketType === S3_EXPRESS_BUCKET_TYPE;
          if (isS3ExpressBucket) {
            client.setFeature(context, "S3_EXPRESS_BUCKET", "J");
            context.isS3ExpressBucket = true;
          }
          if (isS3ExpressAuth) {
            const requestBucket = args.input.Bucket;
            if (requestBucket) {
              const s3ExpressIdentity = await options.s3ExpressIdentityProvider.getS3ExpressIdentity(await options.credentials(), {
                Bucket: requestBucket
              });
              context.s3ExpressIdentity = s3ExpressIdentity;
              if (protocolHttp.HttpRequest.isInstance(args.request) && s3ExpressIdentity.sessionToken) {
                args.request.headers[SESSION_TOKEN_HEADER] = s3ExpressIdentity.sessionToken;
              }
            }
          }
        }
        return next(args);
      };
    }, "s3ExpressMiddleware");
    var s3ExpressMiddlewareOptions = {
      name: "s3ExpressMiddleware",
      step: "build",
      tags: ["S3", "S3_EXPRESS"],
      override: true
    };
    var getS3ExpressPlugin = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(s3ExpressMiddleware(options), s3ExpressMiddlewareOptions);
      }, "applyToStack")
    }), "getS3ExpressPlugin");
    var signS3Express = /* @__PURE__ */ __name(async (s3ExpressIdentity, signingOptions, request4, sigV4MultiRegionSigner) => {
      const signedRequest = await sigV4MultiRegionSigner.signWithCredentials(request4, s3ExpressIdentity, {});
      if (signedRequest.headers["X-Amz-Security-Token"] || signedRequest.headers["x-amz-security-token"]) {
        throw new Error("X-Amz-Security-Token must not be set for s3-express requests.");
      }
      return signedRequest;
    }, "signS3Express");
    var defaultErrorHandler3 = /* @__PURE__ */ __name((signingProperties) => (error4) => {
      throw error4;
    }, "defaultErrorHandler");
    var defaultSuccessHandler3 = /* @__PURE__ */ __name((httpResponse, signingProperties) => {
    }, "defaultSuccessHandler");
    var s3ExpressHttpSigningMiddlewareOptions = core.httpSigningMiddlewareOptions;
    var s3ExpressHttpSigningMiddleware = /* @__PURE__ */ __name((config2) => (next, context) => async (args) => {
      if (!protocolHttp.HttpRequest.isInstance(args.request)) {
        return next(args);
      }
      const smithyContext = utilMiddleware.getSmithyContext(context);
      const scheme = smithyContext.selectedHttpAuthScheme;
      if (!scheme) {
        throw new Error(`No HttpAuthScheme was selected: unable to sign request`);
      }
      const { httpAuthOption: { signingProperties = {} }, identity, signer } = scheme;
      let request4;
      if (context.s3ExpressIdentity) {
        request4 = await signS3Express(context.s3ExpressIdentity, signingProperties, args.request, await config2.signer());
      } else {
        request4 = await signer.sign(args.request, identity, signingProperties);
      }
      const output = await next({
        ...args,
        request: request4
      }).catch((signer.errorHandler || defaultErrorHandler3)(signingProperties));
      (signer.successHandler || defaultSuccessHandler3)(output.response, signingProperties);
      return output;
    }, "s3ExpressHttpSigningMiddleware");
    var getS3ExpressHttpSigningPlugin = /* @__PURE__ */ __name((config2) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.addRelativeTo(s3ExpressHttpSigningMiddleware(config2), core.httpSigningMiddlewareOptions);
      }, "applyToStack")
    }), "getS3ExpressHttpSigningPlugin");
    var resolveS3Config = /* @__PURE__ */ __name((input, { session }) => {
      const [s3ClientProvider, CreateSessionCommandCtor] = session;
      const { forcePathStyle, useAccelerateEndpoint, disableMultiregionAccessPoints, followRegionRedirects, s3ExpressIdentityProvider, bucketEndpoint, expectContinueHeader } = input;
      return Object.assign(input, {
        forcePathStyle: forcePathStyle ?? false,
        useAccelerateEndpoint: useAccelerateEndpoint ?? false,
        disableMultiregionAccessPoints: disableMultiregionAccessPoints ?? false,
        followRegionRedirects: followRegionRedirects ?? false,
        s3ExpressIdentityProvider: s3ExpressIdentityProvider ?? new S3ExpressIdentityProviderImpl(async (key) => s3ClientProvider().send(new CreateSessionCommandCtor({
          Bucket: key
        }))),
        bucketEndpoint: bucketEndpoint ?? false,
        expectContinueHeader: expectContinueHeader ?? 2097152
      });
    }, "resolveS3Config");
    var THROW_IF_EMPTY_BODY = {
      CopyObjectCommand: true,
      UploadPartCopyCommand: true,
      CompleteMultipartUploadCommand: true
    };
    var throw200ExceptionsMiddleware = /* @__PURE__ */ __name((config2) => (next, context) => async (args) => {
      const result2 = await next(args);
      const { response } = result2;
      if (!protocolHttp.HttpResponse.isInstance(response)) {
        return result2;
      }
      const { statusCode, body } = response;
      if (statusCode < 200 || statusCode >= 300) {
        return result2;
      }
      const bodyBytes = await collectBody17(body, config2);
      response.body = toStream.toStream(bodyBytes);
      if (bodyBytes.length === 0 && THROW_IF_EMPTY_BODY[context.commandName]) {
        const err = new Error("S3 aborted request");
        err.$metadata = {
          httpStatusCode: 503
        };
        err.name = "InternalError";
        throw err;
      }
      const bodyStringTail = config2.utf8Encoder(bodyBytes.subarray(bodyBytes.length - 16));
      if (bodyStringTail && bodyStringTail.endsWith("</Error>")) {
        response.statusCode = 503;
      }
      return result2;
    }, "throw200ExceptionsMiddleware");
    var collectBody17 = /* @__PURE__ */ __name((streamBody = new Uint8Array(), context) => {
      if (streamBody instanceof Uint8Array) {
        return Promise.resolve(streamBody);
      }
      return context.streamCollector(streamBody) || Promise.resolve(new Uint8Array());
    }, "collectBody");
    var throw200ExceptionsMiddlewareOptions = {
      relation: "after",
      toMiddleware: "deserializerMiddleware",
      tags: ["THROW_200_EXCEPTIONS", "S3"],
      name: "throw200ExceptionsMiddleware",
      override: true
    };
    var getThrow200ExceptionsPlugin = /* @__PURE__ */ __name((config2) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.addRelativeTo(throw200ExceptionsMiddleware(config2), throw200ExceptionsMiddlewareOptions);
      }, "applyToStack")
    }), "getThrow200ExceptionsPlugin");
    function bucketEndpointMiddleware(options) {
      return (next, context) => async (args) => {
        if (options.bucketEndpoint) {
          const endpoint = context.endpointV2;
          if (endpoint) {
            const bucket = args.input.Bucket;
            if (typeof bucket === "string") {
              try {
                const bucketEndpointUrl = new URL(bucket);
                context.endpointV2 = {
                  ...endpoint,
                  url: bucketEndpointUrl
                };
              } catch (e32) {
                const warning2 = `@aws-sdk/middleware-sdk-s3: bucketEndpoint=true was set but Bucket=${bucket} could not be parsed as URL.`;
                if (context.logger?.constructor?.name === "NoOpLogger") {
                  console.warn(warning2);
                } else {
                  context.logger?.warn?.(warning2);
                }
                throw e32;
              }
            }
          }
        }
        return next(args);
      };
    }
    __name(bucketEndpointMiddleware, "bucketEndpointMiddleware");
    var bucketEndpointMiddlewareOptions = {
      name: "bucketEndpointMiddleware",
      override: true,
      relation: "after",
      toMiddleware: "endpointV2Middleware"
    };
    function validateBucketNameMiddleware({ bucketEndpoint }) {
      return (next) => async (args) => {
        const { input: { Bucket } } = args;
        if (!bucketEndpoint && typeof Bucket === "string" && !utilArnParser.validate(Bucket) && Bucket.indexOf("/") >= 0) {
          const err = new Error(`Bucket name shouldn't contain '/', received '${Bucket}'`);
          err.name = "InvalidBucketName";
          throw err;
        }
        return next({ ...args });
      };
    }
    __name(validateBucketNameMiddleware, "validateBucketNameMiddleware");
    var validateBucketNameMiddlewareOptions = {
      step: "initialize",
      tags: ["VALIDATE_BUCKET_NAME"],
      name: "validateBucketNameMiddleware",
      override: true
    };
    var getValidateBucketNamePlugin = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(validateBucketNameMiddleware(options), validateBucketNameMiddlewareOptions);
        clientStack.addRelativeTo(bucketEndpointMiddleware(options), bucketEndpointMiddlewareOptions);
      }, "applyToStack")
    }), "getValidateBucketNamePlugin");
    var S3RestXmlProtocol = class extends protocols.AwsRestXmlProtocol {
      static {
        __name(this, "S3RestXmlProtocol");
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        const ns = schema.NormalizedSchema.of(operationSchema.input);
        const staticStructureSchema = ns.getSchema();
        let bucketMemberIndex = 0;
        const requiredMemberCount = staticStructureSchema[6] ?? 0;
        if (input && typeof input === "object") {
          for (const [memberName, memberNs] of ns.structIterator()) {
            if (++bucketMemberIndex > requiredMemberCount) {
              break;
            }
            if (memberName === "Bucket") {
              if (!input.Bucket && memberNs.getMergedTraits().httpLabel) {
                throw new Error(`No value provided for input HTTP label: Bucket.`);
              }
              break;
            }
          }
        }
        return request4;
      }
    };
    exports2.NODE_DISABLE_S3_EXPRESS_SESSION_AUTH_OPTIONS = NODE_DISABLE_S3_EXPRESS_SESSION_AUTH_OPTIONS;
    exports2.S3ExpressIdentityCache = S3ExpressIdentityCache;
    exports2.S3ExpressIdentityCacheEntry = S3ExpressIdentityCacheEntry;
    exports2.S3ExpressIdentityProviderImpl = S3ExpressIdentityProviderImpl;
    exports2.S3RestXmlProtocol = S3RestXmlProtocol;
    exports2.SignatureV4S3Express = SignatureV4S3Express;
    exports2.checkContentLengthHeader = checkContentLengthHeader;
    exports2.checkContentLengthHeaderMiddlewareOptions = checkContentLengthHeaderMiddlewareOptions;
    exports2.getCheckContentLengthHeaderPlugin = getCheckContentLengthHeaderPlugin;
    exports2.getRegionRedirectMiddlewarePlugin = getRegionRedirectMiddlewarePlugin;
    exports2.getS3ExpiresMiddlewarePlugin = getS3ExpiresMiddlewarePlugin;
    exports2.getS3ExpressHttpSigningPlugin = getS3ExpressHttpSigningPlugin;
    exports2.getS3ExpressPlugin = getS3ExpressPlugin;
    exports2.getThrow200ExceptionsPlugin = getThrow200ExceptionsPlugin;
    exports2.getValidateBucketNamePlugin = getValidateBucketNamePlugin;
    exports2.regionRedirectEndpointMiddleware = regionRedirectEndpointMiddleware;
    exports2.regionRedirectEndpointMiddlewareOptions = regionRedirectEndpointMiddlewareOptions;
    exports2.regionRedirectMiddleware = regionRedirectMiddleware;
    exports2.regionRedirectMiddlewareOptions = regionRedirectMiddlewareOptions;
    exports2.resolveS3Config = resolveS3Config;
    exports2.s3ExpiresMiddleware = s3ExpiresMiddleware;
    exports2.s3ExpiresMiddlewareOptions = s3ExpiresMiddlewareOptions;
    exports2.s3ExpressHttpSigningMiddleware = s3ExpressHttpSigningMiddleware;
    exports2.s3ExpressHttpSigningMiddlewareOptions = s3ExpressHttpSigningMiddlewareOptions;
    exports2.s3ExpressMiddleware = s3ExpressMiddleware;
    exports2.s3ExpressMiddlewareOptions = s3ExpressMiddlewareOptions;
    exports2.throw200ExceptionsMiddleware = throw200ExceptionsMiddleware;
    exports2.throw200ExceptionsMiddlewareOptions = throw200ExceptionsMiddlewareOptions;
    exports2.validateBucketNameMiddleware = validateBucketNameMiddleware;
    exports2.validateBucketNameMiddlewareOptions = validateBucketNameMiddlewareOptions;
  }
});

// ../../node_modules/@aws-sdk/client-sts/node_modules/@aws-sdk/signature-v4-multi-region/dist-cjs/index.js
var require_dist_cjs109 = __commonJS({
  "../../node_modules/@aws-sdk/client-sts/node_modules/@aws-sdk/signature-v4-multi-region/dist-cjs/index.js"(exports2) {
    "use strict";
    var middlewareSdkS3 = require_dist_cjs108();
    var signatureV4 = require_dist_cjs36();
    var signatureV4CrtContainer = {
      CrtSignerV4: null
    };
    var SignatureV4MultiRegion19 = class {
      static {
        __name(this, "SignatureV4MultiRegion");
      }
      sigv4aSigner;
      sigv4Signer;
      signerOptions;
      static sigv4aDependency() {
        if (typeof signatureV4CrtContainer.CrtSignerV4 === "function") {
          return "crt";
        } else if (typeof signatureV4.signatureV4aContainer.SignatureV4a === "function") {
          return "js";
        }
        return "none";
      }
      constructor(options) {
        this.sigv4Signer = new middlewareSdkS3.SignatureV4S3Express(options);
        this.signerOptions = options;
      }
      async sign(requestToSign, options = {}) {
        if (options.signingRegion === "*") {
          return this.getSigv4aSigner().sign(requestToSign, options);
        }
        return this.sigv4Signer.sign(requestToSign, options);
      }
      async signWithCredentials(requestToSign, credentials, options = {}) {
        if (options.signingRegion === "*") {
          const signer = this.getSigv4aSigner();
          const CrtSignerV4 = signatureV4CrtContainer.CrtSignerV4;
          if (CrtSignerV4 && signer instanceof CrtSignerV4) {
            return signer.signWithCredentials(requestToSign, credentials, options);
          } else {
            throw new Error(`signWithCredentials with signingRegion '*' is only supported when using the CRT dependency @aws-sdk/signature-v4-crt. Please check whether you have installed the "@aws-sdk/signature-v4-crt" package explicitly. You must also register the package by calling [require("@aws-sdk/signature-v4-crt");] or an ESM equivalent such as [import "@aws-sdk/signature-v4-crt";]. For more information please go to https://github.com/aws/aws-sdk-js-v3#functionality-requiring-aws-common-runtime-crt`);
          }
        }
        return this.sigv4Signer.signWithCredentials(requestToSign, credentials, options);
      }
      async presign(originalRequest, options = {}) {
        if (options.signingRegion === "*") {
          const signer = this.getSigv4aSigner();
          const CrtSignerV4 = signatureV4CrtContainer.CrtSignerV4;
          if (CrtSignerV4 && signer instanceof CrtSignerV4) {
            return signer.presign(originalRequest, options);
          } else {
            throw new Error(`presign with signingRegion '*' is only supported when using the CRT dependency @aws-sdk/signature-v4-crt. Please check whether you have installed the "@aws-sdk/signature-v4-crt" package explicitly. You must also register the package by calling [require("@aws-sdk/signature-v4-crt");] or an ESM equivalent such as [import "@aws-sdk/signature-v4-crt";]. For more information please go to https://github.com/aws/aws-sdk-js-v3#functionality-requiring-aws-common-runtime-crt`);
          }
        }
        return this.sigv4Signer.presign(originalRequest, options);
      }
      async presignWithCredentials(originalRequest, credentials, options = {}) {
        if (options.signingRegion === "*") {
          throw new Error("Method presignWithCredentials is not supported for [signingRegion=*].");
        }
        return this.sigv4Signer.presignWithCredentials(originalRequest, credentials, options);
      }
      getSigv4aSigner() {
        if (!this.sigv4aSigner) {
          const CrtSignerV4 = signatureV4CrtContainer.CrtSignerV4;
          const JsSigV4aSigner = signatureV4.signatureV4aContainer.SignatureV4a;
          if (this.signerOptions.runtime === "node") {
            if (!CrtSignerV4 && !JsSigV4aSigner) {
              throw new Error("Neither CRT nor JS SigV4a implementation is available. Please load either @aws-sdk/signature-v4-crt or @aws-sdk/signature-v4a. For more information please go to https://github.com/aws/aws-sdk-js-v3#functionality-requiring-aws-common-runtime-crt");
            }
            if (CrtSignerV4 && typeof CrtSignerV4 === "function") {
              this.sigv4aSigner = new CrtSignerV4({
                ...this.signerOptions,
                signingAlgorithm: 1
              });
            } else if (JsSigV4aSigner && typeof JsSigV4aSigner === "function") {
              this.sigv4aSigner = new JsSigV4aSigner({
                ...this.signerOptions
              });
            } else {
              throw new Error("Available SigV4a implementation is not a valid constructor. Please ensure you've properly imported @aws-sdk/signature-v4-crt or @aws-sdk/signature-v4a.For more information please go to https://github.com/aws/aws-sdk-js-v3#functionality-requiring-aws-common-runtime-crt");
            }
          } else {
            if (!JsSigV4aSigner || typeof JsSigV4aSigner !== "function") {
              throw new Error("JS SigV4a implementation is not available or not a valid constructor. Please check whether you have installed the @aws-sdk/signature-v4a package explicitly. The CRT implementation is not available for browsers. You must also register the package by calling [require('@aws-sdk/signature-v4a');] or an ESM equivalent such as [import '@aws-sdk/signature-v4a';]. For more information please go to https://github.com/aws/aws-sdk-js-v3#using-javascript-non-crt-implementation-of-sigv4a");
            }
            this.sigv4aSigner = new JsSigV4aSigner({
              ...this.signerOptions
            });
          }
        }
        return this.sigv4aSigner;
      }
    };
    exports2.SignatureV4MultiRegion = SignatureV4MultiRegion19;
    exports2.signatureV4CrtContainer = signatureV4CrtContainer;
  }
});

// ../../node_modules/@aws-sdk/client-sts/dist-cjs/endpoint/bdd.js
var require_bdd4 = __commonJS({
  "../../node_modules/@aws-sdk/client-sts/dist-cjs/endpoint/bdd.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.bdd = void 0;
    var util_endpoints_1 = require_dist_cjs20();
    var q10 = "ref";
    var a32 = -1;
    var b32 = true;
    var c32 = "isSet";
    var d32 = "PartitionResult";
    var e32 = "booleanEquals";
    var f32 = "stringEquals";
    var g32 = "getAttr";
    var h32 = "us-east-1";
    var i32 = "sigv4";
    var j32 = "sts";
    var k32 = "https://sts.{Region}.{PartitionResult#dnsSuffix}";
    var l20 = { [q10]: "Endpoint" };
    var m20 = { [q10]: "Region" };
    var n10 = { [q10]: d32 };
    var o10 = {};
    var p10 = [m20];
    var _data32 = {
      conditions: [
        [c32, [l20]],
        [c32, p10],
        ["aws.partition", p10, d32],
        [e32, [{ [q10]: "UseFIPS" }, b32]],
        [e32, [{ [q10]: "UseDualStack" }, b32]],
        [f32, [m20, "aws-global"]],
        [e32, [{ [q10]: "UseGlobalEndpoint" }, b32]],
        [f32, [m20, "eu-central-1"]],
        [e32, [{ fn: g32, argv: [n10, "supportsDualStack"] }, b32]],
        [e32, [{ fn: g32, argv: [n10, "supportsFIPS"] }, b32]],
        [f32, [m20, "ap-south-1"]],
        [f32, [m20, "eu-north-1"]],
        [f32, [m20, "eu-west-1"]],
        [f32, [m20, "eu-west-2"]],
        [f32, [m20, "eu-west-3"]],
        [f32, [m20, "sa-east-1"]],
        [f32, [m20, h32]],
        [f32, [m20, "us-east-2"]],
        [f32, [m20, "us-west-2"]],
        [f32, [m20, "us-west-1"]],
        [f32, [m20, "ca-central-1"]],
        [f32, [m20, "ap-southeast-1"]],
        [f32, [m20, "ap-northeast-1"]],
        [f32, [m20, "ap-southeast-2"]],
        [f32, [{ fn: g32, argv: [n10, "name"] }, "aws-us-gov"]]
      ],
      results: [
        [a32],
        ["https://sts.amazonaws.com", { authSchemes: [{ name: i32, signingName: j32, signingRegion: h32 }] }],
        [k32, { authSchemes: [{ name: i32, signingName: j32, signingRegion: "{Region}" }] }],
        [a32, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a32, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [l20, o10],
        ["https://sts-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", o10],
        [a32, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://sts.{Region}.amazonaws.com", o10],
        ["https://sts-fips.{Region}.{PartitionResult#dnsSuffix}", o10],
        [a32, "FIPS is enabled but this partition does not support FIPS"],
        ["https://sts.{Region}.{PartitionResult#dualStackDnsSuffix}", o10],
        [a32, "DualStack is enabled but this partition does not support DualStack"],
        [k32, o10],
        [a32, "Invalid Configuration: Missing Region"]
      ]
    };
    var root32 = 2;
    var r32 = 1e8;
    var nodes32 = new Int32Array([
      -1,
      1,
      -1,
      0,
      30,
      3,
      1,
      4,
      r32 + 14,
      2,
      5,
      r32 + 14,
      3,
      25,
      6,
      4,
      24,
      7,
      5,
      r32 + 1,
      8,
      6,
      9,
      r32 + 13,
      7,
      r32 + 1,
      10,
      10,
      r32 + 1,
      11,
      11,
      r32 + 1,
      12,
      12,
      r32 + 1,
      13,
      13,
      r32 + 1,
      14,
      14,
      r32 + 1,
      15,
      15,
      r32 + 1,
      16,
      16,
      r32 + 1,
      17,
      17,
      r32 + 1,
      18,
      18,
      r32 + 1,
      19,
      19,
      r32 + 1,
      20,
      20,
      r32 + 1,
      21,
      21,
      r32 + 1,
      22,
      22,
      r32 + 1,
      23,
      23,
      r32 + 1,
      r32 + 2,
      8,
      r32 + 11,
      r32 + 12,
      4,
      28,
      26,
      9,
      27,
      r32 + 10,
      24,
      r32 + 8,
      r32 + 9,
      8,
      29,
      r32 + 7,
      9,
      r32 + 6,
      r32 + 7,
      3,
      r32 + 3,
      31,
      4,
      r32 + 4,
      r32 + 5
    ]);
    exports2.bdd = util_endpoints_1.BinaryDecisionDiagram.from(nodes32, root32, _data32.conditions, _data32.results);
  }
});

// ../../node_modules/@aws-sdk/client-sts/dist-cjs/endpoint/endpointResolver.js
var require_endpointResolver4 = __commonJS({
  "../../node_modules/@aws-sdk/client-sts/dist-cjs/endpoint/endpointResolver.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.defaultEndpointResolver = void 0;
    var util_endpoints_1 = require_dist_cjs21();
    var util_endpoints_2 = require_dist_cjs20();
    var bdd_1 = require_bdd4();
    var cache32 = new util_endpoints_2.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS", "UseGlobalEndpoint"]
    });
    var defaultEndpointResolver32 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache32.get(endpointParams, () => (0, util_endpoints_2.decideEndpoint)(bdd_1.bdd, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    exports2.defaultEndpointResolver = defaultEndpointResolver32;
    util_endpoints_2.customEndpointFunctions.aws = util_endpoints_1.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-sts/dist-cjs/auth/httpAuthSchemeProvider.js
var require_httpAuthSchemeProvider4 = __commonJS({
  "../../node_modules/@aws-sdk/client-sts/dist-cjs/auth/httpAuthSchemeProvider.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.resolveHttpAuthSchemeConfig = exports2.resolveStsAuthConfig = exports2.defaultSTSHttpAuthSchemeProvider = exports2.defaultSTSHttpAuthSchemeParametersProvider = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var signature_v4_multi_region_1 = require_dist_cjs109();
    var middleware_endpoint_1 = require_dist_cjs31();
    var util_middleware_1 = require_dist_cjs6();
    var endpointResolver_1 = require_endpointResolver4();
    var STSClient_1 = require_STSClient();
    var createEndpointRuleSetHttpAuthSchemeParametersProvider10 = /* @__PURE__ */ __name((defaultHttpAuthSchemeParametersProvider) => async (config2, context, input) => {
      if (!input) {
        throw new Error("Could not find `input` for `defaultEndpointRuleSetHttpAuthSchemeParametersProvider`");
      }
      const defaultParameters = await defaultHttpAuthSchemeParametersProvider(config2, context, input);
      const instructionsFn = (0, util_middleware_1.getSmithyContext)(context)?.commandInstance?.constructor?.getEndpointParameterInstructions;
      if (!instructionsFn) {
        throw new Error(`getEndpointParameterInstructions() is not defined on '${context.commandName}'`);
      }
      const endpointParameters = await (0, middleware_endpoint_1.resolveParams)(input, { getEndpointParameterInstructions: instructionsFn }, config2);
      return Object.assign(defaultParameters, endpointParameters);
    }, "createEndpointRuleSetHttpAuthSchemeParametersProvider");
    var _defaultSTSHttpAuthSchemeParametersProvider10 = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, util_middleware_1.getSmithyContext)(context).operation,
        region: await (0, util_middleware_1.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "_defaultSTSHttpAuthSchemeParametersProvider");
    exports2.defaultSTSHttpAuthSchemeParametersProvider = createEndpointRuleSetHttpAuthSchemeParametersProvider10(_defaultSTSHttpAuthSchemeParametersProvider10);
    function createAwsAuthSigv4HttpAuthOption32(authParameters) {
      return {
        schemeId: "aws.auth#sigv4",
        signingProperties: {
          name: "sts",
          region: authParameters.region
        },
        propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
          signingProperties: {
            config: config2,
            context
          }
        }), "propertiesExtractor")
      };
    }
    __name(createAwsAuthSigv4HttpAuthOption32, "createAwsAuthSigv4HttpAuthOption");
    function createAwsAuthSigv4aHttpAuthOption10(authParameters) {
      return {
        schemeId: "aws.auth#sigv4a",
        signingProperties: {
          name: "sts",
          region: authParameters.region
        },
        propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
          signingProperties: {
            config: config2,
            context
          }
        }), "propertiesExtractor")
      };
    }
    __name(createAwsAuthSigv4aHttpAuthOption10, "createAwsAuthSigv4aHttpAuthOption");
    function createSmithyApiNoAuthHttpAuthOption32(authParameters) {
      return {
        schemeId: "smithy.api#noAuth"
      };
    }
    __name(createSmithyApiNoAuthHttpAuthOption32, "createSmithyApiNoAuthHttpAuthOption");
    var createEndpointRuleSetHttpAuthSchemeProvider10 = /* @__PURE__ */ __name((defaultEndpointResolver32, defaultHttpAuthSchemeResolver, createHttpAuthOptionFunctions) => {
      const endpointRuleSetHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
        const endpoint = defaultEndpointResolver32(authParameters);
        const authSchemes = endpoint.properties?.authSchemes;
        if (!authSchemes) {
          return defaultHttpAuthSchemeResolver(authParameters);
        }
        const options = [];
        for (const scheme of authSchemes) {
          const { name: resolvedName, properties = {}, ...rest } = scheme;
          const name = resolvedName.toLowerCase();
          if (resolvedName !== name) {
            console.warn(`HttpAuthScheme has been normalized with lowercasing: '${resolvedName}' to '${name}'`);
          }
          let schemeId;
          if (name === "sigv4a") {
            schemeId = "aws.auth#sigv4a";
            const sigv4Present = authSchemes.find((s) => {
              const name2 = s.name.toLowerCase();
              return name2 !== "sigv4a" && name2.startsWith("sigv4");
            });
            if (signature_v4_multi_region_1.SignatureV4MultiRegion.sigv4aDependency() === "none" && sigv4Present) {
              continue;
            }
          } else if (name.startsWith("sigv4")) {
            schemeId = "aws.auth#sigv4";
          } else {
            throw new Error(`Unknown HttpAuthScheme found in '@smithy.rules#endpointRuleSet': '${name}'`);
          }
          const createOption = createHttpAuthOptionFunctions[schemeId];
          if (!createOption) {
            throw new Error(`Could not find HttpAuthOption create function for '${schemeId}'`);
          }
          const option = createOption(authParameters);
          option.schemeId = schemeId;
          option.signingProperties = { ...option.signingProperties || {}, ...rest, ...properties };
          options.push(option);
        }
        return options;
      }, "endpointRuleSetHttpAuthSchemeProvider");
      return endpointRuleSetHttpAuthSchemeProvider;
    }, "createEndpointRuleSetHttpAuthSchemeProvider");
    var _defaultSTSHttpAuthSchemeProvider10 = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "AssumeRoleWithSAML": {
          options.push(createSmithyApiNoAuthHttpAuthOption32(authParameters));
          options.push(createAwsAuthSigv4aHttpAuthOption10(authParameters));
          break;
        }
        case "AssumeRoleWithWebIdentity": {
          options.push(createSmithyApiNoAuthHttpAuthOption32(authParameters));
          options.push(createAwsAuthSigv4aHttpAuthOption10(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption32(authParameters));
          options.push(createAwsAuthSigv4aHttpAuthOption10(authParameters));
        }
      }
      return options;
    }, "_defaultSTSHttpAuthSchemeProvider");
    exports2.defaultSTSHttpAuthSchemeProvider = createEndpointRuleSetHttpAuthSchemeProvider10(endpointResolver_1.defaultEndpointResolver, _defaultSTSHttpAuthSchemeProvider10, {
      "aws.auth#sigv4": createAwsAuthSigv4HttpAuthOption32,
      "aws.auth#sigv4a": createAwsAuthSigv4aHttpAuthOption10,
      "smithy.api#noAuth": createSmithyApiNoAuthHttpAuthOption32
    });
    var resolveStsAuthConfig9 = /* @__PURE__ */ __name((input) => Object.assign(input, {
      stsClientCtor: STSClient_1.STSClient
    }), "resolveStsAuthConfig");
    exports2.resolveStsAuthConfig = resolveStsAuthConfig9;
    var resolveHttpAuthSchemeConfig32 = /* @__PURE__ */ __name((config2) => {
      const config_0 = (0, exports2.resolveStsAuthConfig)(config2);
      const config_1 = (0, httpAuthSchemes_1.resolveAwsSdkSigV4Config)(config_0);
      const config_2 = (0, httpAuthSchemes_1.resolveAwsSdkSigV4AConfig)(config_1);
      return Object.assign(config_2, {
        authSchemePreference: (0, util_middleware_1.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
    exports2.resolveHttpAuthSchemeConfig = resolveHttpAuthSchemeConfig32;
  }
});

// ../../node_modules/@aws-sdk/client-sts/dist-cjs/endpoint/EndpointParameters.js
var require_EndpointParameters = __commonJS({
  "../../node_modules/@aws-sdk/client-sts/dist-cjs/endpoint/EndpointParameters.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.commonParams = exports2.resolveClientEndpointParameters = void 0;
    var resolveClientEndpointParameters32 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        useGlobalEndpoint: options.useGlobalEndpoint ?? false,
        defaultSigningName: "sts"
      });
    }, "resolveClientEndpointParameters");
    exports2.resolveClientEndpointParameters = resolveClientEndpointParameters32;
    exports2.commonParams = {
      UseGlobalEndpoint: { type: "builtInParams", name: "useGlobalEndpoint" },
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/client-sts/package.json
var require_package4 = __commonJS({
  "../../node_modules/@aws-sdk/client-sts/package.json"(exports2, module2) {
    module2.exports = {
      name: "@aws-sdk/client-sts",
      description: "AWS SDK for JavaScript Sts Client for Node.js, Browser and React Native",
      version: "3.1036.0",
      scripts: {
        build: "concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline client-sts",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "premove ./dist-types tsconfig.types.tsbuildinfo && tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        "extract:docs": "api-extractor run --local",
        "generate:client": "node ../../scripts/generate-clients/single-service --solo sts",
        test: "yarn g:vitest run",
        "test:e2e": "yarn g:vitest run -c vitest.config.e2e.mts --mode development",
        "test:e2e:watch": "yarn g:vitest watch -c vitest.config.e2e.mts",
        "test:index": "tsc --noEmit ./test/index-types.ts && node ./test/index-objects.spec.mjs",
        "test:integration": "yarn g:vitest run --passWithNoTests -c vitest.config.integ.mts",
        "test:integration:watch": "yarn g:vitest run --passWithNoTests -c vitest.config.integ.mts",
        "test:watch": "yarn g:vitest watch"
      },
      main: "./dist-cjs/index.js",
      types: "./dist-types/index.d.ts",
      module: "./dist-es/index.js",
      sideEffects: false,
      dependencies: {
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.5",
        "@aws-sdk/credential-provider-node": "^3.972.36",
        "@aws-sdk/middleware-host-header": "^3.972.10",
        "@aws-sdk/middleware-logger": "^3.972.10",
        "@aws-sdk/middleware-recursion-detection": "^3.972.11",
        "@aws-sdk/middleware-user-agent": "^3.972.35",
        "@aws-sdk/region-config-resolver": "^3.972.13",
        "@aws-sdk/signature-v4-multi-region": "^3.996.22",
        "@aws-sdk/types": "^3.973.8",
        "@aws-sdk/util-endpoints": "^3.996.8",
        "@aws-sdk/util-user-agent-browser": "^3.972.10",
        "@aws-sdk/util-user-agent-node": "^3.973.21",
        "@smithy/config-resolver": "^4.4.17",
        "@smithy/core": "^3.23.17",
        "@smithy/fetch-http-handler": "^5.3.17",
        "@smithy/hash-node": "^4.2.14",
        "@smithy/invalid-dependency": "^4.2.14",
        "@smithy/middleware-content-length": "^4.2.14",
        "@smithy/middleware-endpoint": "^4.4.32",
        "@smithy/middleware-retry": "^4.5.5",
        "@smithy/middleware-serde": "^4.2.20",
        "@smithy/middleware-stack": "^4.2.14",
        "@smithy/node-config-provider": "^4.3.14",
        "@smithy/node-http-handler": "^4.6.1",
        "@smithy/protocol-http": "^5.3.14",
        "@smithy/smithy-client": "^4.12.13",
        "@smithy/types": "^4.14.1",
        "@smithy/url-parser": "^4.2.14",
        "@smithy/util-base64": "^4.3.2",
        "@smithy/util-body-length-browser": "^4.2.2",
        "@smithy/util-body-length-node": "^4.2.3",
        "@smithy/util-defaults-mode-browser": "^4.3.49",
        "@smithy/util-defaults-mode-node": "^4.2.54",
        "@smithy/util-endpoints": "^3.4.2",
        "@smithy/util-middleware": "^4.2.14",
        "@smithy/util-retry": "^4.3.4",
        "@smithy/util-utf8": "^4.2.2",
        tslib: "^2.6.2"
      },
      devDependencies: {
        "@smithy/snapshot-testing": "^2.0.8",
        "@tsconfig/node20": "20.1.8",
        "@types/node": "^20.14.8",
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3",
        vitest: "^4.0.17"
      },
      engines: {
        node: ">=20.0.0"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "dist-*/**"
      ],
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      browser: {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.browser"
      },
      "react-native": {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.native"
      },
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/clients/client-sts",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "clients/client-sts"
      }
    };
  }
});

// ../../node_modules/@aws-sdk/credential-provider-env/dist-cjs/index.js
var require_dist_cjs110 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-env/dist-cjs/index.js"(exports2) {
    "use strict";
    var client = (init_client8(), __toCommonJS(client_exports7));
    var propertyProvider = require_dist_cjs27();
    var ENV_KEY = "AWS_ACCESS_KEY_ID";
    var ENV_SECRET = "AWS_SECRET_ACCESS_KEY";
    var ENV_SESSION = "AWS_SESSION_TOKEN";
    var ENV_EXPIRATION = "AWS_CREDENTIAL_EXPIRATION";
    var ENV_CREDENTIAL_SCOPE = "AWS_CREDENTIAL_SCOPE";
    var ENV_ACCOUNT_ID = "AWS_ACCOUNT_ID";
    var fromEnv6 = /* @__PURE__ */ __name((init) => async () => {
      init?.logger?.debug("@aws-sdk/credential-provider-env - fromEnv");
      const accessKeyId = process.env[ENV_KEY];
      const secretAccessKey = process.env[ENV_SECRET];
      const sessionToken = process.env[ENV_SESSION];
      const expiry = process.env[ENV_EXPIRATION];
      const credentialScope = process.env[ENV_CREDENTIAL_SCOPE];
      const accountId = process.env[ENV_ACCOUNT_ID];
      if (accessKeyId && secretAccessKey) {
        const credentials = {
          accessKeyId,
          secretAccessKey,
          ...sessionToken && { sessionToken },
          ...expiry && { expiration: new Date(expiry) },
          ...credentialScope && { credentialScope },
          ...accountId && { accountId }
        };
        client.setCredentialFeature(credentials, "CREDENTIALS_ENV_VARS", "g");
        return credentials;
      }
      throw new propertyProvider.CredentialsProviderError("Unable to find environment variable credentials.", { logger: init?.logger });
    }, "fromEnv");
    exports2.ENV_ACCOUNT_ID = ENV_ACCOUNT_ID;
    exports2.ENV_CREDENTIAL_SCOPE = ENV_CREDENTIAL_SCOPE;
    exports2.ENV_EXPIRATION = ENV_EXPIRATION;
    exports2.ENV_KEY = ENV_KEY;
    exports2.ENV_SECRET = ENV_SECRET;
    exports2.ENV_SESSION = ENV_SESSION;
    exports2.fromEnv = fromEnv6;
  }
});

// ../../node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/checkUrl.js
var require_checkUrl4 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/checkUrl.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.checkUrl = void 0;
    var property_provider_1 = require_dist_cjs27();
    var ECS_CONTAINER_HOST = "169.254.170.2";
    var EKS_CONTAINER_HOST_IPv4 = "169.254.170.23";
    var EKS_CONTAINER_HOST_IPv6 = "[fd00:ec2::23]";
    var checkUrl = /* @__PURE__ */ __name((url, logger5) => {
      if (url.protocol === "https:") {
        return;
      }
      if (url.hostname === ECS_CONTAINER_HOST || url.hostname === EKS_CONTAINER_HOST_IPv4 || url.hostname === EKS_CONTAINER_HOST_IPv6) {
        return;
      }
      if (url.hostname.includes("[")) {
        if (url.hostname === "[::1]" || url.hostname === "[0000:0000:0000:0000:0000:0000:0000:0001]") {
          return;
        }
      } else {
        if (url.hostname === "localhost") {
          return;
        }
        const ipComponents = url.hostname.split(".");
        const inRange = /* @__PURE__ */ __name((component) => {
          const num = parseInt(component, 10);
          return 0 <= num && num <= 255;
        }, "inRange");
        if (ipComponents[0] === "127" && inRange(ipComponents[1]) && inRange(ipComponents[2]) && inRange(ipComponents[3]) && ipComponents.length === 4) {
          return;
        }
      }
      throw new property_provider_1.CredentialsProviderError(`URL not accepted. It must either be HTTPS or match one of the following:
  - loopback CIDR 127.0.0.0/8 or [::1/128]
  - ECS container host 169.254.170.2
  - EKS container host 169.254.170.23 or [fd00:ec2::23]`, { logger: logger5 });
    }, "checkUrl");
    exports2.checkUrl = checkUrl;
  }
});

// ../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.js
var require_ChecksumStream6 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ChecksumStream = void 0;
    var util_base64_1 = require_dist_cjs10();
    var stream_1 = require("stream");
    var ChecksumStream5 = class extends stream_1.Duplex {
      static {
        __name(this, "ChecksumStream");
      }
      expectedChecksum;
      checksumSourceLocation;
      checksum;
      source;
      base64Encoder;
      pendingCallback = null;
      constructor({ expectedChecksum, checksum, source, checksumSourceLocation, base64Encoder }) {
        super();
        if (typeof source.pipe === "function") {
          this.source = source;
        } else {
          throw new Error(`@smithy/util-stream: unsupported source type ${source?.constructor?.name ?? source} in ChecksumStream.`);
        }
        this.base64Encoder = base64Encoder ?? util_base64_1.toBase64;
        this.expectedChecksum = expectedChecksum;
        this.checksum = checksum;
        this.checksumSourceLocation = checksumSourceLocation;
        this.source.pipe(this);
      }
      _read(size) {
        if (this.pendingCallback) {
          const callback = this.pendingCallback;
          this.pendingCallback = null;
          callback();
        }
      }
      _write(chunk, encoding, callback) {
        try {
          this.checksum.update(chunk);
          const canPushMore = this.push(chunk);
          if (!canPushMore) {
            this.pendingCallback = callback;
            return;
          }
        } catch (e32) {
          return callback(e32);
        }
        return callback();
      }
      async _final(callback) {
        try {
          const digest = await this.checksum.digest();
          const received = this.base64Encoder(digest);
          if (this.expectedChecksum !== received) {
            return callback(new Error(`Checksum mismatch: expected "${this.expectedChecksum}" but received "${received}" in response header "${this.checksumSourceLocation}".`));
          }
        } catch (e32) {
          return callback(e32);
        }
        this.push(null);
        return callback();
      }
    };
    exports2.ChecksumStream = ChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/stream-type-check.js
var require_stream_type_check6 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/stream-type-check.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isBlob = exports2.isReadableStream = void 0;
    var isReadableStream6 = /* @__PURE__ */ __name((stream) => typeof ReadableStream === "function" && (stream?.constructor?.name === ReadableStream.name || stream instanceof ReadableStream), "isReadableStream");
    exports2.isReadableStream = isReadableStream6;
    var isBlob3 = /* @__PURE__ */ __name((blob) => {
      return typeof Blob === "function" && (blob?.constructor?.name === Blob.name || blob instanceof Blob);
    }, "isBlob");
    exports2.isBlob = isBlob3;
  }
});

// ../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.browser.js
var require_ChecksumStream_browser6 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ChecksumStream = void 0;
    var ReadableStreamRef3 = typeof ReadableStream === "function" ? ReadableStream : function() {
    };
    var ChecksumStream5 = class extends ReadableStreamRef3 {
      static {
        __name(this, "ChecksumStream");
      }
    };
    exports2.ChecksumStream = ChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.browser.js
var require_createChecksumStream_browser6 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createChecksumStream = void 0;
    var util_base64_1 = require_dist_cjs10();
    var stream_type_check_1 = require_stream_type_check6();
    var ChecksumStream_browser_1 = require_ChecksumStream_browser6();
    var createChecksumStream5 = /* @__PURE__ */ __name(({ expectedChecksum, checksum, source, checksumSourceLocation, base64Encoder }) => {
      if (!(0, stream_type_check_1.isReadableStream)(source)) {
        throw new Error(`@smithy/util-stream: unsupported source type ${source?.constructor?.name ?? source} in ChecksumStream.`);
      }
      const encoder = base64Encoder ?? util_base64_1.toBase64;
      if (typeof TransformStream !== "function") {
        throw new Error("@smithy/util-stream: unable to instantiate ChecksumStream because API unavailable: ReadableStream/TransformStream.");
      }
      const transform = new TransformStream({
        start() {
        },
        async transform(chunk, controller) {
          checksum.update(chunk);
          controller.enqueue(chunk);
        },
        async flush(controller) {
          const digest = await checksum.digest();
          const received = encoder(digest);
          if (expectedChecksum !== received) {
            const error4 = new Error(`Checksum mismatch: expected "${expectedChecksum}" but received "${received}" in response header "${checksumSourceLocation}".`);
            controller.error(error4);
          } else {
            controller.terminate();
          }
        }
      });
      source.pipeThrough(transform);
      const readable = transform.readable;
      Object.setPrototypeOf(readable, ChecksumStream_browser_1.ChecksumStream.prototype);
      return readable;
    }, "createChecksumStream");
    exports2.createChecksumStream = createChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.js
var require_createChecksumStream6 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createChecksumStream = createChecksumStream5;
    var stream_type_check_1 = require_stream_type_check6();
    var ChecksumStream_1 = require_ChecksumStream6();
    var createChecksumStream_browser_1 = require_createChecksumStream_browser6();
    function createChecksumStream5(init) {
      if (typeof ReadableStream === "function" && (0, stream_type_check_1.isReadableStream)(init.source)) {
        return (0, createChecksumStream_browser_1.createChecksumStream)(init);
      }
      return new ChecksumStream_1.ChecksumStream(init);
    }
    __name(createChecksumStream5, "createChecksumStream");
  }
});

// ../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/ByteArrayCollector.js
var require_ByteArrayCollector6 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/ByteArrayCollector.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ByteArrayCollector = void 0;
    var ByteArrayCollector3 = class {
      static {
        __name(this, "ByteArrayCollector");
      }
      allocByteArray;
      byteLength = 0;
      byteArrays = [];
      constructor(allocByteArray) {
        this.allocByteArray = allocByteArray;
      }
      push(byteArray) {
        this.byteArrays.push(byteArray);
        this.byteLength += byteArray.byteLength;
      }
      flush() {
        if (this.byteArrays.length === 1) {
          const bytes = this.byteArrays[0];
          this.reset();
          return bytes;
        }
        const aggregation = this.allocByteArray(this.byteLength);
        let cursor3 = 0;
        for (let i32 = 0; i32 < this.byteArrays.length; ++i32) {
          const bytes = this.byteArrays[i32];
          aggregation.set(bytes, cursor3);
          cursor3 += bytes.byteLength;
        }
        this.reset();
        return aggregation;
      }
      reset() {
        this.byteArrays = [];
        this.byteLength = 0;
      }
    };
    exports2.ByteArrayCollector = ByteArrayCollector3;
  }
});

// ../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadableStream.js
var require_createBufferedReadableStream6 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadableStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createBufferedReadable = void 0;
    exports2.createBufferedReadableStream = createBufferedReadableStream3;
    exports2.merge = merge3;
    exports2.flush = flush3;
    exports2.sizeOf = sizeOf3;
    exports2.modeOf = modeOf3;
    var ByteArrayCollector_1 = require_ByteArrayCollector6();
    function createBufferedReadableStream3(upstream, size, logger5) {
      const reader = upstream.getReader();
      let streamBufferingLoggedWarning = false;
      let bytesSeen = 0;
      const buffers = ["", new ByteArrayCollector_1.ByteArrayCollector((size2) => new Uint8Array(size2))];
      let mode = -1;
      const pull = /* @__PURE__ */ __name(async (controller) => {
        const { value, done } = await reader.read();
        const chunk = value;
        if (done) {
          if (mode !== -1) {
            const remainder = flush3(buffers, mode);
            if (sizeOf3(remainder) > 0) {
              controller.enqueue(remainder);
            }
          }
          controller.close();
        } else {
          const chunkMode = modeOf3(chunk, false);
          if (mode !== chunkMode) {
            if (mode >= 0) {
              controller.enqueue(flush3(buffers, mode));
            }
            mode = chunkMode;
          }
          if (mode === -1) {
            controller.enqueue(chunk);
            return;
          }
          const chunkSize = sizeOf3(chunk);
          bytesSeen += chunkSize;
          const bufferSize = sizeOf3(buffers[mode]);
          if (chunkSize >= size && bufferSize === 0) {
            controller.enqueue(chunk);
          } else {
            const newSize = merge3(buffers, mode, chunk);
            if (!streamBufferingLoggedWarning && bytesSeen > size * 2) {
              streamBufferingLoggedWarning = true;
              logger5?.warn(`@smithy/util-stream - stream chunk size ${chunkSize} is below threshold of ${size}, automatically buffering.`);
            }
            if (newSize >= size) {
              controller.enqueue(flush3(buffers, mode));
            } else {
              await pull(controller);
            }
          }
        }
      }, "pull");
      return new ReadableStream({
        pull
      });
    }
    __name(createBufferedReadableStream3, "createBufferedReadableStream");
    exports2.createBufferedReadable = createBufferedReadableStream3;
    function merge3(buffers, mode, chunk) {
      switch (mode) {
        case 0:
          buffers[0] += chunk;
          return sizeOf3(buffers[0]);
        case 1:
        case 2:
          buffers[mode].push(chunk);
          return sizeOf3(buffers[mode]);
      }
    }
    __name(merge3, "merge");
    function flush3(buffers, mode) {
      switch (mode) {
        case 0:
          const s = buffers[0];
          buffers[0] = "";
          return s;
        case 1:
        case 2:
          return buffers[mode].flush();
      }
      throw new Error(`@smithy/util-stream - invalid index ${mode} given to flush()`);
    }
    __name(flush3, "flush");
    function sizeOf3(chunk) {
      return chunk?.byteLength ?? chunk?.length ?? 0;
    }
    __name(sizeOf3, "sizeOf");
    function modeOf3(chunk, allowBuffer = true) {
      if (allowBuffer && typeof Buffer !== "undefined" && chunk instanceof Buffer) {
        return 2;
      }
      if (chunk instanceof Uint8Array) {
        return 1;
      }
      if (typeof chunk === "string") {
        return 0;
      }
      return -1;
    }
    __name(modeOf3, "modeOf");
  }
});

// ../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadable.js
var require_createBufferedReadable6 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadable.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createBufferedReadable = createBufferedReadable3;
    var node_stream_1 = require("node:stream");
    var ByteArrayCollector_1 = require_ByteArrayCollector6();
    var createBufferedReadableStream_1 = require_createBufferedReadableStream6();
    var stream_type_check_1 = require_stream_type_check6();
    function createBufferedReadable3(upstream, size, logger5) {
      if ((0, stream_type_check_1.isReadableStream)(upstream)) {
        return (0, createBufferedReadableStream_1.createBufferedReadableStream)(upstream, size, logger5);
      }
      const downstream = new node_stream_1.Readable({ read() {
      } });
      let streamBufferingLoggedWarning = false;
      let bytesSeen = 0;
      const buffers = [
        "",
        new ByteArrayCollector_1.ByteArrayCollector((size2) => new Uint8Array(size2)),
        new ByteArrayCollector_1.ByteArrayCollector((size2) => Buffer.from(new Uint8Array(size2)))
      ];
      let mode = -1;
      upstream.on("data", (chunk) => {
        const chunkMode = (0, createBufferedReadableStream_1.modeOf)(chunk, true);
        if (mode !== chunkMode) {
          if (mode >= 0) {
            downstream.push((0, createBufferedReadableStream_1.flush)(buffers, mode));
          }
          mode = chunkMode;
        }
        if (mode === -1) {
          downstream.push(chunk);
          return;
        }
        const chunkSize = (0, createBufferedReadableStream_1.sizeOf)(chunk);
        bytesSeen += chunkSize;
        const bufferSize = (0, createBufferedReadableStream_1.sizeOf)(buffers[mode]);
        if (chunkSize >= size && bufferSize === 0) {
          downstream.push(chunk);
        } else {
          const newSize = (0, createBufferedReadableStream_1.merge)(buffers, mode, chunk);
          if (!streamBufferingLoggedWarning && bytesSeen > size * 2) {
            streamBufferingLoggedWarning = true;
            logger5?.warn(`@smithy/util-stream - stream chunk size ${chunkSize} is below threshold of ${size}, automatically buffering.`);
          }
          if (newSize >= size) {
            downstream.push((0, createBufferedReadableStream_1.flush)(buffers, mode));
          }
        }
      });
      upstream.on("end", () => {
        if (mode !== -1) {
          const remainder = (0, createBufferedReadableStream_1.flush)(buffers, mode);
          if ((0, createBufferedReadableStream_1.sizeOf)(remainder) > 0) {
            downstream.push(remainder);
          }
        }
        downstream.push(null);
      });
      return downstream;
    }
    __name(createBufferedReadable3, "createBufferedReadable");
  }
});

// ../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.browser.js
var require_getAwsChunkedEncodingStream_browser6 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getAwsChunkedEncodingStream = void 0;
    var getAwsChunkedEncodingStream5 = /* @__PURE__ */ __name((readableStream, options) => {
      const { base64Encoder, bodyLengthChecker, checksumAlgorithmFn, checksumLocationName, streamHasher } = options;
      const checksumRequired = base64Encoder !== void 0 && bodyLengthChecker !== void 0 && checksumAlgorithmFn !== void 0 && checksumLocationName !== void 0 && streamHasher !== void 0;
      const digest = checksumRequired ? streamHasher(checksumAlgorithmFn, readableStream) : void 0;
      const reader = readableStream.getReader();
      return new ReadableStream({
        async pull(controller) {
          const { value, done } = await reader.read();
          if (done) {
            controller.enqueue(`0\r
`);
            if (checksumRequired) {
              const checksum = base64Encoder(await digest);
              controller.enqueue(`${checksumLocationName}:${checksum}\r
`);
              controller.enqueue(`\r
`);
            }
            controller.close();
          } else {
            controller.enqueue(`${(bodyLengthChecker(value) || 0).toString(16)}\r
${value}\r
`);
          }
        }
      });
    }, "getAwsChunkedEncodingStream");
    exports2.getAwsChunkedEncodingStream = getAwsChunkedEncodingStream5;
  }
});

// ../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.js
var require_getAwsChunkedEncodingStream6 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getAwsChunkedEncodingStream = getAwsChunkedEncodingStream5;
    var node_stream_1 = require("node:stream");
    var getAwsChunkedEncodingStream_browser_1 = require_getAwsChunkedEncodingStream_browser6();
    var stream_type_check_1 = require_stream_type_check6();
    function getAwsChunkedEncodingStream5(stream, options) {
      const readable = stream;
      const readableStream = stream;
      if ((0, stream_type_check_1.isReadableStream)(readableStream)) {
        return (0, getAwsChunkedEncodingStream_browser_1.getAwsChunkedEncodingStream)(readableStream, options);
      }
      const { base64Encoder, bodyLengthChecker, checksumAlgorithmFn, checksumLocationName, streamHasher } = options;
      const checksumRequired = base64Encoder !== void 0 && checksumAlgorithmFn !== void 0 && checksumLocationName !== void 0 && streamHasher !== void 0;
      const digest = checksumRequired ? streamHasher(checksumAlgorithmFn, readable) : void 0;
      const awsChunkedEncodingStream = new node_stream_1.Readable({
        read: /* @__PURE__ */ __name(() => {
        }, "read")
      });
      readable.on("data", (data3) => {
        const length = bodyLengthChecker(data3) || 0;
        if (length === 0) {
          return;
        }
        awsChunkedEncodingStream.push(`${length.toString(16)}\r
`);
        awsChunkedEncodingStream.push(data3);
        awsChunkedEncodingStream.push("\r\n");
      });
      readable.on("end", async () => {
        awsChunkedEncodingStream.push(`0\r
`);
        if (checksumRequired) {
          const checksum = base64Encoder(await digest);
          awsChunkedEncodingStream.push(`${checksumLocationName}:${checksum}\r
`);
          awsChunkedEncodingStream.push(`\r
`);
        }
        awsChunkedEncodingStream.push(null);
      });
      return awsChunkedEncodingStream;
    }
    __name(getAwsChunkedEncodingStream5, "getAwsChunkedEncodingStream");
  }
});

// ../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/headStream.browser.js
var require_headStream_browser6 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/headStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.headStream = headStream5;
    async function headStream5(stream, bytes) {
      let byteLengthCounter = 0;
      const chunks2 = [];
      const reader = stream.getReader();
      let isDone = false;
      while (!isDone) {
        const { done, value } = await reader.read();
        if (value) {
          chunks2.push(value);
          byteLengthCounter += value?.byteLength ?? 0;
        }
        if (byteLengthCounter >= bytes) {
          break;
        }
        isDone = done;
      }
      reader.releaseLock();
      const collected = new Uint8Array(Math.min(bytes, byteLengthCounter));
      let offset = 0;
      for (const chunk of chunks2) {
        if (chunk.byteLength > collected.byteLength - offset) {
          collected.set(chunk.subarray(0, collected.byteLength - offset), offset);
          break;
        } else {
          collected.set(chunk, offset);
        }
        offset += chunk.length;
      }
      return collected;
    }
    __name(headStream5, "headStream");
  }
});

// ../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/headStream.js
var require_headStream6 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/headStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.headStream = void 0;
    var stream_1 = require("stream");
    var headStream_browser_1 = require_headStream_browser6();
    var stream_type_check_1 = require_stream_type_check6();
    var headStream5 = /* @__PURE__ */ __name((stream, bytes) => {
      if ((0, stream_type_check_1.isReadableStream)(stream)) {
        return (0, headStream_browser_1.headStream)(stream, bytes);
      }
      return new Promise((resolve13, reject) => {
        const collector = new Collector8();
        collector.limit = bytes;
        stream.pipe(collector);
        stream.on("error", (err) => {
          collector.end();
          reject(err);
        });
        collector.on("error", reject);
        collector.on("finish", function() {
          const bytes2 = new Uint8Array(Buffer.concat(this.buffers));
          resolve13(bytes2);
        });
      });
    }, "headStream");
    exports2.headStream = headStream5;
    var Collector8 = class extends stream_1.Writable {
      static {
        __name(this, "Collector");
      }
      buffers = [];
      limit = Infinity;
      bytesBuffered = 0;
      _write(chunk, encoding, callback) {
        this.buffers.push(chunk);
        this.bytesBuffered += chunk.byteLength ?? 0;
        if (this.bytesBuffered >= this.limit) {
          const excess = this.bytesBuffered - this.limit;
          const tailBuffer = this.buffers[this.buffers.length - 1];
          this.buffers[this.buffers.length - 1] = tailBuffer.subarray(0, tailBuffer.byteLength - excess);
          this.emit("finish");
        }
        callback();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.browser.js
var require_sdk_stream_mixin_browser6 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.sdkStreamMixin = void 0;
    var fetch_http_handler_1 = require_dist_cjs14();
    var util_base64_1 = require_dist_cjs10();
    var util_hex_encoding_1 = require_dist_cjs15();
    var util_utf8_1 = require_dist_cjs9();
    var stream_type_check_1 = require_stream_type_check6();
    var ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11 = "The stream has already been transformed.";
    var sdkStreamMixin12 = /* @__PURE__ */ __name((stream) => {
      if (!isBlobInstance6(stream) && !(0, stream_type_check_1.isReadableStream)(stream)) {
        const name = stream?.__proto__?.constructor?.name || stream;
        throw new Error(`Unexpected stream implementation, expect Blob or ReadableStream, got ${name}`);
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
        }
        transformed = true;
        return await (0, fetch_http_handler_1.streamCollector)(stream);
      }, "transformToByteArray");
      const blobToWebStream = /* @__PURE__ */ __name((blob) => {
        if (typeof blob.stream !== "function") {
          throw new Error("Cannot transform payload Blob to web stream. Please make sure the Blob.stream() is polyfilled.\nIf you are using React Native, this API is not yet supported, see: https://react-native.canny.io/feature-requests/p/fetch-streaming-body");
        }
        return blob.stream();
      }, "blobToWebStream");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === "base64") {
            return (0, util_base64_1.toBase64)(buf);
          } else if (encoding === "hex") {
            return (0, util_hex_encoding_1.toHex)(buf);
          } else if (encoding === void 0 || encoding === "utf8" || encoding === "utf-8") {
            return (0, util_utf8_1.toUtf8)(buf);
          } else if (typeof TextDecoder === "function") {
            return new TextDecoder(encoding).decode(buf);
          } else {
            throw new Error("TextDecoder is not available, please make sure polyfill is provided.");
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
          }
          transformed = true;
          if (isBlobInstance6(stream)) {
            return blobToWebStream(stream);
          } else if ((0, stream_type_check_1.isReadableStream)(stream)) {
            return stream;
          } else {
            throw new Error(`Cannot transform payload to web stream, got ${stream}`);
          }
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
    exports2.sdkStreamMixin = sdkStreamMixin12;
    var isBlobInstance6 = /* @__PURE__ */ __name((stream) => typeof Blob === "function" && stream instanceof Blob, "isBlobInstance");
  }
});

// ../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.js
var require_sdk_stream_mixin6 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.sdkStreamMixin = void 0;
    var node_http_handler_1 = require_dist_cjs13();
    var util_buffer_from_1 = require_dist_cjs8();
    var stream_1 = require("stream");
    var sdk_stream_mixin_browser_1 = require_sdk_stream_mixin_browser6();
    var ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11 = "The stream has already been transformed.";
    var sdkStreamMixin12 = /* @__PURE__ */ __name((stream) => {
      if (!(stream instanceof stream_1.Readable)) {
        try {
          return (0, sdk_stream_mixin_browser_1.sdkStreamMixin)(stream);
        } catch (e32) {
          const name = stream?.__proto__?.constructor?.name || stream;
          throw new Error(`Unexpected stream implementation, expect Stream.Readable instance, got ${name}`);
        }
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
        }
        transformed = true;
        return await (0, node_http_handler_1.streamCollector)(stream);
      }, "transformToByteArray");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === void 0 || Buffer.isEncoding(encoding)) {
            return (0, util_buffer_from_1.fromArrayBuffer)(buf.buffer, buf.byteOffset, buf.byteLength).toString(encoding);
          } else {
            const decoder = new TextDecoder(encoding);
            return decoder.decode(buf);
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
          }
          if (stream.readableFlowing !== null) {
            throw new Error("The stream has been consumed by other callbacks.");
          }
          if (typeof stream_1.Readable.toWeb !== "function") {
            throw new Error("Readable.toWeb() is not supported. Please ensure a polyfill is available.");
          }
          transformed = true;
          return stream_1.Readable.toWeb(stream);
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
    exports2.sdkStreamMixin = sdkStreamMixin12;
  }
});

// ../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/splitStream.browser.js
var require_splitStream_browser6 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/splitStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.splitStream = splitStream5;
    async function splitStream5(stream) {
      if (typeof stream.stream === "function") {
        stream = stream.stream();
      }
      const readableStream = stream;
      return readableStream.tee();
    }
    __name(splitStream5, "splitStream");
  }
});

// ../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/splitStream.js
var require_splitStream6 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/splitStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.splitStream = splitStream5;
    var stream_1 = require("stream");
    var splitStream_browser_1 = require_splitStream_browser6();
    var stream_type_check_1 = require_stream_type_check6();
    async function splitStream5(stream) {
      if ((0, stream_type_check_1.isReadableStream)(stream) || (0, stream_type_check_1.isBlob)(stream)) {
        return (0, splitStream_browser_1.splitStream)(stream);
      }
      const stream1 = new stream_1.PassThrough();
      const stream2 = new stream_1.PassThrough();
      stream.pipe(stream1);
      stream.pipe(stream2);
      return [stream1, stream2];
    }
    __name(splitStream5, "splitStream");
  }
});

// ../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/index.js
var require_dist_cjs111 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-http/node_modules/@smithy/util-stream/dist-cjs/index.js"(exports2) {
    "use strict";
    var utilBase64 = require_dist_cjs10();
    var utilUtf8 = require_dist_cjs9();
    var ChecksumStream5 = require_ChecksumStream6();
    var createChecksumStream5 = require_createChecksumStream6();
    var createBufferedReadable3 = require_createBufferedReadable6();
    var getAwsChunkedEncodingStream5 = require_getAwsChunkedEncodingStream6();
    var headStream5 = require_headStream6();
    var sdkStreamMixin12 = require_sdk_stream_mixin6();
    var splitStream5 = require_splitStream6();
    var streamTypeCheck = require_stream_type_check6();
    var Uint8ArrayBlobAdapter8 = class _Uint8ArrayBlobAdapter extends Uint8Array {
      static {
        __name(this, "Uint8ArrayBlobAdapter");
      }
      static fromString(source, encoding = "utf-8") {
        if (typeof source === "string") {
          if (encoding === "base64") {
            return _Uint8ArrayBlobAdapter.mutate(utilBase64.fromBase64(source));
          }
          return _Uint8ArrayBlobAdapter.mutate(utilUtf8.fromUtf8(source));
        }
        throw new Error(`Unsupported conversion from ${typeof source} to Uint8ArrayBlobAdapter.`);
      }
      static mutate(source) {
        Object.setPrototypeOf(source, _Uint8ArrayBlobAdapter.prototype);
        return source;
      }
      transformToString(encoding = "utf-8") {
        if (encoding === "base64") {
          return utilBase64.toBase64(this);
        }
        return utilUtf8.toUtf8(this);
      }
    };
    exports2.isBlob = streamTypeCheck.isBlob;
    exports2.isReadableStream = streamTypeCheck.isReadableStream;
    exports2.Uint8ArrayBlobAdapter = Uint8ArrayBlobAdapter8;
    Object.prototype.hasOwnProperty.call(ChecksumStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: ChecksumStream5["__proto__"]
    });
    Object.keys(ChecksumStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = ChecksumStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(createChecksumStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: createChecksumStream5["__proto__"]
    });
    Object.keys(createChecksumStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = createChecksumStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(createBufferedReadable3, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: createBufferedReadable3["__proto__"]
    });
    Object.keys(createBufferedReadable3).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = createBufferedReadable3[k32];
    });
    Object.prototype.hasOwnProperty.call(getAwsChunkedEncodingStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: getAwsChunkedEncodingStream5["__proto__"]
    });
    Object.keys(getAwsChunkedEncodingStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = getAwsChunkedEncodingStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(headStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: headStream5["__proto__"]
    });
    Object.keys(headStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = headStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(sdkStreamMixin12, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: sdkStreamMixin12["__proto__"]
    });
    Object.keys(sdkStreamMixin12).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = sdkStreamMixin12[k32];
    });
    Object.prototype.hasOwnProperty.call(splitStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: splitStream5["__proto__"]
    });
    Object.keys(splitStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = splitStream5[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/requestHelpers.js
var require_requestHelpers4 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/requestHelpers.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createGetRequest = createGetRequest;
    exports2.getCredentials = getCredentials;
    var property_provider_1 = require_dist_cjs27();
    var protocol_http_1 = require_dist_cjs2();
    var smithy_client_1 = require_dist_cjs34();
    var util_stream_1 = require_dist_cjs111();
    function createGetRequest(url) {
      return new protocol_http_1.HttpRequest({
        protocol: url.protocol,
        hostname: url.hostname,
        port: Number(url.port),
        path: url.pathname,
        query: Array.from(url.searchParams.entries()).reduce((acc, [k32, v]) => {
          acc[k32] = v;
          return acc;
        }, {}),
        fragment: url.hash
      });
    }
    __name(createGetRequest, "createGetRequest");
    async function getCredentials(response, logger5) {
      const stream = (0, util_stream_1.sdkStreamMixin)(response.body);
      const str = await stream.transformToString();
      if (response.statusCode === 200) {
        const parsed = JSON.parse(str);
        if (typeof parsed.AccessKeyId !== "string" || typeof parsed.SecretAccessKey !== "string" || typeof parsed.Token !== "string" || typeof parsed.Expiration !== "string") {
          throw new property_provider_1.CredentialsProviderError("HTTP credential provider response not of the required format, an object matching: { AccessKeyId: string, SecretAccessKey: string, Token: string, Expiration: string(rfc3339) }", { logger: logger5 });
        }
        return {
          accessKeyId: parsed.AccessKeyId,
          secretAccessKey: parsed.SecretAccessKey,
          sessionToken: parsed.Token,
          expiration: (0, smithy_client_1.parseRfc3339DateTime)(parsed.Expiration)
        };
      }
      if (response.statusCode >= 400 && response.statusCode < 500) {
        let parsedBody = {};
        try {
          parsedBody = JSON.parse(str);
        } catch (e32) {
        }
        throw Object.assign(new property_provider_1.CredentialsProviderError(`Server responded with status: ${response.statusCode}`, { logger: logger5 }), {
          Code: parsedBody.Code,
          Message: parsedBody.Message
        });
      }
      throw new property_provider_1.CredentialsProviderError(`Server responded with status: ${response.statusCode}`, { logger: logger5 });
    }
    __name(getCredentials, "getCredentials");
  }
});

// ../../node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/retry-wrapper.js
var require_retry_wrapper4 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/retry-wrapper.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.retryWrapper = void 0;
    var retryWrapper = /* @__PURE__ */ __name((toRetry, maxRetries, delayMs) => {
      return async () => {
        for (let i32 = 0; i32 < maxRetries; ++i32) {
          try {
            return await toRetry();
          } catch (e32) {
            await new Promise((resolve13) => setTimeout(resolve13, delayMs));
          }
        }
        return await toRetry();
      };
    }, "retryWrapper");
    exports2.retryWrapper = retryWrapper;
  }
});

// ../../node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/fromHttp.js
var require_fromHttp4 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/fromHttp.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromHttp = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var client_1 = (init_client8(), __toCommonJS(client_exports7));
    var node_http_handler_1 = require_dist_cjs13();
    var property_provider_1 = require_dist_cjs27();
    var promises_1 = tslib_1.__importDefault(require("node:fs/promises"));
    var checkUrl_1 = require_checkUrl4();
    var requestHelpers_1 = require_requestHelpers4();
    var retry_wrapper_1 = require_retry_wrapper4();
    var AWS_CONTAINER_CREDENTIALS_RELATIVE_URI = "AWS_CONTAINER_CREDENTIALS_RELATIVE_URI";
    var DEFAULT_LINK_LOCAL_HOST = "http://169.254.170.2";
    var AWS_CONTAINER_CREDENTIALS_FULL_URI = "AWS_CONTAINER_CREDENTIALS_FULL_URI";
    var AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE = "AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE";
    var AWS_CONTAINER_AUTHORIZATION_TOKEN = "AWS_CONTAINER_AUTHORIZATION_TOKEN";
    var fromHttp = /* @__PURE__ */ __name((options = {}) => {
      options.logger?.debug("@aws-sdk/credential-provider-http - fromHttp");
      let host;
      const relative5 = options.awsContainerCredentialsRelativeUri ?? process.env[AWS_CONTAINER_CREDENTIALS_RELATIVE_URI];
      const full = options.awsContainerCredentialsFullUri ?? process.env[AWS_CONTAINER_CREDENTIALS_FULL_URI];
      const token = options.awsContainerAuthorizationToken ?? process.env[AWS_CONTAINER_AUTHORIZATION_TOKEN];
      const tokenFile = options.awsContainerAuthorizationTokenFile ?? process.env[AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE];
      const warn2 = options.logger?.constructor?.name === "NoOpLogger" || !options.logger?.warn ? console.warn : options.logger.warn.bind(options.logger);
      if (relative5 && full) {
        warn2("@aws-sdk/credential-provider-http: you have set both awsContainerCredentialsRelativeUri and awsContainerCredentialsFullUri.");
        warn2("awsContainerCredentialsFullUri will take precedence.");
      }
      if (token && tokenFile) {
        warn2("@aws-sdk/credential-provider-http: you have set both awsContainerAuthorizationToken and awsContainerAuthorizationTokenFile.");
        warn2("awsContainerAuthorizationToken will take precedence.");
      }
      if (full) {
        host = full;
      } else if (relative5) {
        host = `${DEFAULT_LINK_LOCAL_HOST}${relative5}`;
      } else {
        throw new property_provider_1.CredentialsProviderError(`No HTTP credential provider host provided.
Set AWS_CONTAINER_CREDENTIALS_FULL_URI or AWS_CONTAINER_CREDENTIALS_RELATIVE_URI.`, { logger: options.logger });
      }
      const url = new URL(host);
      (0, checkUrl_1.checkUrl)(url, options.logger);
      const requestHandler = node_http_handler_1.NodeHttpHandler.create({
        requestTimeout: options.timeout ?? 1e3,
        connectionTimeout: options.timeout ?? 1e3
      });
      return (0, retry_wrapper_1.retryWrapper)(async () => {
        const request4 = (0, requestHelpers_1.createGetRequest)(url);
        if (token) {
          request4.headers.Authorization = token;
        } else if (tokenFile) {
          request4.headers.Authorization = (await promises_1.default.readFile(tokenFile)).toString();
        }
        try {
          const result2 = await requestHandler.handle(request4);
          return (0, requestHelpers_1.getCredentials)(result2.response).then((creds) => (0, client_1.setCredentialFeature)(creds, "CREDENTIALS_HTTP", "z"));
        } catch (e32) {
          throw new property_provider_1.CredentialsProviderError(String(e32), { logger: options.logger });
        }
      }, options.maxRetries ?? 3, options.timeout ?? 1e3);
    }, "fromHttp");
    exports2.fromHttp = fromHttp;
  }
});

// ../../node_modules/@aws-sdk/credential-provider-http/dist-cjs/index.js
var require_dist_cjs112 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-http/dist-cjs/index.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromHttp = void 0;
    var fromHttp_1 = require_fromHttp4();
    Object.defineProperty(exports2, "fromHttp", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return fromHttp_1.fromHttp;
    }, "get") });
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption11(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "sso-oauth",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption11(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var import_util_middleware16, defaultSSOOIDCHttpAuthSchemeParametersProvider2, defaultSSOOIDCHttpAuthSchemeProvider2, resolveHttpAuthSchemeConfig11;
var init_httpAuthSchemeProvider11 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes6();
    import_util_middleware16 = __toESM(require_dist_cjs6());
    defaultSSOOIDCHttpAuthSchemeParametersProvider2 = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, import_util_middleware16.getSmithyContext)(context).operation,
        region: await (0, import_util_middleware16.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultSSOOIDCHttpAuthSchemeParametersProvider");
    __name(createAwsAuthSigv4HttpAuthOption11, "createAwsAuthSigv4HttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption11, "createSmithyApiNoAuthHttpAuthOption");
    defaultSSOOIDCHttpAuthSchemeProvider2 = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "CreateToken": {
          options.push(createSmithyApiNoAuthHttpAuthOption11(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption11(authParameters));
        }
      }
      return options;
    }, "defaultSSOOIDCHttpAuthSchemeProvider");
    resolveHttpAuthSchemeConfig11 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveAwsSdkSigV4Config5(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, import_util_middleware16.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/endpoint/EndpointParameters.js
var resolveClientEndpointParameters11, commonParams11;
var init_EndpointParameters11 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters11 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "sso-oauth"
      });
    }, "resolveClientEndpointParameters");
    commonParams11 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/package.json
var package_default5;
var init_package5 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/package.json"() {
    package_default5 = {
      name: "@aws-sdk/nested-clients",
      version: "3.997.3",
      description: "Nested clients for AWS SDK packages.",
      main: "./dist-cjs/index.js",
      module: "./dist-es/index.js",
      types: "./dist-types/index.d.ts",
      scripts: {
        build: "yarn lint && concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline nested-clients",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        lint: "node ../../scripts/validation/submodules-linter.js --pkg nested-clients",
        test: "yarn g:vitest run",
        "test:watch": "yarn g:vitest watch"
      },
      engines: {
        node: ">=20.0.0"
      },
      sideEffects: false,
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      dependencies: {
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.5",
        "@aws-sdk/middleware-host-header": "^3.972.10",
        "@aws-sdk/middleware-logger": "^3.972.10",
        "@aws-sdk/middleware-recursion-detection": "^3.972.11",
        "@aws-sdk/middleware-user-agent": "^3.972.35",
        "@aws-sdk/region-config-resolver": "^3.972.13",
        "@aws-sdk/signature-v4-multi-region": "^3.996.22",
        "@aws-sdk/types": "^3.973.8",
        "@aws-sdk/util-endpoints": "^3.996.8",
        "@aws-sdk/util-user-agent-browser": "^3.972.10",
        "@aws-sdk/util-user-agent-node": "^3.973.21",
        "@smithy/config-resolver": "^4.4.17",
        "@smithy/core": "^3.23.17",
        "@smithy/fetch-http-handler": "^5.3.17",
        "@smithy/hash-node": "^4.2.14",
        "@smithy/invalid-dependency": "^4.2.14",
        "@smithy/middleware-content-length": "^4.2.14",
        "@smithy/middleware-endpoint": "^4.4.32",
        "@smithy/middleware-retry": "^4.5.5",
        "@smithy/middleware-serde": "^4.2.20",
        "@smithy/middleware-stack": "^4.2.14",
        "@smithy/node-config-provider": "^4.3.14",
        "@smithy/node-http-handler": "^4.6.1",
        "@smithy/protocol-http": "^5.3.14",
        "@smithy/smithy-client": "^4.12.13",
        "@smithy/types": "^4.14.1",
        "@smithy/url-parser": "^4.2.14",
        "@smithy/util-base64": "^4.3.2",
        "@smithy/util-body-length-browser": "^4.2.2",
        "@smithy/util-body-length-node": "^4.2.3",
        "@smithy/util-defaults-mode-browser": "^4.3.49",
        "@smithy/util-defaults-mode-node": "^4.2.54",
        "@smithy/util-endpoints": "^3.4.2",
        "@smithy/util-middleware": "^4.2.14",
        "@smithy/util-retry": "^4.3.4",
        "@smithy/util-utf8": "^4.2.2",
        tslib: "^2.6.2"
      },
      devDependencies: {
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "./cognito-identity.d.ts",
        "./cognito-identity.js",
        "./signin.d.ts",
        "./signin.js",
        "./sso-oidc.d.ts",
        "./sso-oidc.js",
        "./sso.d.ts",
        "./sso.js",
        "./sts.d.ts",
        "./sts.js",
        "dist-*/**"
      ],
      browser: {
        "./dist-es/submodules/cognito-identity/runtimeConfig": "./dist-es/submodules/cognito-identity/runtimeConfig.browser",
        "./dist-es/submodules/signin/runtimeConfig": "./dist-es/submodules/signin/runtimeConfig.browser",
        "./dist-es/submodules/sso-oidc/runtimeConfig": "./dist-es/submodules/sso-oidc/runtimeConfig.browser",
        "./dist-es/submodules/sso/runtimeConfig": "./dist-es/submodules/sso/runtimeConfig.browser",
        "./dist-es/submodules/sts/runtimeConfig": "./dist-es/submodules/sts/runtimeConfig.browser"
      },
      "react-native": {},
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/packages/nested-clients",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "packages/nested-clients"
      },
      exports: {
        "./package.json": "./package.json",
        "./sso-oidc": {
          types: "./dist-types/submodules/sso-oidc/index.d.ts",
          module: "./dist-es/submodules/sso-oidc/index.js",
          node: "./dist-cjs/submodules/sso-oidc/index.js",
          import: "./dist-es/submodules/sso-oidc/index.js",
          require: "./dist-cjs/submodules/sso-oidc/index.js"
        },
        "./sts": {
          types: "./dist-types/submodules/sts/index.d.ts",
          module: "./dist-es/submodules/sts/index.js",
          node: "./dist-cjs/submodules/sts/index.js",
          import: "./dist-es/submodules/sts/index.js",
          require: "./dist-cjs/submodules/sts/index.js"
        },
        "./signin": {
          types: "./dist-types/submodules/signin/index.d.ts",
          module: "./dist-es/submodules/signin/index.js",
          node: "./dist-cjs/submodules/signin/index.js",
          import: "./dist-es/submodules/signin/index.js",
          require: "./dist-cjs/submodules/signin/index.js"
        },
        "./cognito-identity": {
          types: "./dist-types/submodules/cognito-identity/index.d.ts",
          module: "./dist-es/submodules/cognito-identity/index.js",
          node: "./dist-cjs/submodules/cognito-identity/index.js",
          import: "./dist-es/submodules/cognito-identity/index.js",
          require: "./dist-cjs/submodules/cognito-identity/index.js"
        },
        "./sso": {
          types: "./dist-types/submodules/sso/index.d.ts",
          module: "./dist-es/submodules/sso/index.js",
          node: "./dist-cjs/submodules/sso/index.js",
          import: "./dist-es/submodules/sso/index.js",
          require: "./dist-cjs/submodules/sso/index.js"
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/util-user-agent-node/dist-cjs/index.js
var require_dist_cjs113 = __commonJS({
  "../../node_modules/@aws-sdk/util-user-agent-node/dist-cjs/index.js"(exports2) {
    "use strict";
    var node_os = require("node:os");
    var node_process = require("node:process");
    var utilConfigProvider = require_dist_cjs24();
    var promises5 = require("node:fs/promises");
    var node_path = require("node:path");
    var middlewareUserAgent = require_dist_cjs104();
    var getRuntimeUserAgentPair2 = /* @__PURE__ */ __name(() => {
      const runtimesToCheck = ["deno", "bun", "llrt"];
      for (const runtime of runtimesToCheck) {
        if (node_process.versions[runtime]) {
          return [`md/${runtime}`, node_process.versions[runtime]];
        }
      }
      return ["md/nodejs", node_process.versions.node];
    }, "getRuntimeUserAgentPair");
    var getNodeModulesParentDirs2 = /* @__PURE__ */ __name((dirname14) => {
      const cwd = process.cwd();
      if (!dirname14) {
        return [cwd];
      }
      const normalizedPath = node_path.normalize(dirname14);
      const parts = normalizedPath.split(node_path.sep);
      const nodeModulesIndex = parts.indexOf("node_modules");
      const parentDir = nodeModulesIndex !== -1 ? parts.slice(0, nodeModulesIndex).join(node_path.sep) : normalizedPath;
      if (cwd === parentDir) {
        return [cwd];
      }
      return [parentDir, cwd];
    }, "getNodeModulesParentDirs");
    var SEMVER_REGEX2 = /^(0|[1-9]\d*)\.(0|[1-9]\d*)\.(0|[1-9]\d*)(?:-((?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*)(?:\.(?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*))*))?(?:\+[0-9a-zA-Z-]+(?:\.[0-9a-zA-Z-]+)*)?$/;
    var getSanitizedTypeScriptVersion2 = /* @__PURE__ */ __name((version = "") => {
      const match = version.match(SEMVER_REGEX2);
      if (!match) {
        return void 0;
      }
      const [major6, minor, patch, prerelease] = [match[1], match[2], match[3], match[4]];
      return prerelease ? `${major6}.${minor}.${patch}-${prerelease}` : `${major6}.${minor}.${patch}`;
    }, "getSanitizedTypeScriptVersion");
    var ALLOWED_PREFIXES2 = ["^", "~", ">=", "<=", ">", "<"];
    var ALLOWED_DIST_TAGS2 = ["latest", "beta", "dev", "rc", "insiders", "next"];
    var getSanitizedDevTypeScriptVersion2 = /* @__PURE__ */ __name((version = "") => {
      if (ALLOWED_DIST_TAGS2.includes(version)) {
        return version;
      }
      const prefix = ALLOWED_PREFIXES2.find((p10) => version.startsWith(p10)) ?? "";
      const sanitizedTypeScriptVersion = getSanitizedTypeScriptVersion2(version.slice(prefix.length));
      if (!sanitizedTypeScriptVersion) {
        return void 0;
      }
      return `${prefix}${sanitizedTypeScriptVersion}`;
    }, "getSanitizedDevTypeScriptVersion");
    var tscVersion2;
    var TS_PACKAGE_JSON2 = node_path.join("node_modules", "typescript", "package.json");
    var getTypeScriptUserAgentPair2 = /* @__PURE__ */ __name(async () => {
      if (tscVersion2 === null) {
        return void 0;
      } else if (typeof tscVersion2 === "string") {
        return ["md/tsc", tscVersion2];
      }
      let isTypeScriptDetectionDisabled = false;
      try {
        isTypeScriptDetectionDisabled = utilConfigProvider.booleanSelector(process.env, "AWS_SDK_JS_TYPESCRIPT_DETECTION_DISABLED", utilConfigProvider.SelectorType.ENV) || false;
      } catch {
      }
      if (isTypeScriptDetectionDisabled) {
        tscVersion2 = null;
        return void 0;
      }
      const dirname14 = typeof __dirname !== "undefined" ? __dirname : void 0;
      const nodeModulesParentDirs = getNodeModulesParentDirs2(dirname14);
      let versionFromApp;
      for (const nodeModulesParentDir of nodeModulesParentDirs) {
        try {
          const appPackageJsonPath = node_path.join(nodeModulesParentDir, "package.json");
          const packageJson = await promises5.readFile(appPackageJsonPath, "utf-8");
          const { dependencies, devDependencies } = JSON.parse(packageJson);
          const version = devDependencies?.typescript ?? dependencies?.typescript;
          if (typeof version !== "string") {
            continue;
          }
          versionFromApp = version;
          break;
        } catch {
        }
      }
      if (!versionFromApp) {
        tscVersion2 = null;
        return void 0;
      }
      let versionFromNodeModules;
      for (const nodeModulesParentDir of nodeModulesParentDirs) {
        try {
          const tsPackageJsonPath = node_path.join(nodeModulesParentDir, TS_PACKAGE_JSON2);
          const packageJson = await promises5.readFile(tsPackageJsonPath, "utf-8");
          const { version } = JSON.parse(packageJson);
          const sanitizedVersion2 = getSanitizedTypeScriptVersion2(version);
          if (typeof sanitizedVersion2 !== "string") {
            continue;
          }
          versionFromNodeModules = sanitizedVersion2;
          break;
        } catch {
        }
      }
      if (versionFromNodeModules) {
        tscVersion2 = versionFromNodeModules;
        return ["md/tsc", tscVersion2];
      }
      const sanitizedVersion = getSanitizedDevTypeScriptVersion2(versionFromApp);
      if (typeof sanitizedVersion !== "string") {
        tscVersion2 = null;
        return void 0;
      }
      tscVersion2 = `dev_${sanitizedVersion}`;
      return ["md/tsc", tscVersion2];
    }, "getTypeScriptUserAgentPair");
    var crtAvailability2 = {
      isCrtAvailable: false
    };
    var isCrtAvailable2 = /* @__PURE__ */ __name(() => {
      if (crtAvailability2.isCrtAvailable) {
        return ["md/crt-avail"];
      }
      return null;
    }, "isCrtAvailable");
    var createDefaultUserAgentProvider29 = /* @__PURE__ */ __name(({ serviceId, clientVersion }) => {
      const runtimeUserAgentPair = getRuntimeUserAgentPair2();
      return async (config2) => {
        const sections = [
          ["aws-sdk-js", clientVersion],
          ["ua", "2.1"],
          [`os/${node_os.platform()}`, node_os.release()],
          ["lang/js"],
          runtimeUserAgentPair
        ];
        const typescriptUserAgentPair = await getTypeScriptUserAgentPair2();
        if (typescriptUserAgentPair) {
          sections.push(typescriptUserAgentPair);
        }
        const crtAvailable = isCrtAvailable2();
        if (crtAvailable) {
          sections.push(crtAvailable);
        }
        if (serviceId) {
          sections.push([`api/${serviceId}`, clientVersion]);
        }
        if (node_process.env.AWS_EXECUTION_ENV) {
          sections.push([`exec-env/${node_process.env.AWS_EXECUTION_ENV}`]);
        }
        const appId = await config2?.userAgentAppId?.();
        const resolvedUserAgent = appId ? [...sections, [`app/${appId}`]] : [...sections];
        return resolvedUserAgent;
      };
    }, "createDefaultUserAgentProvider");
    var defaultUserAgent2 = createDefaultUserAgentProvider29;
    var UA_APP_ID_ENV_NAME2 = "AWS_SDK_UA_APP_ID";
    var UA_APP_ID_INI_NAME2 = "sdk_ua_app_id";
    var UA_APP_ID_INI_NAME_DEPRECATED2 = "sdk-ua-app-id";
    var NODE_APP_ID_CONFIG_OPTIONS29 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[UA_APP_ID_ENV_NAME2], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[UA_APP_ID_INI_NAME2] ?? profile[UA_APP_ID_INI_NAME_DEPRECATED2], "configFileSelector"),
      default: middlewareUserAgent.DEFAULT_UA_APP_ID
    };
    exports2.NODE_APP_ID_CONFIG_OPTIONS = NODE_APP_ID_CONFIG_OPTIONS29;
    exports2.UA_APP_ID_ENV_NAME = UA_APP_ID_ENV_NAME2;
    exports2.UA_APP_ID_INI_NAME = UA_APP_ID_INI_NAME2;
    exports2.createDefaultUserAgentProvider = createDefaultUserAgentProvider29;
    exports2.crtAvailability = crtAvailability2;
    exports2.defaultUserAgent = defaultUserAgent2;
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/endpoint/bdd.js
var import_util_endpoints31, k11, a11, b11, c11, d11, e11, f11, g11, h11, i11, j11, _data11, root11, r11, nodes11, bdd11;
var init_bdd11 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/endpoint/bdd.js"() {
    import_util_endpoints31 = __toESM(require_dist_cjs20());
    k11 = "ref";
    a11 = -1;
    b11 = true;
    c11 = "isSet";
    d11 = "PartitionResult";
    e11 = "booleanEquals";
    f11 = "getAttr";
    g11 = { [k11]: "Endpoint" };
    h11 = { [k11]: d11 };
    i11 = {};
    j11 = [{ [k11]: "Region" }];
    _data11 = {
      conditions: [
        [c11, [g11]],
        [c11, j11],
        ["aws.partition", j11, d11],
        [e11, [{ [k11]: "UseFIPS" }, b11]],
        [e11, [{ [k11]: "UseDualStack" }, b11]],
        [e11, [{ fn: f11, argv: [h11, "supportsDualStack"] }, b11]],
        [e11, [{ fn: f11, argv: [h11, "supportsFIPS"] }, b11]],
        ["stringEquals", [{ fn: f11, argv: [h11, "name"] }, "aws-us-gov"]]
      ],
      results: [
        [a11],
        [a11, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a11, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [g11, i11],
        ["https://oidc-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", i11],
        [a11, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://oidc.{Region}.amazonaws.com", i11],
        ["https://oidc-fips.{Region}.{PartitionResult#dnsSuffix}", i11],
        [a11, "FIPS is enabled but this partition does not support FIPS"],
        ["https://oidc.{Region}.{PartitionResult#dualStackDnsSuffix}", i11],
        [a11, "DualStack is enabled but this partition does not support DualStack"],
        ["https://oidc.{Region}.{PartitionResult#dnsSuffix}", i11],
        [a11, "Invalid Configuration: Missing Region"]
      ]
    };
    root11 = 2;
    r11 = 1e8;
    nodes11 = new Int32Array([
      -1,
      1,
      -1,
      0,
      13,
      3,
      1,
      4,
      r11 + 12,
      2,
      5,
      r11 + 12,
      3,
      8,
      6,
      4,
      7,
      r11 + 11,
      5,
      r11 + 9,
      r11 + 10,
      4,
      11,
      9,
      6,
      10,
      r11 + 8,
      7,
      r11 + 6,
      r11 + 7,
      5,
      12,
      r11 + 5,
      6,
      r11 + 4,
      r11 + 5,
      3,
      r11 + 1,
      14,
      4,
      r11 + 2,
      r11 + 3
    ]);
    bdd11 = import_util_endpoints31.BinaryDecisionDiagram.from(nodes11, root11, _data11.conditions, _data11.results);
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/endpoint/endpointResolver.js
var import_util_endpoints32, import_util_endpoints33, cache11, defaultEndpointResolver11;
var init_endpointResolver11 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/endpoint/endpointResolver.js"() {
    import_util_endpoints32 = __toESM(require_dist_cjs21());
    import_util_endpoints33 = __toESM(require_dist_cjs20());
    init_bdd11();
    cache11 = new import_util_endpoints33.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    defaultEndpointResolver11 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache11.get(endpointParams, () => (0, import_util_endpoints33.decideEndpoint)(bdd11, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    import_util_endpoints33.customEndpointFunctions.aws = import_util_endpoints32.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/models/SSOOIDCServiceException.js
var import_smithy_client108, SSOOIDCServiceException2;
var init_SSOOIDCServiceException2 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/models/SSOOIDCServiceException.js"() {
    import_smithy_client108 = __toESM(require_dist_cjs34());
    SSOOIDCServiceException2 = class _SSOOIDCServiceException extends import_smithy_client108.ServiceException {
      static {
        __name(this, "SSOOIDCServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _SSOOIDCServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/models/errors.js
var AccessDeniedException5, AuthorizationPendingException2, ExpiredTokenException5, InternalServerException5, InvalidClientException2, InvalidGrantException2, InvalidRequestException5, InvalidScopeException2, SlowDownException2, UnauthorizedClientException2, UnsupportedGrantTypeException2;
var init_errors11 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/models/errors.js"() {
    init_SSOOIDCServiceException2();
    AccessDeniedException5 = class _AccessDeniedException extends SSOOIDCServiceException2 {
      static {
        __name(this, "AccessDeniedException");
      }
      name = "AccessDeniedException";
      $fault = "client";
      error;
      reason;
      error_description;
      constructor(opts) {
        super({
          name: "AccessDeniedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AccessDeniedException.prototype);
        this.error = opts.error;
        this.reason = opts.reason;
        this.error_description = opts.error_description;
      }
    };
    AuthorizationPendingException2 = class _AuthorizationPendingException extends SSOOIDCServiceException2 {
      static {
        __name(this, "AuthorizationPendingException");
      }
      name = "AuthorizationPendingException";
      $fault = "client";
      error;
      error_description;
      constructor(opts) {
        super({
          name: "AuthorizationPendingException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AuthorizationPendingException.prototype);
        this.error = opts.error;
        this.error_description = opts.error_description;
      }
    };
    ExpiredTokenException5 = class _ExpiredTokenException extends SSOOIDCServiceException2 {
      static {
        __name(this, "ExpiredTokenException");
      }
      name = "ExpiredTokenException";
      $fault = "client";
      error;
      error_description;
      constructor(opts) {
        super({
          name: "ExpiredTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ExpiredTokenException.prototype);
        this.error = opts.error;
        this.error_description = opts.error_description;
      }
    };
    InternalServerException5 = class _InternalServerException extends SSOOIDCServiceException2 {
      static {
        __name(this, "InternalServerException");
      }
      name = "InternalServerException";
      $fault = "server";
      error;
      error_description;
      constructor(opts) {
        super({
          name: "InternalServerException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _InternalServerException.prototype);
        this.error = opts.error;
        this.error_description = opts.error_description;
      }
    };
    InvalidClientException2 = class _InvalidClientException extends SSOOIDCServiceException2 {
      static {
        __name(this, "InvalidClientException");
      }
      name = "InvalidClientException";
      $fault = "client";
      error;
      error_description;
      constructor(opts) {
        super({
          name: "InvalidClientException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidClientException.prototype);
        this.error = opts.error;
        this.error_description = opts.error_description;
      }
    };
    InvalidGrantException2 = class _InvalidGrantException extends SSOOIDCServiceException2 {
      static {
        __name(this, "InvalidGrantException");
      }
      name = "InvalidGrantException";
      $fault = "client";
      error;
      error_description;
      constructor(opts) {
        super({
          name: "InvalidGrantException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidGrantException.prototype);
        this.error = opts.error;
        this.error_description = opts.error_description;
      }
    };
    InvalidRequestException5 = class _InvalidRequestException extends SSOOIDCServiceException2 {
      static {
        __name(this, "InvalidRequestException");
      }
      name = "InvalidRequestException";
      $fault = "client";
      error;
      reason;
      error_description;
      constructor(opts) {
        super({
          name: "InvalidRequestException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidRequestException.prototype);
        this.error = opts.error;
        this.reason = opts.reason;
        this.error_description = opts.error_description;
      }
    };
    InvalidScopeException2 = class _InvalidScopeException extends SSOOIDCServiceException2 {
      static {
        __name(this, "InvalidScopeException");
      }
      name = "InvalidScopeException";
      $fault = "client";
      error;
      error_description;
      constructor(opts) {
        super({
          name: "InvalidScopeException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidScopeException.prototype);
        this.error = opts.error;
        this.error_description = opts.error_description;
      }
    };
    SlowDownException2 = class _SlowDownException extends SSOOIDCServiceException2 {
      static {
        __name(this, "SlowDownException");
      }
      name = "SlowDownException";
      $fault = "client";
      error;
      error_description;
      constructor(opts) {
        super({
          name: "SlowDownException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _SlowDownException.prototype);
        this.error = opts.error;
        this.error_description = opts.error_description;
      }
    };
    UnauthorizedClientException2 = class _UnauthorizedClientException extends SSOOIDCServiceException2 {
      static {
        __name(this, "UnauthorizedClientException");
      }
      name = "UnauthorizedClientException";
      $fault = "client";
      error;
      error_description;
      constructor(opts) {
        super({
          name: "UnauthorizedClientException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnauthorizedClientException.prototype);
        this.error = opts.error;
        this.error_description = opts.error_description;
      }
    };
    UnsupportedGrantTypeException2 = class _UnsupportedGrantTypeException extends SSOOIDCServiceException2 {
      static {
        __name(this, "UnsupportedGrantTypeException");
      }
      name = "UnsupportedGrantTypeException";
      $fault = "client";
      error;
      error_description;
      constructor(opts) {
        super({
          name: "UnsupportedGrantTypeException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnsupportedGrantTypeException.prototype);
        this.error = opts.error;
        this.error_description = opts.error_description;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/schemas/schemas_0.js
var _ADE5, _APE2, _AT5, _CS2, _CT2, _CTR2, _CTRr2, _CV2, _ETE5, _ICE2, _IGE2, _IRE5, _ISE5, _ISEn2, _IT2, _RT5, _SDE2, _UCE2, _UGTE2, _aT8, _c11, _cI5, _cS2, _cV5, _co5, _dC2, _e11, _eI5, _ed2, _gT5, _h8, _hE11, _iT5, _r2, _rT5, _rU5, _s11, _sc2, _se5, _tT5, n011, _s_registry11, SSOOIDCServiceException$2, n0_registry11, AccessDeniedException$5, AuthorizationPendingException$2, ExpiredTokenException$5, InternalServerException$5, InvalidClientException$2, InvalidGrantException$2, InvalidRequestException$5, InvalidScopeException$2, SlowDownException$2, UnauthorizedClientException$2, UnsupportedGrantTypeException$2, errorTypeRegistries11, AccessToken2, ClientSecret2, CodeVerifier2, IdToken2, RefreshToken5, CreateTokenRequest$2, CreateTokenResponse$2, Scopes2, CreateToken$2;
var init_schemas_011 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/schemas/schemas_0.js"() {
    init_schema4();
    init_errors11();
    init_SSOOIDCServiceException2();
    _ADE5 = "AccessDeniedException";
    _APE2 = "AuthorizationPendingException";
    _AT5 = "AccessToken";
    _CS2 = "ClientSecret";
    _CT2 = "CreateToken";
    _CTR2 = "CreateTokenRequest";
    _CTRr2 = "CreateTokenResponse";
    _CV2 = "CodeVerifier";
    _ETE5 = "ExpiredTokenException";
    _ICE2 = "InvalidClientException";
    _IGE2 = "InvalidGrantException";
    _IRE5 = "InvalidRequestException";
    _ISE5 = "InternalServerException";
    _ISEn2 = "InvalidScopeException";
    _IT2 = "IdToken";
    _RT5 = "RefreshToken";
    _SDE2 = "SlowDownException";
    _UCE2 = "UnauthorizedClientException";
    _UGTE2 = "UnsupportedGrantTypeException";
    _aT8 = "accessToken";
    _c11 = "client";
    _cI5 = "clientId";
    _cS2 = "clientSecret";
    _cV5 = "codeVerifier";
    _co5 = "code";
    _dC2 = "deviceCode";
    _e11 = "error";
    _eI5 = "expiresIn";
    _ed2 = "error_description";
    _gT5 = "grantType";
    _h8 = "http";
    _hE11 = "httpError";
    _iT5 = "idToken";
    _r2 = "reason";
    _rT5 = "refreshToken";
    _rU5 = "redirectUri";
    _s11 = "smithy.ts.sdk.synthetic.com.amazonaws.ssooidc";
    _sc2 = "scope";
    _se5 = "server";
    _tT5 = "tokenType";
    n011 = "com.amazonaws.ssooidc";
    _s_registry11 = TypeRegistry.for(_s11);
    SSOOIDCServiceException$2 = [-3, _s11, "SSOOIDCServiceException", 0, [], []];
    _s_registry11.registerError(SSOOIDCServiceException$2, SSOOIDCServiceException2);
    n0_registry11 = TypeRegistry.for(n011);
    AccessDeniedException$5 = [
      -3,
      n011,
      _ADE5,
      { [_e11]: _c11, [_hE11]: 400 },
      [_e11, _r2, _ed2],
      [0, 0, 0]
    ];
    n0_registry11.registerError(AccessDeniedException$5, AccessDeniedException5);
    AuthorizationPendingException$2 = [
      -3,
      n011,
      _APE2,
      { [_e11]: _c11, [_hE11]: 400 },
      [_e11, _ed2],
      [0, 0]
    ];
    n0_registry11.registerError(AuthorizationPendingException$2, AuthorizationPendingException2);
    ExpiredTokenException$5 = [-3, n011, _ETE5, { [_e11]: _c11, [_hE11]: 400 }, [_e11, _ed2], [0, 0]];
    n0_registry11.registerError(ExpiredTokenException$5, ExpiredTokenException5);
    InternalServerException$5 = [-3, n011, _ISE5, { [_e11]: _se5, [_hE11]: 500 }, [_e11, _ed2], [0, 0]];
    n0_registry11.registerError(InternalServerException$5, InternalServerException5);
    InvalidClientException$2 = [-3, n011, _ICE2, { [_e11]: _c11, [_hE11]: 401 }, [_e11, _ed2], [0, 0]];
    n0_registry11.registerError(InvalidClientException$2, InvalidClientException2);
    InvalidGrantException$2 = [-3, n011, _IGE2, { [_e11]: _c11, [_hE11]: 400 }, [_e11, _ed2], [0, 0]];
    n0_registry11.registerError(InvalidGrantException$2, InvalidGrantException2);
    InvalidRequestException$5 = [
      -3,
      n011,
      _IRE5,
      { [_e11]: _c11, [_hE11]: 400 },
      [_e11, _r2, _ed2],
      [0, 0, 0]
    ];
    n0_registry11.registerError(InvalidRequestException$5, InvalidRequestException5);
    InvalidScopeException$2 = [-3, n011, _ISEn2, { [_e11]: _c11, [_hE11]: 400 }, [_e11, _ed2], [0, 0]];
    n0_registry11.registerError(InvalidScopeException$2, InvalidScopeException2);
    SlowDownException$2 = [-3, n011, _SDE2, { [_e11]: _c11, [_hE11]: 400 }, [_e11, _ed2], [0, 0]];
    n0_registry11.registerError(SlowDownException$2, SlowDownException2);
    UnauthorizedClientException$2 = [
      -3,
      n011,
      _UCE2,
      { [_e11]: _c11, [_hE11]: 400 },
      [_e11, _ed2],
      [0, 0]
    ];
    n0_registry11.registerError(UnauthorizedClientException$2, UnauthorizedClientException2);
    UnsupportedGrantTypeException$2 = [
      -3,
      n011,
      _UGTE2,
      { [_e11]: _c11, [_hE11]: 400 },
      [_e11, _ed2],
      [0, 0]
    ];
    n0_registry11.registerError(UnsupportedGrantTypeException$2, UnsupportedGrantTypeException2);
    errorTypeRegistries11 = [_s_registry11, n0_registry11];
    AccessToken2 = [0, n011, _AT5, 8, 0];
    ClientSecret2 = [0, n011, _CS2, 8, 0];
    CodeVerifier2 = [0, n011, _CV2, 8, 0];
    IdToken2 = [0, n011, _IT2, 8, 0];
    RefreshToken5 = [0, n011, _RT5, 8, 0];
    CreateTokenRequest$2 = [
      3,
      n011,
      _CTR2,
      0,
      [_cI5, _cS2, _gT5, _dC2, _co5, _rT5, _sc2, _rU5, _cV5],
      [0, [() => ClientSecret2, 0], 0, 0, 0, [() => RefreshToken5, 0], 64 | 0, 0, [() => CodeVerifier2, 0]],
      3
    ];
    CreateTokenResponse$2 = [
      3,
      n011,
      _CTRr2,
      0,
      [_aT8, _tT5, _eI5, _rT5, _iT5],
      [[() => AccessToken2, 0], 0, 1, [() => RefreshToken5, 0], [() => IdToken2, 0]]
    ];
    Scopes2 = 64 | 0;
    CreateToken$2 = [
      9,
      n011,
      _CT2,
      { [_h8]: ["POST", "/token", 200] },
      () => CreateTokenRequest$2,
      () => CreateTokenResponse$2
    ];
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/runtimeConfig.shared.js
var import_smithy_client109, import_url_parser12, import_util_base6435, import_util_utf827, getRuntimeConfig21;
var init_runtimeConfig_shared11 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/runtimeConfig.shared.js"() {
    init_httpAuthSchemes6();
    init_protocols8();
    init_dist_es();
    import_smithy_client109 = __toESM(require_dist_cjs34());
    import_url_parser12 = __toESM(require_dist_cjs18());
    import_util_base6435 = __toESM(require_dist_cjs10());
    import_util_utf827 = __toESM(require_dist_cjs9());
    init_httpAuthSchemeProvider11();
    init_endpointResolver11();
    init_schemas_011();
    getRuntimeConfig21 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2019-06-10",
        base64Decoder: config2?.base64Decoder ?? import_util_base6435.fromBase64,
        base64Encoder: config2?.base64Encoder ?? import_util_base6435.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver11,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSSOOIDCHttpAuthSchemeProvider2,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer5()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        logger: config2?.logger ?? new import_smithy_client109.NoOpLogger(),
        protocol: config2?.protocol ?? AwsRestJsonProtocol6,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.ssooidc",
          errorTypeRegistries: errorTypeRegistries11,
          version: "2019-06-10",
          serviceTarget: "AWSSSOOIDCService"
        },
        serviceId: config2?.serviceId ?? "SSO OIDC",
        urlParser: config2?.urlParser ?? import_url_parser12.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? import_util_utf827.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? import_util_utf827.toUtf8
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/runtimeConfig.js
var import_util_user_agent_node11, import_config_resolver21, import_hash_node11, import_middleware_retry21, import_node_config_provider11, import_node_http_handler11, import_smithy_client110, import_util_body_length_node11, import_util_defaults_mode_node11, import_util_retry18, getRuntimeConfig22;
var init_runtimeConfig11 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/runtimeConfig.js"() {
    init_package5();
    init_client8();
    init_httpAuthSchemes6();
    import_util_user_agent_node11 = __toESM(require_dist_cjs113());
    import_config_resolver21 = __toESM(require_dist_cjs25());
    import_hash_node11 = __toESM(require_dist_cjs44());
    import_middleware_retry21 = __toESM(require_dist_cjs106());
    import_node_config_provider11 = __toESM(require_dist_cjs29());
    import_node_http_handler11 = __toESM(require_dist_cjs13());
    import_smithy_client110 = __toESM(require_dist_cjs34());
    import_util_body_length_node11 = __toESM(require_dist_cjs45());
    import_util_defaults_mode_node11 = __toESM(require_dist_cjs46());
    import_util_retry18 = __toESM(require_dist_cjs22());
    init_runtimeConfig_shared11();
    getRuntimeConfig22 = /* @__PURE__ */ __name((config2) => {
      (0, import_smithy_client110.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, import_util_defaults_mode_node11.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(import_smithy_client110.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig21(config2);
      emitWarningIfUnsupportedVersion17(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, import_node_config_provider11.loadConfig)(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS5, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? import_util_body_length_node11.calculateBodyLength,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, import_util_user_agent_node11.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_default5.version }),
        maxAttempts: config2?.maxAttempts ?? (0, import_node_config_provider11.loadConfig)(import_middleware_retry21.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, import_node_config_provider11.loadConfig)(import_config_resolver21.NODE_REGION_CONFIG_OPTIONS, { ...import_config_resolver21.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: import_node_http_handler11.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, import_node_config_provider11.loadConfig)({
          ...import_middleware_retry21.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || import_util_retry18.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? import_hash_node11.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? import_node_http_handler11.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, import_node_config_provider11.loadConfig)(import_config_resolver21.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, import_node_config_provider11.loadConfig)(import_config_resolver21.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, import_node_config_provider11.loadConfig)(import_util_user_agent_node11.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration11, resolveHttpAuthRuntimeConfig11;
var init_httpAuthExtensionConfiguration11 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration11 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig11 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/runtimeExtensions.js
var import_region_config_resolver14, import_protocol_http34, import_smithy_client111, resolveRuntimeExtensions11;
var init_runtimeExtensions11 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/runtimeExtensions.js"() {
    import_region_config_resolver14 = __toESM(require_dist_cjs48());
    import_protocol_http34 = __toESM(require_dist_cjs2());
    import_smithy_client111 = __toESM(require_dist_cjs34());
    init_httpAuthExtensionConfiguration11();
    resolveRuntimeExtensions11 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign((0, import_region_config_resolver14.getAwsRegionExtensionConfiguration)(runtimeConfig), (0, import_smithy_client111.getDefaultExtensionConfiguration)(runtimeConfig), (0, import_protocol_http34.getHttpHandlerExtensionConfiguration)(runtimeConfig), getHttpAuthExtensionConfiguration11(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, (0, import_region_config_resolver14.resolveAwsRegionExtensionConfiguration)(extensionConfiguration), (0, import_smithy_client111.resolveDefaultRuntimeConfig)(extensionConfiguration), (0, import_protocol_http34.resolveHttpHandlerRuntimeConfig)(extensionConfiguration), resolveHttpAuthRuntimeConfig11(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/SSOOIDCClient.js
var import_middleware_host_header11, import_middleware_logger11, import_middleware_recursion_detection11, import_middleware_user_agent11, import_config_resolver22, import_middleware_content_length11, import_middleware_endpoint27, import_middleware_retry22, import_smithy_client112, SSOOIDCClient2;
var init_SSOOIDCClient2 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/SSOOIDCClient.js"() {
    import_middleware_host_header11 = __toESM(require_dist_cjs3());
    import_middleware_logger11 = __toESM(require_dist_cjs4());
    import_middleware_recursion_detection11 = __toESM(require_dist_cjs5());
    import_middleware_user_agent11 = __toESM(require_dist_cjs104());
    import_config_resolver22 = __toESM(require_dist_cjs25());
    init_dist_es();
    init_schema4();
    import_middleware_content_length11 = __toESM(require_dist_cjs26());
    import_middleware_endpoint27 = __toESM(require_dist_cjs31());
    import_middleware_retry22 = __toESM(require_dist_cjs106());
    import_smithy_client112 = __toESM(require_dist_cjs34());
    init_httpAuthSchemeProvider11();
    init_EndpointParameters11();
    init_runtimeConfig11();
    init_runtimeExtensions11();
    SSOOIDCClient2 = class extends import_smithy_client112.Client {
      static {
        __name(this, "SSOOIDCClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig22(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters11(_config_0);
        const _config_2 = (0, import_middleware_user_agent11.resolveUserAgentConfig)(_config_1);
        const _config_3 = (0, import_middleware_retry22.resolveRetryConfig)(_config_2);
        const _config_4 = (0, import_config_resolver22.resolveRegionConfig)(_config_3);
        const _config_5 = (0, import_middleware_host_header11.resolveHostHeaderConfig)(_config_4);
        const _config_6 = (0, import_middleware_endpoint27.resolveEndpointConfig)(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig11(_config_6);
        const _config_8 = resolveRuntimeExtensions11(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin(this.config));
        this.middlewareStack.use((0, import_middleware_user_agent11.getUserAgentPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_retry22.getRetryPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_content_length11.getContentLengthPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_host_header11.getHostHeaderPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_logger11.getLoggerPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_recursion_detection11.getRecursionDetectionPlugin)(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: defaultSSOOIDCHttpAuthSchemeParametersProvider2,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/commands/CreateTokenCommand.js
var import_middleware_endpoint28, import_smithy_client113, CreateTokenCommand2;
var init_CreateTokenCommand2 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/commands/CreateTokenCommand.js"() {
    import_middleware_endpoint28 = __toESM(require_dist_cjs31());
    import_smithy_client113 = __toESM(require_dist_cjs34());
    init_EndpointParameters11();
    init_schemas_011();
    CreateTokenCommand2 = class extends import_smithy_client113.Command.classBuilder().ep(commonParams11).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint28.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSSOOIDCService", "CreateToken", {}).n("SSOOIDCClient", "CreateTokenCommand").sc(CreateToken$2).build() {
      static {
        __name(this, "CreateTokenCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/SSOOIDC.js
var import_smithy_client114, commands11, SSOOIDC2;
var init_SSOOIDC2 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/SSOOIDC.js"() {
    import_smithy_client114 = __toESM(require_dist_cjs34());
    init_CreateTokenCommand2();
    init_SSOOIDCClient2();
    commands11 = {
      CreateTokenCommand: CreateTokenCommand2
    };
    SSOOIDC2 = class extends SSOOIDCClient2 {
      static {
        __name(this, "SSOOIDC");
      }
    };
    (0, import_smithy_client114.createAggregatedClient)(commands11, SSOOIDC2);
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/commands/index.js
var init_commands12 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/commands/index.js"() {
    init_CreateTokenCommand2();
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/models/enums.js
var AccessDeniedExceptionReason2, InvalidRequestExceptionReason2;
var init_enums5 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/models/enums.js"() {
    AccessDeniedExceptionReason2 = {
      KMS_ACCESS_DENIED: "KMS_AccessDeniedException"
    };
    InvalidRequestExceptionReason2 = {
      KMS_DISABLED_KEY: "KMS_DisabledException",
      KMS_INVALID_KEY_USAGE: "KMS_InvalidKeyUsageException",
      KMS_INVALID_STATE: "KMS_InvalidStateException",
      KMS_KEY_NOT_FOUND: "KMS_NotFoundException"
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/models/models_0.js
var init_models_011 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/index.js
var sso_oidc_exports2 = {};
__export(sso_oidc_exports2, {
  $Command: () => import_smithy_client113.Command,
  AccessDeniedException: () => AccessDeniedException5,
  AccessDeniedException$: () => AccessDeniedException$5,
  AccessDeniedExceptionReason: () => AccessDeniedExceptionReason2,
  AuthorizationPendingException: () => AuthorizationPendingException2,
  AuthorizationPendingException$: () => AuthorizationPendingException$2,
  CreateToken$: () => CreateToken$2,
  CreateTokenCommand: () => CreateTokenCommand2,
  CreateTokenRequest$: () => CreateTokenRequest$2,
  CreateTokenResponse$: () => CreateTokenResponse$2,
  ExpiredTokenException: () => ExpiredTokenException5,
  ExpiredTokenException$: () => ExpiredTokenException$5,
  InternalServerException: () => InternalServerException5,
  InternalServerException$: () => InternalServerException$5,
  InvalidClientException: () => InvalidClientException2,
  InvalidClientException$: () => InvalidClientException$2,
  InvalidGrantException: () => InvalidGrantException2,
  InvalidGrantException$: () => InvalidGrantException$2,
  InvalidRequestException: () => InvalidRequestException5,
  InvalidRequestException$: () => InvalidRequestException$5,
  InvalidRequestExceptionReason: () => InvalidRequestExceptionReason2,
  InvalidScopeException: () => InvalidScopeException2,
  InvalidScopeException$: () => InvalidScopeException$2,
  SSOOIDC: () => SSOOIDC2,
  SSOOIDCClient: () => SSOOIDCClient2,
  SSOOIDCServiceException: () => SSOOIDCServiceException2,
  SSOOIDCServiceException$: () => SSOOIDCServiceException$2,
  SlowDownException: () => SlowDownException2,
  SlowDownException$: () => SlowDownException$2,
  UnauthorizedClientException: () => UnauthorizedClientException2,
  UnauthorizedClientException$: () => UnauthorizedClientException$2,
  UnsupportedGrantTypeException: () => UnsupportedGrantTypeException2,
  UnsupportedGrantTypeException$: () => UnsupportedGrantTypeException$2,
  __Client: () => import_smithy_client112.Client,
  errorTypeRegistries: () => errorTypeRegistries11
});
var init_sso_oidc2 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/index.js"() {
    init_SSOOIDCClient2();
    init_SSOOIDC2();
    init_commands12();
    init_schemas_011();
    init_enums5();
    init_errors11();
    init_models_011();
    init_SSOOIDCServiceException2();
  }
});

// ../../node_modules/@aws-sdk/credential-provider-sso/node_modules/@aws-sdk/token-providers/dist-cjs/index.js
var require_dist_cjs114 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-sso/node_modules/@aws-sdk/token-providers/dist-cjs/index.js"(exports2) {
    "use strict";
    var client = (init_client8(), __toCommonJS(client_exports7));
    var httpAuthSchemes = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var propertyProvider = require_dist_cjs27();
    var sharedIniFileLoader = require_dist_cjs28();
    var node_fs = require("node:fs");
    var fromEnvSigningName = /* @__PURE__ */ __name(({ logger: logger5, signingName } = {}) => async () => {
      logger5?.debug?.("@aws-sdk/token-providers - fromEnvSigningName");
      if (!signingName) {
        throw new propertyProvider.TokenProviderError("Please pass 'signingName' to compute environment variable key", { logger: logger5 });
      }
      const bearerTokenKey = httpAuthSchemes.getBearerTokenEnvKey(signingName);
      if (!(bearerTokenKey in process.env)) {
        throw new propertyProvider.TokenProviderError(`Token not present in '${bearerTokenKey}' environment variable`, { logger: logger5 });
      }
      const token = { token: process.env[bearerTokenKey] };
      client.setTokenFeature(token, "BEARER_SERVICE_ENV_VARS", "3");
      return token;
    }, "fromEnvSigningName");
    var EXPIRE_WINDOW_MS = 5 * 60 * 1e3;
    var REFRESH_MESSAGE = `To refresh this SSO session run 'aws sso login' with the corresponding profile.`;
    var getSsoOidcClient = /* @__PURE__ */ __name(async (ssoRegion, init = {}, callerClientConfig) => {
      const { SSOOIDCClient: SSOOIDCClient4 } = await Promise.resolve().then(() => (init_sso_oidc2(), sso_oidc_exports2));
      const coalesce3 = /* @__PURE__ */ __name((prop) => init.clientConfig?.[prop] ?? init.parentClientConfig?.[prop] ?? callerClientConfig?.[prop], "coalesce");
      const ssoOidcClient = new SSOOIDCClient4(Object.assign({}, init.clientConfig ?? {}, {
        region: ssoRegion ?? init.clientConfig?.region,
        logger: coalesce3("logger"),
        userAgentAppId: coalesce3("userAgentAppId")
      }));
      return ssoOidcClient;
    }, "getSsoOidcClient");
    var getNewSsoOidcToken = /* @__PURE__ */ __name(async (ssoToken, ssoRegion, init = {}, callerClientConfig) => {
      const { CreateTokenCommand: CreateTokenCommand4 } = await Promise.resolve().then(() => (init_sso_oidc2(), sso_oidc_exports2));
      const ssoOidcClient = await getSsoOidcClient(ssoRegion, init, callerClientConfig);
      return ssoOidcClient.send(new CreateTokenCommand4({
        clientId: ssoToken.clientId,
        clientSecret: ssoToken.clientSecret,
        refreshToken: ssoToken.refreshToken,
        grantType: "refresh_token"
      }));
    }, "getNewSsoOidcToken");
    var validateTokenExpiry = /* @__PURE__ */ __name((token) => {
      if (token.expiration && token.expiration.getTime() < Date.now()) {
        throw new propertyProvider.TokenProviderError(`Token is expired. ${REFRESH_MESSAGE}`, false);
      }
    }, "validateTokenExpiry");
    var validateTokenKey = /* @__PURE__ */ __name((key, value, forRefresh = false) => {
      if (typeof value === "undefined") {
        throw new propertyProvider.TokenProviderError(`Value not present for '${key}' in SSO Token${forRefresh ? ". Cannot refresh" : ""}. ${REFRESH_MESSAGE}`, false);
      }
    }, "validateTokenKey");
    var { writeFile: writeFile6 } = node_fs.promises;
    var writeSSOTokenToFile = /* @__PURE__ */ __name((id, ssoToken) => {
      const tokenFilepath = sharedIniFileLoader.getSSOTokenFilepath(id);
      const tokenString = JSON.stringify(ssoToken, null, 2);
      return writeFile6(tokenFilepath, tokenString);
    }, "writeSSOTokenToFile");
    var lastRefreshAttemptTime = /* @__PURE__ */ new Date(0);
    var fromSso = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/token-providers - fromSso");
      const profiles = await sharedIniFileLoader.parseKnownFiles(init);
      const profileName = sharedIniFileLoader.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      });
      const profile = profiles[profileName];
      if (!profile) {
        throw new propertyProvider.TokenProviderError(`Profile '${profileName}' could not be found in shared credentials file.`, false);
      } else if (!profile["sso_session"]) {
        throw new propertyProvider.TokenProviderError(`Profile '${profileName}' is missing required property 'sso_session'.`);
      }
      const ssoSessionName = profile["sso_session"];
      const ssoSessions = await sharedIniFileLoader.loadSsoSessionData(init);
      const ssoSession = ssoSessions[ssoSessionName];
      if (!ssoSession) {
        throw new propertyProvider.TokenProviderError(`Sso session '${ssoSessionName}' could not be found in shared credentials file.`, false);
      }
      for (const ssoSessionRequiredKey of ["sso_start_url", "sso_region"]) {
        if (!ssoSession[ssoSessionRequiredKey]) {
          throw new propertyProvider.TokenProviderError(`Sso session '${ssoSessionName}' is missing required property '${ssoSessionRequiredKey}'.`, false);
        }
      }
      ssoSession["sso_start_url"];
      const ssoRegion = ssoSession["sso_region"];
      let ssoToken;
      try {
        ssoToken = await sharedIniFileLoader.getSSOTokenFromFile(ssoSessionName);
      } catch (e32) {
        throw new propertyProvider.TokenProviderError(`The SSO session token associated with profile=${profileName} was not found or is invalid. ${REFRESH_MESSAGE}`, false);
      }
      validateTokenKey("accessToken", ssoToken.accessToken);
      validateTokenKey("expiresAt", ssoToken.expiresAt);
      const { accessToken, expiresAt } = ssoToken;
      const existingToken = { token: accessToken, expiration: new Date(expiresAt) };
      if (existingToken.expiration.getTime() - Date.now() > EXPIRE_WINDOW_MS) {
        return existingToken;
      }
      if (Date.now() - lastRefreshAttemptTime.getTime() < 30 * 1e3) {
        validateTokenExpiry(existingToken);
        return existingToken;
      }
      validateTokenKey("clientId", ssoToken.clientId, true);
      validateTokenKey("clientSecret", ssoToken.clientSecret, true);
      validateTokenKey("refreshToken", ssoToken.refreshToken, true);
      try {
        lastRefreshAttemptTime.setTime(Date.now());
        const newSsoOidcToken = await getNewSsoOidcToken(ssoToken, ssoRegion, init, callerClientConfig);
        validateTokenKey("accessToken", newSsoOidcToken.accessToken);
        validateTokenKey("expiresIn", newSsoOidcToken.expiresIn);
        const newTokenExpiration = new Date(Date.now() + newSsoOidcToken.expiresIn * 1e3);
        try {
          await writeSSOTokenToFile(ssoSessionName, {
            ...ssoToken,
            accessToken: newSsoOidcToken.accessToken,
            expiresAt: newTokenExpiration.toISOString(),
            refreshToken: newSsoOidcToken.refreshToken
          });
        } catch (error4) {
        }
        return {
          token: newSsoOidcToken.accessToken,
          expiration: newTokenExpiration
        };
      } catch (error4) {
        validateTokenExpiry(existingToken);
        return existingToken;
      }
    }, "fromSso");
    var fromStatic5 = /* @__PURE__ */ __name(({ token, logger: logger5 }) => async () => {
      logger5?.debug("@aws-sdk/token-providers - fromStatic");
      if (!token || !token.token) {
        throw new propertyProvider.TokenProviderError(`Please pass a valid token to fromStatic`, false);
      }
      return token;
    }, "fromStatic");
    var nodeProvider = /* @__PURE__ */ __name((init = {}) => propertyProvider.memoize(propertyProvider.chain(fromSso(init), async () => {
      throw new propertyProvider.TokenProviderError("Could not load token from any providers", false);
    }), (token) => token.expiration !== void 0 && token.expiration.getTime() - Date.now() < 3e5, (token) => token.expiration !== void 0), "nodeProvider");
    exports2.fromEnvSigningName = fromEnvSigningName;
    exports2.fromSso = fromSso;
    exports2.fromStatic = fromStatic5;
    exports2.nodeProvider = nodeProvider;
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption12(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "awsssoportal",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption12(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var import_util_middleware17, defaultSSOHttpAuthSchemeParametersProvider4, defaultSSOHttpAuthSchemeProvider4, resolveHttpAuthSchemeConfig12;
var init_httpAuthSchemeProvider12 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes6();
    import_util_middleware17 = __toESM(require_dist_cjs6());
    defaultSSOHttpAuthSchemeParametersProvider4 = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, import_util_middleware17.getSmithyContext)(context).operation,
        region: await (0, import_util_middleware17.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultSSOHttpAuthSchemeParametersProvider");
    __name(createAwsAuthSigv4HttpAuthOption12, "createAwsAuthSigv4HttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption12, "createSmithyApiNoAuthHttpAuthOption");
    defaultSSOHttpAuthSchemeProvider4 = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "GetRoleCredentials": {
          options.push(createSmithyApiNoAuthHttpAuthOption12(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption12(authParameters));
        }
      }
      return options;
    }, "defaultSSOHttpAuthSchemeProvider");
    resolveHttpAuthSchemeConfig12 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveAwsSdkSigV4Config5(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, import_util_middleware17.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/EndpointParameters.js
var resolveClientEndpointParameters12, commonParams12;
var init_EndpointParameters12 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters12 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "awsssoportal"
      });
    }, "resolveClientEndpointParameters");
    commonParams12 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/bdd.js
var import_util_endpoints34, k12, a12, b12, c12, d12, e12, f12, g12, h12, i12, j12, _data12, root12, r12, nodes12, bdd12;
var init_bdd12 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/bdd.js"() {
    import_util_endpoints34 = __toESM(require_dist_cjs20());
    k12 = "ref";
    a12 = -1;
    b12 = true;
    c12 = "isSet";
    d12 = "PartitionResult";
    e12 = "booleanEquals";
    f12 = "getAttr";
    g12 = { [k12]: "Endpoint" };
    h12 = { [k12]: d12 };
    i12 = {};
    j12 = [{ [k12]: "Region" }];
    _data12 = {
      conditions: [
        [c12, [g12]],
        [c12, j12],
        ["aws.partition", j12, d12],
        [e12, [{ [k12]: "UseFIPS" }, b12]],
        [e12, [{ [k12]: "UseDualStack" }, b12]],
        [e12, [{ fn: f12, argv: [h12, "supportsDualStack"] }, b12]],
        [e12, [{ fn: f12, argv: [h12, "supportsFIPS"] }, b12]],
        ["stringEquals", [{ fn: f12, argv: [h12, "name"] }, "aws-us-gov"]]
      ],
      results: [
        [a12],
        [a12, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a12, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [g12, i12],
        ["https://portal.sso-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", i12],
        [a12, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://portal.sso.{Region}.amazonaws.com", i12],
        ["https://portal.sso-fips.{Region}.{PartitionResult#dnsSuffix}", i12],
        [a12, "FIPS is enabled but this partition does not support FIPS"],
        ["https://portal.sso.{Region}.{PartitionResult#dualStackDnsSuffix}", i12],
        [a12, "DualStack is enabled but this partition does not support DualStack"],
        ["https://portal.sso.{Region}.{PartitionResult#dnsSuffix}", i12],
        [a12, "Invalid Configuration: Missing Region"]
      ]
    };
    root12 = 2;
    r12 = 1e8;
    nodes12 = new Int32Array([
      -1,
      1,
      -1,
      0,
      13,
      3,
      1,
      4,
      r12 + 12,
      2,
      5,
      r12 + 12,
      3,
      8,
      6,
      4,
      7,
      r12 + 11,
      5,
      r12 + 9,
      r12 + 10,
      4,
      11,
      9,
      6,
      10,
      r12 + 8,
      7,
      r12 + 6,
      r12 + 7,
      5,
      12,
      r12 + 5,
      6,
      r12 + 4,
      r12 + 5,
      3,
      r12 + 1,
      14,
      4,
      r12 + 2,
      r12 + 3
    ]);
    bdd12 = import_util_endpoints34.BinaryDecisionDiagram.from(nodes12, root12, _data12.conditions, _data12.results);
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/endpointResolver.js
var import_util_endpoints35, import_util_endpoints36, cache12, defaultEndpointResolver12;
var init_endpointResolver12 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/endpointResolver.js"() {
    import_util_endpoints35 = __toESM(require_dist_cjs21());
    import_util_endpoints36 = __toESM(require_dist_cjs20());
    init_bdd12();
    cache12 = new import_util_endpoints36.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    defaultEndpointResolver12 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache12.get(endpointParams, () => (0, import_util_endpoints36.decideEndpoint)(bdd12, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    import_util_endpoints36.customEndpointFunctions.aws = import_util_endpoints35.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/SSOServiceException.js
var import_smithy_client115, SSOServiceException4;
var init_SSOServiceException4 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/SSOServiceException.js"() {
    import_smithy_client115 = __toESM(require_dist_cjs34());
    SSOServiceException4 = class _SSOServiceException extends import_smithy_client115.ServiceException {
      static {
        __name(this, "SSOServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _SSOServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/errors.js
var InvalidRequestException6, ResourceNotFoundException4, TooManyRequestsException4, UnauthorizedException4;
var init_errors12 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/errors.js"() {
    init_SSOServiceException4();
    InvalidRequestException6 = class _InvalidRequestException extends SSOServiceException4 {
      static {
        __name(this, "InvalidRequestException");
      }
      name = "InvalidRequestException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidRequestException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidRequestException.prototype);
      }
    };
    ResourceNotFoundException4 = class _ResourceNotFoundException extends SSOServiceException4 {
      static {
        __name(this, "ResourceNotFoundException");
      }
      name = "ResourceNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ResourceNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceNotFoundException.prototype);
      }
    };
    TooManyRequestsException4 = class _TooManyRequestsException extends SSOServiceException4 {
      static {
        __name(this, "TooManyRequestsException");
      }
      name = "TooManyRequestsException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TooManyRequestsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyRequestsException.prototype);
      }
    };
    UnauthorizedException4 = class _UnauthorizedException extends SSOServiceException4 {
      static {
        __name(this, "UnauthorizedException");
      }
      name = "UnauthorizedException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "UnauthorizedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnauthorizedException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/schemas/schemas_0.js
var _ATT4, _GRC4, _GRCR4, _GRCRe4, _IRE6, _RC4, _RNFE4, _SAKT4, _STT4, _TMRE7, _UE4, _aI4, _aKI7, _aT9, _ai4, _c12, _e12, _ex4, _h9, _hE12, _hH4, _hQ4, _m10, _rC4, _rN4, _rn4, _s12, _sAK7, _sT7, _xasbt4, n012, _s_registry12, SSOServiceException$4, n0_registry12, InvalidRequestException$6, ResourceNotFoundException$4, TooManyRequestsException$4, UnauthorizedException$4, errorTypeRegistries12, AccessTokenType4, SecretAccessKeyType4, SessionTokenType4, GetRoleCredentialsRequest$4, GetRoleCredentialsResponse$4, RoleCredentials$4, GetRoleCredentials$4;
var init_schemas_012 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/schemas/schemas_0.js"() {
    init_schema4();
    init_errors12();
    init_SSOServiceException4();
    _ATT4 = "AccessTokenType";
    _GRC4 = "GetRoleCredentials";
    _GRCR4 = "GetRoleCredentialsRequest";
    _GRCRe4 = "GetRoleCredentialsResponse";
    _IRE6 = "InvalidRequestException";
    _RC4 = "RoleCredentials";
    _RNFE4 = "ResourceNotFoundException";
    _SAKT4 = "SecretAccessKeyType";
    _STT4 = "SessionTokenType";
    _TMRE7 = "TooManyRequestsException";
    _UE4 = "UnauthorizedException";
    _aI4 = "accountId";
    _aKI7 = "accessKeyId";
    _aT9 = "accessToken";
    _ai4 = "account_id";
    _c12 = "client";
    _e12 = "error";
    _ex4 = "expiration";
    _h9 = "http";
    _hE12 = "httpError";
    _hH4 = "httpHeader";
    _hQ4 = "httpQuery";
    _m10 = "message";
    _rC4 = "roleCredentials";
    _rN4 = "roleName";
    _rn4 = "role_name";
    _s12 = "smithy.ts.sdk.synthetic.com.amazonaws.sso";
    _sAK7 = "secretAccessKey";
    _sT7 = "sessionToken";
    _xasbt4 = "x-amz-sso_bearer_token";
    n012 = "com.amazonaws.sso";
    _s_registry12 = TypeRegistry.for(_s12);
    SSOServiceException$4 = [-3, _s12, "SSOServiceException", 0, [], []];
    _s_registry12.registerError(SSOServiceException$4, SSOServiceException4);
    n0_registry12 = TypeRegistry.for(n012);
    InvalidRequestException$6 = [-3, n012, _IRE6, { [_e12]: _c12, [_hE12]: 400 }, [_m10], [0]];
    n0_registry12.registerError(InvalidRequestException$6, InvalidRequestException6);
    ResourceNotFoundException$4 = [-3, n012, _RNFE4, { [_e12]: _c12, [_hE12]: 404 }, [_m10], [0]];
    n0_registry12.registerError(ResourceNotFoundException$4, ResourceNotFoundException4);
    TooManyRequestsException$4 = [-3, n012, _TMRE7, { [_e12]: _c12, [_hE12]: 429 }, [_m10], [0]];
    n0_registry12.registerError(TooManyRequestsException$4, TooManyRequestsException4);
    UnauthorizedException$4 = [-3, n012, _UE4, { [_e12]: _c12, [_hE12]: 401 }, [_m10], [0]];
    n0_registry12.registerError(UnauthorizedException$4, UnauthorizedException4);
    errorTypeRegistries12 = [_s_registry12, n0_registry12];
    AccessTokenType4 = [0, n012, _ATT4, 8, 0];
    SecretAccessKeyType4 = [0, n012, _SAKT4, 8, 0];
    SessionTokenType4 = [0, n012, _STT4, 8, 0];
    GetRoleCredentialsRequest$4 = [
      3,
      n012,
      _GRCR4,
      0,
      [_rN4, _aI4, _aT9],
      [
        [0, { [_hQ4]: _rn4 }],
        [0, { [_hQ4]: _ai4 }],
        [() => AccessTokenType4, { [_hH4]: _xasbt4 }]
      ],
      3
    ];
    GetRoleCredentialsResponse$4 = [
      3,
      n012,
      _GRCRe4,
      0,
      [_rC4],
      [[() => RoleCredentials$4, 0]]
    ];
    RoleCredentials$4 = [
      3,
      n012,
      _RC4,
      0,
      [_aKI7, _sAK7, _sT7, _ex4],
      [0, [() => SecretAccessKeyType4, 0], [() => SessionTokenType4, 0], 1]
    ];
    GetRoleCredentials$4 = [
      9,
      n012,
      _GRC4,
      { [_h9]: ["GET", "/federation/credentials", 200] },
      () => GetRoleCredentialsRequest$4,
      () => GetRoleCredentialsResponse$4
    ];
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.shared.js
var import_smithy_client116, import_url_parser13, import_util_base6436, import_util_utf828, getRuntimeConfig23;
var init_runtimeConfig_shared12 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.shared.js"() {
    init_httpAuthSchemes6();
    init_protocols8();
    init_dist_es();
    import_smithy_client116 = __toESM(require_dist_cjs34());
    import_url_parser13 = __toESM(require_dist_cjs18());
    import_util_base6436 = __toESM(require_dist_cjs10());
    import_util_utf828 = __toESM(require_dist_cjs9());
    init_httpAuthSchemeProvider12();
    init_endpointResolver12();
    init_schemas_012();
    getRuntimeConfig23 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2019-06-10",
        base64Decoder: config2?.base64Decoder ?? import_util_base6436.fromBase64,
        base64Encoder: config2?.base64Encoder ?? import_util_base6436.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver12,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSSOHttpAuthSchemeProvider4,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer5()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        logger: config2?.logger ?? new import_smithy_client116.NoOpLogger(),
        protocol: config2?.protocol ?? AwsRestJsonProtocol6,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.sso",
          errorTypeRegistries: errorTypeRegistries12,
          version: "2019-06-10",
          serviceTarget: "SWBPortalService"
        },
        serviceId: config2?.serviceId ?? "SSO",
        urlParser: config2?.urlParser ?? import_url_parser13.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? import_util_utf828.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? import_util_utf828.toUtf8
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.js
var import_util_user_agent_node12, import_config_resolver23, import_hash_node12, import_middleware_retry23, import_node_config_provider12, import_node_http_handler12, import_smithy_client117, import_util_body_length_node12, import_util_defaults_mode_node12, import_util_retry19, getRuntimeConfig24;
var init_runtimeConfig12 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.js"() {
    init_package5();
    init_client8();
    init_httpAuthSchemes6();
    import_util_user_agent_node12 = __toESM(require_dist_cjs113());
    import_config_resolver23 = __toESM(require_dist_cjs25());
    import_hash_node12 = __toESM(require_dist_cjs44());
    import_middleware_retry23 = __toESM(require_dist_cjs106());
    import_node_config_provider12 = __toESM(require_dist_cjs29());
    import_node_http_handler12 = __toESM(require_dist_cjs13());
    import_smithy_client117 = __toESM(require_dist_cjs34());
    import_util_body_length_node12 = __toESM(require_dist_cjs45());
    import_util_defaults_mode_node12 = __toESM(require_dist_cjs46());
    import_util_retry19 = __toESM(require_dist_cjs22());
    init_runtimeConfig_shared12();
    getRuntimeConfig24 = /* @__PURE__ */ __name((config2) => {
      (0, import_smithy_client117.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, import_util_defaults_mode_node12.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(import_smithy_client117.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig23(config2);
      emitWarningIfUnsupportedVersion17(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, import_node_config_provider12.loadConfig)(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS5, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? import_util_body_length_node12.calculateBodyLength,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, import_util_user_agent_node12.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_default5.version }),
        maxAttempts: config2?.maxAttempts ?? (0, import_node_config_provider12.loadConfig)(import_middleware_retry23.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, import_node_config_provider12.loadConfig)(import_config_resolver23.NODE_REGION_CONFIG_OPTIONS, { ...import_config_resolver23.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: import_node_http_handler12.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, import_node_config_provider12.loadConfig)({
          ...import_middleware_retry23.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || import_util_retry19.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? import_hash_node12.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? import_node_http_handler12.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, import_node_config_provider12.loadConfig)(import_config_resolver23.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, import_node_config_provider12.loadConfig)(import_config_resolver23.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, import_node_config_provider12.loadConfig)(import_util_user_agent_node12.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration12, resolveHttpAuthRuntimeConfig12;
var init_httpAuthExtensionConfiguration12 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration12 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig12 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeExtensions.js
var import_region_config_resolver15, import_protocol_http35, import_smithy_client118, resolveRuntimeExtensions12;
var init_runtimeExtensions12 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeExtensions.js"() {
    import_region_config_resolver15 = __toESM(require_dist_cjs48());
    import_protocol_http35 = __toESM(require_dist_cjs2());
    import_smithy_client118 = __toESM(require_dist_cjs34());
    init_httpAuthExtensionConfiguration12();
    resolveRuntimeExtensions12 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign((0, import_region_config_resolver15.getAwsRegionExtensionConfiguration)(runtimeConfig), (0, import_smithy_client118.getDefaultExtensionConfiguration)(runtimeConfig), (0, import_protocol_http35.getHttpHandlerExtensionConfiguration)(runtimeConfig), getHttpAuthExtensionConfiguration12(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, (0, import_region_config_resolver15.resolveAwsRegionExtensionConfiguration)(extensionConfiguration), (0, import_smithy_client118.resolveDefaultRuntimeConfig)(extensionConfiguration), (0, import_protocol_http35.resolveHttpHandlerRuntimeConfig)(extensionConfiguration), resolveHttpAuthRuntimeConfig12(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSOClient.js
var import_middleware_host_header12, import_middleware_logger12, import_middleware_recursion_detection12, import_middleware_user_agent12, import_config_resolver24, import_middleware_content_length12, import_middleware_endpoint29, import_middleware_retry24, import_smithy_client119, SSOClient4;
var init_SSOClient4 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSOClient.js"() {
    import_middleware_host_header12 = __toESM(require_dist_cjs3());
    import_middleware_logger12 = __toESM(require_dist_cjs4());
    import_middleware_recursion_detection12 = __toESM(require_dist_cjs5());
    import_middleware_user_agent12 = __toESM(require_dist_cjs104());
    import_config_resolver24 = __toESM(require_dist_cjs25());
    init_dist_es();
    init_schema4();
    import_middleware_content_length12 = __toESM(require_dist_cjs26());
    import_middleware_endpoint29 = __toESM(require_dist_cjs31());
    import_middleware_retry24 = __toESM(require_dist_cjs106());
    import_smithy_client119 = __toESM(require_dist_cjs34());
    init_httpAuthSchemeProvider12();
    init_EndpointParameters12();
    init_runtimeConfig12();
    init_runtimeExtensions12();
    SSOClient4 = class extends import_smithy_client119.Client {
      static {
        __name(this, "SSOClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig24(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters12(_config_0);
        const _config_2 = (0, import_middleware_user_agent12.resolveUserAgentConfig)(_config_1);
        const _config_3 = (0, import_middleware_retry24.resolveRetryConfig)(_config_2);
        const _config_4 = (0, import_config_resolver24.resolveRegionConfig)(_config_3);
        const _config_5 = (0, import_middleware_host_header12.resolveHostHeaderConfig)(_config_4);
        const _config_6 = (0, import_middleware_endpoint29.resolveEndpointConfig)(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig12(_config_6);
        const _config_8 = resolveRuntimeExtensions12(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin(this.config));
        this.middlewareStack.use((0, import_middleware_user_agent12.getUserAgentPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_retry24.getRetryPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_content_length12.getContentLengthPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_host_header12.getHostHeaderPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_logger12.getLoggerPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_recursion_detection12.getRecursionDetectionPlugin)(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: defaultSSOHttpAuthSchemeParametersProvider4,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/GetRoleCredentialsCommand.js
var import_middleware_endpoint30, import_smithy_client120, GetRoleCredentialsCommand4;
var init_GetRoleCredentialsCommand4 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/GetRoleCredentialsCommand.js"() {
    import_middleware_endpoint30 = __toESM(require_dist_cjs31());
    import_smithy_client120 = __toESM(require_dist_cjs34());
    init_EndpointParameters12();
    init_schemas_012();
    GetRoleCredentialsCommand4 = class extends import_smithy_client120.Command.classBuilder().ep(commonParams12).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint30.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("SWBPortalService", "GetRoleCredentials", {}).n("SSOClient", "GetRoleCredentialsCommand").sc(GetRoleCredentials$4).build() {
      static {
        __name(this, "GetRoleCredentialsCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSO.js
var import_smithy_client121, commands12, SSO4;
var init_SSO4 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSO.js"() {
    import_smithy_client121 = __toESM(require_dist_cjs34());
    init_GetRoleCredentialsCommand4();
    init_SSOClient4();
    commands12 = {
      GetRoleCredentialsCommand: GetRoleCredentialsCommand4
    };
    SSO4 = class extends SSOClient4 {
      static {
        __name(this, "SSO");
      }
    };
    (0, import_smithy_client121.createAggregatedClient)(commands12, SSO4);
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/index.js
var init_commands13 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/index.js"() {
    init_GetRoleCredentialsCommand4();
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/models_0.js
var init_models_012 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/index.js
var sso_exports4 = {};
__export(sso_exports4, {
  $Command: () => import_smithy_client120.Command,
  GetRoleCredentials$: () => GetRoleCredentials$4,
  GetRoleCredentialsCommand: () => GetRoleCredentialsCommand4,
  GetRoleCredentialsRequest$: () => GetRoleCredentialsRequest$4,
  GetRoleCredentialsResponse$: () => GetRoleCredentialsResponse$4,
  InvalidRequestException: () => InvalidRequestException6,
  InvalidRequestException$: () => InvalidRequestException$6,
  ResourceNotFoundException: () => ResourceNotFoundException4,
  ResourceNotFoundException$: () => ResourceNotFoundException$4,
  RoleCredentials$: () => RoleCredentials$4,
  SSO: () => SSO4,
  SSOClient: () => SSOClient4,
  SSOServiceException: () => SSOServiceException4,
  SSOServiceException$: () => SSOServiceException$4,
  TooManyRequestsException: () => TooManyRequestsException4,
  TooManyRequestsException$: () => TooManyRequestsException$4,
  UnauthorizedException: () => UnauthorizedException4,
  UnauthorizedException$: () => UnauthorizedException$4,
  __Client: () => import_smithy_client119.Client,
  errorTypeRegistries: () => errorTypeRegistries12
});
var init_sso4 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/index.js"() {
    init_SSOClient4();
    init_SSO4();
    init_commands13();
    init_schemas_012();
    init_errors12();
    init_models_012();
    init_SSOServiceException4();
  }
});

// ../../node_modules/@aws-sdk/credential-provider-sso/dist-cjs/loadSso-BKDNrsal.js
var require_loadSso_BKDNrsal4 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-sso/dist-cjs/loadSso-BKDNrsal.js"(exports2) {
    "use strict";
    var sso = (init_sso4(), __toCommonJS(sso_exports4));
    exports2.GetRoleCredentialsCommand = sso.GetRoleCredentialsCommand;
    exports2.SSOClient = sso.SSOClient;
  }
});

// ../../node_modules/@aws-sdk/credential-provider-sso/dist-cjs/index.js
var require_dist_cjs115 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-sso/dist-cjs/index.js"(exports2) {
    "use strict";
    var propertyProvider = require_dist_cjs27();
    var sharedIniFileLoader = require_dist_cjs28();
    var client = (init_client8(), __toCommonJS(client_exports7));
    var tokenProviders = require_dist_cjs114();
    var isSsoProfile = /* @__PURE__ */ __name((arg) => arg && (typeof arg.sso_start_url === "string" || typeof arg.sso_account_id === "string" || typeof arg.sso_session === "string" || typeof arg.sso_region === "string" || typeof arg.sso_role_name === "string"), "isSsoProfile");
    var SHOULD_FAIL_CREDENTIAL_CHAIN = false;
    var resolveSSOCredentials = /* @__PURE__ */ __name(async ({ ssoStartUrl, ssoSession, ssoAccountId, ssoRegion, ssoRoleName, ssoClient, clientConfig, parentClientConfig, callerClientConfig, profile, filepath, configFilepath, ignoreCache, logger: logger5 }) => {
      let token;
      const refreshMessage = `To refresh this SSO session run aws sso login with the corresponding profile.`;
      if (ssoSession) {
        try {
          const _token = await tokenProviders.fromSso({
            profile,
            filepath,
            configFilepath,
            ignoreCache
          })();
          token = {
            accessToken: _token.token,
            expiresAt: new Date(_token.expiration).toISOString()
          };
        } catch (e32) {
          throw new propertyProvider.CredentialsProviderError(e32.message, {
            tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
            logger: logger5
          });
        }
      } else {
        try {
          token = await sharedIniFileLoader.getSSOTokenFromFile(ssoStartUrl);
        } catch (e32) {
          throw new propertyProvider.CredentialsProviderError(`The SSO session associated with this profile is invalid. ${refreshMessage}`, {
            tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
            logger: logger5
          });
        }
      }
      if (new Date(token.expiresAt).getTime() - Date.now() <= 0) {
        throw new propertyProvider.CredentialsProviderError(`The SSO session associated with this profile has expired. ${refreshMessage}`, {
          tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
          logger: logger5
        });
      }
      const { accessToken } = token;
      const { SSOClient: SSOClient10, GetRoleCredentialsCommand: GetRoleCredentialsCommand10 } = await Promise.resolve().then(function() {
        return require_loadSso_BKDNrsal4();
      });
      const sso = ssoClient || new SSOClient10(Object.assign({}, clientConfig ?? {}, {
        logger: clientConfig?.logger ?? callerClientConfig?.logger ?? parentClientConfig?.logger,
        region: clientConfig?.region ?? ssoRegion,
        userAgentAppId: clientConfig?.userAgentAppId ?? callerClientConfig?.userAgentAppId ?? parentClientConfig?.userAgentAppId
      }));
      let ssoResp;
      try {
        ssoResp = await sso.send(new GetRoleCredentialsCommand10({
          accountId: ssoAccountId,
          roleName: ssoRoleName,
          accessToken
        }));
      } catch (e32) {
        throw new propertyProvider.CredentialsProviderError(e32, {
          tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
          logger: logger5
        });
      }
      const { roleCredentials: { accessKeyId, secretAccessKey, sessionToken, expiration, credentialScope, accountId } = {} } = ssoResp;
      if (!accessKeyId || !secretAccessKey || !sessionToken || !expiration) {
        throw new propertyProvider.CredentialsProviderError("SSO returns an invalid temporary credential.", {
          tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
          logger: logger5
        });
      }
      const credentials = {
        accessKeyId,
        secretAccessKey,
        sessionToken,
        expiration: new Date(expiration),
        ...credentialScope && { credentialScope },
        ...accountId && { accountId }
      };
      if (ssoSession) {
        client.setCredentialFeature(credentials, "CREDENTIALS_SSO", "s");
      } else {
        client.setCredentialFeature(credentials, "CREDENTIALS_SSO_LEGACY", "u");
      }
      return credentials;
    }, "resolveSSOCredentials");
    var validateSsoProfile = /* @__PURE__ */ __name((profile, logger5) => {
      const { sso_start_url, sso_account_id, sso_region, sso_role_name } = profile;
      if (!sso_start_url || !sso_account_id || !sso_region || !sso_role_name) {
        throw new propertyProvider.CredentialsProviderError(`Profile is configured with invalid SSO credentials. Required parameters "sso_account_id", "sso_region", "sso_role_name", "sso_start_url". Got ${Object.keys(profile).join(", ")}
Reference: https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-sso.html`, { tryNextLink: false, logger: logger5 });
      }
      return profile;
    }, "validateSsoProfile");
    var fromSSO = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/credential-provider-sso - fromSSO");
      const { ssoStartUrl, ssoAccountId, ssoRegion, ssoRoleName, ssoSession } = init;
      const { ssoClient } = init;
      const profileName = sharedIniFileLoader.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      });
      if (!ssoStartUrl && !ssoAccountId && !ssoRegion && !ssoRoleName && !ssoSession) {
        const profiles = await sharedIniFileLoader.parseKnownFiles(init);
        const profile = profiles[profileName];
        if (!profile) {
          throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} was not found.`, { logger: init.logger });
        }
        if (!isSsoProfile(profile)) {
          throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} is not configured with SSO credentials.`, {
            logger: init.logger
          });
        }
        if (profile?.sso_session) {
          const ssoSessions = await sharedIniFileLoader.loadSsoSessionData(init);
          const session = ssoSessions[profile.sso_session];
          const conflictMsg = ` configurations in profile ${profileName} and sso-session ${profile.sso_session}`;
          if (ssoRegion && ssoRegion !== session.sso_region) {
            throw new propertyProvider.CredentialsProviderError(`Conflicting SSO region` + conflictMsg, {
              tryNextLink: false,
              logger: init.logger
            });
          }
          if (ssoStartUrl && ssoStartUrl !== session.sso_start_url) {
            throw new propertyProvider.CredentialsProviderError(`Conflicting SSO start_url` + conflictMsg, {
              tryNextLink: false,
              logger: init.logger
            });
          }
          profile.sso_region = session.sso_region;
          profile.sso_start_url = session.sso_start_url;
        }
        const { sso_start_url, sso_account_id, sso_region, sso_role_name, sso_session } = validateSsoProfile(profile, init.logger);
        return resolveSSOCredentials({
          ssoStartUrl: sso_start_url,
          ssoSession: sso_session,
          ssoAccountId: sso_account_id,
          ssoRegion: sso_region,
          ssoRoleName: sso_role_name,
          ssoClient,
          clientConfig: init.clientConfig,
          parentClientConfig: init.parentClientConfig,
          callerClientConfig: init.callerClientConfig,
          profile: profileName,
          filepath: init.filepath,
          configFilepath: init.configFilepath,
          ignoreCache: init.ignoreCache,
          logger: init.logger
        });
      } else if (!ssoStartUrl || !ssoAccountId || !ssoRegion || !ssoRoleName) {
        throw new propertyProvider.CredentialsProviderError('Incomplete configuration. The fromSSO() argument hash must include "ssoStartUrl", "ssoAccountId", "ssoRegion", "ssoRoleName"', { tryNextLink: false, logger: init.logger });
      } else {
        return resolveSSOCredentials({
          ssoStartUrl,
          ssoSession,
          ssoAccountId,
          ssoRegion,
          ssoRoleName,
          ssoClient,
          clientConfig: init.clientConfig,
          parentClientConfig: init.parentClientConfig,
          callerClientConfig: init.callerClientConfig,
          profile: profileName,
          filepath: init.filepath,
          configFilepath: init.configFilepath,
          ignoreCache: init.ignoreCache,
          logger: init.logger
        });
      }
    }, "fromSSO");
    exports2.fromSSO = fromSSO;
    exports2.isSsoProfile = isSsoProfile;
    exports2.validateSsoProfile = validateSsoProfile;
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption13(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "signin",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption13(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var import_util_middleware18, defaultSigninHttpAuthSchemeParametersProvider4, defaultSigninHttpAuthSchemeProvider4, resolveHttpAuthSchemeConfig13;
var init_httpAuthSchemeProvider13 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes6();
    import_util_middleware18 = __toESM(require_dist_cjs6());
    defaultSigninHttpAuthSchemeParametersProvider4 = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, import_util_middleware18.getSmithyContext)(context).operation,
        region: await (0, import_util_middleware18.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultSigninHttpAuthSchemeParametersProvider");
    __name(createAwsAuthSigv4HttpAuthOption13, "createAwsAuthSigv4HttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption13, "createSmithyApiNoAuthHttpAuthOption");
    defaultSigninHttpAuthSchemeProvider4 = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "CreateOAuth2Token": {
          options.push(createSmithyApiNoAuthHttpAuthOption13(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption13(authParameters));
        }
      }
      return options;
    }, "defaultSigninHttpAuthSchemeProvider");
    resolveHttpAuthSchemeConfig13 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveAwsSdkSigV4Config5(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, import_util_middleware18.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/EndpointParameters.js
var resolveClientEndpointParameters13, commonParams13;
var init_EndpointParameters13 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters13 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "signin"
      });
    }, "resolveClientEndpointParameters");
    commonParams13 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/bdd.js
var import_util_endpoints37, m7, a13, b13, c13, d13, e13, f13, g13, h13, i13, j13, k13, l7, _data13, root13, r13, nodes13, bdd13;
var init_bdd13 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/bdd.js"() {
    import_util_endpoints37 = __toESM(require_dist_cjs20());
    m7 = "ref";
    a13 = -1;
    b13 = true;
    c13 = "isSet";
    d13 = "PartitionResult";
    e13 = "booleanEquals";
    f13 = "getAttr";
    g13 = "stringEquals";
    h13 = { [m7]: "Endpoint" };
    i13 = { [m7]: d13 };
    j13 = { fn: f13, argv: [i13, "name"] };
    k13 = {};
    l7 = [{ [m7]: "Region" }];
    _data13 = {
      conditions: [
        [c13, [h13]],
        [c13, l7],
        ["aws.partition", l7, d13],
        [e13, [{ [m7]: "UseFIPS" }, b13]],
        [e13, [{ [m7]: "UseDualStack" }, b13]],
        [e13, [{ fn: f13, argv: [i13, "supportsDualStack"] }, b13]],
        [e13, [{ fn: f13, argv: [i13, "supportsFIPS"] }, b13]],
        [g13, [j13, "aws"]],
        [g13, [j13, "aws-cn"]],
        [g13, [j13, "aws-us-gov"]]
      ],
      results: [
        [a13],
        [a13, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a13, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [h13, k13],
        ["https://{Region}.signin.aws.amazon.com", k13],
        ["https://{Region}.signin.amazonaws.cn", k13],
        ["https://{Region}.signin.amazonaws-us-gov.com", k13],
        ["https://signin-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", k13],
        [a13, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://signin-fips.{Region}.{PartitionResult#dnsSuffix}", k13],
        [a13, "FIPS is enabled but this partition does not support FIPS"],
        ["https://signin.{Region}.{PartitionResult#dualStackDnsSuffix}", k13],
        [a13, "DualStack is enabled but this partition does not support DualStack"],
        ["https://signin.{Region}.{PartitionResult#dnsSuffix}", k13],
        [a13, "Invalid Configuration: Missing Region"]
      ]
    };
    root13 = 2;
    r13 = 1e8;
    nodes13 = new Int32Array([
      -1,
      1,
      -1,
      0,
      15,
      3,
      1,
      4,
      r13 + 14,
      2,
      5,
      r13 + 14,
      3,
      11,
      6,
      4,
      10,
      7,
      7,
      r13 + 4,
      8,
      8,
      r13 + 5,
      9,
      9,
      r13 + 6,
      r13 + 13,
      5,
      r13 + 11,
      r13 + 12,
      4,
      13,
      12,
      6,
      r13 + 9,
      r13 + 10,
      5,
      14,
      r13 + 8,
      6,
      r13 + 7,
      r13 + 8,
      3,
      r13 + 1,
      16,
      4,
      r13 + 2,
      r13 + 3
    ]);
    bdd13 = import_util_endpoints37.BinaryDecisionDiagram.from(nodes13, root13, _data13.conditions, _data13.results);
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/endpointResolver.js
var import_util_endpoints38, import_util_endpoints39, cache13, defaultEndpointResolver13;
var init_endpointResolver13 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/endpointResolver.js"() {
    import_util_endpoints38 = __toESM(require_dist_cjs21());
    import_util_endpoints39 = __toESM(require_dist_cjs20());
    init_bdd13();
    cache13 = new import_util_endpoints39.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    defaultEndpointResolver13 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache13.get(endpointParams, () => (0, import_util_endpoints39.decideEndpoint)(bdd13, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    import_util_endpoints39.customEndpointFunctions.aws = import_util_endpoints38.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/SigninServiceException.js
var import_smithy_client122, SigninServiceException4;
var init_SigninServiceException4 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/SigninServiceException.js"() {
    import_smithy_client122 = __toESM(require_dist_cjs34());
    SigninServiceException4 = class _SigninServiceException extends import_smithy_client122.ServiceException {
      static {
        __name(this, "SigninServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _SigninServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/errors.js
var AccessDeniedException6, InternalServerException6, TooManyRequestsError4, ValidationException4;
var init_errors13 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/errors.js"() {
    init_SigninServiceException4();
    AccessDeniedException6 = class _AccessDeniedException extends SigninServiceException4 {
      static {
        __name(this, "AccessDeniedException");
      }
      name = "AccessDeniedException";
      $fault = "client";
      error;
      constructor(opts) {
        super({
          name: "AccessDeniedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AccessDeniedException.prototype);
        this.error = opts.error;
      }
    };
    InternalServerException6 = class _InternalServerException extends SigninServiceException4 {
      static {
        __name(this, "InternalServerException");
      }
      name = "InternalServerException";
      $fault = "server";
      error;
      constructor(opts) {
        super({
          name: "InternalServerException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _InternalServerException.prototype);
        this.error = opts.error;
      }
    };
    TooManyRequestsError4 = class _TooManyRequestsError extends SigninServiceException4 {
      static {
        __name(this, "TooManyRequestsError");
      }
      name = "TooManyRequestsError";
      $fault = "client";
      error;
      constructor(opts) {
        super({
          name: "TooManyRequestsError",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyRequestsError.prototype);
        this.error = opts.error;
      }
    };
    ValidationException4 = class _ValidationException extends SigninServiceException4 {
      static {
        __name(this, "ValidationException");
      }
      name = "ValidationException";
      $fault = "client";
      error;
      constructor(opts) {
        super({
          name: "ValidationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ValidationException.prototype);
        this.error = opts.error;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/schemas/schemas_0.js
var _ADE6, _AT6, _COAT4, _COATR4, _COATRB4, _COATRBr4, _COATRr4, _ISE6, _RT6, _TMRE8, _VE4, _aKI8, _aT10, _c13, _cI6, _cV6, _co6, _e13, _eI6, _gT6, _h10, _hE13, _iT6, _jN4, _m11, _rT6, _rU6, _s13, _sAK8, _sT8, _se6, _tI4, _tO4, _tT6, n013, _s_registry13, SigninServiceException$4, n0_registry13, AccessDeniedException$6, InternalServerException$6, TooManyRequestsError$4, ValidationException$4, errorTypeRegistries13, RefreshToken6, AccessToken$4, CreateOAuth2TokenRequest$4, CreateOAuth2TokenRequestBody$4, CreateOAuth2TokenResponse$4, CreateOAuth2TokenResponseBody$4, CreateOAuth2Token$4;
var init_schemas_013 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/schemas/schemas_0.js"() {
    init_schema4();
    init_errors13();
    init_SigninServiceException4();
    _ADE6 = "AccessDeniedException";
    _AT6 = "AccessToken";
    _COAT4 = "CreateOAuth2Token";
    _COATR4 = "CreateOAuth2TokenRequest";
    _COATRB4 = "CreateOAuth2TokenRequestBody";
    _COATRBr4 = "CreateOAuth2TokenResponseBody";
    _COATRr4 = "CreateOAuth2TokenResponse";
    _ISE6 = "InternalServerException";
    _RT6 = "RefreshToken";
    _TMRE8 = "TooManyRequestsError";
    _VE4 = "ValidationException";
    _aKI8 = "accessKeyId";
    _aT10 = "accessToken";
    _c13 = "client";
    _cI6 = "clientId";
    _cV6 = "codeVerifier";
    _co6 = "code";
    _e13 = "error";
    _eI6 = "expiresIn";
    _gT6 = "grantType";
    _h10 = "http";
    _hE13 = "httpError";
    _iT6 = "idToken";
    _jN4 = "jsonName";
    _m11 = "message";
    _rT6 = "refreshToken";
    _rU6 = "redirectUri";
    _s13 = "smithy.ts.sdk.synthetic.com.amazonaws.signin";
    _sAK8 = "secretAccessKey";
    _sT8 = "sessionToken";
    _se6 = "server";
    _tI4 = "tokenInput";
    _tO4 = "tokenOutput";
    _tT6 = "tokenType";
    n013 = "com.amazonaws.signin";
    _s_registry13 = TypeRegistry.for(_s13);
    SigninServiceException$4 = [-3, _s13, "SigninServiceException", 0, [], []];
    _s_registry13.registerError(SigninServiceException$4, SigninServiceException4);
    n0_registry13 = TypeRegistry.for(n013);
    AccessDeniedException$6 = [-3, n013, _ADE6, { [_e13]: _c13 }, [_e13, _m11], [0, 0], 2];
    n0_registry13.registerError(AccessDeniedException$6, AccessDeniedException6);
    InternalServerException$6 = [-3, n013, _ISE6, { [_e13]: _se6, [_hE13]: 500 }, [_e13, _m11], [0, 0], 2];
    n0_registry13.registerError(InternalServerException$6, InternalServerException6);
    TooManyRequestsError$4 = [-3, n013, _TMRE8, { [_e13]: _c13, [_hE13]: 429 }, [_e13, _m11], [0, 0], 2];
    n0_registry13.registerError(TooManyRequestsError$4, TooManyRequestsError4);
    ValidationException$4 = [-3, n013, _VE4, { [_e13]: _c13, [_hE13]: 400 }, [_e13, _m11], [0, 0], 2];
    n0_registry13.registerError(ValidationException$4, ValidationException4);
    errorTypeRegistries13 = [_s_registry13, n0_registry13];
    RefreshToken6 = [0, n013, _RT6, 8, 0];
    AccessToken$4 = [
      3,
      n013,
      _AT6,
      8,
      [_aKI8, _sAK8, _sT8],
      [
        [0, { [_jN4]: _aKI8 }],
        [0, { [_jN4]: _sAK8 }],
        [0, { [_jN4]: _sT8 }]
      ],
      3
    ];
    CreateOAuth2TokenRequest$4 = [
      3,
      n013,
      _COATR4,
      0,
      [_tI4],
      [[() => CreateOAuth2TokenRequestBody$4, 16]],
      1
    ];
    CreateOAuth2TokenRequestBody$4 = [
      3,
      n013,
      _COATRB4,
      0,
      [_cI6, _gT6, _co6, _rU6, _cV6, _rT6],
      [
        [0, { [_jN4]: _cI6 }],
        [0, { [_jN4]: _gT6 }],
        0,
        [0, { [_jN4]: _rU6 }],
        [0, { [_jN4]: _cV6 }],
        [() => RefreshToken6, { [_jN4]: _rT6 }]
      ],
      2
    ];
    CreateOAuth2TokenResponse$4 = [
      3,
      n013,
      _COATRr4,
      0,
      [_tO4],
      [[() => CreateOAuth2TokenResponseBody$4, 16]],
      1
    ];
    CreateOAuth2TokenResponseBody$4 = [
      3,
      n013,
      _COATRBr4,
      0,
      [_aT10, _tT6, _eI6, _rT6, _iT6],
      [
        [() => AccessToken$4, { [_jN4]: _aT10 }],
        [0, { [_jN4]: _tT6 }],
        [1, { [_jN4]: _eI6 }],
        [() => RefreshToken6, { [_jN4]: _rT6 }],
        [0, { [_jN4]: _iT6 }]
      ],
      4
    ];
    CreateOAuth2Token$4 = [
      9,
      n013,
      _COAT4,
      { [_h10]: ["POST", "/v1/token", 200] },
      () => CreateOAuth2TokenRequest$4,
      () => CreateOAuth2TokenResponse$4
    ];
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.shared.js
var import_smithy_client123, import_url_parser14, import_util_base6437, import_util_utf829, getRuntimeConfig25;
var init_runtimeConfig_shared13 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.shared.js"() {
    init_httpAuthSchemes6();
    init_protocols8();
    init_dist_es();
    import_smithy_client123 = __toESM(require_dist_cjs34());
    import_url_parser14 = __toESM(require_dist_cjs18());
    import_util_base6437 = __toESM(require_dist_cjs10());
    import_util_utf829 = __toESM(require_dist_cjs9());
    init_httpAuthSchemeProvider13();
    init_endpointResolver13();
    init_schemas_013();
    getRuntimeConfig25 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2023-01-01",
        base64Decoder: config2?.base64Decoder ?? import_util_base6437.fromBase64,
        base64Encoder: config2?.base64Encoder ?? import_util_base6437.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver13,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSigninHttpAuthSchemeProvider4,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer5()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        logger: config2?.logger ?? new import_smithy_client123.NoOpLogger(),
        protocol: config2?.protocol ?? AwsRestJsonProtocol6,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.signin",
          errorTypeRegistries: errorTypeRegistries13,
          version: "2023-01-01",
          serviceTarget: "Signin"
        },
        serviceId: config2?.serviceId ?? "Signin",
        urlParser: config2?.urlParser ?? import_url_parser14.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? import_util_utf829.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? import_util_utf829.toUtf8
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.js
var import_util_user_agent_node13, import_config_resolver25, import_hash_node13, import_middleware_retry25, import_node_config_provider13, import_node_http_handler13, import_smithy_client124, import_util_body_length_node13, import_util_defaults_mode_node13, import_util_retry20, getRuntimeConfig26;
var init_runtimeConfig13 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.js"() {
    init_package5();
    init_client8();
    init_httpAuthSchemes6();
    import_util_user_agent_node13 = __toESM(require_dist_cjs113());
    import_config_resolver25 = __toESM(require_dist_cjs25());
    import_hash_node13 = __toESM(require_dist_cjs44());
    import_middleware_retry25 = __toESM(require_dist_cjs106());
    import_node_config_provider13 = __toESM(require_dist_cjs29());
    import_node_http_handler13 = __toESM(require_dist_cjs13());
    import_smithy_client124 = __toESM(require_dist_cjs34());
    import_util_body_length_node13 = __toESM(require_dist_cjs45());
    import_util_defaults_mode_node13 = __toESM(require_dist_cjs46());
    import_util_retry20 = __toESM(require_dist_cjs22());
    init_runtimeConfig_shared13();
    getRuntimeConfig26 = /* @__PURE__ */ __name((config2) => {
      (0, import_smithy_client124.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, import_util_defaults_mode_node13.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(import_smithy_client124.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig25(config2);
      emitWarningIfUnsupportedVersion17(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, import_node_config_provider13.loadConfig)(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS5, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? import_util_body_length_node13.calculateBodyLength,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, import_util_user_agent_node13.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_default5.version }),
        maxAttempts: config2?.maxAttempts ?? (0, import_node_config_provider13.loadConfig)(import_middleware_retry25.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, import_node_config_provider13.loadConfig)(import_config_resolver25.NODE_REGION_CONFIG_OPTIONS, { ...import_config_resolver25.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: import_node_http_handler13.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, import_node_config_provider13.loadConfig)({
          ...import_middleware_retry25.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || import_util_retry20.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? import_hash_node13.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? import_node_http_handler13.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, import_node_config_provider13.loadConfig)(import_config_resolver25.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, import_node_config_provider13.loadConfig)(import_config_resolver25.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, import_node_config_provider13.loadConfig)(import_util_user_agent_node13.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration13, resolveHttpAuthRuntimeConfig13;
var init_httpAuthExtensionConfiguration13 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration13 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig13 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeExtensions.js
var import_region_config_resolver16, import_protocol_http36, import_smithy_client125, resolveRuntimeExtensions13;
var init_runtimeExtensions13 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeExtensions.js"() {
    import_region_config_resolver16 = __toESM(require_dist_cjs48());
    import_protocol_http36 = __toESM(require_dist_cjs2());
    import_smithy_client125 = __toESM(require_dist_cjs34());
    init_httpAuthExtensionConfiguration13();
    resolveRuntimeExtensions13 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign((0, import_region_config_resolver16.getAwsRegionExtensionConfiguration)(runtimeConfig), (0, import_smithy_client125.getDefaultExtensionConfiguration)(runtimeConfig), (0, import_protocol_http36.getHttpHandlerExtensionConfiguration)(runtimeConfig), getHttpAuthExtensionConfiguration13(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, (0, import_region_config_resolver16.resolveAwsRegionExtensionConfiguration)(extensionConfiguration), (0, import_smithy_client125.resolveDefaultRuntimeConfig)(extensionConfiguration), (0, import_protocol_http36.resolveHttpHandlerRuntimeConfig)(extensionConfiguration), resolveHttpAuthRuntimeConfig13(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/SigninClient.js
var import_middleware_host_header13, import_middleware_logger13, import_middleware_recursion_detection13, import_middleware_user_agent13, import_config_resolver26, import_middleware_content_length13, import_middleware_endpoint31, import_middleware_retry26, import_smithy_client126, SigninClient4;
var init_SigninClient4 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/SigninClient.js"() {
    import_middleware_host_header13 = __toESM(require_dist_cjs3());
    import_middleware_logger13 = __toESM(require_dist_cjs4());
    import_middleware_recursion_detection13 = __toESM(require_dist_cjs5());
    import_middleware_user_agent13 = __toESM(require_dist_cjs104());
    import_config_resolver26 = __toESM(require_dist_cjs25());
    init_dist_es();
    init_schema4();
    import_middleware_content_length13 = __toESM(require_dist_cjs26());
    import_middleware_endpoint31 = __toESM(require_dist_cjs31());
    import_middleware_retry26 = __toESM(require_dist_cjs106());
    import_smithy_client126 = __toESM(require_dist_cjs34());
    init_httpAuthSchemeProvider13();
    init_EndpointParameters13();
    init_runtimeConfig13();
    init_runtimeExtensions13();
    SigninClient4 = class extends import_smithy_client126.Client {
      static {
        __name(this, "SigninClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig26(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters13(_config_0);
        const _config_2 = (0, import_middleware_user_agent13.resolveUserAgentConfig)(_config_1);
        const _config_3 = (0, import_middleware_retry26.resolveRetryConfig)(_config_2);
        const _config_4 = (0, import_config_resolver26.resolveRegionConfig)(_config_3);
        const _config_5 = (0, import_middleware_host_header13.resolveHostHeaderConfig)(_config_4);
        const _config_6 = (0, import_middleware_endpoint31.resolveEndpointConfig)(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig13(_config_6);
        const _config_8 = resolveRuntimeExtensions13(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin(this.config));
        this.middlewareStack.use((0, import_middleware_user_agent13.getUserAgentPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_retry26.getRetryPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_content_length13.getContentLengthPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_host_header13.getHostHeaderPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_logger13.getLoggerPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_recursion_detection13.getRecursionDetectionPlugin)(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: defaultSigninHttpAuthSchemeParametersProvider4,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/CreateOAuth2TokenCommand.js
var import_middleware_endpoint32, import_smithy_client127, CreateOAuth2TokenCommand4;
var init_CreateOAuth2TokenCommand4 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/CreateOAuth2TokenCommand.js"() {
    import_middleware_endpoint32 = __toESM(require_dist_cjs31());
    import_smithy_client127 = __toESM(require_dist_cjs34());
    init_EndpointParameters13();
    init_schemas_013();
    CreateOAuth2TokenCommand4 = class extends import_smithy_client127.Command.classBuilder().ep(commonParams13).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint32.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("Signin", "CreateOAuth2Token", {}).n("SigninClient", "CreateOAuth2TokenCommand").sc(CreateOAuth2Token$4).build() {
      static {
        __name(this, "CreateOAuth2TokenCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/Signin.js
var import_smithy_client128, commands13, Signin4;
var init_Signin4 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/Signin.js"() {
    import_smithy_client128 = __toESM(require_dist_cjs34());
    init_CreateOAuth2TokenCommand4();
    init_SigninClient4();
    commands13 = {
      CreateOAuth2TokenCommand: CreateOAuth2TokenCommand4
    };
    Signin4 = class extends SigninClient4 {
      static {
        __name(this, "Signin");
      }
    };
    (0, import_smithy_client128.createAggregatedClient)(commands13, Signin4);
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/index.js
var init_commands14 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/index.js"() {
    init_CreateOAuth2TokenCommand4();
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/enums.js
var OAuth2ErrorCode4;
var init_enums6 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/enums.js"() {
    OAuth2ErrorCode4 = {
      AUTHCODE_EXPIRED: "AUTHCODE_EXPIRED",
      INSUFFICIENT_PERMISSIONS: "INSUFFICIENT_PERMISSIONS",
      INVALID_REQUEST: "INVALID_REQUEST",
      SERVER_ERROR: "server_error",
      TOKEN_EXPIRED: "TOKEN_EXPIRED",
      USER_CREDENTIALS_CHANGED: "USER_CREDENTIALS_CHANGED"
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/models_0.js
var init_models_013 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/index.js
var signin_exports4 = {};
__export(signin_exports4, {
  $Command: () => import_smithy_client127.Command,
  AccessDeniedException: () => AccessDeniedException6,
  AccessDeniedException$: () => AccessDeniedException$6,
  AccessToken$: () => AccessToken$4,
  CreateOAuth2Token$: () => CreateOAuth2Token$4,
  CreateOAuth2TokenCommand: () => CreateOAuth2TokenCommand4,
  CreateOAuth2TokenRequest$: () => CreateOAuth2TokenRequest$4,
  CreateOAuth2TokenRequestBody$: () => CreateOAuth2TokenRequestBody$4,
  CreateOAuth2TokenResponse$: () => CreateOAuth2TokenResponse$4,
  CreateOAuth2TokenResponseBody$: () => CreateOAuth2TokenResponseBody$4,
  InternalServerException: () => InternalServerException6,
  InternalServerException$: () => InternalServerException$6,
  OAuth2ErrorCode: () => OAuth2ErrorCode4,
  Signin: () => Signin4,
  SigninClient: () => SigninClient4,
  SigninServiceException: () => SigninServiceException4,
  SigninServiceException$: () => SigninServiceException$4,
  TooManyRequestsError: () => TooManyRequestsError4,
  TooManyRequestsError$: () => TooManyRequestsError$4,
  ValidationException: () => ValidationException4,
  ValidationException$: () => ValidationException$4,
  __Client: () => import_smithy_client126.Client,
  errorTypeRegistries: () => errorTypeRegistries13
});
var init_signin4 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/index.js"() {
    init_SigninClient4();
    init_Signin4();
    init_commands14();
    init_schemas_013();
    init_enums6();
    init_errors13();
    init_models_013();
    init_SigninServiceException4();
  }
});

// ../../node_modules/@aws-sdk/credential-provider-login/dist-cjs/index.js
var require_dist_cjs116 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-login/dist-cjs/index.js"(exports2) {
    "use strict";
    var client = (init_client8(), __toCommonJS(client_exports7));
    var propertyProvider = require_dist_cjs27();
    var sharedIniFileLoader = require_dist_cjs28();
    var protocolHttp = require_dist_cjs2();
    var node_crypto = require("node:crypto");
    var node_fs = require("node:fs");
    var node_os = require("node:os");
    var node_path = require("node:path");
    var LoginCredentialsFetcher = class _LoginCredentialsFetcher {
      static {
        __name(this, "LoginCredentialsFetcher");
      }
      profileData;
      init;
      callerClientConfig;
      static REFRESH_THRESHOLD = 5 * 60 * 1e3;
      constructor(profileData, init, callerClientConfig) {
        this.profileData = profileData;
        this.init = init;
        this.callerClientConfig = callerClientConfig;
      }
      async loadCredentials() {
        const token = await this.loadToken();
        if (!token) {
          throw new propertyProvider.CredentialsProviderError(`Failed to load a token for session ${this.loginSession}, please re-authenticate using aws login`, { tryNextLink: false, logger: this.logger });
        }
        const accessToken = token.accessToken;
        const now = Date.now();
        const expiryTime = new Date(accessToken.expiresAt).getTime();
        const timeUntilExpiry = expiryTime - now;
        if (timeUntilExpiry <= _LoginCredentialsFetcher.REFRESH_THRESHOLD) {
          return this.refresh(token);
        }
        return {
          accessKeyId: accessToken.accessKeyId,
          secretAccessKey: accessToken.secretAccessKey,
          sessionToken: accessToken.sessionToken,
          accountId: accessToken.accountId,
          expiration: new Date(accessToken.expiresAt)
        };
      }
      get logger() {
        return this.init?.logger;
      }
      get loginSession() {
        return this.profileData.login_session;
      }
      async refresh(token) {
        const { SigninClient: SigninClient10, CreateOAuth2TokenCommand: CreateOAuth2TokenCommand10 } = await Promise.resolve().then(() => (init_signin4(), signin_exports4));
        const { logger: logger5, userAgentAppId } = this.callerClientConfig ?? {};
        const isH210 = /* @__PURE__ */ __name((requestHandler2) => {
          return requestHandler2?.metadata?.handlerProtocol === "h2";
        }, "isH2");
        const requestHandler = isH210(this.callerClientConfig?.requestHandler) ? void 0 : this.callerClientConfig?.requestHandler;
        const region = this.profileData.region ?? await this.callerClientConfig?.region?.() ?? process.env.AWS_REGION;
        const client2 = new SigninClient10({
          credentials: {
            accessKeyId: "",
            secretAccessKey: ""
          },
          region,
          requestHandler,
          logger: logger5,
          userAgentAppId,
          ...this.init?.clientConfig
        });
        this.createDPoPInterceptor(client2.middlewareStack);
        const commandInput = {
          tokenInput: {
            clientId: token.clientId,
            refreshToken: token.refreshToken,
            grantType: "refresh_token"
          }
        };
        try {
          const response = await client2.send(new CreateOAuth2TokenCommand10(commandInput));
          const { accessKeyId, secretAccessKey, sessionToken } = response.tokenOutput?.accessToken ?? {};
          const { refreshToken, expiresIn } = response.tokenOutput ?? {};
          if (!accessKeyId || !secretAccessKey || !sessionToken || !refreshToken) {
            throw new propertyProvider.CredentialsProviderError("Token refresh response missing required fields", {
              logger: this.logger,
              tryNextLink: false
            });
          }
          const expiresInMs = (expiresIn ?? 900) * 1e3;
          const expiration = new Date(Date.now() + expiresInMs);
          const updatedToken = {
            ...token,
            accessToken: {
              ...token.accessToken,
              accessKeyId,
              secretAccessKey,
              sessionToken,
              expiresAt: expiration.toISOString()
            },
            refreshToken
          };
          await this.saveToken(updatedToken);
          const newAccessToken = updatedToken.accessToken;
          return {
            accessKeyId: newAccessToken.accessKeyId,
            secretAccessKey: newAccessToken.secretAccessKey,
            sessionToken: newAccessToken.sessionToken,
            accountId: newAccessToken.accountId,
            expiration
          };
        } catch (error4) {
          if (error4.name === "AccessDeniedException") {
            const errorType = error4.error;
            let message2;
            switch (errorType) {
              case "TOKEN_EXPIRED":
                message2 = "Your session has expired. Please reauthenticate.";
                break;
              case "USER_CREDENTIALS_CHANGED":
                message2 = "Unable to refresh credentials because of a change in your password. Please reauthenticate with your new password.";
                break;
              case "INSUFFICIENT_PERMISSIONS":
                message2 = "Unable to refresh credentials due to insufficient permissions. You may be missing permission for the 'CreateOAuth2Token' action.";
                break;
              default:
                message2 = `Failed to refresh token: ${String(error4)}. Please re-authenticate using \`aws login\``;
            }
            throw new propertyProvider.CredentialsProviderError(message2, { logger: this.logger, tryNextLink: false });
          }
          throw new propertyProvider.CredentialsProviderError(`Failed to refresh token: ${String(error4)}. Please re-authenticate using aws login`, { logger: this.logger });
        }
      }
      async loadToken() {
        const tokenFilePath = this.getTokenFilePath();
        try {
          let tokenData;
          try {
            tokenData = await sharedIniFileLoader.readFile(tokenFilePath, { ignoreCache: this.init?.ignoreCache });
          } catch {
            tokenData = await node_fs.promises.readFile(tokenFilePath, "utf8");
          }
          const token = JSON.parse(tokenData);
          const missingFields = ["accessToken", "clientId", "refreshToken", "dpopKey"].filter((k32) => !token[k32]);
          if (!token.accessToken?.accountId) {
            missingFields.push("accountId");
          }
          if (missingFields.length > 0) {
            throw new propertyProvider.CredentialsProviderError(`Token validation failed, missing fields: ${missingFields.join(", ")}`, {
              logger: this.logger,
              tryNextLink: false
            });
          }
          return token;
        } catch (error4) {
          throw new propertyProvider.CredentialsProviderError(`Failed to load token from ${tokenFilePath}: ${String(error4)}`, {
            logger: this.logger,
            tryNextLink: false
          });
        }
      }
      async saveToken(token) {
        const tokenFilePath = this.getTokenFilePath();
        const directory = node_path.dirname(tokenFilePath);
        try {
          await node_fs.promises.mkdir(directory, { recursive: true });
        } catch (error4) {
        }
        await node_fs.promises.writeFile(tokenFilePath, JSON.stringify(token, null, 2), "utf8");
      }
      getTokenFilePath() {
        const directory = process.env.AWS_LOGIN_CACHE_DIRECTORY ?? node_path.join(node_os.homedir(), ".aws", "login", "cache");
        const loginSessionBytes = Buffer.from(this.loginSession, "utf8");
        const loginSessionSha256 = node_crypto.createHash("sha256").update(loginSessionBytes).digest("hex");
        return node_path.join(directory, `${loginSessionSha256}.json`);
      }
      derToRawSignature(derSignature) {
        let offset = 2;
        if (derSignature[offset] !== 2) {
          throw new Error("Invalid DER signature");
        }
        offset++;
        const rLength = derSignature[offset++];
        let r32 = derSignature.subarray(offset, offset + rLength);
        offset += rLength;
        if (derSignature[offset] !== 2) {
          throw new Error("Invalid DER signature");
        }
        offset++;
        const sLength = derSignature[offset++];
        let s = derSignature.subarray(offset, offset + sLength);
        r32 = r32[0] === 0 ? r32.subarray(1) : r32;
        s = s[0] === 0 ? s.subarray(1) : s;
        const rPadded = Buffer.concat([Buffer.alloc(32 - r32.length), r32]);
        const sPadded = Buffer.concat([Buffer.alloc(32 - s.length), s]);
        return Buffer.concat([rPadded, sPadded]);
      }
      createDPoPInterceptor(middlewareStack) {
        middlewareStack.add((next) => async (args) => {
          if (protocolHttp.HttpRequest.isInstance(args.request)) {
            const request4 = args.request;
            const actualEndpoint = `${request4.protocol}//${request4.hostname}${request4.port ? `:${request4.port}` : ""}${request4.path}`;
            const dpop = await this.generateDpop(request4.method, actualEndpoint);
            request4.headers = {
              ...request4.headers,
              DPoP: dpop
            };
          }
          return next(args);
        }, {
          step: "finalizeRequest",
          name: "dpopInterceptor",
          override: true
        });
      }
      async generateDpop(method = "POST", endpoint) {
        const token = await this.loadToken();
        try {
          const privateKey = node_crypto.createPrivateKey({
            key: token.dpopKey,
            format: "pem",
            type: "sec1"
          });
          const publicKey = node_crypto.createPublicKey(privateKey);
          const publicDer = publicKey.export({ format: "der", type: "spki" });
          let pointStart = -1;
          for (let i32 = 0; i32 < publicDer.length; i32++) {
            if (publicDer[i32] === 4) {
              pointStart = i32;
              break;
            }
          }
          const x = publicDer.slice(pointStart + 1, pointStart + 33);
          const y = publicDer.slice(pointStart + 33, pointStart + 65);
          const header = {
            alg: "ES256",
            typ: "dpop+jwt",
            jwk: {
              kty: "EC",
              crv: "P-256",
              x: x.toString("base64url"),
              y: y.toString("base64url")
            }
          };
          const payload3 = {
            jti: crypto.randomUUID(),
            htm: method,
            htu: endpoint,
            iat: Math.floor(Date.now() / 1e3)
          };
          const headerB64 = Buffer.from(JSON.stringify(header)).toString("base64url");
          const payloadB64 = Buffer.from(JSON.stringify(payload3)).toString("base64url");
          const message2 = `${headerB64}.${payloadB64}`;
          const asn1Signature = node_crypto.sign("sha256", Buffer.from(message2), privateKey);
          const rawSignature = this.derToRawSignature(asn1Signature);
          const signatureB64 = rawSignature.toString("base64url");
          return `${message2}.${signatureB64}`;
        } catch (error4) {
          throw new propertyProvider.CredentialsProviderError(`Failed to generate Dpop proof: ${error4 instanceof Error ? error4.message : String(error4)}`, { logger: this.logger, tryNextLink: false });
        }
      }
    };
    var fromLoginCredentials = /* @__PURE__ */ __name((init) => async ({ callerClientConfig } = {}) => {
      init?.logger?.debug?.("@aws-sdk/credential-providers - fromLoginCredentials");
      const profiles = await sharedIniFileLoader.parseKnownFiles(init || {});
      const profileName = sharedIniFileLoader.getProfileName({
        profile: init?.profile ?? callerClientConfig?.profile
      });
      const profile = profiles[profileName];
      if (!profile?.login_session) {
        throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} does not contain login_session.`, {
          tryNextLink: true,
          logger: init?.logger
        });
      }
      const fetcher = new LoginCredentialsFetcher(profile, init, callerClientConfig);
      const credentials = await fetcher.loadCredentials();
      return client.setCredentialFeature(credentials, "CREDENTIALS_LOGIN", "AD");
    }, "fromLoginCredentials");
    exports2.fromLoginCredentials = fromLoginCredentials;
  }
});

// ../../node_modules/@aws-sdk/nested-clients/node_modules/@aws-sdk/middleware-sdk-s3/dist-cjs/toStream.js
var require_toStream3 = __commonJS({
  "../../node_modules/@aws-sdk/nested-clients/node_modules/@aws-sdk/middleware-sdk-s3/dist-cjs/toStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.toStream = toStream;
    var node_stream_1 = require("node:stream");
    function toStream(bytes) {
      return node_stream_1.Readable.from(Buffer.from(bytes));
    }
    __name(toStream, "toStream");
  }
});

// ../../node_modules/@aws-sdk/nested-clients/node_modules/@aws-sdk/middleware-sdk-s3/dist-cjs/index.js
var require_dist_cjs117 = __commonJS({
  "../../node_modules/@aws-sdk/nested-clients/node_modules/@aws-sdk/middleware-sdk-s3/dist-cjs/index.js"(exports2) {
    "use strict";
    var protocolHttp = require_dist_cjs2();
    var smithyClient = require_dist_cjs34();
    var toStream = require_toStream3();
    var utilArnParser = require_dist_cjs53();
    var protocols = (init_protocols8(), __toCommonJS(protocols_exports5));
    var schema = (init_schema4(), __toCommonJS(schema_exports));
    var signatureV4 = require_dist_cjs36();
    var utilConfigProvider = require_dist_cjs24();
    var client = (init_client8(), __toCommonJS(client_exports7));
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var utilMiddleware = require_dist_cjs6();
    var CONTENT_LENGTH_HEADER6 = "content-length";
    var DECODED_CONTENT_LENGTH_HEADER = "x-amz-decoded-content-length";
    function checkContentLengthHeader() {
      return (next, context) => async (args) => {
        const { request: request4 } = args;
        if (protocolHttp.HttpRequest.isInstance(request4)) {
          if (!(CONTENT_LENGTH_HEADER6 in request4.headers) && !(DECODED_CONTENT_LENGTH_HEADER in request4.headers)) {
            const message2 = `Are you using a Stream of unknown length as the Body of a PutObject request? Consider using Upload instead from @aws-sdk/lib-storage.`;
            if (typeof context?.logger?.warn === "function" && !(context.logger instanceof smithyClient.NoOpLogger)) {
              context.logger.warn(message2);
            } else {
              console.warn(message2);
            }
          }
        }
        return next({ ...args });
      };
    }
    __name(checkContentLengthHeader, "checkContentLengthHeader");
    var checkContentLengthHeaderMiddlewareOptions = {
      step: "finalizeRequest",
      tags: ["CHECK_CONTENT_LENGTH_HEADER"],
      name: "getCheckContentLengthHeaderPlugin",
      override: true
    };
    var getCheckContentLengthHeaderPlugin = /* @__PURE__ */ __name((unused) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(checkContentLengthHeader(), checkContentLengthHeaderMiddlewareOptions);
      }, "applyToStack")
    }), "getCheckContentLengthHeaderPlugin");
    var regionRedirectEndpointMiddleware = /* @__PURE__ */ __name((config2) => {
      return (next, context) => async (args) => {
        const originalRegion = await config2.region();
        const regionProviderRef = config2.region;
        let unlock = /* @__PURE__ */ __name(() => {
        }, "unlock");
        if (context.__s3RegionRedirect) {
          Object.defineProperty(config2, "region", {
            writable: false,
            value: /* @__PURE__ */ __name(async () => {
              return context.__s3RegionRedirect;
            }, "value")
          });
          unlock = /* @__PURE__ */ __name(() => Object.defineProperty(config2, "region", {
            writable: true,
            value: regionProviderRef
          }), "unlock");
        }
        try {
          const result2 = await next(args);
          if (context.__s3RegionRedirect) {
            unlock();
            const region = await config2.region();
            if (originalRegion !== region) {
              throw new Error("Region was not restored following S3 region redirect.");
            }
          }
          return result2;
        } catch (e32) {
          unlock();
          throw e32;
        }
      };
    }, "regionRedirectEndpointMiddleware");
    var regionRedirectEndpointMiddlewareOptions = {
      tags: ["REGION_REDIRECT", "S3"],
      name: "regionRedirectEndpointMiddleware",
      override: true,
      relation: "before",
      toMiddleware: "endpointV2Middleware"
    };
    function regionRedirectMiddleware(clientConfig) {
      return (next, context) => async (args) => {
        try {
          return await next(args);
        } catch (err) {
          if (clientConfig.followRegionRedirects) {
            const statusCode = err?.$metadata?.httpStatusCode;
            const isHeadBucket = context.commandName === "HeadBucketCommand";
            const bucketRegionHeader = err?.$response?.headers?.["x-amz-bucket-region"];
            if (bucketRegionHeader) {
              if (statusCode === 301 || statusCode === 400 && (err?.name === "IllegalLocationConstraintException" || isHeadBucket)) {
                try {
                  const actualRegion = bucketRegionHeader;
                  context.logger?.debug(`Redirecting from ${await clientConfig.region()} to ${actualRegion}`);
                  context.__s3RegionRedirect = actualRegion;
                } catch (e32) {
                  throw new Error("Region redirect failed: " + e32);
                }
                return next(args);
              }
            }
          }
          throw err;
        }
      };
    }
    __name(regionRedirectMiddleware, "regionRedirectMiddleware");
    var regionRedirectMiddlewareOptions = {
      step: "initialize",
      tags: ["REGION_REDIRECT", "S3"],
      name: "regionRedirectMiddleware",
      override: true
    };
    var getRegionRedirectMiddlewarePlugin = /* @__PURE__ */ __name((clientConfig) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(regionRedirectMiddleware(clientConfig), regionRedirectMiddlewareOptions);
        clientStack.addRelativeTo(regionRedirectEndpointMiddleware(clientConfig), regionRedirectEndpointMiddlewareOptions);
      }, "applyToStack")
    }), "getRegionRedirectMiddlewarePlugin");
    var s3ExpiresMiddleware = /* @__PURE__ */ __name((config2) => {
      return (next, context) => async (args) => {
        const result2 = await next(args);
        const { response } = result2;
        if (protocolHttp.HttpResponse.isInstance(response)) {
          if (response.headers.expires) {
            response.headers.expiresstring = response.headers.expires;
            try {
              smithyClient.parseRfc7231DateTime(response.headers.expires);
            } catch (e32) {
              context.logger?.warn(`AWS SDK Warning for ${context.clientName}::${context.commandName} response parsing (${response.headers.expires}): ${e32}`);
              delete response.headers.expires;
            }
          }
        }
        return result2;
      };
    }, "s3ExpiresMiddleware");
    var s3ExpiresMiddlewareOptions = {
      tags: ["S3"],
      name: "s3ExpiresMiddleware",
      override: true,
      relation: "after",
      toMiddleware: "deserializerMiddleware"
    };
    var getS3ExpiresMiddlewarePlugin = /* @__PURE__ */ __name((clientConfig) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.addRelativeTo(s3ExpiresMiddleware(), s3ExpiresMiddlewareOptions);
      }, "applyToStack")
    }), "getS3ExpiresMiddlewarePlugin");
    var S3ExpressIdentityCache = class _S3ExpressIdentityCache {
      static {
        __name(this, "S3ExpressIdentityCache");
      }
      data;
      lastPurgeTime = Date.now();
      static EXPIRED_CREDENTIAL_PURGE_INTERVAL_MS = 3e4;
      constructor(data3 = {}) {
        this.data = data3;
      }
      get(key) {
        const entry = this.data[key];
        if (!entry) {
          return;
        }
        return entry;
      }
      set(key, entry) {
        this.data[key] = entry;
        return entry;
      }
      delete(key) {
        delete this.data[key];
      }
      async purgeExpired() {
        const now = Date.now();
        if (this.lastPurgeTime + _S3ExpressIdentityCache.EXPIRED_CREDENTIAL_PURGE_INTERVAL_MS > now) {
          return;
        }
        for (const key in this.data) {
          const entry = this.data[key];
          if (!entry.isRefreshing) {
            const credential = await entry.identity;
            if (credential.expiration) {
              if (credential.expiration.getTime() < now) {
                delete this.data[key];
              }
            }
          }
        }
      }
    };
    var S3ExpressIdentityCacheEntry = class {
      static {
        __name(this, "S3ExpressIdentityCacheEntry");
      }
      _identity;
      isRefreshing;
      accessed;
      constructor(_identity, isRefreshing = false, accessed = Date.now()) {
        this._identity = _identity;
        this.isRefreshing = isRefreshing;
        this.accessed = accessed;
      }
      get identity() {
        this.accessed = Date.now();
        return this._identity;
      }
    };
    var S3ExpressIdentityProviderImpl = class _S3ExpressIdentityProviderImpl {
      static {
        __name(this, "S3ExpressIdentityProviderImpl");
      }
      createSessionFn;
      cache;
      static REFRESH_WINDOW_MS = 6e4;
      constructor(createSessionFn, cache32 = new S3ExpressIdentityCache()) {
        this.createSessionFn = createSessionFn;
        this.cache = cache32;
      }
      async getS3ExpressIdentity(awsIdentity, identityProperties) {
        const key = identityProperties.Bucket;
        const { cache: cache32 } = this;
        const entry = cache32.get(key);
        if (entry) {
          return entry.identity.then((identity) => {
            const isExpired = (identity.expiration?.getTime() ?? 0) < Date.now();
            if (isExpired) {
              return cache32.set(key, new S3ExpressIdentityCacheEntry(this.getIdentity(key))).identity;
            }
            const isExpiringSoon = (identity.expiration?.getTime() ?? 0) < Date.now() + _S3ExpressIdentityProviderImpl.REFRESH_WINDOW_MS;
            if (isExpiringSoon && !entry.isRefreshing) {
              entry.isRefreshing = true;
              this.getIdentity(key).then((id) => {
                cache32.set(key, new S3ExpressIdentityCacheEntry(Promise.resolve(id)));
              });
            }
            return identity;
          });
        }
        return cache32.set(key, new S3ExpressIdentityCacheEntry(this.getIdentity(key))).identity;
      }
      async getIdentity(key) {
        await this.cache.purgeExpired().catch((error4) => {
          console.warn("Error while clearing expired entries in S3ExpressIdentityCache: \n" + error4);
        });
        const session = await this.createSessionFn(key);
        if (!session.Credentials?.AccessKeyId || !session.Credentials?.SecretAccessKey) {
          throw new Error("s3#createSession response credential missing AccessKeyId or SecretAccessKey.");
        }
        const identity = {
          accessKeyId: session.Credentials.AccessKeyId,
          secretAccessKey: session.Credentials.SecretAccessKey,
          sessionToken: session.Credentials.SessionToken,
          expiration: session.Credentials.Expiration ? new Date(session.Credentials.Expiration) : void 0
        };
        return identity;
      }
    };
    var S3_EXPRESS_BUCKET_TYPE = "Directory";
    var S3_EXPRESS_BACKEND = "S3Express";
    var S3_EXPRESS_AUTH_SCHEME = "sigv4-s3express";
    var SESSION_TOKEN_QUERY_PARAM = "X-Amz-S3session-Token";
    var SESSION_TOKEN_HEADER = SESSION_TOKEN_QUERY_PARAM.toLowerCase();
    var NODE_DISABLE_S3_EXPRESS_SESSION_AUTH_ENV_NAME = "AWS_S3_DISABLE_EXPRESS_SESSION_AUTH";
    var NODE_DISABLE_S3_EXPRESS_SESSION_AUTH_INI_NAME = "s3_disable_express_session_auth";
    var NODE_DISABLE_S3_EXPRESS_SESSION_AUTH_OPTIONS = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => utilConfigProvider.booleanSelector(env3, NODE_DISABLE_S3_EXPRESS_SESSION_AUTH_ENV_NAME, utilConfigProvider.SelectorType.ENV), "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => utilConfigProvider.booleanSelector(profile, NODE_DISABLE_S3_EXPRESS_SESSION_AUTH_INI_NAME, utilConfigProvider.SelectorType.CONFIG), "configFileSelector"),
      default: false
    };
    var SignatureV4S3Express = class extends signatureV4.SignatureV4 {
      static {
        __name(this, "SignatureV4S3Express");
      }
      async signWithCredentials(requestToSign, credentials, options) {
        const credentialsWithoutSessionToken = getCredentialsWithoutSessionToken(credentials);
        requestToSign.headers[SESSION_TOKEN_HEADER] = credentials.sessionToken;
        const privateAccess = this;
        setSingleOverride(privateAccess, credentialsWithoutSessionToken);
        return privateAccess.signRequest(requestToSign, options ?? {});
      }
      async presignWithCredentials(requestToSign, credentials, options) {
        const credentialsWithoutSessionToken = getCredentialsWithoutSessionToken(credentials);
        delete requestToSign.headers[SESSION_TOKEN_HEADER];
        requestToSign.headers[SESSION_TOKEN_QUERY_PARAM] = credentials.sessionToken;
        requestToSign.query = requestToSign.query ?? {};
        requestToSign.query[SESSION_TOKEN_QUERY_PARAM] = credentials.sessionToken;
        const privateAccess = this;
        setSingleOverride(privateAccess, credentialsWithoutSessionToken);
        return this.presign(requestToSign, options);
      }
    };
    function getCredentialsWithoutSessionToken(credentials) {
      const credentialsWithoutSessionToken = {
        accessKeyId: credentials.accessKeyId,
        secretAccessKey: credentials.secretAccessKey,
        expiration: credentials.expiration
      };
      return credentialsWithoutSessionToken;
    }
    __name(getCredentialsWithoutSessionToken, "getCredentialsWithoutSessionToken");
    function setSingleOverride(privateAccess, credentialsWithoutSessionToken) {
      const id = setTimeout(() => {
        throw new Error("SignatureV4S3Express credential override was created but not called.");
      }, 10);
      const currentCredentialProvider = privateAccess.credentialProvider;
      const overrideCredentialsProviderOnce = /* @__PURE__ */ __name(() => {
        clearTimeout(id);
        privateAccess.credentialProvider = currentCredentialProvider;
        return Promise.resolve(credentialsWithoutSessionToken);
      }, "overrideCredentialsProviderOnce");
      privateAccess.credentialProvider = overrideCredentialsProviderOnce;
    }
    __name(setSingleOverride, "setSingleOverride");
    var s3ExpressMiddleware = /* @__PURE__ */ __name((options) => {
      return (next, context) => async (args) => {
        if (context.endpointV2) {
          const endpoint = context.endpointV2;
          const isS3ExpressAuth = endpoint.properties?.authSchemes?.[0]?.name === S3_EXPRESS_AUTH_SCHEME;
          const isS3ExpressBucket = endpoint.properties?.backend === S3_EXPRESS_BACKEND || endpoint.properties?.bucketType === S3_EXPRESS_BUCKET_TYPE;
          if (isS3ExpressBucket) {
            client.setFeature(context, "S3_EXPRESS_BUCKET", "J");
            context.isS3ExpressBucket = true;
          }
          if (isS3ExpressAuth) {
            const requestBucket = args.input.Bucket;
            if (requestBucket) {
              const s3ExpressIdentity = await options.s3ExpressIdentityProvider.getS3ExpressIdentity(await options.credentials(), {
                Bucket: requestBucket
              });
              context.s3ExpressIdentity = s3ExpressIdentity;
              if (protocolHttp.HttpRequest.isInstance(args.request) && s3ExpressIdentity.sessionToken) {
                args.request.headers[SESSION_TOKEN_HEADER] = s3ExpressIdentity.sessionToken;
              }
            }
          }
        }
        return next(args);
      };
    }, "s3ExpressMiddleware");
    var s3ExpressMiddlewareOptions = {
      name: "s3ExpressMiddleware",
      step: "build",
      tags: ["S3", "S3_EXPRESS"],
      override: true
    };
    var getS3ExpressPlugin = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(s3ExpressMiddleware(options), s3ExpressMiddlewareOptions);
      }, "applyToStack")
    }), "getS3ExpressPlugin");
    var signS3Express = /* @__PURE__ */ __name(async (s3ExpressIdentity, signingOptions, request4, sigV4MultiRegionSigner) => {
      const signedRequest = await sigV4MultiRegionSigner.signWithCredentials(request4, s3ExpressIdentity, {});
      if (signedRequest.headers["X-Amz-Security-Token"] || signedRequest.headers["x-amz-security-token"]) {
        throw new Error("X-Amz-Security-Token must not be set for s3-express requests.");
      }
      return signedRequest;
    }, "signS3Express");
    var defaultErrorHandler3 = /* @__PURE__ */ __name((signingProperties) => (error4) => {
      throw error4;
    }, "defaultErrorHandler");
    var defaultSuccessHandler3 = /* @__PURE__ */ __name((httpResponse, signingProperties) => {
    }, "defaultSuccessHandler");
    var s3ExpressHttpSigningMiddlewareOptions = core.httpSigningMiddlewareOptions;
    var s3ExpressHttpSigningMiddleware = /* @__PURE__ */ __name((config2) => (next, context) => async (args) => {
      if (!protocolHttp.HttpRequest.isInstance(args.request)) {
        return next(args);
      }
      const smithyContext = utilMiddleware.getSmithyContext(context);
      const scheme = smithyContext.selectedHttpAuthScheme;
      if (!scheme) {
        throw new Error(`No HttpAuthScheme was selected: unable to sign request`);
      }
      const { httpAuthOption: { signingProperties = {} }, identity, signer } = scheme;
      let request4;
      if (context.s3ExpressIdentity) {
        request4 = await signS3Express(context.s3ExpressIdentity, signingProperties, args.request, await config2.signer());
      } else {
        request4 = await signer.sign(args.request, identity, signingProperties);
      }
      const output = await next({
        ...args,
        request: request4
      }).catch((signer.errorHandler || defaultErrorHandler3)(signingProperties));
      (signer.successHandler || defaultSuccessHandler3)(output.response, signingProperties);
      return output;
    }, "s3ExpressHttpSigningMiddleware");
    var getS3ExpressHttpSigningPlugin = /* @__PURE__ */ __name((config2) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.addRelativeTo(s3ExpressHttpSigningMiddleware(config2), core.httpSigningMiddlewareOptions);
      }, "applyToStack")
    }), "getS3ExpressHttpSigningPlugin");
    var resolveS3Config = /* @__PURE__ */ __name((input, { session }) => {
      const [s3ClientProvider, CreateSessionCommandCtor] = session;
      const { forcePathStyle, useAccelerateEndpoint, disableMultiregionAccessPoints, followRegionRedirects, s3ExpressIdentityProvider, bucketEndpoint, expectContinueHeader } = input;
      return Object.assign(input, {
        forcePathStyle: forcePathStyle ?? false,
        useAccelerateEndpoint: useAccelerateEndpoint ?? false,
        disableMultiregionAccessPoints: disableMultiregionAccessPoints ?? false,
        followRegionRedirects: followRegionRedirects ?? false,
        s3ExpressIdentityProvider: s3ExpressIdentityProvider ?? new S3ExpressIdentityProviderImpl(async (key) => s3ClientProvider().send(new CreateSessionCommandCtor({
          Bucket: key
        }))),
        bucketEndpoint: bucketEndpoint ?? false,
        expectContinueHeader: expectContinueHeader ?? 2097152
      });
    }, "resolveS3Config");
    var THROW_IF_EMPTY_BODY = {
      CopyObjectCommand: true,
      UploadPartCopyCommand: true,
      CompleteMultipartUploadCommand: true
    };
    var throw200ExceptionsMiddleware = /* @__PURE__ */ __name((config2) => (next, context) => async (args) => {
      const result2 = await next(args);
      const { response } = result2;
      if (!protocolHttp.HttpResponse.isInstance(response)) {
        return result2;
      }
      const { statusCode, body } = response;
      if (statusCode < 200 || statusCode >= 300) {
        return result2;
      }
      const bodyBytes = await collectBody17(body, config2);
      response.body = toStream.toStream(bodyBytes);
      if (bodyBytes.length === 0 && THROW_IF_EMPTY_BODY[context.commandName]) {
        const err = new Error("S3 aborted request");
        err.$metadata = {
          httpStatusCode: 503
        };
        err.name = "InternalError";
        throw err;
      }
      const bodyStringTail = config2.utf8Encoder(bodyBytes.subarray(bodyBytes.length - 16));
      if (bodyStringTail && bodyStringTail.endsWith("</Error>")) {
        response.statusCode = 503;
      }
      return result2;
    }, "throw200ExceptionsMiddleware");
    var collectBody17 = /* @__PURE__ */ __name((streamBody = new Uint8Array(), context) => {
      if (streamBody instanceof Uint8Array) {
        return Promise.resolve(streamBody);
      }
      return context.streamCollector(streamBody) || Promise.resolve(new Uint8Array());
    }, "collectBody");
    var throw200ExceptionsMiddlewareOptions = {
      relation: "after",
      toMiddleware: "deserializerMiddleware",
      tags: ["THROW_200_EXCEPTIONS", "S3"],
      name: "throw200ExceptionsMiddleware",
      override: true
    };
    var getThrow200ExceptionsPlugin = /* @__PURE__ */ __name((config2) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.addRelativeTo(throw200ExceptionsMiddleware(config2), throw200ExceptionsMiddlewareOptions);
      }, "applyToStack")
    }), "getThrow200ExceptionsPlugin");
    function bucketEndpointMiddleware(options) {
      return (next, context) => async (args) => {
        if (options.bucketEndpoint) {
          const endpoint = context.endpointV2;
          if (endpoint) {
            const bucket = args.input.Bucket;
            if (typeof bucket === "string") {
              try {
                const bucketEndpointUrl = new URL(bucket);
                context.endpointV2 = {
                  ...endpoint,
                  url: bucketEndpointUrl
                };
              } catch (e32) {
                const warning2 = `@aws-sdk/middleware-sdk-s3: bucketEndpoint=true was set but Bucket=${bucket} could not be parsed as URL.`;
                if (context.logger?.constructor?.name === "NoOpLogger") {
                  console.warn(warning2);
                } else {
                  context.logger?.warn?.(warning2);
                }
                throw e32;
              }
            }
          }
        }
        return next(args);
      };
    }
    __name(bucketEndpointMiddleware, "bucketEndpointMiddleware");
    var bucketEndpointMiddlewareOptions = {
      name: "bucketEndpointMiddleware",
      override: true,
      relation: "after",
      toMiddleware: "endpointV2Middleware"
    };
    function validateBucketNameMiddleware({ bucketEndpoint }) {
      return (next) => async (args) => {
        const { input: { Bucket } } = args;
        if (!bucketEndpoint && typeof Bucket === "string" && !utilArnParser.validate(Bucket) && Bucket.indexOf("/") >= 0) {
          const err = new Error(`Bucket name shouldn't contain '/', received '${Bucket}'`);
          err.name = "InvalidBucketName";
          throw err;
        }
        return next({ ...args });
      };
    }
    __name(validateBucketNameMiddleware, "validateBucketNameMiddleware");
    var validateBucketNameMiddlewareOptions = {
      step: "initialize",
      tags: ["VALIDATE_BUCKET_NAME"],
      name: "validateBucketNameMiddleware",
      override: true
    };
    var getValidateBucketNamePlugin = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(validateBucketNameMiddleware(options), validateBucketNameMiddlewareOptions);
        clientStack.addRelativeTo(bucketEndpointMiddleware(options), bucketEndpointMiddlewareOptions);
      }, "applyToStack")
    }), "getValidateBucketNamePlugin");
    var S3RestXmlProtocol = class extends protocols.AwsRestXmlProtocol {
      static {
        __name(this, "S3RestXmlProtocol");
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        const ns = schema.NormalizedSchema.of(operationSchema.input);
        const staticStructureSchema = ns.getSchema();
        let bucketMemberIndex = 0;
        const requiredMemberCount = staticStructureSchema[6] ?? 0;
        if (input && typeof input === "object") {
          for (const [memberName, memberNs] of ns.structIterator()) {
            if (++bucketMemberIndex > requiredMemberCount) {
              break;
            }
            if (memberName === "Bucket") {
              if (!input.Bucket && memberNs.getMergedTraits().httpLabel) {
                throw new Error(`No value provided for input HTTP label: Bucket.`);
              }
              break;
            }
          }
        }
        return request4;
      }
    };
    exports2.NODE_DISABLE_S3_EXPRESS_SESSION_AUTH_OPTIONS = NODE_DISABLE_S3_EXPRESS_SESSION_AUTH_OPTIONS;
    exports2.S3ExpressIdentityCache = S3ExpressIdentityCache;
    exports2.S3ExpressIdentityCacheEntry = S3ExpressIdentityCacheEntry;
    exports2.S3ExpressIdentityProviderImpl = S3ExpressIdentityProviderImpl;
    exports2.S3RestXmlProtocol = S3RestXmlProtocol;
    exports2.SignatureV4S3Express = SignatureV4S3Express;
    exports2.checkContentLengthHeader = checkContentLengthHeader;
    exports2.checkContentLengthHeaderMiddlewareOptions = checkContentLengthHeaderMiddlewareOptions;
    exports2.getCheckContentLengthHeaderPlugin = getCheckContentLengthHeaderPlugin;
    exports2.getRegionRedirectMiddlewarePlugin = getRegionRedirectMiddlewarePlugin;
    exports2.getS3ExpiresMiddlewarePlugin = getS3ExpiresMiddlewarePlugin;
    exports2.getS3ExpressHttpSigningPlugin = getS3ExpressHttpSigningPlugin;
    exports2.getS3ExpressPlugin = getS3ExpressPlugin;
    exports2.getThrow200ExceptionsPlugin = getThrow200ExceptionsPlugin;
    exports2.getValidateBucketNamePlugin = getValidateBucketNamePlugin;
    exports2.regionRedirectEndpointMiddleware = regionRedirectEndpointMiddleware;
    exports2.regionRedirectEndpointMiddlewareOptions = regionRedirectEndpointMiddlewareOptions;
    exports2.regionRedirectMiddleware = regionRedirectMiddleware;
    exports2.regionRedirectMiddlewareOptions = regionRedirectMiddlewareOptions;
    exports2.resolveS3Config = resolveS3Config;
    exports2.s3ExpiresMiddleware = s3ExpiresMiddleware;
    exports2.s3ExpiresMiddlewareOptions = s3ExpiresMiddlewareOptions;
    exports2.s3ExpressHttpSigningMiddleware = s3ExpressHttpSigningMiddleware;
    exports2.s3ExpressHttpSigningMiddlewareOptions = s3ExpressHttpSigningMiddlewareOptions;
    exports2.s3ExpressMiddleware = s3ExpressMiddleware;
    exports2.s3ExpressMiddlewareOptions = s3ExpressMiddlewareOptions;
    exports2.throw200ExceptionsMiddleware = throw200ExceptionsMiddleware;
    exports2.throw200ExceptionsMiddlewareOptions = throw200ExceptionsMiddlewareOptions;
    exports2.validateBucketNameMiddleware = validateBucketNameMiddleware;
    exports2.validateBucketNameMiddlewareOptions = validateBucketNameMiddlewareOptions;
  }
});

// ../../node_modules/@aws-sdk/nested-clients/node_modules/@aws-sdk/signature-v4-multi-region/dist-cjs/index.js
var require_dist_cjs118 = __commonJS({
  "../../node_modules/@aws-sdk/nested-clients/node_modules/@aws-sdk/signature-v4-multi-region/dist-cjs/index.js"(exports2) {
    "use strict";
    var middlewareSdkS3 = require_dist_cjs117();
    var signatureV4 = require_dist_cjs36();
    var signatureV4CrtContainer = {
      CrtSignerV4: null
    };
    var SignatureV4MultiRegion19 = class {
      static {
        __name(this, "SignatureV4MultiRegion");
      }
      sigv4aSigner;
      sigv4Signer;
      signerOptions;
      static sigv4aDependency() {
        if (typeof signatureV4CrtContainer.CrtSignerV4 === "function") {
          return "crt";
        } else if (typeof signatureV4.signatureV4aContainer.SignatureV4a === "function") {
          return "js";
        }
        return "none";
      }
      constructor(options) {
        this.sigv4Signer = new middlewareSdkS3.SignatureV4S3Express(options);
        this.signerOptions = options;
      }
      async sign(requestToSign, options = {}) {
        if (options.signingRegion === "*") {
          return this.getSigv4aSigner().sign(requestToSign, options);
        }
        return this.sigv4Signer.sign(requestToSign, options);
      }
      async signWithCredentials(requestToSign, credentials, options = {}) {
        if (options.signingRegion === "*") {
          const signer = this.getSigv4aSigner();
          const CrtSignerV4 = signatureV4CrtContainer.CrtSignerV4;
          if (CrtSignerV4 && signer instanceof CrtSignerV4) {
            return signer.signWithCredentials(requestToSign, credentials, options);
          } else {
            throw new Error(`signWithCredentials with signingRegion '*' is only supported when using the CRT dependency @aws-sdk/signature-v4-crt. Please check whether you have installed the "@aws-sdk/signature-v4-crt" package explicitly. You must also register the package by calling [require("@aws-sdk/signature-v4-crt");] or an ESM equivalent such as [import "@aws-sdk/signature-v4-crt";]. For more information please go to https://github.com/aws/aws-sdk-js-v3#functionality-requiring-aws-common-runtime-crt`);
          }
        }
        return this.sigv4Signer.signWithCredentials(requestToSign, credentials, options);
      }
      async presign(originalRequest, options = {}) {
        if (options.signingRegion === "*") {
          const signer = this.getSigv4aSigner();
          const CrtSignerV4 = signatureV4CrtContainer.CrtSignerV4;
          if (CrtSignerV4 && signer instanceof CrtSignerV4) {
            return signer.presign(originalRequest, options);
          } else {
            throw new Error(`presign with signingRegion '*' is only supported when using the CRT dependency @aws-sdk/signature-v4-crt. Please check whether you have installed the "@aws-sdk/signature-v4-crt" package explicitly. You must also register the package by calling [require("@aws-sdk/signature-v4-crt");] or an ESM equivalent such as [import "@aws-sdk/signature-v4-crt";]. For more information please go to https://github.com/aws/aws-sdk-js-v3#functionality-requiring-aws-common-runtime-crt`);
          }
        }
        return this.sigv4Signer.presign(originalRequest, options);
      }
      async presignWithCredentials(originalRequest, credentials, options = {}) {
        if (options.signingRegion === "*") {
          throw new Error("Method presignWithCredentials is not supported for [signingRegion=*].");
        }
        return this.sigv4Signer.presignWithCredentials(originalRequest, credentials, options);
      }
      getSigv4aSigner() {
        if (!this.sigv4aSigner) {
          const CrtSignerV4 = signatureV4CrtContainer.CrtSignerV4;
          const JsSigV4aSigner = signatureV4.signatureV4aContainer.SignatureV4a;
          if (this.signerOptions.runtime === "node") {
            if (!CrtSignerV4 && !JsSigV4aSigner) {
              throw new Error("Neither CRT nor JS SigV4a implementation is available. Please load either @aws-sdk/signature-v4-crt or @aws-sdk/signature-v4a. For more information please go to https://github.com/aws/aws-sdk-js-v3#functionality-requiring-aws-common-runtime-crt");
            }
            if (CrtSignerV4 && typeof CrtSignerV4 === "function") {
              this.sigv4aSigner = new CrtSignerV4({
                ...this.signerOptions,
                signingAlgorithm: 1
              });
            } else if (JsSigV4aSigner && typeof JsSigV4aSigner === "function") {
              this.sigv4aSigner = new JsSigV4aSigner({
                ...this.signerOptions
              });
            } else {
              throw new Error("Available SigV4a implementation is not a valid constructor. Please ensure you've properly imported @aws-sdk/signature-v4-crt or @aws-sdk/signature-v4a.For more information please go to https://github.com/aws/aws-sdk-js-v3#functionality-requiring-aws-common-runtime-crt");
            }
          } else {
            if (!JsSigV4aSigner || typeof JsSigV4aSigner !== "function") {
              throw new Error("JS SigV4a implementation is not available or not a valid constructor. Please check whether you have installed the @aws-sdk/signature-v4a package explicitly. The CRT implementation is not available for browsers. You must also register the package by calling [require('@aws-sdk/signature-v4a');] or an ESM equivalent such as [import '@aws-sdk/signature-v4a';]. For more information please go to https://github.com/aws/aws-sdk-js-v3#using-javascript-non-crt-implementation-of-sigv4a");
            }
            this.sigv4aSigner = new JsSigV4aSigner({
              ...this.signerOptions
            });
          }
        }
        return this.sigv4aSigner;
      }
    };
    exports2.SignatureV4MultiRegion = SignatureV4MultiRegion19;
    exports2.signatureV4CrtContainer = signatureV4CrtContainer;
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/bdd.js
var import_util_endpoints40, q4, a14, b14, c14, d14, e14, f14, g14, h14, i14, j14, k14, l8, m8, n4, o4, p4, _data14, root14, r14, nodes14, bdd14;
var init_bdd14 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/bdd.js"() {
    import_util_endpoints40 = __toESM(require_dist_cjs20());
    q4 = "ref";
    a14 = -1;
    b14 = true;
    c14 = "isSet";
    d14 = "PartitionResult";
    e14 = "booleanEquals";
    f14 = "stringEquals";
    g14 = "getAttr";
    h14 = "us-east-1";
    i14 = "sigv4";
    j14 = "sts";
    k14 = "https://sts.{Region}.{PartitionResult#dnsSuffix}";
    l8 = { [q4]: "Endpoint" };
    m8 = { [q4]: "Region" };
    n4 = { [q4]: d14 };
    o4 = {};
    p4 = [m8];
    _data14 = {
      conditions: [
        [c14, [l8]],
        [c14, p4],
        ["aws.partition", p4, d14],
        [e14, [{ [q4]: "UseFIPS" }, b14]],
        [e14, [{ [q4]: "UseDualStack" }, b14]],
        [f14, [m8, "aws-global"]],
        [e14, [{ [q4]: "UseGlobalEndpoint" }, b14]],
        [f14, [m8, "eu-central-1"]],
        [e14, [{ fn: g14, argv: [n4, "supportsDualStack"] }, b14]],
        [e14, [{ fn: g14, argv: [n4, "supportsFIPS"] }, b14]],
        [f14, [m8, "ap-south-1"]],
        [f14, [m8, "eu-north-1"]],
        [f14, [m8, "eu-west-1"]],
        [f14, [m8, "eu-west-2"]],
        [f14, [m8, "eu-west-3"]],
        [f14, [m8, "sa-east-1"]],
        [f14, [m8, h14]],
        [f14, [m8, "us-east-2"]],
        [f14, [m8, "us-west-2"]],
        [f14, [m8, "us-west-1"]],
        [f14, [m8, "ca-central-1"]],
        [f14, [m8, "ap-southeast-1"]],
        [f14, [m8, "ap-northeast-1"]],
        [f14, [m8, "ap-southeast-2"]],
        [f14, [{ fn: g14, argv: [n4, "name"] }, "aws-us-gov"]]
      ],
      results: [
        [a14],
        ["https://sts.amazonaws.com", { authSchemes: [{ name: i14, signingName: j14, signingRegion: h14 }] }],
        [k14, { authSchemes: [{ name: i14, signingName: j14, signingRegion: "{Region}" }] }],
        [a14, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a14, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [l8, o4],
        ["https://sts-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", o4],
        [a14, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://sts.{Region}.amazonaws.com", o4],
        ["https://sts-fips.{Region}.{PartitionResult#dnsSuffix}", o4],
        [a14, "FIPS is enabled but this partition does not support FIPS"],
        ["https://sts.{Region}.{PartitionResult#dualStackDnsSuffix}", o4],
        [a14, "DualStack is enabled but this partition does not support DualStack"],
        [k14, o4],
        [a14, "Invalid Configuration: Missing Region"]
      ]
    };
    root14 = 2;
    r14 = 1e8;
    nodes14 = new Int32Array([
      -1,
      1,
      -1,
      0,
      30,
      3,
      1,
      4,
      r14 + 14,
      2,
      5,
      r14 + 14,
      3,
      25,
      6,
      4,
      24,
      7,
      5,
      r14 + 1,
      8,
      6,
      9,
      r14 + 13,
      7,
      r14 + 1,
      10,
      10,
      r14 + 1,
      11,
      11,
      r14 + 1,
      12,
      12,
      r14 + 1,
      13,
      13,
      r14 + 1,
      14,
      14,
      r14 + 1,
      15,
      15,
      r14 + 1,
      16,
      16,
      r14 + 1,
      17,
      17,
      r14 + 1,
      18,
      18,
      r14 + 1,
      19,
      19,
      r14 + 1,
      20,
      20,
      r14 + 1,
      21,
      21,
      r14 + 1,
      22,
      22,
      r14 + 1,
      23,
      23,
      r14 + 1,
      r14 + 2,
      8,
      r14 + 11,
      r14 + 12,
      4,
      28,
      26,
      9,
      27,
      r14 + 10,
      24,
      r14 + 8,
      r14 + 9,
      8,
      29,
      r14 + 7,
      9,
      r14 + 6,
      r14 + 7,
      3,
      r14 + 3,
      31,
      4,
      r14 + 4,
      r14 + 5
    ]);
    bdd14 = import_util_endpoints40.BinaryDecisionDiagram.from(nodes14, root14, _data14.conditions, _data14.results);
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/endpointResolver.js
var import_util_endpoints41, import_util_endpoints42, cache14, defaultEndpointResolver14;
var init_endpointResolver14 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/endpointResolver.js"() {
    import_util_endpoints41 = __toESM(require_dist_cjs21());
    import_util_endpoints42 = __toESM(require_dist_cjs20());
    init_bdd14();
    cache14 = new import_util_endpoints42.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS", "UseGlobalEndpoint"]
    });
    defaultEndpointResolver14 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache14.get(endpointParams, () => (0, import_util_endpoints42.decideEndpoint)(bdd14, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    import_util_endpoints42.customEndpointFunctions.aws = import_util_endpoints41.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption14(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "sts",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createAwsAuthSigv4aHttpAuthOption4(authParameters) {
  return {
    schemeId: "aws.auth#sigv4a",
    signingProperties: {
      name: "sts",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption14(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var import_signature_v4_multi_region7, import_middleware_endpoint33, import_util_middleware19, createEndpointRuleSetHttpAuthSchemeParametersProvider4, _defaultSTSHttpAuthSchemeParametersProvider4, defaultSTSHttpAuthSchemeParametersProvider4, createEndpointRuleSetHttpAuthSchemeProvider4, _defaultSTSHttpAuthSchemeProvider4, defaultSTSHttpAuthSchemeProvider4, resolveStsAuthConfig4, resolveHttpAuthSchemeConfig14;
var init_httpAuthSchemeProvider14 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes6();
    import_signature_v4_multi_region7 = __toESM(require_dist_cjs118());
    import_middleware_endpoint33 = __toESM(require_dist_cjs31());
    import_util_middleware19 = __toESM(require_dist_cjs6());
    init_endpointResolver14();
    init_STSClient4();
    createEndpointRuleSetHttpAuthSchemeParametersProvider4 = /* @__PURE__ */ __name((defaultHttpAuthSchemeParametersProvider) => async (config2, context, input) => {
      if (!input) {
        throw new Error("Could not find `input` for `defaultEndpointRuleSetHttpAuthSchemeParametersProvider`");
      }
      const defaultParameters = await defaultHttpAuthSchemeParametersProvider(config2, context, input);
      const instructionsFn = (0, import_util_middleware19.getSmithyContext)(context)?.commandInstance?.constructor?.getEndpointParameterInstructions;
      if (!instructionsFn) {
        throw new Error(`getEndpointParameterInstructions() is not defined on '${context.commandName}'`);
      }
      const endpointParameters = await (0, import_middleware_endpoint33.resolveParams)(input, { getEndpointParameterInstructions: instructionsFn }, config2);
      return Object.assign(defaultParameters, endpointParameters);
    }, "createEndpointRuleSetHttpAuthSchemeParametersProvider");
    _defaultSTSHttpAuthSchemeParametersProvider4 = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, import_util_middleware19.getSmithyContext)(context).operation,
        region: await (0, import_util_middleware19.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "_defaultSTSHttpAuthSchemeParametersProvider");
    defaultSTSHttpAuthSchemeParametersProvider4 = createEndpointRuleSetHttpAuthSchemeParametersProvider4(_defaultSTSHttpAuthSchemeParametersProvider4);
    __name(createAwsAuthSigv4HttpAuthOption14, "createAwsAuthSigv4HttpAuthOption");
    __name(createAwsAuthSigv4aHttpAuthOption4, "createAwsAuthSigv4aHttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption14, "createSmithyApiNoAuthHttpAuthOption");
    createEndpointRuleSetHttpAuthSchemeProvider4 = /* @__PURE__ */ __name((defaultEndpointResolver32, defaultHttpAuthSchemeResolver, createHttpAuthOptionFunctions) => {
      const endpointRuleSetHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
        const endpoint = defaultEndpointResolver32(authParameters);
        const authSchemes = endpoint.properties?.authSchemes;
        if (!authSchemes) {
          return defaultHttpAuthSchemeResolver(authParameters);
        }
        const options = [];
        for (const scheme of authSchemes) {
          const { name: resolvedName, properties = {}, ...rest } = scheme;
          const name = resolvedName.toLowerCase();
          if (resolvedName !== name) {
            console.warn(`HttpAuthScheme has been normalized with lowercasing: '${resolvedName}' to '${name}'`);
          }
          let schemeId;
          if (name === "sigv4a") {
            schemeId = "aws.auth#sigv4a";
            const sigv4Present = authSchemes.find((s) => {
              const name2 = s.name.toLowerCase();
              return name2 !== "sigv4a" && name2.startsWith("sigv4");
            });
            if (import_signature_v4_multi_region7.SignatureV4MultiRegion.sigv4aDependency() === "none" && sigv4Present) {
              continue;
            }
          } else if (name.startsWith("sigv4")) {
            schemeId = "aws.auth#sigv4";
          } else {
            throw new Error(`Unknown HttpAuthScheme found in '@smithy.rules#endpointRuleSet': '${name}'`);
          }
          const createOption = createHttpAuthOptionFunctions[schemeId];
          if (!createOption) {
            throw new Error(`Could not find HttpAuthOption create function for '${schemeId}'`);
          }
          const option = createOption(authParameters);
          option.schemeId = schemeId;
          option.signingProperties = { ...option.signingProperties || {}, ...rest, ...properties };
          options.push(option);
        }
        return options;
      }, "endpointRuleSetHttpAuthSchemeProvider");
      return endpointRuleSetHttpAuthSchemeProvider;
    }, "createEndpointRuleSetHttpAuthSchemeProvider");
    _defaultSTSHttpAuthSchemeProvider4 = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "AssumeRoleWithWebIdentity": {
          options.push(createSmithyApiNoAuthHttpAuthOption14(authParameters));
          options.push(createAwsAuthSigv4aHttpAuthOption4(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption14(authParameters));
          options.push(createAwsAuthSigv4aHttpAuthOption4(authParameters));
        }
      }
      return options;
    }, "_defaultSTSHttpAuthSchemeProvider");
    defaultSTSHttpAuthSchemeProvider4 = createEndpointRuleSetHttpAuthSchemeProvider4(defaultEndpointResolver14, _defaultSTSHttpAuthSchemeProvider4, {
      "aws.auth#sigv4": createAwsAuthSigv4HttpAuthOption14,
      "aws.auth#sigv4a": createAwsAuthSigv4aHttpAuthOption4,
      "smithy.api#noAuth": createSmithyApiNoAuthHttpAuthOption14
    });
    resolveStsAuthConfig4 = /* @__PURE__ */ __name((input) => Object.assign(input, {
      stsClientCtor: STSClient4
    }), "resolveStsAuthConfig");
    resolveHttpAuthSchemeConfig14 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveStsAuthConfig4(config2);
      const config_1 = resolveAwsSdkSigV4Config5(config_0);
      const config_2 = resolveAwsSdkSigV4AConfig5(config_1);
      return Object.assign(config_2, {
        authSchemePreference: (0, import_util_middleware19.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/EndpointParameters.js
var resolveClientEndpointParameters14, commonParams14;
var init_EndpointParameters14 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters14 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        useGlobalEndpoint: options.useGlobalEndpoint ?? false,
        defaultSigningName: "sts"
      });
    }, "resolveClientEndpointParameters");
    commonParams14 = {
      UseGlobalEndpoint: { type: "builtInParams", name: "useGlobalEndpoint" },
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/STSServiceException.js
var import_smithy_client129, STSServiceException4;
var init_STSServiceException4 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/STSServiceException.js"() {
    import_smithy_client129 = __toESM(require_dist_cjs34());
    STSServiceException4 = class _STSServiceException extends import_smithy_client129.ServiceException {
      static {
        __name(this, "STSServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _STSServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/errors.js
var ExpiredTokenException6, MalformedPolicyDocumentException4, PackedPolicyTooLargeException4, RegionDisabledException4, IDPRejectedClaimException4, InvalidIdentityTokenException4, IDPCommunicationErrorException4;
var init_errors14 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/errors.js"() {
    init_STSServiceException4();
    ExpiredTokenException6 = class _ExpiredTokenException extends STSServiceException4 {
      static {
        __name(this, "ExpiredTokenException");
      }
      name = "ExpiredTokenException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ExpiredTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ExpiredTokenException.prototype);
      }
    };
    MalformedPolicyDocumentException4 = class _MalformedPolicyDocumentException extends STSServiceException4 {
      static {
        __name(this, "MalformedPolicyDocumentException");
      }
      name = "MalformedPolicyDocumentException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "MalformedPolicyDocumentException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _MalformedPolicyDocumentException.prototype);
      }
    };
    PackedPolicyTooLargeException4 = class _PackedPolicyTooLargeException extends STSServiceException4 {
      static {
        __name(this, "PackedPolicyTooLargeException");
      }
      name = "PackedPolicyTooLargeException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "PackedPolicyTooLargeException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _PackedPolicyTooLargeException.prototype);
      }
    };
    RegionDisabledException4 = class _RegionDisabledException extends STSServiceException4 {
      static {
        __name(this, "RegionDisabledException");
      }
      name = "RegionDisabledException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "RegionDisabledException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _RegionDisabledException.prototype);
      }
    };
    IDPRejectedClaimException4 = class _IDPRejectedClaimException extends STSServiceException4 {
      static {
        __name(this, "IDPRejectedClaimException");
      }
      name = "IDPRejectedClaimException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "IDPRejectedClaimException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _IDPRejectedClaimException.prototype);
      }
    };
    InvalidIdentityTokenException4 = class _InvalidIdentityTokenException extends STSServiceException4 {
      static {
        __name(this, "InvalidIdentityTokenException");
      }
      name = "InvalidIdentityTokenException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidIdentityTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidIdentityTokenException.prototype);
      }
    };
    IDPCommunicationErrorException4 = class _IDPCommunicationErrorException extends STSServiceException4 {
      static {
        __name(this, "IDPCommunicationErrorException");
      }
      name = "IDPCommunicationErrorException";
      $fault = "client";
      $retryable = {};
      constructor(opts) {
        super({
          name: "IDPCommunicationErrorException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _IDPCommunicationErrorException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/schemas/schemas_0.js
var _A4, _AKI4, _AR4, _ARI4, _ARR4, _ARRs4, _ARU4, _ARWWI4, _ARWWIR4, _ARWWIRs4, _Au4, _C4, _CA4, _DS4, _E4, _EI4, _ETE6, _IDPCEE4, _IDPRCE4, _IITE4, _K4, _MPDE4, _P4, _PA4, _PAr4, _PC4, _PCLT4, _PCr4, _PDT4, _PI4, _PPS4, _PPTLE4, _Pr4, _RA4, _RDE4, _RSN4, _SAK4, _SFWIT4, _SI4, _SN4, _ST4, _T4, _TC4, _TTK4, _Ta4, _V4, _WIT4, _a4, _aKST4, _aQE4, _c14, _cTT4, _e14, _hE14, _m12, _pDLT4, _s14, _tLT4, n014, _s_registry14, STSServiceException$4, n0_registry14, ExpiredTokenException$6, IDPCommunicationErrorException$4, IDPRejectedClaimException$4, InvalidIdentityTokenException$4, MalformedPolicyDocumentException$4, PackedPolicyTooLargeException$4, RegionDisabledException$4, errorTypeRegistries14, accessKeySecretType4, clientTokenType4, AssumedRoleUser$4, AssumeRoleRequest$4, AssumeRoleResponse$4, AssumeRoleWithWebIdentityRequest$4, AssumeRoleWithWebIdentityResponse$4, Credentials$4, PolicyDescriptorType$4, ProvidedContext$4, Tag$4, policyDescriptorListType4, ProvidedContextsListType4, tagKeyListType4, tagListType4, AssumeRole$4, AssumeRoleWithWebIdentity$4;
var init_schemas_014 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/schemas/schemas_0.js"() {
    init_schema4();
    init_errors14();
    init_STSServiceException4();
    _A4 = "Arn";
    _AKI4 = "AccessKeyId";
    _AR4 = "AssumeRole";
    _ARI4 = "AssumedRoleId";
    _ARR4 = "AssumeRoleRequest";
    _ARRs4 = "AssumeRoleResponse";
    _ARU4 = "AssumedRoleUser";
    _ARWWI4 = "AssumeRoleWithWebIdentity";
    _ARWWIR4 = "AssumeRoleWithWebIdentityRequest";
    _ARWWIRs4 = "AssumeRoleWithWebIdentityResponse";
    _Au4 = "Audience";
    _C4 = "Credentials";
    _CA4 = "ContextAssertion";
    _DS4 = "DurationSeconds";
    _E4 = "Expiration";
    _EI4 = "ExternalId";
    _ETE6 = "ExpiredTokenException";
    _IDPCEE4 = "IDPCommunicationErrorException";
    _IDPRCE4 = "IDPRejectedClaimException";
    _IITE4 = "InvalidIdentityTokenException";
    _K4 = "Key";
    _MPDE4 = "MalformedPolicyDocumentException";
    _P4 = "Policy";
    _PA4 = "PolicyArns";
    _PAr4 = "ProviderArn";
    _PC4 = "ProvidedContexts";
    _PCLT4 = "ProvidedContextsListType";
    _PCr4 = "ProvidedContext";
    _PDT4 = "PolicyDescriptorType";
    _PI4 = "ProviderId";
    _PPS4 = "PackedPolicySize";
    _PPTLE4 = "PackedPolicyTooLargeException";
    _Pr4 = "Provider";
    _RA4 = "RoleArn";
    _RDE4 = "RegionDisabledException";
    _RSN4 = "RoleSessionName";
    _SAK4 = "SecretAccessKey";
    _SFWIT4 = "SubjectFromWebIdentityToken";
    _SI4 = "SourceIdentity";
    _SN4 = "SerialNumber";
    _ST4 = "SessionToken";
    _T4 = "Tags";
    _TC4 = "TokenCode";
    _TTK4 = "TransitiveTagKeys";
    _Ta4 = "Tag";
    _V4 = "Value";
    _WIT4 = "WebIdentityToken";
    _a4 = "arn";
    _aKST4 = "accessKeySecretType";
    _aQE4 = "awsQueryError";
    _c14 = "client";
    _cTT4 = "clientTokenType";
    _e14 = "error";
    _hE14 = "httpError";
    _m12 = "message";
    _pDLT4 = "policyDescriptorListType";
    _s14 = "smithy.ts.sdk.synthetic.com.amazonaws.sts";
    _tLT4 = "tagListType";
    n014 = "com.amazonaws.sts";
    _s_registry14 = TypeRegistry.for(_s14);
    STSServiceException$4 = [-3, _s14, "STSServiceException", 0, [], []];
    _s_registry14.registerError(STSServiceException$4, STSServiceException4);
    n0_registry14 = TypeRegistry.for(n014);
    ExpiredTokenException$6 = [
      -3,
      n014,
      _ETE6,
      { [_aQE4]: [`ExpiredTokenException`, 400], [_e14]: _c14, [_hE14]: 400 },
      [_m12],
      [0]
    ];
    n0_registry14.registerError(ExpiredTokenException$6, ExpiredTokenException6);
    IDPCommunicationErrorException$4 = [
      -3,
      n014,
      _IDPCEE4,
      { [_aQE4]: [`IDPCommunicationError`, 400], [_e14]: _c14, [_hE14]: 400 },
      [_m12],
      [0]
    ];
    n0_registry14.registerError(IDPCommunicationErrorException$4, IDPCommunicationErrorException4);
    IDPRejectedClaimException$4 = [
      -3,
      n014,
      _IDPRCE4,
      { [_aQE4]: [`IDPRejectedClaim`, 403], [_e14]: _c14, [_hE14]: 403 },
      [_m12],
      [0]
    ];
    n0_registry14.registerError(IDPRejectedClaimException$4, IDPRejectedClaimException4);
    InvalidIdentityTokenException$4 = [
      -3,
      n014,
      _IITE4,
      { [_aQE4]: [`InvalidIdentityToken`, 400], [_e14]: _c14, [_hE14]: 400 },
      [_m12],
      [0]
    ];
    n0_registry14.registerError(InvalidIdentityTokenException$4, InvalidIdentityTokenException4);
    MalformedPolicyDocumentException$4 = [
      -3,
      n014,
      _MPDE4,
      { [_aQE4]: [`MalformedPolicyDocument`, 400], [_e14]: _c14, [_hE14]: 400 },
      [_m12],
      [0]
    ];
    n0_registry14.registerError(MalformedPolicyDocumentException$4, MalformedPolicyDocumentException4);
    PackedPolicyTooLargeException$4 = [
      -3,
      n014,
      _PPTLE4,
      { [_aQE4]: [`PackedPolicyTooLarge`, 400], [_e14]: _c14, [_hE14]: 400 },
      [_m12],
      [0]
    ];
    n0_registry14.registerError(PackedPolicyTooLargeException$4, PackedPolicyTooLargeException4);
    RegionDisabledException$4 = [
      -3,
      n014,
      _RDE4,
      { [_aQE4]: [`RegionDisabledException`, 403], [_e14]: _c14, [_hE14]: 403 },
      [_m12],
      [0]
    ];
    n0_registry14.registerError(RegionDisabledException$4, RegionDisabledException4);
    errorTypeRegistries14 = [_s_registry14, n0_registry14];
    accessKeySecretType4 = [0, n014, _aKST4, 8, 0];
    clientTokenType4 = [0, n014, _cTT4, 8, 0];
    AssumedRoleUser$4 = [3, n014, _ARU4, 0, [_ARI4, _A4], [0, 0], 2];
    AssumeRoleRequest$4 = [
      3,
      n014,
      _ARR4,
      0,
      [_RA4, _RSN4, _PA4, _P4, _DS4, _T4, _TTK4, _EI4, _SN4, _TC4, _SI4, _PC4],
      [0, 0, () => policyDescriptorListType4, 0, 1, () => tagListType4, 64 | 0, 0, 0, 0, 0, () => ProvidedContextsListType4],
      2
    ];
    AssumeRoleResponse$4 = [
      3,
      n014,
      _ARRs4,
      0,
      [_C4, _ARU4, _PPS4, _SI4],
      [[() => Credentials$4, 0], () => AssumedRoleUser$4, 1, 0]
    ];
    AssumeRoleWithWebIdentityRequest$4 = [
      3,
      n014,
      _ARWWIR4,
      0,
      [_RA4, _RSN4, _WIT4, _PI4, _PA4, _P4, _DS4],
      [0, 0, [() => clientTokenType4, 0], 0, () => policyDescriptorListType4, 0, 1],
      3
    ];
    AssumeRoleWithWebIdentityResponse$4 = [
      3,
      n014,
      _ARWWIRs4,
      0,
      [_C4, _SFWIT4, _ARU4, _PPS4, _Pr4, _Au4, _SI4],
      [[() => Credentials$4, 0], 0, () => AssumedRoleUser$4, 1, 0, 0, 0]
    ];
    Credentials$4 = [
      3,
      n014,
      _C4,
      0,
      [_AKI4, _SAK4, _ST4, _E4],
      [0, [() => accessKeySecretType4, 0], 0, 4],
      4
    ];
    PolicyDescriptorType$4 = [3, n014, _PDT4, 0, [_a4], [0]];
    ProvidedContext$4 = [3, n014, _PCr4, 0, [_PAr4, _CA4], [0, 0]];
    Tag$4 = [3, n014, _Ta4, 0, [_K4, _V4], [0, 0], 2];
    policyDescriptorListType4 = [1, n014, _pDLT4, 0, () => PolicyDescriptorType$4];
    ProvidedContextsListType4 = [1, n014, _PCLT4, 0, () => ProvidedContext$4];
    tagKeyListType4 = 64 | 0;
    tagListType4 = [1, n014, _tLT4, 0, () => Tag$4];
    AssumeRole$4 = [9, n014, _AR4, 0, () => AssumeRoleRequest$4, () => AssumeRoleResponse$4];
    AssumeRoleWithWebIdentity$4 = [
      9,
      n014,
      _ARWWI4,
      0,
      () => AssumeRoleWithWebIdentityRequest$4,
      () => AssumeRoleWithWebIdentityResponse$4
    ];
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.shared.js
var import_signature_v4_multi_region8, import_smithy_client130, import_url_parser15, import_util_base6438, import_util_utf830, getRuntimeConfig27;
var init_runtimeConfig_shared14 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.shared.js"() {
    init_httpAuthSchemes6();
    init_protocols8();
    import_signature_v4_multi_region8 = __toESM(require_dist_cjs118());
    init_dist_es();
    import_smithy_client130 = __toESM(require_dist_cjs34());
    import_url_parser15 = __toESM(require_dist_cjs18());
    import_util_base6438 = __toESM(require_dist_cjs10());
    import_util_utf830 = __toESM(require_dist_cjs9());
    init_httpAuthSchemeProvider14();
    init_endpointResolver14();
    init_schemas_014();
    getRuntimeConfig27 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2011-06-15",
        base64Decoder: config2?.base64Decoder ?? import_util_base6438.fromBase64,
        base64Encoder: config2?.base64Encoder ?? import_util_base6438.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver14,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSTSHttpAuthSchemeProvider4,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer5()
          },
          {
            schemeId: "aws.auth#sigv4a",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4a"), "identityProvider"),
            signer: new AwsSdkSigV4ASigner5()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        logger: config2?.logger ?? new import_smithy_client130.NoOpLogger(),
        protocol: config2?.protocol ?? AwsQueryProtocol5,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.sts",
          errorTypeRegistries: errorTypeRegistries14,
          xmlNamespace: "https://sts.amazonaws.com/doc/2011-06-15/",
          version: "2011-06-15",
          serviceTarget: "AWSSecurityTokenServiceV20110615"
        },
        serviceId: config2?.serviceId ?? "STS",
        signerConstructor: config2?.signerConstructor ?? import_signature_v4_multi_region8.SignatureV4MultiRegion,
        urlParser: config2?.urlParser ?? import_url_parser15.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? import_util_utf830.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? import_util_utf830.toUtf8
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.js
var import_util_user_agent_node14, import_config_resolver27, import_hash_node14, import_middleware_retry27, import_node_config_provider14, import_node_http_handler14, import_smithy_client131, import_util_body_length_node14, import_util_defaults_mode_node14, import_util_retry21, getRuntimeConfig28;
var init_runtimeConfig14 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.js"() {
    init_package5();
    init_client8();
    init_httpAuthSchemes6();
    import_util_user_agent_node14 = __toESM(require_dist_cjs113());
    import_config_resolver27 = __toESM(require_dist_cjs25());
    init_dist_es();
    import_hash_node14 = __toESM(require_dist_cjs44());
    import_middleware_retry27 = __toESM(require_dist_cjs106());
    import_node_config_provider14 = __toESM(require_dist_cjs29());
    import_node_http_handler14 = __toESM(require_dist_cjs13());
    import_smithy_client131 = __toESM(require_dist_cjs34());
    import_util_body_length_node14 = __toESM(require_dist_cjs45());
    import_util_defaults_mode_node14 = __toESM(require_dist_cjs46());
    import_util_retry21 = __toESM(require_dist_cjs22());
    init_runtimeConfig_shared14();
    getRuntimeConfig28 = /* @__PURE__ */ __name((config2) => {
      (0, import_smithy_client131.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, import_util_defaults_mode_node14.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(import_smithy_client131.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig27(config2);
      emitWarningIfUnsupportedVersion17(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, import_node_config_provider14.loadConfig)(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS5, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? import_util_body_length_node14.calculateBodyLength,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, import_util_user_agent_node14.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_default5.version }),
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4") || (async (idProps) => await config2.credentialDefaultProvider(idProps?.__config || {})()), "identityProvider"),
            signer: new AwsSdkSigV4Signer5()
          },
          {
            schemeId: "aws.auth#sigv4a",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4a"), "identityProvider"),
            signer: new AwsSdkSigV4ASigner5()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        maxAttempts: config2?.maxAttempts ?? (0, import_node_config_provider14.loadConfig)(import_middleware_retry27.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, import_node_config_provider14.loadConfig)(import_config_resolver27.NODE_REGION_CONFIG_OPTIONS, { ...import_config_resolver27.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: import_node_http_handler14.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, import_node_config_provider14.loadConfig)({
          ...import_middleware_retry27.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || import_util_retry21.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? import_hash_node14.Hash.bind(null, "sha256"),
        sigv4aSigningRegionSet: config2?.sigv4aSigningRegionSet ?? (0, import_node_config_provider14.loadConfig)(NODE_SIGV4A_CONFIG_OPTIONS5, loaderConfig),
        streamCollector: config2?.streamCollector ?? import_node_http_handler14.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, import_node_config_provider14.loadConfig)(import_config_resolver27.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, import_node_config_provider14.loadConfig)(import_config_resolver27.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, import_node_config_provider14.loadConfig)(import_util_user_agent_node14.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration14, resolveHttpAuthRuntimeConfig14;
var init_httpAuthExtensionConfiguration14 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration14 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig14 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeExtensions.js
var import_region_config_resolver17, import_protocol_http37, import_smithy_client132, resolveRuntimeExtensions14;
var init_runtimeExtensions14 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeExtensions.js"() {
    import_region_config_resolver17 = __toESM(require_dist_cjs48());
    import_protocol_http37 = __toESM(require_dist_cjs2());
    import_smithy_client132 = __toESM(require_dist_cjs34());
    init_httpAuthExtensionConfiguration14();
    resolveRuntimeExtensions14 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign((0, import_region_config_resolver17.getAwsRegionExtensionConfiguration)(runtimeConfig), (0, import_smithy_client132.getDefaultExtensionConfiguration)(runtimeConfig), (0, import_protocol_http37.getHttpHandlerExtensionConfiguration)(runtimeConfig), getHttpAuthExtensionConfiguration14(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, (0, import_region_config_resolver17.resolveAwsRegionExtensionConfiguration)(extensionConfiguration), (0, import_smithy_client132.resolveDefaultRuntimeConfig)(extensionConfiguration), (0, import_protocol_http37.resolveHttpHandlerRuntimeConfig)(extensionConfiguration), resolveHttpAuthRuntimeConfig14(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STSClient.js
var import_middleware_host_header14, import_middleware_logger14, import_middleware_recursion_detection14, import_middleware_user_agent14, import_config_resolver28, import_middleware_content_length14, import_middleware_endpoint34, import_middleware_retry28, import_smithy_client133, STSClient4;
var init_STSClient4 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STSClient.js"() {
    import_middleware_host_header14 = __toESM(require_dist_cjs3());
    import_middleware_logger14 = __toESM(require_dist_cjs4());
    import_middleware_recursion_detection14 = __toESM(require_dist_cjs5());
    import_middleware_user_agent14 = __toESM(require_dist_cjs104());
    import_config_resolver28 = __toESM(require_dist_cjs25());
    init_dist_es();
    init_schema4();
    import_middleware_content_length14 = __toESM(require_dist_cjs26());
    import_middleware_endpoint34 = __toESM(require_dist_cjs31());
    import_middleware_retry28 = __toESM(require_dist_cjs106());
    import_smithy_client133 = __toESM(require_dist_cjs34());
    init_httpAuthSchemeProvider14();
    init_EndpointParameters14();
    init_runtimeConfig14();
    init_runtimeExtensions14();
    STSClient4 = class extends import_smithy_client133.Client {
      static {
        __name(this, "STSClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig28(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters14(_config_0);
        const _config_2 = (0, import_middleware_user_agent14.resolveUserAgentConfig)(_config_1);
        const _config_3 = (0, import_middleware_retry28.resolveRetryConfig)(_config_2);
        const _config_4 = (0, import_config_resolver28.resolveRegionConfig)(_config_3);
        const _config_5 = (0, import_middleware_host_header14.resolveHostHeaderConfig)(_config_4);
        const _config_6 = (0, import_middleware_endpoint34.resolveEndpointConfig)(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig14(_config_6);
        const _config_8 = resolveRuntimeExtensions14(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin(this.config));
        this.middlewareStack.use((0, import_middleware_user_agent14.getUserAgentPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_retry28.getRetryPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_content_length14.getContentLengthPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_host_header14.getHostHeaderPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_logger14.getLoggerPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_recursion_detection14.getRecursionDetectionPlugin)(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: defaultSTSHttpAuthSchemeParametersProvider4,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials,
            "aws.auth#sigv4a": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleCommand.js
var import_middleware_endpoint35, import_smithy_client134, AssumeRoleCommand4;
var init_AssumeRoleCommand4 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleCommand.js"() {
    import_middleware_endpoint35 = __toESM(require_dist_cjs31());
    import_smithy_client134 = __toESM(require_dist_cjs34());
    init_EndpointParameters14();
    init_schemas_014();
    AssumeRoleCommand4 = class extends import_smithy_client134.Command.classBuilder().ep(commonParams14).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint35.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "AssumeRole", {}).n("STSClient", "AssumeRoleCommand").sc(AssumeRole$4).build() {
      static {
        __name(this, "AssumeRoleCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleWithWebIdentityCommand.js
var import_middleware_endpoint36, import_smithy_client135, AssumeRoleWithWebIdentityCommand4;
var init_AssumeRoleWithWebIdentityCommand4 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleWithWebIdentityCommand.js"() {
    import_middleware_endpoint36 = __toESM(require_dist_cjs31());
    import_smithy_client135 = __toESM(require_dist_cjs34());
    init_EndpointParameters14();
    init_schemas_014();
    AssumeRoleWithWebIdentityCommand4 = class extends import_smithy_client135.Command.classBuilder().ep(commonParams14).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint36.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "AssumeRoleWithWebIdentity", {}).n("STSClient", "AssumeRoleWithWebIdentityCommand").sc(AssumeRoleWithWebIdentity$4).build() {
      static {
        __name(this, "AssumeRoleWithWebIdentityCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STS.js
var import_smithy_client136, commands14, STS4;
var init_STS4 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STS.js"() {
    import_smithy_client136 = __toESM(require_dist_cjs34());
    init_AssumeRoleCommand4();
    init_AssumeRoleWithWebIdentityCommand4();
    init_STSClient4();
    commands14 = {
      AssumeRoleCommand: AssumeRoleCommand4,
      AssumeRoleWithWebIdentityCommand: AssumeRoleWithWebIdentityCommand4
    };
    STS4 = class extends STSClient4 {
      static {
        __name(this, "STS");
      }
    };
    (0, import_smithy_client136.createAggregatedClient)(commands14, STS4);
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/index.js
var init_commands15 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/index.js"() {
    init_AssumeRoleCommand4();
    init_AssumeRoleWithWebIdentityCommand4();
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/models_0.js
var init_models_014 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultStsRoleAssumers.js
var import_region_config_resolver18, getAccountIdFromAssumedRoleUser4, resolveRegion4, getDefaultRoleAssumer7, getDefaultRoleAssumerWithWebIdentity7, isH24;
var init_defaultStsRoleAssumers4 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultStsRoleAssumers.js"() {
    init_client8();
    import_region_config_resolver18 = __toESM(require_dist_cjs48());
    init_AssumeRoleCommand4();
    init_AssumeRoleWithWebIdentityCommand4();
    getAccountIdFromAssumedRoleUser4 = /* @__PURE__ */ __name((assumedRoleUser) => {
      if (typeof assumedRoleUser?.Arn === "string") {
        const arnComponents = assumedRoleUser.Arn.split(":");
        if (arnComponents.length > 4 && arnComponents[4] !== "") {
          return arnComponents[4];
        }
      }
      return void 0;
    }, "getAccountIdFromAssumedRoleUser");
    resolveRegion4 = /* @__PURE__ */ __name(async (_region, _parentRegion, credentialProviderLogger, loaderConfig = {}) => {
      const region = typeof _region === "function" ? await _region() : _region;
      const parentRegion = typeof _parentRegion === "function" ? await _parentRegion() : _parentRegion;
      let stsDefaultRegion = "";
      const resolvedRegion = region ?? parentRegion ?? (stsDefaultRegion = await (0, import_region_config_resolver18.stsRegionDefaultResolver)(loaderConfig)());
      credentialProviderLogger?.debug?.("@aws-sdk/client-sts::resolveRegion", "accepting first of:", `${region} (credential provider clientConfig)`, `${parentRegion} (contextual client)`, `${stsDefaultRegion} (STS default: AWS_REGION, profile region, or us-east-1)`);
      return resolvedRegion;
    }, "resolveRegion");
    getDefaultRoleAssumer7 = /* @__PURE__ */ __name((stsOptions, STSClient12) => {
      let stsClient;
      let closureSourceCreds;
      return async (sourceCreds, params) => {
        closureSourceCreds = sourceCreds;
        if (!stsClient) {
          const { logger: logger5 = stsOptions?.parentClientConfig?.logger, profile = stsOptions?.parentClientConfig?.profile, region, requestHandler = stsOptions?.parentClientConfig?.requestHandler, credentialProviderLogger, userAgentAppId = stsOptions?.parentClientConfig?.userAgentAppId } = stsOptions;
          const resolvedRegion = await resolveRegion4(region, stsOptions?.parentClientConfig?.region, credentialProviderLogger, {
            logger: logger5,
            profile
          });
          const isCompatibleRequestHandler = !isH24(requestHandler);
          stsClient = new STSClient12({
            ...stsOptions,
            userAgentAppId,
            profile,
            credentialDefaultProvider: /* @__PURE__ */ __name(() => async () => closureSourceCreds, "credentialDefaultProvider"),
            region: resolvedRegion,
            requestHandler: isCompatibleRequestHandler ? requestHandler : void 0,
            logger: logger5
          });
        }
        const { Credentials, AssumedRoleUser } = await stsClient.send(new AssumeRoleCommand4(params));
        if (!Credentials || !Credentials.AccessKeyId || !Credentials.SecretAccessKey) {
          throw new Error(`Invalid response from STS.assumeRole call with role ${params.RoleArn}`);
        }
        const accountId = getAccountIdFromAssumedRoleUser4(AssumedRoleUser);
        const credentials = {
          accessKeyId: Credentials.AccessKeyId,
          secretAccessKey: Credentials.SecretAccessKey,
          sessionToken: Credentials.SessionToken,
          expiration: Credentials.Expiration,
          ...Credentials.CredentialScope && { credentialScope: Credentials.CredentialScope },
          ...accountId && { accountId }
        };
        setCredentialFeature7(credentials, "CREDENTIALS_STS_ASSUME_ROLE", "i");
        return credentials;
      };
    }, "getDefaultRoleAssumer");
    getDefaultRoleAssumerWithWebIdentity7 = /* @__PURE__ */ __name((stsOptions, STSClient12) => {
      let stsClient;
      return async (params) => {
        if (!stsClient) {
          const { logger: logger5 = stsOptions?.parentClientConfig?.logger, profile = stsOptions?.parentClientConfig?.profile, region, requestHandler = stsOptions?.parentClientConfig?.requestHandler, credentialProviderLogger, userAgentAppId = stsOptions?.parentClientConfig?.userAgentAppId } = stsOptions;
          const resolvedRegion = await resolveRegion4(region, stsOptions?.parentClientConfig?.region, credentialProviderLogger, {
            logger: logger5,
            profile
          });
          const isCompatibleRequestHandler = !isH24(requestHandler);
          stsClient = new STSClient12({
            ...stsOptions,
            userAgentAppId,
            profile,
            region: resolvedRegion,
            requestHandler: isCompatibleRequestHandler ? requestHandler : void 0,
            logger: logger5
          });
        }
        const { Credentials, AssumedRoleUser } = await stsClient.send(new AssumeRoleWithWebIdentityCommand4(params));
        if (!Credentials || !Credentials.AccessKeyId || !Credentials.SecretAccessKey) {
          throw new Error(`Invalid response from STS.assumeRoleWithWebIdentity call with role ${params.RoleArn}`);
        }
        const accountId = getAccountIdFromAssumedRoleUser4(AssumedRoleUser);
        const credentials = {
          accessKeyId: Credentials.AccessKeyId,
          secretAccessKey: Credentials.SecretAccessKey,
          sessionToken: Credentials.SessionToken,
          expiration: Credentials.Expiration,
          ...Credentials.CredentialScope && { credentialScope: Credentials.CredentialScope },
          ...accountId && { accountId }
        };
        if (accountId) {
          setCredentialFeature7(credentials, "RESOLVED_ACCOUNT_ID", "T");
        }
        setCredentialFeature7(credentials, "CREDENTIALS_STS_ASSUME_ROLE_WEB_ID", "k");
        return credentials;
      };
    }, "getDefaultRoleAssumerWithWebIdentity");
    isH24 = /* @__PURE__ */ __name((requestHandler) => {
      return requestHandler?.metadata?.handlerProtocol === "h2";
    }, "isH2");
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultRoleAssumers.js
var getCustomizableStsClientCtor4, getDefaultRoleAssumer8, getDefaultRoleAssumerWithWebIdentity8, decorateDefaultCredentialProvider4;
var init_defaultRoleAssumers4 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultRoleAssumers.js"() {
    init_defaultStsRoleAssumers4();
    init_STSClient4();
    getCustomizableStsClientCtor4 = /* @__PURE__ */ __name((baseCtor, customizations) => {
      if (!customizations)
        return baseCtor;
      else
        return class CustomizableSTSClient extends baseCtor {
          static {
            __name(this, "CustomizableSTSClient");
          }
          constructor(config2) {
            super(config2);
            for (const customization of customizations) {
              this.middlewareStack.use(customization);
            }
          }
        };
    }, "getCustomizableStsClientCtor");
    getDefaultRoleAssumer8 = /* @__PURE__ */ __name((stsOptions = {}, stsPlugins) => getDefaultRoleAssumer7(stsOptions, getCustomizableStsClientCtor4(STSClient4, stsPlugins)), "getDefaultRoleAssumer");
    getDefaultRoleAssumerWithWebIdentity8 = /* @__PURE__ */ __name((stsOptions = {}, stsPlugins) => getDefaultRoleAssumerWithWebIdentity7(stsOptions, getCustomizableStsClientCtor4(STSClient4, stsPlugins)), "getDefaultRoleAssumerWithWebIdentity");
    decorateDefaultCredentialProvider4 = /* @__PURE__ */ __name((provider) => (input) => provider({
      roleAssumer: getDefaultRoleAssumer8(input),
      roleAssumerWithWebIdentity: getDefaultRoleAssumerWithWebIdentity8(input),
      ...input
    }), "decorateDefaultCredentialProvider");
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/index.js
var sts_exports4 = {};
__export(sts_exports4, {
  AssumeRole$: () => AssumeRole$4,
  AssumeRoleCommand: () => AssumeRoleCommand4,
  AssumeRoleRequest$: () => AssumeRoleRequest$4,
  AssumeRoleResponse$: () => AssumeRoleResponse$4,
  AssumeRoleWithWebIdentity$: () => AssumeRoleWithWebIdentity$4,
  AssumeRoleWithWebIdentityCommand: () => AssumeRoleWithWebIdentityCommand4,
  AssumeRoleWithWebIdentityRequest$: () => AssumeRoleWithWebIdentityRequest$4,
  AssumeRoleWithWebIdentityResponse$: () => AssumeRoleWithWebIdentityResponse$4,
  AssumedRoleUser$: () => AssumedRoleUser$4,
  Credentials$: () => Credentials$4,
  ExpiredTokenException: () => ExpiredTokenException6,
  ExpiredTokenException$: () => ExpiredTokenException$6,
  IDPCommunicationErrorException: () => IDPCommunicationErrorException4,
  IDPCommunicationErrorException$: () => IDPCommunicationErrorException$4,
  IDPRejectedClaimException: () => IDPRejectedClaimException4,
  IDPRejectedClaimException$: () => IDPRejectedClaimException$4,
  InvalidIdentityTokenException: () => InvalidIdentityTokenException4,
  InvalidIdentityTokenException$: () => InvalidIdentityTokenException$4,
  MalformedPolicyDocumentException: () => MalformedPolicyDocumentException4,
  MalformedPolicyDocumentException$: () => MalformedPolicyDocumentException$4,
  PackedPolicyTooLargeException: () => PackedPolicyTooLargeException4,
  PackedPolicyTooLargeException$: () => PackedPolicyTooLargeException$4,
  PolicyDescriptorType$: () => PolicyDescriptorType$4,
  ProvidedContext$: () => ProvidedContext$4,
  RegionDisabledException: () => RegionDisabledException4,
  RegionDisabledException$: () => RegionDisabledException$4,
  STS: () => STS4,
  STSClient: () => STSClient4,
  STSServiceException: () => STSServiceException4,
  STSServiceException$: () => STSServiceException$4,
  Tag$: () => Tag$4,
  __Client: () => import_smithy_client133.Client,
  decorateDefaultCredentialProvider: () => decorateDefaultCredentialProvider4,
  errorTypeRegistries: () => errorTypeRegistries14,
  getDefaultRoleAssumer: () => getDefaultRoleAssumer8,
  getDefaultRoleAssumerWithWebIdentity: () => getDefaultRoleAssumerWithWebIdentity8
});
var init_sts4 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/index.js"() {
    init_STSClient4();
    init_STS4();
    init_commands15();
    init_schemas_014();
    init_errors14();
    init_models_014();
    init_defaultRoleAssumers4();
    init_STSServiceException4();
  }
});

// ../../node_modules/@aws-sdk/credential-provider-process/dist-cjs/index.js
var require_dist_cjs119 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-process/dist-cjs/index.js"(exports2) {
    "use strict";
    var sharedIniFileLoader = require_dist_cjs28();
    var propertyProvider = require_dist_cjs27();
    var node_child_process = require("node:child_process");
    var node_util = require("node:util");
    var client = (init_client8(), __toCommonJS(client_exports7));
    var getValidatedProcessCredentials = /* @__PURE__ */ __name((profileName, data3, profiles) => {
      if (data3.Version !== 1) {
        throw Error(`Profile ${profileName} credential_process did not return Version 1.`);
      }
      if (data3.AccessKeyId === void 0 || data3.SecretAccessKey === void 0) {
        throw Error(`Profile ${profileName} credential_process returned invalid credentials.`);
      }
      if (data3.Expiration) {
        const currentTime = /* @__PURE__ */ new Date();
        const expireTime = new Date(data3.Expiration);
        if (expireTime < currentTime) {
          throw Error(`Profile ${profileName} credential_process returned expired credentials.`);
        }
      }
      let accountId = data3.AccountId;
      if (!accountId && profiles?.[profileName]?.aws_account_id) {
        accountId = profiles[profileName].aws_account_id;
      }
      const credentials = {
        accessKeyId: data3.AccessKeyId,
        secretAccessKey: data3.SecretAccessKey,
        ...data3.SessionToken && { sessionToken: data3.SessionToken },
        ...data3.Expiration && { expiration: new Date(data3.Expiration) },
        ...data3.CredentialScope && { credentialScope: data3.CredentialScope },
        ...accountId && { accountId }
      };
      client.setCredentialFeature(credentials, "CREDENTIALS_PROCESS", "w");
      return credentials;
    }, "getValidatedProcessCredentials");
    var resolveProcessCredentials = /* @__PURE__ */ __name(async (profileName, profiles, logger5) => {
      const profile = profiles[profileName];
      if (profiles[profileName]) {
        const credentialProcess = profile["credential_process"];
        if (credentialProcess !== void 0) {
          const execPromise = node_util.promisify(sharedIniFileLoader.externalDataInterceptor?.getTokenRecord?.().exec ?? node_child_process.exec);
          try {
            const { stdout } = await execPromise(credentialProcess);
            let data3;
            try {
              data3 = JSON.parse(stdout.trim());
            } catch {
              throw Error(`Profile ${profileName} credential_process returned invalid JSON.`);
            }
            return getValidatedProcessCredentials(profileName, data3, profiles);
          } catch (error4) {
            throw new propertyProvider.CredentialsProviderError(error4.message, { logger: logger5 });
          }
        } else {
          throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} did not contain credential_process.`, { logger: logger5 });
        }
      } else {
        throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} could not be found in shared credentials file.`, {
          logger: logger5
        });
      }
    }, "resolveProcessCredentials");
    var fromProcess = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/credential-provider-process - fromProcess");
      const profiles = await sharedIniFileLoader.parseKnownFiles(init);
      return resolveProcessCredentials(sharedIniFileLoader.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      }), profiles, init.logger);
    }, "fromProcess");
    exports2.fromProcess = fromProcess;
  }
});

// ../../node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromWebToken.js
var require_fromWebToken4 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromWebToken.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __setModuleDefault2 = exports2 && exports2.__setModuleDefault || (Object.create ? (function(o10, v) {
      Object.defineProperty(o10, "default", { enumerable: true, value: v });
    }) : function(o10, v) {
      o10["default"] = v;
    });
    var __importStar2 = exports2 && exports2.__importStar || /* @__PURE__ */ (function() {
      var ownKeys2 = /* @__PURE__ */ __name(function(o10) {
        ownKeys2 = Object.getOwnPropertyNames || function(o11) {
          var ar = [];
          for (var k32 in o11) if (Object.prototype.hasOwnProperty.call(o11, k32)) ar[ar.length] = k32;
          return ar;
        };
        return ownKeys2(o10);
      }, "ownKeys");
      return function(mod) {
        if (mod && mod.__esModule) return mod;
        var result2 = {};
        if (mod != null) {
          for (var k32 = ownKeys2(mod), i32 = 0; i32 < k32.length; i32++) if (k32[i32] !== "default") __createBinding3(result2, mod, k32[i32]);
        }
        __setModuleDefault2(result2, mod);
        return result2;
      };
    })();
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromWebToken = void 0;
    var fromWebToken = /* @__PURE__ */ __name((init) => async (awsIdentityProperties) => {
      init.logger?.debug("@aws-sdk/credential-provider-web-identity - fromWebToken");
      const { roleArn, roleSessionName, webIdentityToken, providerId, policyArns, policy, durationSeconds } = init;
      let { roleAssumerWithWebIdentity } = init;
      if (!roleAssumerWithWebIdentity) {
        const { getDefaultRoleAssumerWithWebIdentity: getDefaultRoleAssumerWithWebIdentity19 } = await Promise.resolve().then(() => __importStar2((init_sts4(), __toCommonJS(sts_exports4))));
        roleAssumerWithWebIdentity = getDefaultRoleAssumerWithWebIdentity19({
          ...init.clientConfig,
          credentialProviderLogger: init.logger,
          parentClientConfig: {
            ...awsIdentityProperties?.callerClientConfig,
            ...init.parentClientConfig
          }
        }, init.clientPlugins);
      }
      return roleAssumerWithWebIdentity({
        RoleArn: roleArn,
        RoleSessionName: roleSessionName ?? `aws-sdk-js-session-${Date.now()}`,
        WebIdentityToken: webIdentityToken,
        ProviderId: providerId,
        PolicyArns: policyArns,
        Policy: policy,
        DurationSeconds: durationSeconds
      });
    }, "fromWebToken");
    exports2.fromWebToken = fromWebToken;
  }
});

// ../../node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromTokenFile.js
var require_fromTokenFile4 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromTokenFile.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromTokenFile = void 0;
    var client_1 = (init_client8(), __toCommonJS(client_exports7));
    var property_provider_1 = require_dist_cjs27();
    var shared_ini_file_loader_1 = require_dist_cjs28();
    var node_fs_1 = require("node:fs");
    var fromWebToken_1 = require_fromWebToken4();
    var ENV_TOKEN_FILE = "AWS_WEB_IDENTITY_TOKEN_FILE";
    var ENV_ROLE_ARN = "AWS_ROLE_ARN";
    var ENV_ROLE_SESSION_NAME = "AWS_ROLE_SESSION_NAME";
    var fromTokenFile = /* @__PURE__ */ __name((init = {}) => async (awsIdentityProperties) => {
      init.logger?.debug("@aws-sdk/credential-provider-web-identity - fromTokenFile");
      const webIdentityTokenFile = init?.webIdentityTokenFile ?? process.env[ENV_TOKEN_FILE];
      const roleArn = init?.roleArn ?? process.env[ENV_ROLE_ARN];
      const roleSessionName = init?.roleSessionName ?? process.env[ENV_ROLE_SESSION_NAME];
      if (!webIdentityTokenFile || !roleArn) {
        throw new property_provider_1.CredentialsProviderError("Web identity configuration not specified", {
          logger: init.logger
        });
      }
      const credentials = await (0, fromWebToken_1.fromWebToken)({
        ...init,
        webIdentityToken: shared_ini_file_loader_1.externalDataInterceptor?.getTokenRecord?.()[webIdentityTokenFile] ?? (0, node_fs_1.readFileSync)(webIdentityTokenFile, { encoding: "ascii" }),
        roleArn,
        roleSessionName
      })(awsIdentityProperties);
      if (webIdentityTokenFile === process.env[ENV_TOKEN_FILE]) {
        (0, client_1.setCredentialFeature)(credentials, "CREDENTIALS_ENV_VARS_STS_WEB_ID_TOKEN", "h");
      }
      return credentials;
    }, "fromTokenFile");
    exports2.fromTokenFile = fromTokenFile;
  }
});

// ../../node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/index.js
var require_dist_cjs120 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/index.js"(exports2) {
    "use strict";
    var fromTokenFile = require_fromTokenFile4();
    var fromWebToken = require_fromWebToken4();
    Object.prototype.hasOwnProperty.call(fromTokenFile, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: fromTokenFile["__proto__"]
    });
    Object.keys(fromTokenFile).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = fromTokenFile[k32];
    });
    Object.prototype.hasOwnProperty.call(fromWebToken, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: fromWebToken["__proto__"]
    });
    Object.keys(fromWebToken).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = fromWebToken[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/credential-provider-ini/dist-cjs/index.js
var require_dist_cjs121 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-ini/dist-cjs/index.js"(exports2) {
    "use strict";
    var sharedIniFileLoader = require_dist_cjs28();
    var propertyProvider = require_dist_cjs27();
    var client = (init_client8(), __toCommonJS(client_exports7));
    var credentialProviderLogin = require_dist_cjs116();
    var resolveCredentialSource = /* @__PURE__ */ __name((credentialSource, profileName, logger5) => {
      const sourceProvidersMap = {
        EcsContainer: /* @__PURE__ */ __name(async (options) => {
          const { fromHttp } = await Promise.resolve().then(() => __toESM(require_dist_cjs112()));
          const { fromContainerMetadata } = await Promise.resolve().then(() => __toESM(require_dist_cjs38()));
          logger5?.debug("@aws-sdk/credential-provider-ini - credential_source is EcsContainer");
          return async () => propertyProvider.chain(fromHttp(options ?? {}), fromContainerMetadata(options))().then(setNamedProvider);
        }, "EcsContainer"),
        Ec2InstanceMetadata: /* @__PURE__ */ __name(async (options) => {
          logger5?.debug("@aws-sdk/credential-provider-ini - credential_source is Ec2InstanceMetadata");
          const { fromInstanceMetadata } = await Promise.resolve().then(() => __toESM(require_dist_cjs38()));
          return async () => fromInstanceMetadata(options)().then(setNamedProvider);
        }, "Ec2InstanceMetadata"),
        Environment: /* @__PURE__ */ __name(async (options) => {
          logger5?.debug("@aws-sdk/credential-provider-ini - credential_source is Environment");
          const { fromEnv: fromEnv6 } = await Promise.resolve().then(() => __toESM(require_dist_cjs110()));
          return async () => fromEnv6(options)().then(setNamedProvider);
        }, "Environment")
      };
      if (credentialSource in sourceProvidersMap) {
        return sourceProvidersMap[credentialSource];
      } else {
        throw new propertyProvider.CredentialsProviderError(`Unsupported credential source in profile ${profileName}. Got ${credentialSource}, expected EcsContainer or Ec2InstanceMetadata or Environment.`, { logger: logger5 });
      }
    }, "resolveCredentialSource");
    var setNamedProvider = /* @__PURE__ */ __name((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_NAMED_PROVIDER", "p"), "setNamedProvider");
    var isAssumeRoleProfile = /* @__PURE__ */ __name((arg, { profile = "default", logger: logger5 } = {}) => {
      return Boolean(arg) && typeof arg === "object" && typeof arg.role_arn === "string" && ["undefined", "string"].indexOf(typeof arg.role_session_name) > -1 && ["undefined", "string"].indexOf(typeof arg.external_id) > -1 && ["undefined", "string"].indexOf(typeof arg.mfa_serial) > -1 && (isAssumeRoleWithSourceProfile(arg, { profile, logger: logger5 }) || isCredentialSourceProfile(arg, { profile, logger: logger5 }));
    }, "isAssumeRoleProfile");
    var isAssumeRoleWithSourceProfile = /* @__PURE__ */ __name((arg, { profile, logger: logger5 }) => {
      const withSourceProfile = typeof arg.source_profile === "string" && typeof arg.credential_source === "undefined";
      if (withSourceProfile) {
        logger5?.debug?.(`    ${profile} isAssumeRoleWithSourceProfile source_profile=${arg.source_profile}`);
      }
      return withSourceProfile;
    }, "isAssumeRoleWithSourceProfile");
    var isCredentialSourceProfile = /* @__PURE__ */ __name((arg, { profile, logger: logger5 }) => {
      const withProviderProfile = typeof arg.credential_source === "string" && typeof arg.source_profile === "undefined";
      if (withProviderProfile) {
        logger5?.debug?.(`    ${profile} isCredentialSourceProfile credential_source=${arg.credential_source}`);
      }
      return withProviderProfile;
    }, "isCredentialSourceProfile");
    var resolveAssumeRoleCredentials = /* @__PURE__ */ __name(async (profileName, profiles, options, callerClientConfig, visitedProfiles = {}, resolveProfileData2) => {
      options.logger?.debug("@aws-sdk/credential-provider-ini - resolveAssumeRoleCredentials (STS)");
      const profileData = profiles[profileName];
      const { source_profile, region } = profileData;
      if (!options.roleAssumer) {
        const { getDefaultRoleAssumer: getDefaultRoleAssumer19 } = await Promise.resolve().then(() => (init_sts4(), sts_exports4));
        options.roleAssumer = getDefaultRoleAssumer19({
          ...options.clientConfig,
          credentialProviderLogger: options.logger,
          parentClientConfig: {
            ...callerClientConfig,
            ...options?.parentClientConfig,
            region: region ?? options?.parentClientConfig?.region ?? callerClientConfig?.region
          }
        }, options.clientPlugins);
      }
      if (source_profile && source_profile in visitedProfiles) {
        throw new propertyProvider.CredentialsProviderError(`Detected a cycle attempting to resolve credentials for profile ${sharedIniFileLoader.getProfileName(options)}. Profiles visited: ` + Object.keys(visitedProfiles).join(", "), { logger: options.logger });
      }
      options.logger?.debug(`@aws-sdk/credential-provider-ini - finding credential resolver using ${source_profile ? `source_profile=[${source_profile}]` : `profile=[${profileName}]`}`);
      const sourceCredsProvider = source_profile ? resolveProfileData2(source_profile, profiles, options, callerClientConfig, {
        ...visitedProfiles,
        [source_profile]: true
      }, isCredentialSourceWithoutRoleArn(profiles[source_profile] ?? {})) : (await resolveCredentialSource(profileData.credential_source, profileName, options.logger)(options))();
      if (isCredentialSourceWithoutRoleArn(profileData)) {
        return sourceCredsProvider.then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SOURCE_PROFILE", "o"));
      } else {
        const params = {
          RoleArn: profileData.role_arn,
          RoleSessionName: profileData.role_session_name || `aws-sdk-js-${Date.now()}`,
          ExternalId: profileData.external_id,
          DurationSeconds: parseInt(profileData.duration_seconds || "3600", 10)
        };
        const { mfa_serial } = profileData;
        if (mfa_serial) {
          if (!options.mfaCodeProvider) {
            throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} requires multi-factor authentication, but no MFA code callback was provided.`, { logger: options.logger, tryNextLink: false });
          }
          params.SerialNumber = mfa_serial;
          params.TokenCode = await options.mfaCodeProvider(mfa_serial);
        }
        const sourceCreds = await sourceCredsProvider;
        return options.roleAssumer(sourceCreds, params).then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SOURCE_PROFILE", "o"));
      }
    }, "resolveAssumeRoleCredentials");
    var isCredentialSourceWithoutRoleArn = /* @__PURE__ */ __name((section) => {
      return !section.role_arn && !!section.credential_source;
    }, "isCredentialSourceWithoutRoleArn");
    var isLoginProfile = /* @__PURE__ */ __name((data3) => {
      return Boolean(data3 && data3.login_session);
    }, "isLoginProfile");
    var resolveLoginCredentials = /* @__PURE__ */ __name(async (profileName, options, callerClientConfig) => {
      const credentials = await credentialProviderLogin.fromLoginCredentials({
        ...options,
        profile: profileName
      })({ callerClientConfig });
      return client.setCredentialFeature(credentials, "CREDENTIALS_PROFILE_LOGIN", "AC");
    }, "resolveLoginCredentials");
    var isProcessProfile = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.credential_process === "string", "isProcessProfile");
    var resolveProcessCredentials = /* @__PURE__ */ __name(async (options, profile) => Promise.resolve().then(() => __toESM(require_dist_cjs119())).then(({ fromProcess }) => fromProcess({
      ...options,
      profile
    })().then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_PROCESS", "v"))), "resolveProcessCredentials");
    var resolveSsoCredentials = /* @__PURE__ */ __name(async (profile, profileData, options = {}, callerClientConfig) => {
      const { fromSSO } = await Promise.resolve().then(() => __toESM(require_dist_cjs115()));
      return fromSSO({
        profile,
        logger: options.logger,
        parentClientConfig: options.parentClientConfig,
        clientConfig: options.clientConfig
      })({
        callerClientConfig
      }).then((creds) => {
        if (profileData.sso_session) {
          return client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SSO", "r");
        } else {
          return client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SSO_LEGACY", "t");
        }
      });
    }, "resolveSsoCredentials");
    var isSsoProfile = /* @__PURE__ */ __name((arg) => arg && (typeof arg.sso_start_url === "string" || typeof arg.sso_account_id === "string" || typeof arg.sso_session === "string" || typeof arg.sso_region === "string" || typeof arg.sso_role_name === "string"), "isSsoProfile");
    var isStaticCredsProfile = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.aws_access_key_id === "string" && typeof arg.aws_secret_access_key === "string" && ["undefined", "string"].indexOf(typeof arg.aws_session_token) > -1 && ["undefined", "string"].indexOf(typeof arg.aws_account_id) > -1, "isStaticCredsProfile");
    var resolveStaticCredentials = /* @__PURE__ */ __name(async (profile, options) => {
      options?.logger?.debug("@aws-sdk/credential-provider-ini - resolveStaticCredentials");
      const credentials = {
        accessKeyId: profile.aws_access_key_id,
        secretAccessKey: profile.aws_secret_access_key,
        sessionToken: profile.aws_session_token,
        ...profile.aws_credential_scope && { credentialScope: profile.aws_credential_scope },
        ...profile.aws_account_id && { accountId: profile.aws_account_id }
      };
      return client.setCredentialFeature(credentials, "CREDENTIALS_PROFILE", "n");
    }, "resolveStaticCredentials");
    var isWebIdentityProfile = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.web_identity_token_file === "string" && typeof arg.role_arn === "string" && ["undefined", "string"].indexOf(typeof arg.role_session_name) > -1, "isWebIdentityProfile");
    var resolveWebIdentityCredentials = /* @__PURE__ */ __name(async (profile, options, callerClientConfig) => Promise.resolve().then(() => __toESM(require_dist_cjs120())).then(({ fromTokenFile }) => fromTokenFile({
      webIdentityTokenFile: profile.web_identity_token_file,
      roleArn: profile.role_arn,
      roleSessionName: profile.role_session_name,
      roleAssumerWithWebIdentity: options.roleAssumerWithWebIdentity,
      logger: options.logger,
      parentClientConfig: options.parentClientConfig
    })({
      callerClientConfig
    }).then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_STS_WEB_ID_TOKEN", "q"))), "resolveWebIdentityCredentials");
    var resolveProfileData = /* @__PURE__ */ __name(async (profileName, profiles, options, callerClientConfig, visitedProfiles = {}, isAssumeRoleRecursiveCall = false) => {
      const data3 = profiles[profileName];
      if (Object.keys(visitedProfiles).length > 0 && isStaticCredsProfile(data3)) {
        return resolveStaticCredentials(data3, options);
      }
      if (isAssumeRoleRecursiveCall || isAssumeRoleProfile(data3, { profile: profileName, logger: options.logger })) {
        return resolveAssumeRoleCredentials(profileName, profiles, options, callerClientConfig, visitedProfiles, resolveProfileData);
      }
      if (isStaticCredsProfile(data3)) {
        return resolveStaticCredentials(data3, options);
      }
      if (isWebIdentityProfile(data3)) {
        return resolveWebIdentityCredentials(data3, options, callerClientConfig);
      }
      if (isProcessProfile(data3)) {
        return resolveProcessCredentials(options, profileName);
      }
      if (isSsoProfile(data3)) {
        return await resolveSsoCredentials(profileName, data3, options, callerClientConfig);
      }
      if (isLoginProfile(data3)) {
        return resolveLoginCredentials(profileName, options, callerClientConfig);
      }
      throw new propertyProvider.CredentialsProviderError(`Could not resolve credentials using profile: [${profileName}] in configuration/credentials file(s).`, { logger: options.logger });
    }, "resolveProfileData");
    var fromIni2 = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/credential-provider-ini - fromIni");
      const profiles = await sharedIniFileLoader.parseKnownFiles(init);
      return resolveProfileData(sharedIniFileLoader.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      }), profiles, init, callerClientConfig);
    }, "fromIni");
    exports2.fromIni = fromIni2;
  }
});

// ../../node_modules/@aws-sdk/credential-provider-node/dist-cjs/index.js
var require_dist_cjs122 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-node/dist-cjs/index.js"(exports2) {
    "use strict";
    var credentialProviderEnv = require_dist_cjs110();
    var propertyProvider = require_dist_cjs27();
    var sharedIniFileLoader = require_dist_cjs28();
    var ENV_IMDS_DISABLED3 = "AWS_EC2_METADATA_DISABLED";
    var remoteProvider = /* @__PURE__ */ __name(async (init) => {
      const { ENV_CMDS_FULL_URI, ENV_CMDS_RELATIVE_URI, fromContainerMetadata, fromInstanceMetadata } = await Promise.resolve().then(() => __toESM(require_dist_cjs38()));
      if (process.env[ENV_CMDS_RELATIVE_URI] || process.env[ENV_CMDS_FULL_URI]) {
        init.logger?.debug("@aws-sdk/credential-provider-node - remoteProvider::fromHttp/fromContainerMetadata");
        const { fromHttp } = await Promise.resolve().then(() => __toESM(require_dist_cjs112()));
        return propertyProvider.chain(fromHttp(init), fromContainerMetadata(init));
      }
      if (process.env[ENV_IMDS_DISABLED3] && process.env[ENV_IMDS_DISABLED3] !== "false") {
        return async () => {
          throw new propertyProvider.CredentialsProviderError("EC2 Instance Metadata Service access disabled", { logger: init.logger });
        };
      }
      init.logger?.debug("@aws-sdk/credential-provider-node - remoteProvider::fromInstanceMetadata");
      return fromInstanceMetadata(init);
    }, "remoteProvider");
    function memoizeChain(providers, treatAsExpired) {
      const chain5 = internalCreateChain(providers);
      let activeLock;
      let passiveLock;
      let credentials;
      const provider = /* @__PURE__ */ __name(async (options) => {
        if (options?.forceRefresh) {
          return await chain5(options);
        }
        if (credentials?.expiration) {
          if (credentials?.expiration?.getTime() < Date.now()) {
            credentials = void 0;
          }
        }
        if (activeLock) {
          await activeLock;
        } else if (!credentials || treatAsExpired?.(credentials)) {
          if (credentials) {
            if (!passiveLock) {
              passiveLock = chain5(options).then((c32) => {
                credentials = c32;
              }).finally(() => {
                passiveLock = void 0;
              });
            }
          } else {
            activeLock = chain5(options).then((c32) => {
              credentials = c32;
            }).finally(() => {
              activeLock = void 0;
            });
            return provider(options);
          }
        }
        return credentials;
      }, "provider");
      return provider;
    }
    __name(memoizeChain, "memoizeChain");
    var internalCreateChain = /* @__PURE__ */ __name((providers) => async (awsIdentityProperties) => {
      let lastProviderError;
      for (const provider of providers) {
        try {
          return await provider(awsIdentityProperties);
        } catch (err) {
          lastProviderError = err;
          if (err?.tryNextLink) {
            continue;
          }
          throw err;
        }
      }
      throw lastProviderError;
    }, "internalCreateChain");
    var multipleCredentialSourceWarningEmitted = false;
    var defaultProvider = /* @__PURE__ */ __name((init = {}) => memoizeChain([
      async () => {
        const profile = init.profile ?? process.env[sharedIniFileLoader.ENV_PROFILE];
        if (profile) {
          const envStaticCredentialsAreSet = process.env[credentialProviderEnv.ENV_KEY] && process.env[credentialProviderEnv.ENV_SECRET];
          if (envStaticCredentialsAreSet) {
            if (!multipleCredentialSourceWarningEmitted) {
              const warnFn = init.logger?.warn && init.logger?.constructor?.name !== "NoOpLogger" ? init.logger.warn.bind(init.logger) : console.warn;
              warnFn(`@aws-sdk/credential-provider-node - defaultProvider::fromEnv WARNING:
    Multiple credential sources detected: 
    Both AWS_PROFILE and the pair AWS_ACCESS_KEY_ID/AWS_SECRET_ACCESS_KEY static credentials are set.
    This SDK will proceed with the AWS_PROFILE value.
    
    However, a future version may change this behavior to prefer the ENV static credentials.
    Please ensure that your environment only sets either the AWS_PROFILE or the
    AWS_ACCESS_KEY_ID/AWS_SECRET_ACCESS_KEY pair.
`);
              multipleCredentialSourceWarningEmitted = true;
            }
          }
          throw new propertyProvider.CredentialsProviderError("AWS_PROFILE is set, skipping fromEnv provider.", {
            logger: init.logger,
            tryNextLink: true
          });
        }
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromEnv");
        return credentialProviderEnv.fromEnv(init)();
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromSSO");
        const { ssoStartUrl, ssoAccountId, ssoRegion, ssoRoleName, ssoSession } = init;
        if (!ssoStartUrl && !ssoAccountId && !ssoRegion && !ssoRoleName && !ssoSession) {
          throw new propertyProvider.CredentialsProviderError("Skipping SSO provider in default chain (inputs do not include SSO fields).", { logger: init.logger });
        }
        const { fromSSO } = await Promise.resolve().then(() => __toESM(require_dist_cjs115()));
        return fromSSO(init)(awsIdentityProperties);
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromIni");
        const { fromIni: fromIni2 } = await Promise.resolve().then(() => __toESM(require_dist_cjs121()));
        return fromIni2(init)(awsIdentityProperties);
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromProcess");
        const { fromProcess } = await Promise.resolve().then(() => __toESM(require_dist_cjs119()));
        return fromProcess(init)(awsIdentityProperties);
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromTokenFile");
        const { fromTokenFile } = await Promise.resolve().then(() => __toESM(require_dist_cjs120()));
        return fromTokenFile(init)(awsIdentityProperties);
      },
      async () => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::remoteProvider");
        return (await remoteProvider(init))();
      },
      async () => {
        throw new propertyProvider.CredentialsProviderError("Could not load credentials from any providers", {
          tryNextLink: false,
          logger: init.logger
        });
      }
    ], credentialsTreatedAsExpired), "defaultProvider");
    var credentialsWillNeedRefresh = /* @__PURE__ */ __name((credentials) => credentials?.expiration !== void 0, "credentialsWillNeedRefresh");
    var credentialsTreatedAsExpired = /* @__PURE__ */ __name((credentials) => credentials?.expiration !== void 0 && credentials.expiration.getTime() - Date.now() < 3e5, "credentialsTreatedAsExpired");
    exports2.credentialsTreatedAsExpired = credentialsTreatedAsExpired;
    exports2.credentialsWillNeedRefresh = credentialsWillNeedRefresh;
    exports2.defaultProvider = defaultProvider;
  }
});

// ../../node_modules/@aws-sdk/client-sts/dist-cjs/models/STSServiceException.js
var require_STSServiceException = __commonJS({
  "../../node_modules/@aws-sdk/client-sts/dist-cjs/models/STSServiceException.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.STSServiceException = exports2.__ServiceException = void 0;
    var smithy_client_1 = require_dist_cjs34();
    Object.defineProperty(exports2, "__ServiceException", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return smithy_client_1.ServiceException;
    }, "get") });
    var STSServiceException10 = class _STSServiceException extends smithy_client_1.ServiceException {
      static {
        __name(this, "STSServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _STSServiceException.prototype);
      }
    };
    exports2.STSServiceException = STSServiceException10;
  }
});

// ../../node_modules/@aws-sdk/client-sts/dist-cjs/models/errors.js
var require_errors4 = __commonJS({
  "../../node_modules/@aws-sdk/client-sts/dist-cjs/models/errors.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.SessionDurationEscalationException = exports2.OutboundWebIdentityFederationDisabledException = exports2.JWTPayloadSizeExceededException = exports2.ExpiredTradeInTokenException = exports2.InvalidAuthorizationMessageException = exports2.IDPCommunicationErrorException = exports2.InvalidIdentityTokenException = exports2.IDPRejectedClaimException = exports2.RegionDisabledException = exports2.PackedPolicyTooLargeException = exports2.MalformedPolicyDocumentException = exports2.ExpiredTokenException = void 0;
    var STSServiceException_1 = require_STSServiceException();
    var ExpiredTokenException13 = class _ExpiredTokenException extends STSServiceException_1.STSServiceException {
      static {
        __name(this, "ExpiredTokenException");
      }
      name = "ExpiredTokenException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ExpiredTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ExpiredTokenException.prototype);
      }
    };
    exports2.ExpiredTokenException = ExpiredTokenException13;
    var MalformedPolicyDocumentException10 = class _MalformedPolicyDocumentException extends STSServiceException_1.STSServiceException {
      static {
        __name(this, "MalformedPolicyDocumentException");
      }
      name = "MalformedPolicyDocumentException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "MalformedPolicyDocumentException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _MalformedPolicyDocumentException.prototype);
      }
    };
    exports2.MalformedPolicyDocumentException = MalformedPolicyDocumentException10;
    var PackedPolicyTooLargeException10 = class _PackedPolicyTooLargeException extends STSServiceException_1.STSServiceException {
      static {
        __name(this, "PackedPolicyTooLargeException");
      }
      name = "PackedPolicyTooLargeException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "PackedPolicyTooLargeException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _PackedPolicyTooLargeException.prototype);
      }
    };
    exports2.PackedPolicyTooLargeException = PackedPolicyTooLargeException10;
    var RegionDisabledException10 = class _RegionDisabledException extends STSServiceException_1.STSServiceException {
      static {
        __name(this, "RegionDisabledException");
      }
      name = "RegionDisabledException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "RegionDisabledException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _RegionDisabledException.prototype);
      }
    };
    exports2.RegionDisabledException = RegionDisabledException10;
    var IDPRejectedClaimException10 = class _IDPRejectedClaimException extends STSServiceException_1.STSServiceException {
      static {
        __name(this, "IDPRejectedClaimException");
      }
      name = "IDPRejectedClaimException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "IDPRejectedClaimException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _IDPRejectedClaimException.prototype);
      }
    };
    exports2.IDPRejectedClaimException = IDPRejectedClaimException10;
    var InvalidIdentityTokenException10 = class _InvalidIdentityTokenException extends STSServiceException_1.STSServiceException {
      static {
        __name(this, "InvalidIdentityTokenException");
      }
      name = "InvalidIdentityTokenException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidIdentityTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidIdentityTokenException.prototype);
      }
    };
    exports2.InvalidIdentityTokenException = InvalidIdentityTokenException10;
    var IDPCommunicationErrorException10 = class _IDPCommunicationErrorException extends STSServiceException_1.STSServiceException {
      static {
        __name(this, "IDPCommunicationErrorException");
      }
      name = "IDPCommunicationErrorException";
      $fault = "client";
      $retryable = {};
      constructor(opts) {
        super({
          name: "IDPCommunicationErrorException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _IDPCommunicationErrorException.prototype);
      }
    };
    exports2.IDPCommunicationErrorException = IDPCommunicationErrorException10;
    var InvalidAuthorizationMessageException = class _InvalidAuthorizationMessageException extends STSServiceException_1.STSServiceException {
      static {
        __name(this, "InvalidAuthorizationMessageException");
      }
      name = "InvalidAuthorizationMessageException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidAuthorizationMessageException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidAuthorizationMessageException.prototype);
      }
    };
    exports2.InvalidAuthorizationMessageException = InvalidAuthorizationMessageException;
    var ExpiredTradeInTokenException = class _ExpiredTradeInTokenException extends STSServiceException_1.STSServiceException {
      static {
        __name(this, "ExpiredTradeInTokenException");
      }
      name = "ExpiredTradeInTokenException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ExpiredTradeInTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ExpiredTradeInTokenException.prototype);
      }
    };
    exports2.ExpiredTradeInTokenException = ExpiredTradeInTokenException;
    var JWTPayloadSizeExceededException = class _JWTPayloadSizeExceededException extends STSServiceException_1.STSServiceException {
      static {
        __name(this, "JWTPayloadSizeExceededException");
      }
      name = "JWTPayloadSizeExceededException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "JWTPayloadSizeExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _JWTPayloadSizeExceededException.prototype);
      }
    };
    exports2.JWTPayloadSizeExceededException = JWTPayloadSizeExceededException;
    var OutboundWebIdentityFederationDisabledException = class _OutboundWebIdentityFederationDisabledException extends STSServiceException_1.STSServiceException {
      static {
        __name(this, "OutboundWebIdentityFederationDisabledException");
      }
      name = "OutboundWebIdentityFederationDisabledException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "OutboundWebIdentityFederationDisabledException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _OutboundWebIdentityFederationDisabledException.prototype);
      }
    };
    exports2.OutboundWebIdentityFederationDisabledException = OutboundWebIdentityFederationDisabledException;
    var SessionDurationEscalationException = class _SessionDurationEscalationException extends STSServiceException_1.STSServiceException {
      static {
        __name(this, "SessionDurationEscalationException");
      }
      name = "SessionDurationEscalationException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "SessionDurationEscalationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _SessionDurationEscalationException.prototype);
      }
    };
    exports2.SessionDurationEscalationException = SessionDurationEscalationException;
  }
});

// ../../node_modules/@aws-sdk/client-sts/dist-cjs/schemas/schemas_0.js
var require_schemas_04 = __commonJS({
  "../../node_modules/@aws-sdk/client-sts/dist-cjs/schemas/schemas_0.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.GetDelegatedAccessToken$ = exports2.GetCallerIdentity$ = exports2.GetAccessKeyInfo$ = exports2.DecodeAuthorizationMessage$ = exports2.AssumeRoot$ = exports2.AssumeRoleWithWebIdentity$ = exports2.AssumeRoleWithSAML$ = exports2.AssumeRole$ = exports2.Tag$ = exports2.ProvidedContext$ = exports2.PolicyDescriptorType$ = exports2.GetWebIdentityTokenResponse$ = exports2.GetWebIdentityTokenRequest$ = exports2.GetSessionTokenResponse$ = exports2.GetSessionTokenRequest$ = exports2.GetFederationTokenResponse$ = exports2.GetFederationTokenRequest$ = exports2.GetDelegatedAccessTokenResponse$ = exports2.GetDelegatedAccessTokenRequest$ = exports2.GetCallerIdentityResponse$ = exports2.GetCallerIdentityRequest$ = exports2.GetAccessKeyInfoResponse$ = exports2.GetAccessKeyInfoRequest$ = exports2.FederatedUser$ = exports2.DecodeAuthorizationMessageResponse$ = exports2.DecodeAuthorizationMessageRequest$ = exports2.Credentials$ = exports2.AssumeRootResponse$ = exports2.AssumeRootRequest$ = exports2.AssumeRoleWithWebIdentityResponse$ = exports2.AssumeRoleWithWebIdentityRequest$ = exports2.AssumeRoleWithSAMLResponse$ = exports2.AssumeRoleWithSAMLRequest$ = exports2.AssumeRoleResponse$ = exports2.AssumeRoleRequest$ = exports2.AssumedRoleUser$ = exports2.errorTypeRegistries = exports2.SessionDurationEscalationException$ = exports2.RegionDisabledException$ = exports2.PackedPolicyTooLargeException$ = exports2.OutboundWebIdentityFederationDisabledException$ = exports2.MalformedPolicyDocumentException$ = exports2.JWTPayloadSizeExceededException$ = exports2.InvalidIdentityTokenException$ = exports2.InvalidAuthorizationMessageException$ = exports2.IDPRejectedClaimException$ = exports2.IDPCommunicationErrorException$ = exports2.ExpiredTradeInTokenException$ = exports2.ExpiredTokenException$ = exports2.STSServiceException$ = void 0;
    exports2.GetWebIdentityToken$ = exports2.GetSessionToken$ = exports2.GetFederationToken$ = void 0;
    var _A10 = "Arn";
    var _AKI11 = "AccessKeyId";
    var _AP = "AssumedPrincipal";
    var _AR10 = "AssumeRole";
    var _ARI10 = "AssumedRoleId";
    var _ARR10 = "AssumeRoleRequest";
    var _ARRs10 = "AssumeRoleResponse";
    var _ARRss = "AssumeRootRequest";
    var _ARRssu = "AssumeRootResponse";
    var _ARU10 = "AssumedRoleUser";
    var _ARWSAML = "AssumeRoleWithSAML";
    var _ARWSAMLR = "AssumeRoleWithSAMLRequest";
    var _ARWSAMLRs = "AssumeRoleWithSAMLResponse";
    var _ARWWI10 = "AssumeRoleWithWebIdentity";
    var _ARWWIR10 = "AssumeRoleWithWebIdentityRequest";
    var _ARWWIRs10 = "AssumeRoleWithWebIdentityResponse";
    var _ARs = "AssumeRoot";
    var _Ac = "Account";
    var _Au10 = "Audience";
    var _C11 = "Credentials";
    var _CA10 = "ContextAssertion";
    var _DAM = "DecodeAuthorizationMessage";
    var _DAMR = "DecodeAuthorizationMessageRequest";
    var _DAMRe = "DecodeAuthorizationMessageResponse";
    var _DM = "DecodedMessage";
    var _DS10 = "DurationSeconds";
    var _E11 = "Expiration";
    var _EI10 = "ExternalId";
    var _EM = "EncodedMessage";
    var _ETE13 = "ExpiredTokenException";
    var _ETITE = "ExpiredTradeInTokenException";
    var _FU = "FederatedUser";
    var _FUI = "FederatedUserId";
    var _GAKI = "GetAccessKeyInfo";
    var _GAKIR = "GetAccessKeyInfoRequest";
    var _GAKIRe = "GetAccessKeyInfoResponse";
    var _GCI = "GetCallerIdentity";
    var _GCIR = "GetCallerIdentityRequest";
    var _GCIRe = "GetCallerIdentityResponse";
    var _GDAT = "GetDelegatedAccessToken";
    var _GDATR = "GetDelegatedAccessTokenRequest";
    var _GDATRe = "GetDelegatedAccessTokenResponse";
    var _GFT = "GetFederationToken";
    var _GFTR = "GetFederationTokenRequest";
    var _GFTRe = "GetFederationTokenResponse";
    var _GST = "GetSessionToken";
    var _GSTR = "GetSessionTokenRequest";
    var _GSTRe = "GetSessionTokenResponse";
    var _GWIT = "GetWebIdentityToken";
    var _GWITR = "GetWebIdentityTokenRequest";
    var _GWITRe = "GetWebIdentityTokenResponse";
    var _I = "Issuer";
    var _IAME = "InvalidAuthorizationMessageException";
    var _IDPCEE10 = "IDPCommunicationErrorException";
    var _IDPRCE10 = "IDPRejectedClaimException";
    var _IITE10 = "InvalidIdentityTokenException";
    var _JWTPSEE = "JWTPayloadSizeExceededException";
    var _K10 = "Key";
    var _MPDE10 = "MalformedPolicyDocumentException";
    var _N = "Name";
    var _NQ = "NameQualifier";
    var _OWIFDE = "OutboundWebIdentityFederationDisabledException";
    var _P10 = "Policy";
    var _PA10 = "PolicyArns";
    var _PAr10 = "PrincipalArn";
    var _PAro = "ProviderArn";
    var _PC10 = "ProvidedContexts";
    var _PCLT10 = "ProvidedContextsListType";
    var _PCr10 = "ProvidedContext";
    var _PDT10 = "PolicyDescriptorType";
    var _PI10 = "ProviderId";
    var _PPS10 = "PackedPolicySize";
    var _PPTLE10 = "PackedPolicyTooLargeException";
    var _Pr10 = "Provider";
    var _RA10 = "RoleArn";
    var _RDE10 = "RegionDisabledException";
    var _RSN10 = "RoleSessionName";
    var _S = "Subject";
    var _SA = "SigningAlgorithm";
    var _SAK10 = "SecretAccessKey";
    var _SAMLA = "SAMLAssertion";
    var _SAMLAT = "SAMLAssertionType";
    var _SDEE = "SessionDurationEscalationException";
    var _SFWIT10 = "SubjectFromWebIdentityToken";
    var _SI10 = "SourceIdentity";
    var _SN10 = "SerialNumber";
    var _ST11 = "SubjectType";
    var _STe = "SessionToken";
    var _T10 = "Tags";
    var _TC10 = "TokenCode";
    var _TIT = "TradeInToken";
    var _TP = "TargetPrincipal";
    var _TPA = "TaskPolicyArn";
    var _TTK10 = "TransitiveTagKeys";
    var _Ta10 = "Tag";
    var _UI = "UserId";
    var _V10 = "Value";
    var _WIT10 = "WebIdentityToken";
    var _a10 = "arn";
    var _aKST10 = "accessKeySecretType";
    var _aQE10 = "awsQueryError";
    var _c32 = "client";
    var _cTT10 = "clientTokenType";
    var _e32 = "error";
    var _hE32 = "httpError";
    var _m29 = "message";
    var _pDLT10 = "policyDescriptorListType";
    var _s32 = "smithy.ts.sdk.synthetic.com.amazonaws.sts";
    var _tITT = "tradeInTokenType";
    var _tLT10 = "tagListType";
    var _wITT = "webIdentityTokenType";
    var n032 = "com.amazonaws.sts";
    var schema_1 = (init_schema4(), __toCommonJS(schema_exports));
    var errors_1 = require_errors4();
    var STSServiceException_1 = require_STSServiceException();
    var _s_registry32 = schema_1.TypeRegistry.for(_s32);
    exports2.STSServiceException$ = [-3, _s32, "STSServiceException", 0, [], []];
    _s_registry32.registerError(exports2.STSServiceException$, STSServiceException_1.STSServiceException);
    var n0_registry32 = schema_1.TypeRegistry.for(n032);
    exports2.ExpiredTokenException$ = [
      -3,
      n032,
      _ETE13,
      { [_aQE10]: [`ExpiredTokenException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ExpiredTokenException$, errors_1.ExpiredTokenException);
    exports2.ExpiredTradeInTokenException$ = [
      -3,
      n032,
      _ETITE,
      { [_aQE10]: [`ExpiredTradeInTokenException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ExpiredTradeInTokenException$, errors_1.ExpiredTradeInTokenException);
    exports2.IDPCommunicationErrorException$ = [
      -3,
      n032,
      _IDPCEE10,
      { [_aQE10]: [`IDPCommunicationError`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.IDPCommunicationErrorException$, errors_1.IDPCommunicationErrorException);
    exports2.IDPRejectedClaimException$ = [
      -3,
      n032,
      _IDPRCE10,
      { [_aQE10]: [`IDPRejectedClaim`, 403], [_e32]: _c32, [_hE32]: 403 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.IDPRejectedClaimException$, errors_1.IDPRejectedClaimException);
    exports2.InvalidAuthorizationMessageException$ = [
      -3,
      n032,
      _IAME,
      { [_aQE10]: [`InvalidAuthorizationMessageException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidAuthorizationMessageException$, errors_1.InvalidAuthorizationMessageException);
    exports2.InvalidIdentityTokenException$ = [
      -3,
      n032,
      _IITE10,
      { [_aQE10]: [`InvalidIdentityToken`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidIdentityTokenException$, errors_1.InvalidIdentityTokenException);
    exports2.JWTPayloadSizeExceededException$ = [
      -3,
      n032,
      _JWTPSEE,
      { [_aQE10]: [`JWTPayloadSizeExceededException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.JWTPayloadSizeExceededException$, errors_1.JWTPayloadSizeExceededException);
    exports2.MalformedPolicyDocumentException$ = [
      -3,
      n032,
      _MPDE10,
      { [_aQE10]: [`MalformedPolicyDocument`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.MalformedPolicyDocumentException$, errors_1.MalformedPolicyDocumentException);
    exports2.OutboundWebIdentityFederationDisabledException$ = [
      -3,
      n032,
      _OWIFDE,
      { [_aQE10]: [`OutboundWebIdentityFederationDisabledException`, 403], [_e32]: _c32, [_hE32]: 403 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.OutboundWebIdentityFederationDisabledException$, errors_1.OutboundWebIdentityFederationDisabledException);
    exports2.PackedPolicyTooLargeException$ = [
      -3,
      n032,
      _PPTLE10,
      { [_aQE10]: [`PackedPolicyTooLarge`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.PackedPolicyTooLargeException$, errors_1.PackedPolicyTooLargeException);
    exports2.RegionDisabledException$ = [
      -3,
      n032,
      _RDE10,
      { [_aQE10]: [`RegionDisabledException`, 403], [_e32]: _c32, [_hE32]: 403 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.RegionDisabledException$, errors_1.RegionDisabledException);
    exports2.SessionDurationEscalationException$ = [
      -3,
      n032,
      _SDEE,
      { [_aQE10]: [`SessionDurationEscalationException`, 403], [_e32]: _c32, [_hE32]: 403 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.SessionDurationEscalationException$, errors_1.SessionDurationEscalationException);
    exports2.errorTypeRegistries = [
      _s_registry32,
      n0_registry32
    ];
    var accessKeySecretType10 = [0, n032, _aKST10, 8, 0];
    var clientTokenType10 = [0, n032, _cTT10, 8, 0];
    var SAMLAssertionType = [0, n032, _SAMLAT, 8, 0];
    var tradeInTokenType = [0, n032, _tITT, 8, 0];
    var webIdentityTokenType = [0, n032, _wITT, 8, 0];
    exports2.AssumedRoleUser$ = [
      3,
      n032,
      _ARU10,
      0,
      [_ARI10, _A10],
      [0, 0],
      2
    ];
    exports2.AssumeRoleRequest$ = [
      3,
      n032,
      _ARR10,
      0,
      [_RA10, _RSN10, _PA10, _P10, _DS10, _T10, _TTK10, _EI10, _SN10, _TC10, _SI10, _PC10],
      [0, 0, () => policyDescriptorListType10, 0, 1, () => tagListType10, 64 | 0, 0, 0, 0, 0, () => ProvidedContextsListType10],
      2
    ];
    exports2.AssumeRoleResponse$ = [
      3,
      n032,
      _ARRs10,
      0,
      [_C11, _ARU10, _PPS10, _SI10],
      [[() => exports2.Credentials$, 0], () => exports2.AssumedRoleUser$, 1, 0]
    ];
    exports2.AssumeRoleWithSAMLRequest$ = [
      3,
      n032,
      _ARWSAMLR,
      0,
      [_RA10, _PAr10, _SAMLA, _PA10, _P10, _DS10],
      [0, 0, [() => SAMLAssertionType, 0], () => policyDescriptorListType10, 0, 1],
      3
    ];
    exports2.AssumeRoleWithSAMLResponse$ = [
      3,
      n032,
      _ARWSAMLRs,
      0,
      [_C11, _ARU10, _PPS10, _S, _ST11, _I, _Au10, _NQ, _SI10],
      [[() => exports2.Credentials$, 0], () => exports2.AssumedRoleUser$, 1, 0, 0, 0, 0, 0, 0]
    ];
    exports2.AssumeRoleWithWebIdentityRequest$ = [
      3,
      n032,
      _ARWWIR10,
      0,
      [_RA10, _RSN10, _WIT10, _PI10, _PA10, _P10, _DS10],
      [0, 0, [() => clientTokenType10, 0], 0, () => policyDescriptorListType10, 0, 1],
      3
    ];
    exports2.AssumeRoleWithWebIdentityResponse$ = [
      3,
      n032,
      _ARWWIRs10,
      0,
      [_C11, _SFWIT10, _ARU10, _PPS10, _Pr10, _Au10, _SI10],
      [[() => exports2.Credentials$, 0], 0, () => exports2.AssumedRoleUser$, 1, 0, 0, 0]
    ];
    exports2.AssumeRootRequest$ = [
      3,
      n032,
      _ARRss,
      0,
      [_TP, _TPA, _DS10],
      [0, () => exports2.PolicyDescriptorType$, 1],
      2
    ];
    exports2.AssumeRootResponse$ = [
      3,
      n032,
      _ARRssu,
      0,
      [_C11, _SI10],
      [[() => exports2.Credentials$, 0], 0]
    ];
    exports2.Credentials$ = [
      3,
      n032,
      _C11,
      0,
      [_AKI11, _SAK10, _STe, _E11],
      [0, [() => accessKeySecretType10, 0], 0, 4],
      4
    ];
    exports2.DecodeAuthorizationMessageRequest$ = [
      3,
      n032,
      _DAMR,
      0,
      [_EM],
      [0],
      1
    ];
    exports2.DecodeAuthorizationMessageResponse$ = [
      3,
      n032,
      _DAMRe,
      0,
      [_DM],
      [0]
    ];
    exports2.FederatedUser$ = [
      3,
      n032,
      _FU,
      0,
      [_FUI, _A10],
      [0, 0],
      2
    ];
    exports2.GetAccessKeyInfoRequest$ = [
      3,
      n032,
      _GAKIR,
      0,
      [_AKI11],
      [0],
      1
    ];
    exports2.GetAccessKeyInfoResponse$ = [
      3,
      n032,
      _GAKIRe,
      0,
      [_Ac],
      [0]
    ];
    exports2.GetCallerIdentityRequest$ = [
      3,
      n032,
      _GCIR,
      0,
      [],
      []
    ];
    exports2.GetCallerIdentityResponse$ = [
      3,
      n032,
      _GCIRe,
      0,
      [_UI, _Ac, _A10],
      [0, 0, 0]
    ];
    exports2.GetDelegatedAccessTokenRequest$ = [
      3,
      n032,
      _GDATR,
      0,
      [_TIT],
      [[() => tradeInTokenType, 0]],
      1
    ];
    exports2.GetDelegatedAccessTokenResponse$ = [
      3,
      n032,
      _GDATRe,
      0,
      [_C11, _PPS10, _AP],
      [[() => exports2.Credentials$, 0], 1, 0]
    ];
    exports2.GetFederationTokenRequest$ = [
      3,
      n032,
      _GFTR,
      0,
      [_N, _P10, _PA10, _DS10, _T10],
      [0, 0, () => policyDescriptorListType10, 1, () => tagListType10],
      1
    ];
    exports2.GetFederationTokenResponse$ = [
      3,
      n032,
      _GFTRe,
      0,
      [_C11, _FU, _PPS10],
      [[() => exports2.Credentials$, 0], () => exports2.FederatedUser$, 1]
    ];
    exports2.GetSessionTokenRequest$ = [
      3,
      n032,
      _GSTR,
      0,
      [_DS10, _SN10, _TC10],
      [1, 0, 0]
    ];
    exports2.GetSessionTokenResponse$ = [
      3,
      n032,
      _GSTRe,
      0,
      [_C11],
      [[() => exports2.Credentials$, 0]]
    ];
    exports2.GetWebIdentityTokenRequest$ = [
      3,
      n032,
      _GWITR,
      0,
      [_Au10, _SA, _DS10, _T10],
      [64 | 0, 0, 1, () => tagListType10],
      2
    ];
    exports2.GetWebIdentityTokenResponse$ = [
      3,
      n032,
      _GWITRe,
      0,
      [_WIT10, _E11],
      [[() => webIdentityTokenType, 0], 4]
    ];
    exports2.PolicyDescriptorType$ = [
      3,
      n032,
      _PDT10,
      0,
      [_a10],
      [0]
    ];
    exports2.ProvidedContext$ = [
      3,
      n032,
      _PCr10,
      0,
      [_PAro, _CA10],
      [0, 0]
    ];
    exports2.Tag$ = [
      3,
      n032,
      _Ta10,
      0,
      [_K10, _V10],
      [0, 0],
      2
    ];
    var policyDescriptorListType10 = [
      1,
      n032,
      _pDLT10,
      0,
      () => exports2.PolicyDescriptorType$
    ];
    var ProvidedContextsListType10 = [
      1,
      n032,
      _PCLT10,
      0,
      () => exports2.ProvidedContext$
    ];
    var tagKeyListType10 = 64 | 0;
    var tagListType10 = [
      1,
      n032,
      _tLT10,
      0,
      () => exports2.Tag$
    ];
    var webIdentityTokenAudienceListType = 64 | 0;
    exports2.AssumeRole$ = [
      9,
      n032,
      _AR10,
      0,
      () => exports2.AssumeRoleRequest$,
      () => exports2.AssumeRoleResponse$
    ];
    exports2.AssumeRoleWithSAML$ = [
      9,
      n032,
      _ARWSAML,
      0,
      () => exports2.AssumeRoleWithSAMLRequest$,
      () => exports2.AssumeRoleWithSAMLResponse$
    ];
    exports2.AssumeRoleWithWebIdentity$ = [
      9,
      n032,
      _ARWWI10,
      0,
      () => exports2.AssumeRoleWithWebIdentityRequest$,
      () => exports2.AssumeRoleWithWebIdentityResponse$
    ];
    exports2.AssumeRoot$ = [
      9,
      n032,
      _ARs,
      0,
      () => exports2.AssumeRootRequest$,
      () => exports2.AssumeRootResponse$
    ];
    exports2.DecodeAuthorizationMessage$ = [
      9,
      n032,
      _DAM,
      0,
      () => exports2.DecodeAuthorizationMessageRequest$,
      () => exports2.DecodeAuthorizationMessageResponse$
    ];
    exports2.GetAccessKeyInfo$ = [
      9,
      n032,
      _GAKI,
      0,
      () => exports2.GetAccessKeyInfoRequest$,
      () => exports2.GetAccessKeyInfoResponse$
    ];
    exports2.GetCallerIdentity$ = [
      9,
      n032,
      _GCI,
      0,
      () => exports2.GetCallerIdentityRequest$,
      () => exports2.GetCallerIdentityResponse$
    ];
    exports2.GetDelegatedAccessToken$ = [
      9,
      n032,
      _GDAT,
      0,
      () => exports2.GetDelegatedAccessTokenRequest$,
      () => exports2.GetDelegatedAccessTokenResponse$
    ];
    exports2.GetFederationToken$ = [
      9,
      n032,
      _GFT,
      0,
      () => exports2.GetFederationTokenRequest$,
      () => exports2.GetFederationTokenResponse$
    ];
    exports2.GetSessionToken$ = [
      9,
      n032,
      _GST,
      0,
      () => exports2.GetSessionTokenRequest$,
      () => exports2.GetSessionTokenResponse$
    ];
    exports2.GetWebIdentityToken$ = [
      9,
      n032,
      _GWIT,
      0,
      () => exports2.GetWebIdentityTokenRequest$,
      () => exports2.GetWebIdentityTokenResponse$
    ];
  }
});

// ../../node_modules/@aws-sdk/client-sts/dist-cjs/runtimeConfig.shared.js
var require_runtimeConfig_shared4 = __commonJS({
  "../../node_modules/@aws-sdk/client-sts/dist-cjs/runtimeConfig.shared.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var protocols_1 = (init_protocols8(), __toCommonJS(protocols_exports5));
    var signature_v4_multi_region_1 = require_dist_cjs109();
    var core_1 = (init_dist_es(), __toCommonJS(dist_es_exports));
    var smithy_client_1 = require_dist_cjs34();
    var url_parser_1 = require_dist_cjs18();
    var util_base64_1 = require_dist_cjs10();
    var util_utf8_1 = require_dist_cjs9();
    var httpAuthSchemeProvider_1 = require_httpAuthSchemeProvider4();
    var endpointResolver_1 = require_endpointResolver4();
    var schemas_0_1 = require_schemas_04();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2011-06-15",
        base64Decoder: config2?.base64Decoder ?? util_base64_1.fromBase64,
        base64Encoder: config2?.base64Encoder ?? util_base64_1.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? endpointResolver_1.defaultEndpointResolver,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? httpAuthSchemeProvider_1.defaultSTSHttpAuthSchemeProvider,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new httpAuthSchemes_1.AwsSdkSigV4Signer()
          },
          {
            schemeId: "aws.auth#sigv4a",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4a"), "identityProvider"),
            signer: new httpAuthSchemes_1.AwsSdkSigV4ASigner()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new core_1.NoAuthSigner()
          }
        ],
        logger: config2?.logger ?? new smithy_client_1.NoOpLogger(),
        protocol: config2?.protocol ?? protocols_1.AwsQueryProtocol,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.sts",
          errorTypeRegistries: schemas_0_1.errorTypeRegistries,
          xmlNamespace: "https://sts.amazonaws.com/doc/2011-06-15/",
          version: "2011-06-15",
          serviceTarget: "AWSSecurityTokenServiceV20110615"
        },
        serviceId: config2?.serviceId ?? "STS",
        signerConstructor: config2?.signerConstructor ?? signature_v4_multi_region_1.SignatureV4MultiRegion,
        urlParser: config2?.urlParser ?? url_parser_1.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? util_utf8_1.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? util_utf8_1.toUtf8
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-sts/dist-cjs/runtimeConfig.js
var require_runtimeConfig4 = __commonJS({
  "../../node_modules/@aws-sdk/client-sts/dist-cjs/runtimeConfig.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var package_json_1 = tslib_1.__importDefault(require_package4());
    var client_1 = (init_client8(), __toCommonJS(client_exports7));
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var credential_provider_node_1 = require_dist_cjs122();
    var util_user_agent_node_1 = require_dist_cjs113();
    var config_resolver_1 = require_dist_cjs25();
    var core_1 = (init_dist_es(), __toCommonJS(dist_es_exports));
    var hash_node_1 = require_dist_cjs44();
    var middleware_retry_1 = require_dist_cjs106();
    var node_config_provider_1 = require_dist_cjs29();
    var node_http_handler_1 = require_dist_cjs13();
    var smithy_client_1 = require_dist_cjs34();
    var util_body_length_node_1 = require_dist_cjs45();
    var util_defaults_mode_node_1 = require_dist_cjs46();
    var util_retry_1 = require_dist_cjs22();
    var runtimeConfig_shared_1 = require_runtimeConfig_shared4();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      (0, smithy_client_1.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, util_defaults_mode_node_1.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(smithy_client_1.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = (0, runtimeConfig_shared_1.getRuntimeConfig)(config2);
      (0, client_1.emitWarningIfUnsupportedVersion)(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, node_config_provider_1.loadConfig)(httpAuthSchemes_1.NODE_AUTH_SCHEME_PREFERENCE_OPTIONS, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? util_body_length_node_1.calculateBodyLength,
        credentialDefaultProvider: config2?.credentialDefaultProvider ?? credential_provider_node_1.defaultProvider,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, util_user_agent_node_1.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_json_1.default.version }),
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4") || (async (idProps) => await (0, credential_provider_node_1.defaultProvider)(idProps?.__config || {})()), "identityProvider"),
            signer: new httpAuthSchemes_1.AwsSdkSigV4Signer()
          },
          {
            schemeId: "aws.auth#sigv4a",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4a"), "identityProvider"),
            signer: new httpAuthSchemes_1.AwsSdkSigV4ASigner()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new core_1.NoAuthSigner()
          }
        ],
        maxAttempts: config2?.maxAttempts ?? (0, node_config_provider_1.loadConfig)(middleware_retry_1.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_REGION_CONFIG_OPTIONS, { ...config_resolver_1.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: node_http_handler_1.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, node_config_provider_1.loadConfig)({
          ...middleware_retry_1.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || util_retry_1.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? hash_node_1.Hash.bind(null, "sha256"),
        sigv4aSigningRegionSet: config2?.sigv4aSigningRegionSet ?? (0, node_config_provider_1.loadConfig)(httpAuthSchemes_1.NODE_SIGV4A_CONFIG_OPTIONS, loaderConfig),
        streamCollector: config2?.streamCollector ?? node_http_handler_1.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, node_config_provider_1.loadConfig)(util_user_agent_node_1.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-sts/dist-cjs/auth/httpAuthExtensionConfiguration.js
var require_httpAuthExtensionConfiguration = __commonJS({
  "../../node_modules/@aws-sdk/client-sts/dist-cjs/auth/httpAuthExtensionConfiguration.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.resolveHttpAuthRuntimeConfig = exports2.getHttpAuthExtensionConfiguration = void 0;
    var getHttpAuthExtensionConfiguration32 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    exports2.getHttpAuthExtensionConfiguration = getHttpAuthExtensionConfiguration32;
    var resolveHttpAuthRuntimeConfig32 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
    exports2.resolveHttpAuthRuntimeConfig = resolveHttpAuthRuntimeConfig32;
  }
});

// ../../node_modules/@aws-sdk/client-sts/dist-cjs/runtimeExtensions.js
var require_runtimeExtensions = __commonJS({
  "../../node_modules/@aws-sdk/client-sts/dist-cjs/runtimeExtensions.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.resolveRuntimeExtensions = void 0;
    var region_config_resolver_1 = require_dist_cjs48();
    var protocol_http_1 = require_dist_cjs2();
    var smithy_client_1 = require_dist_cjs34();
    var httpAuthExtensionConfiguration_1 = require_httpAuthExtensionConfiguration();
    var resolveRuntimeExtensions32 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign((0, region_config_resolver_1.getAwsRegionExtensionConfiguration)(runtimeConfig), (0, smithy_client_1.getDefaultExtensionConfiguration)(runtimeConfig), (0, protocol_http_1.getHttpHandlerExtensionConfiguration)(runtimeConfig), (0, httpAuthExtensionConfiguration_1.getHttpAuthExtensionConfiguration)(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, (0, region_config_resolver_1.resolveAwsRegionExtensionConfiguration)(extensionConfiguration), (0, smithy_client_1.resolveDefaultRuntimeConfig)(extensionConfiguration), (0, protocol_http_1.resolveHttpHandlerRuntimeConfig)(extensionConfiguration), (0, httpAuthExtensionConfiguration_1.resolveHttpAuthRuntimeConfig)(extensionConfiguration));
    }, "resolveRuntimeExtensions");
    exports2.resolveRuntimeExtensions = resolveRuntimeExtensions32;
  }
});

// ../../node_modules/@aws-sdk/client-sts/dist-cjs/STSClient.js
var require_STSClient = __commonJS({
  "../../node_modules/@aws-sdk/client-sts/dist-cjs/STSClient.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.STSClient = exports2.__Client = void 0;
    var middleware_host_header_1 = require_dist_cjs3();
    var middleware_logger_1 = require_dist_cjs4();
    var middleware_recursion_detection_1 = require_dist_cjs5();
    var middleware_user_agent_1 = require_dist_cjs104();
    var config_resolver_1 = require_dist_cjs25();
    var core_1 = (init_dist_es(), __toCommonJS(dist_es_exports));
    var schema_1 = (init_schema4(), __toCommonJS(schema_exports));
    var middleware_content_length_1 = require_dist_cjs26();
    var middleware_endpoint_1 = require_dist_cjs31();
    var middleware_retry_1 = require_dist_cjs106();
    var smithy_client_1 = require_dist_cjs34();
    Object.defineProperty(exports2, "__Client", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return smithy_client_1.Client;
    }, "get") });
    var httpAuthSchemeProvider_1 = require_httpAuthSchemeProvider4();
    var EndpointParameters_1 = require_EndpointParameters();
    var runtimeConfig_1 = require_runtimeConfig4();
    var runtimeExtensions_1 = require_runtimeExtensions();
    var STSClient12 = class extends smithy_client_1.Client {
      static {
        __name(this, "STSClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = (0, runtimeConfig_1.getRuntimeConfig)(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = (0, EndpointParameters_1.resolveClientEndpointParameters)(_config_0);
        const _config_2 = (0, middleware_user_agent_1.resolveUserAgentConfig)(_config_1);
        const _config_3 = (0, middleware_retry_1.resolveRetryConfig)(_config_2);
        const _config_4 = (0, config_resolver_1.resolveRegionConfig)(_config_3);
        const _config_5 = (0, middleware_host_header_1.resolveHostHeaderConfig)(_config_4);
        const _config_6 = (0, middleware_endpoint_1.resolveEndpointConfig)(_config_5);
        const _config_7 = (0, httpAuthSchemeProvider_1.resolveHttpAuthSchemeConfig)(_config_6);
        const _config_8 = (0, runtimeExtensions_1.resolveRuntimeExtensions)(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use((0, schema_1.getSchemaSerdePlugin)(this.config));
        this.middlewareStack.use((0, middleware_user_agent_1.getUserAgentPlugin)(this.config));
        this.middlewareStack.use((0, middleware_retry_1.getRetryPlugin)(this.config));
        this.middlewareStack.use((0, middleware_content_length_1.getContentLengthPlugin)(this.config));
        this.middlewareStack.use((0, middleware_host_header_1.getHostHeaderPlugin)(this.config));
        this.middlewareStack.use((0, middleware_logger_1.getLoggerPlugin)(this.config));
        this.middlewareStack.use((0, middleware_recursion_detection_1.getRecursionDetectionPlugin)(this.config));
        this.middlewareStack.use((0, core_1.getHttpAuthSchemeEndpointRuleSetPlugin)(this.config, {
          httpAuthSchemeParametersProvider: httpAuthSchemeProvider_1.defaultSTSHttpAuthSchemeParametersProvider,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new core_1.DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials,
            "aws.auth#sigv4a": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use((0, core_1.getHttpSigningPlugin)(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
    exports2.STSClient = STSClient12;
  }
});

// ../../node_modules/@aws-sdk/client-sts/dist-cjs/index.js
var require_dist_cjs123 = __commonJS({
  "../../node_modules/@aws-sdk/client-sts/dist-cjs/index.js"(exports2) {
    "use strict";
    var STSClient12 = require_STSClient();
    var smithyClient = require_dist_cjs34();
    var middlewareEndpoint = require_dist_cjs31();
    var EndpointParameters = require_EndpointParameters();
    var schemas_0 = require_schemas_04();
    var errors = require_errors4();
    var client = (init_client8(), __toCommonJS(client_exports7));
    var regionConfigResolver = require_dist_cjs48();
    var STSServiceException10 = require_STSServiceException();
    var AssumeRoleCommand10 = class extends smithyClient.Command.classBuilder().ep(EndpointParameters.commonParams).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "AssumeRole", {}).n("STSClient", "AssumeRoleCommand").sc(schemas_0.AssumeRole$).build() {
      static {
        __name(this, "AssumeRoleCommand");
      }
    };
    var AssumeRoleWithSAMLCommand = class extends smithyClient.Command.classBuilder().ep(EndpointParameters.commonParams).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "AssumeRoleWithSAML", {}).n("STSClient", "AssumeRoleWithSAMLCommand").sc(schemas_0.AssumeRoleWithSAML$).build() {
      static {
        __name(this, "AssumeRoleWithSAMLCommand");
      }
    };
    var AssumeRoleWithWebIdentityCommand10 = class extends smithyClient.Command.classBuilder().ep(EndpointParameters.commonParams).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "AssumeRoleWithWebIdentity", {}).n("STSClient", "AssumeRoleWithWebIdentityCommand").sc(schemas_0.AssumeRoleWithWebIdentity$).build() {
      static {
        __name(this, "AssumeRoleWithWebIdentityCommand");
      }
    };
    var AssumeRootCommand = class extends smithyClient.Command.classBuilder().ep(EndpointParameters.commonParams).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "AssumeRoot", {}).n("STSClient", "AssumeRootCommand").sc(schemas_0.AssumeRoot$).build() {
      static {
        __name(this, "AssumeRootCommand");
      }
    };
    var DecodeAuthorizationMessageCommand = class extends smithyClient.Command.classBuilder().ep(EndpointParameters.commonParams).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "DecodeAuthorizationMessage", {}).n("STSClient", "DecodeAuthorizationMessageCommand").sc(schemas_0.DecodeAuthorizationMessage$).build() {
      static {
        __name(this, "DecodeAuthorizationMessageCommand");
      }
    };
    var GetAccessKeyInfoCommand = class extends smithyClient.Command.classBuilder().ep(EndpointParameters.commonParams).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "GetAccessKeyInfo", {}).n("STSClient", "GetAccessKeyInfoCommand").sc(schemas_0.GetAccessKeyInfo$).build() {
      static {
        __name(this, "GetAccessKeyInfoCommand");
      }
    };
    var GetCallerIdentityCommand3 = class extends smithyClient.Command.classBuilder().ep(EndpointParameters.commonParams).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "GetCallerIdentity", {}).n("STSClient", "GetCallerIdentityCommand").sc(schemas_0.GetCallerIdentity$).build() {
      static {
        __name(this, "GetCallerIdentityCommand");
      }
    };
    var GetDelegatedAccessTokenCommand = class extends smithyClient.Command.classBuilder().ep(EndpointParameters.commonParams).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "GetDelegatedAccessToken", {}).n("STSClient", "GetDelegatedAccessTokenCommand").sc(schemas_0.GetDelegatedAccessToken$).build() {
      static {
        __name(this, "GetDelegatedAccessTokenCommand");
      }
    };
    var GetFederationTokenCommand = class extends smithyClient.Command.classBuilder().ep(EndpointParameters.commonParams).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "GetFederationToken", {}).n("STSClient", "GetFederationTokenCommand").sc(schemas_0.GetFederationToken$).build() {
      static {
        __name(this, "GetFederationTokenCommand");
      }
    };
    var GetSessionTokenCommand = class extends smithyClient.Command.classBuilder().ep(EndpointParameters.commonParams).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "GetSessionToken", {}).n("STSClient", "GetSessionTokenCommand").sc(schemas_0.GetSessionToken$).build() {
      static {
        __name(this, "GetSessionTokenCommand");
      }
    };
    var GetWebIdentityTokenCommand = class extends smithyClient.Command.classBuilder().ep(EndpointParameters.commonParams).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "GetWebIdentityToken", {}).n("STSClient", "GetWebIdentityTokenCommand").sc(schemas_0.GetWebIdentityToken$).build() {
      static {
        __name(this, "GetWebIdentityTokenCommand");
      }
    };
    var commands32 = {
      AssumeRoleCommand: AssumeRoleCommand10,
      AssumeRoleWithSAMLCommand,
      AssumeRoleWithWebIdentityCommand: AssumeRoleWithWebIdentityCommand10,
      AssumeRootCommand,
      DecodeAuthorizationMessageCommand,
      GetAccessKeyInfoCommand,
      GetCallerIdentityCommand: GetCallerIdentityCommand3,
      GetDelegatedAccessTokenCommand,
      GetFederationTokenCommand,
      GetSessionTokenCommand,
      GetWebIdentityTokenCommand
    };
    var STS10 = class extends STSClient12.STSClient {
      static {
        __name(this, "STS");
      }
    };
    smithyClient.createAggregatedClient(commands32, STS10);
    var getAccountIdFromAssumedRoleUser10 = /* @__PURE__ */ __name((assumedRoleUser) => {
      if (typeof assumedRoleUser?.Arn === "string") {
        const arnComponents = assumedRoleUser.Arn.split(":");
        if (arnComponents.length > 4 && arnComponents[4] !== "") {
          return arnComponents[4];
        }
      }
      return void 0;
    }, "getAccountIdFromAssumedRoleUser");
    var resolveRegion10 = /* @__PURE__ */ __name(async (_region, _parentRegion, credentialProviderLogger, loaderConfig = {}) => {
      const region = typeof _region === "function" ? await _region() : _region;
      const parentRegion = typeof _parentRegion === "function" ? await _parentRegion() : _parentRegion;
      let stsDefaultRegion = "";
      const resolvedRegion = region ?? parentRegion ?? (stsDefaultRegion = await regionConfigResolver.stsRegionDefaultResolver(loaderConfig)());
      credentialProviderLogger?.debug?.("@aws-sdk/client-sts::resolveRegion", "accepting first of:", `${region} (credential provider clientConfig)`, `${parentRegion} (contextual client)`, `${stsDefaultRegion} (STS default: AWS_REGION, profile region, or us-east-1)`);
      return resolvedRegion;
    }, "resolveRegion");
    var getDefaultRoleAssumer$1 = /* @__PURE__ */ __name((stsOptions, STSClient13) => {
      let stsClient;
      let closureSourceCreds;
      return async (sourceCreds, params) => {
        closureSourceCreds = sourceCreds;
        if (!stsClient) {
          const { logger: logger5 = stsOptions?.parentClientConfig?.logger, profile = stsOptions?.parentClientConfig?.profile, region, requestHandler = stsOptions?.parentClientConfig?.requestHandler, credentialProviderLogger, userAgentAppId = stsOptions?.parentClientConfig?.userAgentAppId } = stsOptions;
          const resolvedRegion = await resolveRegion10(region, stsOptions?.parentClientConfig?.region, credentialProviderLogger, {
            logger: logger5,
            profile
          });
          const isCompatibleRequestHandler = !isH210(requestHandler);
          stsClient = new STSClient13({
            ...stsOptions,
            userAgentAppId,
            profile,
            credentialDefaultProvider: /* @__PURE__ */ __name(() => async () => closureSourceCreds, "credentialDefaultProvider"),
            region: resolvedRegion,
            requestHandler: isCompatibleRequestHandler ? requestHandler : void 0,
            logger: logger5
          });
        }
        const { Credentials, AssumedRoleUser } = await stsClient.send(new AssumeRoleCommand10(params));
        if (!Credentials || !Credentials.AccessKeyId || !Credentials.SecretAccessKey) {
          throw new Error(`Invalid response from STS.assumeRole call with role ${params.RoleArn}`);
        }
        const accountId = getAccountIdFromAssumedRoleUser10(AssumedRoleUser);
        const credentials = {
          accessKeyId: Credentials.AccessKeyId,
          secretAccessKey: Credentials.SecretAccessKey,
          sessionToken: Credentials.SessionToken,
          expiration: Credentials.Expiration,
          ...Credentials.CredentialScope && { credentialScope: Credentials.CredentialScope },
          ...accountId && { accountId }
        };
        client.setCredentialFeature(credentials, "CREDENTIALS_STS_ASSUME_ROLE", "i");
        return credentials;
      };
    }, "getDefaultRoleAssumer$1");
    var getDefaultRoleAssumerWithWebIdentity$1 = /* @__PURE__ */ __name((stsOptions, STSClient13) => {
      let stsClient;
      return async (params) => {
        if (!stsClient) {
          const { logger: logger5 = stsOptions?.parentClientConfig?.logger, profile = stsOptions?.parentClientConfig?.profile, region, requestHandler = stsOptions?.parentClientConfig?.requestHandler, credentialProviderLogger, userAgentAppId = stsOptions?.parentClientConfig?.userAgentAppId } = stsOptions;
          const resolvedRegion = await resolveRegion10(region, stsOptions?.parentClientConfig?.region, credentialProviderLogger, {
            logger: logger5,
            profile
          });
          const isCompatibleRequestHandler = !isH210(requestHandler);
          stsClient = new STSClient13({
            ...stsOptions,
            userAgentAppId,
            profile,
            region: resolvedRegion,
            requestHandler: isCompatibleRequestHandler ? requestHandler : void 0,
            logger: logger5
          });
        }
        const { Credentials, AssumedRoleUser } = await stsClient.send(new AssumeRoleWithWebIdentityCommand10(params));
        if (!Credentials || !Credentials.AccessKeyId || !Credentials.SecretAccessKey) {
          throw new Error(`Invalid response from STS.assumeRoleWithWebIdentity call with role ${params.RoleArn}`);
        }
        const accountId = getAccountIdFromAssumedRoleUser10(AssumedRoleUser);
        const credentials = {
          accessKeyId: Credentials.AccessKeyId,
          secretAccessKey: Credentials.SecretAccessKey,
          sessionToken: Credentials.SessionToken,
          expiration: Credentials.Expiration,
          ...Credentials.CredentialScope && { credentialScope: Credentials.CredentialScope },
          ...accountId && { accountId }
        };
        if (accountId) {
          client.setCredentialFeature(credentials, "RESOLVED_ACCOUNT_ID", "T");
        }
        client.setCredentialFeature(credentials, "CREDENTIALS_STS_ASSUME_ROLE_WEB_ID", "k");
        return credentials;
      };
    }, "getDefaultRoleAssumerWithWebIdentity$1");
    var isH210 = /* @__PURE__ */ __name((requestHandler) => {
      return requestHandler?.metadata?.handlerProtocol === "h2";
    }, "isH2");
    var getCustomizableStsClientCtor10 = /* @__PURE__ */ __name((baseCtor, customizations) => {
      if (!customizations)
        return baseCtor;
      else
        return class CustomizableSTSClient extends baseCtor {
          static {
            __name(this, "CustomizableSTSClient");
          }
          constructor(config2) {
            super(config2);
            for (const customization of customizations) {
              this.middlewareStack.use(customization);
            }
          }
        };
    }, "getCustomizableStsClientCtor");
    var getDefaultRoleAssumer19 = /* @__PURE__ */ __name((stsOptions = {}, stsPlugins) => getDefaultRoleAssumer$1(stsOptions, getCustomizableStsClientCtor10(STSClient12.STSClient, stsPlugins)), "getDefaultRoleAssumer");
    var getDefaultRoleAssumerWithWebIdentity19 = /* @__PURE__ */ __name((stsOptions = {}, stsPlugins) => getDefaultRoleAssumerWithWebIdentity$1(stsOptions, getCustomizableStsClientCtor10(STSClient12.STSClient, stsPlugins)), "getDefaultRoleAssumerWithWebIdentity");
    var decorateDefaultCredentialProvider10 = /* @__PURE__ */ __name((provider) => (input) => provider({
      roleAssumer: getDefaultRoleAssumer19(input),
      roleAssumerWithWebIdentity: getDefaultRoleAssumerWithWebIdentity19(input),
      ...input
    }), "decorateDefaultCredentialProvider");
    exports2.$Command = smithyClient.Command;
    exports2.STSServiceException = STSServiceException10.STSServiceException;
    exports2.AssumeRoleCommand = AssumeRoleCommand10;
    exports2.AssumeRoleWithSAMLCommand = AssumeRoleWithSAMLCommand;
    exports2.AssumeRoleWithWebIdentityCommand = AssumeRoleWithWebIdentityCommand10;
    exports2.AssumeRootCommand = AssumeRootCommand;
    exports2.DecodeAuthorizationMessageCommand = DecodeAuthorizationMessageCommand;
    exports2.GetAccessKeyInfoCommand = GetAccessKeyInfoCommand;
    exports2.GetCallerIdentityCommand = GetCallerIdentityCommand3;
    exports2.GetDelegatedAccessTokenCommand = GetDelegatedAccessTokenCommand;
    exports2.GetFederationTokenCommand = GetFederationTokenCommand;
    exports2.GetSessionTokenCommand = GetSessionTokenCommand;
    exports2.GetWebIdentityTokenCommand = GetWebIdentityTokenCommand;
    exports2.STS = STS10;
    exports2.decorateDefaultCredentialProvider = decorateDefaultCredentialProvider10;
    exports2.getDefaultRoleAssumer = getDefaultRoleAssumer19;
    exports2.getDefaultRoleAssumerWithWebIdentity = getDefaultRoleAssumerWithWebIdentity19;
    Object.prototype.hasOwnProperty.call(STSClient12, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: STSClient12["__proto__"]
    });
    Object.keys(STSClient12).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = STSClient12[k32];
    });
    Object.prototype.hasOwnProperty.call(schemas_0, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: schemas_0["__proto__"]
    });
    Object.keys(schemas_0).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = schemas_0[k32];
    });
    Object.prototype.hasOwnProperty.call(errors, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: errors["__proto__"]
    });
    Object.keys(errors).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = errors[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/credential-providers/dist-cjs/createCredentialChain.js
var require_createCredentialChain = __commonJS({
  "../../node_modules/@aws-sdk/credential-providers/dist-cjs/createCredentialChain.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.propertyProviderChain = exports2.createCredentialChain = void 0;
    var property_provider_1 = require_dist_cjs27();
    var createCredentialChain2 = /* @__PURE__ */ __name((...credentialProviders) => {
      let expireAfter = -1;
      const baseFunction = /* @__PURE__ */ __name(async (awsIdentityProperties) => {
        const credentials = await (0, exports2.propertyProviderChain)(...credentialProviders)(awsIdentityProperties);
        if (!credentials.expiration && expireAfter !== -1) {
          credentials.expiration = new Date(Date.now() + expireAfter);
        }
        return credentials;
      }, "baseFunction");
      const withOptions = Object.assign(baseFunction, {
        expireAfter(milliseconds) {
          if (milliseconds < 5 * 6e4) {
            throw new Error("@aws-sdk/credential-providers - createCredentialChain(...).expireAfter(ms) may not be called with a duration lower than five minutes.");
          }
          expireAfter = milliseconds;
          return withOptions;
        }
      });
      return withOptions;
    }, "createCredentialChain");
    exports2.createCredentialChain = createCredentialChain2;
    var propertyProviderChain = /* @__PURE__ */ __name((...providers) => async (awsIdentityProperties) => {
      if (providers.length === 0) {
        throw new property_provider_1.ProviderError("No providers in chain", { tryNextLink: false });
      }
      let lastProviderError;
      for (const provider of providers) {
        try {
          return await provider(awsIdentityProperties);
        } catch (err) {
          lastProviderError = err;
          if (err?.tryNextLink) {
            continue;
          }
          throw err;
        }
      }
      throw lastProviderError;
    }, "propertyProviderChain");
    exports2.propertyProviderChain = propertyProviderChain;
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption15(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "cognito-identity",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption15(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var import_util_middleware20, defaultCognitoIdentityHttpAuthSchemeParametersProvider, defaultCognitoIdentityHttpAuthSchemeProvider, resolveHttpAuthSchemeConfig15;
var init_httpAuthSchemeProvider15 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes6();
    import_util_middleware20 = __toESM(require_dist_cjs6());
    defaultCognitoIdentityHttpAuthSchemeParametersProvider = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, import_util_middleware20.getSmithyContext)(context).operation,
        region: await (0, import_util_middleware20.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultCognitoIdentityHttpAuthSchemeParametersProvider");
    __name(createAwsAuthSigv4HttpAuthOption15, "createAwsAuthSigv4HttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption15, "createSmithyApiNoAuthHttpAuthOption");
    defaultCognitoIdentityHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "GetCredentialsForIdentity": {
          options.push(createSmithyApiNoAuthHttpAuthOption15(authParameters));
          break;
        }
        case "GetId": {
          options.push(createSmithyApiNoAuthHttpAuthOption15(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption15(authParameters));
        }
      }
      return options;
    }, "defaultCognitoIdentityHttpAuthSchemeProvider");
    resolveHttpAuthSchemeConfig15 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveAwsSdkSigV4Config5(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, import_util_middleware20.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/endpoint/EndpointParameters.js
var resolveClientEndpointParameters15, commonParams15;
var init_EndpointParameters15 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters15 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "cognito-identity"
      });
    }, "resolveClientEndpointParameters");
    commonParams15 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/endpoint/bdd.js
var import_util_endpoints43, m9, a15, b15, c15, d15, e15, f15, g15, h15, i15, j15, k15, l9, _data15, root15, r15, nodes15, bdd15;
var init_bdd15 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/endpoint/bdd.js"() {
    import_util_endpoints43 = __toESM(require_dist_cjs20());
    m9 = "ref";
    a15 = -1;
    b15 = true;
    c15 = "isSet";
    d15 = "PartitionResult";
    e15 = "booleanEquals";
    f15 = "getAttr";
    g15 = "stringEquals";
    h15 = { [m9]: "Endpoint" };
    i15 = { [m9]: d15 };
    j15 = { [m9]: "Region" };
    k15 = {};
    l9 = [j15];
    _data15 = {
      conditions: [
        [c15, [h15]],
        [c15, l9],
        ["aws.partition", l9, d15],
        [e15, [{ [m9]: "UseFIPS" }, b15]],
        [e15, [{ fn: f15, argv: [i15, "supportsFIPS"] }, b15]],
        [e15, [{ [m9]: "UseDualStack" }, b15]],
        [e15, [{ fn: f15, argv: [i15, "supportsDualStack"] }, b15]],
        [g15, [{ fn: f15, argv: [i15, "name"] }, "aws"]],
        [g15, [j15, "us-east-1"]],
        [g15, [j15, "us-east-2"]],
        [g15, [j15, "us-west-1"]],
        [g15, [j15, "us-west-2"]]
      ],
      results: [
        [a15],
        [a15, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a15, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [h15, k15],
        ["https://cognito-identity-fips.us-east-1.amazonaws.com", k15],
        ["https://cognito-identity-fips.us-east-2.amazonaws.com", k15],
        ["https://cognito-identity-fips.us-west-1.amazonaws.com", k15],
        ["https://cognito-identity-fips.us-west-2.amazonaws.com", k15],
        ["https://cognito-identity-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", k15],
        [a15, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://cognito-identity-fips.{Region}.{PartitionResult#dnsSuffix}", k15],
        [a15, "FIPS is enabled but this partition does not support FIPS"],
        ["https://cognito-identity.{Region}.amazonaws.com", k15],
        ["https://cognito-identity.{Region}.{PartitionResult#dualStackDnsSuffix}", k15],
        [a15, "DualStack is enabled but this partition does not support DualStack"],
        ["https://cognito-identity.{Region}.{PartitionResult#dnsSuffix}", k15],
        [a15, "Invalid Configuration: Missing Region"]
      ]
    };
    root15 = 2;
    r15 = 1e8;
    nodes15 = new Int32Array([
      -1,
      1,
      -1,
      0,
      17,
      3,
      1,
      4,
      r15 + 16,
      2,
      5,
      r15 + 16,
      3,
      9,
      6,
      5,
      7,
      r15 + 15,
      6,
      8,
      r15 + 14,
      7,
      r15 + 12,
      r15 + 13,
      4,
      11,
      10,
      5,
      r15 + 9,
      r15 + 11,
      5,
      12,
      r15 + 10,
      6,
      13,
      r15 + 9,
      8,
      r15 + 4,
      14,
      9,
      r15 + 5,
      15,
      10,
      r15 + 6,
      16,
      11,
      r15 + 7,
      r15 + 8,
      3,
      r15 + 1,
      18,
      5,
      r15 + 2,
      r15 + 3
    ]);
    bdd15 = import_util_endpoints43.BinaryDecisionDiagram.from(nodes15, root15, _data15.conditions, _data15.results);
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/endpoint/endpointResolver.js
var import_util_endpoints44, import_util_endpoints45, cache15, defaultEndpointResolver15;
var init_endpointResolver15 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/endpoint/endpointResolver.js"() {
    import_util_endpoints44 = __toESM(require_dist_cjs21());
    import_util_endpoints45 = __toESM(require_dist_cjs20());
    init_bdd15();
    cache15 = new import_util_endpoints45.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    defaultEndpointResolver15 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache15.get(endpointParams, () => (0, import_util_endpoints45.decideEndpoint)(bdd15, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    import_util_endpoints45.customEndpointFunctions.aws = import_util_endpoints44.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/models/CognitoIdentityServiceException.js
var import_smithy_client137, CognitoIdentityServiceException;
var init_CognitoIdentityServiceException = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/models/CognitoIdentityServiceException.js"() {
    import_smithy_client137 = __toESM(require_dist_cjs34());
    CognitoIdentityServiceException = class _CognitoIdentityServiceException extends import_smithy_client137.ServiceException {
      static {
        __name(this, "CognitoIdentityServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _CognitoIdentityServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/models/errors.js
var ExternalServiceException, InternalErrorException, InvalidIdentityPoolConfigurationException, InvalidParameterException, NotAuthorizedException, ResourceConflictException, ResourceNotFoundException5, TooManyRequestsException5, LimitExceededException;
var init_errors15 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/models/errors.js"() {
    init_CognitoIdentityServiceException();
    ExternalServiceException = class _ExternalServiceException extends CognitoIdentityServiceException {
      static {
        __name(this, "ExternalServiceException");
      }
      name = "ExternalServiceException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ExternalServiceException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ExternalServiceException.prototype);
      }
    };
    InternalErrorException = class _InternalErrorException extends CognitoIdentityServiceException {
      static {
        __name(this, "InternalErrorException");
      }
      name = "InternalErrorException";
      $fault = "server";
      constructor(opts) {
        super({
          name: "InternalErrorException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _InternalErrorException.prototype);
      }
    };
    InvalidIdentityPoolConfigurationException = class _InvalidIdentityPoolConfigurationException extends CognitoIdentityServiceException {
      static {
        __name(this, "InvalidIdentityPoolConfigurationException");
      }
      name = "InvalidIdentityPoolConfigurationException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidIdentityPoolConfigurationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidIdentityPoolConfigurationException.prototype);
      }
    };
    InvalidParameterException = class _InvalidParameterException extends CognitoIdentityServiceException {
      static {
        __name(this, "InvalidParameterException");
      }
      name = "InvalidParameterException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidParameterException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidParameterException.prototype);
      }
    };
    NotAuthorizedException = class _NotAuthorizedException extends CognitoIdentityServiceException {
      static {
        __name(this, "NotAuthorizedException");
      }
      name = "NotAuthorizedException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "NotAuthorizedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _NotAuthorizedException.prototype);
      }
    };
    ResourceConflictException = class _ResourceConflictException extends CognitoIdentityServiceException {
      static {
        __name(this, "ResourceConflictException");
      }
      name = "ResourceConflictException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ResourceConflictException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceConflictException.prototype);
      }
    };
    ResourceNotFoundException5 = class _ResourceNotFoundException extends CognitoIdentityServiceException {
      static {
        __name(this, "ResourceNotFoundException");
      }
      name = "ResourceNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ResourceNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceNotFoundException.prototype);
      }
    };
    TooManyRequestsException5 = class _TooManyRequestsException extends CognitoIdentityServiceException {
      static {
        __name(this, "TooManyRequestsException");
      }
      name = "TooManyRequestsException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TooManyRequestsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyRequestsException.prototype);
      }
    };
    LimitExceededException = class _LimitExceededException extends CognitoIdentityServiceException {
      static {
        __name(this, "LimitExceededException");
      }
      name = "LimitExceededException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "LimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _LimitExceededException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/schemas/schemas_0.js
var _AI, _AKI5, _C5, _CRA, _E5, _ESE, _GCFI, _GCFII, _GCFIR, _GI, _GII, _GIR, _IEE, _II, _IIPCE, _IPE, _IPI, _IPT, _L, _LEE, _LM, _NAE, _RCE, _RNFE5, _SK, _SKS, _ST5, _TMRE9, _c15, _e15, _hE15, _m13, _s15, _se7, n015, _s_registry15, CognitoIdentityServiceException$, n0_registry15, ExternalServiceException$, InternalErrorException$, InvalidIdentityPoolConfigurationException$, InvalidParameterException$, LimitExceededException$, NotAuthorizedException$, ResourceConflictException$, ResourceNotFoundException$5, TooManyRequestsException$5, errorTypeRegistries15, IdentityProviderToken, SecretKeyString, Credentials$5, GetCredentialsForIdentityInput$, GetCredentialsForIdentityResponse$, GetIdInput$, GetIdResponse$, LoginsMap, GetCredentialsForIdentity$, GetId$;
var init_schemas_015 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/schemas/schemas_0.js"() {
    init_schema4();
    init_CognitoIdentityServiceException();
    init_errors15();
    _AI = "AccountId";
    _AKI5 = "AccessKeyId";
    _C5 = "Credentials";
    _CRA = "CustomRoleArn";
    _E5 = "Expiration";
    _ESE = "ExternalServiceException";
    _GCFI = "GetCredentialsForIdentity";
    _GCFII = "GetCredentialsForIdentityInput";
    _GCFIR = "GetCredentialsForIdentityResponse";
    _GI = "GetId";
    _GII = "GetIdInput";
    _GIR = "GetIdResponse";
    _IEE = "InternalErrorException";
    _II = "IdentityId";
    _IIPCE = "InvalidIdentityPoolConfigurationException";
    _IPE = "InvalidParameterException";
    _IPI = "IdentityPoolId";
    _IPT = "IdentityProviderToken";
    _L = "Logins";
    _LEE = "LimitExceededException";
    _LM = "LoginsMap";
    _NAE = "NotAuthorizedException";
    _RCE = "ResourceConflictException";
    _RNFE5 = "ResourceNotFoundException";
    _SK = "SecretKey";
    _SKS = "SecretKeyString";
    _ST5 = "SessionToken";
    _TMRE9 = "TooManyRequestsException";
    _c15 = "client";
    _e15 = "error";
    _hE15 = "httpError";
    _m13 = "message";
    _s15 = "smithy.ts.sdk.synthetic.com.amazonaws.cognitoidentity";
    _se7 = "server";
    n015 = "com.amazonaws.cognitoidentity";
    _s_registry15 = TypeRegistry.for(_s15);
    CognitoIdentityServiceException$ = [-3, _s15, "CognitoIdentityServiceException", 0, [], []];
    _s_registry15.registerError(CognitoIdentityServiceException$, CognitoIdentityServiceException);
    n0_registry15 = TypeRegistry.for(n015);
    ExternalServiceException$ = [-3, n015, _ESE, { [_e15]: _c15, [_hE15]: 400 }, [_m13], [0]];
    n0_registry15.registerError(ExternalServiceException$, ExternalServiceException);
    InternalErrorException$ = [-3, n015, _IEE, { [_e15]: _se7 }, [_m13], [0]];
    n0_registry15.registerError(InternalErrorException$, InternalErrorException);
    InvalidIdentityPoolConfigurationException$ = [
      -3,
      n015,
      _IIPCE,
      { [_e15]: _c15, [_hE15]: 400 },
      [_m13],
      [0]
    ];
    n0_registry15.registerError(InvalidIdentityPoolConfigurationException$, InvalidIdentityPoolConfigurationException);
    InvalidParameterException$ = [-3, n015, _IPE, { [_e15]: _c15, [_hE15]: 400 }, [_m13], [0]];
    n0_registry15.registerError(InvalidParameterException$, InvalidParameterException);
    LimitExceededException$ = [-3, n015, _LEE, { [_e15]: _c15, [_hE15]: 400 }, [_m13], [0]];
    n0_registry15.registerError(LimitExceededException$, LimitExceededException);
    NotAuthorizedException$ = [-3, n015, _NAE, { [_e15]: _c15, [_hE15]: 403 }, [_m13], [0]];
    n0_registry15.registerError(NotAuthorizedException$, NotAuthorizedException);
    ResourceConflictException$ = [-3, n015, _RCE, { [_e15]: _c15, [_hE15]: 409 }, [_m13], [0]];
    n0_registry15.registerError(ResourceConflictException$, ResourceConflictException);
    ResourceNotFoundException$5 = [-3, n015, _RNFE5, { [_e15]: _c15, [_hE15]: 404 }, [_m13], [0]];
    n0_registry15.registerError(ResourceNotFoundException$5, ResourceNotFoundException5);
    TooManyRequestsException$5 = [-3, n015, _TMRE9, { [_e15]: _c15, [_hE15]: 429 }, [_m13], [0]];
    n0_registry15.registerError(TooManyRequestsException$5, TooManyRequestsException5);
    errorTypeRegistries15 = [_s_registry15, n0_registry15];
    IdentityProviderToken = [0, n015, _IPT, 8, 0];
    SecretKeyString = [0, n015, _SKS, 8, 0];
    Credentials$5 = [
      3,
      n015,
      _C5,
      0,
      [_AKI5, _SK, _ST5, _E5],
      [0, [() => SecretKeyString, 0], 0, 4]
    ];
    GetCredentialsForIdentityInput$ = [
      3,
      n015,
      _GCFII,
      0,
      [_II, _L, _CRA],
      [0, [() => LoginsMap, 0], 0],
      1
    ];
    GetCredentialsForIdentityResponse$ = [
      3,
      n015,
      _GCFIR,
      0,
      [_II, _C5],
      [0, [() => Credentials$5, 0]]
    ];
    GetIdInput$ = [3, n015, _GII, 0, [_IPI, _AI, _L], [0, 0, [() => LoginsMap, 0]], 1];
    GetIdResponse$ = [3, n015, _GIR, 0, [_II], [0]];
    LoginsMap = [2, n015, _LM, 0, [0, 0], [() => IdentityProviderToken, 0]];
    GetCredentialsForIdentity$ = [
      9,
      n015,
      _GCFI,
      0,
      () => GetCredentialsForIdentityInput$,
      () => GetCredentialsForIdentityResponse$
    ];
    GetId$ = [9, n015, _GI, 0, () => GetIdInput$, () => GetIdResponse$];
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/runtimeConfig.shared.js
var import_smithy_client138, import_url_parser16, import_util_base6439, import_util_utf831, getRuntimeConfig29;
var init_runtimeConfig_shared15 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/runtimeConfig.shared.js"() {
    init_httpAuthSchemes6();
    init_protocols8();
    init_dist_es();
    import_smithy_client138 = __toESM(require_dist_cjs34());
    import_url_parser16 = __toESM(require_dist_cjs18());
    import_util_base6439 = __toESM(require_dist_cjs10());
    import_util_utf831 = __toESM(require_dist_cjs9());
    init_httpAuthSchemeProvider15();
    init_endpointResolver15();
    init_schemas_015();
    getRuntimeConfig29 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2014-06-30",
        base64Decoder: config2?.base64Decoder ?? import_util_base6439.fromBase64,
        base64Encoder: config2?.base64Encoder ?? import_util_base6439.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver15,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultCognitoIdentityHttpAuthSchemeProvider,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer5()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        logger: config2?.logger ?? new import_smithy_client138.NoOpLogger(),
        protocol: config2?.protocol ?? AwsJson1_1Protocol4,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.cognitoidentity",
          errorTypeRegistries: errorTypeRegistries15,
          xmlNamespace: "http://cognito-identity.amazonaws.com/doc/2014-06-30/",
          version: "2014-06-30",
          serviceTarget: "AWSCognitoIdentityService"
        },
        serviceId: config2?.serviceId ?? "Cognito Identity",
        urlParser: config2?.urlParser ?? import_url_parser16.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? import_util_utf831.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? import_util_utf831.toUtf8
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/runtimeConfig.js
var import_util_user_agent_node15, import_config_resolver29, import_hash_node15, import_middleware_retry29, import_node_config_provider15, import_node_http_handler15, import_smithy_client139, import_util_body_length_node15, import_util_defaults_mode_node15, import_util_retry22, getRuntimeConfig30;
var init_runtimeConfig15 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/runtimeConfig.js"() {
    init_package5();
    init_client8();
    init_httpAuthSchemes6();
    import_util_user_agent_node15 = __toESM(require_dist_cjs113());
    import_config_resolver29 = __toESM(require_dist_cjs25());
    import_hash_node15 = __toESM(require_dist_cjs44());
    import_middleware_retry29 = __toESM(require_dist_cjs106());
    import_node_config_provider15 = __toESM(require_dist_cjs29());
    import_node_http_handler15 = __toESM(require_dist_cjs13());
    import_smithy_client139 = __toESM(require_dist_cjs34());
    import_util_body_length_node15 = __toESM(require_dist_cjs45());
    import_util_defaults_mode_node15 = __toESM(require_dist_cjs46());
    import_util_retry22 = __toESM(require_dist_cjs22());
    init_runtimeConfig_shared15();
    getRuntimeConfig30 = /* @__PURE__ */ __name((config2) => {
      (0, import_smithy_client139.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, import_util_defaults_mode_node15.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(import_smithy_client139.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig29(config2);
      emitWarningIfUnsupportedVersion17(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, import_node_config_provider15.loadConfig)(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS5, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? import_util_body_length_node15.calculateBodyLength,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, import_util_user_agent_node15.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_default5.version }),
        maxAttempts: config2?.maxAttempts ?? (0, import_node_config_provider15.loadConfig)(import_middleware_retry29.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, import_node_config_provider15.loadConfig)(import_config_resolver29.NODE_REGION_CONFIG_OPTIONS, { ...import_config_resolver29.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: import_node_http_handler15.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, import_node_config_provider15.loadConfig)({
          ...import_middleware_retry29.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || import_util_retry22.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? import_hash_node15.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? import_node_http_handler15.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, import_node_config_provider15.loadConfig)(import_config_resolver29.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, import_node_config_provider15.loadConfig)(import_config_resolver29.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, import_node_config_provider15.loadConfig)(import_util_user_agent_node15.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration15, resolveHttpAuthRuntimeConfig15;
var init_httpAuthExtensionConfiguration15 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration15 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig15 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/runtimeExtensions.js
var import_region_config_resolver19, import_protocol_http38, import_smithy_client140, resolveRuntimeExtensions15;
var init_runtimeExtensions15 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/runtimeExtensions.js"() {
    import_region_config_resolver19 = __toESM(require_dist_cjs48());
    import_protocol_http38 = __toESM(require_dist_cjs2());
    import_smithy_client140 = __toESM(require_dist_cjs34());
    init_httpAuthExtensionConfiguration15();
    resolveRuntimeExtensions15 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign((0, import_region_config_resolver19.getAwsRegionExtensionConfiguration)(runtimeConfig), (0, import_smithy_client140.getDefaultExtensionConfiguration)(runtimeConfig), (0, import_protocol_http38.getHttpHandlerExtensionConfiguration)(runtimeConfig), getHttpAuthExtensionConfiguration15(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, (0, import_region_config_resolver19.resolveAwsRegionExtensionConfiguration)(extensionConfiguration), (0, import_smithy_client140.resolveDefaultRuntimeConfig)(extensionConfiguration), (0, import_protocol_http38.resolveHttpHandlerRuntimeConfig)(extensionConfiguration), resolveHttpAuthRuntimeConfig15(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/CognitoIdentityClient.js
var import_middleware_host_header15, import_middleware_logger15, import_middleware_recursion_detection15, import_middleware_user_agent15, import_config_resolver30, import_middleware_content_length15, import_middleware_endpoint37, import_middleware_retry30, import_smithy_client141, CognitoIdentityClient;
var init_CognitoIdentityClient = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/CognitoIdentityClient.js"() {
    import_middleware_host_header15 = __toESM(require_dist_cjs3());
    import_middleware_logger15 = __toESM(require_dist_cjs4());
    import_middleware_recursion_detection15 = __toESM(require_dist_cjs5());
    import_middleware_user_agent15 = __toESM(require_dist_cjs104());
    import_config_resolver30 = __toESM(require_dist_cjs25());
    init_dist_es();
    init_schema4();
    import_middleware_content_length15 = __toESM(require_dist_cjs26());
    import_middleware_endpoint37 = __toESM(require_dist_cjs31());
    import_middleware_retry30 = __toESM(require_dist_cjs106());
    import_smithy_client141 = __toESM(require_dist_cjs34());
    init_httpAuthSchemeProvider15();
    init_EndpointParameters15();
    init_runtimeConfig15();
    init_runtimeExtensions15();
    CognitoIdentityClient = class extends import_smithy_client141.Client {
      static {
        __name(this, "CognitoIdentityClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig30(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters15(_config_0);
        const _config_2 = (0, import_middleware_user_agent15.resolveUserAgentConfig)(_config_1);
        const _config_3 = (0, import_middleware_retry30.resolveRetryConfig)(_config_2);
        const _config_4 = (0, import_config_resolver30.resolveRegionConfig)(_config_3);
        const _config_5 = (0, import_middleware_host_header15.resolveHostHeaderConfig)(_config_4);
        const _config_6 = (0, import_middleware_endpoint37.resolveEndpointConfig)(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig15(_config_6);
        const _config_8 = resolveRuntimeExtensions15(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin(this.config));
        this.middlewareStack.use((0, import_middleware_user_agent15.getUserAgentPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_retry30.getRetryPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_content_length15.getContentLengthPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_host_header15.getHostHeaderPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_logger15.getLoggerPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_recursion_detection15.getRecursionDetectionPlugin)(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: defaultCognitoIdentityHttpAuthSchemeParametersProvider,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/commands/GetCredentialsForIdentityCommand.js
var import_middleware_endpoint38, import_smithy_client142, GetCredentialsForIdentityCommand;
var init_GetCredentialsForIdentityCommand = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/commands/GetCredentialsForIdentityCommand.js"() {
    import_middleware_endpoint38 = __toESM(require_dist_cjs31());
    import_smithy_client142 = __toESM(require_dist_cjs34());
    init_EndpointParameters15();
    init_schemas_015();
    GetCredentialsForIdentityCommand = class extends import_smithy_client142.Command.classBuilder().ep(commonParams15).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint38.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSCognitoIdentityService", "GetCredentialsForIdentity", {}).n("CognitoIdentityClient", "GetCredentialsForIdentityCommand").sc(GetCredentialsForIdentity$).build() {
      static {
        __name(this, "GetCredentialsForIdentityCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/commands/GetIdCommand.js
var import_middleware_endpoint39, import_smithy_client143, GetIdCommand;
var init_GetIdCommand = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/commands/GetIdCommand.js"() {
    import_middleware_endpoint39 = __toESM(require_dist_cjs31());
    import_smithy_client143 = __toESM(require_dist_cjs34());
    init_EndpointParameters15();
    init_schemas_015();
    GetIdCommand = class extends import_smithy_client143.Command.classBuilder().ep(commonParams15).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint39.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSCognitoIdentityService", "GetId", {}).n("CognitoIdentityClient", "GetIdCommand").sc(GetId$).build() {
      static {
        __name(this, "GetIdCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/CognitoIdentity.js
var import_smithy_client144, commands15, CognitoIdentity;
var init_CognitoIdentity = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/CognitoIdentity.js"() {
    import_smithy_client144 = __toESM(require_dist_cjs34());
    init_CognitoIdentityClient();
    init_GetCredentialsForIdentityCommand();
    init_GetIdCommand();
    commands15 = {
      GetCredentialsForIdentityCommand,
      GetIdCommand
    };
    CognitoIdentity = class extends CognitoIdentityClient {
      static {
        __name(this, "CognitoIdentity");
      }
    };
    (0, import_smithy_client144.createAggregatedClient)(commands15, CognitoIdentity);
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/commands/index.js
var init_commands16 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/commands/index.js"() {
    init_GetCredentialsForIdentityCommand();
    init_GetIdCommand();
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/models/models_0.js
var init_models_015 = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/index.js
var cognito_identity_exports = {};
__export(cognito_identity_exports, {
  CognitoIdentity: () => CognitoIdentity,
  CognitoIdentityClient: () => CognitoIdentityClient,
  CognitoIdentityServiceException: () => CognitoIdentityServiceException,
  CognitoIdentityServiceException$: () => CognitoIdentityServiceException$,
  Credentials$: () => Credentials$5,
  ExternalServiceException: () => ExternalServiceException,
  ExternalServiceException$: () => ExternalServiceException$,
  GetCredentialsForIdentity$: () => GetCredentialsForIdentity$,
  GetCredentialsForIdentityCommand: () => GetCredentialsForIdentityCommand,
  GetCredentialsForIdentityInput$: () => GetCredentialsForIdentityInput$,
  GetCredentialsForIdentityResponse$: () => GetCredentialsForIdentityResponse$,
  GetId$: () => GetId$,
  GetIdCommand: () => GetIdCommand,
  GetIdInput$: () => GetIdInput$,
  GetIdResponse$: () => GetIdResponse$,
  InternalErrorException: () => InternalErrorException,
  InternalErrorException$: () => InternalErrorException$,
  InvalidIdentityPoolConfigurationException: () => InvalidIdentityPoolConfigurationException,
  InvalidIdentityPoolConfigurationException$: () => InvalidIdentityPoolConfigurationException$,
  InvalidParameterException: () => InvalidParameterException,
  InvalidParameterException$: () => InvalidParameterException$,
  LimitExceededException: () => LimitExceededException,
  LimitExceededException$: () => LimitExceededException$,
  NotAuthorizedException: () => NotAuthorizedException,
  NotAuthorizedException$: () => NotAuthorizedException$,
  ResourceConflictException: () => ResourceConflictException,
  ResourceConflictException$: () => ResourceConflictException$,
  ResourceNotFoundException: () => ResourceNotFoundException5,
  ResourceNotFoundException$: () => ResourceNotFoundException$5,
  TooManyRequestsException: () => TooManyRequestsException5,
  TooManyRequestsException$: () => TooManyRequestsException$5,
  __Client: () => import_smithy_client141.Client,
  errorTypeRegistries: () => errorTypeRegistries15
});
var init_cognito_identity = __esm({
  "../../node_modules/@aws-sdk/nested-clients/dist-es/submodules/cognito-identity/index.js"() {
    init_CognitoIdentityClient();
    init_CognitoIdentity();
    init_commands16();
    init_schemas_015();
    init_errors15();
    init_models_015();
    init_CognitoIdentityServiceException();
  }
});

// ../../node_modules/@aws-sdk/credential-provider-cognito-identity/dist-cjs/loadCognitoIdentity-C-kPrLZ4.js
var require_loadCognitoIdentity_C_kPrLZ4 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-cognito-identity/dist-cjs/loadCognitoIdentity-C-kPrLZ4.js"(exports2) {
    "use strict";
    var cognitoIdentity = (init_cognito_identity(), __toCommonJS(cognito_identity_exports));
    exports2.CognitoIdentityClient = cognitoIdentity.CognitoIdentityClient;
    exports2.GetCredentialsForIdentityCommand = cognitoIdentity.GetCredentialsForIdentityCommand;
    exports2.GetIdCommand = cognitoIdentity.GetIdCommand;
  }
});

// ../../node_modules/@aws-sdk/credential-provider-cognito-identity/dist-cjs/index.js
var require_dist_cjs124 = __commonJS({
  "../../node_modules/@aws-sdk/credential-provider-cognito-identity/dist-cjs/index.js"(exports2) {
    "use strict";
    var propertyProvider = require_dist_cjs27();
    function resolveLogins(logins) {
      return Promise.all(Object.keys(logins).reduce((arr, name) => {
        const tokenOrProvider = logins[name];
        if (typeof tokenOrProvider === "string") {
          arr.push([name, tokenOrProvider]);
        } else {
          arr.push(tokenOrProvider().then((token) => [name, token]));
        }
        return arr;
      }, [])).then((resolvedPairs) => resolvedPairs.reduce((logins2, [key, value]) => {
        logins2[key] = value;
        return logins2;
      }, {}));
    }
    __name(resolveLogins, "resolveLogins");
    function fromCognitoIdentity(parameters) {
      return async (awsIdentityProperties) => {
        parameters.logger?.debug("@aws-sdk/credential-provider-cognito-identity - fromCognitoIdentity");
        const { GetCredentialsForIdentityCommand: GetCredentialsForIdentityCommand2, CognitoIdentityClient: CognitoIdentityClient2 } = await Promise.resolve().then(function() {
          return require_loadCognitoIdentity_C_kPrLZ4();
        });
        const fromConfigs = /* @__PURE__ */ __name((property) => parameters.clientConfig?.[property] ?? parameters.parentClientConfig?.[property] ?? awsIdentityProperties?.callerClientConfig?.[property], "fromConfigs");
        const { Credentials: { AccessKeyId = throwOnMissingAccessKeyId(parameters.logger), Expiration, SecretKey = throwOnMissingSecretKey(parameters.logger), SessionToken } = throwOnMissingCredentials(parameters.logger) } = await (parameters.client ?? new CognitoIdentityClient2(Object.assign({}, parameters.clientConfig ?? {}, {
          region: fromConfigs("region"),
          profile: fromConfigs("profile"),
          userAgentAppId: fromConfigs("userAgentAppId")
        }))).send(new GetCredentialsForIdentityCommand2({
          CustomRoleArn: parameters.customRoleArn,
          IdentityId: parameters.identityId,
          Logins: parameters.logins ? await resolveLogins(parameters.logins) : void 0
        }));
        return {
          identityId: parameters.identityId,
          accessKeyId: AccessKeyId,
          secretAccessKey: SecretKey,
          sessionToken: SessionToken,
          expiration: Expiration
        };
      };
    }
    __name(fromCognitoIdentity, "fromCognitoIdentity");
    function throwOnMissingAccessKeyId(logger5) {
      throw new propertyProvider.CredentialsProviderError("Response from Amazon Cognito contained no access key ID", { logger: logger5 });
    }
    __name(throwOnMissingAccessKeyId, "throwOnMissingAccessKeyId");
    function throwOnMissingCredentials(logger5) {
      throw new propertyProvider.CredentialsProviderError("Response from Amazon Cognito contained no credentials", { logger: logger5 });
    }
    __name(throwOnMissingCredentials, "throwOnMissingCredentials");
    function throwOnMissingSecretKey(logger5) {
      throw new propertyProvider.CredentialsProviderError("Response from Amazon Cognito contained no secret key", { logger: logger5 });
    }
    __name(throwOnMissingSecretKey, "throwOnMissingSecretKey");
    var STORE_NAME = "IdentityIds";
    var IndexedDbStorage = class {
      static {
        __name(this, "IndexedDbStorage");
      }
      dbName;
      constructor(dbName = "aws:cognito-identity-ids") {
        this.dbName = dbName;
      }
      getItem(key) {
        return this.withObjectStore("readonly", (store) => {
          const req = store.get(key);
          return new Promise((resolve13) => {
            req.onerror = () => resolve13(null);
            req.onsuccess = () => resolve13(req.result ? req.result.value : null);
          });
        }).catch(() => null);
      }
      removeItem(key) {
        return this.withObjectStore("readwrite", (store) => {
          const req = store.delete(key);
          return new Promise((resolve13, reject) => {
            req.onerror = () => reject(req.error);
            req.onsuccess = () => resolve13();
          });
        });
      }
      setItem(id, value) {
        return this.withObjectStore("readwrite", (store) => {
          const req = store.put({ id, value });
          return new Promise((resolve13, reject) => {
            req.onerror = () => reject(req.error);
            req.onsuccess = () => resolve13();
          });
        });
      }
      getDb() {
        const openDbRequest = self.indexedDB.open(this.dbName, 1);
        return new Promise((resolve13, reject) => {
          openDbRequest.onsuccess = () => {
            resolve13(openDbRequest.result);
          };
          openDbRequest.onerror = () => {
            reject(openDbRequest.error);
          };
          openDbRequest.onblocked = () => {
            reject(new Error("Unable to access DB"));
          };
          openDbRequest.onupgradeneeded = () => {
            const db = openDbRequest.result;
            db.onerror = () => {
              reject(new Error("Failed to create object store"));
            };
            db.createObjectStore(STORE_NAME, { keyPath: "id" });
          };
        });
      }
      withObjectStore(mode, action) {
        return this.getDb().then((db) => {
          const tx = db.transaction(STORE_NAME, mode);
          tx.oncomplete = () => db.close();
          return new Promise((resolve13, reject) => {
            tx.onerror = () => reject(tx.error);
            resolve13(action(tx.objectStore(STORE_NAME)));
          }).catch((err) => {
            db.close();
            throw err;
          });
        });
      }
    };
    var InMemoryStorage = class {
      static {
        __name(this, "InMemoryStorage");
      }
      store;
      constructor(store = {}) {
        this.store = store;
      }
      getItem(key) {
        if (key in this.store) {
          return this.store[key];
        }
        return null;
      }
      removeItem(key) {
        delete this.store[key];
      }
      setItem(key, value) {
        this.store[key] = value;
      }
    };
    var inMemoryStorage = new InMemoryStorage();
    function localStorage2() {
      if (typeof self === "object" && self.indexedDB) {
        return new IndexedDbStorage();
      }
      if (typeof window === "object" && window.localStorage) {
        return window.localStorage;
      }
      return inMemoryStorage;
    }
    __name(localStorage2, "localStorage");
    function fromCognitoIdentityPool({ accountId, cache: cache32 = localStorage2(), client, clientConfig, customRoleArn, identityPoolId, logins, userIdentifier = !logins || Object.keys(logins).length === 0 ? "ANONYMOUS" : void 0, logger: logger5, parentClientConfig }) {
      logger5?.debug("@aws-sdk/credential-provider-cognito-identity - fromCognitoIdentity");
      const cacheKey = userIdentifier ? `aws:cognito-identity-credentials:${identityPoolId}:${userIdentifier}` : void 0;
      let provider = /* @__PURE__ */ __name(async (awsIdentityProperties) => {
        const { GetIdCommand: GetIdCommand2, CognitoIdentityClient: CognitoIdentityClient2 } = await Promise.resolve().then(function() {
          return require_loadCognitoIdentity_C_kPrLZ4();
        });
        const fromConfigs = /* @__PURE__ */ __name((property) => clientConfig?.[property] ?? parentClientConfig?.[property] ?? awsIdentityProperties?.callerClientConfig?.[property], "fromConfigs");
        const _client = client ?? new CognitoIdentityClient2(Object.assign({}, clientConfig ?? {}, {
          region: fromConfigs("region"),
          profile: fromConfigs("profile"),
          userAgentAppId: fromConfigs("userAgentAppId")
        }));
        let identityId = cacheKey && await cache32.getItem(cacheKey);
        if (!identityId) {
          const { IdentityId = throwOnMissingId(logger5) } = await _client.send(new GetIdCommand2({
            AccountId: accountId,
            IdentityPoolId: identityPoolId,
            Logins: logins ? await resolveLogins(logins) : void 0
          }));
          identityId = IdentityId;
          if (cacheKey) {
            Promise.resolve(cache32.setItem(cacheKey, identityId)).catch(() => {
            });
          }
        }
        provider = fromCognitoIdentity({
          client: _client,
          customRoleArn,
          logins,
          identityId
        });
        return provider(awsIdentityProperties);
      }, "provider");
      return (awsIdentityProperties) => provider(awsIdentityProperties).catch(async (err) => {
        if (cacheKey) {
          Promise.resolve(cache32.removeItem(cacheKey)).catch(() => {
          });
        }
        throw err;
      });
    }
    __name(fromCognitoIdentityPool, "fromCognitoIdentityPool");
    function throwOnMissingId(logger5) {
      throw new propertyProvider.CredentialsProviderError("Response from Amazon Cognito contained no identity ID", { logger: logger5 });
    }
    __name(throwOnMissingId, "throwOnMissingId");
    exports2.fromCognitoIdentity = fromCognitoIdentity;
    exports2.fromCognitoIdentityPool = fromCognitoIdentityPool;
  }
});

// ../../node_modules/@aws-sdk/credential-providers/dist-cjs/fromCognitoIdentity.js
var require_fromCognitoIdentity = __commonJS({
  "../../node_modules/@aws-sdk/credential-providers/dist-cjs/fromCognitoIdentity.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromCognitoIdentity = void 0;
    var credential_provider_cognito_identity_1 = require_dist_cjs124();
    var fromCognitoIdentity = /* @__PURE__ */ __name((options) => (0, credential_provider_cognito_identity_1.fromCognitoIdentity)({
      ...options
    }), "fromCognitoIdentity");
    exports2.fromCognitoIdentity = fromCognitoIdentity;
  }
});

// ../../node_modules/@aws-sdk/credential-providers/dist-cjs/fromCognitoIdentityPool.js
var require_fromCognitoIdentityPool = __commonJS({
  "../../node_modules/@aws-sdk/credential-providers/dist-cjs/fromCognitoIdentityPool.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromCognitoIdentityPool = void 0;
    var credential_provider_cognito_identity_1 = require_dist_cjs124();
    var fromCognitoIdentityPool = /* @__PURE__ */ __name((options) => (0, credential_provider_cognito_identity_1.fromCognitoIdentityPool)({
      ...options
    }), "fromCognitoIdentityPool");
    exports2.fromCognitoIdentityPool = fromCognitoIdentityPool;
  }
});

// ../../node_modules/@aws-sdk/credential-providers/dist-cjs/fromContainerMetadata.js
var require_fromContainerMetadata = __commonJS({
  "../../node_modules/@aws-sdk/credential-providers/dist-cjs/fromContainerMetadata.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromContainerMetadata = void 0;
    var credential_provider_imds_1 = require_dist_cjs38();
    var fromContainerMetadata = /* @__PURE__ */ __name((init) => {
      init?.logger?.debug("@smithy/credential-provider-imds", "fromContainerMetadata");
      return (0, credential_provider_imds_1.fromContainerMetadata)(init);
    }, "fromContainerMetadata");
    exports2.fromContainerMetadata = fromContainerMetadata;
  }
});

// ../../node_modules/@aws-sdk/credential-providers/dist-cjs/fromEnv.js
var require_fromEnv = __commonJS({
  "../../node_modules/@aws-sdk/credential-providers/dist-cjs/fromEnv.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromEnv = void 0;
    var credential_provider_env_1 = require_dist_cjs110();
    var fromEnv6 = /* @__PURE__ */ __name((init) => (0, credential_provider_env_1.fromEnv)(init), "fromEnv");
    exports2.fromEnv = fromEnv6;
  }
});

// ../../node_modules/@aws-sdk/credential-providers/dist-cjs/fromIni.js
var require_fromIni = __commonJS({
  "../../node_modules/@aws-sdk/credential-providers/dist-cjs/fromIni.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromIni = void 0;
    var credential_provider_ini_1 = require_dist_cjs121();
    var fromIni2 = /* @__PURE__ */ __name((init = {}) => (0, credential_provider_ini_1.fromIni)({
      ...init
    }), "fromIni");
    exports2.fromIni = fromIni2;
  }
});

// ../../node_modules/@aws-sdk/credential-providers/dist-cjs/fromInstanceMetadata.js
var require_fromInstanceMetadata = __commonJS({
  "../../node_modules/@aws-sdk/credential-providers/dist-cjs/fromInstanceMetadata.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromInstanceMetadata = void 0;
    var client_1 = (init_client8(), __toCommonJS(client_exports7));
    var credential_provider_imds_1 = require_dist_cjs38();
    var fromInstanceMetadata = /* @__PURE__ */ __name((init) => {
      init?.logger?.debug("@smithy/credential-provider-imds", "fromInstanceMetadata");
      return async () => (0, credential_provider_imds_1.fromInstanceMetadata)(init)().then((creds) => (0, client_1.setCredentialFeature)(creds, "CREDENTIALS_IMDS", "0"));
    }, "fromInstanceMetadata");
    exports2.fromInstanceMetadata = fromInstanceMetadata;
  }
});

// ../../node_modules/@aws-sdk/credential-providers/dist-cjs/fromLoginCredentials.js
var require_fromLoginCredentials = __commonJS({
  "../../node_modules/@aws-sdk/credential-providers/dist-cjs/fromLoginCredentials.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromLoginCredentials = void 0;
    var credential_provider_login_1 = require_dist_cjs116();
    var fromLoginCredentials = /* @__PURE__ */ __name((init) => (0, credential_provider_login_1.fromLoginCredentials)({
      ...init
    }), "fromLoginCredentials");
    exports2.fromLoginCredentials = fromLoginCredentials;
  }
});

// ../../node_modules/@aws-sdk/credential-providers/dist-cjs/fromNodeProviderChain.js
var require_fromNodeProviderChain = __commonJS({
  "../../node_modules/@aws-sdk/credential-providers/dist-cjs/fromNodeProviderChain.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromNodeProviderChain = void 0;
    var credential_provider_node_1 = require_dist_cjs122();
    var fromNodeProviderChain3 = /* @__PURE__ */ __name((init = {}) => (0, credential_provider_node_1.defaultProvider)({
      ...init
    }), "fromNodeProviderChain");
    exports2.fromNodeProviderChain = fromNodeProviderChain3;
  }
});

// ../../node_modules/@aws-sdk/credential-providers/dist-cjs/fromProcess.js
var require_fromProcess = __commonJS({
  "../../node_modules/@aws-sdk/credential-providers/dist-cjs/fromProcess.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromProcess = void 0;
    var credential_provider_process_1 = require_dist_cjs119();
    var fromProcess = /* @__PURE__ */ __name((init) => (0, credential_provider_process_1.fromProcess)(init), "fromProcess");
    exports2.fromProcess = fromProcess;
  }
});

// ../../node_modules/@aws-sdk/credential-providers/dist-cjs/fromSSO.js
var require_fromSSO = __commonJS({
  "../../node_modules/@aws-sdk/credential-providers/dist-cjs/fromSSO.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromSSO = void 0;
    var credential_provider_sso_1 = require_dist_cjs115();
    var fromSSO = /* @__PURE__ */ __name((init = {}) => {
      return (0, credential_provider_sso_1.fromSSO)({ ...init });
    }, "fromSSO");
    exports2.fromSSO = fromSSO;
  }
});

// ../../node_modules/@aws-sdk/credential-providers/dist-cjs/loadSts.js
var require_loadSts = __commonJS({
  "../../node_modules/@aws-sdk/credential-providers/dist-cjs/loadSts.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.STSClient = exports2.AssumeRoleCommand = void 0;
    var sts_1 = (init_sts4(), __toCommonJS(sts_exports4));
    Object.defineProperty(exports2, "AssumeRoleCommand", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return sts_1.AssumeRoleCommand;
    }, "get") });
    Object.defineProperty(exports2, "STSClient", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return sts_1.STSClient;
    }, "get") });
  }
});

// ../../node_modules/@aws-sdk/credential-providers/dist-cjs/fromTemporaryCredentials.base.js
var require_fromTemporaryCredentials_base = __commonJS({
  "../../node_modules/@aws-sdk/credential-providers/dist-cjs/fromTemporaryCredentials.base.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __setModuleDefault2 = exports2 && exports2.__setModuleDefault || (Object.create ? (function(o10, v) {
      Object.defineProperty(o10, "default", { enumerable: true, value: v });
    }) : function(o10, v) {
      o10["default"] = v;
    });
    var __importStar2 = exports2 && exports2.__importStar || /* @__PURE__ */ (function() {
      var ownKeys2 = /* @__PURE__ */ __name(function(o10) {
        ownKeys2 = Object.getOwnPropertyNames || function(o11) {
          var ar = [];
          for (var k32 in o11) if (Object.prototype.hasOwnProperty.call(o11, k32)) ar[ar.length] = k32;
          return ar;
        };
        return ownKeys2(o10);
      }, "ownKeys");
      return function(mod) {
        if (mod && mod.__esModule) return mod;
        var result2 = {};
        if (mod != null) {
          for (var k32 = ownKeys2(mod), i32 = 0; i32 < k32.length; i32++) if (k32[i32] !== "default") __createBinding3(result2, mod, k32[i32]);
        }
        __setModuleDefault2(result2, mod);
        return result2;
      };
    })();
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromTemporaryCredentials = void 0;
    var core_1 = (init_dist_es(), __toCommonJS(dist_es_exports));
    var property_provider_1 = require_dist_cjs27();
    var ASSUME_ROLE_DEFAULT_REGION = "us-east-1";
    var fromTemporaryCredentials3 = /* @__PURE__ */ __name((options, credentialDefaultProvider, regionProvider) => {
      let stsClient;
      return async (awsIdentityProperties = {}) => {
        const { callerClientConfig } = awsIdentityProperties;
        const profile = options.clientConfig?.profile ?? callerClientConfig?.profile;
        const logger5 = options.logger ?? callerClientConfig?.logger;
        logger5?.debug("@aws-sdk/credential-providers - fromTemporaryCredentials (STS)");
        const params = { ...options.params, RoleSessionName: options.params.RoleSessionName ?? "aws-sdk-js-" + Date.now() };
        if (params?.SerialNumber) {
          if (!options.mfaCodeProvider) {
            throw new property_provider_1.CredentialsProviderError(`Temporary credential requires multi-factor authentication, but no MFA code callback was provided.`, {
              tryNextLink: false,
              logger: logger5
            });
          }
          params.TokenCode = await options.mfaCodeProvider(params?.SerialNumber);
        }
        const { AssumeRoleCommand: AssumeRoleCommand10, STSClient: STSClient12 } = await Promise.resolve().then(() => __importStar2(require_loadSts()));
        if (!stsClient) {
          const defaultCredentialsOrError = typeof credentialDefaultProvider === "function" ? credentialDefaultProvider() : void 0;
          const credentialSources = [
            options.masterCredentials,
            options.clientConfig?.credentials,
            void callerClientConfig?.credentials,
            callerClientConfig?.credentialDefaultProvider?.(),
            defaultCredentialsOrError
          ];
          let credentialSource = "STS client default credentials";
          if (credentialSources[0]) {
            credentialSource = "options.masterCredentials";
          } else if (credentialSources[1]) {
            credentialSource = "options.clientConfig.credentials";
          } else if (credentialSources[2]) {
            credentialSource = "caller client's credentials";
            throw new Error("fromTemporaryCredentials recursion in callerClientConfig.credentials");
          } else if (credentialSources[3]) {
            credentialSource = "caller client's credentialDefaultProvider";
          } else if (credentialSources[4]) {
            credentialSource = "AWS SDK default credentials";
          }
          const regionSources = [
            options.clientConfig?.region,
            callerClientConfig?.region,
            await regionProvider?.({
              profile
            }),
            ASSUME_ROLE_DEFAULT_REGION
          ];
          let regionSource = "default partition's default region";
          if (regionSources[0]) {
            regionSource = "options.clientConfig.region";
          } else if (regionSources[1]) {
            regionSource = "caller client's region";
          } else if (regionSources[2]) {
            regionSource = "file or env region";
          }
          const requestHandlerSources = [
            filterRequestHandler(options.clientConfig?.requestHandler),
            filterRequestHandler(callerClientConfig?.requestHandler)
          ];
          let requestHandlerSource = "STS default requestHandler";
          if (requestHandlerSources[0]) {
            requestHandlerSource = "options.clientConfig.requestHandler";
          } else if (requestHandlerSources[1]) {
            requestHandlerSource = "caller client's requestHandler";
          }
          logger5?.debug?.(`@aws-sdk/credential-providers - fromTemporaryCredentials STS client init with ${regionSource}=${await (0, core_1.normalizeProvider)(coalesce3(regionSources))()}, ${credentialSource}, ${requestHandlerSource}.`);
          stsClient = new STSClient12({
            userAgentAppId: callerClientConfig?.userAgentAppId,
            ...options.clientConfig,
            credentials: coalesce3(credentialSources),
            logger: logger5,
            profile,
            region: coalesce3(regionSources),
            requestHandler: coalesce3(requestHandlerSources)
          });
        }
        if (options.clientPlugins) {
          for (const plugin of options.clientPlugins) {
            stsClient.middlewareStack.use(plugin);
          }
        }
        const { Credentials } = await stsClient.send(new AssumeRoleCommand10(params));
        if (!Credentials || !Credentials.AccessKeyId || !Credentials.SecretAccessKey) {
          throw new property_provider_1.CredentialsProviderError(`Invalid response from STS.assumeRole call with role ${params.RoleArn}`, {
            logger: logger5
          });
        }
        return {
          accessKeyId: Credentials.AccessKeyId,
          secretAccessKey: Credentials.SecretAccessKey,
          sessionToken: Credentials.SessionToken,
          expiration: Credentials.Expiration,
          credentialScope: Credentials.CredentialScope
        };
      };
    }, "fromTemporaryCredentials");
    exports2.fromTemporaryCredentials = fromTemporaryCredentials3;
    var filterRequestHandler = /* @__PURE__ */ __name((requestHandler) => {
      return requestHandler?.metadata?.handlerProtocol === "h2" ? void 0 : requestHandler;
    }, "filterRequestHandler");
    var coalesce3 = /* @__PURE__ */ __name((args) => {
      for (const item of args) {
        if (item !== void 0) {
          return item;
        }
      }
    }, "coalesce");
  }
});

// ../../node_modules/@aws-sdk/credential-providers/dist-cjs/fromTemporaryCredentials.js
var require_fromTemporaryCredentials = __commonJS({
  "../../node_modules/@aws-sdk/credential-providers/dist-cjs/fromTemporaryCredentials.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromTemporaryCredentials = void 0;
    var config_resolver_1 = require_dist_cjs25();
    var node_config_provider_1 = require_dist_cjs29();
    var fromNodeProviderChain_1 = require_fromNodeProviderChain();
    var fromTemporaryCredentials_base_1 = require_fromTemporaryCredentials_base();
    var fromTemporaryCredentials3 = /* @__PURE__ */ __name((options) => {
      return (0, fromTemporaryCredentials_base_1.fromTemporaryCredentials)(options, fromNodeProviderChain_1.fromNodeProviderChain, async ({ profile = process.env.AWS_PROFILE }) => (0, node_config_provider_1.loadConfig)({
        environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3.AWS_REGION, "environmentVariableSelector"),
        configFileSelector: /* @__PURE__ */ __name((profileData) => {
          return profileData.region;
        }, "configFileSelector"),
        default: /* @__PURE__ */ __name(() => void 0, "default")
      }, { ...config_resolver_1.NODE_REGION_CONFIG_FILE_OPTIONS, profile })());
    }, "fromTemporaryCredentials");
    exports2.fromTemporaryCredentials = fromTemporaryCredentials3;
  }
});

// ../../node_modules/@aws-sdk/credential-providers/dist-cjs/fromTokenFile.js
var require_fromTokenFile5 = __commonJS({
  "../../node_modules/@aws-sdk/credential-providers/dist-cjs/fromTokenFile.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromTokenFile = void 0;
    var credential_provider_web_identity_1 = require_dist_cjs120();
    var fromTokenFile = /* @__PURE__ */ __name((init = {}) => (0, credential_provider_web_identity_1.fromTokenFile)({
      ...init
    }), "fromTokenFile");
    exports2.fromTokenFile = fromTokenFile;
  }
});

// ../../node_modules/@aws-sdk/credential-providers/dist-cjs/fromWebToken.js
var require_fromWebToken5 = __commonJS({
  "../../node_modules/@aws-sdk/credential-providers/dist-cjs/fromWebToken.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromWebToken = void 0;
    var credential_provider_web_identity_1 = require_dist_cjs120();
    var fromWebToken = /* @__PURE__ */ __name((init) => (0, credential_provider_web_identity_1.fromWebToken)({
      ...init
    }), "fromWebToken");
    exports2.fromWebToken = fromWebToken;
  }
});

// ../../node_modules/@aws-sdk/credential-providers/dist-cjs/index.js
var require_dist_cjs125 = __commonJS({
  "../../node_modules/@aws-sdk/credential-providers/dist-cjs/index.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromHttp = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    tslib_1.__exportStar(require_createCredentialChain(), exports2);
    tslib_1.__exportStar(require_fromCognitoIdentity(), exports2);
    tslib_1.__exportStar(require_fromCognitoIdentityPool(), exports2);
    tslib_1.__exportStar(require_fromContainerMetadata(), exports2);
    tslib_1.__exportStar(require_fromEnv(), exports2);
    var credential_provider_http_1 = require_dist_cjs112();
    Object.defineProperty(exports2, "fromHttp", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return credential_provider_http_1.fromHttp;
    }, "get") });
    tslib_1.__exportStar(require_fromIni(), exports2);
    tslib_1.__exportStar(require_fromInstanceMetadata(), exports2);
    tslib_1.__exportStar(require_fromLoginCredentials(), exports2);
    tslib_1.__exportStar(require_fromNodeProviderChain(), exports2);
    tslib_1.__exportStar(require_fromProcess(), exports2);
    tslib_1.__exportStar(require_fromSSO(), exports2);
    tslib_1.__exportStar(require_fromTemporaryCredentials(), exports2);
    tslib_1.__exportStar(require_fromTokenFile5(), exports2);
    tslib_1.__exportStar(require_fromWebToken5(), exports2);
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/property-provider/ProviderError.js
var ProviderError6;
var init_ProviderError = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/property-provider/ProviderError.js"() {
    ProviderError6 = class _ProviderError extends Error {
      static {
        __name(this, "ProviderError");
      }
      name = "ProviderError";
      tryNextLink;
      constructor(message2, options = true) {
        let logger5;
        let tryNextLink = true;
        if (typeof options === "boolean") {
          logger5 = void 0;
          tryNextLink = options;
        } else if (options != null && typeof options === "object") {
          logger5 = options.logger;
          tryNextLink = options.tryNextLink ?? true;
        }
        super(message2);
        this.tryNextLink = tryNextLink;
        Object.setPrototypeOf(this, _ProviderError.prototype);
        logger5?.debug?.(`@smithy/property-provider ${tryNextLink ? "->" : "(!)"} ${message2}`);
      }
      static from(error4, options = true) {
        return Object.assign(new this(error4.message, options), error4);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/property-provider/CredentialsProviderError.js
var CredentialsProviderError;
var init_CredentialsProviderError = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/property-provider/CredentialsProviderError.js"() {
    init_ProviderError();
    CredentialsProviderError = class _CredentialsProviderError extends ProviderError6 {
      static {
        __name(this, "CredentialsProviderError");
      }
      name = "CredentialsProviderError";
      constructor(message2, options = true) {
        super(message2, options);
        Object.setPrototypeOf(this, _CredentialsProviderError.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/property-provider/chain.js
var chain;
var init_chain = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/property-provider/chain.js"() {
    init_ProviderError();
    chain = /* @__PURE__ */ __name((...providers) => async () => {
      if (providers.length === 0) {
        throw new ProviderError6("No providers in chain");
      }
      let lastProviderError;
      for (const provider of providers) {
        try {
          const credentials = await provider();
          return credentials;
        } catch (err) {
          lastProviderError = err;
          if (err?.tryNextLink) {
            continue;
          }
          throw err;
        }
      }
      throw lastProviderError;
    }, "chain");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/property-provider/fromValue.js
var fromValue;
var init_fromValue = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/property-provider/fromValue.js"() {
    fromValue = /* @__PURE__ */ __name((staticValue) => () => Promise.resolve(staticValue), "fromValue");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/property-provider/memoize.js
var memoize;
var init_memoize = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/property-provider/memoize.js"() {
    memoize = /* @__PURE__ */ __name((provider, isExpired, requiresRefresh) => {
      let resolved;
      let pending;
      let hasResult;
      let isConstant = false;
      const coalesceProvider = /* @__PURE__ */ __name(async () => {
        if (!pending) {
          pending = provider();
        }
        try {
          resolved = await pending;
          hasResult = true;
          isConstant = false;
        } finally {
          pending = void 0;
        }
        return resolved;
      }, "coalesceProvider");
      if (isExpired === void 0) {
        return async (options) => {
          if (!hasResult || options?.forceRefresh) {
            resolved = await coalesceProvider();
          }
          return resolved;
        };
      }
      return async (options) => {
        if (!hasResult || options?.forceRefresh) {
          resolved = await coalesceProvider();
        }
        if (isConstant) {
          return resolved;
        }
        if (requiresRefresh && !requiresRefresh(resolved)) {
          isConstant = true;
          return resolved;
        }
        if (isExpired(resolved)) {
          await coalesceProvider();
          return resolved;
        }
        return resolved;
      };
    }, "memoize");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getHomeDir.js
var import_node_os, import_node_path, homeDirCache, getHomeDirCacheKey, getHomeDir;
var init_getHomeDir = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getHomeDir.js"() {
    import_node_os = require("node:os");
    import_node_path = require("node:path");
    homeDirCache = {};
    getHomeDirCacheKey = /* @__PURE__ */ __name(() => {
      if (process && process.geteuid) {
        return `${process.geteuid()}`;
      }
      return "DEFAULT";
    }, "getHomeDirCacheKey");
    getHomeDir = /* @__PURE__ */ __name(() => {
      const { HOME, USERPROFILE, HOMEPATH, HOMEDRIVE = `C:${import_node_path.sep}` } = process.env;
      if (HOME)
        return HOME;
      if (USERPROFILE)
        return USERPROFILE;
      if (HOMEPATH)
        return `${HOMEDRIVE}${HOMEPATH}`;
      const homeDirCacheKey = getHomeDirCacheKey();
      if (!homeDirCache[homeDirCacheKey])
        homeDirCache[homeDirCacheKey] = (0, import_node_os.homedir)();
      return homeDirCache[homeDirCacheKey];
    }, "getHomeDir");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getProfileName.js
var ENV_PROFILE, DEFAULT_PROFILE, getProfileName;
var init_getProfileName = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getProfileName.js"() {
    ENV_PROFILE = "AWS_PROFILE";
    DEFAULT_PROFILE = "default";
    getProfileName = /* @__PURE__ */ __name((init) => init.profile || process.env[ENV_PROFILE] || DEFAULT_PROFILE, "getProfileName");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/constants.js
var CONFIG_PREFIX_SEPARATOR;
var init_constants3 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/constants.js"() {
    CONFIG_PREFIX_SEPARATOR = ".";
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getConfigData.js
var import_types3, getConfigData;
var init_getConfigData = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getConfigData.js"() {
    import_types3 = __toESM(require_dist_cjs());
    init_constants3();
    getConfigData = /* @__PURE__ */ __name((data3) => Object.entries(data3).filter(([key]) => {
      const indexOfSeparator = key.indexOf(CONFIG_PREFIX_SEPARATOR);
      if (indexOfSeparator === -1) {
        return false;
      }
      return Object.values(import_types3.IniSectionType).includes(key.substring(0, indexOfSeparator));
    }).reduce((acc, [key, value]) => {
      const indexOfSeparator = key.indexOf(CONFIG_PREFIX_SEPARATOR);
      const updatedKey = key.substring(0, indexOfSeparator) === import_types3.IniSectionType.PROFILE ? key.substring(indexOfSeparator + 1) : key;
      acc[updatedKey] = value;
      return acc;
    }, {
      ...data3.default && { default: data3.default }
    }), "getConfigData");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getConfigFilepath.js
var import_node_path2, ENV_CONFIG_PATH, getConfigFilepath;
var init_getConfigFilepath = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getConfigFilepath.js"() {
    import_node_path2 = require("node:path");
    init_getHomeDir();
    ENV_CONFIG_PATH = "AWS_CONFIG_FILE";
    getConfigFilepath = /* @__PURE__ */ __name(() => process.env[ENV_CONFIG_PATH] || (0, import_node_path2.join)(getHomeDir(), ".aws", "config"), "getConfigFilepath");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getCredentialsFilepath.js
var import_node_path3, ENV_CREDENTIALS_PATH, getCredentialsFilepath;
var init_getCredentialsFilepath = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getCredentialsFilepath.js"() {
    import_node_path3 = require("node:path");
    init_getHomeDir();
    ENV_CREDENTIALS_PATH = "AWS_SHARED_CREDENTIALS_FILE";
    getCredentialsFilepath = /* @__PURE__ */ __name(() => process.env[ENV_CREDENTIALS_PATH] || (0, import_node_path3.join)(getHomeDir(), ".aws", "credentials"), "getCredentialsFilepath");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/parseIni.js
var import_types4, prefixKeyRegex, profileNameBlockList, parseIni;
var init_parseIni = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/parseIni.js"() {
    import_types4 = __toESM(require_dist_cjs());
    init_constants3();
    prefixKeyRegex = /^([\w-]+)\s(["'])?([\w-@\+\.%:/]+)\2$/;
    profileNameBlockList = ["__proto__", "profile __proto__"];
    parseIni = /* @__PURE__ */ __name((iniData) => {
      const map5 = {};
      let currentSection;
      let currentSubSection;
      for (const iniLine of iniData.split(/\r?\n/)) {
        const trimmedLine = iniLine.split(/(^|\s)[;#]/)[0].trim();
        const isSection = trimmedLine[0] === "[" && trimmedLine[trimmedLine.length - 1] === "]";
        if (isSection) {
          currentSection = void 0;
          currentSubSection = void 0;
          const sectionName = trimmedLine.substring(1, trimmedLine.length - 1);
          const matches = prefixKeyRegex.exec(sectionName);
          if (matches) {
            const [, prefix, , name] = matches;
            if (Object.values(import_types4.IniSectionType).includes(prefix)) {
              currentSection = [prefix, name].join(CONFIG_PREFIX_SEPARATOR);
            }
          } else {
            currentSection = sectionName;
          }
          if (profileNameBlockList.includes(sectionName)) {
            throw new Error(`Found invalid profile name "${sectionName}"`);
          }
        } else if (currentSection) {
          const indexOfEqualsSign = trimmedLine.indexOf("=");
          if (![0, -1].includes(indexOfEqualsSign)) {
            const [name, value] = [
              trimmedLine.substring(0, indexOfEqualsSign).trim(),
              trimmedLine.substring(indexOfEqualsSign + 1).trim()
            ];
            if (value === "") {
              currentSubSection = name;
            } else {
              if (currentSubSection && iniLine.trimStart() === iniLine) {
                currentSubSection = void 0;
              }
              map5[currentSection] = map5[currentSection] || {};
              const key = currentSubSection ? [currentSubSection, name].join(CONFIG_PREFIX_SEPARATOR) : name;
              map5[currentSection][key] = value;
            }
          }
        }
      }
      return map5;
    }, "parseIni");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/readFile.js
var import_promises, filePromises, fileIntercept, readFile;
var init_readFile = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/readFile.js"() {
    import_promises = require("node:fs/promises");
    filePromises = {};
    fileIntercept = {};
    readFile = /* @__PURE__ */ __name((path47, options) => {
      if (fileIntercept[path47] !== void 0) {
        return fileIntercept[path47];
      }
      if (!filePromises[path47] || options?.ignoreCache) {
        filePromises[path47] = (0, import_promises.readFile)(path47, "utf8");
      }
      return filePromises[path47];
    }, "readFile");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/loadSharedConfigFiles.js
var import_node_path4, swallowError, loadSharedConfigFiles;
var init_loadSharedConfigFiles = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/loadSharedConfigFiles.js"() {
    import_node_path4 = require("node:path");
    init_getConfigData();
    init_getConfigFilepath();
    init_getCredentialsFilepath();
    init_getHomeDir();
    init_parseIni();
    init_readFile();
    swallowError = /* @__PURE__ */ __name(() => ({}), "swallowError");
    loadSharedConfigFiles = /* @__PURE__ */ __name(async (init = {}) => {
      const { filepath = getCredentialsFilepath(), configFilepath = getConfigFilepath() } = init;
      const homeDir = getHomeDir();
      const relativeHomeDirPrefix = "~/";
      let resolvedFilepath = filepath;
      if (filepath.startsWith(relativeHomeDirPrefix)) {
        resolvedFilepath = (0, import_node_path4.join)(homeDir, filepath.slice(2));
      }
      let resolvedConfigFilepath = configFilepath;
      if (configFilepath.startsWith(relativeHomeDirPrefix)) {
        resolvedConfigFilepath = (0, import_node_path4.join)(homeDir, configFilepath.slice(2));
      }
      const parsedFiles = await Promise.all([
        readFile(resolvedConfigFilepath, {
          ignoreCache: init.ignoreCache
        }).then(parseIni).then(getConfigData).catch(swallowError),
        readFile(resolvedFilepath, {
          ignoreCache: init.ignoreCache
        }).then(parseIni).catch(swallowError)
      ]);
      return {
        configFile: parsedFiles[0],
        credentialsFile: parsedFiles[1]
      };
    }, "loadSharedConfigFiles");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/getSelectorName.js
function getSelectorName(functionString) {
  try {
    const constants3 = new Set(Array.from(functionString.match(/([A-Z_]){3,}/g) ?? []));
    constants3.delete("CONFIG");
    constants3.delete("CONFIG_PREFIX_SEPARATOR");
    constants3.delete("ENV");
    return [...constants3].join(", ");
  } catch (e32) {
    return functionString;
  }
}
var init_getSelectorName = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/getSelectorName.js"() {
    __name(getSelectorName, "getSelectorName");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/fromEnv.js
var fromEnv;
var init_fromEnv = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/fromEnv.js"() {
    init_CredentialsProviderError();
    init_getSelectorName();
    fromEnv = /* @__PURE__ */ __name((envVarSelector, options) => async () => {
      try {
        const config2 = envVarSelector(process.env, options);
        if (config2 === void 0) {
          throw new Error();
        }
        return config2;
      } catch (e32) {
        throw new CredentialsProviderError(e32.message || `Not found in ENV: ${getSelectorName(envVarSelector.toString())}`, { logger: options?.logger });
      }
    }, "fromEnv");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/fromSharedConfigFiles.js
var fromSharedConfigFiles;
var init_fromSharedConfigFiles = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/fromSharedConfigFiles.js"() {
    init_CredentialsProviderError();
    init_getProfileName();
    init_loadSharedConfigFiles();
    init_getSelectorName();
    fromSharedConfigFiles = /* @__PURE__ */ __name((configSelector, { preferredFile = "config", ...init } = {}) => async () => {
      const profile = getProfileName(init);
      const { configFile, credentialsFile } = await loadSharedConfigFiles(init);
      const profileFromCredentials = credentialsFile[profile] || {};
      const profileFromConfig = configFile[profile] || {};
      const mergedProfile = preferredFile === "config" ? { ...profileFromCredentials, ...profileFromConfig } : { ...profileFromConfig, ...profileFromCredentials };
      try {
        const cfgFile = preferredFile === "config" ? configFile : credentialsFile;
        const configValue = configSelector(mergedProfile, cfgFile);
        if (configValue === void 0) {
          throw new Error();
        }
        return configValue;
      } catch (e32) {
        throw new CredentialsProviderError(e32.message || `Not found in config files w/ profile [${profile}]: ${getSelectorName(configSelector.toString())}`, { logger: init.logger });
      }
    }, "fromSharedConfigFiles");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/fromStatic.js
var isFunction, fromStatic;
var init_fromStatic = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/fromStatic.js"() {
    init_fromValue();
    isFunction = /* @__PURE__ */ __name((func) => typeof func === "function", "isFunction");
    fromStatic = /* @__PURE__ */ __name((defaultValue2) => isFunction(defaultValue2) ? async () => await defaultValue2() : fromValue(defaultValue2), "fromStatic");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/configLoader.js
var loadConfig;
var init_configLoader = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/configLoader.js"() {
    init_chain();
    init_memoize();
    init_fromEnv();
    init_fromSharedConfigFiles();
    init_fromStatic();
    loadConfig = /* @__PURE__ */ __name(({ environmentVariableSelector, configFileSelector, default: defaultValue2 }, configuration = {}) => {
      const { signingName, logger: logger5 } = configuration;
      const envOptions = { signingName, logger: logger5 };
      return memoize(chain(fromEnv(environmentVariableSelector, envOptions), fromSharedConfigFiles(configFileSelector, configuration), fromStatic(defaultValue2)));
    }, "loadConfig");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/transport/getSmithyContext.js
var import_types5, getSmithyContext22;
var init_getSmithyContext2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/transport/getSmithyContext.js"() {
    import_types5 = __toESM(require_dist_cjs());
    getSmithyContext22 = /* @__PURE__ */ __name((context) => context[import_types5.SMITHY_CONTEXT_KEY] || (context[import_types5.SMITHY_CONTEXT_KEY] = {}), "getSmithyContext");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/transport/httpRequest.js
function cloneQuery2(query) {
  return Object.keys(query).reduce((carry, paramName) => {
    const param = query[paramName];
    return {
      ...carry,
      [paramName]: Array.isArray(param) ? [...param] : param
    };
  }, {});
}
var HttpRequest19;
var init_httpRequest2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/transport/httpRequest.js"() {
    HttpRequest19 = class _HttpRequest {
      static {
        __name(this, "HttpRequest");
      }
      method;
      protocol;
      hostname;
      port;
      path;
      query;
      headers;
      username;
      password;
      fragment;
      body;
      constructor(options) {
        this.method = options.method || "GET";
        this.hostname = options.hostname || "localhost";
        this.port = options.port;
        this.query = options.query || {};
        this.headers = options.headers || {};
        this.body = options.body;
        this.protocol = options.protocol ? options.protocol.slice(-1) !== ":" ? `${options.protocol}:` : options.protocol : "https:";
        this.path = options.path ? options.path.charAt(0) !== "/" ? `/${options.path}` : options.path : "/";
        this.username = options.username;
        this.password = options.password;
        this.fragment = options.fragment;
      }
      static clone(request4) {
        const cloned = new _HttpRequest({
          ...request4,
          headers: { ...request4.headers }
        });
        if (cloned.query) {
          cloned.query = cloneQuery2(cloned.query);
        }
        return cloned;
      }
      static isInstance(request4) {
        if (!request4) {
          return false;
        }
        const req = request4;
        return "method" in req && "protocol" in req && "hostname" in req && "path" in req && typeof req["query"] === "object" && typeof req["headers"] === "object";
      }
      clone() {
        return _HttpRequest.clone(this);
      }
    };
    __name(cloneQuery2, "cloneQuery");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/transport/httpResponse.js
var HttpResponse9;
var init_httpResponse2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/transport/httpResponse.js"() {
    HttpResponse9 = class {
      static {
        __name(this, "HttpResponse");
      }
      statusCode;
      reason;
      headers;
      body;
      constructor(options) {
        this.statusCode = options.statusCode;
        this.reason = options.reason;
        this.headers = options.headers || {};
        this.body = options.body;
      }
      static isInstance(response) {
        if (!response)
          return false;
        const resp = response;
        return typeof resp.statusCode === "number" && typeof resp.headers === "object";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/transport/isValidHostLabel.js
var VALID_HOST_LABEL_REGEX, isValidHostLabel;
var init_isValidHostLabel = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/transport/isValidHostLabel.js"() {
    VALID_HOST_LABEL_REGEX = new RegExp(`^(?!.*-$)(?!-)[a-zA-Z0-9-]{1,63}$`);
    isValidHostLabel = /* @__PURE__ */ __name((value, allowSubDomains = false) => {
      if (!allowSubDomains) {
        return VALID_HOST_LABEL_REGEX.test(value);
      }
      const labels = value.split(".");
      for (const label of labels) {
        if (!isValidHostLabel(label)) {
          return false;
        }
      }
      return true;
    }, "isValidHostLabel");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/transport/isValidHostname.js
function isValidHostname(hostname) {
  const hostPattern = /^[a-z0-9][a-z0-9\.\-]*[a-z0-9]$/;
  return hostPattern.test(hostname);
}
var init_isValidHostname = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/transport/isValidHostname.js"() {
    __name(isValidHostname, "isValidHostname");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/transport/normalizeProvider.js
var normalizeProvider18;
var init_normalizeProvider3 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/transport/normalizeProvider.js"() {
    normalizeProvider18 = /* @__PURE__ */ __name((input) => {
      if (typeof input === "function")
        return input;
      const promisified = Promise.resolve(input);
      return () => promisified;
    }, "normalizeProvider");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/transport/parseQueryString.js
function parseQueryString(querystring) {
  const query = {};
  querystring = querystring.replace(/^\?/, "");
  if (querystring) {
    for (const pair of querystring.split("&")) {
      let [key, value = null] = pair.split("=");
      key = decodeURIComponent(key);
      if (value) {
        value = decodeURIComponent(value);
      }
      if (!(key in query)) {
        query[key] = value;
      } else if (Array.isArray(query[key])) {
        query[key].push(value);
      } else {
        query[key] = [query[key], value];
      }
    }
  }
  return query;
}
var init_parseQueryString = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/transport/parseQueryString.js"() {
    __name(parseQueryString, "parseQueryString");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/transport/parseUrl.js
var parseUrl17;
var init_parseUrl = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/transport/parseUrl.js"() {
    init_parseQueryString();
    parseUrl17 = /* @__PURE__ */ __name((url) => {
      if (typeof url === "string") {
        return parseUrl17(new URL(url));
      }
      const { hostname, pathname, port, protocol, search } = url;
      let query;
      if (search) {
        query = parseQueryString(search);
      }
      return {
        hostname,
        port: port ? parseInt(port) : void 0,
        protocol,
        path: pathname,
        query
      };
    }, "parseUrl");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/transport/toEndpointV1.js
var toEndpointV12;
var init_toEndpointV12 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/transport/toEndpointV1.js"() {
    init_parseUrl();
    toEndpointV12 = /* @__PURE__ */ __name((endpoint) => {
      if (typeof endpoint === "object") {
        if ("url" in endpoint) {
          const v1Endpoint = parseUrl17(endpoint.url);
          if (endpoint.headers) {
            v1Endpoint.headers = {};
            for (const name in endpoint.headers) {
              v1Endpoint.headers[name.toLowerCase()] = endpoint.headers[name].join(", ");
            }
          }
          return v1Endpoint;
        }
        return endpoint;
      }
      return parseUrl17(endpoint);
    }, "toEndpointV1");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/transport/index.js
var init_transport2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/transport/index.js"() {
    init_getSmithyContext2();
    init_httpRequest2();
    init_httpResponse2();
    init_isValidHostLabel();
    init_isValidHostname();
    init_normalizeProvider3();
    init_parseQueryString();
    init_parseUrl();
    init_toEndpointV12();
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/deref.js
var deref2;
var init_deref2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/deref.js"() {
    deref2 = /* @__PURE__ */ __name((schemaRef) => {
      if (typeof schemaRef === "function") {
        return schemaRef();
      }
      return schemaRef;
    }, "deref");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/schemas/operation.js
var init_operation2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/schemas/operation.js"() {
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/middleware/getSchemaSerdePlugin.js
var init_getSchemaSerdePlugin2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/middleware/getSchemaSerdePlugin.js"() {
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/schemas/Schema.js
var init_Schema2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/schemas/Schema.js"() {
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/schemas/ListSchema.js
var init_ListSchema2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/schemas/ListSchema.js"() {
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/schemas/MapSchema.js
var init_MapSchema2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/schemas/MapSchema.js"() {
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/schemas/OperationSchema.js
var init_OperationSchema2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/schemas/OperationSchema.js"() {
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/schemas/StructureSchema.js
var init_StructureSchema2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/schemas/StructureSchema.js"() {
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/schemas/ErrorSchema.js
var init_ErrorSchema2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/schemas/ErrorSchema.js"() {
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/schemas/translateTraits.js
function translateTraits2(indicator) {
  if (typeof indicator === "object") {
    return indicator;
  }
  indicator = indicator | 0;
  if (traitsCache2[indicator]) {
    return traitsCache2[indicator];
  }
  const traits = {};
  let i32 = 0;
  for (const trait of [
    "httpLabel",
    "idempotent",
    "idempotencyToken",
    "sensitive",
    "httpPayload",
    "httpResponseCode",
    "httpQueryParams"
  ]) {
    if ((indicator >> i32++ & 1) === 1) {
      traits[trait] = 1;
    }
  }
  return traitsCache2[indicator] = traits;
}
var traitsCache2;
var init_translateTraits2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/schemas/translateTraits.js"() {
    traitsCache2 = [];
    __name(translateTraits2, "translateTraits");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/schemas/NormalizedSchema.js
function member2(memberSchema, memberName) {
  if (memberSchema instanceof NormalizedSchema2) {
    return Object.assign(memberSchema, {
      memberName,
      _isMemberSchema: true
    });
  }
  const internalCtorAccess = NormalizedSchema2;
  return new internalCtorAccess(memberSchema, memberName);
}
var anno2, simpleSchemaCacheN2, simpleSchemaCacheS2, NormalizedSchema2, isMemberSchema2, isStaticSchema2;
var init_NormalizedSchema2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/schemas/NormalizedSchema.js"() {
    init_deref2();
    init_translateTraits2();
    anno2 = {
      it: /* @__PURE__ */ Symbol.for("@smithy/nor-struct-it"),
      ns: /* @__PURE__ */ Symbol.for("@smithy/ns")
    };
    simpleSchemaCacheN2 = [];
    simpleSchemaCacheS2 = {};
    NormalizedSchema2 = class _NormalizedSchema {
      static {
        __name(this, "NormalizedSchema");
      }
      ref;
      memberName;
      static symbol = /* @__PURE__ */ Symbol.for("@smithy/nor");
      symbol = _NormalizedSchema.symbol;
      name;
      schema;
      _isMemberSchema;
      traits;
      memberTraits;
      normalizedTraits;
      constructor(ref, memberName) {
        this.ref = ref;
        this.memberName = memberName;
        const traitStack = [];
        let _ref = ref;
        let schema = ref;
        this._isMemberSchema = false;
        while (isMemberSchema2(_ref)) {
          traitStack.push(_ref[1]);
          _ref = _ref[0];
          schema = deref2(_ref);
          this._isMemberSchema = true;
        }
        if (traitStack.length > 0) {
          this.memberTraits = {};
          for (let i32 = traitStack.length - 1; i32 >= 0; --i32) {
            const traitSet = traitStack[i32];
            Object.assign(this.memberTraits, translateTraits2(traitSet));
          }
        } else {
          this.memberTraits = 0;
        }
        if (schema instanceof _NormalizedSchema) {
          const computedMemberTraits = this.memberTraits;
          Object.assign(this, schema);
          this.memberTraits = Object.assign({}, computedMemberTraits, schema.getMemberTraits(), this.getMemberTraits());
          this.normalizedTraits = void 0;
          this.memberName = memberName ?? schema.memberName;
          return;
        }
        this.schema = deref2(schema);
        if (isStaticSchema2(this.schema)) {
          this.name = `${this.schema[1]}#${this.schema[2]}`;
          this.traits = this.schema[3];
        } else {
          this.name = this.memberName ?? String(schema);
          this.traits = 0;
        }
        if (this._isMemberSchema && !memberName) {
          throw new Error(`@smithy/core/schema - NormalizedSchema member init ${this.getName(true)} missing member name.`);
        }
      }
      static [Symbol.hasInstance](lhs) {
        const isPrototype = this.prototype.isPrototypeOf(lhs);
        if (!isPrototype && typeof lhs === "object" && lhs !== null) {
          const ns = lhs;
          return ns.symbol === this.symbol;
        }
        return isPrototype;
      }
      static of(ref) {
        const keyAble = typeof ref === "function" || typeof ref === "object" && ref !== null;
        if (typeof ref === "number") {
          if (simpleSchemaCacheN2[ref]) {
            return simpleSchemaCacheN2[ref];
          }
        } else if (typeof ref === "string") {
          if (simpleSchemaCacheS2[ref]) {
            return simpleSchemaCacheS2[ref];
          }
        } else if (keyAble) {
          if (ref[anno2.ns]) {
            return ref[anno2.ns];
          }
        }
        const sc = deref2(ref);
        if (sc instanceof _NormalizedSchema) {
          return sc;
        }
        if (isMemberSchema2(sc)) {
          const [ns2, traits] = sc;
          if (ns2 instanceof _NormalizedSchema) {
            Object.assign(ns2.getMergedTraits(), translateTraits2(traits));
            return ns2;
          }
          throw new Error(`@smithy/core/schema - may not init unwrapped member schema=${JSON.stringify(ref, null, 2)}.`);
        }
        const ns = new _NormalizedSchema(sc);
        if (keyAble) {
          return ref[anno2.ns] = ns;
        }
        if (typeof sc === "string") {
          return simpleSchemaCacheS2[sc] = ns;
        }
        if (typeof sc === "number") {
          return simpleSchemaCacheN2[sc] = ns;
        }
        return ns;
      }
      getSchema() {
        const sc = this.schema;
        if (Array.isArray(sc) && sc[0] === 0) {
          return sc[4];
        }
        return sc;
      }
      getName(withNamespace = false) {
        const { name } = this;
        const short = !withNamespace && name && name.includes("#");
        return short ? name.split("#")[1] : name || void 0;
      }
      getMemberName() {
        return this.memberName;
      }
      isMemberSchema() {
        return this._isMemberSchema;
      }
      isListSchema() {
        const sc = this.getSchema();
        return typeof sc === "number" ? sc >= 64 && sc < 128 : sc[0] === 1;
      }
      isMapSchema() {
        const sc = this.getSchema();
        return typeof sc === "number" ? sc >= 128 && sc <= 255 : sc[0] === 2;
      }
      isStructSchema() {
        const sc = this.getSchema();
        if (typeof sc !== "object") {
          return false;
        }
        const id = sc[0];
        return id === 3 || id === -3 || id === 4;
      }
      isUnionSchema() {
        const sc = this.getSchema();
        if (typeof sc !== "object") {
          return false;
        }
        return sc[0] === 4;
      }
      isBlobSchema() {
        const sc = this.getSchema();
        return sc === 21 || sc === 42;
      }
      isTimestampSchema() {
        const sc = this.getSchema();
        return typeof sc === "number" && sc >= 4 && sc <= 7;
      }
      isUnitSchema() {
        return this.getSchema() === "unit";
      }
      isDocumentSchema() {
        return this.getSchema() === 15;
      }
      isStringSchema() {
        return this.getSchema() === 0;
      }
      isBooleanSchema() {
        return this.getSchema() === 2;
      }
      isNumericSchema() {
        return this.getSchema() === 1;
      }
      isBigIntegerSchema() {
        return this.getSchema() === 17;
      }
      isBigDecimalSchema() {
        return this.getSchema() === 19;
      }
      isStreaming() {
        const { streaming } = this.getMergedTraits();
        return !!streaming || this.getSchema() === 42;
      }
      isIdempotencyToken() {
        return !!this.getMergedTraits().idempotencyToken;
      }
      getMergedTraits() {
        return this.normalizedTraits ?? (this.normalizedTraits = {
          ...this.getOwnTraits(),
          ...this.getMemberTraits()
        });
      }
      getMemberTraits() {
        return translateTraits2(this.memberTraits);
      }
      getOwnTraits() {
        return translateTraits2(this.traits);
      }
      getKeySchema() {
        const [isDoc, isMap] = [this.isDocumentSchema(), this.isMapSchema()];
        if (!isDoc && !isMap) {
          throw new Error(`@smithy/core/schema - cannot get key for non-map: ${this.getName(true)}`);
        }
        const schema = this.getSchema();
        const memberSchema = isDoc ? 15 : schema[4] ?? 0;
        return member2([memberSchema, 0], "key");
      }
      getValueSchema() {
        const sc = this.getSchema();
        const [isDoc, isMap, isList] = [this.isDocumentSchema(), this.isMapSchema(), this.isListSchema()];
        const memberSchema = typeof sc === "number" ? 63 & sc : sc && typeof sc === "object" && (isMap || isList) ? sc[3 + sc[0]] : isDoc ? 15 : void 0;
        if (memberSchema != null) {
          return member2([memberSchema, 0], isMap ? "value" : "member");
        }
        throw new Error(`@smithy/core/schema - ${this.getName(true)} has no value member.`);
      }
      getMemberSchema(memberName) {
        const struct3 = this.getSchema();
        if (this.isStructSchema() && struct3[4].includes(memberName)) {
          const i32 = struct3[4].indexOf(memberName);
          const memberSchema = struct3[5][i32];
          return member2(isMemberSchema2(memberSchema) ? memberSchema : [memberSchema, 0], memberName);
        }
        if (this.isDocumentSchema()) {
          return member2([15, 0], memberName);
        }
        throw new Error(`@smithy/core/schema - ${this.getName(true)} has no member=${memberName}.`);
      }
      getMemberSchemas() {
        const buffer = {};
        try {
          for (const [k32, v] of this.structIterator()) {
            buffer[k32] = v;
          }
        } catch (ignored) {
        }
        return buffer;
      }
      getEventStreamMember() {
        if (this.isStructSchema()) {
          for (const [memberName, memberSchema] of this.structIterator()) {
            if (memberSchema.isStreaming() && memberSchema.isStructSchema()) {
              return memberName;
            }
          }
        }
        return "";
      }
      *structIterator() {
        if (this.isUnitSchema()) {
          return;
        }
        if (!this.isStructSchema()) {
          throw new Error("@smithy/core/schema - cannot iterate non-struct schema.");
        }
        const struct3 = this.getSchema();
        const z = struct3[4].length;
        let it = struct3[anno2.it];
        if (it && z === it.length) {
          yield* it;
          return;
        }
        it = Array(z);
        for (let i32 = 0; i32 < z; ++i32) {
          const k32 = struct3[4][i32];
          const v = member2([struct3[5][i32], 0], k32);
          yield it[i32] = [k32, v];
        }
        struct3[anno2.it] = it;
      }
    };
    __name(member2, "member");
    isMemberSchema2 = /* @__PURE__ */ __name((sc) => Array.isArray(sc) && sc.length === 2, "isMemberSchema");
    isStaticSchema2 = /* @__PURE__ */ __name((sc) => Array.isArray(sc) && sc.length >= 5, "isStaticSchema");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/schemas/SimpleSchema.js
var init_SimpleSchema2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/schemas/SimpleSchema.js"() {
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/schemas/sentinels.js
var init_sentinels2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/schemas/sentinels.js"() {
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/TypeRegistry.js
var TypeRegistry2;
var init_TypeRegistry2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/TypeRegistry.js"() {
    TypeRegistry2 = class _TypeRegistry {
      static {
        __name(this, "TypeRegistry");
      }
      namespace;
      schemas;
      exceptions;
      static registries = /* @__PURE__ */ new Map();
      constructor(namespace, schemas = /* @__PURE__ */ new Map(), exceptions = /* @__PURE__ */ new Map()) {
        this.namespace = namespace;
        this.schemas = schemas;
        this.exceptions = exceptions;
      }
      static for(namespace) {
        if (!_TypeRegistry.registries.has(namespace)) {
          _TypeRegistry.registries.set(namespace, new _TypeRegistry(namespace));
        }
        return _TypeRegistry.registries.get(namespace);
      }
      copyFrom(other) {
        const { schemas, exceptions } = this;
        for (const [k32, v] of other.schemas) {
          if (!schemas.has(k32)) {
            schemas.set(k32, v);
          }
        }
        for (const [k32, v] of other.exceptions) {
          if (!exceptions.has(k32)) {
            exceptions.set(k32, v);
          }
        }
      }
      register(shapeId, schema) {
        const qualifiedName = this.normalizeShapeId(shapeId);
        for (const r32 of [this, _TypeRegistry.for(qualifiedName.split("#")[0])]) {
          r32.schemas.set(qualifiedName, schema);
        }
      }
      getSchema(shapeId) {
        const id = this.normalizeShapeId(shapeId);
        if (!this.schemas.has(id)) {
          if (!shapeId.includes("#")) {
            const suffix = "#" + shapeId;
            const candidates = [];
            for (const [shapeId2, schema] of this.schemas.entries()) {
              if (shapeId2.endsWith(suffix)) {
                candidates.push(schema);
              }
            }
            if (candidates.length === 1) {
              return candidates[0];
            }
          }
          throw new Error(`@smithy/core/schema - schema not found for ${id}`);
        }
        return this.schemas.get(id);
      }
      registerError(es, ctor) {
        const $error = es;
        const ns = $error[1];
        for (const r32 of [this, _TypeRegistry.for(ns)]) {
          r32.schemas.set(ns + "#" + $error[2], $error);
          r32.exceptions.set($error, ctor);
        }
      }
      getErrorCtor(es) {
        const $error = es;
        if (this.exceptions.has($error)) {
          return this.exceptions.get($error);
        }
        const registry = _TypeRegistry.for($error[1]);
        return registry.exceptions.get($error);
      }
      getBaseException() {
        for (const exceptionKey of this.exceptions.keys()) {
          if (Array.isArray(exceptionKey)) {
            const [, ns, name] = exceptionKey;
            const id = ns + "#" + name;
            if (id.startsWith("smithy.ts.sdk.synthetic.") && id.endsWith("ServiceException")) {
              return exceptionKey;
            }
          }
        }
        return void 0;
      }
      find(predicate) {
        for (const schema of this.schemas.values()) {
          if (predicate(schema)) {
            return schema;
          }
        }
        return void 0;
      }
      clear() {
        this.schemas.clear();
        this.exceptions.clear();
      }
      normalizeShapeId(shapeId) {
        if (shapeId.includes("#")) {
          return shapeId;
        }
        return this.namespace + "#" + shapeId;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/index.js
var init_schema5 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/schema/index.js"() {
    init_deref2();
    init_getSchemaSerdePlugin2();
    init_ListSchema2();
    init_MapSchema2();
    init_OperationSchema2();
    init_operation2();
    init_ErrorSchema2();
    init_NormalizedSchema2();
    init_Schema2();
    init_SimpleSchema2();
    init_StructureSchema2();
    init_sentinels2();
    init_translateTraits2();
    init_TypeRegistry2();
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/client/index.js
var init_client9 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/client/index.js"() {
    init_transport2();
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/index.js
var init_config2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/config/index.js"() {
    init_constants3();
    init_configLoader();
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/getEndpointUrlConfig.js
var ENV_ENDPOINT_URL, CONFIG_ENDPOINT_URL, getEndpointUrlConfig;
var init_getEndpointUrlConfig = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/getEndpointUrlConfig.js"() {
    init_config2();
    ENV_ENDPOINT_URL = "AWS_ENDPOINT_URL";
    CONFIG_ENDPOINT_URL = "endpoint_url";
    getEndpointUrlConfig = /* @__PURE__ */ __name((serviceId) => ({
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => {
        const serviceSuffixParts = serviceId.split(" ").map((w) => w.toUpperCase());
        const serviceEndpointUrl = env3[[ENV_ENDPOINT_URL, ...serviceSuffixParts].join("_")];
        if (serviceEndpointUrl)
          return serviceEndpointUrl;
        const endpointUrl = env3[ENV_ENDPOINT_URL];
        if (endpointUrl)
          return endpointUrl;
        return void 0;
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile, config2) => {
        if (config2 && profile.services) {
          const servicesSection = config2[["services", profile.services].join(CONFIG_PREFIX_SEPARATOR)];
          if (servicesSection) {
            const servicePrefixParts = serviceId.split(" ").map((w) => w.toLowerCase());
            const endpointUrl2 = servicesSection[[servicePrefixParts.join("_"), CONFIG_ENDPOINT_URL].join(CONFIG_PREFIX_SEPARATOR)];
            if (endpointUrl2)
              return endpointUrl2;
          }
        }
        const endpointUrl = profile[CONFIG_ENDPOINT_URL];
        if (endpointUrl)
          return endpointUrl;
        return void 0;
      }, "configFileSelector"),
      default: void 0
    }), "getEndpointUrlConfig");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/getEndpointFromConfig.js
var getEndpointFromConfig;
var init_getEndpointFromConfig = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/getEndpointFromConfig.js"() {
    init_config2();
    init_getEndpointUrlConfig();
    getEndpointFromConfig = /* @__PURE__ */ __name(async (serviceId) => loadConfig(getEndpointUrlConfig(serviceId ?? ""))(), "getEndpointFromConfig");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/service-customizations/s3.js
var resolveParamsForS3, DOMAIN_PATTERN, IP_ADDRESS_PATTERN, DOTS_PATTERN, isDnsCompatibleBucketName, isArnBucketName;
var init_s3 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/service-customizations/s3.js"() {
    resolveParamsForS3 = /* @__PURE__ */ __name(async (endpointParams) => {
      const bucket = endpointParams?.Bucket || "";
      if (typeof endpointParams.Bucket === "string") {
        endpointParams.Bucket = bucket.replace(/#/g, encodeURIComponent("#")).replace(/\?/g, encodeURIComponent("?"));
      }
      if (isArnBucketName(bucket)) {
        if (endpointParams.ForcePathStyle === true) {
          throw new Error("Path-style addressing cannot be used with ARN buckets");
        }
      } else if (!isDnsCompatibleBucketName(bucket) || bucket.indexOf(".") !== -1 && !String(endpointParams.Endpoint).startsWith("http:") || bucket.toLowerCase() !== bucket || bucket.length < 3) {
        endpointParams.ForcePathStyle = true;
      }
      if (endpointParams.DisableMultiRegionAccessPoints) {
        endpointParams.disableMultiRegionAccessPoints = true;
        endpointParams.DisableMRAP = true;
      }
      return endpointParams;
    }, "resolveParamsForS3");
    DOMAIN_PATTERN = /^[a-z0-9][a-z0-9\.\-]{1,61}[a-z0-9]$/;
    IP_ADDRESS_PATTERN = /(\d+\.){3}\d+/;
    DOTS_PATTERN = /\.\./;
    isDnsCompatibleBucketName = /* @__PURE__ */ __name((bucketName) => DOMAIN_PATTERN.test(bucketName) && !IP_ADDRESS_PATTERN.test(bucketName) && !DOTS_PATTERN.test(bucketName), "isDnsCompatibleBucketName");
    isArnBucketName = /* @__PURE__ */ __name((bucketName) => {
      const [arn, partition4, service, , , bucket] = bucketName.split(":");
      const isArn = arn === "arn" && bucketName.split(":").length >= 6;
      const isValidArn = Boolean(isArn && partition4 && service && bucket);
      if (isArn && !isValidArn) {
        throw new Error(`Invalid ARN: ${bucketName} was an invalid ARN.`);
      }
      return isValidArn;
    }, "isArnBucketName");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/service-customizations/index.js
var init_service_customizations = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/service-customizations/index.js"() {
    init_s3();
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/createConfigValueProvider.js
var createConfigValueProvider;
var init_createConfigValueProvider = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/createConfigValueProvider.js"() {
    createConfigValueProvider = /* @__PURE__ */ __name((configKey, canonicalEndpointParamKey, config2, isClientContextParam = false) => {
      const configProvider = /* @__PURE__ */ __name(async () => {
        let configValue;
        if (isClientContextParam) {
          const clientContextParams = config2.clientContextParams;
          const nestedValue = clientContextParams?.[configKey];
          configValue = nestedValue ?? config2[configKey] ?? config2[canonicalEndpointParamKey];
        } else {
          configValue = config2[configKey] ?? config2[canonicalEndpointParamKey];
        }
        if (typeof configValue === "function") {
          return configValue();
        }
        return configValue;
      }, "configProvider");
      if (configKey === "credentialScope" || canonicalEndpointParamKey === "CredentialScope") {
        return async () => {
          const credentials = typeof config2.credentials === "function" ? await config2.credentials() : config2.credentials;
          const configValue = credentials?.credentialScope ?? credentials?.CredentialScope;
          return configValue;
        };
      }
      if (configKey === "accountId" || canonicalEndpointParamKey === "AccountId") {
        return async () => {
          const credentials = typeof config2.credentials === "function" ? await config2.credentials() : config2.credentials;
          const configValue = credentials?.accountId ?? credentials?.AccountId;
          return configValue;
        };
      }
      if (configKey === "endpoint" || canonicalEndpointParamKey === "endpoint") {
        return async () => {
          if (config2.isCustomEndpoint === false) {
            return void 0;
          }
          const endpoint = await configProvider();
          if (endpoint && typeof endpoint === "object") {
            if ("url" in endpoint) {
              return endpoint.url.href;
            }
            if ("hostname" in endpoint) {
              const { protocol, hostname, port, path: path47 } = endpoint;
              return `${protocol}//${hostname}${port ? ":" + port : ""}${path47}`;
            }
          }
          return endpoint;
        };
      }
      return configProvider;
    }, "createConfigValueProvider");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/toEndpointV1.js
var init_toEndpointV13 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/toEndpointV1.js"() {
    init_transport2();
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/getEndpointFromInstructions.js
function bindGetEndpointFromInstructions(getEndpointFromConfig5) {
  return async (commandInput, instructionsSupplier, clientConfig, context) => {
    if (!clientConfig.isCustomEndpoint) {
      let endpointFromConfig;
      if (clientConfig.serviceConfiguredEndpoint) {
        endpointFromConfig = await clientConfig.serviceConfiguredEndpoint();
      } else {
        endpointFromConfig = await getEndpointFromConfig5(clientConfig.serviceId);
      }
      if (endpointFromConfig) {
        clientConfig.endpoint = () => Promise.resolve(toEndpointV12(endpointFromConfig));
        clientConfig.isCustomEndpoint = true;
      }
    }
    const endpointParams = await resolveParams5(commandInput, instructionsSupplier, clientConfig);
    if (typeof clientConfig.endpointProvider !== "function") {
      throw new Error("config.endpointProvider is not set.");
    }
    const endpoint = clientConfig.endpointProvider(endpointParams, context);
    if (clientConfig.isCustomEndpoint && clientConfig.endpoint) {
      const customEndpoint = await clientConfig.endpoint();
      if (customEndpoint?.headers) {
        endpoint.headers ??= {};
        for (const [name, value] of Object.entries(customEndpoint.headers)) {
          endpoint.headers[name] = Array.isArray(value) ? value : [value];
        }
      }
    }
    return endpoint;
  };
}
var resolveParams5;
var init_getEndpointFromInstructions = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/getEndpointFromInstructions.js"() {
    init_service_customizations();
    init_createConfigValueProvider();
    init_toEndpointV13();
    __name(bindGetEndpointFromInstructions, "bindGetEndpointFromInstructions");
    resolveParams5 = /* @__PURE__ */ __name(async (commandInput, instructionsSupplier, clientConfig) => {
      const endpointParams = {};
      const instructions = instructionsSupplier?.getEndpointParameterInstructions?.() || {};
      for (const [name, instruction] of Object.entries(instructions)) {
        switch (instruction.type) {
          case "staticContextParams":
            endpointParams[name] = instruction.value;
            break;
          case "contextParams":
            endpointParams[name] = commandInput[instruction.name];
            break;
          case "clientContextParams":
          case "builtInParams":
            endpointParams[name] = await createConfigValueProvider(instruction.name, name, clientConfig, instruction.type !== "builtInParams")();
            break;
          case "operationContextParams":
            endpointParams[name] = instruction.get(commandInput);
            break;
          default:
            throw new Error("Unrecognized endpoint parameter instruction: " + JSON.stringify(instruction));
        }
      }
      if (Object.keys(instructions).length === 0) {
        Object.assign(endpointParams, clientConfig);
      }
      if (String(clientConfig.serviceId).toLowerCase() === "s3") {
        await resolveParamsForS3(endpointParams);
      }
      return endpointParams;
    }, "resolveParams");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/endpointMiddleware.js
function setFeature9(context, feature, value) {
  if (!context.__smithy_context) {
    context.__smithy_context = { features: {} };
  } else if (!context.__smithy_context.features) {
    context.__smithy_context.features = {};
  }
  context.__smithy_context.features[feature] = value;
}
function bindEndpointMiddleware(getEndpointFromConfig5) {
  const getEndpointFromInstructions7 = bindGetEndpointFromInstructions(getEndpointFromConfig5);
  return ({ config: config2, instructions }) => {
    return (next, context) => async (args) => {
      if (config2.isCustomEndpoint) {
        setFeature9(context, "ENDPOINT_OVERRIDE", "N");
      }
      const endpoint = await getEndpointFromInstructions7(args.input, {
        getEndpointParameterInstructions() {
          return instructions;
        }
      }, { ...config2 }, context);
      context.endpointV2 = endpoint;
      context.authSchemes = endpoint.properties?.authSchemes;
      const authScheme = context.authSchemes?.[0];
      if (authScheme) {
        context["signing_region"] = authScheme.signingRegion;
        context["signing_service"] = authScheme.signingName;
        const smithyContext = getSmithyContext22(context);
        const httpAuthOption = smithyContext?.selectedHttpAuthScheme?.httpAuthOption;
        if (httpAuthOption) {
          httpAuthOption.signingProperties = Object.assign(httpAuthOption.signingProperties || {}, {
            signing_region: authScheme.signingRegion,
            signingRegion: authScheme.signingRegion,
            signing_service: authScheme.signingName,
            signingName: authScheme.signingName,
            signingRegionSet: authScheme.signingRegionSet
          }, authScheme.properties);
        }
      }
      return next({
        ...args
      });
    };
  };
}
var init_endpointMiddleware = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/endpointMiddleware.js"() {
    init_client9();
    init_getEndpointFromInstructions();
    __name(setFeature9, "setFeature");
    __name(bindEndpointMiddleware, "bindEndpointMiddleware");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/getEndpointPlugin.js
function bindGetEndpointPlugin(getEndpointFromConfig5) {
  const endpointMiddleware5 = bindEndpointMiddleware(getEndpointFromConfig5);
  return (config2, instructions) => ({
    applyToStack: /* @__PURE__ */ __name((clientStack) => {
      clientStack.addRelativeTo(endpointMiddleware5({
        config: config2,
        instructions
      }), endpointMiddlewareOptions);
    }, "applyToStack")
  });
}
var serializerMiddlewareOption2, endpointMiddlewareOptions;
var init_getEndpointPlugin = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/getEndpointPlugin.js"() {
    init_endpointMiddleware();
    serializerMiddlewareOption2 = {
      name: "serializerMiddleware",
      step: "serialize",
      tags: ["SERIALIZER"],
      override: true
    };
    endpointMiddlewareOptions = {
      step: "serialize",
      tags: ["ENDPOINT_PARAMETERS", "ENDPOINT_V2", "ENDPOINT"],
      name: "endpointV2Middleware",
      override: true,
      relation: "before",
      toMiddleware: serializerMiddlewareOption2.name
    };
    __name(bindGetEndpointPlugin, "bindGetEndpointPlugin");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/resolveEndpointConfig.js
function bindResolveEndpointConfig(getEndpointFromConfig5) {
  return (input) => {
    const tls = input.tls ?? true;
    const { endpoint, useDualstackEndpoint, useFipsEndpoint } = input;
    const customEndpointProvider = endpoint != null ? async () => toEndpointV12(await normalizeProvider18(endpoint)()) : void 0;
    const isCustomEndpoint = !!endpoint;
    const resolvedConfig = Object.assign(input, {
      endpoint: customEndpointProvider,
      tls,
      isCustomEndpoint,
      useDualstackEndpoint: normalizeProvider18(useDualstackEndpoint ?? false),
      useFipsEndpoint: normalizeProvider18(useFipsEndpoint ?? false)
    });
    let configuredEndpointPromise = void 0;
    resolvedConfig.serviceConfiguredEndpoint = async () => {
      if (input.serviceId && !configuredEndpointPromise) {
        configuredEndpointPromise = getEndpointFromConfig5(input.serviceId);
      }
      return configuredEndpointPromise;
    };
    return resolvedConfig;
  };
}
var init_resolveEndpointConfig = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/resolveEndpointConfig.js"() {
    init_transport2();
    init_toEndpointV13();
    __name(bindResolveEndpointConfig, "bindResolveEndpointConfig");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/bdd/BinaryDecisionDiagram.js
var BinaryDecisionDiagram16;
var init_BinaryDecisionDiagram = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/bdd/BinaryDecisionDiagram.js"() {
    BinaryDecisionDiagram16 = class _BinaryDecisionDiagram {
      static {
        __name(this, "BinaryDecisionDiagram");
      }
      nodes;
      root;
      conditions;
      results;
      constructor(bdd32, root32, conditions, results) {
        this.nodes = bdd32;
        this.root = root32;
        this.conditions = conditions;
        this.results = results;
      }
      static from(bdd32, root32, conditions, results) {
        return new _BinaryDecisionDiagram(bdd32, root32, conditions, results);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/cache/EndpointCache.js
var EndpointCache16;
var init_EndpointCache = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/cache/EndpointCache.js"() {
    EndpointCache16 = class {
      static {
        __name(this, "EndpointCache");
      }
      capacity;
      data = /* @__PURE__ */ new Map();
      parameters = [];
      constructor({ size, params }) {
        this.capacity = size ?? 50;
        if (params) {
          this.parameters = params;
        }
      }
      get(endpointParams, resolver) {
        const key = this.hash(endpointParams);
        if (key === false) {
          return resolver();
        }
        if (!this.data.has(key)) {
          if (this.data.size > this.capacity + 10) {
            const keys = this.data.keys();
            let i32 = 0;
            while (true) {
              const { value, done } = keys.next();
              this.data.delete(value);
              if (done || ++i32 > 10) {
                break;
              }
            }
          }
          this.data.set(key, resolver());
        }
        return this.data.get(key);
      }
      size() {
        return this.data.size;
      }
      hash(endpointParams) {
        let buffer = "";
        const { parameters } = this;
        if (parameters.length === 0) {
          return false;
        }
        for (const param of parameters) {
          const val = String(endpointParams[param] ?? "");
          if (val.includes("|;")) {
            return false;
          }
          buffer += val + "|;";
        }
        return buffer;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/EndpointError.js
var EndpointError;
var init_EndpointError = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/EndpointError.js"() {
    EndpointError = class extends Error {
      static {
        __name(this, "EndpointError");
      }
      constructor(message2) {
        super(message2);
        this.name = "EndpointError";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/EndpointFunctions.js
var init_EndpointFunctions = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/EndpointFunctions.js"() {
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/EndpointRuleObject.js
var init_EndpointRuleObject = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/EndpointRuleObject.js"() {
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/ErrorRuleObject.js
var init_ErrorRuleObject = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/ErrorRuleObject.js"() {
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/RuleSetObject.js
var init_RuleSetObject = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/RuleSetObject.js"() {
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/TreeRuleObject.js
var init_TreeRuleObject = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/TreeRuleObject.js"() {
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/shared.js
var init_shared = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/shared.js"() {
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/index.js
var init_types = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/index.js"() {
    init_EndpointError();
    init_EndpointFunctions();
    init_EndpointRuleObject();
    init_ErrorRuleObject();
    init_RuleSetObject();
    init_TreeRuleObject();
    init_shared();
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/debug/debugId.js
var debugId;
var init_debugId = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/debug/debugId.js"() {
    debugId = "endpoints";
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/debug/toDebugString.js
function toDebugString(input) {
  if (typeof input !== "object" || input == null) {
    return input;
  }
  if ("ref" in input) {
    return `$${toDebugString(input.ref)}`;
  }
  if ("fn" in input) {
    return `${input.fn}(${(input.argv || []).map(toDebugString).join(", ")})`;
  }
  return JSON.stringify(input, null, 2);
}
var init_toDebugString = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/debug/toDebugString.js"() {
    __name(toDebugString, "toDebugString");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/debug/index.js
var init_debug = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/debug/index.js"() {
    init_debugId();
    init_toDebugString();
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/customEndpointFunctions.js
var customEndpointFunctions16;
var init_customEndpointFunctions = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/customEndpointFunctions.js"() {
    customEndpointFunctions16 = {};
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/booleanEquals.js
var booleanEquals;
var init_booleanEquals = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/booleanEquals.js"() {
    booleanEquals = /* @__PURE__ */ __name((value1, value2) => value1 === value2, "booleanEquals");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/coalesce.js
function coalesce(...args) {
  for (const arg of args) {
    if (arg != null) {
      return arg;
    }
  }
  return void 0;
}
var init_coalesce = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/coalesce.js"() {
    __name(coalesce, "coalesce");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/getAttrPathList.js
var getAttrPathList;
var init_getAttrPathList = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/getAttrPathList.js"() {
    init_types();
    getAttrPathList = /* @__PURE__ */ __name((path47) => {
      const parts = path47.split(".");
      const pathList = [];
      for (const part of parts) {
        const squareBracketIndex = part.indexOf("[");
        if (squareBracketIndex !== -1) {
          if (part.indexOf("]") !== part.length - 1) {
            throw new EndpointError(`Path: '${path47}' does not end with ']'`);
          }
          const arrayIndex = part.slice(squareBracketIndex + 1, -1);
          if (Number.isNaN(parseInt(arrayIndex))) {
            throw new EndpointError(`Invalid array index: '${arrayIndex}' in path: '${path47}'`);
          }
          if (squareBracketIndex !== 0) {
            pathList.push(part.slice(0, squareBracketIndex));
          }
          pathList.push(arrayIndex);
        } else {
          pathList.push(part);
        }
      }
      return pathList;
    }, "getAttrPathList");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/getAttr.js
var getAttr;
var init_getAttr = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/getAttr.js"() {
    init_types();
    init_getAttrPathList();
    getAttr = /* @__PURE__ */ __name((value, path47) => getAttrPathList(path47).reduce((acc, index) => {
      if (typeof acc !== "object") {
        throw new EndpointError(`Index '${index}' in '${path47}' not found in '${JSON.stringify(value)}'`);
      } else if (Array.isArray(acc)) {
        const i32 = parseInt(index);
        return acc[i32 < 0 ? acc.length + i32 : i32];
      }
      return acc[index];
    }, value), "getAttr");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/isSet.js
var isSet;
var init_isSet = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/isSet.js"() {
    isSet = /* @__PURE__ */ __name((value) => value != null, "isSet");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/ite.js
function ite(condition, trueValue, falseValue) {
  return condition ? trueValue : falseValue;
}
var init_ite = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/ite.js"() {
    __name(ite, "ite");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/not.js
var not;
var init_not = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/not.js"() {
    not = /* @__PURE__ */ __name((value) => !value, "not");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/isIpAddress.js
var IP_V4_REGEX, isIpAddress;
var init_isIpAddress = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/isIpAddress.js"() {
    IP_V4_REGEX = new RegExp(`^(?:25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]\\d|\\d)(?:\\.(?:25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]\\d|\\d)){3}$`);
    isIpAddress = /* @__PURE__ */ __name((value) => IP_V4_REGEX.test(value) || value.startsWith("[") && value.endsWith("]"), "isIpAddress");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/parseURL.js
var import_types8, DEFAULT_PORTS, parseURL;
var init_parseURL = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/parseURL.js"() {
    import_types8 = __toESM(require_dist_cjs());
    init_isIpAddress();
    DEFAULT_PORTS = {
      [import_types8.EndpointURLScheme.HTTP]: 80,
      [import_types8.EndpointURLScheme.HTTPS]: 443
    };
    parseURL = /* @__PURE__ */ __name((value) => {
      const whatwgURL = (() => {
        try {
          if (value instanceof URL) {
            return value;
          }
          if (typeof value === "object" && "hostname" in value) {
            const { hostname: hostname2, port, protocol: protocol2 = "", path: path47 = "", query = {} } = value;
            const url = new URL(`${protocol2}//${hostname2}${port ? `:${port}` : ""}${path47}`);
            url.search = Object.entries(query).map(([k32, v]) => `${k32}=${v}`).join("&");
            return url;
          }
          return new URL(value);
        } catch (error4) {
          return null;
        }
      })();
      if (!whatwgURL) {
        console.error(`Unable to parse ${JSON.stringify(value)} as a whatwg URL.`);
        return null;
      }
      const urlString = whatwgURL.href;
      const { host, hostname, pathname, protocol, search } = whatwgURL;
      if (search) {
        return null;
      }
      const scheme = protocol.slice(0, -1);
      if (!Object.values(import_types8.EndpointURLScheme).includes(scheme)) {
        return null;
      }
      const isIp = isIpAddress(hostname);
      const inputContainsDefaultPort = urlString.includes(`${host}:${DEFAULT_PORTS[scheme]}`) || typeof value === "string" && value.includes(`${host}:${DEFAULT_PORTS[scheme]}`);
      const authority = `${host}${inputContainsDefaultPort ? `:${DEFAULT_PORTS[scheme]}` : ``}`;
      return {
        scheme,
        authority,
        path: pathname,
        normalizedPath: pathname.endsWith("/") ? pathname : `${pathname}/`,
        isIp
      };
    }, "parseURL");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/split.js
function split(value, delimiter2, limit) {
  if (limit === 1) {
    return [value];
  }
  if (value === "") {
    return [""];
  }
  const parts = value.split(delimiter2);
  if (limit === 0) {
    return parts;
  }
  return parts.slice(0, limit - 1).concat(parts.slice(1).join(delimiter2));
}
var init_split = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/split.js"() {
    __name(split, "split");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/stringEquals.js
var stringEquals;
var init_stringEquals = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/stringEquals.js"() {
    stringEquals = /* @__PURE__ */ __name((value1, value2) => value1 === value2, "stringEquals");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/substring.js
var substring;
var init_substring = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/substring.js"() {
    substring = /* @__PURE__ */ __name((input, start, stop, reverse) => {
      if (input == null || start >= stop || input.length < stop || /[^\u0000-\u007f]/.test(input)) {
        return null;
      }
      if (!reverse) {
        return input.substring(start, stop);
      }
      return input.substring(input.length - stop, input.length - start);
    }, "substring");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/uriEncode.js
var uriEncode;
var init_uriEncode = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/uriEncode.js"() {
    uriEncode = /* @__PURE__ */ __name((value) => encodeURIComponent(value).replace(/[!*'()]/g, (c32) => `%${c32.charCodeAt(0).toString(16).toUpperCase()}`), "uriEncode");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/index.js
var init_lib = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/index.js"() {
    init_booleanEquals();
    init_coalesce();
    init_getAttr();
    init_isSet();
    init_transport2();
    init_ite();
    init_not();
    init_parseURL();
    init_split();
    init_stringEquals();
    init_substring();
    init_uriEncode();
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/endpointFunctions.js
var endpointFunctions;
var init_endpointFunctions = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/endpointFunctions.js"() {
    init_lib();
    endpointFunctions = {
      booleanEquals,
      coalesce,
      getAttr,
      isSet,
      isValidHostLabel,
      ite,
      not,
      parseURL,
      split,
      stringEquals,
      substring,
      uriEncode
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/evaluateTemplate.js
var evaluateTemplate;
var init_evaluateTemplate = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/evaluateTemplate.js"() {
    init_lib();
    evaluateTemplate = /* @__PURE__ */ __name((template, options) => {
      const evaluatedTemplateArr = [];
      const { referenceRecord, endpointParams } = options;
      let currentIndex = 0;
      while (currentIndex < template.length) {
        const openingBraceIndex = template.indexOf("{", currentIndex);
        if (openingBraceIndex === -1) {
          evaluatedTemplateArr.push(template.slice(currentIndex));
          break;
        }
        evaluatedTemplateArr.push(template.slice(currentIndex, openingBraceIndex));
        const closingBraceIndex = template.indexOf("}", openingBraceIndex);
        if (closingBraceIndex === -1) {
          evaluatedTemplateArr.push(template.slice(openingBraceIndex));
          break;
        }
        if (template[openingBraceIndex + 1] === "{" && template[closingBraceIndex + 1] === "}") {
          evaluatedTemplateArr.push(template.slice(openingBraceIndex + 1, closingBraceIndex));
          currentIndex = closingBraceIndex + 2;
        }
        const parameterName = template.substring(openingBraceIndex + 1, closingBraceIndex);
        if (parameterName.includes("#")) {
          const [refName, attrName] = parameterName.split("#");
          evaluatedTemplateArr.push(getAttr(referenceRecord[refName] ?? endpointParams[refName], attrName));
        } else {
          evaluatedTemplateArr.push(referenceRecord[parameterName] ?? endpointParams[parameterName]);
        }
        currentIndex = closingBraceIndex + 1;
      }
      return evaluatedTemplateArr.join("");
    }, "evaluateTemplate");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/getReferenceValue.js
var getReferenceValue;
var init_getReferenceValue = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/getReferenceValue.js"() {
    getReferenceValue = /* @__PURE__ */ __name(({ ref }, options) => {
      return options.referenceRecord[ref] ?? options.endpointParams[ref];
    }, "getReferenceValue");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/evaluateExpression.js
var evaluateExpression, callFunction, group;
var init_evaluateExpression = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/evaluateExpression.js"() {
    init_types();
    init_customEndpointFunctions();
    init_endpointFunctions();
    init_evaluateTemplate();
    init_getReferenceValue();
    evaluateExpression = /* @__PURE__ */ __name((obj, keyName, options) => {
      if (typeof obj === "string") {
        return evaluateTemplate(obj, options);
      } else if (obj["fn"]) {
        return group.callFunction(obj, options);
      } else if (obj["ref"]) {
        return getReferenceValue(obj, options);
      }
      throw new EndpointError(`'${keyName}': ${String(obj)} is not a string, function or reference.`);
    }, "evaluateExpression");
    callFunction = /* @__PURE__ */ __name(({ fn, argv }, options) => {
      const evaluatedArgs = Array(argv.length);
      for (let i32 = 0; i32 < evaluatedArgs.length; ++i32) {
        const arg = argv[i32];
        if (typeof arg === "boolean" || typeof arg === "number") {
          evaluatedArgs[i32] = arg;
        } else {
          evaluatedArgs[i32] = group.evaluateExpression(arg, "arg", options);
        }
      }
      const namespaceSeparatorIndex = fn.indexOf(".");
      if (namespaceSeparatorIndex !== -1) {
        const namespaceFunctions = customEndpointFunctions16[fn.slice(0, namespaceSeparatorIndex)];
        const customFunction = namespaceFunctions?.[fn.slice(namespaceSeparatorIndex + 1)];
        if (typeof customFunction === "function") {
          return customFunction(...evaluatedArgs);
        }
      }
      const callable = endpointFunctions[fn];
      if (typeof callable === "function") {
        return callable(...evaluatedArgs);
      }
      throw new Error(`function ${fn} not loaded in endpointFunctions.`);
    }, "callFunction");
    group = {
      evaluateExpression,
      callFunction
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/callFunction.js
var init_callFunction = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/callFunction.js"() {
    init_evaluateExpression();
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/evaluateCondition.js
var evaluateCondition;
var init_evaluateCondition = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/evaluateCondition.js"() {
    init_debug();
    init_types();
    init_callFunction();
    evaluateCondition = /* @__PURE__ */ __name((condition, options) => {
      const { assign } = condition;
      if (assign && assign in options.referenceRecord) {
        throw new EndpointError(`'${assign}' is already defined in Reference Record.`);
      }
      const value = callFunction(condition, options);
      options.logger?.debug?.(`${debugId} evaluateCondition: ${toDebugString(condition)} = ${toDebugString(value)}`);
      const result2 = value === "" ? true : !!value;
      if (assign != null) {
        return { result: result2, toAssign: { name: assign, value } };
      }
      return { result: result2 };
    }, "evaluateCondition");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/getEndpointHeaders.js
var getEndpointHeaders;
var init_getEndpointHeaders = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/getEndpointHeaders.js"() {
    init_types();
    init_evaluateExpression();
    getEndpointHeaders = /* @__PURE__ */ __name((headers, options) => Object.entries(headers ?? {}).reduce((acc, [headerKey, headerVal]) => {
      acc[headerKey] = headerVal.map((headerValEntry) => {
        const processedExpr = evaluateExpression(headerValEntry, "Header value entry", options);
        if (typeof processedExpr !== "string") {
          throw new EndpointError(`Header '${headerKey}' value '${processedExpr}' is not a string`);
        }
        return processedExpr;
      });
      return acc;
    }, {}), "getEndpointHeaders");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/getEndpointProperties.js
var getEndpointProperties, getEndpointProperty, group2;
var init_getEndpointProperties = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/getEndpointProperties.js"() {
    init_types();
    init_evaluateTemplate();
    getEndpointProperties = /* @__PURE__ */ __name((properties, options) => Object.entries(properties).reduce((acc, [propertyKey, propertyVal]) => {
      acc[propertyKey] = group2.getEndpointProperty(propertyVal, options);
      return acc;
    }, {}), "getEndpointProperties");
    getEndpointProperty = /* @__PURE__ */ __name((property, options) => {
      if (Array.isArray(property)) {
        return property.map((propertyEntry) => getEndpointProperty(propertyEntry, options));
      }
      switch (typeof property) {
        case "string":
          return evaluateTemplate(property, options);
        case "object":
          if (property === null) {
            throw new EndpointError(`Unexpected endpoint property: ${property}`);
          }
          return group2.getEndpointProperties(property, options);
        case "boolean":
          return property;
        default:
          throw new EndpointError(`Unexpected endpoint property type: ${typeof property}`);
      }
    }, "getEndpointProperty");
    group2 = {
      getEndpointProperty,
      getEndpointProperties
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/getEndpointUrl.js
var getEndpointUrl;
var init_getEndpointUrl = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/getEndpointUrl.js"() {
    init_types();
    init_evaluateExpression();
    getEndpointUrl = /* @__PURE__ */ __name((endpointUrl, options) => {
      const expression = evaluateExpression(endpointUrl, "Endpoint URL", options);
      if (typeof expression === "string") {
        try {
          return new URL(expression);
        } catch (error4) {
          console.error(`Failed to construct URL with ${expression}`, error4);
          throw error4;
        }
      }
      throw new EndpointError(`Endpoint URL must be a string, got ${typeof expression}`);
    }, "getEndpointUrl");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/decideEndpoint.js
var RESULT, decideEndpoint16;
var init_decideEndpoint = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/decideEndpoint.js"() {
    init_types();
    init_evaluateCondition();
    init_evaluateExpression();
    init_getEndpointHeaders();
    init_getEndpointProperties();
    init_getEndpointUrl();
    RESULT = 1e8;
    decideEndpoint16 = /* @__PURE__ */ __name((bdd32, options) => {
      const { nodes: nodes32, root: root32, results, conditions } = bdd32;
      let ref = root32;
      const referenceRecord = {};
      const closure = {
        referenceRecord,
        endpointParams: options.endpointParams,
        logger: options.logger
      };
      while (ref !== 1 && ref !== -1 && ref < RESULT) {
        const node_i = 3 * (Math.abs(ref) - 1);
        const [condition_i, highRef, lowRef] = [nodes32[node_i], nodes32[node_i + 1], nodes32[node_i + 2]];
        const [fn, argv, assign] = conditions[condition_i];
        const evaluation = evaluateCondition({ fn, assign, argv }, closure);
        if (evaluation.toAssign) {
          const { name, value } = evaluation.toAssign;
          referenceRecord[name] = value;
        }
        ref = ref >= 0 === evaluation.result ? highRef : lowRef;
      }
      if (ref >= RESULT) {
        const result2 = results[ref - RESULT];
        if (result2[0] === -1) {
          const [, errorExpression] = result2;
          throw new EndpointError(evaluateExpression(errorExpression, "Error", closure));
        }
        const [url, properties, headers] = result2;
        return {
          url: getEndpointUrl(url, closure),
          properties: getEndpointProperties(properties, closure),
          headers: getEndpointHeaders(headers ?? {}, closure)
        };
      }
      throw new EndpointError(`No matching endpoint.`);
    }, "decideEndpoint");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/evaluateConditions.js
var evaluateConditions;
var init_evaluateConditions = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/evaluateConditions.js"() {
    init_debug();
    init_evaluateCondition();
    evaluateConditions = /* @__PURE__ */ __name((conditions = [], options) => {
      const conditionsReferenceRecord = {};
      const conditionOptions = {
        ...options,
        referenceRecord: { ...options.referenceRecord }
      };
      let didAssign = false;
      for (const condition of conditions) {
        const { result: result2, toAssign } = evaluateCondition(condition, conditionOptions);
        if (!result2) {
          return { result: result2 };
        }
        if (toAssign) {
          didAssign = true;
          conditionsReferenceRecord[toAssign.name] = toAssign.value;
          conditionOptions.referenceRecord[toAssign.name] = toAssign.value;
          options.logger?.debug?.(`${debugId} assign: ${toAssign.name} := ${toDebugString(toAssign.value)}`);
        }
      }
      if (didAssign) {
        return { result: true, referenceRecord: conditionsReferenceRecord };
      }
      return { result: true };
    }, "evaluateConditions");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/evaluateEndpointRule.js
var evaluateEndpointRule;
var init_evaluateEndpointRule = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/evaluateEndpointRule.js"() {
    init_debug();
    init_evaluateConditions();
    init_getEndpointHeaders();
    init_getEndpointProperties();
    init_getEndpointUrl();
    evaluateEndpointRule = /* @__PURE__ */ __name((endpointRule, options) => {
      const { conditions, endpoint } = endpointRule;
      const { result: result2, referenceRecord } = evaluateConditions(conditions, options);
      if (!result2) {
        return;
      }
      const endpointRuleOptions = referenceRecord ? {
        ...options,
        referenceRecord: { ...options.referenceRecord, ...referenceRecord }
      } : options;
      const { url, properties, headers } = endpoint;
      options.logger?.debug?.(`${debugId} Resolving endpoint from template: ${toDebugString(endpoint)}`);
      const endpointToReturn = { url: getEndpointUrl(url, endpointRuleOptions) };
      if (headers != null) {
        endpointToReturn.headers = getEndpointHeaders(headers, endpointRuleOptions);
      }
      if (properties != null) {
        endpointToReturn.properties = getEndpointProperties(properties, endpointRuleOptions);
      }
      return endpointToReturn;
    }, "evaluateEndpointRule");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/evaluateErrorRule.js
var evaluateErrorRule;
var init_evaluateErrorRule = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/evaluateErrorRule.js"() {
    init_types();
    init_evaluateConditions();
    init_evaluateExpression();
    evaluateErrorRule = /* @__PURE__ */ __name((errorRule, options) => {
      const { conditions, error: error4 } = errorRule;
      const { result: result2, referenceRecord } = evaluateConditions(conditions, options);
      if (!result2) {
        return;
      }
      const errorRuleOptions = referenceRecord ? {
        ...options,
        referenceRecord: { ...options.referenceRecord, ...referenceRecord }
      } : options;
      throw new EndpointError(evaluateExpression(error4, "Error", errorRuleOptions));
    }, "evaluateErrorRule");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/evaluateRules.js
var evaluateRules, evaluateTreeRule, group3;
var init_evaluateRules = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/evaluateRules.js"() {
    init_types();
    init_evaluateConditions();
    init_evaluateEndpointRule();
    init_evaluateErrorRule();
    evaluateRules = /* @__PURE__ */ __name((rules, options) => {
      for (const rule of rules) {
        if (rule.type === "endpoint") {
          const endpointOrUndefined = evaluateEndpointRule(rule, options);
          if (endpointOrUndefined) {
            return endpointOrUndefined;
          }
        } else if (rule.type === "error") {
          evaluateErrorRule(rule, options);
        } else if (rule.type === "tree") {
          const endpointOrUndefined = group3.evaluateTreeRule(rule, options);
          if (endpointOrUndefined) {
            return endpointOrUndefined;
          }
        } else {
          throw new EndpointError(`Unknown endpoint rule: ${rule}`);
        }
      }
      throw new EndpointError(`Rules evaluation failed`);
    }, "evaluateRules");
    evaluateTreeRule = /* @__PURE__ */ __name((treeRule, options) => {
      const { conditions, rules } = treeRule;
      const { result: result2, referenceRecord } = evaluateConditions(conditions, options);
      if (!result2) {
        return;
      }
      const treeRuleOptions = referenceRecord ? { ...options, referenceRecord: { ...options.referenceRecord, ...referenceRecord } } : options;
      return group3.evaluateRules(rules, treeRuleOptions);
    }, "evaluateTreeRule");
    group3 = {
      evaluateRules,
      evaluateTreeRule
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/index.js
var init_utils6 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/index.js"() {
    init_customEndpointFunctions();
    init_evaluateRules();
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/resolveEndpoint.js
var resolveEndpoint;
var init_resolveEndpoint = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/resolveEndpoint.js"() {
    init_debug();
    init_types();
    init_utils6();
    resolveEndpoint = /* @__PURE__ */ __name((ruleSetObject, options) => {
      const { endpointParams, logger: logger5 } = options;
      const { parameters, rules } = ruleSetObject;
      options.logger?.debug?.(`${debugId} Initial EndpointParams: ${toDebugString(endpointParams)}`);
      for (const paramKey in parameters) {
        const parameter = parameters[paramKey];
        const endpointParam = endpointParams[paramKey];
        if (endpointParam == null && parameter.default != null) {
          endpointParams[paramKey] = parameter.default;
          continue;
        }
        if (parameter.required && endpointParam == null) {
          throw new EndpointError(`Missing required parameter: '${paramKey}'`);
        }
      }
      const endpoint = evaluateRules(rules, { endpointParams, logger: logger5, referenceRecord: {} });
      options.logger?.debug?.(`${debugId} Resolved endpoint: ${toDebugString(endpoint)}`);
      return endpoint;
    }, "resolveEndpoint");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/resolveEndpointRequiredConfig.js
var resolveEndpointRequiredConfig;
var init_resolveEndpointRequiredConfig = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/resolveEndpointRequiredConfig.js"() {
    resolveEndpointRequiredConfig = /* @__PURE__ */ __name((input) => {
      const { endpoint } = input;
      if (endpoint === void 0) {
        input.endpoint = async () => {
          throw new Error("@smithy/middleware-endpoint: (default endpointRuleSet) endpoint is not set - you must configure an endpoint.");
        };
      }
      return input;
    }, "resolveEndpointRequiredConfig");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/index.js
var endpoints_exports2 = {};
__export(endpoints_exports2, {
  BinaryDecisionDiagram: () => BinaryDecisionDiagram16,
  EndpointCache: () => EndpointCache16,
  EndpointError: () => EndpointError,
  customEndpointFunctions: () => customEndpointFunctions16,
  decideEndpoint: () => decideEndpoint16,
  endpointMiddleware: () => endpointMiddleware,
  endpointMiddlewareOptions: () => endpointMiddlewareOptions,
  getEndpointFromInstructions: () => getEndpointFromInstructions,
  getEndpointPlugin: () => getEndpointPlugin21,
  isIpAddress: () => isIpAddress,
  isValidHostLabel: () => isValidHostLabel,
  middlewareEndpointToEndpointV1: () => toEndpointV12,
  resolveEndpoint: () => resolveEndpoint,
  resolveEndpointConfig: () => resolveEndpointConfig16,
  resolveEndpointRequiredConfig: () => resolveEndpointRequiredConfig,
  resolveParams: () => resolveParams5,
  toEndpointV1: () => toEndpointV12
});
var getEndpointFromInstructions, resolveEndpointConfig16, endpointMiddleware, getEndpointPlugin21;
var init_endpoints2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/endpoints/index.js"() {
    init_getEndpointFromConfig();
    init_getEndpointFromInstructions();
    init_endpointMiddleware();
    init_getEndpointPlugin();
    init_resolveEndpointConfig();
    init_transport2();
    init_BinaryDecisionDiagram();
    init_EndpointCache();
    init_decideEndpoint();
    init_isIpAddress();
    init_transport2();
    init_customEndpointFunctions();
    init_resolveEndpoint();
    init_types();
    init_getEndpointFromInstructions();
    init_toEndpointV13();
    init_getEndpointPlugin();
    init_resolveEndpointRequiredConfig();
    getEndpointFromInstructions = bindGetEndpointFromInstructions(getEndpointFromConfig);
    resolveEndpointConfig16 = bindResolveEndpointConfig(getEndpointFromConfig);
    endpointMiddleware = bindEndpointMiddleware(getEndpointFromConfig);
    getEndpointPlugin21 = bindGetEndpointPlugin(getEndpointFromConfig);
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/is-array-buffer/is-array-buffer.js
var isArrayBuffer2;
var init_is_array_buffer2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/is-array-buffer/is-array-buffer.js"() {
    isArrayBuffer2 = /* @__PURE__ */ __name((arg) => typeof ArrayBuffer === "function" && arg instanceof ArrayBuffer || Object.prototype.toString.call(arg) === "[object ArrayBuffer]", "isArrayBuffer");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-buffer-from/buffer-from.js
var fromArrayBuffer2, fromString2;
var init_buffer_from2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-buffer-from/buffer-from.js"() {
    init_is_array_buffer2();
    fromArrayBuffer2 = /* @__PURE__ */ __name((input, offset = 0, length = input.byteLength - offset) => {
      if (!isArrayBuffer2(input)) {
        throw new TypeError(`The "input" argument must be ArrayBuffer. Received type ${typeof input} (${input})`);
      }
      return Buffer.from(input, offset, length);
    }, "fromArrayBuffer");
    fromString2 = /* @__PURE__ */ __name((input, encoding) => {
      if (typeof input !== "string") {
        throw new TypeError(`The "input" argument must be of type string. Received type ${typeof input} (${input})`);
      }
      return encoding ? Buffer.from(input, encoding) : Buffer.from(input);
    }, "fromString");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/fromBase64.js
var BASE64_REGEX2, fromBase6429;
var init_fromBase642 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/fromBase64.js"() {
    init_buffer_from2();
    BASE64_REGEX2 = /^[A-Za-z0-9+/]*={0,2}$/;
    fromBase6429 = /* @__PURE__ */ __name((input) => {
      if (input.length * 3 % 4 !== 0) {
        throw new TypeError(`Incorrect padding on base64 string.`);
      }
      if (!BASE64_REGEX2.exec(input)) {
        throw new TypeError(`Invalid base64 string.`);
      }
      const buffer = fromString2(input, "base64");
      return new Uint8Array(buffer.buffer, buffer.byteOffset, buffer.byteLength);
    }, "fromBase64");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/fromUtf8.js
var fromUtf820;
var init_fromUtf82 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/fromUtf8.js"() {
    init_buffer_from2();
    fromUtf820 = /* @__PURE__ */ __name((input) => {
      const buf = fromString2(input, "utf8");
      return new Uint8Array(buf.buffer, buf.byteOffset, buf.byteLength / Uint8Array.BYTES_PER_ELEMENT);
    }, "fromUtf8");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/toBase64.js
var toBase6433;
var init_toBase642 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/toBase64.js"() {
    init_buffer_from2();
    init_fromUtf82();
    toBase6433 = /* @__PURE__ */ __name((_input) => {
      let input;
      if (typeof _input === "string") {
        input = fromUtf820(_input);
      } else {
        input = _input;
      }
      if (typeof input !== "object" || typeof input.byteOffset !== "number" || typeof input.byteLength !== "number") {
        throw new Error("@smithy/util-base64: toBase64 encoder function only accepts string | Uint8Array.");
      }
      return fromArrayBuffer2(input.buffer, input.byteOffset, input.byteLength).toString("base64");
    }, "toBase64");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/blob/Uint8ArrayBlobAdapter.js
function bindUint8ArrayBlobAdapter2(toUtf862, fromUtf842, toBase6467, fromBase6459) {
  return class Uint8ArrayBlobAdapter8 extends Uint8Array {
    static {
      __name(this, "Uint8ArrayBlobAdapter");
    }
    static fromString(source, encoding = "utf-8") {
      if (typeof source === "string") {
        if (encoding === "base64") {
          return Uint8ArrayBlobAdapter8.mutate(fromBase6459(source));
        }
        return Uint8ArrayBlobAdapter8.mutate(fromUtf842(source));
      }
      throw new Error(`Unsupported conversion from ${typeof source} to Uint8ArrayBlobAdapter.`);
    }
    static mutate(source) {
      Object.setPrototypeOf(source, Uint8ArrayBlobAdapter8.prototype);
      return source;
    }
    transformToString(encoding = "utf-8") {
      if (encoding === "base64") {
        return toBase6467(this);
      }
      return toUtf862(this);
    }
  };
}
var init_Uint8ArrayBlobAdapter2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/blob/Uint8ArrayBlobAdapter.js"() {
    __name(bindUint8ArrayBlobAdapter2, "bindUint8ArrayBlobAdapter");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/toUtf8.js
var toUtf832;
var init_toUtf82 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/toUtf8.js"() {
    init_buffer_from2();
    toUtf832 = /* @__PURE__ */ __name((input) => {
      if (typeof input === "string") {
        return input;
      }
      if (typeof input !== "object" || typeof input.byteOffset !== "number" || typeof input.byteLength !== "number") {
        throw new Error("@smithy/util-utf8: toUtf8 encoder function only accepts string | Uint8Array.");
      }
      return fromArrayBuffer2(input.buffer, input.byteOffset, input.byteLength).toString("utf8");
    }, "toUtf8");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/uuid/v4.js
function bindV42(getRandomValues7) {
  if (typeof crypto !== "undefined" && typeof crypto.randomUUID === "function") {
    return () => crypto.randomUUID();
  }
  return () => {
    const rnds = new Uint8Array(16);
    getRandomValues7(rnds);
    rnds[6] = rnds[6] & 15 | 64;
    rnds[8] = rnds[8] & 63 | 128;
    return decimalToHex2[rnds[0]] + decimalToHex2[rnds[1]] + decimalToHex2[rnds[2]] + decimalToHex2[rnds[3]] + "-" + decimalToHex2[rnds[4]] + decimalToHex2[rnds[5]] + "-" + decimalToHex2[rnds[6]] + decimalToHex2[rnds[7]] + "-" + decimalToHex2[rnds[8]] + decimalToHex2[rnds[9]] + "-" + decimalToHex2[rnds[10]] + decimalToHex2[rnds[11]] + decimalToHex2[rnds[12]] + decimalToHex2[rnds[13]] + decimalToHex2[rnds[14]] + decimalToHex2[rnds[15]];
  };
}
var decimalToHex2;
var init_v42 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/uuid/v4.js"() {
    decimalToHex2 = Array.from({ length: 256 }, (_, i32) => i32.toString(16).padStart(2, "0"));
    __name(bindV42, "bindV4");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/date-utils.js
function dateToUtcString12(date7) {
  const year7 = date7.getUTCFullYear();
  const month = date7.getUTCMonth();
  const dayOfWeek = date7.getUTCDay();
  const dayOfMonthInt = date7.getUTCDate();
  const hoursInt = date7.getUTCHours();
  const minutesInt = date7.getUTCMinutes();
  const secondsInt = date7.getUTCSeconds();
  const dayOfMonthString = dayOfMonthInt < 10 ? `0${dayOfMonthInt}` : `${dayOfMonthInt}`;
  const hoursString = hoursInt < 10 ? `0${hoursInt}` : `${hoursInt}`;
  const minutesString = minutesInt < 10 ? `0${minutesInt}` : `${minutesInt}`;
  const secondsString = secondsInt < 10 ? `0${secondsInt}` : `${secondsInt}`;
  return `${DAYS2[dayOfWeek]}, ${dayOfMonthString} ${MONTHS3[month]} ${year7} ${hoursString}:${minutesString}:${secondsString} GMT`;
}
var DAYS2, MONTHS3, RFC33393, RFC3339_WITH_OFFSET4, IMF_FIXDATE4, RFC_850_DATE4, ASC_TIME4, FIFTY_YEARS_IN_MILLIS3;
var init_date_utils3 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/date-utils.js"() {
    DAYS2 = ["Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"];
    MONTHS3 = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"];
    __name(dateToUtcString12, "dateToUtcString");
    RFC33393 = new RegExp(/^(\d{4})-(\d{2})-(\d{2})[tT](\d{2}):(\d{2}):(\d{2})(?:\.(\d+))?[zZ]$/);
    RFC3339_WITH_OFFSET4 = new RegExp(/^(\d{4})-(\d{2})-(\d{2})[tT](\d{2}):(\d{2}):(\d{2})(?:\.(\d+))?(([-+]\d{2}\:\d{2})|[zZ])$/);
    IMF_FIXDATE4 = new RegExp(/^(?:Mon|Tue|Wed|Thu|Fri|Sat|Sun), (\d{2}) (Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec) (\d{4}) (\d{1,2}):(\d{2}):(\d{2})(?:\.(\d+))? GMT$/);
    RFC_850_DATE4 = new RegExp(/^(?:Monday|Tuesday|Wednesday|Thursday|Friday|Saturday|Sunday), (\d{2})-(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)-(\d{2}) (\d{1,2}):(\d{2}):(\d{2})(?:\.(\d+))? GMT$/);
    ASC_TIME4 = new RegExp(/^(?:Mon|Tue|Wed|Thu|Fri|Sat|Sun) (Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec) ( [1-9]|\d{2}) (\d{1,2}):(\d{2}):(\d{2})(?:\.(\d+))? (\d{4})$/);
    FIFTY_YEARS_IN_MILLIS3 = 50 * 365 * 24 * 60 * 60 * 1e3;
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/lazy-json.js
var LazyJsonString3;
var init_lazy_json2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/lazy-json.js"() {
    LazyJsonString3 = /* @__PURE__ */ __name(function LazyJsonString4(val) {
      const str = Object.assign(new String(val), {
        deserializeJSON() {
          return JSON.parse(String(val));
        },
        toString() {
          return String(val);
        },
        toJSON() {
          return String(val);
        }
      });
      return str;
    }, "LazyJsonString");
    LazyJsonString3.from = (object) => {
      if (object && typeof object === "object" && (object instanceof LazyJsonString3 || "deserializeJSON" in object)) {
        return object;
      } else if (typeof object === "string" || Object.getPrototypeOf(object) === String.prototype) {
        return LazyJsonString3(String(object));
      }
      return LazyJsonString3(JSON.stringify(object));
    };
    LazyJsonString3.fromObject = LazyJsonString3.from;
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/quote-header.js
function quoteHeader2(part) {
  if (part.includes(",") || part.includes('"')) {
    part = `"${part.replace(/"/g, '\\"')}"`;
  }
  return part;
}
var init_quote_header2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/quote-header.js"() {
    __name(quoteHeader2, "quoteHeader");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/schema-serde-lib/schema-date-utils.js
function range2(v, min, max) {
  const _v = Number(v);
  if (_v < min || _v > max) {
    throw new Error(`Value ${_v} out of range [${min}, ${max}]`);
  }
}
var ddd2, mmm2, time2, date2, year2, RFC3339_WITH_OFFSET5, IMF_FIXDATE5, RFC_850_DATE5, ASC_TIME5, months2, _parseEpochTimestamp2, _parseRfc3339DateTimeWithOffset2, _parseRfc7231DateTime2;
var init_schema_date_utils2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/schema-serde-lib/schema-date-utils.js"() {
    ddd2 = `(?:Mon|Tue|Wed|Thu|Fri|Sat|Sun)(?:[ne|u?r]?s?day)?`;
    mmm2 = `(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)`;
    time2 = `(\\d?\\d):(\\d{2}):(\\d{2})(?:\\.(\\d+))?`;
    date2 = `(\\d?\\d)`;
    year2 = `(\\d{4})`;
    RFC3339_WITH_OFFSET5 = new RegExp(/^(\d{4})-(\d\d)-(\d\d)[tT](\d\d):(\d\d):(\d\d)(\.(\d+))?(([-+]\d\d:\d\d)|[zZ])$/);
    IMF_FIXDATE5 = new RegExp(`^${ddd2}, ${date2} ${mmm2} ${year2} ${time2} GMT$`);
    RFC_850_DATE5 = new RegExp(`^${ddd2}, ${date2}-${mmm2}-(\\d\\d) ${time2} GMT$`);
    ASC_TIME5 = new RegExp(`^${ddd2} ${mmm2} ( [1-9]|\\d\\d) ${time2} ${year2}$`);
    months2 = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"];
    _parseEpochTimestamp2 = /* @__PURE__ */ __name((value) => {
      if (value == null) {
        return void 0;
      }
      let num = NaN;
      if (typeof value === "number") {
        num = value;
      } else if (typeof value === "string") {
        if (!/^-?\d*\.?\d+$/.test(value)) {
          throw new TypeError(`parseEpochTimestamp - numeric string invalid.`);
        }
        num = Number.parseFloat(value);
      } else if (typeof value === "object" && value.tag === 1) {
        num = value.value;
      }
      if (isNaN(num) || Math.abs(num) === Infinity) {
        throw new TypeError("Epoch timestamps must be valid finite numbers.");
      }
      return new Date(Math.round(num * 1e3));
    }, "_parseEpochTimestamp");
    _parseRfc3339DateTimeWithOffset2 = /* @__PURE__ */ __name((value) => {
      if (value == null) {
        return void 0;
      }
      if (typeof value !== "string") {
        throw new TypeError("RFC3339 timestamps must be strings");
      }
      const matches = RFC3339_WITH_OFFSET5.exec(value);
      if (!matches) {
        throw new TypeError(`Invalid RFC3339 timestamp format ${value}`);
      }
      const [, yearStr, monthStr, dayStr, hours, minutes, seconds, , ms, offsetStr] = matches;
      range2(monthStr, 1, 12);
      range2(dayStr, 1, 31);
      range2(hours, 0, 23);
      range2(minutes, 0, 59);
      range2(seconds, 0, 60);
      const date7 = new Date(Date.UTC(Number(yearStr), Number(monthStr) - 1, Number(dayStr), Number(hours), Number(minutes), Number(seconds), Number(ms) ? Math.round(parseFloat(`0.${ms}`) * 1e3) : 0));
      date7.setUTCFullYear(Number(yearStr));
      if (offsetStr.toUpperCase() != "Z") {
        const [, sign, offsetH, offsetM] = /([+-])(\d\d):(\d\d)/.exec(offsetStr) || [void 0, "+", 0, 0];
        const scalar = sign === "-" ? 1 : -1;
        date7.setTime(date7.getTime() + scalar * (Number(offsetH) * 60 * 60 * 1e3 + Number(offsetM) * 60 * 1e3));
      }
      return date7;
    }, "_parseRfc3339DateTimeWithOffset");
    _parseRfc7231DateTime2 = /* @__PURE__ */ __name((value) => {
      if (value == null) {
        return void 0;
      }
      if (typeof value !== "string") {
        throw new TypeError("RFC7231 timestamps must be strings.");
      }
      let day;
      let month;
      let year7;
      let hour;
      let minute;
      let second;
      let fraction;
      let matches;
      if (matches = IMF_FIXDATE5.exec(value)) {
        [, day, month, year7, hour, minute, second, fraction] = matches;
      } else if (matches = RFC_850_DATE5.exec(value)) {
        [, day, month, year7, hour, minute, second, fraction] = matches;
        year7 = (Number(year7) + 1900).toString();
      } else if (matches = ASC_TIME5.exec(value)) {
        [, month, day, hour, minute, second, fraction, year7] = matches;
      }
      if (year7 && second) {
        const timestamp = Date.UTC(Number(year7), months2.indexOf(month), Number(day), Number(hour), Number(minute), Number(second), fraction ? Math.round(parseFloat(`0.${fraction}`) * 1e3) : 0);
        range2(day, 1, 31);
        range2(hour, 0, 23);
        range2(minute, 0, 59);
        range2(second, 0, 60);
        const date7 = new Date(timestamp);
        date7.setUTCFullYear(Number(year7));
        return date7;
      }
      throw new TypeError(`Invalid RFC7231 date-time value ${value}.`);
    }, "_parseRfc7231DateTime");
    __name(range2, "range");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/split-every.js
function splitEvery2(value, delimiter2, numDelimiters) {
  if (numDelimiters <= 0 || !Number.isInteger(numDelimiters)) {
    throw new Error("Invalid number of delimiters (" + numDelimiters + ") for splitEvery.");
  }
  const segments = value.split(delimiter2);
  if (numDelimiters === 1) {
    return segments;
  }
  const compoundSegments = [];
  let currentSegment = "";
  for (let i32 = 0; i32 < segments.length; i32++) {
    if (currentSegment === "") {
      currentSegment = segments[i32];
    } else {
      currentSegment += delimiter2 + segments[i32];
    }
    if ((i32 + 1) % numDelimiters === 0) {
      compoundSegments.push(currentSegment);
      currentSegment = "";
    }
  }
  if (currentSegment !== "") {
    compoundSegments.push(currentSegment);
  }
  return compoundSegments;
}
var init_split_every2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/split-every.js"() {
    __name(splitEvery2, "splitEvery");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/split-header.js
var splitHeader2;
var init_split_header2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/split-header.js"() {
    splitHeader2 = /* @__PURE__ */ __name((value) => {
      const z = value.length;
      const values = [];
      let withinQuotes = false;
      let prevChar = void 0;
      let anchor = 0;
      for (let i32 = 0; i32 < z; ++i32) {
        const char = value[i32];
        switch (char) {
          case `"`:
            if (prevChar !== "\\") {
              withinQuotes = !withinQuotes;
            }
            break;
          case ",":
            if (!withinQuotes) {
              values.push(value.slice(anchor, i32));
              anchor = i32 + 1;
            }
            break;
          default:
        }
        prevChar = char;
      }
      values.push(value.slice(anchor));
      return values.map((v) => {
        v = v.trim();
        const z2 = v.length;
        if (z2 < 2) {
          return v;
        }
        if (v[0] === `"` && v[z2 - 1] === `"`) {
          v = v.slice(1, z2 - 1);
        }
        return v.replace(/\\"/g, '"');
      });
    }, "splitHeader");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/value/NumericValue.js
var format2, NumericValue2;
var init_NumericValue2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/value/NumericValue.js"() {
    format2 = /^-?\d*(\.\d+)?$/;
    NumericValue2 = class _NumericValue {
      static {
        __name(this, "NumericValue");
      }
      string;
      type;
      constructor(string, type) {
        this.string = string;
        this.type = type;
        if (!format2.test(string)) {
          throw new Error(`@smithy/core/serde - NumericValue must only contain [0-9], at most one decimal point ".", and an optional negation prefix "-".`);
        }
      }
      toString() {
        return this.string;
      }
      static [Symbol.hasInstance](object) {
        if (!object || typeof object !== "object") {
          return false;
        }
        const _nv = object;
        return _NumericValue.prototype.isPrototypeOf(object) || _nv.type === "bigDecimal" && format2.test(_nv.string);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-hex-encoding/hex-encoding.js
function fromHex(encoded) {
  if (encoded.length % 2 !== 0) {
    throw new Error("Hex encoded strings must have an even number length");
  }
  const out = new Uint8Array(encoded.length / 2);
  for (let i32 = 0; i32 < encoded.length; i32 += 2) {
    const encodedByte = encoded.slice(i32, i32 + 2).toLowerCase();
    if (encodedByte in HEX_TO_SHORT) {
      out[i32 / 2] = HEX_TO_SHORT[encodedByte];
    } else {
      throw new Error(`Cannot decode unrecognized sequence ${encodedByte} as hexadecimal`);
    }
  }
  return out;
}
function toHex(bytes) {
  let out = "";
  for (let i32 = 0; i32 < bytes.byteLength; i32++) {
    out += SHORT_TO_HEX[bytes[i32]];
  }
  return out;
}
var SHORT_TO_HEX, HEX_TO_SHORT;
var init_hex_encoding = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-hex-encoding/hex-encoding.js"() {
    SHORT_TO_HEX = {};
    HEX_TO_SHORT = {};
    for (let i32 = 0; i32 < 256; i32++) {
      let encodedByte = i32.toString(16).toLowerCase();
      if (encodedByte.length === 1) {
        encodedByte = `0${encodedByte}`;
      }
      SHORT_TO_HEX[i32] = encodedByte;
      HEX_TO_SHORT[encodedByte] = i32;
    }
    __name(fromHex, "fromHex");
    __name(toHex, "toHex");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-type-check.js
var isReadableStream;
var init_stream_type_check = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-type-check.js"() {
    isReadableStream = /* @__PURE__ */ __name((stream) => typeof ReadableStream === "function" && (stream?.constructor?.name === ReadableStream.name || stream instanceof ReadableStream), "isReadableStream");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/fromUtf8.browser.js
var fromUtf821;
var init_fromUtf8_browser = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/fromUtf8.browser.js"() {
    fromUtf821 = /* @__PURE__ */ __name((input) => new TextEncoder().encode(input), "fromUtf8");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/constants-for-browser.js
var chars, alphabetByEncoding, alphabetByValue, bitsPerLetter, bitsPerByte, maxLetterValue;
var init_constants_for_browser = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/constants-for-browser.js"() {
    chars = `ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/`;
    alphabetByEncoding = Object.entries(chars).reduce((acc, [i32, c32]) => {
      acc[c32] = Number(i32);
      return acc;
    }, {});
    alphabetByValue = chars.split("");
    bitsPerLetter = 6;
    bitsPerByte = 8;
    maxLetterValue = 63;
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/toBase64.browser.js
function toBase6434(_input) {
  let input;
  if (typeof _input === "string") {
    input = fromUtf821(_input);
  } else {
    input = _input;
  }
  const isArrayLike = typeof input === "object" && typeof input.length === "number";
  const isUint8Array = typeof input === "object" && typeof input.byteOffset === "number" && typeof input.byteLength === "number";
  if (!isArrayLike && !isUint8Array) {
    throw new Error("@smithy/util-base64: toBase64 encoder function only accepts string | Uint8Array.");
  }
  let str = "";
  for (let i32 = 0; i32 < input.length; i32 += 3) {
    let bits = 0;
    let bitLength = 0;
    for (let j32 = i32, limit = Math.min(i32 + 3, input.length); j32 < limit; j32++) {
      bits |= input[j32] << (limit - j32 - 1) * bitsPerByte;
      bitLength += bitsPerByte;
    }
    const bitClusterCount = Math.ceil(bitLength / bitsPerLetter);
    bits <<= bitClusterCount * bitsPerLetter - bitLength;
    for (let k32 = 1; k32 <= bitClusterCount; k32++) {
      const offset = (bitClusterCount - k32) * bitsPerLetter;
      str += alphabetByValue[(bits & maxLetterValue << offset) >> offset];
    }
    str += "==".slice(0, 4 - bitClusterCount);
  }
  return str;
}
var init_toBase64_browser = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/toBase64.browser.js"() {
    init_fromUtf8_browser();
    init_constants_for_browser();
    __name(toBase6434, "toBase64");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/toUtf8.browser.js
var toUtf833;
var init_toUtf8_browser = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/toUtf8.browser.js"() {
    toUtf833 = /* @__PURE__ */ __name((input) => {
      if (typeof input === "string") {
        return input;
      }
      if (typeof input !== "object" || typeof input.byteOffset !== "number" || typeof input.byteLength !== "number") {
        throw new Error("@smithy/util-utf8: toUtf8 encoder function only accepts string | Uint8Array.");
      }
      return new TextDecoder("utf-8").decode(input);
    }, "toUtf8");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/fromBase64.browser.js
var fromBase6430;
var init_fromBase64_browser = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/fromBase64.browser.js"() {
    init_constants_for_browser();
    fromBase6430 = /* @__PURE__ */ __name((input) => {
      let totalByteLength = input.length / 4 * 3;
      if (input.slice(-2) === "==") {
        totalByteLength -= 2;
      } else if (input.slice(-1) === "=") {
        totalByteLength--;
      }
      const out = new ArrayBuffer(totalByteLength);
      const dataView5 = new DataView(out);
      for (let i32 = 0; i32 < input.length; i32 += 4) {
        let bits = 0;
        let bitLength = 0;
        for (let j32 = i32, limit = i32 + 3; j32 <= limit; j32++) {
          if (input[j32] !== "=") {
            if (!(input[j32] in alphabetByEncoding)) {
              throw new TypeError(`Invalid character ${input[j32]} in base64 string.`);
            }
            bits |= alphabetByEncoding[input[j32]] << (limit - j32) * bitsPerLetter;
            bitLength += bitsPerLetter;
          } else {
            bits >>= bitsPerLetter;
          }
        }
        const chunkOffset = i32 / 4 * 3;
        bits >>= bitLength % bitsPerByte;
        const byteLength = Math.floor(bitLength / bitsPerByte);
        for (let k32 = 0; k32 < byteLength; k32++) {
          const offset = (byteLength - k32 - 1) * bitsPerByte;
          dataView5.setUint8(chunkOffset + k32, (bits & 255 << offset) >> offset);
        }
      }
      return new Uint8Array(out);
    }, "fromBase64");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-collector.browser.js
async function collectBlob(blob) {
  const base64 = await readToBase64(blob);
  const arrayBuffer = fromBase6430(base64);
  return new Uint8Array(arrayBuffer);
}
async function collectStream(stream) {
  const chunks2 = [];
  const reader = stream.getReader();
  let isDone = false;
  let length = 0;
  while (!isDone) {
    const { done, value } = await reader.read();
    if (value) {
      chunks2.push(value);
      length += value.length;
    }
    isDone = done;
  }
  const collected = new Uint8Array(length);
  let offset = 0;
  for (const chunk of chunks2) {
    collected.set(chunk, offset);
    offset += chunk.length;
  }
  return collected;
}
function readToBase64(blob) {
  return new Promise((resolve13, reject) => {
    const reader = new FileReader();
    reader.onloadend = () => {
      if (reader.readyState !== 2) {
        return reject(new Error("Reader aborted too early"));
      }
      const result2 = reader.result ?? "";
      const commaIndex = result2.indexOf(",");
      const dataOffset = commaIndex > -1 ? commaIndex + 1 : result2.length;
      resolve13(result2.substring(dataOffset));
    };
    reader.onabort = () => reject(new Error("Read aborted"));
    reader.onerror = () => reject(reader.error);
    reader.readAsDataURL(blob);
  });
}
var streamCollector16;
var init_stream_collector_browser = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-collector.browser.js"() {
    init_fromBase64_browser();
    streamCollector16 = /* @__PURE__ */ __name(async (stream) => {
      if (typeof Blob === "function" && stream instanceof Blob || stream.constructor?.name === "Blob") {
        if (Blob.prototype.arrayBuffer !== void 0) {
          return new Uint8Array(await stream.arrayBuffer());
        }
        return collectBlob(stream);
      }
      return collectStream(stream);
    }, "streamCollector");
    __name(collectBlob, "collectBlob");
    __name(collectStream, "collectStream");
    __name(readToBase64, "readToBase64");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/sdk-stream-mixin.browser.js
var ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED, sdkStreamMixin2, isBlobInstance;
var init_sdk_stream_mixin_browser = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/sdk-stream-mixin.browser.js"() {
    init_toBase64_browser();
    init_hex_encoding();
    init_toUtf8_browser();
    init_stream_collector_browser();
    init_stream_type_check();
    ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED = "The stream has already been transformed.";
    sdkStreamMixin2 = /* @__PURE__ */ __name((stream) => {
      if (!isBlobInstance(stream) && !isReadableStream(stream)) {
        const name = stream?.__proto__?.constructor?.name || stream;
        throw new Error(`Unexpected stream implementation, expect Blob or ReadableStream, got ${name}`);
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED);
        }
        transformed = true;
        return await streamCollector16(stream);
      }, "transformToByteArray");
      const blobToWebStream = /* @__PURE__ */ __name((blob) => {
        if (typeof blob.stream !== "function") {
          throw new Error("Cannot transform payload Blob to web stream. Please make sure the Blob.stream() is polyfilled.\nIf you are using React Native, this API is not yet supported, see: https://react-native.canny.io/feature-requests/p/fetch-streaming-body");
        }
        return blob.stream();
      }, "blobToWebStream");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === "base64") {
            return toBase6434(buf);
          } else if (encoding === "hex") {
            return toHex(buf);
          } else if (encoding === void 0 || encoding === "utf8" || encoding === "utf-8") {
            return toUtf833(buf);
          } else if (typeof TextDecoder === "function") {
            return new TextDecoder(encoding).decode(buf);
          } else {
            throw new Error("TextDecoder is not available, please make sure polyfill is provided.");
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED);
          }
          transformed = true;
          if (isBlobInstance(stream)) {
            return blobToWebStream(stream);
          } else if (isReadableStream(stream)) {
            return stream;
          } else {
            throw new Error(`Cannot transform payload to web stream, got ${stream}`);
          }
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
    isBlobInstance = /* @__PURE__ */ __name((stream) => typeof Blob === "function" && stream instanceof Blob, "isBlobInstance");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-collector.js
async function collectReadableStream(stream) {
  const chunks2 = [];
  const reader = stream.getReader();
  let isDone = false;
  let length = 0;
  while (!isDone) {
    const { done, value } = await reader.read();
    if (value) {
      chunks2.push(value);
      length += value.length;
    }
    isDone = done;
  }
  const collected = new Uint8Array(length);
  let offset = 0;
  for (const chunk of chunks2) {
    collected.set(chunk, offset);
    offset += chunk.length;
  }
  return collected;
}
var import_node_stream2, Collector, isReadableStreamInstance, streamCollector17;
var init_stream_collector = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-collector.js"() {
    import_node_stream2 = require("node:stream");
    Collector = class extends import_node_stream2.Writable {
      static {
        __name(this, "Collector");
      }
      bufferedBytes = [];
      _write(chunk, encoding, callback) {
        this.bufferedBytes.push(chunk);
        callback();
      }
    };
    isReadableStreamInstance = /* @__PURE__ */ __name((stream) => typeof ReadableStream === "function" && stream instanceof ReadableStream, "isReadableStreamInstance");
    __name(collectReadableStream, "collectReadableStream");
    streamCollector17 = /* @__PURE__ */ __name((stream) => {
      if (isReadableStreamInstance(stream)) {
        return collectReadableStream(stream);
      }
      return new Promise((resolve13, reject) => {
        const collector = new Collector();
        stream.pipe(collector);
        stream.on("error", (err) => {
          collector.end();
          reject(err);
        });
        collector.on("error", reject);
        collector.on("finish", function() {
          const bytes = new Uint8Array(Buffer.concat(this.bufferedBytes));
          resolve13(bytes);
        });
      });
    }, "streamCollector");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/sdk-stream-mixin.js
var import_node_stream3, ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED2, sdkStreamMixin3;
var init_sdk_stream_mixin = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/sdk-stream-mixin.js"() {
    import_node_stream3 = require("node:stream");
    init_buffer_from2();
    init_sdk_stream_mixin_browser();
    init_stream_collector();
    ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED2 = "The stream has already been transformed.";
    sdkStreamMixin3 = /* @__PURE__ */ __name((stream) => {
      if (!(stream instanceof import_node_stream3.Readable)) {
        try {
          return sdkStreamMixin2(stream);
        } catch (e32) {
          const name = stream?.__proto__?.constructor?.name || stream;
          throw new Error(`Unexpected stream implementation, expect Stream.Readable instance, got ${name}`);
        }
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED2);
        }
        transformed = true;
        return await streamCollector17(stream);
      }, "transformToByteArray");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === void 0 || Buffer.isEncoding(encoding)) {
            return fromArrayBuffer2(buf.buffer, buf.byteOffset, buf.byteLength).toString(encoding);
          } else {
            const decoder = new TextDecoder(encoding);
            return decoder.decode(buf);
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED2);
          }
          if (stream.readableFlowing !== null) {
            throw new Error("The stream has been consumed by other callbacks.");
          }
          if (typeof import_node_stream3.Readable.toWeb !== "function") {
            throw new Error("Readable.toWeb() is not supported. Please ensure a polyfill is available.");
          }
          transformed = true;
          return import_node_stream3.Readable.toWeb(stream);
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/index.js
var import_node_crypto2, Uint8ArrayBlobAdapter3, _getRandomValues2, v42, generateIdempotencyToken2;
var init_serde3 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/serde/index.js"() {
    import_node_crypto2 = require("node:crypto");
    init_fromBase642();
    init_toBase642();
    init_Uint8ArrayBlobAdapter2();
    init_fromUtf82();
    init_toUtf82();
    init_v42();
    init_date_utils3();
    init_lazy_json2();
    init_quote_header2();
    init_schema_date_utils2();
    init_split_every2();
    init_split_header2();
    init_NumericValue2();
    init_hex_encoding();
    init_sdk_stream_mixin();
    Uint8ArrayBlobAdapter3 = class extends bindUint8ArrayBlobAdapter2(toUtf832, fromUtf820, toBase6433, fromBase6429) {
      static {
        __name(this, "Uint8ArrayBlobAdapter");
      }
    };
    _getRandomValues2 = import_node_crypto2.getRandomValues;
    v42 = bindV42(_getRandomValues2);
    generateIdempotencyToken2 = v42;
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/collect-stream-body.js
var collectBody8;
var init_collect_stream_body3 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/collect-stream-body.js"() {
    init_serde3();
    collectBody8 = /* @__PURE__ */ __name(async (streamBody = new Uint8Array(), context) => {
      if (streamBody instanceof Uint8Array) {
        return Uint8ArrayBlobAdapter3.mutate(streamBody);
      }
      if (!streamBody) {
        return Uint8ArrayBlobAdapter3.mutate(new Uint8Array());
      }
      const fromContext = context.streamCollector(streamBody);
      return Uint8ArrayBlobAdapter3.mutate(await fromContext);
    }, "collectBody");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/extended-encode-uri-component.js
function extendedEncodeURIComponent2(str) {
  return encodeURIComponent(str).replace(/[!'()*]/g, function(c32) {
    return "%" + c32.charCodeAt(0).toString(16).toUpperCase();
  });
}
var init_extended_encode_uri_component3 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/extended-encode-uri-component.js"() {
    __name(extendedEncodeURIComponent2, "extendedEncodeURIComponent");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/SerdeContext.js
var SerdeContext2;
var init_SerdeContext3 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/SerdeContext.js"() {
    SerdeContext2 = class {
      static {
        __name(this, "SerdeContext");
      }
      serdeContext;
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/Int64.js
function negate(bytes) {
  for (let i32 = 0; i32 < 8; i32++) {
    bytes[i32] ^= 255;
  }
  for (let i32 = 7; i32 > -1; i32--) {
    bytes[i32]++;
    if (bytes[i32] !== 0)
      break;
  }
}
var Int64;
var init_Int64 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/Int64.js"() {
    init_serde3();
    Int64 = class _Int64 {
      static {
        __name(this, "Int64");
      }
      bytes;
      constructor(bytes) {
        this.bytes = bytes;
        if (bytes.byteLength !== 8) {
          throw new Error("Int64 buffers must be exactly 8 bytes");
        }
      }
      static fromNumber(number) {
        if (number > 9223372036854776e3 || number < -9223372036854776e3) {
          throw new Error(`${number} is too large (or, if negative, too small) to represent as an Int64`);
        }
        const bytes = new Uint8Array(8);
        for (let i32 = 7, remaining = Math.abs(Math.round(number)); i32 > -1 && remaining > 0; i32--, remaining /= 256) {
          bytes[i32] = remaining;
        }
        if (number < 0) {
          negate(bytes);
        }
        return new _Int64(bytes);
      }
      valueOf() {
        const bytes = this.bytes.slice(0);
        const negative = bytes[0] & 128;
        if (negative) {
          negate(bytes);
        }
        return parseInt(toHex(bytes), 16) * (negative ? -1 : 1);
      }
      toString() {
        return String(this.valueOf());
      }
    };
    __name(negate, "negate");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/HeaderMarshaller.js
var HeaderMarshaller, HEADER_VALUE_TYPE, BOOLEAN_TAG, BYTE_TAG, SHORT_TAG, INT_TAG, LONG_TAG, BINARY_TAG, STRING_TAG, TIMESTAMP_TAG, UUID_TAG, UUID_PATTERN;
var init_HeaderMarshaller = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/HeaderMarshaller.js"() {
    init_serde3();
    init_Int64();
    HeaderMarshaller = class {
      static {
        __name(this, "HeaderMarshaller");
      }
      toUtf8;
      fromUtf8;
      constructor(toUtf862, fromUtf842) {
        this.toUtf8 = toUtf862;
        this.fromUtf8 = fromUtf842;
      }
      format(headers) {
        const chunks2 = [];
        for (const headerName of Object.keys(headers)) {
          const bytes = this.fromUtf8(headerName);
          chunks2.push(Uint8Array.from([bytes.byteLength]), bytes, this.formatHeaderValue(headers[headerName]));
        }
        const out = new Uint8Array(chunks2.reduce((carry, bytes) => carry + bytes.byteLength, 0));
        let position = 0;
        for (const chunk of chunks2) {
          out.set(chunk, position);
          position += chunk.byteLength;
        }
        return out;
      }
      formatHeaderValue(header) {
        switch (header.type) {
          case "boolean":
            return Uint8Array.from([header.value ? 0 : 1]);
          case "byte":
            return Uint8Array.from([2, header.value]);
          case "short":
            const shortView = new DataView(new ArrayBuffer(3));
            shortView.setUint8(0, 3);
            shortView.setInt16(1, header.value, false);
            return new Uint8Array(shortView.buffer);
          case "integer":
            const intView = new DataView(new ArrayBuffer(5));
            intView.setUint8(0, 4);
            intView.setInt32(1, header.value, false);
            return new Uint8Array(intView.buffer);
          case "long":
            const longBytes = new Uint8Array(9);
            longBytes[0] = 5;
            longBytes.set(header.value.bytes, 1);
            return longBytes;
          case "binary":
            const binView = new DataView(new ArrayBuffer(3 + header.value.byteLength));
            binView.setUint8(0, 6);
            binView.setUint16(1, header.value.byteLength, false);
            const binBytes = new Uint8Array(binView.buffer);
            binBytes.set(header.value, 3);
            return binBytes;
          case "string":
            const utf8Bytes = this.fromUtf8(header.value);
            const strView = new DataView(new ArrayBuffer(3 + utf8Bytes.byteLength));
            strView.setUint8(0, 7);
            strView.setUint16(1, utf8Bytes.byteLength, false);
            const strBytes = new Uint8Array(strView.buffer);
            strBytes.set(utf8Bytes, 3);
            return strBytes;
          case "timestamp":
            const tsBytes = new Uint8Array(9);
            tsBytes[0] = 8;
            tsBytes.set(Int64.fromNumber(header.value.valueOf()).bytes, 1);
            return tsBytes;
          case "uuid":
            if (!UUID_PATTERN.test(header.value)) {
              throw new Error(`Invalid UUID received: ${header.value}`);
            }
            const uuidBytes = new Uint8Array(17);
            uuidBytes[0] = 9;
            uuidBytes.set(fromHex(header.value.replace(/\-/g, "")), 1);
            return uuidBytes;
        }
      }
      parse(headers) {
        const out = {};
        let position = 0;
        while (position < headers.byteLength) {
          const nameLength = headers.getUint8(position++);
          const name = this.toUtf8(new Uint8Array(headers.buffer, headers.byteOffset + position, nameLength));
          position += nameLength;
          switch (headers.getUint8(position++)) {
            case 0:
              out[name] = {
                type: BOOLEAN_TAG,
                value: true
              };
              break;
            case 1:
              out[name] = {
                type: BOOLEAN_TAG,
                value: false
              };
              break;
            case 2:
              out[name] = {
                type: BYTE_TAG,
                value: headers.getInt8(position++)
              };
              break;
            case 3:
              out[name] = {
                type: SHORT_TAG,
                value: headers.getInt16(position, false)
              };
              position += 2;
              break;
            case 4:
              out[name] = {
                type: INT_TAG,
                value: headers.getInt32(position, false)
              };
              position += 4;
              break;
            case 5:
              out[name] = {
                type: LONG_TAG,
                value: new Int64(new Uint8Array(headers.buffer, headers.byteOffset + position, 8))
              };
              position += 8;
              break;
            case 6:
              const binaryLength = headers.getUint16(position, false);
              position += 2;
              out[name] = {
                type: BINARY_TAG,
                value: new Uint8Array(headers.buffer, headers.byteOffset + position, binaryLength)
              };
              position += binaryLength;
              break;
            case 7:
              const stringLength = headers.getUint16(position, false);
              position += 2;
              out[name] = {
                type: STRING_TAG,
                value: this.toUtf8(new Uint8Array(headers.buffer, headers.byteOffset + position, stringLength))
              };
              position += stringLength;
              break;
            case 8:
              out[name] = {
                type: TIMESTAMP_TAG,
                value: new Date(new Int64(new Uint8Array(headers.buffer, headers.byteOffset + position, 8)).valueOf())
              };
              position += 8;
              break;
            case 9:
              const uuidBytes = new Uint8Array(headers.buffer, headers.byteOffset + position, 16);
              position += 16;
              out[name] = {
                type: UUID_TAG,
                value: `${toHex(uuidBytes.subarray(0, 4))}-${toHex(uuidBytes.subarray(4, 6))}-${toHex(uuidBytes.subarray(6, 8))}-${toHex(uuidBytes.subarray(8, 10))}-${toHex(uuidBytes.subarray(10))}`
              };
              break;
            default:
              throw new Error(`Unrecognized header type tag`);
          }
        }
        return out;
      }
    };
    (function(HEADER_VALUE_TYPE6) {
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["boolTrue"] = 0] = "boolTrue";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["boolFalse"] = 1] = "boolFalse";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["byte"] = 2] = "byte";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["short"] = 3] = "short";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["integer"] = 4] = "integer";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["long"] = 5] = "long";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["byteArray"] = 6] = "byteArray";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["string"] = 7] = "string";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["timestamp"] = 8] = "timestamp";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["uuid"] = 9] = "uuid";
    })(HEADER_VALUE_TYPE || (HEADER_VALUE_TYPE = {}));
    BOOLEAN_TAG = "boolean";
    BYTE_TAG = "byte";
    SHORT_TAG = "short";
    INT_TAG = "integer";
    LONG_TAG = "long";
    BINARY_TAG = "binary";
    STRING_TAG = "string";
    TIMESTAMP_TAG = "timestamp";
    UUID_TAG = "uuid";
    UUID_PATTERN = /^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$/;
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/splitMessage.js
function splitMessage({ byteLength, byteOffset, buffer }) {
  if (byteLength < MINIMUM_MESSAGE_LENGTH) {
    throw new Error("Provided message too short to accommodate event stream message overhead");
  }
  const view = new DataView(buffer, byteOffset, byteLength);
  const messageLength = view.getUint32(0, false);
  if (byteLength !== messageLength) {
    throw new Error("Reported message length does not match received message length");
  }
  const headerLength = view.getUint32(PRELUDE_MEMBER_LENGTH, false);
  const expectedPreludeChecksum = view.getUint32(PRELUDE_LENGTH, false);
  const expectedMessageChecksum = view.getUint32(byteLength - CHECKSUM_LENGTH, false);
  const checksummer = new import_crc32.Crc32().update(new Uint8Array(buffer, byteOffset, PRELUDE_LENGTH));
  if (expectedPreludeChecksum !== checksummer.digest()) {
    throw new Error(`The prelude checksum specified in the message (${expectedPreludeChecksum}) does not match the calculated CRC32 checksum (${checksummer.digest()})`);
  }
  checksummer.update(new Uint8Array(buffer, byteOffset + PRELUDE_LENGTH, byteLength - (PRELUDE_LENGTH + CHECKSUM_LENGTH)));
  if (expectedMessageChecksum !== checksummer.digest()) {
    throw new Error(`The message checksum (${checksummer.digest()}) did not match the expected value of ${expectedMessageChecksum}`);
  }
  return {
    headers: new DataView(buffer, byteOffset + PRELUDE_LENGTH + CHECKSUM_LENGTH, headerLength),
    body: new Uint8Array(buffer, byteOffset + PRELUDE_LENGTH + CHECKSUM_LENGTH + headerLength, messageLength - headerLength - (PRELUDE_LENGTH + CHECKSUM_LENGTH + CHECKSUM_LENGTH))
  };
}
var import_crc32, PRELUDE_MEMBER_LENGTH, PRELUDE_LENGTH, CHECKSUM_LENGTH, MINIMUM_MESSAGE_LENGTH;
var init_splitMessage = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/splitMessage.js"() {
    import_crc32 = __toESM(require_main3());
    PRELUDE_MEMBER_LENGTH = 4;
    PRELUDE_LENGTH = PRELUDE_MEMBER_LENGTH * 2;
    CHECKSUM_LENGTH = 4;
    MINIMUM_MESSAGE_LENGTH = PRELUDE_LENGTH + CHECKSUM_LENGTH * 2;
    __name(splitMessage, "splitMessage");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/EventStreamCodec.js
var import_crc322, EventStreamCodec;
var init_EventStreamCodec = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/EventStreamCodec.js"() {
    import_crc322 = __toESM(require_main3());
    init_HeaderMarshaller();
    init_splitMessage();
    EventStreamCodec = class {
      static {
        __name(this, "EventStreamCodec");
      }
      headerMarshaller;
      messageBuffer;
      isEndOfStream;
      constructor(toUtf862, fromUtf842) {
        this.headerMarshaller = new HeaderMarshaller(toUtf862, fromUtf842);
        this.messageBuffer = [];
        this.isEndOfStream = false;
      }
      feed(message2) {
        this.messageBuffer.push(this.decode(message2));
      }
      endOfStream() {
        this.isEndOfStream = true;
      }
      getMessage() {
        const message2 = this.messageBuffer.pop();
        const isEndOfStream = this.isEndOfStream;
        return {
          getMessage() {
            return message2;
          },
          isEndOfStream() {
            return isEndOfStream;
          }
        };
      }
      getAvailableMessages() {
        const messages = this.messageBuffer;
        this.messageBuffer = [];
        const isEndOfStream = this.isEndOfStream;
        return {
          getMessages() {
            return messages;
          },
          isEndOfStream() {
            return isEndOfStream;
          }
        };
      }
      encode({ headers: rawHeaders, body }) {
        const headers = this.headerMarshaller.format(rawHeaders);
        const length = headers.byteLength + body.byteLength + 16;
        const out = new Uint8Array(length);
        const view = new DataView(out.buffer, out.byteOffset, out.byteLength);
        const checksum = new import_crc322.Crc32();
        view.setUint32(0, length, false);
        view.setUint32(4, headers.byteLength, false);
        view.setUint32(8, checksum.update(out.subarray(0, 8)).digest(), false);
        out.set(headers, 12);
        out.set(body, headers.byteLength + 12);
        view.setUint32(length - 4, checksum.update(out.subarray(8, length - 4)).digest(), false);
        return out;
      }
      decode(message2) {
        const { headers, body } = splitMessage(message2);
        return { headers: this.headerMarshaller.parse(headers), body };
      }
      formatHeaders(rawHeaders) {
        return this.headerMarshaller.format(rawHeaders);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/MessageDecoderStream.js
var MessageDecoderStream;
var init_MessageDecoderStream = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/MessageDecoderStream.js"() {
    MessageDecoderStream = class {
      static {
        __name(this, "MessageDecoderStream");
      }
      options;
      constructor(options) {
        this.options = options;
      }
      [Symbol.asyncIterator]() {
        return this.asyncIterator();
      }
      async *asyncIterator() {
        for await (const bytes of this.options.inputStream) {
          const decoded = this.options.decoder.decode(bytes);
          yield decoded;
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/MessageEncoderStream.js
var MessageEncoderStream;
var init_MessageEncoderStream = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/MessageEncoderStream.js"() {
    MessageEncoderStream = class {
      static {
        __name(this, "MessageEncoderStream");
      }
      options;
      constructor(options) {
        this.options = options;
      }
      [Symbol.asyncIterator]() {
        return this.asyncIterator();
      }
      async *asyncIterator() {
        for await (const msg of this.options.messageStream) {
          const encoded = this.options.encoder.encode(msg);
          yield encoded;
        }
        if (this.options.includeEndFrame) {
          yield new Uint8Array(0);
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/SmithyMessageDecoderStream.js
var SmithyMessageDecoderStream;
var init_SmithyMessageDecoderStream = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/SmithyMessageDecoderStream.js"() {
    SmithyMessageDecoderStream = class {
      static {
        __name(this, "SmithyMessageDecoderStream");
      }
      options;
      constructor(options) {
        this.options = options;
      }
      [Symbol.asyncIterator]() {
        return this.asyncIterator();
      }
      async *asyncIterator() {
        for await (const message2 of this.options.messageStream) {
          const deserialized = await this.options.deserializer(message2);
          if (deserialized === void 0)
            continue;
          yield deserialized;
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/SmithyMessageEncoderStream.js
var SmithyMessageEncoderStream;
var init_SmithyMessageEncoderStream = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/SmithyMessageEncoderStream.js"() {
    SmithyMessageEncoderStream = class {
      static {
        __name(this, "SmithyMessageEncoderStream");
      }
      options;
      constructor(options) {
        this.options = options;
      }
      [Symbol.asyncIterator]() {
        return this.asyncIterator();
      }
      async *asyncIterator() {
        for await (const chunk of this.options.inputStream) {
          const payloadBuf = this.options.serializer(chunk);
          yield payloadBuf;
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/getChunkedStream.js
function getChunkedStream(source) {
  let currentMessageTotalLength = 0;
  let currentMessagePendingLength = 0;
  let currentMessage = null;
  let messageLengthBuffer = null;
  const allocateMessage = /* @__PURE__ */ __name((size) => {
    if (typeof size !== "number") {
      throw new Error("Attempted to allocate an event message where size was not a number: " + size);
    }
    currentMessageTotalLength = size;
    currentMessagePendingLength = 4;
    currentMessage = new Uint8Array(size);
    const currentMessageView = new DataView(currentMessage.buffer);
    currentMessageView.setUint32(0, size, false);
  }, "allocateMessage");
  const iterator = /* @__PURE__ */ __name(async function* () {
    const sourceIterator = source[Symbol.asyncIterator]();
    while (true) {
      const { value, done } = await sourceIterator.next();
      if (done) {
        if (!currentMessageTotalLength) {
          return;
        } else if (currentMessageTotalLength === currentMessagePendingLength) {
          yield currentMessage;
        } else {
          throw new Error("Truncated event message received.");
        }
        return;
      }
      const chunkLength = value.length;
      let currentOffset = 0;
      while (currentOffset < chunkLength) {
        if (!currentMessage) {
          const bytesRemaining = chunkLength - currentOffset;
          if (!messageLengthBuffer) {
            messageLengthBuffer = new Uint8Array(4);
          }
          const numBytesForTotal = Math.min(4 - currentMessagePendingLength, bytesRemaining);
          messageLengthBuffer.set(value.slice(currentOffset, currentOffset + numBytesForTotal), currentMessagePendingLength);
          currentMessagePendingLength += numBytesForTotal;
          currentOffset += numBytesForTotal;
          if (currentMessagePendingLength < 4) {
            break;
          }
          allocateMessage(new DataView(messageLengthBuffer.buffer).getUint32(0, false));
          messageLengthBuffer = null;
        }
        const numBytesToWrite = Math.min(currentMessageTotalLength - currentMessagePendingLength, chunkLength - currentOffset);
        currentMessage.set(value.slice(currentOffset, currentOffset + numBytesToWrite), currentMessagePendingLength);
        currentMessagePendingLength += numBytesToWrite;
        currentOffset += numBytesToWrite;
        if (currentMessageTotalLength && currentMessageTotalLength === currentMessagePendingLength) {
          yield currentMessage;
          currentMessage = null;
          currentMessageTotalLength = 0;
          currentMessagePendingLength = 0;
        }
      }
    }
  }, "iterator");
  return {
    [Symbol.asyncIterator]: iterator
  };
}
var init_getChunkedStream = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/getChunkedStream.js"() {
    __name(getChunkedStream, "getChunkedStream");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/getUnmarshalledStream.js
function getUnmarshalledStream(source, options) {
  const messageUnmarshaller = getMessageUnmarshaller(options.deserializer, options.toUtf8);
  return {
    [Symbol.asyncIterator]: async function* () {
      for await (const chunk of source) {
        const message2 = options.eventStreamCodec.decode(chunk);
        const type = await messageUnmarshaller(message2);
        if (type === void 0)
          continue;
        yield type;
      }
    }
  };
}
function getMessageUnmarshaller(deserializer, toUtf862) {
  return async function(message2) {
    const { value: messageType } = message2.headers[":message-type"];
    if (messageType === "error") {
      const unmodeledError = new Error(message2.headers[":error-message"].value || "UnknownError");
      unmodeledError.name = message2.headers[":error-code"].value;
      throw unmodeledError;
    } else if (messageType === "exception") {
      const code = message2.headers[":exception-type"].value;
      const exception = { [code]: message2 };
      const deserializedException = await deserializer(exception);
      if (deserializedException.$unknown) {
        const error4 = new Error(toUtf862(message2.body));
        error4.name = code;
        throw error4;
      }
      throw deserializedException[code];
    } else if (messageType === "event") {
      const event = {
        [message2.headers[":event-type"].value]: message2
      };
      const deserialized = await deserializer(event);
      if (deserialized.$unknown)
        return;
      return deserialized;
    } else {
      throw Error(`Unrecognizable event type: ${message2.headers[":event-type"].value}`);
    }
  };
}
var init_getUnmarshalledStream = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/getUnmarshalledStream.js"() {
    __name(getUnmarshalledStream, "getUnmarshalledStream");
    __name(getMessageUnmarshaller, "getMessageUnmarshaller");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/EventStreamMarshaller.js
var EventStreamMarshaller, eventStreamSerdeProvider;
var init_EventStreamMarshaller = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/EventStreamMarshaller.js"() {
    init_EventStreamCodec();
    init_MessageDecoderStream();
    init_MessageEncoderStream();
    init_SmithyMessageDecoderStream();
    init_SmithyMessageEncoderStream();
    init_getChunkedStream();
    init_getUnmarshalledStream();
    EventStreamMarshaller = class {
      static {
        __name(this, "EventStreamMarshaller");
      }
      eventStreamCodec;
      utfEncoder;
      constructor({ utf8Encoder, utf8Decoder }) {
        this.eventStreamCodec = new EventStreamCodec(utf8Encoder, utf8Decoder);
        this.utfEncoder = utf8Encoder;
      }
      deserialize(body, deserializer) {
        const inputStream = getChunkedStream(body);
        return new SmithyMessageDecoderStream({
          messageStream: new MessageDecoderStream({ inputStream, decoder: this.eventStreamCodec }),
          deserializer: getMessageUnmarshaller(deserializer, this.utfEncoder)
        });
      }
      serialize(inputStream, serializer) {
        return new MessageEncoderStream({
          messageStream: new SmithyMessageEncoderStream({ inputStream, serializer }),
          encoder: this.eventStreamCodec,
          includeEndFrame: true
        });
      }
    };
    eventStreamSerdeProvider = /* @__PURE__ */ __name((options) => new EventStreamMarshaller(options), "eventStreamSerdeProvider");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde/EventStreamMarshaller.js
async function* readableToIterable(readStream) {
  let streamEnded = false;
  let generationEnded = false;
  const records = new Array();
  readStream.on("error", (err) => {
    if (!streamEnded) {
      streamEnded = true;
    }
    if (err) {
      throw err;
    }
  });
  readStream.on("data", (data3) => {
    records.push(data3);
  });
  readStream.on("end", () => {
    streamEnded = true;
  });
  while (!generationEnded) {
    const value = await new Promise((resolve13) => setTimeout(() => resolve13(records.shift()), 0));
    if (value) {
      yield value;
    }
    generationEnded = streamEnded && records.length === 0;
  }
}
var import_node_stream4, EventStreamMarshaller2, eventStreamSerdeProvider2;
var init_EventStreamMarshaller2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde/EventStreamMarshaller.js"() {
    import_node_stream4 = require("node:stream");
    init_EventStreamMarshaller();
    EventStreamMarshaller2 = class {
      static {
        __name(this, "EventStreamMarshaller");
      }
      universalMarshaller;
      constructor({ utf8Encoder, utf8Decoder }) {
        this.universalMarshaller = new EventStreamMarshaller({
          utf8Decoder,
          utf8Encoder
        });
      }
      deserialize(body, deserializer) {
        const bodyIterable = typeof body[Symbol.asyncIterator] === "function" ? body : readableToIterable(body);
        return this.universalMarshaller.deserialize(bodyIterable, deserializer);
      }
      serialize(input, serializer) {
        return import_node_stream4.Readable.from(this.universalMarshaller.serialize(input, serializer));
      }
    };
    eventStreamSerdeProvider2 = /* @__PURE__ */ __name((options) => new EventStreamMarshaller2(options), "eventStreamSerdeProvider");
    __name(readableToIterable, "readableToIterable");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde/utils.js
var readableStreamToIterable, iterableToReadableStream;
var init_utils7 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde/utils.js"() {
    readableStreamToIterable = /* @__PURE__ */ __name((readableStream) => ({
      [Symbol.asyncIterator]: async function* () {
        const reader = readableStream.getReader();
        try {
          while (true) {
            const { done, value } = await reader.read();
            if (done)
              return;
            yield value;
          }
        } finally {
          reader.releaseLock();
        }
      }
    }), "readableStreamToIterable");
    iterableToReadableStream = /* @__PURE__ */ __name((asyncIterable) => {
      const iterator = asyncIterable[Symbol.asyncIterator]();
      return new ReadableStream({
        async pull(controller) {
          const { done, value } = await iterator.next();
          if (done) {
            return controller.close();
          }
          controller.enqueue(value);
        }
      });
    }, "iterableToReadableStream");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-config-resolver/EventStreamSerdeConfig.js
var resolveEventStreamSerdeConfig;
var init_EventStreamSerdeConfig = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-config-resolver/EventStreamSerdeConfig.js"() {
    resolveEventStreamSerdeConfig = /* @__PURE__ */ __name((input) => Object.assign(input, {
      eventStreamMarshaller: input.eventStreamSerdeProvider(input)
    }), "resolveEventStreamSerdeConfig");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/EventStreamSerde.js
var EventStreamSerde2;
var init_EventStreamSerde2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/EventStreamSerde.js"() {
    init_serde3();
    EventStreamSerde2 = class {
      static {
        __name(this, "EventStreamSerde");
      }
      marshaller;
      serializer;
      deserializer;
      serdeContext;
      defaultContentType;
      constructor({ marshaller, serializer, deserializer, serdeContext, defaultContentType }) {
        this.marshaller = marshaller;
        this.serializer = serializer;
        this.deserializer = deserializer;
        this.serdeContext = serdeContext;
        this.defaultContentType = defaultContentType;
      }
      async serializeEventStream({ eventStream, requestSchema, initialRequest }) {
        const marshaller = this.marshaller;
        const eventStreamMember = requestSchema.getEventStreamMember();
        const unionSchema = requestSchema.getMemberSchema(eventStreamMember);
        const serializer = this.serializer;
        const defaultContentType = this.defaultContentType;
        const initialRequestMarker = /* @__PURE__ */ Symbol("initialRequestMarker");
        const eventStreamIterable = {
          async *[Symbol.asyncIterator]() {
            if (initialRequest) {
              const headers = {
                ":event-type": { type: "string", value: "initial-request" },
                ":message-type": { type: "string", value: "event" },
                ":content-type": { type: "string", value: defaultContentType }
              };
              serializer.write(requestSchema, initialRequest);
              const body = serializer.flush();
              yield {
                [initialRequestMarker]: true,
                headers,
                body
              };
            }
            for await (const page of eventStream) {
              yield page;
            }
          }
        };
        return marshaller.serialize(eventStreamIterable, (event) => {
          if (event[initialRequestMarker]) {
            return {
              headers: event.headers,
              body: event.body
            };
          }
          let unionMember = "";
          for (const key in event) {
            if (key !== "__type") {
              unionMember = key;
              break;
            }
          }
          const { additionalHeaders, body, eventType, explicitPayloadContentType } = this.writeEventBody(unionMember, unionSchema, event);
          const headers = {
            ":event-type": { type: "string", value: eventType },
            ":message-type": { type: "string", value: "event" },
            ":content-type": { type: "string", value: explicitPayloadContentType ?? defaultContentType },
            ...additionalHeaders
          };
          return {
            headers,
            body
          };
        });
      }
      async deserializeEventStream({ response, responseSchema, initialResponseContainer }) {
        const marshaller = this.marshaller;
        const eventStreamMember = responseSchema.getEventStreamMember();
        const unionSchema = responseSchema.getMemberSchema(eventStreamMember);
        const memberSchemas = unionSchema.getMemberSchemas();
        const initialResponseMarker = /* @__PURE__ */ Symbol("initialResponseMarker");
        const asyncIterable = marshaller.deserialize(response.body, async (event) => {
          let unionMember = "";
          for (const key in event) {
            if (key !== "__type") {
              unionMember = key;
              break;
            }
          }
          const body = event[unionMember].body;
          if (unionMember === "initial-response") {
            const dataObject = await this.deserializer.read(responseSchema, body);
            delete dataObject[eventStreamMember];
            return {
              [initialResponseMarker]: true,
              ...dataObject
            };
          } else if (unionMember in memberSchemas) {
            const eventStreamSchema = memberSchemas[unionMember];
            if (eventStreamSchema.isStructSchema()) {
              const out = {};
              let hasBindings = false;
              for (const [name, member7] of eventStreamSchema.structIterator()) {
                const { eventHeader, eventPayload } = member7.getMergedTraits();
                hasBindings = hasBindings || Boolean(eventHeader || eventPayload);
                if (eventPayload) {
                  if (member7.isBlobSchema()) {
                    out[name] = body;
                  } else if (member7.isStringSchema()) {
                    out[name] = (this.serdeContext?.utf8Encoder ?? toUtf832)(body);
                  } else if (member7.isStructSchema()) {
                    out[name] = await this.deserializer.read(member7, body);
                  }
                } else if (eventHeader) {
                  const value = event[unionMember].headers[name]?.value;
                  if (value != null) {
                    if (member7.isNumericSchema()) {
                      if (value && typeof value === "object" && "bytes" in value) {
                        out[name] = BigInt(value.toString());
                      } else {
                        out[name] = Number(value);
                      }
                    } else {
                      out[name] = value;
                    }
                  }
                }
              }
              if (hasBindings) {
                return {
                  [unionMember]: out
                };
              }
              if (body.byteLength === 0) {
                return {
                  [unionMember]: {}
                };
              }
            }
            return {
              [unionMember]: await this.deserializer.read(eventStreamSchema, body)
            };
          } else {
            return {
              $unknown: event
            };
          }
        });
        const asyncIterator = asyncIterable[Symbol.asyncIterator]();
        const firstEvent = await asyncIterator.next();
        if (firstEvent.done) {
          return asyncIterable;
        }
        if (firstEvent.value?.[initialResponseMarker]) {
          if (!responseSchema) {
            throw new Error("@smithy::core/protocols - initial-response event encountered in event stream but no response schema given.");
          }
          for (const key in firstEvent.value) {
            initialResponseContainer[key] = firstEvent.value[key];
          }
        }
        return {
          async *[Symbol.asyncIterator]() {
            if (!firstEvent?.value?.[initialResponseMarker]) {
              yield firstEvent.value;
            }
            while (true) {
              const { done, value } = await asyncIterator.next();
              if (done) {
                break;
              }
              yield value;
            }
          }
        };
      }
      writeEventBody(unionMember, unionSchema, event) {
        const serializer = this.serializer;
        let eventType = unionMember;
        let explicitPayloadMember = null;
        let explicitPayloadContentType;
        const isKnownSchema = (() => {
          const struct3 = unionSchema.getSchema();
          return struct3[4].includes(unionMember);
        })();
        const additionalHeaders = {};
        if (!isKnownSchema) {
          const [type, value] = event[unionMember];
          eventType = type;
          serializer.write(15, value);
        } else {
          const eventSchema = unionSchema.getMemberSchema(unionMember);
          if (eventSchema.isStructSchema()) {
            for (const [memberName, memberSchema] of eventSchema.structIterator()) {
              const { eventHeader, eventPayload } = memberSchema.getMergedTraits();
              if (eventPayload) {
                explicitPayloadMember = memberName;
              } else if (eventHeader) {
                const value = event[unionMember][memberName];
                let type = "binary";
                if (memberSchema.isNumericSchema()) {
                  if ((-2) ** 31 <= value && value <= 2 ** 31 - 1) {
                    type = "integer";
                  } else {
                    type = "long";
                  }
                } else if (memberSchema.isTimestampSchema()) {
                  type = "timestamp";
                } else if (memberSchema.isStringSchema()) {
                  type = "string";
                } else if (memberSchema.isBooleanSchema()) {
                  type = "boolean";
                }
                if (value != null) {
                  additionalHeaders[memberName] = {
                    type,
                    value
                  };
                  delete event[unionMember][memberName];
                }
              }
            }
            if (explicitPayloadMember !== null) {
              const payloadSchema = eventSchema.getMemberSchema(explicitPayloadMember);
              if (payloadSchema.isBlobSchema()) {
                explicitPayloadContentType = "application/octet-stream";
              } else if (payloadSchema.isStringSchema()) {
                explicitPayloadContentType = "text/plain";
              }
              serializer.write(payloadSchema, event[unionMember][explicitPayloadMember]);
            } else {
              serializer.write(eventSchema, event[unionMember]);
            }
          } else if (eventSchema.isUnitSchema()) {
            serializer.write(eventSchema, {});
          } else {
            throw new Error("@smithy/core/event-streams - non-struct member not supported in event stream union.");
          }
        }
        const messageSerialization = serializer.flush() ?? new Uint8Array();
        const body = typeof messageSerialization === "string" ? (this.serdeContext?.utf8Decoder ?? fromUtf820)(messageSerialization) : messageSerialization;
        return {
          body,
          eventType,
          explicitPayloadContentType,
          additionalHeaders
        };
      }
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/index.js
var event_streams_exports2 = {};
__export(event_streams_exports2, {
  EventStreamCodec: () => EventStreamCodec,
  EventStreamMarshaller: () => EventStreamMarshaller2,
  EventStreamSerde: () => EventStreamSerde2,
  HeaderMarshaller: () => HeaderMarshaller,
  Int64: () => Int64,
  MessageDecoderStream: () => MessageDecoderStream,
  MessageEncoderStream: () => MessageEncoderStream,
  SmithyMessageDecoderStream: () => SmithyMessageDecoderStream,
  SmithyMessageEncoderStream: () => SmithyMessageEncoderStream,
  UniversalEventStreamMarshaller: () => EventStreamMarshaller,
  eventStreamSerdeProvider: () => eventStreamSerdeProvider2,
  getChunkedStream: () => getChunkedStream,
  getMessageUnmarshaller: () => getMessageUnmarshaller,
  getUnmarshalledStream: () => getUnmarshalledStream,
  iterableToReadableStream: () => iterableToReadableStream,
  readableStreamToIterable: () => readableStreamToIterable,
  resolveEventStreamSerdeConfig: () => resolveEventStreamSerdeConfig,
  universalEventStreamSerdeProvider: () => eventStreamSerdeProvider
});
var init_event_streams2 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/event-streams/index.js"() {
    init_EventStreamCodec();
    init_HeaderMarshaller();
    init_Int64();
    init_MessageDecoderStream();
    init_MessageEncoderStream();
    init_SmithyMessageDecoderStream();
    init_SmithyMessageEncoderStream();
    init_EventStreamMarshaller2();
    init_utils7();
    init_EventStreamMarshaller();
    init_getChunkedStream();
    init_getUnmarshalledStream();
    init_EventStreamSerdeConfig();
    init_EventStreamSerde2();
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/HttpProtocol.js
var HttpProtocol2;
var init_HttpProtocol3 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/HttpProtocol.js"() {
    init_schema5();
    init_transport2();
    init_SerdeContext3();
    HttpProtocol2 = class extends SerdeContext2 {
      static {
        __name(this, "HttpProtocol");
      }
      options;
      compositeErrorRegistry;
      constructor(options) {
        super();
        this.options = options;
        this.compositeErrorRegistry = TypeRegistry2.for(options.defaultNamespace);
        for (const etr of options.errorTypeRegistries ?? []) {
          this.compositeErrorRegistry.copyFrom(etr);
        }
      }
      getRequestType() {
        return HttpRequest19;
      }
      getResponseType() {
        return HttpResponse9;
      }
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
        this.serializer.setSerdeContext(serdeContext);
        this.deserializer.setSerdeContext(serdeContext);
        if (this.getPayloadCodec()) {
          this.getPayloadCodec().setSerdeContext(serdeContext);
        }
      }
      updateServiceEndpoint(request4, endpoint) {
        if ("url" in endpoint) {
          request4.protocol = endpoint.url.protocol;
          request4.hostname = endpoint.url.hostname;
          request4.port = endpoint.url.port ? Number(endpoint.url.port) : void 0;
          request4.path = endpoint.url.pathname;
          request4.fragment = endpoint.url.hash || void 0;
          request4.username = endpoint.url.username || void 0;
          request4.password = endpoint.url.password || void 0;
          if (!request4.query) {
            request4.query = {};
          }
          for (const [k32, v] of endpoint.url.searchParams.entries()) {
            request4.query[k32] = v;
          }
          if (endpoint.headers) {
            for (const name in endpoint.headers) {
              request4.headers[name] = endpoint.headers[name].join(", ");
            }
          }
          return request4;
        } else {
          request4.protocol = endpoint.protocol;
          request4.hostname = endpoint.hostname;
          request4.port = endpoint.port ? Number(endpoint.port) : void 0;
          request4.path = endpoint.path;
          request4.query = {
            ...endpoint.query
          };
          if (endpoint.headers) {
            for (const name in endpoint.headers) {
              request4.headers[name] = endpoint.headers[name];
            }
          }
          return request4;
        }
      }
      setHostPrefix(request4, operationSchema, input) {
        if (this.serdeContext?.disableHostPrefix) {
          return;
        }
        const inputNs = NormalizedSchema2.of(operationSchema.input);
        const opTraits = translateTraits2(operationSchema.traits ?? {});
        if (opTraits.endpoint) {
          let hostPrefix = opTraits.endpoint?.[0];
          if (typeof hostPrefix === "string") {
            for (const [name, member7] of inputNs.structIterator()) {
              if (!member7.getMergedTraits().hostLabel) {
                continue;
              }
              const replacement = input[name];
              if (typeof replacement !== "string") {
                throw new Error(`@smithy/core/schema - ${name} in input must be a string as hostLabel.`);
              }
              hostPrefix = hostPrefix.replace(`{${name}}`, replacement);
            }
            request4.hostname = hostPrefix + request4.hostname;
          }
        }
      }
      deserializeMetadata(output) {
        return {
          httpStatusCode: output.statusCode,
          requestId: output.headers["x-amzn-requestid"] ?? output.headers["x-amzn-request-id"] ?? output.headers["x-amz-request-id"],
          extendedRequestId: output.headers["x-amz-id-2"],
          cfId: output.headers["x-amz-cf-id"]
        };
      }
      async serializeEventStream({ eventStream, requestSchema, initialRequest }) {
        const eventStreamSerde = await this.loadEventStreamCapability();
        return eventStreamSerde.serializeEventStream({
          eventStream,
          requestSchema,
          initialRequest
        });
      }
      async deserializeEventStream({ response, responseSchema, initialResponseContainer }) {
        const eventStreamSerde = await this.loadEventStreamCapability();
        return eventStreamSerde.deserializeEventStream({
          response,
          responseSchema,
          initialResponseContainer
        });
      }
      async loadEventStreamCapability() {
        const { EventStreamSerde: EventStreamSerde7 } = await Promise.resolve().then(() => (init_event_streams2(), event_streams_exports2));
        return new EventStreamSerde7({
          marshaller: this.getEventStreamMarshaller(),
          serializer: this.serializer,
          deserializer: this.deserializer,
          serdeContext: this.serdeContext,
          defaultContentType: this.getDefaultContentType()
        });
      }
      getDefaultContentType() {
        throw new Error(`@smithy/core/protocols - ${this.constructor.name} getDefaultContentType() implementation missing.`);
      }
      async deserializeHttpMessage(schema, context, response, arg4, arg5) {
        void schema;
        void context;
        void response;
        void arg4;
        void arg5;
        return [];
      }
      getEventStreamMarshaller() {
        const context = this.serdeContext;
        if (!context.eventStreamMarshaller) {
          throw new Error("@smithy/core - HttpProtocol: eventStreamMarshaller missing in serdeContext.");
        }
        return context.eventStreamMarshaller;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/HttpBindingProtocol.js
var HttpBindingProtocol2;
var init_HttpBindingProtocol3 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/HttpBindingProtocol.js"() {
    init_schema5();
    init_serde3();
    init_transport2();
    init_HttpProtocol3();
    init_collect_stream_body3();
    init_extended_encode_uri_component3();
    HttpBindingProtocol2 = class extends HttpProtocol2 {
      static {
        __name(this, "HttpBindingProtocol");
      }
      async serializeRequest(operationSchema, _input, context) {
        const input = _input && typeof _input === "object" ? _input : {};
        const serializer = this.serializer;
        const query = {};
        const headers = {};
        const endpoint = await context.endpoint();
        const ns = NormalizedSchema2.of(operationSchema?.input);
        const payloadMemberNames = [];
        const payloadMemberSchemas = [];
        let hasNonHttpBindingMember = false;
        let payload3;
        const request4 = new HttpRequest19({
          protocol: "",
          hostname: "",
          port: void 0,
          path: "",
          fragment: void 0,
          query,
          headers,
          body: void 0
        });
        if (endpoint) {
          this.updateServiceEndpoint(request4, endpoint);
          this.setHostPrefix(request4, operationSchema, input);
          const opTraits = translateTraits2(operationSchema.traits);
          if (opTraits.http) {
            request4.method = opTraits.http[0];
            const [path47, search] = opTraits.http[1].split("?");
            if (request4.path == "/") {
              request4.path = path47;
            } else {
              request4.path += path47;
            }
            const traitSearchParams = new URLSearchParams(search ?? "");
            for (const [key, value] of traitSearchParams) {
              query[key] = value;
            }
          }
        }
        for (const [memberName, memberNs] of ns.structIterator()) {
          const memberTraits = memberNs.getMergedTraits() ?? {};
          const inputMemberValue = input[memberName];
          if (inputMemberValue == null && !memberNs.isIdempotencyToken()) {
            if (memberTraits.httpLabel) {
              if (request4.path.includes(`{${memberName}+}`) || request4.path.includes(`{${memberName}}`)) {
                throw new Error(`No value provided for input HTTP label: ${memberName}.`);
              }
            }
            continue;
          }
          if (memberTraits.httpPayload) {
            const isStreaming = memberNs.isStreaming();
            if (isStreaming) {
              const isEventStream = memberNs.isStructSchema();
              if (isEventStream) {
                if (input[memberName]) {
                  payload3 = await this.serializeEventStream({
                    eventStream: input[memberName],
                    requestSchema: ns
                  });
                }
              } else {
                payload3 = inputMemberValue;
              }
            } else {
              serializer.write(memberNs, inputMemberValue);
              payload3 = serializer.flush();
            }
          } else if (memberTraits.httpLabel) {
            serializer.write(memberNs, inputMemberValue);
            const replacement = serializer.flush();
            if (request4.path.includes(`{${memberName}+}`)) {
              request4.path = request4.path.replace(`{${memberName}+}`, replacement.split("/").map(extendedEncodeURIComponent2).join("/"));
            } else if (request4.path.includes(`{${memberName}}`)) {
              request4.path = request4.path.replace(`{${memberName}}`, extendedEncodeURIComponent2(replacement));
            }
          } else if (memberTraits.httpHeader) {
            serializer.write(memberNs, inputMemberValue);
            headers[memberTraits.httpHeader.toLowerCase()] = String(serializer.flush());
          } else if (typeof memberTraits.httpPrefixHeaders === "string") {
            for (const key in inputMemberValue) {
              const val = inputMemberValue[key];
              const amalgam = memberTraits.httpPrefixHeaders + key;
              serializer.write([memberNs.getValueSchema(), { httpHeader: amalgam }], val);
              headers[amalgam.toLowerCase()] = serializer.flush();
            }
          } else if (memberTraits.httpQuery || memberTraits.httpQueryParams) {
            this.serializeQuery(memberNs, inputMemberValue, query);
          } else {
            hasNonHttpBindingMember = true;
            payloadMemberNames.push(memberName);
            payloadMemberSchemas.push(memberNs);
          }
        }
        if (hasNonHttpBindingMember && input) {
          const [namespace, name] = (ns.getName(true) ?? "#Unknown").split("#");
          const requiredMembers = ns.getSchema()[6];
          const payloadSchema = [
            3,
            namespace,
            name,
            ns.getMergedTraits(),
            payloadMemberNames,
            payloadMemberSchemas,
            void 0
          ];
          if (requiredMembers) {
            payloadSchema[6] = requiredMembers;
          } else {
            payloadSchema.pop();
          }
          serializer.write(payloadSchema, input);
          payload3 = serializer.flush();
        }
        request4.headers = headers;
        request4.query = query;
        request4.body = payload3;
        return request4;
      }
      serializeQuery(ns, data3, query) {
        const serializer = this.serializer;
        const traits = ns.getMergedTraits();
        if (traits.httpQueryParams) {
          for (const key in data3) {
            if (!(key in query)) {
              const val = data3[key];
              const valueSchema = ns.getValueSchema();
              Object.assign(valueSchema.getMergedTraits(), {
                ...traits,
                httpQuery: key,
                httpQueryParams: void 0
              });
              this.serializeQuery(valueSchema, val, query);
            }
          }
          return;
        }
        if (ns.isListSchema()) {
          const sparse = !!ns.getMergedTraits().sparse;
          const buffer = [];
          for (const item of data3) {
            serializer.write([ns.getValueSchema(), traits], item);
            const serializable = serializer.flush();
            if (sparse || serializable !== void 0) {
              buffer.push(serializable);
            }
          }
          query[traits.httpQuery] = buffer;
        } else {
          serializer.write([ns, traits], data3);
          query[traits.httpQuery] = serializer.flush();
        }
      }
      async deserializeResponse(operationSchema, context, response) {
        const deserializer = this.deserializer;
        const ns = NormalizedSchema2.of(operationSchema.output);
        const dataObject = {};
        if (response.statusCode >= 300) {
          const bytes = await collectBody8(response.body, context);
          if (bytes.byteLength > 0) {
            Object.assign(dataObject, await deserializer.read(15, bytes));
          }
          await this.handleError(operationSchema, context, response, dataObject, this.deserializeMetadata(response));
          throw new Error("@smithy/core/protocols - HTTP Protocol error handler failed to throw.");
        }
        for (const header in response.headers) {
          const value = response.headers[header];
          delete response.headers[header];
          response.headers[header.toLowerCase()] = value;
        }
        const nonHttpBindingMembers = await this.deserializeHttpMessage(ns, context, response, dataObject);
        if (nonHttpBindingMembers.length) {
          const bytes = await collectBody8(response.body, context);
          if (bytes.byteLength > 0) {
            const dataFromBody = await deserializer.read(ns, bytes);
            for (const member7 of nonHttpBindingMembers) {
              if (dataFromBody[member7] != null) {
                dataObject[member7] = dataFromBody[member7];
              }
            }
          }
        } else if (nonHttpBindingMembers.discardResponseBody) {
          await collectBody8(response.body, context);
        }
        dataObject.$metadata = this.deserializeMetadata(response);
        return dataObject;
      }
      async deserializeHttpMessage(schema, context, response, arg4, arg5) {
        let dataObject;
        if (arg4 instanceof Set) {
          dataObject = arg5;
        } else {
          dataObject = arg4;
        }
        let discardResponseBody = true;
        const deserializer = this.deserializer;
        const ns = NormalizedSchema2.of(schema);
        const nonHttpBindingMembers = [];
        for (const [memberName, memberSchema] of ns.structIterator()) {
          const memberTraits = memberSchema.getMemberTraits();
          if (memberTraits.httpPayload) {
            discardResponseBody = false;
            const isStreaming = memberSchema.isStreaming();
            if (isStreaming) {
              const isEventStream = memberSchema.isStructSchema();
              if (isEventStream) {
                dataObject[memberName] = await this.deserializeEventStream({
                  response,
                  responseSchema: ns
                });
              } else {
                dataObject[memberName] = sdkStreamMixin3(response.body);
              }
            } else if (response.body) {
              const bytes = await collectBody8(response.body, context);
              if (bytes.byteLength > 0) {
                dataObject[memberName] = await deserializer.read(memberSchema, bytes);
              }
            }
          } else if (memberTraits.httpHeader) {
            const key = String(memberTraits.httpHeader).toLowerCase();
            const value = response.headers[key];
            if (null != value) {
              if (memberSchema.isListSchema()) {
                const headerListValueSchema = memberSchema.getValueSchema();
                headerListValueSchema.getMergedTraits().httpHeader = key;
                let sections;
                if (headerListValueSchema.isTimestampSchema() && headerListValueSchema.getSchema() === 4) {
                  sections = splitEvery2(value, ",", 2);
                } else {
                  sections = splitHeader2(value);
                }
                const list3 = [];
                for (const section of sections) {
                  list3.push(await deserializer.read(headerListValueSchema, section.trim()));
                }
                dataObject[memberName] = list3;
              } else {
                dataObject[memberName] = await deserializer.read(memberSchema, value);
              }
            }
          } else if (memberTraits.httpPrefixHeaders !== void 0) {
            dataObject[memberName] = {};
            for (const header in response.headers) {
              if (header.startsWith(memberTraits.httpPrefixHeaders)) {
                const value = response.headers[header];
                const valueSchema = memberSchema.getValueSchema();
                valueSchema.getMergedTraits().httpHeader = header;
                dataObject[memberName][header.slice(memberTraits.httpPrefixHeaders.length)] = await deserializer.read(valueSchema, value);
              }
            }
          } else if (memberTraits.httpResponseCode) {
            dataObject[memberName] = response.statusCode;
          } else {
            nonHttpBindingMembers.push(memberName);
          }
        }
        nonHttpBindingMembers.discardResponseBody = discardResponseBody;
        return nonHttpBindingMembers;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/RpcProtocol.js
var RpcProtocol2;
var init_RpcProtocol3 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/RpcProtocol.js"() {
    init_schema5();
    init_transport2();
    init_HttpProtocol3();
    init_collect_stream_body3();
    RpcProtocol2 = class extends HttpProtocol2 {
      static {
        __name(this, "RpcProtocol");
      }
      async serializeRequest(operationSchema, _input, context) {
        const serializer = this.serializer;
        const query = {};
        const headers = {};
        const endpoint = await context.endpoint();
        const ns = NormalizedSchema2.of(operationSchema?.input);
        const schema = ns.getSchema();
        let payload3;
        const input = _input && typeof _input === "object" ? _input : {};
        const request4 = new HttpRequest19({
          protocol: "",
          hostname: "",
          port: void 0,
          path: "/",
          fragment: void 0,
          query,
          headers,
          body: void 0
        });
        if (endpoint) {
          this.updateServiceEndpoint(request4, endpoint);
          this.setHostPrefix(request4, operationSchema, input);
        }
        if (input) {
          const eventStreamMember = ns.getEventStreamMember();
          if (eventStreamMember) {
            if (input[eventStreamMember]) {
              const initialRequest = {};
              for (const [memberName, memberSchema] of ns.structIterator()) {
                if (memberName !== eventStreamMember && input[memberName]) {
                  serializer.write(memberSchema, input[memberName]);
                  initialRequest[memberName] = serializer.flush();
                }
              }
              payload3 = await this.serializeEventStream({
                eventStream: input[eventStreamMember],
                requestSchema: ns,
                initialRequest
              });
            }
          } else {
            serializer.write(schema, input);
            payload3 = serializer.flush();
          }
        }
        request4.headers = Object.assign(request4.headers, headers);
        request4.query = query;
        request4.body = payload3;
        request4.method = "POST";
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        const deserializer = this.deserializer;
        const ns = NormalizedSchema2.of(operationSchema.output);
        const dataObject = {};
        if (response.statusCode >= 300) {
          const bytes = await collectBody8(response.body, context);
          if (bytes.byteLength > 0) {
            Object.assign(dataObject, await deserializer.read(15, bytes));
          }
          await this.handleError(operationSchema, context, response, dataObject, this.deserializeMetadata(response));
          throw new Error("@smithy/core/protocols - RPC Protocol error handler failed to throw.");
        }
        for (const header in response.headers) {
          const value = response.headers[header];
          delete response.headers[header];
          response.headers[header.toLowerCase()] = value;
        }
        const eventStreamMember = ns.getEventStreamMember();
        if (eventStreamMember) {
          dataObject[eventStreamMember] = await this.deserializeEventStream({
            response,
            responseSchema: ns,
            initialResponseContainer: dataObject
          });
        } else {
          const bytes = await collectBody8(response.body, context);
          if (bytes.byteLength > 0) {
            Object.assign(dataObject, await deserializer.read(ns, bytes));
          }
        }
        dataObject.$metadata = this.deserializeMetadata(response);
        return dataObject;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/resolve-path.js
var resolvedPath2;
var init_resolve_path3 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/resolve-path.js"() {
    init_extended_encode_uri_component3();
    resolvedPath2 = /* @__PURE__ */ __name((resolvedPath7, input, memberName, labelValueProvider, uriLabel, isGreedyLabel) => {
      if (input != null && input[memberName] !== void 0) {
        const labelValue = labelValueProvider();
        if (labelValue == null || labelValue.length <= 0) {
          throw new Error("Empty value provided for input HTTP label: " + memberName + ".");
        }
        resolvedPath7 = resolvedPath7.replace(uriLabel, isGreedyLabel ? labelValue.split("/").map((segment) => extendedEncodeURIComponent2(segment)).join("/") : extendedEncodeURIComponent2(labelValue));
      } else {
        throw new Error("No value provided for input HTTP label: " + memberName + ".");
      }
      return resolvedPath7;
    }, "resolvedPath");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/requestBuilder.js
function requestBuilder2(input, context) {
  return new RequestBuilder2(input, context);
}
var RequestBuilder2;
var init_requestBuilder4 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/requestBuilder.js"() {
    init_transport2();
    init_resolve_path3();
    __name(requestBuilder2, "requestBuilder");
    RequestBuilder2 = class {
      static {
        __name(this, "RequestBuilder");
      }
      input;
      context;
      query = {};
      method = "";
      headers = {};
      path = "";
      body = null;
      hostname = "";
      resolvePathStack = [];
      constructor(input, context) {
        this.input = input;
        this.context = context;
      }
      async build() {
        const { hostname, protocol = "https", port, path: basePath } = await this.context.endpoint();
        this.path = basePath;
        for (const resolvePath of this.resolvePathStack) {
          resolvePath(this.path);
        }
        return new HttpRequest19({
          protocol,
          hostname: this.hostname || hostname,
          port,
          method: this.method,
          path: this.path,
          query: this.query,
          body: this.body,
          headers: this.headers
        });
      }
      hn(hostname) {
        this.hostname = hostname;
        return this;
      }
      bp(uriLabel) {
        this.resolvePathStack.push((basePath) => {
          this.path = `${basePath?.endsWith("/") ? basePath.slice(0, -1) : basePath || ""}` + uriLabel;
        });
        return this;
      }
      p(memberName, labelValueProvider, uriLabel, isGreedyLabel) {
        this.resolvePathStack.push((path47) => {
          this.path = resolvedPath2(path47, this.input, memberName, labelValueProvider, uriLabel, isGreedyLabel);
        });
        return this;
      }
      h(headers) {
        this.headers = headers;
        return this;
      }
      q(query) {
        this.query = query;
        return this;
      }
      b(body) {
        this.body = body;
        return this;
      }
      m(method) {
        this.method = method;
        return this;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/serde/determineTimestampFormat.js
function determineTimestampFormat2(ns, settings) {
  if (settings.timestampFormat.useTrait) {
    if (ns.isTimestampSchema() && (ns.getSchema() === 5 || ns.getSchema() === 6 || ns.getSchema() === 7)) {
      return ns.getSchema();
    }
  }
  const { httpLabel, httpPrefixHeaders, httpHeader, httpQuery } = ns.getMergedTraits();
  const bindingFormat = settings.httpBindings ? typeof httpPrefixHeaders === "string" || Boolean(httpHeader) ? 6 : Boolean(httpQuery) || Boolean(httpLabel) ? 5 : void 0 : void 0;
  return bindingFormat ?? settings.timestampFormat.default;
}
var init_determineTimestampFormat3 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/serde/determineTimestampFormat.js"() {
    __name(determineTimestampFormat2, "determineTimestampFormat");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/serde/FromStringShapeDeserializer.js
var FromStringShapeDeserializer2;
var init_FromStringShapeDeserializer3 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/serde/FromStringShapeDeserializer.js"() {
    init_schema5();
    init_serde3();
    init_SerdeContext3();
    init_determineTimestampFormat3();
    FromStringShapeDeserializer2 = class extends SerdeContext2 {
      static {
        __name(this, "FromStringShapeDeserializer");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      read(_schema, data3) {
        const ns = NormalizedSchema2.of(_schema);
        if (ns.isListSchema()) {
          return splitHeader2(data3).map((item) => this.read(ns.getValueSchema(), item));
        }
        if (ns.isBlobSchema()) {
          return (this.serdeContext?.base64Decoder ?? fromBase6429)(data3);
        }
        if (ns.isTimestampSchema()) {
          const format32 = determineTimestampFormat2(ns, this.settings);
          switch (format32) {
            case 5:
              return _parseRfc3339DateTimeWithOffset2(data3);
            case 6:
              return _parseRfc7231DateTime2(data3);
            case 7:
              return _parseEpochTimestamp2(data3);
            default:
              console.warn("Missing timestamp format, parsing value with Date constructor:", data3);
              return new Date(data3);
          }
        }
        if (ns.isStringSchema()) {
          const mediaType = ns.getMergedTraits().mediaType;
          let intermediateValue = data3;
          if (mediaType) {
            if (ns.getMergedTraits().httpHeader) {
              intermediateValue = this.base64ToUtf8(intermediateValue);
            }
            const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
            if (isJson) {
              intermediateValue = LazyJsonString3.from(intermediateValue);
            }
            return intermediateValue;
          }
        }
        if (ns.isNumericSchema()) {
          return Number(data3);
        }
        if (ns.isBigIntegerSchema()) {
          return BigInt(data3);
        }
        if (ns.isBigDecimalSchema()) {
          return new NumericValue2(data3, "bigDecimal");
        }
        if (ns.isBooleanSchema()) {
          return String(data3).toLowerCase() === "true";
        }
        return data3;
      }
      base64ToUtf8(base64String) {
        return (this.serdeContext?.utf8Encoder ?? toUtf832)((this.serdeContext?.base64Decoder ?? fromBase6429)(base64String));
      }
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/serde/HttpInterceptingShapeDeserializer.js
var HttpInterceptingShapeDeserializer2;
var init_HttpInterceptingShapeDeserializer3 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/serde/HttpInterceptingShapeDeserializer.js"() {
    init_schema5();
    init_serde3();
    init_SerdeContext3();
    init_FromStringShapeDeserializer3();
    HttpInterceptingShapeDeserializer2 = class extends SerdeContext2 {
      static {
        __name(this, "HttpInterceptingShapeDeserializer");
      }
      codecDeserializer;
      stringDeserializer;
      constructor(codecDeserializer, codecSettings) {
        super();
        this.codecDeserializer = codecDeserializer;
        this.stringDeserializer = new FromStringShapeDeserializer2(codecSettings);
      }
      setSerdeContext(serdeContext) {
        this.stringDeserializer.setSerdeContext(serdeContext);
        this.codecDeserializer.setSerdeContext(serdeContext);
        this.serdeContext = serdeContext;
      }
      read(schema, data3) {
        const ns = NormalizedSchema2.of(schema);
        const traits = ns.getMergedTraits();
        const toString = this.serdeContext?.utf8Encoder ?? toUtf832;
        if (traits.httpHeader || traits.httpResponseCode) {
          return this.stringDeserializer.read(ns, toString(data3));
        }
        if (traits.httpPayload) {
          if (ns.isBlobSchema()) {
            const toBytes = this.serdeContext?.utf8Decoder ?? fromUtf820;
            if (typeof data3 === "string") {
              return toBytes(data3);
            }
            return data3;
          } else if (ns.isStringSchema()) {
            if ("byteLength" in data3) {
              return toString(data3);
            }
            return data3;
          }
        }
        return this.codecDeserializer.read(ns, data3);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/serde/ToStringShapeSerializer.js
var ToStringShapeSerializer2;
var init_ToStringShapeSerializer3 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/serde/ToStringShapeSerializer.js"() {
    init_schema5();
    init_serde3();
    init_SerdeContext3();
    init_determineTimestampFormat3();
    ToStringShapeSerializer2 = class extends SerdeContext2 {
      static {
        __name(this, "ToStringShapeSerializer");
      }
      settings;
      stringBuffer = "";
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value) {
        const ns = NormalizedSchema2.of(schema);
        switch (typeof value) {
          case "object":
            if (value === null) {
              this.stringBuffer = "null";
              return;
            }
            if (ns.isTimestampSchema()) {
              if (!(value instanceof Date)) {
                throw new Error(`@smithy/core/protocols - received non-Date value ${value} when schema expected Date in ${ns.getName(true)}`);
              }
              const format32 = determineTimestampFormat2(ns, this.settings);
              switch (format32) {
                case 5:
                  this.stringBuffer = value.toISOString().replace(".000Z", "Z");
                  break;
                case 6:
                  this.stringBuffer = dateToUtcString12(value);
                  break;
                case 7:
                  this.stringBuffer = String(value.getTime() / 1e3);
                  break;
                default:
                  console.warn("Missing timestamp format, using epoch seconds", value);
                  this.stringBuffer = String(value.getTime() / 1e3);
              }
              return;
            }
            if (ns.isBlobSchema() && "byteLength" in value) {
              this.stringBuffer = (this.serdeContext?.base64Encoder ?? toBase6433)(value);
              return;
            }
            if (ns.isListSchema() && Array.isArray(value)) {
              let buffer = "";
              for (const item of value) {
                this.write([ns.getValueSchema(), ns.getMergedTraits()], item);
                const headerItem = this.flush();
                const serialized = ns.getValueSchema().isTimestampSchema() ? headerItem : quoteHeader2(headerItem);
                if (buffer !== "") {
                  buffer += ", ";
                }
                buffer += serialized;
              }
              this.stringBuffer = buffer;
              return;
            }
            this.stringBuffer = JSON.stringify(value, null, 2);
            break;
          case "string":
            const mediaType = ns.getMergedTraits().mediaType;
            let intermediateValue = value;
            if (mediaType) {
              const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
              if (isJson) {
                intermediateValue = LazyJsonString3.from(intermediateValue);
              }
              if (ns.getMergedTraits().httpHeader) {
                this.stringBuffer = (this.serdeContext?.base64Encoder ?? toBase6433)(intermediateValue.toString());
                return;
              }
            }
            this.stringBuffer = value;
            break;
          default:
            if (ns.isIdempotencyToken()) {
              this.stringBuffer = generateIdempotencyToken2();
            } else {
              this.stringBuffer = String(value);
            }
        }
      }
      flush() {
        const buffer = this.stringBuffer;
        this.stringBuffer = "";
        return buffer;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/serde/HttpInterceptingShapeSerializer.js
var HttpInterceptingShapeSerializer2;
var init_HttpInterceptingShapeSerializer3 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/serde/HttpInterceptingShapeSerializer.js"() {
    init_schema5();
    init_ToStringShapeSerializer3();
    HttpInterceptingShapeSerializer2 = class {
      static {
        __name(this, "HttpInterceptingShapeSerializer");
      }
      codecSerializer;
      stringSerializer;
      buffer;
      constructor(codecSerializer, codecSettings, stringSerializer = new ToStringShapeSerializer2(codecSettings)) {
        this.codecSerializer = codecSerializer;
        this.stringSerializer = stringSerializer;
      }
      setSerdeContext(serdeContext) {
        this.codecSerializer.setSerdeContext(serdeContext);
        this.stringSerializer.setSerdeContext(serdeContext);
      }
      write(schema, value) {
        const ns = NormalizedSchema2.of(schema);
        const traits = ns.getMergedTraits();
        if (traits.httpHeader || traits.httpLabel || traits.httpQuery) {
          this.stringSerializer.write(ns, value);
          this.buffer = this.stringSerializer.flush();
          return;
        }
        return this.codecSerializer.write(ns, value);
      }
      flush() {
        if (this.buffer !== void 0) {
          const buffer = this.buffer;
          this.buffer = void 0;
          return buffer;
        }
        return this.codecSerializer.flush();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/Field.js
var import_types18, Field;
var init_Field = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/Field.js"() {
    import_types18 = __toESM(require_dist_cjs());
    Field = class {
      static {
        __name(this, "Field");
      }
      name;
      kind;
      values;
      constructor({ name, kind = import_types18.FieldPosition.HEADER, values = [] }) {
        this.name = name;
        this.kind = kind;
        this.values = values;
      }
      add(value) {
        this.values.push(value);
      }
      set(values) {
        this.values = values;
      }
      remove(value) {
        this.values = this.values.filter((v) => v !== value);
      }
      toString() {
        return this.values.map((v) => v.includes(",") || v.includes(" ") ? `"${v}"` : v).join(", ");
      }
      get() {
        return this.values;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/Fields.js
var Fields;
var init_Fields = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/Fields.js"() {
    Fields = class {
      static {
        __name(this, "Fields");
      }
      entries = {};
      encoding;
      constructor({ fields = [], encoding = "utf-8" }) {
        fields.forEach(this.setField.bind(this));
        this.encoding = encoding;
      }
      setField(field) {
        this.entries[field.name.toLowerCase()] = field;
      }
      getField(name) {
        return this.entries[name.toLowerCase()];
      }
      removeField(name) {
        delete this.entries[name.toLowerCase()];
      }
      getByType(kind) {
        return Object.values(this.entries).filter((field) => field.kind === kind);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/extensions/httpExtensionConfiguration.js
var getHttpHandlerExtensionConfiguration16, resolveHttpHandlerRuntimeConfig16;
var init_httpExtensionConfiguration = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/extensions/httpExtensionConfiguration.js"() {
    getHttpHandlerExtensionConfiguration16 = /* @__PURE__ */ __name((runtimeConfig) => {
      return {
        setHttpHandler(handler) {
          runtimeConfig.httpHandler = handler;
        },
        httpHandler() {
          return runtimeConfig.httpHandler;
        },
        updateHttpClientConfig(key, value) {
          runtimeConfig.httpHandler?.updateHttpClientConfig(key, value);
        },
        httpHandlerConfigs() {
          return runtimeConfig.httpHandler.httpHandlerConfigs();
        }
      };
    }, "getHttpHandlerExtensionConfiguration");
    resolveHttpHandlerRuntimeConfig16 = /* @__PURE__ */ __name((httpHandlerExtensionConfiguration) => {
      return {
        httpHandler: httpHandlerExtensionConfiguration.httpHandler()
      };
    }, "resolveHttpHandlerRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/middleware-content-length/contentLengthMiddleware.js
function contentLengthMiddleware(bodyLengthChecker) {
  return (next) => async (args) => {
    const request4 = args.request;
    if (HttpRequest19.isInstance(request4)) {
      const { body, headers } = request4;
      if (body && Object.keys(headers).map((str) => str.toLowerCase()).indexOf(CONTENT_LENGTH_HEADER) === -1) {
        try {
          const length = bodyLengthChecker(body);
          request4.headers = {
            ...request4.headers,
            [CONTENT_LENGTH_HEADER]: String(length)
          };
        } catch (error4) {
        }
      }
    }
    return next({
      ...args,
      request: request4
    });
  };
}
var CONTENT_LENGTH_HEADER, contentLengthMiddlewareOptions, getContentLengthPlugin16;
var init_contentLengthMiddleware = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/middleware-content-length/contentLengthMiddleware.js"() {
    init_transport2();
    CONTENT_LENGTH_HEADER = "content-length";
    __name(contentLengthMiddleware, "contentLengthMiddleware");
    contentLengthMiddlewareOptions = {
      step: "build",
      tags: ["SET_CONTENT_LENGTH", "CONTENT_LENGTH"],
      name: "contentLengthMiddleware",
      override: true
    };
    getContentLengthPlugin16 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(contentLengthMiddleware(options.bodyLengthChecker), contentLengthMiddlewareOptions);
      }, "applyToStack")
    }), "getContentLengthPlugin");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/util-uri-escape/escape-uri.js
var escapeUri, hexEncode;
var init_escape_uri = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/util-uri-escape/escape-uri.js"() {
    escapeUri = /* @__PURE__ */ __name((uri) => encodeURIComponent(uri).replace(/[!'()*]/g, hexEncode), "escapeUri");
    hexEncode = /* @__PURE__ */ __name((c32) => `%${c32.charCodeAt(0).toString(16).toUpperCase()}`, "hexEncode");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/util-uri-escape/escape-uri-path.js
var escapeUriPath;
var init_escape_uri_path = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/util-uri-escape/escape-uri-path.js"() {
    init_escape_uri();
    escapeUriPath = /* @__PURE__ */ __name((uri) => uri.split("/").map(escapeUri).join("/"), "escapeUriPath");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/querystring-builder/buildQueryString.js
function buildQueryString(query) {
  const parts = [];
  for (let key of Object.keys(query).sort()) {
    const value = query[key];
    key = escapeUri(key);
    if (Array.isArray(value)) {
      for (let i32 = 0, iLen = value.length; i32 < iLen; i32++) {
        parts.push(`${key}=${escapeUri(value[i32])}`);
      }
    } else {
      let qsEntry = key;
      if (value || typeof value === "string") {
        qsEntry += `=${escapeUri(value)}`;
      }
      parts.push(qsEntry);
    }
  }
  return parts.join("&");
}
var init_buildQueryString = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/querystring-builder/buildQueryString.js"() {
    init_escape_uri();
    __name(buildQueryString, "buildQueryString");
  }
});

// ../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/index.js
var protocols_exports6 = {};
__export(protocols_exports6, {
  Field: () => Field,
  Fields: () => Fields,
  FromStringShapeDeserializer: () => FromStringShapeDeserializer2,
  HttpBindingProtocol: () => HttpBindingProtocol2,
  HttpInterceptingShapeDeserializer: () => HttpInterceptingShapeDeserializer2,
  HttpInterceptingShapeSerializer: () => HttpInterceptingShapeSerializer2,
  HttpProtocol: () => HttpProtocol2,
  HttpRequest: () => HttpRequest19,
  HttpResponse: () => HttpResponse9,
  RequestBuilder: () => RequestBuilder2,
  RpcProtocol: () => RpcProtocol2,
  SerdeContext: () => SerdeContext2,
  ToStringShapeSerializer: () => ToStringShapeSerializer2,
  buildQueryString: () => buildQueryString,
  collectBody: () => collectBody8,
  contentLengthMiddleware: () => contentLengthMiddleware,
  contentLengthMiddlewareOptions: () => contentLengthMiddlewareOptions,
  determineTimestampFormat: () => determineTimestampFormat2,
  escapeUri: () => escapeUri,
  escapeUriPath: () => escapeUriPath,
  extendedEncodeURIComponent: () => extendedEncodeURIComponent2,
  getContentLengthPlugin: () => getContentLengthPlugin16,
  getHttpHandlerExtensionConfiguration: () => getHttpHandlerExtensionConfiguration16,
  isValidHostname: () => isValidHostname,
  parseQueryString: () => parseQueryString,
  parseUrl: () => parseUrl17,
  requestBuilder: () => requestBuilder2,
  resolveHttpHandlerRuntimeConfig: () => resolveHttpHandlerRuntimeConfig16,
  resolvedPath: () => resolvedPath2
});
var init_protocols9 = __esm({
  "../../node_modules/@aws-sdk/lib-storage/node_modules/@smithy/core/dist-es/submodules/protocols/index.js"() {
    init_collect_stream_body3();
    init_extended_encode_uri_component3();
    init_HttpBindingProtocol3();
    init_HttpProtocol3();
    init_RpcProtocol3();
    init_requestBuilder4();
    init_resolve_path3();
    init_FromStringShapeDeserializer3();
    init_HttpInterceptingShapeDeserializer3();
    init_HttpInterceptingShapeSerializer3();
    init_ToStringShapeSerializer3();
    init_determineTimestampFormat3();
    init_SerdeContext3();
    init_Field();
    init_Fields();
    init_transport2();
    init_transport2();
    init_transport2();
    init_httpExtensionConfiguration();
    init_contentLengthMiddleware();
    init_escape_uri();
    init_escape_uri_path();
    init_buildQueryString();
    init_transport2();
    init_transport2();
  }
});

// ../../node_modules/@aws-sdk/lib-storage/dist-cjs/runtimeConfig.shared.js
var require_runtimeConfig_shared5 = __commonJS({
  "../../node_modules/@aws-sdk/lib-storage/dist-cjs/runtimeConfig.shared.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.runtimeConfigShared = void 0;
    exports2.runtimeConfigShared = {
      lstatSync: /* @__PURE__ */ __name(() => {
      }, "lstatSync"),
      isFileReadStream(f32) {
        return false;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/dist-cjs/runtimeConfig.js
var require_runtimeConfig5 = __commonJS({
  "../../node_modules/@aws-sdk/lib-storage/dist-cjs/runtimeConfig.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.runtimeConfig = void 0;
    var node_fs_1 = require("node:fs");
    var runtimeConfig_shared_1 = require_runtimeConfig_shared5();
    exports2.runtimeConfig = {
      ...runtimeConfig_shared_1.runtimeConfigShared,
      runtime: "node",
      lstatSync: node_fs_1.lstatSync,
      isFileReadStream(f32) {
        return f32 instanceof node_fs_1.ReadStream;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/lib-storage/dist-cjs/index.js
var require_dist_cjs126 = __commonJS({
  "../../node_modules/@aws-sdk/lib-storage/dist-cjs/index.js"(exports2) {
    "use strict";
    var clientS3 = require_dist_cjs90();
    var endpoints = (init_endpoints2(), __toCommonJS(endpoints_exports2));
    var protocols = (init_protocols9(), __toCommonJS(protocols_exports6));
    var events = require("events");
    var buffer = require("buffer");
    var runtimeConfig = require_runtimeConfig5();
    var stream = require("stream");
    var byteLength = /* @__PURE__ */ __name((input) => {
      if (input == null) {
        return 0;
      }
      if (typeof input === "string") {
        return buffer.Buffer.byteLength(input);
      }
      if (typeof input.byteLength === "number") {
        return input.byteLength;
      } else if (typeof input.length === "number") {
        return input.length;
      } else if (typeof input.size === "number") {
        return input.size;
      } else if (typeof input.start === "number" && typeof input.end === "number") {
        return input.end + 1 - input.start;
      } else if (runtimeConfig.runtimeConfig.isFileReadStream(input)) {
        try {
          return runtimeConfig.runtimeConfig.lstatSync(input.path).size;
        } catch (error4) {
          return void 0;
        }
      }
      return void 0;
    }, "byteLength");
    var BYTE_LENGTH_SOURCE;
    (function(BYTE_LENGTH_SOURCE2) {
      BYTE_LENGTH_SOURCE2["EMPTY_INPUT"] = "a null or undefined Body";
      BYTE_LENGTH_SOURCE2["CONTENT_LENGTH"] = "the ContentLength property of the params set by the caller";
      BYTE_LENGTH_SOURCE2["STRING_LENGTH"] = "the encoded byte length of the Body string";
      BYTE_LENGTH_SOURCE2["TYPED_ARRAY"] = "the byteLength of a typed byte array such as Uint8Array";
      BYTE_LENGTH_SOURCE2["LENGTH"] = "the value of Body.length";
      BYTE_LENGTH_SOURCE2["SIZE"] = "the value of Body.size";
      BYTE_LENGTH_SOURCE2["START_END_DIFF"] = "the numeric difference between Body.start and Body.end";
      BYTE_LENGTH_SOURCE2["LSTAT"] = "the size of the file given by Body.path on disk as reported by lstatSync";
    })(BYTE_LENGTH_SOURCE || (BYTE_LENGTH_SOURCE = {}));
    var byteLengthSource = /* @__PURE__ */ __name((input, override) => {
      if (override != null) {
        return BYTE_LENGTH_SOURCE.CONTENT_LENGTH;
      }
      if (input == null) {
        return BYTE_LENGTH_SOURCE.EMPTY_INPUT;
      }
      if (typeof input === "string") {
        return BYTE_LENGTH_SOURCE.STRING_LENGTH;
      }
      if (typeof input.byteLength === "number") {
        return BYTE_LENGTH_SOURCE.TYPED_ARRAY;
      } else if (typeof input.length === "number") {
        return BYTE_LENGTH_SOURCE.LENGTH;
      } else if (typeof input.size === "number") {
        return BYTE_LENGTH_SOURCE.SIZE;
      } else if (typeof input.start === "number" && typeof input.end === "number") {
        return BYTE_LENGTH_SOURCE.START_END_DIFF;
      } else if (runtimeConfig.runtimeConfig.isFileReadStream(input)) {
        try {
          runtimeConfig.runtimeConfig.lstatSync(input.path).size;
          return BYTE_LENGTH_SOURCE.LSTAT;
        } catch (error4) {
          return void 0;
        }
      }
      return void 0;
    }, "byteLengthSource");
    async function* getChunkStream(data3, partSize, getNextData) {
      let partNumber = 1;
      const currentBuffer = { chunks: [], length: 0 };
      for await (const datum of getNextData(data3)) {
        currentBuffer.chunks.push(datum);
        currentBuffer.length += datum.byteLength;
        while (currentBuffer.length > partSize) {
          const dataChunk = currentBuffer.chunks.length > 1 ? buffer.Buffer.concat(currentBuffer.chunks) : currentBuffer.chunks[0];
          yield {
            partNumber,
            data: dataChunk.subarray(0, partSize)
          };
          currentBuffer.chunks = [dataChunk.subarray(partSize)];
          currentBuffer.length = currentBuffer.chunks[0].byteLength;
          partNumber += 1;
        }
      }
      yield {
        partNumber,
        data: currentBuffer.chunks.length !== 1 ? buffer.Buffer.concat(currentBuffer.chunks) : currentBuffer.chunks[0],
        lastPart: true
      };
    }
    __name(getChunkStream, "getChunkStream");
    async function* getChunkUint8Array(data3, partSize) {
      let partNumber = 1;
      let startByte = 0;
      let endByte = partSize;
      while (endByte < data3.byteLength) {
        yield {
          partNumber,
          data: data3.subarray(startByte, endByte)
        };
        partNumber += 1;
        startByte = endByte;
        endByte = startByte + partSize;
      }
      yield {
        partNumber,
        data: data3.subarray(startByte),
        lastPart: true
      };
    }
    __name(getChunkUint8Array, "getChunkUint8Array");
    async function* getDataReadable(data3) {
      for await (const chunk of data3) {
        if (buffer.Buffer.isBuffer(chunk) || chunk instanceof Uint8Array) {
          yield chunk;
        } else {
          yield buffer.Buffer.from(chunk);
        }
      }
    }
    __name(getDataReadable, "getDataReadable");
    async function* getDataReadableStream(data3) {
      const reader = data3.getReader();
      try {
        while (true) {
          const { done, value } = await reader.read();
          if (done) {
            return;
          }
          if (buffer.Buffer.isBuffer(value) || value instanceof Uint8Array) {
            yield value;
          } else {
            yield buffer.Buffer.from(value);
          }
        }
      } catch (e32) {
        throw e32;
      } finally {
        reader.releaseLock();
      }
    }
    __name(getDataReadableStream, "getDataReadableStream");
    var getChunk = /* @__PURE__ */ __name((data3, partSize) => {
      if (data3 instanceof Uint8Array) {
        return getChunkUint8Array(data3, partSize);
      }
      if (data3 instanceof stream.Readable) {
        return getChunkStream(data3, partSize, getDataReadable);
      }
      if (data3 instanceof String || typeof data3 === "string") {
        return getChunkUint8Array(buffer.Buffer.from(data3), partSize);
      }
      if (typeof data3.stream === "function") {
        return getChunkStream(data3.stream(), partSize, getDataReadableStream);
      }
      if (data3 instanceof ReadableStream) {
        return getChunkStream(data3, partSize, getDataReadableStream);
      }
      throw new Error("Body Data is unsupported format, expected data to be one of: string | Uint8Array | Buffer | Readable | ReadableStream | Blob;.");
    }, "getChunk");
    var Upload3 = class _Upload extends events.EventEmitter {
      static {
        __name(this, "Upload");
      }
      static MIN_PART_SIZE = 1024 * 1024 * 5;
      MAX_PARTS = 1e4;
      queueSize = 4;
      partSize;
      leavePartsOnError = false;
      tags = [];
      client;
      params;
      totalBytes;
      totalBytesSource;
      bytesUploadedSoFar;
      abortController;
      concurrentUploaders = [];
      createMultiPartPromise;
      abortMultipartUploadCommand = null;
      uploadedParts = [];
      uploadEnqueuedPartsCount = 0;
      expectedPartsCount;
      uploadId;
      uploadEvent;
      isMultiPart = true;
      singleUploadResult;
      sent = false;
      constructor(options) {
        super();
        this.queueSize = options.queueSize || this.queueSize;
        this.leavePartsOnError = options.leavePartsOnError || this.leavePartsOnError;
        this.tags = options.tags || this.tags;
        this.client = options.client;
        this.params = options.params;
        if (!this.params) {
          throw new Error(`InputError: Upload requires params to be passed to upload.`);
        }
        this.totalBytes = this.params.ContentLength ?? byteLength(this.params.Body);
        this.totalBytesSource = byteLengthSource(this.params.Body, this.params.ContentLength);
        this.bytesUploadedSoFar = 0;
        this.abortController = options.abortController ?? new AbortController();
        this.partSize = options.partSize || Math.max(_Upload.MIN_PART_SIZE, Math.ceil((this.totalBytes || 0) / this.MAX_PARTS));
        if (this.totalBytes !== void 0) {
          this.expectedPartsCount = Math.ceil(this.totalBytes / this.partSize);
        }
        this.__validateInput();
      }
      async abort() {
        this.abortController.abort();
      }
      async done() {
        if (this.sent) {
          throw new Error("@aws-sdk/lib-storage: this instance of Upload has already executed .done(). Create a new instance.");
        }
        this.sent = true;
        return await Promise.race([this.__doMultipartUpload(), this.__abortTimeout(this.abortController.signal)]);
      }
      on(event, listener) {
        this.uploadEvent = event;
        return super.on(event, listener);
      }
      async __uploadUsingPut(dataPart) {
        this.isMultiPart = false;
        const params = { ...this.params, Body: dataPart.data };
        const clientConfig = this.client.config;
        const requestHandler = clientConfig.requestHandler;
        const eventEmitter = requestHandler instanceof events.EventEmitter ? requestHandler : null;
        const uploadEventListener = /* @__PURE__ */ __name((event) => {
          this.bytesUploadedSoFar = event.loaded;
          this.totalBytes = event.total;
          this.__notifyProgress({
            loaded: this.bytesUploadedSoFar,
            total: this.totalBytes,
            part: dataPart.partNumber,
            Key: this.params.Key,
            Bucket: this.params.Bucket
          });
        }, "uploadEventListener");
        if (eventEmitter !== null) {
          eventEmitter.on("xhr.upload.progress", uploadEventListener);
        }
        const resolved = await Promise.all([this.client.send(new clientS3.PutObjectCommand(params)), clientConfig?.endpoint?.()]);
        const putResult = resolved[0];
        let endpoint = resolved[1];
        if (!endpoint) {
          endpoint = endpoints.toEndpointV1(await endpoints.getEndpointFromInstructions(params, clientS3.PutObjectCommand, {
            ...clientConfig
          }));
        }
        if (!endpoint) {
          throw new Error('Could not resolve endpoint from S3 "client.config.endpoint()" nor EndpointsV2.');
        }
        if (eventEmitter !== null) {
          eventEmitter.off("xhr.upload.progress", uploadEventListener);
        }
        const locationKey = this.params.Key.split("/").map((segment) => protocols.extendedEncodeURIComponent(segment)).join("/");
        const locationBucket = protocols.extendedEncodeURIComponent(this.params.Bucket);
        const Location = (() => {
          const endpointHostnameIncludesBucket = endpoint.hostname.startsWith(`${locationBucket}.`);
          const forcePathStyle = this.client.config.forcePathStyle;
          const optionalPort = endpoint.port ? `:${endpoint.port}` : ``;
          if (forcePathStyle) {
            return `${endpoint.protocol}//${endpoint.hostname}${optionalPort}/${locationBucket}/${locationKey}`;
          }
          if (endpointHostnameIncludesBucket) {
            return `${endpoint.protocol}//${endpoint.hostname}${optionalPort}/${locationKey}`;
          }
          return `${endpoint.protocol}//${locationBucket}.${endpoint.hostname}${optionalPort}/${locationKey}`;
        })();
        this.singleUploadResult = {
          ...putResult,
          Bucket: this.params.Bucket,
          Key: this.params.Key,
          Location
        };
        const totalSize = byteLength(dataPart.data);
        this.__notifyProgress({
          loaded: totalSize,
          total: totalSize,
          part: 1,
          Key: this.params.Key,
          Bucket: this.params.Bucket
        });
      }
      async __createMultipartUpload() {
        const requestChecksumCalculation = await this.client.config.requestChecksumCalculation();
        if (!this.createMultiPartPromise) {
          const createCommandParams = { ...this.params, Body: void 0 };
          if (requestChecksumCalculation === "WHEN_SUPPORTED") {
            createCommandParams.ChecksumAlgorithm = this.params.ChecksumAlgorithm || clientS3.ChecksumAlgorithm.CRC32;
          }
          this.createMultiPartPromise = this.client.send(new clientS3.CreateMultipartUploadCommand(createCommandParams)).then((createMpuResponse) => {
            this.abortMultipartUploadCommand = new clientS3.AbortMultipartUploadCommand({
              Bucket: this.params.Bucket,
              Key: this.params.Key,
              UploadId: createMpuResponse.UploadId
            });
            return createMpuResponse;
          });
        }
        return this.createMultiPartPromise;
      }
      async __doConcurrentUpload(dataFeeder) {
        for await (const dataPart of dataFeeder) {
          if (this.uploadEnqueuedPartsCount > this.MAX_PARTS) {
            throw new Error(`Exceeded ${this.MAX_PARTS} parts in multipart upload to Bucket: ${this.params.Bucket} Key: ${this.params.Key}.`);
          }
          if (this.abortController.signal.aborted) {
            return;
          }
          if (dataPart.partNumber === 1 && dataPart.lastPart) {
            return await this.__uploadUsingPut(dataPart);
          }
          if (!this.uploadId) {
            const { UploadId } = await this.__createMultipartUpload();
            this.uploadId = UploadId;
            if (this.abortController.signal.aborted) {
              return;
            }
          }
          const partSize = byteLength(dataPart.data) || 0;
          const requestHandler = this.client.config.requestHandler;
          const eventEmitter = requestHandler instanceof events.EventEmitter ? requestHandler : null;
          let lastSeenBytes = 0;
          const uploadEventListener = /* @__PURE__ */ __name((event, request4) => {
            const requestPartSize = Number(request4.query["partNumber"]) || -1;
            if (requestPartSize !== dataPart.partNumber) {
              return;
            }
            if (event.total && partSize) {
              this.bytesUploadedSoFar += event.loaded - lastSeenBytes;
              lastSeenBytes = event.loaded;
            }
            this.__notifyProgress({
              loaded: this.bytesUploadedSoFar,
              total: this.totalBytes,
              part: dataPart.partNumber,
              Key: this.params.Key,
              Bucket: this.params.Bucket
            });
          }, "uploadEventListener");
          if (eventEmitter !== null) {
            eventEmitter.on("xhr.upload.progress", uploadEventListener);
          }
          this.uploadEnqueuedPartsCount += 1;
          this.__validateUploadPart(dataPart);
          const partResult = await this.client.send(new clientS3.UploadPartCommand({
            ...this.params,
            ContentLength: void 0,
            UploadId: this.uploadId,
            Body: dataPart.data,
            PartNumber: dataPart.partNumber
          }));
          if (eventEmitter !== null) {
            eventEmitter.off("xhr.upload.progress", uploadEventListener);
          }
          if (this.abortController.signal.aborted) {
            return;
          }
          if (!partResult.ETag) {
            throw new Error(`Part ${dataPart.partNumber} is missing ETag in UploadPart response. Missing Bucket CORS configuration for ETag header?`);
          }
          this.uploadedParts.push({
            PartNumber: dataPart.partNumber,
            ETag: partResult.ETag,
            ...partResult.ChecksumCRC32 && { ChecksumCRC32: partResult.ChecksumCRC32 },
            ...partResult.ChecksumCRC32C && { ChecksumCRC32C: partResult.ChecksumCRC32C },
            ...partResult.ChecksumSHA1 && { ChecksumSHA1: partResult.ChecksumSHA1 },
            ...partResult.ChecksumSHA256 && { ChecksumSHA256: partResult.ChecksumSHA256 }
          });
          if (eventEmitter === null) {
            this.bytesUploadedSoFar += partSize;
          }
          this.__notifyProgress({
            loaded: this.bytesUploadedSoFar,
            total: this.totalBytes,
            part: dataPart.partNumber,
            Key: this.params.Key,
            Bucket: this.params.Bucket
          });
        }
      }
      async __doMultipartUpload() {
        const dataFeeder = getChunk(this.params.Body, this.partSize);
        const concurrentUploaderFailures = [];
        for (let index = 0; index < this.queueSize; index++) {
          const currentUpload = this.__doConcurrentUpload(dataFeeder).catch((err) => {
            concurrentUploaderFailures.push(err);
          });
          this.concurrentUploaders.push(currentUpload);
        }
        await Promise.all(this.concurrentUploaders);
        if (concurrentUploaderFailures.length >= 1) {
          await this.markUploadAsAborted();
          throw concurrentUploaderFailures[0];
        }
        if (this.abortController.signal.aborted) {
          await this.markUploadAsAborted();
          throw Object.assign(new Error("Upload aborted."), { name: "AbortError" });
        }
        let result2;
        if (this.isMultiPart) {
          const { expectedPartsCount, uploadedParts, totalBytes, totalBytesSource } = this;
          if (totalBytes !== void 0 && expectedPartsCount !== void 0 && uploadedParts.length !== expectedPartsCount) {
            throw new Error(`Expected ${expectedPartsCount} part(s) but uploaded ${uploadedParts.length} part(s).
The expected part count is based on the byte-count of the input.params.Body,
which was read from ${totalBytesSource} and is ${totalBytes}.
If this is not correct, provide an override value by setting a number
to input.params.ContentLength in bytes.
`);
          }
          this.uploadedParts.sort((a32, b32) => a32.PartNumber - b32.PartNumber);
          const uploadCompleteParams = {
            ...this.params,
            Body: void 0,
            UploadId: this.uploadId,
            MultipartUpload: {
              Parts: this.uploadedParts
            }
          };
          result2 = await this.client.send(new clientS3.CompleteMultipartUploadCommand(uploadCompleteParams));
          if (typeof result2?.Location === "string" && result2.Location.includes("%2F")) {
            result2.Location = result2.Location.replace(/%2F/g, "/");
          }
        } else {
          result2 = this.singleUploadResult;
        }
        this.abortMultipartUploadCommand = null;
        if (this.tags.length) {
          await this.client.send(new clientS3.PutObjectTaggingCommand({
            ...this.params,
            Tagging: {
              TagSet: this.tags
            }
          }));
        }
        return result2;
      }
      async markUploadAsAborted() {
        if (this.uploadId && !this.leavePartsOnError && null !== this.abortMultipartUploadCommand) {
          await this.client.send(this.abortMultipartUploadCommand);
          this.abortMultipartUploadCommand = null;
        }
      }
      __notifyProgress(progress) {
        if (this.uploadEvent) {
          this.emit(this.uploadEvent, progress);
        }
      }
      async __abortTimeout(abortSignal) {
        return new Promise((resolve13, reject) => {
          abortSignal.onabort = () => {
            const abortError = new Error("Upload aborted.");
            abortError.name = "AbortError";
            reject(abortError);
          };
        });
      }
      __validateUploadPart(dataPart) {
        const actualPartSize = byteLength(dataPart.data);
        if (actualPartSize === void 0) {
          throw new Error(`A dataPart was generated without a measurable data chunk size for part number ${dataPart.partNumber}`);
        }
        if (dataPart.partNumber === 1 && dataPart.lastPart) {
          return;
        }
        if (!dataPart.lastPart && actualPartSize !== this.partSize) {
          throw new Error(`The byte size for part number ${dataPart.partNumber}, size ${actualPartSize} does not match expected size ${this.partSize}`);
        }
      }
      __validateInput() {
        if (!this.client) {
          throw new Error(`InputError: Upload requires a AWS client to do uploads with.`);
        }
        if (this.partSize < _Upload.MIN_PART_SIZE) {
          throw new Error(`EntityTooSmall: Your proposed upload part size [${this.partSize}] is smaller than the minimum allowed size [${_Upload.MIN_PART_SIZE}] (5MB)`);
        }
        if (this.queueSize < 1) {
          throw new Error(`Queue size: Must have at least one uploading queue.`);
        }
      }
    };
    exports2.Upload = Upload3;
  }
});

// ../@aws-cdk/cdk-assets-lib/lib/aws.ts
var aws_exports = {};
__export(aws_exports, {
  DefaultAwsClient: () => DefaultAwsClient
});
function safeUsername() {
  try {
    return os4.userInfo().username.replace(/[^\w+=,.@-]/g, "@");
  } catch {
    return "noname";
  }
}
var os4, import_client_ecr, import_client_s3, import_client_secrets_manager, import_client_sts, import_credential_providers, import_lib_storage, import_config_resolver31, import_node_config_provider16, USER_AGENT, DefaultAwsClient;
var init_aws = __esm({
  "../@aws-cdk/cdk-assets-lib/lib/aws.ts"() {
    "use strict";
    os4 = __toESM(require("os"));
    import_client_ecr = __toESM(require_dist_cjs61());
    import_client_s3 = __toESM(require_dist_cjs90());
    import_client_secrets_manager = __toESM(require_dist_cjs103());
    import_client_sts = __toESM(require_dist_cjs123());
    import_credential_providers = __toESM(require_dist_cjs125());
    import_lib_storage = __toESM(require_dist_cjs126());
    import_config_resolver31 = __toESM(require_dist_cjs25());
    import_node_config_provider16 = __toESM(require_dist_cjs29());
    USER_AGENT = "cdk-assets";
    DefaultAwsClient = class {
      constructor(profile) {
        this.profile = profile;
        const clientConfig = {
          customUserAgent: USER_AGENT
        };
        this.mainCredentials = (0, import_credential_providers.fromNodeProviderChain)({
          profile: this.profile,
          clientConfig
        });
        this.config = {
          clientConfig,
          credentials: this.mainCredentials
        };
      }
      static {
        __name(this, "DefaultAwsClient");
      }
      async s3Client(options) {
        const client = new import_client_s3.S3Client(await this.awsOptions(options));
        return {
          getBucketEncryption: /* @__PURE__ */ __name((input) => client.send(new import_client_s3.GetBucketEncryptionCommand(input)), "getBucketEncryption"),
          getBucketLocation: /* @__PURE__ */ __name((input) => client.send(new import_client_s3.GetBucketLocationCommand(input)), "getBucketLocation"),
          listObjectsV2: /* @__PURE__ */ __name((input) => client.send(new import_client_s3.ListObjectsV2Command(input)), "listObjectsV2"),
          upload: /* @__PURE__ */ __name((input) => {
            const upload = new import_lib_storage.Upload({
              client,
              params: input
            });
            return upload.done();
          }, "upload")
        };
      }
      async ecrClient(options) {
        const client = new import_client_ecr.ECRClient(await this.awsOptions(options));
        return {
          describeImages: /* @__PURE__ */ __name((input) => client.send(new import_client_ecr.DescribeImagesCommand(input)), "describeImages"),
          describeRepositories: /* @__PURE__ */ __name((input) => client.send(new import_client_ecr.DescribeRepositoriesCommand(input)), "describeRepositories"),
          getAuthorizationToken: /* @__PURE__ */ __name((input) => client.send(new import_client_ecr.GetAuthorizationTokenCommand(input ?? {})), "getAuthorizationToken")
        };
      }
      async secretsManagerClient(options) {
        const client = new import_client_secrets_manager.SecretsManagerClient(await this.awsOptions(options));
        return {
          getSecretValue: /* @__PURE__ */ __name((input) => client.send(new import_client_secrets_manager.GetSecretValueCommand(input)), "getSecretValue")
        };
      }
      async discoverPartition() {
        return (await this.discoverCurrentAccount()).partition;
      }
      async discoverDefaultRegion() {
        return (0, import_node_config_provider16.loadConfig)(import_config_resolver31.NODE_REGION_CONFIG_OPTIONS, import_config_resolver31.NODE_REGION_CONFIG_FILE_OPTIONS)() || "us-east-1";
      }
      async discoverCurrentAccount() {
        if (this.account === void 0) {
          this.account = await this.getAccount();
        }
        return this.account;
      }
      async discoverTargetAccount(options) {
        return this.getAccount(await this.awsOptions(options));
      }
      async getAccount(options) {
        this.config.clientConfig = options ?? this.config.clientConfig;
        const stsClient = new import_client_sts.STSClient(await this.awsOptions(options));
        const command = new import_client_sts.GetCallerIdentityCommand();
        const response = await stsClient.send(command);
        if (!response.Account || !response.Arn) {
          throw new Error(`Unrecognized response from STS: '${JSON.stringify(response)}'`);
        }
        return {
          accountId: response.Account,
          partition: response.Arn.split(":")[1]
        };
      }
      async awsOptions(options) {
        const config2 = this.config;
        config2.region = options?.region;
        if (options) {
          config2.region = options.region;
          if (options.assumeRoleArn) {
            config2.credentials = (0, import_credential_providers.fromTemporaryCredentials)({
              // dont forget the credentials chain.
              masterCredentials: this.mainCredentials,
              params: {
                RoleArn: options.assumeRoleArn,
                ExternalId: options.assumeRoleExternalId,
                RoleSessionName: `${USER_AGENT}-${safeUsername()}`,
                TransitiveTagKeys: options.assumeRoleAdditionalOptions?.Tags ? options.assumeRoleAdditionalOptions.Tags.map((t) => t.Key) : void 0,
                ...options.assumeRoleAdditionalOptions
              },
              clientConfig: this.config.clientConfig
            });
          }
        }
        return config2;
      }
    };
    __name(safeUsername, "safeUsername");
  }
});

// ../@aws-cdk/cdk-assets-lib/lib/index.js
var require_lib5 = __commonJS({
  "../@aws-cdk/cdk-assets-lib/lib/index.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __exportStar3 = exports2 && exports2.__exportStar || function(m20, exports3) {
      for (var p10 in m20) if (p10 !== "default" && !Object.prototype.hasOwnProperty.call(exports3, p10)) __createBinding3(exports3, m20, p10);
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    __exportStar3((init_publishing(), __toCommonJS(publishing_exports)), exports2);
    __exportStar3((init_asset_manifest(), __toCommonJS(asset_manifest_exports)), exports2);
    __exportStar3((init_aws(), __toCommonJS(aws_exports)), exports2);
    __exportStar3((init_progress(), __toCommonJS(progress_exports)), exports2);
  }
});

// ../../node_modules/color-name/index.js
var require_color_name = __commonJS({
  "../../node_modules/color-name/index.js"(exports2, module2) {
    "use strict";
    module2.exports = {
      "aliceblue": [240, 248, 255],
      "antiquewhite": [250, 235, 215],
      "aqua": [0, 255, 255],
      "aquamarine": [127, 255, 212],
      "azure": [240, 255, 255],
      "beige": [245, 245, 220],
      "bisque": [255, 228, 196],
      "black": [0, 0, 0],
      "blanchedalmond": [255, 235, 205],
      "blue": [0, 0, 255],
      "blueviolet": [138, 43, 226],
      "brown": [165, 42, 42],
      "burlywood": [222, 184, 135],
      "cadetblue": [95, 158, 160],
      "chartreuse": [127, 255, 0],
      "chocolate": [210, 105, 30],
      "coral": [255, 127, 80],
      "cornflowerblue": [100, 149, 237],
      "cornsilk": [255, 248, 220],
      "crimson": [220, 20, 60],
      "cyan": [0, 255, 255],
      "darkblue": [0, 0, 139],
      "darkcyan": [0, 139, 139],
      "darkgoldenrod": [184, 134, 11],
      "darkgray": [169, 169, 169],
      "darkgreen": [0, 100, 0],
      "darkgrey": [169, 169, 169],
      "darkkhaki": [189, 183, 107],
      "darkmagenta": [139, 0, 139],
      "darkolivegreen": [85, 107, 47],
      "darkorange": [255, 140, 0],
      "darkorchid": [153, 50, 204],
      "darkred": [139, 0, 0],
      "darksalmon": [233, 150, 122],
      "darkseagreen": [143, 188, 143],
      "darkslateblue": [72, 61, 139],
      "darkslategray": [47, 79, 79],
      "darkslategrey": [47, 79, 79],
      "darkturquoise": [0, 206, 209],
      "darkviolet": [148, 0, 211],
      "deeppink": [255, 20, 147],
      "deepskyblue": [0, 191, 255],
      "dimgray": [105, 105, 105],
      "dimgrey": [105, 105, 105],
      "dodgerblue": [30, 144, 255],
      "firebrick": [178, 34, 34],
      "floralwhite": [255, 250, 240],
      "forestgreen": [34, 139, 34],
      "fuchsia": [255, 0, 255],
      "gainsboro": [220, 220, 220],
      "ghostwhite": [248, 248, 255],
      "gold": [255, 215, 0],
      "goldenrod": [218, 165, 32],
      "gray": [128, 128, 128],
      "green": [0, 128, 0],
      "greenyellow": [173, 255, 47],
      "grey": [128, 128, 128],
      "honeydew": [240, 255, 240],
      "hotpink": [255, 105, 180],
      "indianred": [205, 92, 92],
      "indigo": [75, 0, 130],
      "ivory": [255, 255, 240],
      "khaki": [240, 230, 140],
      "lavender": [230, 230, 250],
      "lavenderblush": [255, 240, 245],
      "lawngreen": [124, 252, 0],
      "lemonchiffon": [255, 250, 205],
      "lightblue": [173, 216, 230],
      "lightcoral": [240, 128, 128],
      "lightcyan": [224, 255, 255],
      "lightgoldenrodyellow": [250, 250, 210],
      "lightgray": [211, 211, 211],
      "lightgreen": [144, 238, 144],
      "lightgrey": [211, 211, 211],
      "lightpink": [255, 182, 193],
      "lightsalmon": [255, 160, 122],
      "lightseagreen": [32, 178, 170],
      "lightskyblue": [135, 206, 250],
      "lightslategray": [119, 136, 153],
      "lightslategrey": [119, 136, 153],
      "lightsteelblue": [176, 196, 222],
      "lightyellow": [255, 255, 224],
      "lime": [0, 255, 0],
      "limegreen": [50, 205, 50],
      "linen": [250, 240, 230],
      "magenta": [255, 0, 255],
      "maroon": [128, 0, 0],
      "mediumaquamarine": [102, 205, 170],
      "mediumblue": [0, 0, 205],
      "mediumorchid": [186, 85, 211],
      "mediumpurple": [147, 112, 219],
      "mediumseagreen": [60, 179, 113],
      "mediumslateblue": [123, 104, 238],
      "mediumspringgreen": [0, 250, 154],
      "mediumturquoise": [72, 209, 204],
      "mediumvioletred": [199, 21, 133],
      "midnightblue": [25, 25, 112],
      "mintcream": [245, 255, 250],
      "mistyrose": [255, 228, 225],
      "moccasin": [255, 228, 181],
      "navajowhite": [255, 222, 173],
      "navy": [0, 0, 128],
      "oldlace": [253, 245, 230],
      "olive": [128, 128, 0],
      "olivedrab": [107, 142, 35],
      "orange": [255, 165, 0],
      "orangered": [255, 69, 0],
      "orchid": [218, 112, 214],
      "palegoldenrod": [238, 232, 170],
      "palegreen": [152, 251, 152],
      "paleturquoise": [175, 238, 238],
      "palevioletred": [219, 112, 147],
      "papayawhip": [255, 239, 213],
      "peachpuff": [255, 218, 185],
      "peru": [205, 133, 63],
      "pink": [255, 192, 203],
      "plum": [221, 160, 221],
      "powderblue": [176, 224, 230],
      "purple": [128, 0, 128],
      "rebeccapurple": [102, 51, 153],
      "red": [255, 0, 0],
      "rosybrown": [188, 143, 143],
      "royalblue": [65, 105, 225],
      "saddlebrown": [139, 69, 19],
      "salmon": [250, 128, 114],
      "sandybrown": [244, 164, 96],
      "seagreen": [46, 139, 87],
      "seashell": [255, 245, 238],
      "sienna": [160, 82, 45],
      "silver": [192, 192, 192],
      "skyblue": [135, 206, 235],
      "slateblue": [106, 90, 205],
      "slategray": [112, 128, 144],
      "slategrey": [112, 128, 144],
      "snow": [255, 250, 250],
      "springgreen": [0, 255, 127],
      "steelblue": [70, 130, 180],
      "tan": [210, 180, 140],
      "teal": [0, 128, 128],
      "thistle": [216, 191, 216],
      "tomato": [255, 99, 71],
      "turquoise": [64, 224, 208],
      "violet": [238, 130, 238],
      "wheat": [245, 222, 179],
      "white": [255, 255, 255],
      "whitesmoke": [245, 245, 245],
      "yellow": [255, 255, 0],
      "yellowgreen": [154, 205, 50]
    };
  }
});

// ../../node_modules/color-convert/conversions.js
var require_conversions = __commonJS({
  "../../node_modules/color-convert/conversions.js"(exports2, module2) {
    var cssKeywords = require_color_name();
    var reverseKeywords = {};
    for (const key of Object.keys(cssKeywords)) {
      reverseKeywords[cssKeywords[key]] = key;
    }
    var convert = {
      rgb: { channels: 3, labels: "rgb" },
      hsl: { channels: 3, labels: "hsl" },
      hsv: { channels: 3, labels: "hsv" },
      hwb: { channels: 3, labels: "hwb" },
      cmyk: { channels: 4, labels: "cmyk" },
      xyz: { channels: 3, labels: "xyz" },
      lab: { channels: 3, labels: "lab" },
      lch: { channels: 3, labels: "lch" },
      hex: { channels: 1, labels: ["hex"] },
      keyword: { channels: 1, labels: ["keyword"] },
      ansi16: { channels: 1, labels: ["ansi16"] },
      ansi256: { channels: 1, labels: ["ansi256"] },
      hcg: { channels: 3, labels: ["h", "c", "g"] },
      apple: { channels: 3, labels: ["r16", "g16", "b16"] },
      gray: { channels: 1, labels: ["gray"] }
    };
    module2.exports = convert;
    for (const model of Object.keys(convert)) {
      if (!("channels" in convert[model])) {
        throw new Error("missing channels property: " + model);
      }
      if (!("labels" in convert[model])) {
        throw new Error("missing channel labels property: " + model);
      }
      if (convert[model].labels.length !== convert[model].channels) {
        throw new Error("channel and label counts mismatch: " + model);
      }
      const { channels, labels } = convert[model];
      delete convert[model].channels;
      delete convert[model].labels;
      Object.defineProperty(convert[model], "channels", { value: channels });
      Object.defineProperty(convert[model], "labels", { value: labels });
    }
    convert.rgb.hsl = function(rgb) {
      const r32 = rgb[0] / 255;
      const g32 = rgb[1] / 255;
      const b32 = rgb[2] / 255;
      const min = Math.min(r32, g32, b32);
      const max = Math.max(r32, g32, b32);
      const delta = max - min;
      let h32;
      let s;
      if (max === min) {
        h32 = 0;
      } else if (r32 === max) {
        h32 = (g32 - b32) / delta;
      } else if (g32 === max) {
        h32 = 2 + (b32 - r32) / delta;
      } else if (b32 === max) {
        h32 = 4 + (r32 - g32) / delta;
      }
      h32 = Math.min(h32 * 60, 360);
      if (h32 < 0) {
        h32 += 360;
      }
      const l20 = (min + max) / 2;
      if (max === min) {
        s = 0;
      } else if (l20 <= 0.5) {
        s = delta / (max + min);
      } else {
        s = delta / (2 - max - min);
      }
      return [h32, s * 100, l20 * 100];
    };
    convert.rgb.hsv = function(rgb) {
      let rdif;
      let gdif;
      let bdif;
      let h32;
      let s;
      const r32 = rgb[0] / 255;
      const g32 = rgb[1] / 255;
      const b32 = rgb[2] / 255;
      const v = Math.max(r32, g32, b32);
      const diff = v - Math.min(r32, g32, b32);
      const diffc = /* @__PURE__ */ __name(function(c32) {
        return (v - c32) / 6 / diff + 1 / 2;
      }, "diffc");
      if (diff === 0) {
        h32 = 0;
        s = 0;
      } else {
        s = diff / v;
        rdif = diffc(r32);
        gdif = diffc(g32);
        bdif = diffc(b32);
        if (r32 === v) {
          h32 = bdif - gdif;
        } else if (g32 === v) {
          h32 = 1 / 3 + rdif - bdif;
        } else if (b32 === v) {
          h32 = 2 / 3 + gdif - rdif;
        }
        if (h32 < 0) {
          h32 += 1;
        } else if (h32 > 1) {
          h32 -= 1;
        }
      }
      return [
        h32 * 360,
        s * 100,
        v * 100
      ];
    };
    convert.rgb.hwb = function(rgb) {
      const r32 = rgb[0];
      const g32 = rgb[1];
      let b32 = rgb[2];
      const h32 = convert.rgb.hsl(rgb)[0];
      const w = 1 / 255 * Math.min(r32, Math.min(g32, b32));
      b32 = 1 - 1 / 255 * Math.max(r32, Math.max(g32, b32));
      return [h32, w * 100, b32 * 100];
    };
    convert.rgb.cmyk = function(rgb) {
      const r32 = rgb[0] / 255;
      const g32 = rgb[1] / 255;
      const b32 = rgb[2] / 255;
      const k32 = Math.min(1 - r32, 1 - g32, 1 - b32);
      const c32 = (1 - r32 - k32) / (1 - k32) || 0;
      const m20 = (1 - g32 - k32) / (1 - k32) || 0;
      const y = (1 - b32 - k32) / (1 - k32) || 0;
      return [c32 * 100, m20 * 100, y * 100, k32 * 100];
    };
    function comparativeDistance(x, y) {
      return (x[0] - y[0]) ** 2 + (x[1] - y[1]) ** 2 + (x[2] - y[2]) ** 2;
    }
    __name(comparativeDistance, "comparativeDistance");
    convert.rgb.keyword = function(rgb) {
      const reversed = reverseKeywords[rgb];
      if (reversed) {
        return reversed;
      }
      let currentClosestDistance = Infinity;
      let currentClosestKeyword;
      for (const keyword of Object.keys(cssKeywords)) {
        const value = cssKeywords[keyword];
        const distance = comparativeDistance(rgb, value);
        if (distance < currentClosestDistance) {
          currentClosestDistance = distance;
          currentClosestKeyword = keyword;
        }
      }
      return currentClosestKeyword;
    };
    convert.keyword.rgb = function(keyword) {
      return cssKeywords[keyword];
    };
    convert.rgb.xyz = function(rgb) {
      let r32 = rgb[0] / 255;
      let g32 = rgb[1] / 255;
      let b32 = rgb[2] / 255;
      r32 = r32 > 0.04045 ? ((r32 + 0.055) / 1.055) ** 2.4 : r32 / 12.92;
      g32 = g32 > 0.04045 ? ((g32 + 0.055) / 1.055) ** 2.4 : g32 / 12.92;
      b32 = b32 > 0.04045 ? ((b32 + 0.055) / 1.055) ** 2.4 : b32 / 12.92;
      const x = r32 * 0.4124 + g32 * 0.3576 + b32 * 0.1805;
      const y = r32 * 0.2126 + g32 * 0.7152 + b32 * 0.0722;
      const z = r32 * 0.0193 + g32 * 0.1192 + b32 * 0.9505;
      return [x * 100, y * 100, z * 100];
    };
    convert.rgb.lab = function(rgb) {
      const xyz = convert.rgb.xyz(rgb);
      let x = xyz[0];
      let y = xyz[1];
      let z = xyz[2];
      x /= 95.047;
      y /= 100;
      z /= 108.883;
      x = x > 8856e-6 ? x ** (1 / 3) : 7.787 * x + 16 / 116;
      y = y > 8856e-6 ? y ** (1 / 3) : 7.787 * y + 16 / 116;
      z = z > 8856e-6 ? z ** (1 / 3) : 7.787 * z + 16 / 116;
      const l20 = 116 * y - 16;
      const a32 = 500 * (x - y);
      const b32 = 200 * (y - z);
      return [l20, a32, b32];
    };
    convert.hsl.rgb = function(hsl) {
      const h32 = hsl[0] / 360;
      const s = hsl[1] / 100;
      const l20 = hsl[2] / 100;
      let t2;
      let t3;
      let val;
      if (s === 0) {
        val = l20 * 255;
        return [val, val, val];
      }
      if (l20 < 0.5) {
        t2 = l20 * (1 + s);
      } else {
        t2 = l20 + s - l20 * s;
      }
      const t1 = 2 * l20 - t2;
      const rgb = [0, 0, 0];
      for (let i32 = 0; i32 < 3; i32++) {
        t3 = h32 + 1 / 3 * -(i32 - 1);
        if (t3 < 0) {
          t3++;
        }
        if (t3 > 1) {
          t3--;
        }
        if (6 * t3 < 1) {
          val = t1 + (t2 - t1) * 6 * t3;
        } else if (2 * t3 < 1) {
          val = t2;
        } else if (3 * t3 < 2) {
          val = t1 + (t2 - t1) * (2 / 3 - t3) * 6;
        } else {
          val = t1;
        }
        rgb[i32] = val * 255;
      }
      return rgb;
    };
    convert.hsl.hsv = function(hsl) {
      const h32 = hsl[0];
      let s = hsl[1] / 100;
      let l20 = hsl[2] / 100;
      let smin = s;
      const lmin = Math.max(l20, 0.01);
      l20 *= 2;
      s *= l20 <= 1 ? l20 : 2 - l20;
      smin *= lmin <= 1 ? lmin : 2 - lmin;
      const v = (l20 + s) / 2;
      const sv = l20 === 0 ? 2 * smin / (lmin + smin) : 2 * s / (l20 + s);
      return [h32, sv * 100, v * 100];
    };
    convert.hsv.rgb = function(hsv) {
      const h32 = hsv[0] / 60;
      const s = hsv[1] / 100;
      let v = hsv[2] / 100;
      const hi = Math.floor(h32) % 6;
      const f32 = h32 - Math.floor(h32);
      const p10 = 255 * v * (1 - s);
      const q10 = 255 * v * (1 - s * f32);
      const t = 255 * v * (1 - s * (1 - f32));
      v *= 255;
      switch (hi) {
        case 0:
          return [v, t, p10];
        case 1:
          return [q10, v, p10];
        case 2:
          return [p10, v, t];
        case 3:
          return [p10, q10, v];
        case 4:
          return [t, p10, v];
        case 5:
          return [v, p10, q10];
      }
    };
    convert.hsv.hsl = function(hsv) {
      const h32 = hsv[0];
      const s = hsv[1] / 100;
      const v = hsv[2] / 100;
      const vmin = Math.max(v, 0.01);
      let sl;
      let l20;
      l20 = (2 - s) * v;
      const lmin = (2 - s) * vmin;
      sl = s * vmin;
      sl /= lmin <= 1 ? lmin : 2 - lmin;
      sl = sl || 0;
      l20 /= 2;
      return [h32, sl * 100, l20 * 100];
    };
    convert.hwb.rgb = function(hwb) {
      const h32 = hwb[0] / 360;
      let wh = hwb[1] / 100;
      let bl = hwb[2] / 100;
      const ratio = wh + bl;
      let f32;
      if (ratio > 1) {
        wh /= ratio;
        bl /= ratio;
      }
      const i32 = Math.floor(6 * h32);
      const v = 1 - bl;
      f32 = 6 * h32 - i32;
      if ((i32 & 1) !== 0) {
        f32 = 1 - f32;
      }
      const n10 = wh + f32 * (v - wh);
      let r32;
      let g32;
      let b32;
      switch (i32) {
        default:
        case 6:
        case 0:
          r32 = v;
          g32 = n10;
          b32 = wh;
          break;
        case 1:
          r32 = n10;
          g32 = v;
          b32 = wh;
          break;
        case 2:
          r32 = wh;
          g32 = v;
          b32 = n10;
          break;
        case 3:
          r32 = wh;
          g32 = n10;
          b32 = v;
          break;
        case 4:
          r32 = n10;
          g32 = wh;
          b32 = v;
          break;
        case 5:
          r32 = v;
          g32 = wh;
          b32 = n10;
          break;
      }
      return [r32 * 255, g32 * 255, b32 * 255];
    };
    convert.cmyk.rgb = function(cmyk) {
      const c32 = cmyk[0] / 100;
      const m20 = cmyk[1] / 100;
      const y = cmyk[2] / 100;
      const k32 = cmyk[3] / 100;
      const r32 = 1 - Math.min(1, c32 * (1 - k32) + k32);
      const g32 = 1 - Math.min(1, m20 * (1 - k32) + k32);
      const b32 = 1 - Math.min(1, y * (1 - k32) + k32);
      return [r32 * 255, g32 * 255, b32 * 255];
    };
    convert.xyz.rgb = function(xyz) {
      const x = xyz[0] / 100;
      const y = xyz[1] / 100;
      const z = xyz[2] / 100;
      let r32;
      let g32;
      let b32;
      r32 = x * 3.2406 + y * -1.5372 + z * -0.4986;
      g32 = x * -0.9689 + y * 1.8758 + z * 0.0415;
      b32 = x * 0.0557 + y * -0.204 + z * 1.057;
      r32 = r32 > 31308e-7 ? 1.055 * r32 ** (1 / 2.4) - 0.055 : r32 * 12.92;
      g32 = g32 > 31308e-7 ? 1.055 * g32 ** (1 / 2.4) - 0.055 : g32 * 12.92;
      b32 = b32 > 31308e-7 ? 1.055 * b32 ** (1 / 2.4) - 0.055 : b32 * 12.92;
      r32 = Math.min(Math.max(0, r32), 1);
      g32 = Math.min(Math.max(0, g32), 1);
      b32 = Math.min(Math.max(0, b32), 1);
      return [r32 * 255, g32 * 255, b32 * 255];
    };
    convert.xyz.lab = function(xyz) {
      let x = xyz[0];
      let y = xyz[1];
      let z = xyz[2];
      x /= 95.047;
      y /= 100;
      z /= 108.883;
      x = x > 8856e-6 ? x ** (1 / 3) : 7.787 * x + 16 / 116;
      y = y > 8856e-6 ? y ** (1 / 3) : 7.787 * y + 16 / 116;
      z = z > 8856e-6 ? z ** (1 / 3) : 7.787 * z + 16 / 116;
      const l20 = 116 * y - 16;
      const a32 = 500 * (x - y);
      const b32 = 200 * (y - z);
      return [l20, a32, b32];
    };
    convert.lab.xyz = function(lab) {
      const l20 = lab[0];
      const a32 = lab[1];
      const b32 = lab[2];
      let x;
      let y;
      let z;
      y = (l20 + 16) / 116;
      x = a32 / 500 + y;
      z = y - b32 / 200;
      const y2 = y ** 3;
      const x2 = x ** 3;
      const z2 = z ** 3;
      y = y2 > 8856e-6 ? y2 : (y - 16 / 116) / 7.787;
      x = x2 > 8856e-6 ? x2 : (x - 16 / 116) / 7.787;
      z = z2 > 8856e-6 ? z2 : (z - 16 / 116) / 7.787;
      x *= 95.047;
      y *= 100;
      z *= 108.883;
      return [x, y, z];
    };
    convert.lab.lch = function(lab) {
      const l20 = lab[0];
      const a32 = lab[1];
      const b32 = lab[2];
      let h32;
      const hr = Math.atan2(b32, a32);
      h32 = hr * 360 / 2 / Math.PI;
      if (h32 < 0) {
        h32 += 360;
      }
      const c32 = Math.sqrt(a32 * a32 + b32 * b32);
      return [l20, c32, h32];
    };
    convert.lch.lab = function(lch) {
      const l20 = lch[0];
      const c32 = lch[1];
      const h32 = lch[2];
      const hr = h32 / 360 * 2 * Math.PI;
      const a32 = c32 * Math.cos(hr);
      const b32 = c32 * Math.sin(hr);
      return [l20, a32, b32];
    };
    convert.rgb.ansi16 = function(args, saturation = null) {
      const [r32, g32, b32] = args;
      let value = saturation === null ? convert.rgb.hsv(args)[2] : saturation;
      value = Math.round(value / 50);
      if (value === 0) {
        return 30;
      }
      let ansi = 30 + (Math.round(b32 / 255) << 2 | Math.round(g32 / 255) << 1 | Math.round(r32 / 255));
      if (value === 2) {
        ansi += 60;
      }
      return ansi;
    };
    convert.hsv.ansi16 = function(args) {
      return convert.rgb.ansi16(convert.hsv.rgb(args), args[2]);
    };
    convert.rgb.ansi256 = function(args) {
      const r32 = args[0];
      const g32 = args[1];
      const b32 = args[2];
      if (r32 === g32 && g32 === b32) {
        if (r32 < 8) {
          return 16;
        }
        if (r32 > 248) {
          return 231;
        }
        return Math.round((r32 - 8) / 247 * 24) + 232;
      }
      const ansi = 16 + 36 * Math.round(r32 / 255 * 5) + 6 * Math.round(g32 / 255 * 5) + Math.round(b32 / 255 * 5);
      return ansi;
    };
    convert.ansi16.rgb = function(args) {
      let color = args % 10;
      if (color === 0 || color === 7) {
        if (args > 50) {
          color += 3.5;
        }
        color = color / 10.5 * 255;
        return [color, color, color];
      }
      const mult = (~~(args > 50) + 1) * 0.5;
      const r32 = (color & 1) * mult * 255;
      const g32 = (color >> 1 & 1) * mult * 255;
      const b32 = (color >> 2 & 1) * mult * 255;
      return [r32, g32, b32];
    };
    convert.ansi256.rgb = function(args) {
      if (args >= 232) {
        const c32 = (args - 232) * 10 + 8;
        return [c32, c32, c32];
      }
      args -= 16;
      let rem;
      const r32 = Math.floor(args / 36) / 5 * 255;
      const g32 = Math.floor((rem = args % 36) / 6) / 5 * 255;
      const b32 = rem % 6 / 5 * 255;
      return [r32, g32, b32];
    };
    convert.rgb.hex = function(args) {
      const integer = ((Math.round(args[0]) & 255) << 16) + ((Math.round(args[1]) & 255) << 8) + (Math.round(args[2]) & 255);
      const string = integer.toString(16).toUpperCase();
      return "000000".substring(string.length) + string;
    };
    convert.hex.rgb = function(args) {
      const match = args.toString(16).match(/[a-f0-9]{6}|[a-f0-9]{3}/i);
      if (!match) {
        return [0, 0, 0];
      }
      let colorString = match[0];
      if (match[0].length === 3) {
        colorString = colorString.split("").map((char) => {
          return char + char;
        }).join("");
      }
      const integer = parseInt(colorString, 16);
      const r32 = integer >> 16 & 255;
      const g32 = integer >> 8 & 255;
      const b32 = integer & 255;
      return [r32, g32, b32];
    };
    convert.rgb.hcg = function(rgb) {
      const r32 = rgb[0] / 255;
      const g32 = rgb[1] / 255;
      const b32 = rgb[2] / 255;
      const max = Math.max(Math.max(r32, g32), b32);
      const min = Math.min(Math.min(r32, g32), b32);
      const chroma = max - min;
      let grayscale;
      let hue;
      if (chroma < 1) {
        grayscale = min / (1 - chroma);
      } else {
        grayscale = 0;
      }
      if (chroma <= 0) {
        hue = 0;
      } else if (max === r32) {
        hue = (g32 - b32) / chroma % 6;
      } else if (max === g32) {
        hue = 2 + (b32 - r32) / chroma;
      } else {
        hue = 4 + (r32 - g32) / chroma;
      }
      hue /= 6;
      hue %= 1;
      return [hue * 360, chroma * 100, grayscale * 100];
    };
    convert.hsl.hcg = function(hsl) {
      const s = hsl[1] / 100;
      const l20 = hsl[2] / 100;
      const c32 = l20 < 0.5 ? 2 * s * l20 : 2 * s * (1 - l20);
      let f32 = 0;
      if (c32 < 1) {
        f32 = (l20 - 0.5 * c32) / (1 - c32);
      }
      return [hsl[0], c32 * 100, f32 * 100];
    };
    convert.hsv.hcg = function(hsv) {
      const s = hsv[1] / 100;
      const v = hsv[2] / 100;
      const c32 = s * v;
      let f32 = 0;
      if (c32 < 1) {
        f32 = (v - c32) / (1 - c32);
      }
      return [hsv[0], c32 * 100, f32 * 100];
    };
    convert.hcg.rgb = function(hcg) {
      const h32 = hcg[0] / 360;
      const c32 = hcg[1] / 100;
      const g32 = hcg[2] / 100;
      if (c32 === 0) {
        return [g32 * 255, g32 * 255, g32 * 255];
      }
      const pure = [0, 0, 0];
      const hi = h32 % 1 * 6;
      const v = hi % 1;
      const w = 1 - v;
      let mg = 0;
      switch (Math.floor(hi)) {
        case 0:
          pure[0] = 1;
          pure[1] = v;
          pure[2] = 0;
          break;
        case 1:
          pure[0] = w;
          pure[1] = 1;
          pure[2] = 0;
          break;
        case 2:
          pure[0] = 0;
          pure[1] = 1;
          pure[2] = v;
          break;
        case 3:
          pure[0] = 0;
          pure[1] = w;
          pure[2] = 1;
          break;
        case 4:
          pure[0] = v;
          pure[1] = 0;
          pure[2] = 1;
          break;
        default:
          pure[0] = 1;
          pure[1] = 0;
          pure[2] = w;
      }
      mg = (1 - c32) * g32;
      return [
        (c32 * pure[0] + mg) * 255,
        (c32 * pure[1] + mg) * 255,
        (c32 * pure[2] + mg) * 255
      ];
    };
    convert.hcg.hsv = function(hcg) {
      const c32 = hcg[1] / 100;
      const g32 = hcg[2] / 100;
      const v = c32 + g32 * (1 - c32);
      let f32 = 0;
      if (v > 0) {
        f32 = c32 / v;
      }
      return [hcg[0], f32 * 100, v * 100];
    };
    convert.hcg.hsl = function(hcg) {
      const c32 = hcg[1] / 100;
      const g32 = hcg[2] / 100;
      const l20 = g32 * (1 - c32) + 0.5 * c32;
      let s = 0;
      if (l20 > 0 && l20 < 0.5) {
        s = c32 / (2 * l20);
      } else if (l20 >= 0.5 && l20 < 1) {
        s = c32 / (2 * (1 - l20));
      }
      return [hcg[0], s * 100, l20 * 100];
    };
    convert.hcg.hwb = function(hcg) {
      const c32 = hcg[1] / 100;
      const g32 = hcg[2] / 100;
      const v = c32 + g32 * (1 - c32);
      return [hcg[0], (v - c32) * 100, (1 - v) * 100];
    };
    convert.hwb.hcg = function(hwb) {
      const w = hwb[1] / 100;
      const b32 = hwb[2] / 100;
      const v = 1 - b32;
      const c32 = v - w;
      let g32 = 0;
      if (c32 < 1) {
        g32 = (v - c32) / (1 - c32);
      }
      return [hwb[0], c32 * 100, g32 * 100];
    };
    convert.apple.rgb = function(apple) {
      return [apple[0] / 65535 * 255, apple[1] / 65535 * 255, apple[2] / 65535 * 255];
    };
    convert.rgb.apple = function(rgb) {
      return [rgb[0] / 255 * 65535, rgb[1] / 255 * 65535, rgb[2] / 255 * 65535];
    };
    convert.gray.rgb = function(args) {
      return [args[0] / 100 * 255, args[0] / 100 * 255, args[0] / 100 * 255];
    };
    convert.gray.hsl = function(args) {
      return [0, 0, args[0]];
    };
    convert.gray.hsv = convert.gray.hsl;
    convert.gray.hwb = function(gray8) {
      return [0, 100, gray8[0]];
    };
    convert.gray.cmyk = function(gray8) {
      return [0, 0, 0, gray8[0]];
    };
    convert.gray.lab = function(gray8) {
      return [gray8[0], 0, 0];
    };
    convert.gray.hex = function(gray8) {
      const val = Math.round(gray8[0] / 100 * 255) & 255;
      const integer = (val << 16) + (val << 8) + val;
      const string = integer.toString(16).toUpperCase();
      return "000000".substring(string.length) + string;
    };
    convert.rgb.gray = function(rgb) {
      const val = (rgb[0] + rgb[1] + rgb[2]) / 3;
      return [val / 255 * 100];
    };
  }
});

// ../../node_modules/color-convert/route.js
var require_route = __commonJS({
  "../../node_modules/color-convert/route.js"(exports2, module2) {
    var conversions = require_conversions();
    function buildGraph() {
      const graph = {};
      const models = Object.keys(conversions);
      for (let len = models.length, i32 = 0; i32 < len; i32++) {
        graph[models[i32]] = {
          // http://jsperf.com/1-vs-infinity
          // micro-opt, but this is simple.
          distance: -1,
          parent: null
        };
      }
      return graph;
    }
    __name(buildGraph, "buildGraph");
    function deriveBFS(fromModel) {
      const graph = buildGraph();
      const queue = [fromModel];
      graph[fromModel].distance = 0;
      while (queue.length) {
        const current = queue.pop();
        const adjacents = Object.keys(conversions[current]);
        for (let len = adjacents.length, i32 = 0; i32 < len; i32++) {
          const adjacent = adjacents[i32];
          const node = graph[adjacent];
          if (node.distance === -1) {
            node.distance = graph[current].distance + 1;
            node.parent = current;
            queue.unshift(adjacent);
          }
        }
      }
      return graph;
    }
    __name(deriveBFS, "deriveBFS");
    function link(from, to) {
      return function(args) {
        return to(from(args));
      };
    }
    __name(link, "link");
    function wrapConversion(toModel, graph) {
      const path47 = [graph[toModel].parent, toModel];
      let fn = conversions[graph[toModel].parent][toModel];
      let cur = graph[toModel].parent;
      while (graph[cur].parent) {
        path47.unshift(graph[cur].parent);
        fn = link(conversions[graph[cur].parent][cur], fn);
        cur = graph[cur].parent;
      }
      fn.conversion = path47;
      return fn;
    }
    __name(wrapConversion, "wrapConversion");
    module2.exports = function(fromModel) {
      const graph = deriveBFS(fromModel);
      const conversion = {};
      const models = Object.keys(graph);
      for (let len = models.length, i32 = 0; i32 < len; i32++) {
        const toModel = models[i32];
        const node = graph[toModel];
        if (node.parent === null) {
          continue;
        }
        conversion[toModel] = wrapConversion(toModel, graph);
      }
      return conversion;
    };
  }
});

// ../../node_modules/color-convert/index.js
var require_color_convert = __commonJS({
  "../../node_modules/color-convert/index.js"(exports2, module2) {
    var conversions = require_conversions();
    var route = require_route();
    var convert = {};
    var models = Object.keys(conversions);
    function wrapRaw(fn) {
      const wrappedFn = /* @__PURE__ */ __name(function(...args) {
        const arg0 = args[0];
        if (arg0 === void 0 || arg0 === null) {
          return arg0;
        }
        if (arg0.length > 1) {
          args = arg0;
        }
        return fn(args);
      }, "wrappedFn");
      if ("conversion" in fn) {
        wrappedFn.conversion = fn.conversion;
      }
      return wrappedFn;
    }
    __name(wrapRaw, "wrapRaw");
    function wrapRounded(fn) {
      const wrappedFn = /* @__PURE__ */ __name(function(...args) {
        const arg0 = args[0];
        if (arg0 === void 0 || arg0 === null) {
          return arg0;
        }
        if (arg0.length > 1) {
          args = arg0;
        }
        const result2 = fn(args);
        if (typeof result2 === "object") {
          for (let len = result2.length, i32 = 0; i32 < len; i32++) {
            result2[i32] = Math.round(result2[i32]);
          }
        }
        return result2;
      }, "wrappedFn");
      if ("conversion" in fn) {
        wrappedFn.conversion = fn.conversion;
      }
      return wrappedFn;
    }
    __name(wrapRounded, "wrapRounded");
    models.forEach((fromModel) => {
      convert[fromModel] = {};
      Object.defineProperty(convert[fromModel], "channels", { value: conversions[fromModel].channels });
      Object.defineProperty(convert[fromModel], "labels", { value: conversions[fromModel].labels });
      const routes = route(fromModel);
      const routeModels = Object.keys(routes);
      routeModels.forEach((toModel) => {
        const fn = routes[toModel];
        convert[fromModel][toModel] = wrapRounded(fn);
        convert[fromModel][toModel].raw = wrapRaw(fn);
      });
    });
    module2.exports = convert;
  }
});

// ../../node_modules/ansi-styles/index.js
var require_ansi_styles = __commonJS({
  "../../node_modules/ansi-styles/index.js"(exports2, module2) {
    "use strict";
    var wrapAnsi16 = /* @__PURE__ */ __name((fn, offset) => (...args) => {
      const code = fn(...args);
      return `\x1B[${code + offset}m`;
    }, "wrapAnsi16");
    var wrapAnsi256 = /* @__PURE__ */ __name((fn, offset) => (...args) => {
      const code = fn(...args);
      return `\x1B[${38 + offset};5;${code}m`;
    }, "wrapAnsi256");
    var wrapAnsi16m = /* @__PURE__ */ __name((fn, offset) => (...args) => {
      const rgb = fn(...args);
      return `\x1B[${38 + offset};2;${rgb[0]};${rgb[1]};${rgb[2]}m`;
    }, "wrapAnsi16m");
    var ansi2ansi = /* @__PURE__ */ __name((n10) => n10, "ansi2ansi");
    var rgb2rgb = /* @__PURE__ */ __name((r32, g32, b32) => [r32, g32, b32], "rgb2rgb");
    var setLazyProperty = /* @__PURE__ */ __name((object, property, get4) => {
      Object.defineProperty(object, property, {
        get: /* @__PURE__ */ __name(() => {
          const value = get4();
          Object.defineProperty(object, property, {
            value,
            enumerable: true,
            configurable: true
          });
          return value;
        }, "get"),
        enumerable: true,
        configurable: true
      });
    }, "setLazyProperty");
    var colorConvert;
    var makeDynamicStyles = /* @__PURE__ */ __name((wrap, targetSpace, identity, isBackground) => {
      if (colorConvert === void 0) {
        colorConvert = require_color_convert();
      }
      const offset = isBackground ? 10 : 0;
      const styles = {};
      for (const [sourceSpace, suite] of Object.entries(colorConvert)) {
        const name = sourceSpace === "ansi16" ? "ansi" : sourceSpace;
        if (sourceSpace === targetSpace) {
          styles[name] = wrap(identity, offset);
        } else if (typeof suite === "object") {
          styles[name] = wrap(suite[targetSpace], offset);
        }
      }
      return styles;
    }, "makeDynamicStyles");
    function assembleStyles() {
      const codes = /* @__PURE__ */ new Map();
      const styles = {
        modifier: {
          reset: [0, 0],
          // 21 isn't widely supported and 22 does the same thing
          bold: [1, 22],
          dim: [2, 22],
          italic: [3, 23],
          underline: [4, 24],
          inverse: [7, 27],
          hidden: [8, 28],
          strikethrough: [9, 29]
        },
        color: {
          black: [30, 39],
          red: [31, 39],
          green: [32, 39],
          yellow: [33, 39],
          blue: [34, 39],
          magenta: [35, 39],
          cyan: [36, 39],
          white: [37, 39],
          // Bright color
          blackBright: [90, 39],
          redBright: [91, 39],
          greenBright: [92, 39],
          yellowBright: [93, 39],
          blueBright: [94, 39],
          magentaBright: [95, 39],
          cyanBright: [96, 39],
          whiteBright: [97, 39]
        },
        bgColor: {
          bgBlack: [40, 49],
          bgRed: [41, 49],
          bgGreen: [42, 49],
          bgYellow: [43, 49],
          bgBlue: [44, 49],
          bgMagenta: [45, 49],
          bgCyan: [46, 49],
          bgWhite: [47, 49],
          // Bright color
          bgBlackBright: [100, 49],
          bgRedBright: [101, 49],
          bgGreenBright: [102, 49],
          bgYellowBright: [103, 49],
          bgBlueBright: [104, 49],
          bgMagentaBright: [105, 49],
          bgCyanBright: [106, 49],
          bgWhiteBright: [107, 49]
        }
      };
      styles.color.gray = styles.color.blackBright;
      styles.bgColor.bgGray = styles.bgColor.bgBlackBright;
      styles.color.grey = styles.color.blackBright;
      styles.bgColor.bgGrey = styles.bgColor.bgBlackBright;
      for (const [groupName, group7] of Object.entries(styles)) {
        for (const [styleName, style] of Object.entries(group7)) {
          styles[styleName] = {
            open: `\x1B[${style[0]}m`,
            close: `\x1B[${style[1]}m`
          };
          group7[styleName] = styles[styleName];
          codes.set(style[0], style[1]);
        }
        Object.defineProperty(styles, groupName, {
          value: group7,
          enumerable: false
        });
      }
      Object.defineProperty(styles, "codes", {
        value: codes,
        enumerable: false
      });
      styles.color.close = "\x1B[39m";
      styles.bgColor.close = "\x1B[49m";
      setLazyProperty(styles.color, "ansi", () => makeDynamicStyles(wrapAnsi16, "ansi16", ansi2ansi, false));
      setLazyProperty(styles.color, "ansi256", () => makeDynamicStyles(wrapAnsi256, "ansi256", ansi2ansi, false));
      setLazyProperty(styles.color, "ansi16m", () => makeDynamicStyles(wrapAnsi16m, "rgb", rgb2rgb, false));
      setLazyProperty(styles.bgColor, "ansi", () => makeDynamicStyles(wrapAnsi16, "ansi16", ansi2ansi, true));
      setLazyProperty(styles.bgColor, "ansi256", () => makeDynamicStyles(wrapAnsi256, "ansi256", ansi2ansi, true));
      setLazyProperty(styles.bgColor, "ansi16m", () => makeDynamicStyles(wrapAnsi16m, "rgb", rgb2rgb, true));
      return styles;
    }
    __name(assembleStyles, "assembleStyles");
    Object.defineProperty(module2, "exports", {
      enumerable: true,
      get: assembleStyles
    });
  }
});

// ../../node_modules/has-flag/index.js
var require_has_flag = __commonJS({
  "../../node_modules/has-flag/index.js"(exports2, module2) {
    "use strict";
    module2.exports = (flag, argv = process.argv) => {
      const prefix = flag.startsWith("-") ? "" : flag.length === 1 ? "-" : "--";
      const position = argv.indexOf(prefix + flag);
      const terminatorPosition = argv.indexOf("--");
      return position !== -1 && (terminatorPosition === -1 || position < terminatorPosition);
    };
  }
});

// ../../node_modules/supports-color/index.js
var require_supports_color = __commonJS({
  "../../node_modules/supports-color/index.js"(exports2, module2) {
    "use strict";
    var os14 = require("os");
    var tty = require("tty");
    var hasFlag = require_has_flag();
    var { env: env3 } = process;
    var forceColor;
    if (hasFlag("no-color") || hasFlag("no-colors") || hasFlag("color=false") || hasFlag("color=never")) {
      forceColor = 0;
    } else if (hasFlag("color") || hasFlag("colors") || hasFlag("color=true") || hasFlag("color=always")) {
      forceColor = 1;
    }
    if ("FORCE_COLOR" in env3) {
      if (env3.FORCE_COLOR === "true") {
        forceColor = 1;
      } else if (env3.FORCE_COLOR === "false") {
        forceColor = 0;
      } else {
        forceColor = env3.FORCE_COLOR.length === 0 ? 1 : Math.min(parseInt(env3.FORCE_COLOR, 10), 3);
      }
    }
    function translateLevel(level) {
      if (level === 0) {
        return false;
      }
      return {
        level,
        hasBasic: true,
        has256: level >= 2,
        has16m: level >= 3
      };
    }
    __name(translateLevel, "translateLevel");
    function supportsColor(haveStream, streamIsTTY) {
      if (forceColor === 0) {
        return 0;
      }
      if (hasFlag("color=16m") || hasFlag("color=full") || hasFlag("color=truecolor")) {
        return 3;
      }
      if (hasFlag("color=256")) {
        return 2;
      }
      if (haveStream && !streamIsTTY && forceColor === void 0) {
        return 0;
      }
      const min = forceColor || 0;
      if (env3.TERM === "dumb") {
        return min;
      }
      if (process.platform === "win32") {
        const osRelease = os14.release().split(".");
        if (Number(osRelease[0]) >= 10 && Number(osRelease[2]) >= 10586) {
          return Number(osRelease[2]) >= 14931 ? 3 : 2;
        }
        return 1;
      }
      if ("CI" in env3) {
        if (["TRAVIS", "CIRCLECI", "APPVEYOR", "GITLAB_CI", "GITHUB_ACTIONS", "BUILDKITE"].some((sign) => sign in env3) || env3.CI_NAME === "codeship") {
          return 1;
        }
        return min;
      }
      if ("TEAMCITY_VERSION" in env3) {
        return /^(9\.(0*[1-9]\d*)\.|\d{2,}\.)/.test(env3.TEAMCITY_VERSION) ? 1 : 0;
      }
      if (env3.COLORTERM === "truecolor") {
        return 3;
      }
      if ("TERM_PROGRAM" in env3) {
        const version = parseInt((env3.TERM_PROGRAM_VERSION || "").split(".")[0], 10);
        switch (env3.TERM_PROGRAM) {
          case "iTerm.app":
            return version >= 3 ? 3 : 2;
          case "Apple_Terminal":
            return 2;
        }
      }
      if (/-256(color)?$/i.test(env3.TERM)) {
        return 2;
      }
      if (/^screen|^xterm|^vt100|^vt220|^rxvt|color|ansi|cygwin|linux/i.test(env3.TERM)) {
        return 1;
      }
      if ("COLORTERM" in env3) {
        return 1;
      }
      return min;
    }
    __name(supportsColor, "supportsColor");
    function getSupportLevel(stream) {
      const level = supportsColor(stream, stream && stream.isTTY);
      return translateLevel(level);
    }
    __name(getSupportLevel, "getSupportLevel");
    module2.exports = {
      supportsColor: getSupportLevel,
      stdout: translateLevel(supportsColor(true, tty.isatty(1))),
      stderr: translateLevel(supportsColor(true, tty.isatty(2)))
    };
  }
});

// ../../node_modules/chalk/source/util.js
var require_util = __commonJS({
  "../../node_modules/chalk/source/util.js"(exports2, module2) {
    "use strict";
    var stringReplaceAll = /* @__PURE__ */ __name((string, substring3, replacer) => {
      let index = string.indexOf(substring3);
      if (index === -1) {
        return string;
      }
      const substringLength = substring3.length;
      let endIndex = 0;
      let returnValue = "";
      do {
        returnValue += string.substr(endIndex, index - endIndex) + substring3 + replacer;
        endIndex = index + substringLength;
        index = string.indexOf(substring3, endIndex);
      } while (index !== -1);
      returnValue += string.substr(endIndex);
      return returnValue;
    }, "stringReplaceAll");
    var stringEncaseCRLFWithFirstIndex = /* @__PURE__ */ __name((string, prefix, postfix, index) => {
      let endIndex = 0;
      let returnValue = "";
      do {
        const gotCR = string[index - 1] === "\r";
        returnValue += string.substr(endIndex, (gotCR ? index - 1 : index) - endIndex) + prefix + (gotCR ? "\r\n" : "\n") + postfix;
        endIndex = index + 1;
        index = string.indexOf("\n", endIndex);
      } while (index !== -1);
      returnValue += string.substr(endIndex);
      return returnValue;
    }, "stringEncaseCRLFWithFirstIndex");
    module2.exports = {
      stringReplaceAll,
      stringEncaseCRLFWithFirstIndex
    };
  }
});

// ../../node_modules/chalk/source/templates.js
var require_templates = __commonJS({
  "../../node_modules/chalk/source/templates.js"(exports2, module2) {
    "use strict";
    var TEMPLATE_REGEX = /(?:\\(u(?:[a-f\d]{4}|\{[a-f\d]{1,6}\})|x[a-f\d]{2}|.))|(?:\{(~)?(\w+(?:\([^)]*\))?(?:\.\w+(?:\([^)]*\))?)*)(?:[ \t]|(?=\r?\n)))|(\})|((?:.|[\r\n\f])+?)/gi;
    var STYLE_REGEX = /(?:^|\.)(\w+)(?:\(([^)]*)\))?/g;
    var STRING_REGEX = /^(['"])((?:\\.|(?!\1)[^\\])*)\1$/;
    var ESCAPE_REGEX = /\\(u(?:[a-f\d]{4}|{[a-f\d]{1,6}})|x[a-f\d]{2}|.)|([^\\])/gi;
    var ESCAPES = /* @__PURE__ */ new Map([
      ["n", "\n"],
      ["r", "\r"],
      ["t", "	"],
      ["b", "\b"],
      ["f", "\f"],
      ["v", "\v"],
      ["0", "\0"],
      ["\\", "\\"],
      ["e", "\x1B"],
      ["a", "\x07"]
    ]);
    function unescape2(c32) {
      const u = c32[0] === "u";
      const bracket = c32[1] === "{";
      if (u && !bracket && c32.length === 5 || c32[0] === "x" && c32.length === 3) {
        return String.fromCharCode(parseInt(c32.slice(1), 16));
      }
      if (u && bracket) {
        return String.fromCodePoint(parseInt(c32.slice(2, -1), 16));
      }
      return ESCAPES.get(c32) || c32;
    }
    __name(unescape2, "unescape");
    function parseArguments(name, arguments_) {
      const results = [];
      const chunks2 = arguments_.trim().split(/\s*,\s*/g);
      let matches;
      for (const chunk of chunks2) {
        const number = Number(chunk);
        if (!Number.isNaN(number)) {
          results.push(number);
        } else if (matches = chunk.match(STRING_REGEX)) {
          results.push(matches[2].replace(ESCAPE_REGEX, (m20, escape, character) => escape ? unescape2(escape) : character));
        } else {
          throw new Error(`Invalid Chalk template style argument: ${chunk} (in style '${name}')`);
        }
      }
      return results;
    }
    __name(parseArguments, "parseArguments");
    function parseStyle(style) {
      STYLE_REGEX.lastIndex = 0;
      const results = [];
      let matches;
      while ((matches = STYLE_REGEX.exec(style)) !== null) {
        const name = matches[1];
        if (matches[2]) {
          const args = parseArguments(name, matches[2]);
          results.push([name].concat(args));
        } else {
          results.push([name]);
        }
      }
      return results;
    }
    __name(parseStyle, "parseStyle");
    function buildStyle(chalk39, styles) {
      const enabled = {};
      for (const layer of styles) {
        for (const style of layer.styles) {
          enabled[style[0]] = layer.inverse ? null : style.slice(1);
        }
      }
      let current = chalk39;
      for (const [styleName, styles2] of Object.entries(enabled)) {
        if (!Array.isArray(styles2)) {
          continue;
        }
        if (!(styleName in current)) {
          throw new Error(`Unknown Chalk style: ${styleName}`);
        }
        current = styles2.length > 0 ? current[styleName](...styles2) : current[styleName];
      }
      return current;
    }
    __name(buildStyle, "buildStyle");
    module2.exports = (chalk39, temporary) => {
      const styles = [];
      const chunks2 = [];
      let chunk = [];
      temporary.replace(TEMPLATE_REGEX, (m20, escapeCharacter, inverse, style, close, character) => {
        if (escapeCharacter) {
          chunk.push(unescape2(escapeCharacter));
        } else if (style) {
          const string = chunk.join("");
          chunk = [];
          chunks2.push(styles.length === 0 ? string : buildStyle(chalk39, styles)(string));
          styles.push({ inverse, styles: parseStyle(style) });
        } else if (close) {
          if (styles.length === 0) {
            throw new Error("Found extraneous } in Chalk template literal");
          }
          chunks2.push(buildStyle(chalk39, styles)(chunk.join("")));
          chunk = [];
          styles.pop();
        } else {
          chunk.push(character);
        }
      });
      chunks2.push(chunk.join(""));
      if (styles.length > 0) {
        const errMessage = `Chalk template literal is missing ${styles.length} closing bracket${styles.length === 1 ? "" : "s"} (\`}\`)`;
        throw new Error(errMessage);
      }
      return chunks2.join("");
    };
  }
});

// ../../node_modules/chalk/source/index.js
var require_source = __commonJS({
  "../../node_modules/chalk/source/index.js"(exports2, module2) {
    "use strict";
    var ansiStyles = require_ansi_styles();
    var { stdout: stdoutColor, stderr: stderrColor } = require_supports_color();
    var {
      stringReplaceAll,
      stringEncaseCRLFWithFirstIndex
    } = require_util();
    var { isArray: isArray2 } = Array;
    var levelMapping = [
      "ansi",
      "ansi",
      "ansi256",
      "ansi16m"
    ];
    var styles = /* @__PURE__ */ Object.create(null);
    var applyOptions = /* @__PURE__ */ __name((object, options = {}) => {
      if (options.level && !(Number.isInteger(options.level) && options.level >= 0 && options.level <= 3)) {
        throw new Error("The `level` option should be an integer from 0 to 3");
      }
      const colorLevel = stdoutColor ? stdoutColor.level : 0;
      object.level = options.level === void 0 ? colorLevel : options.level;
    }, "applyOptions");
    var ChalkClass = class {
      static {
        __name(this, "ChalkClass");
      }
      constructor(options) {
        return chalkFactory(options);
      }
    };
    var chalkFactory = /* @__PURE__ */ __name((options) => {
      const chalk40 = {};
      applyOptions(chalk40, options);
      chalk40.template = (...arguments_) => chalkTag(chalk40.template, ...arguments_);
      Object.setPrototypeOf(chalk40, Chalk.prototype);
      Object.setPrototypeOf(chalk40.template, chalk40);
      chalk40.template.constructor = () => {
        throw new Error("`chalk.constructor()` is deprecated. Use `new chalk.Instance()` instead.");
      };
      chalk40.template.Instance = ChalkClass;
      return chalk40.template;
    }, "chalkFactory");
    function Chalk(options) {
      return chalkFactory(options);
    }
    __name(Chalk, "Chalk");
    for (const [styleName, style] of Object.entries(ansiStyles)) {
      styles[styleName] = {
        get() {
          const builder = createBuilder(this, createStyler(style.open, style.close, this._styler), this._isEmpty);
          Object.defineProperty(this, styleName, { value: builder });
          return builder;
        }
      };
    }
    styles.visible = {
      get() {
        const builder = createBuilder(this, this._styler, true);
        Object.defineProperty(this, "visible", { value: builder });
        return builder;
      }
    };
    var usedModels = ["rgb", "hex", "keyword", "hsl", "hsv", "hwb", "ansi", "ansi256"];
    for (const model of usedModels) {
      styles[model] = {
        get() {
          const { level } = this;
          return function(...arguments_) {
            const styler = createStyler(ansiStyles.color[levelMapping[level]][model](...arguments_), ansiStyles.color.close, this._styler);
            return createBuilder(this, styler, this._isEmpty);
          };
        }
      };
    }
    for (const model of usedModels) {
      const bgModel = "bg" + model[0].toUpperCase() + model.slice(1);
      styles[bgModel] = {
        get() {
          const { level } = this;
          return function(...arguments_) {
            const styler = createStyler(ansiStyles.bgColor[levelMapping[level]][model](...arguments_), ansiStyles.bgColor.close, this._styler);
            return createBuilder(this, styler, this._isEmpty);
          };
        }
      };
    }
    var proto = Object.defineProperties(() => {
    }, {
      ...styles,
      level: {
        enumerable: true,
        get() {
          return this._generator.level;
        },
        set(level) {
          this._generator.level = level;
        }
      }
    });
    var createStyler = /* @__PURE__ */ __name((open2, close, parent) => {
      let openAll;
      let closeAll;
      if (parent === void 0) {
        openAll = open2;
        closeAll = close;
      } else {
        openAll = parent.openAll + open2;
        closeAll = close + parent.closeAll;
      }
      return {
        open: open2,
        close,
        openAll,
        closeAll,
        parent
      };
    }, "createStyler");
    var createBuilder = /* @__PURE__ */ __name((self2, _styler, _isEmpty) => {
      const builder = /* @__PURE__ */ __name((...arguments_) => {
        if (isArray2(arguments_[0]) && isArray2(arguments_[0].raw)) {
          return applyStyle(builder, chalkTag(builder, ...arguments_));
        }
        return applyStyle(builder, arguments_.length === 1 ? "" + arguments_[0] : arguments_.join(" "));
      }, "builder");
      Object.setPrototypeOf(builder, proto);
      builder._generator = self2;
      builder._styler = _styler;
      builder._isEmpty = _isEmpty;
      return builder;
    }, "createBuilder");
    var applyStyle = /* @__PURE__ */ __name((self2, string) => {
      if (self2.level <= 0 || !string) {
        return self2._isEmpty ? "" : string;
      }
      let styler = self2._styler;
      if (styler === void 0) {
        return string;
      }
      const { openAll, closeAll } = styler;
      if (string.indexOf("\x1B") !== -1) {
        while (styler !== void 0) {
          string = stringReplaceAll(string, styler.close, styler.open);
          styler = styler.parent;
        }
      }
      const lfIndex = string.indexOf("\n");
      if (lfIndex !== -1) {
        string = stringEncaseCRLFWithFirstIndex(string, closeAll, openAll, lfIndex);
      }
      return openAll + string + closeAll;
    }, "applyStyle");
    var template;
    var chalkTag = /* @__PURE__ */ __name((chalk40, ...strings) => {
      const [firstString] = strings;
      if (!isArray2(firstString) || !isArray2(firstString.raw)) {
        return strings.join(" ");
      }
      const arguments_ = strings.slice(1);
      const parts = [firstString.raw[0]];
      for (let i32 = 1; i32 < firstString.length; i32++) {
        parts.push(
          String(arguments_[i32 - 1]).replace(/[{}\\]/g, "\\$&"),
          String(firstString.raw[i32])
        );
      }
      if (template === void 0) {
        template = require_templates();
      }
      return template(chalk40, parts.join(""));
    }, "chalkTag");
    Object.defineProperties(Chalk.prototype, styles);
    var chalk39 = Chalk();
    chalk39.supportsColor = stdoutColor;
    chalk39.stderr = Chalk({ level: stderrColor ? stderrColor.level : 0 });
    chalk39.stderr.supportsColor = stderrColor;
    module2.exports = chalk39;
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/deployments/asset-manifest-builder.ts
var import_cdk_assets_lib, cxschema5, AssetManifestBuilder;
var init_asset_manifest_builder = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/deployments/asset-manifest-builder.ts"() {
    "use strict";
    import_cdk_assets_lib = __toESM(require_lib5());
    cxschema5 = __toESM(require_lib2());
    AssetManifestBuilder = class {
      static {
        __name(this, "AssetManifestBuilder");
      }
      manifest = {
        version: cxschema5.Manifest.version(),
        files: {},
        dockerImages: {}
      };
      addFileAsset(id, source, destination) {
        this.manifest.files[id] = {
          source,
          destinations: {
            current: destination
          }
        };
      }
      addDockerImageAsset(id, source, destination) {
        this.manifest.dockerImages[id] = {
          source,
          destinations: {
            current: destination
          }
        };
      }
      toManifest(directory) {
        return new import_cdk_assets_lib.AssetManifest(directory, this.manifest);
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/toolkit/toolkit-error.ts
var toolkit_error_exports = {};
__export(toolkit_error_exports, {
  AssemblyError: () => AssemblyError,
  AuthenticationError: () => AuthenticationError,
  ContextProviderError: () => ContextProviderError,
  DeploymentError: () => DeploymentError,
  DeploymentErrorCodes: () => DeploymentErrorCodes,
  NoResultsFoundError: () => NoResultsFoundError,
  ToolkitError: () => ToolkitError
});
var TOOLKIT_ERROR_SYMBOL, AUTHENTICATION_ERROR_SYMBOL, DEPLOYMENT_ERROR_SYMBOL, ASSEMBLY_ERROR_SYMBOL2, CONTEXT_PROVIDER_ERROR_SYMBOL, NO_RESULTS_FOUND_ERROR_SYMBOL, ToolkitError, AuthenticationError, AssemblyError, DeploymentError, ContextProviderError, NoResultsFoundError, DeploymentErrorCodes;
var init_toolkit_error = __esm({
  "../@aws-cdk/toolkit-lib/lib/toolkit/toolkit-error.ts"() {
    "use strict";
    TOOLKIT_ERROR_SYMBOL = /* @__PURE__ */ Symbol.for("@aws-cdk/toolkit-lib.ToolkitError");
    AUTHENTICATION_ERROR_SYMBOL = /* @__PURE__ */ Symbol.for("@aws-cdk/toolkit-lib.AuthenticationError");
    DEPLOYMENT_ERROR_SYMBOL = /* @__PURE__ */ Symbol.for("@aws-cdk/toolkit-lib.DeploymentError");
    ASSEMBLY_ERROR_SYMBOL2 = /* @__PURE__ */ Symbol.for("@aws-cdk/toolkit-lib.AssemblyError");
    CONTEXT_PROVIDER_ERROR_SYMBOL = /* @__PURE__ */ Symbol.for("@aws-cdk/toolkit-lib.ContextProviderError");
    NO_RESULTS_FOUND_ERROR_SYMBOL = /* @__PURE__ */ Symbol.for("@aws-cdk/toolkit-lib.NoResultsFoundError");
    ToolkitError = class _ToolkitError extends Error {
      static {
        __name(this, "ToolkitError");
      }
      /**
       * Determines if a given error is an instance of ToolkitError.
       */
      static isToolkitError(x) {
        return x !== null && typeof x === "object" && TOOLKIT_ERROR_SYMBOL in x;
      }
      /**
       * Determines if a given error is an instance of AuthenticationError.
       */
      static isAuthenticationError(x) {
        return _ToolkitError.isToolkitError(x) && AUTHENTICATION_ERROR_SYMBOL in x;
      }
      /**
       * Determines if a given error is an instance of DeploymentError.
       */
      static isDeploymentError(x) {
        return _ToolkitError.isToolkitError(x) && DEPLOYMENT_ERROR_SYMBOL in x;
      }
      /**
       * Determines if a given error is an instance of AssemblyError.
       */
      static isAssemblyError(x) {
        return _ToolkitError.isToolkitError(x) && ASSEMBLY_ERROR_SYMBOL2 in x;
      }
      /**
       * Determines if a given error is an instance of ContextProviderError.
       */
      static isContextProviderError(x) {
        return _ToolkitError.isToolkitError(x) && CONTEXT_PROVIDER_ERROR_SYMBOL in x;
      }
      /**
       * A ToolkitError with an original error as cause
       */
      static withCause(errorCode, message2, error4) {
        return new _ToolkitError(errorCode, message2, "toolkit", error4);
      }
      /**
       * The type of the error, defaults to "toolkit".
       */
      type;
      /**
       * Denotes the source of the error as the toolkit.
       */
      source;
      /**
       * The specific original cause of the error, if available
       */
      cause;
      constructor(errorCode, message2, type = "toolkit", cause) {
        super(message2);
        this.name = errorCode;
        Object.setPrototypeOf(this, _ToolkitError.prototype);
        Object.defineProperty(this, TOOLKIT_ERROR_SYMBOL, { value: true });
        this.type = type;
        this.source = "toolkit";
        this.cause = cause;
      }
    };
    AuthenticationError = class _AuthenticationError extends ToolkitError {
      static {
        __name(this, "AuthenticationError");
      }
      /**
       * Denotes the source of the error as user.
       */
      source = "user";
      constructor(errorCode, message2) {
        super(errorCode, message2, "authentication");
        Object.setPrototypeOf(this, _AuthenticationError.prototype);
        Object.defineProperty(this, AUTHENTICATION_ERROR_SYMBOL, { value: true });
      }
    };
    AssemblyError = class _AssemblyError extends ToolkitError {
      static {
        __name(this, "AssemblyError");
      }
      /**
       * An AssemblyError with an original error as cause
       */
      static withCause(message2, error4) {
        return new _AssemblyError(message2, void 0, error4);
      }
      /**
       * An AssemblyError with a list of stacks as cause
       */
      static withStacks(message2, stacks) {
        return new _AssemblyError(message2, stacks);
      }
      /**
       * Denotes the source of the error as user.
       */
      source = "user";
      /**
       * The stacks that caused the error, if available
       *
       * The `messages` property of each `cxapi.CloudFormationStackArtifact` will contain the respective errors.
       * Absence indicates synthesis didn't fully complete.
       */
      stacks;
      _synthErrorCode;
      constructor(message2, stacks, cause) {
        super("AssemblyError", message2, "assembly", cause);
        Object.setPrototypeOf(this, _AssemblyError.prototype);
        Object.defineProperty(this, ASSEMBLY_ERROR_SYMBOL2, { value: true });
        this.stacks = stacks;
      }
      /**
       * The synthesis error code
       */
      get synthErrorCode() {
        return this._synthErrorCode;
      }
      attachSynthesisErrorCode(synthesisErrorCode) {
        this._synthErrorCode = synthesisErrorCode;
      }
    };
    DeploymentError = class _DeploymentError extends ToolkitError {
      static {
        __name(this, "DeploymentError");
      }
      /**
       * Denotes the source of the error as user.
       */
      source = "user";
      deploymentErrorCode;
      constructor(message2, deploymentErrorCode) {
        super("DeploymentError", message2, "deployment");
        Object.setPrototypeOf(this, _DeploymentError.prototype);
        Object.defineProperty(this, DEPLOYMENT_ERROR_SYMBOL, { value: true });
        this.deploymentErrorCode = deploymentErrorCode;
      }
    };
    ContextProviderError = class _ContextProviderError extends ToolkitError {
      static {
        __name(this, "ContextProviderError");
      }
      /**
       * Determines if a given error is an instance of NoResultsFoundError.
       */
      static isNoResultsFoundError(x) {
        return ToolkitError.isContextProviderError(x) && NO_RESULTS_FOUND_ERROR_SYMBOL in x;
      }
      /**
       * A ContextProviderError with an original error as cause
       */
      static withCause(errorCode, message2, error4) {
        return new _ContextProviderError(errorCode, message2, error4);
      }
      /**
       * Denotes the source of the error as user.
       */
      source = "user";
      constructor(errorCode, message2, cause) {
        super(errorCode, message2, "context-provider", cause);
        Object.setPrototypeOf(this, _ContextProviderError.prototype);
        Object.defineProperty(this, CONTEXT_PROVIDER_ERROR_SYMBOL, { value: true });
      }
    };
    NoResultsFoundError = class _NoResultsFoundError extends ContextProviderError {
      static {
        __name(this, "NoResultsFoundError");
      }
      constructor(message2) {
        super("NoResultsFound", message2);
        Object.setPrototypeOf(this, _NoResultsFoundError.prototype);
        Object.defineProperty(this, NO_RESULTS_FOUND_ERROR_SYMBOL, { value: true });
      }
    };
    DeploymentErrorCodes = class {
      static {
        __name(this, "DeploymentErrorCodes");
      }
      static STACK_DISAPPEARED_ERROR_CODE = "StackDisappeared";
      static UNKNOWN_ERROR = "UnknownError";
      static PRIVATE_RESOURCE_ERROR = "PrivateResourceError";
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/io/private/io-host-wrappers.ts
function withoutColor(ioHost) {
  return {
    notify: /* @__PURE__ */ __name(async (msg) => {
      await ioHost.notify({
        ...msg,
        message: stripColor(msg.message)
      });
    }, "notify"),
    requestResponse: /* @__PURE__ */ __name(async (msg) => {
      return ioHost.requestResponse({
        ...msg,
        message: stripColor(msg.message)
      });
    }, "requestResponse")
  };
}
function stripColor(msg) {
  return msg.replace(/[\u001b\u009b][[()#;?]*(?:[0-9]{1,4}(?:;[0-9]{0,4})*)?[0-9A-ORZcf-nqry=><]/g, "");
}
function withoutEmojis(ioHost) {
  return {
    notify: /* @__PURE__ */ __name(async (msg) => {
      await ioHost.notify({
        ...msg,
        message: stripEmojis(msg.message)
      });
    }, "notify"),
    requestResponse: /* @__PURE__ */ __name(async (msg) => {
      return ioHost.requestResponse({
        ...msg,
        message: stripEmojis(msg.message)
      });
    }, "requestResponse")
  };
}
function stripEmojis(msg) {
  return msg.replace(new RegExp("\\p{Emoji_Presentation}", "gu"), "");
}
function withTrimmedWhitespace(ioHost) {
  return {
    notify: /* @__PURE__ */ __name(async (msg) => {
      await ioHost.notify({
        ...msg,
        message: msg.message.trim()
      });
    }, "notify"),
    requestResponse: /* @__PURE__ */ __name(async (msg) => {
      return ioHost.requestResponse({
        ...msg,
        message: msg.message.trim()
      });
    }, "requestResponse")
  };
}
var init_io_host_wrappers = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/io/private/io-host-wrappers.ts"() {
    "use strict";
    __name(withoutColor, "withoutColor");
    __name(stripColor, "stripColor");
    __name(withoutEmojis, "withoutEmojis");
    __name(stripEmojis, "stripEmojis");
    __name(withTrimmedWhitespace, "withTrimmedWhitespace");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/io/private/io-default-messages.ts
var util, IoDefaultMessages;
var init_io_default_messages = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/io/private/io-default-messages.ts"() {
    "use strict";
    util = __toESM(require("util"));
    IoDefaultMessages = class {
      static {
        __name(this, "IoDefaultMessages");
      }
      ioHelper;
      constructor(ioHelper) {
        this.ioHelper = ioHelper;
      }
      async notify(msg) {
        return this.ioHelper.notify({
          ...msg,
          code: void 0
        });
      }
      async error(input, ...args) {
        return this.emitMessage("error", input, ...args);
      }
      async warn(input, ...args) {
        return this.emitMessage("warn", input, ...args);
      }
      async warning(input, ...args) {
        return this.emitMessage("warn", input, ...args);
      }
      async info(input, ...args) {
        return this.emitMessage("info", input, ...args);
      }
      async debug(input, ...args) {
        return this.emitMessage("debug", input, ...args);
      }
      async trace(input, ...args) {
        return this.emitMessage("trace", input, ...args);
      }
      async result(input, ...args) {
        return this.emitMessage("result", input, ...args);
      }
      /**
       * Makes a default message object from a level and a message
       */
      msg(level, input, ...args) {
        const message2 = args.length > 0 ? util.format(input, ...args) : input;
        return {
          time: /* @__PURE__ */ new Date(),
          level,
          message: message2,
          data: void 0
        };
      }
      async emitMessage(level, input, ...args) {
        return this.ioHelper.notify(this.msg(level, input, ...args));
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/private/dispose-polyfill.ts
var require_dispose_polyfill = __commonJS({
  "../@aws-cdk/toolkit-lib/lib/private/dispose-polyfill.ts"() {
    "use strict";
    Symbol.dispose ??= /* @__PURE__ */ Symbol("Symbol.dispose");
    Symbol.asyncDispose ??= /* @__PURE__ */ Symbol("Symbol.asyncDispose");
  }
});

// ../@aws-cdk/toolkit-lib/lib/util/arrays.ts
function flatMap(xs, fn) {
  return flatten2(xs.map(fn));
}
function flatten2(xs) {
  return Array.prototype.concat.apply([], xs);
}
function partition(collection, pred) {
  const ret = [];
  let i32 = 0;
  while (i32 < collection.length) {
    if (pred(collection[i32])) {
      ret.push(collection.splice(i32, 1)[0]);
    } else {
      i32++;
    }
  }
  return ret;
}
async function indexBy(xs, fn) {
  const ret = /* @__PURE__ */ new Map();
  for (const x of xs) {
    const key = await fn(x);
    const group7 = ret.get(key);
    if (group7) {
      group7.push(x);
    } else {
      ret.set(key, [x]);
    }
  }
  return ret;
}
function sortByKey(xs, keyFn) {
  xs.sort((a32, b32) => cmp(keyFn(a32), keyFn(b32)));
  function cmp(as, bs) {
    for (let i32 = 0; i32 < as.length && i32 < bs.length; i32++) {
      const a32 = as[i32];
      const b32 = bs[i32];
      if (typeof a32 !== typeof b32) {
        return (typeof a32).localeCompare(typeof b32);
      }
      if (a32 !== b32) {
        if (typeof a32 === "number" && typeof b32 === "number") {
          return a32 - b32;
        }
        if (typeof a32 === "string" && typeof b32 === "string") {
          return a32.localeCompare(b32);
        }
      }
    }
    return as.length - bs.length;
  }
  __name(cmp, "cmp");
}
var init_arrays = __esm({
  "../@aws-cdk/toolkit-lib/lib/util/arrays.ts"() {
    "use strict";
    __name(flatMap, "flatMap");
    __name(flatten2, "flatten");
    __name(partition, "partition");
    __name(indexBy, "indexBy");
    __name(sortByKey, "sortByKey");
  }
});

// ../@aws-cdk/toolkit-lib/lib/util/bool.ts
var init_bool = __esm({
  "../@aws-cdk/toolkit-lib/lib/util/bool.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/util/bytes.ts
function formatBytes(bytes, decimals = 2) {
  decimals = decimals < 0 ? 0 : decimals;
  if (bytes === 0) {
    return "0 Bytes";
  }
  const k32 = 1024;
  const sizes = ["Bytes", "KiB", "MiB", "GiB", "TiB", "PiB", "EiB", "ZiB", "YiB"];
  const i32 = Math.floor(Math.log(bytes) / Math.log(k32));
  return `${parseFloat((bytes / Math.pow(k32, i32)).toFixed(decimals))} ${sizes[i32]}`;
}
var init_bytes = __esm({
  "../@aws-cdk/toolkit-lib/lib/util/bytes.ts"() {
    "use strict";
    __name(formatBytes, "formatBytes");
  }
});

// ../@aws-cdk/toolkit-lib/lib/util/cloudformation.ts
function validateSnsTopicArn(arn) {
  return /^arn:aws:sns:[a-z0-9\-]+:[0-9]+:[a-z0-9\-\_]+$/i.test(arn);
}
function isErrorEvent(event) {
  const status = event.ResourceStatus ?? "";
  return status.endsWith("_FAILED") || status === "ROLLBACK_IN_PROGRESS" || status === "UPDATE_ROLLBACK_IN_PROGRESS";
}
function isCancellationEvent(event) {
  return (event.ResourceStatusReason ?? "").indexOf("cancelled") > -1;
}
function isRegularResourceEvent(event) {
  return event.ResourceType !== "AWS::CloudFormation::Stack";
}
function isRootStackEvent(event) {
  return event.ResourceType === "AWS::CloudFormation::Stack" && event.PhysicalResourceId === event.StackId;
}
function maxResourceTypeLength(template, startWidth = "AWS::CloudFormation::Stack".length) {
  const resources = template && template.Resources || {};
  let maxWidth = startWidth;
  for (const id of Object.keys(resources)) {
    const type = resources[id].Type || "";
    if (type.length > maxWidth) {
      maxWidth = type.length;
    }
  }
  return maxWidth;
}
function stackNameFromArn(stackNameOrArn) {
  if (!stackNameOrArn.startsWith("arn:")) {
    return stackNameOrArn;
  }
  return stackNameOrArn.slice(stackNameOrArn.indexOf("/") + 1, stackNameOrArn.lastIndexOf("/"));
}
function changeSetNameFromArn(changeSetNameOrArn) {
  if (!changeSetNameOrArn.startsWith("arn:")) {
    return changeSetNameOrArn;
  }
  return changeSetNameOrArn.slice(changeSetNameOrArn.indexOf("/") + 1, changeSetNameOrArn.lastIndexOf("/"));
}
var init_cloudformation = __esm({
  "../@aws-cdk/toolkit-lib/lib/util/cloudformation.ts"() {
    "use strict";
    __name(validateSnsTopicArn, "validateSnsTopicArn");
    __name(isErrorEvent, "isErrorEvent");
    __name(isCancellationEvent, "isCancellationEvent");
    __name(isRegularResourceEvent, "isRegularResourceEvent");
    __name(isRootStackEvent, "isRootStackEvent");
    __name(maxResourceTypeLength, "maxResourceTypeLength");
    __name(stackNameFromArn, "stackNameFromArn");
    __name(changeSetNameFromArn, "changeSetNameFromArn");
  }
});

// ../@aws-cdk/toolkit-lib/lib/util/content-hash.ts
function contentHash(data3) {
  return crypto2.createHash("sha256").update(data3).digest("hex");
}
function contentHashAny(value) {
  const ret = crypto2.createHash("sha256");
  recurse(value);
  return ret.digest("hex");
  function recurse(x) {
    if (typeof x === "string") {
      ret.update(x);
      return;
    }
    if (Array.isArray(x)) {
      ret.update("[");
      for (const e32 of x) {
        recurse(e32);
        ret.update("||");
      }
      ret.update("]");
      return;
    }
    if (x && typeof x === "object") {
      ret.update("{");
      for (const key of Object.keys(x).sort()) {
        ret.update(key);
        ret.update(":");
        recurse(x[key]);
      }
      ret.update("}");
      return;
    }
    ret.update(`${x}${typeof x}`);
  }
  __name(recurse, "recurse");
}
var crypto2;
var init_content_hash = __esm({
  "../@aws-cdk/toolkit-lib/lib/util/content-hash.ts"() {
    "use strict";
    crypto2 = __toESM(require("crypto"));
    __name(contentHash, "contentHash");
    __name(contentHashAny, "contentHashAny");
  }
});

// ../@aws-cdk/toolkit-lib/lib/util/directories.ts
function cdkHomeDir() {
  const tmpDir = fs11.realpathSync(os5.tmpdir());
  let home;
  try {
    let userInfoHome = os5.userInfo().homedir;
    if (userInfoHome == "/var/empty") {
      userInfoHome = void 0;
    }
    home = path11.join((userInfoHome ?? os5.homedir()).trim(), ".cdk");
  } catch {
  }
  return process.env.CDK_HOME ? path11.resolve(process.env.CDK_HOME) : home || fs11.mkdtempSync(path11.join(tmpDir, ".cdk")).trim();
}
function cdkCacheDir() {
  return path11.join(cdkHomeDir(), "cache");
}
function bundledPackageRootDir(start, fail) {
  function _rootDir(dirname14) {
    const manifestPath = path11.join(dirname14, "package.json");
    if (fs11.existsSync(manifestPath)) {
      return dirname14;
    }
    if (path11.dirname(dirname14) === dirname14) {
      if (fail ?? true) {
        throw new ToolkitError("PackageManifestNotFound", "Unable to find package manifest");
      }
      return void 0;
    }
    return _rootDir(path11.dirname(dirname14));
  }
  __name(_rootDir, "_rootDir");
  return _rootDir(start);
}
async function listFiles(dirName, depth, excludeDirs) {
  const ret = await fsExtra.readdir(dirName, { encoding: "utf-8", withFileTypes: true });
  return (await Promise.all(ret.map(async (f32) => {
    if (f32.isDirectory()) {
      if (depth <= 1 || excludeDirs?.includes(f32.name)) {
        return [];
      }
      return listFiles(path11.join(dirName, f32.name), depth - 1, excludeDirs);
    } else {
      return [f32.name];
    }
  }))).flatMap((xs) => xs);
}
var fs11, os5, path11, fsExtra;
var init_directories = __esm({
  "../@aws-cdk/toolkit-lib/lib/util/directories.ts"() {
    "use strict";
    fs11 = __toESM(require("fs"));
    os5 = __toESM(require("os"));
    path11 = __toESM(require("path"));
    fsExtra = __toESM(require_lib4());
    init_toolkit_error();
    __name(cdkHomeDir, "cdkHomeDir");
    __name(cdkCacheDir, "cdkCacheDir");
    __name(bundledPackageRootDir, "bundledPackageRootDir");
    __name(listFiles, "listFiles");
  }
});

// ../@aws-cdk/toolkit-lib/lib/util/format-error.ts
function formatErrorMessage(error4) {
  if (error4 && Array.isArray(error4.errors)) {
    const innerMessages = error4.errors.map((innerError) => innerError?.message || innerError?.toString()).join("\n");
    return `AggregateError: ${innerMessages}`;
  }
  if (ToolkitError.isToolkitError(error4) && error4.cause) {
    return `${error4.message}
${formatErrorMessage(error4.cause)}`;
  }
  return error4?.message || error4?.toString() || "Unknown error";
}
var init_format_error = __esm({
  "../@aws-cdk/toolkit-lib/lib/util/format-error.ts"() {
    "use strict";
    init_toolkit_error();
    __name(formatErrorMessage, "formatErrorMessage");
  }
});

// ../../node_modules/picomatch/lib/constants.js
var require_constants5 = __commonJS({
  "../../node_modules/picomatch/lib/constants.js"(exports2, module2) {
    "use strict";
    var WIN_SLASH = "\\\\/";
    var WIN_NO_SLASH = `[^${WIN_SLASH}]`;
    var DEFAULT_MAX_EXTGLOB_RECURSION = 0;
    var DOT_LITERAL = "\\.";
    var PLUS_LITERAL = "\\+";
    var QMARK_LITERAL = "\\?";
    var SLASH_LITERAL = "\\/";
    var ONE_CHAR = "(?=.)";
    var QMARK = "[^/]";
    var END_ANCHOR = `(?:${SLASH_LITERAL}|$)`;
    var START_ANCHOR = `(?:^|${SLASH_LITERAL})`;
    var DOTS_SLASH = `${DOT_LITERAL}{1,2}${END_ANCHOR}`;
    var NO_DOT = `(?!${DOT_LITERAL})`;
    var NO_DOTS = `(?!${START_ANCHOR}${DOTS_SLASH})`;
    var NO_DOT_SLASH = `(?!${DOT_LITERAL}{0,1}${END_ANCHOR})`;
    var NO_DOTS_SLASH = `(?!${DOTS_SLASH})`;
    var QMARK_NO_DOT = `[^.${SLASH_LITERAL}]`;
    var STAR = `${QMARK}*?`;
    var SEP = "/";
    var POSIX_CHARS = {
      DOT_LITERAL,
      PLUS_LITERAL,
      QMARK_LITERAL,
      SLASH_LITERAL,
      ONE_CHAR,
      QMARK,
      END_ANCHOR,
      DOTS_SLASH,
      NO_DOT,
      NO_DOTS,
      NO_DOT_SLASH,
      NO_DOTS_SLASH,
      QMARK_NO_DOT,
      STAR,
      START_ANCHOR,
      SEP
    };
    var WINDOWS_CHARS = {
      ...POSIX_CHARS,
      SLASH_LITERAL: `[${WIN_SLASH}]`,
      QMARK: WIN_NO_SLASH,
      STAR: `${WIN_NO_SLASH}*?`,
      DOTS_SLASH: `${DOT_LITERAL}{1,2}(?:[${WIN_SLASH}]|$)`,
      NO_DOT: `(?!${DOT_LITERAL})`,
      NO_DOTS: `(?!(?:^|[${WIN_SLASH}])${DOT_LITERAL}{1,2}(?:[${WIN_SLASH}]|$))`,
      NO_DOT_SLASH: `(?!${DOT_LITERAL}{0,1}(?:[${WIN_SLASH}]|$))`,
      NO_DOTS_SLASH: `(?!${DOT_LITERAL}{1,2}(?:[${WIN_SLASH}]|$))`,
      QMARK_NO_DOT: `[^.${WIN_SLASH}]`,
      START_ANCHOR: `(?:^|[${WIN_SLASH}])`,
      END_ANCHOR: `(?:[${WIN_SLASH}]|$)`,
      SEP: "\\"
    };
    var POSIX_REGEX_SOURCE = {
      __proto__: null,
      alnum: "a-zA-Z0-9",
      alpha: "a-zA-Z",
      ascii: "\\x00-\\x7F",
      blank: " \\t",
      cntrl: "\\x00-\\x1F\\x7F",
      digit: "0-9",
      graph: "\\x21-\\x7E",
      lower: "a-z",
      print: "\\x20-\\x7E ",
      punct: "\\-!\"#$%&'()\\*+,./:;<=>?@[\\]^_`{|}~",
      space: " \\t\\r\\n\\v\\f",
      upper: "A-Z",
      word: "A-Za-z0-9_",
      xdigit: "A-Fa-f0-9"
    };
    module2.exports = {
      DEFAULT_MAX_EXTGLOB_RECURSION,
      MAX_LENGTH: 1024 * 64,
      POSIX_REGEX_SOURCE,
      // regular expressions
      REGEX_BACKSLASH: /\\(?![*+?^${}(|)[\]])/g,
      REGEX_NON_SPECIAL_CHARS: /^[^@![\].,$*+?^{}()|\\/]+/,
      REGEX_SPECIAL_CHARS: /[-*+?.^${}(|)[\]]/,
      REGEX_SPECIAL_CHARS_BACKREF: /(\\?)((\W)(\3*))/g,
      REGEX_SPECIAL_CHARS_GLOBAL: /([-*+?.^${}(|)[\]])/g,
      REGEX_REMOVE_BACKSLASH: /(?:\[.*?[^\\]\]|\\(?=.))/g,
      // Replace globs with equivalent patterns to reduce parsing time.
      REPLACEMENTS: {
        __proto__: null,
        "***": "*",
        "**/**": "**",
        "**/**/**": "**"
      },
      // Digits
      CHAR_0: 48,
      /* 0 */
      CHAR_9: 57,
      /* 9 */
      // Alphabet chars.
      CHAR_UPPERCASE_A: 65,
      /* A */
      CHAR_LOWERCASE_A: 97,
      /* a */
      CHAR_UPPERCASE_Z: 90,
      /* Z */
      CHAR_LOWERCASE_Z: 122,
      /* z */
      CHAR_LEFT_PARENTHESES: 40,
      /* ( */
      CHAR_RIGHT_PARENTHESES: 41,
      /* ) */
      CHAR_ASTERISK: 42,
      /* * */
      // Non-alphabetic chars.
      CHAR_AMPERSAND: 38,
      /* & */
      CHAR_AT: 64,
      /* @ */
      CHAR_BACKWARD_SLASH: 92,
      /* \ */
      CHAR_CARRIAGE_RETURN: 13,
      /* \r */
      CHAR_CIRCUMFLEX_ACCENT: 94,
      /* ^ */
      CHAR_COLON: 58,
      /* : */
      CHAR_COMMA: 44,
      /* , */
      CHAR_DOT: 46,
      /* . */
      CHAR_DOUBLE_QUOTE: 34,
      /* " */
      CHAR_EQUAL: 61,
      /* = */
      CHAR_EXCLAMATION_MARK: 33,
      /* ! */
      CHAR_FORM_FEED: 12,
      /* \f */
      CHAR_FORWARD_SLASH: 47,
      /* / */
      CHAR_GRAVE_ACCENT: 96,
      /* ` */
      CHAR_HASH: 35,
      /* # */
      CHAR_HYPHEN_MINUS: 45,
      /* - */
      CHAR_LEFT_ANGLE_BRACKET: 60,
      /* < */
      CHAR_LEFT_CURLY_BRACE: 123,
      /* { */
      CHAR_LEFT_SQUARE_BRACKET: 91,
      /* [ */
      CHAR_LINE_FEED: 10,
      /* \n */
      CHAR_NO_BREAK_SPACE: 160,
      /* \u00A0 */
      CHAR_PERCENT: 37,
      /* % */
      CHAR_PLUS: 43,
      /* + */
      CHAR_QUESTION_MARK: 63,
      /* ? */
      CHAR_RIGHT_ANGLE_BRACKET: 62,
      /* > */
      CHAR_RIGHT_CURLY_BRACE: 125,
      /* } */
      CHAR_RIGHT_SQUARE_BRACKET: 93,
      /* ] */
      CHAR_SEMICOLON: 59,
      /* ; */
      CHAR_SINGLE_QUOTE: 39,
      /* ' */
      CHAR_SPACE: 32,
      /*   */
      CHAR_TAB: 9,
      /* \t */
      CHAR_UNDERSCORE: 95,
      /* _ */
      CHAR_VERTICAL_LINE: 124,
      /* | */
      CHAR_ZERO_WIDTH_NOBREAK_SPACE: 65279,
      /* \uFEFF */
      /**
       * Create EXTGLOB_CHARS
       */
      extglobChars(chars6) {
        return {
          "!": { type: "negate", open: "(?:(?!(?:", close: `))${chars6.STAR})` },
          "?": { type: "qmark", open: "(?:", close: ")?" },
          "+": { type: "plus", open: "(?:", close: ")+" },
          "*": { type: "star", open: "(?:", close: ")*" },
          "@": { type: "at", open: "(?:", close: ")" }
        };
      },
      /**
       * Create GLOB_CHARS
       */
      globChars(win32) {
        return win32 === true ? WINDOWS_CHARS : POSIX_CHARS;
      }
    };
  }
});

// ../../node_modules/picomatch/lib/utils.js
var require_utils7 = __commonJS({
  "../../node_modules/picomatch/lib/utils.js"(exports2) {
    "use strict";
    var {
      REGEX_BACKSLASH,
      REGEX_REMOVE_BACKSLASH,
      REGEX_SPECIAL_CHARS,
      REGEX_SPECIAL_CHARS_GLOBAL
    } = require_constants5();
    exports2.isObject = (val) => val !== null && typeof val === "object" && !Array.isArray(val);
    exports2.hasRegexChars = (str) => REGEX_SPECIAL_CHARS.test(str);
    exports2.isRegexChar = (str) => str.length === 1 && exports2.hasRegexChars(str);
    exports2.escapeRegex = (str) => str.replace(REGEX_SPECIAL_CHARS_GLOBAL, "\\$1");
    exports2.toPosixSlashes = (str) => str.replace(REGEX_BACKSLASH, "/");
    exports2.isWindows = () => {
      if (typeof navigator !== "undefined" && navigator.platform) {
        const platform5 = navigator.platform.toLowerCase();
        return platform5 === "win32" || platform5 === "windows";
      }
      if (typeof process !== "undefined" && process.platform) {
        return process.platform === "win32";
      }
      return false;
    };
    exports2.removeBackslashes = (str) => {
      return str.replace(REGEX_REMOVE_BACKSLASH, (match) => {
        return match === "\\" ? "" : match;
      });
    };
    exports2.escapeLast = (input, char, lastIdx) => {
      const idx = input.lastIndexOf(char, lastIdx);
      if (idx === -1) return input;
      if (input[idx - 1] === "\\") return exports2.escapeLast(input, char, idx - 1);
      return `${input.slice(0, idx)}\\${input.slice(idx)}`;
    };
    exports2.removePrefix = (input, state13 = {}) => {
      let output = input;
      if (output.startsWith("./")) {
        output = output.slice(2);
        state13.prefix = "./";
      }
      return output;
    };
    exports2.wrapOutput = (input, state13 = {}, options = {}) => {
      const prepend = options.contains ? "" : "^";
      const append = options.contains ? "" : "$";
      let output = `${prepend}(?:${input})${append}`;
      if (state13.negated === true) {
        output = `(?:^(?!${output}).*$)`;
      }
      return output;
    };
    exports2.basename = (path47, { windows } = {}) => {
      const segs = path47.split(windows ? /[\\/]/ : "/");
      const last = segs[segs.length - 1];
      if (last === "") {
        return segs[segs.length - 2];
      }
      return last;
    };
  }
});

// ../../node_modules/picomatch/lib/scan.js
var require_scan3 = __commonJS({
  "../../node_modules/picomatch/lib/scan.js"(exports2, module2) {
    "use strict";
    var utils = require_utils7();
    var {
      CHAR_ASTERISK,
      /* * */
      CHAR_AT,
      /* @ */
      CHAR_BACKWARD_SLASH,
      /* \ */
      CHAR_COMMA,
      /* , */
      CHAR_DOT,
      /* . */
      CHAR_EXCLAMATION_MARK,
      /* ! */
      CHAR_FORWARD_SLASH,
      /* / */
      CHAR_LEFT_CURLY_BRACE,
      /* { */
      CHAR_LEFT_PARENTHESES,
      /* ( */
      CHAR_LEFT_SQUARE_BRACKET,
      /* [ */
      CHAR_PLUS,
      /* + */
      CHAR_QUESTION_MARK,
      /* ? */
      CHAR_RIGHT_CURLY_BRACE,
      /* } */
      CHAR_RIGHT_PARENTHESES,
      /* ) */
      CHAR_RIGHT_SQUARE_BRACKET
      /* ] */
    } = require_constants5();
    var isPathSeparator = /* @__PURE__ */ __name((code) => {
      return code === CHAR_FORWARD_SLASH || code === CHAR_BACKWARD_SLASH;
    }, "isPathSeparator");
    var depth = /* @__PURE__ */ __name((token) => {
      if (token.isPrefix !== true) {
        token.depth = token.isGlobstar ? Infinity : 1;
      }
    }, "depth");
    var scan = /* @__PURE__ */ __name((input, options) => {
      const opts = options || {};
      const length = input.length - 1;
      const scanToEnd = opts.parts === true || opts.scanToEnd === true;
      const slashes = [];
      const tokens = [];
      const parts = [];
      let str = input;
      let index = -1;
      let start = 0;
      let lastIndex = 0;
      let isBrace = false;
      let isBracket = false;
      let isGlob = false;
      let isExtglob = false;
      let isGlobstar = false;
      let braceEscaped = false;
      let backslashes = false;
      let negated = false;
      let negatedExtglob = false;
      let finished = false;
      let braces = 0;
      let prev;
      let code;
      let token = { value: "", depth: 0, isGlob: false };
      const eos = /* @__PURE__ */ __name(() => index >= length, "eos");
      const peek = /* @__PURE__ */ __name(() => str.charCodeAt(index + 1), "peek");
      const advance = /* @__PURE__ */ __name(() => {
        prev = code;
        return str.charCodeAt(++index);
      }, "advance");
      while (index < length) {
        code = advance();
        let next;
        if (code === CHAR_BACKWARD_SLASH) {
          backslashes = token.backslashes = true;
          code = advance();
          if (code === CHAR_LEFT_CURLY_BRACE) {
            braceEscaped = true;
          }
          continue;
        }
        if (braceEscaped === true || code === CHAR_LEFT_CURLY_BRACE) {
          braces++;
          while (eos() !== true && (code = advance())) {
            if (code === CHAR_BACKWARD_SLASH) {
              backslashes = token.backslashes = true;
              advance();
              continue;
            }
            if (code === CHAR_LEFT_CURLY_BRACE) {
              braces++;
              continue;
            }
            if (braceEscaped !== true && code === CHAR_DOT && (code = advance()) === CHAR_DOT) {
              isBrace = token.isBrace = true;
              isGlob = token.isGlob = true;
              finished = true;
              if (scanToEnd === true) {
                continue;
              }
              break;
            }
            if (braceEscaped !== true && code === CHAR_COMMA) {
              isBrace = token.isBrace = true;
              isGlob = token.isGlob = true;
              finished = true;
              if (scanToEnd === true) {
                continue;
              }
              break;
            }
            if (code === CHAR_RIGHT_CURLY_BRACE) {
              braces--;
              if (braces === 0) {
                braceEscaped = false;
                isBrace = token.isBrace = true;
                finished = true;
                break;
              }
            }
          }
          if (scanToEnd === true) {
            continue;
          }
          break;
        }
        if (code === CHAR_FORWARD_SLASH) {
          slashes.push(index);
          tokens.push(token);
          token = { value: "", depth: 0, isGlob: false };
          if (finished === true) continue;
          if (prev === CHAR_DOT && index === start + 1) {
            start += 2;
            continue;
          }
          lastIndex = index + 1;
          continue;
        }
        if (opts.noext !== true) {
          const isExtglobChar = code === CHAR_PLUS || code === CHAR_AT || code === CHAR_ASTERISK || code === CHAR_QUESTION_MARK || code === CHAR_EXCLAMATION_MARK;
          if (isExtglobChar === true && peek() === CHAR_LEFT_PARENTHESES) {
            isGlob = token.isGlob = true;
            isExtglob = token.isExtglob = true;
            finished = true;
            if (code === CHAR_EXCLAMATION_MARK && index === start) {
              negatedExtglob = true;
            }
            if (scanToEnd === true) {
              while (eos() !== true && (code = advance())) {
                if (code === CHAR_BACKWARD_SLASH) {
                  backslashes = token.backslashes = true;
                  code = advance();
                  continue;
                }
                if (code === CHAR_RIGHT_PARENTHESES) {
                  isGlob = token.isGlob = true;
                  finished = true;
                  break;
                }
              }
              continue;
            }
            break;
          }
        }
        if (code === CHAR_ASTERISK) {
          if (prev === CHAR_ASTERISK) isGlobstar = token.isGlobstar = true;
          isGlob = token.isGlob = true;
          finished = true;
          if (scanToEnd === true) {
            continue;
          }
          break;
        }
        if (code === CHAR_QUESTION_MARK) {
          isGlob = token.isGlob = true;
          finished = true;
          if (scanToEnd === true) {
            continue;
          }
          break;
        }
        if (code === CHAR_LEFT_SQUARE_BRACKET) {
          while (eos() !== true && (next = advance())) {
            if (next === CHAR_BACKWARD_SLASH) {
              backslashes = token.backslashes = true;
              advance();
              continue;
            }
            if (next === CHAR_RIGHT_SQUARE_BRACKET) {
              isBracket = token.isBracket = true;
              isGlob = token.isGlob = true;
              finished = true;
              break;
            }
          }
          if (scanToEnd === true) {
            continue;
          }
          break;
        }
        if (opts.nonegate !== true && code === CHAR_EXCLAMATION_MARK && index === start) {
          negated = token.negated = true;
          start++;
          continue;
        }
        if (opts.noparen !== true && code === CHAR_LEFT_PARENTHESES) {
          isGlob = token.isGlob = true;
          if (scanToEnd === true) {
            while (eos() !== true && (code = advance())) {
              if (code === CHAR_LEFT_PARENTHESES) {
                backslashes = token.backslashes = true;
                code = advance();
                continue;
              }
              if (code === CHAR_RIGHT_PARENTHESES) {
                finished = true;
                break;
              }
            }
            continue;
          }
          break;
        }
        if (isGlob === true) {
          finished = true;
          if (scanToEnd === true) {
            continue;
          }
          break;
        }
      }
      if (opts.noext === true) {
        isExtglob = false;
        isGlob = false;
      }
      let base = str;
      let prefix = "";
      let glob = "";
      if (start > 0) {
        prefix = str.slice(0, start);
        str = str.slice(start);
        lastIndex -= start;
      }
      if (base && isGlob === true && lastIndex > 0) {
        base = str.slice(0, lastIndex);
        glob = str.slice(lastIndex);
      } else if (isGlob === true) {
        base = "";
        glob = str;
      } else {
        base = str;
      }
      if (base && base !== "" && base !== "/" && base !== str) {
        if (isPathSeparator(base.charCodeAt(base.length - 1))) {
          base = base.slice(0, -1);
        }
      }
      if (opts.unescape === true) {
        if (glob) glob = utils.removeBackslashes(glob);
        if (base && backslashes === true) {
          base = utils.removeBackslashes(base);
        }
      }
      const state13 = {
        prefix,
        input,
        start,
        base,
        glob,
        isBrace,
        isBracket,
        isGlob,
        isExtglob,
        isGlobstar,
        negated,
        negatedExtglob
      };
      if (opts.tokens === true) {
        state13.maxDepth = 0;
        if (!isPathSeparator(code)) {
          tokens.push(token);
        }
        state13.tokens = tokens;
      }
      if (opts.parts === true || opts.tokens === true) {
        let prevIndex;
        for (let idx = 0; idx < slashes.length; idx++) {
          const n10 = prevIndex ? prevIndex + 1 : start;
          const i32 = slashes[idx];
          const value = input.slice(n10, i32);
          if (opts.tokens) {
            if (idx === 0 && start !== 0) {
              tokens[idx].isPrefix = true;
              tokens[idx].value = prefix;
            } else {
              tokens[idx].value = value;
            }
            depth(tokens[idx]);
            state13.maxDepth += tokens[idx].depth;
          }
          if (idx !== 0 || value !== "") {
            parts.push(value);
          }
          prevIndex = i32;
        }
        if (prevIndex && prevIndex + 1 < input.length) {
          const value = input.slice(prevIndex + 1);
          parts.push(value);
          if (opts.tokens) {
            tokens[tokens.length - 1].value = value;
            depth(tokens[tokens.length - 1]);
            state13.maxDepth += tokens[tokens.length - 1].depth;
          }
        }
        state13.slashes = slashes;
        state13.parts = parts;
      }
      return state13;
    }, "scan");
    module2.exports = scan;
  }
});

// ../../node_modules/picomatch/lib/parse.js
var require_parse4 = __commonJS({
  "../../node_modules/picomatch/lib/parse.js"(exports2, module2) {
    "use strict";
    var constants3 = require_constants5();
    var utils = require_utils7();
    var {
      MAX_LENGTH,
      POSIX_REGEX_SOURCE,
      REGEX_NON_SPECIAL_CHARS,
      REGEX_SPECIAL_CHARS_BACKREF,
      REPLACEMENTS
    } = constants3;
    var expandRange = /* @__PURE__ */ __name((args, options) => {
      if (typeof options.expandRange === "function") {
        return options.expandRange(...args, options);
      }
      args.sort();
      const value = `[${args.join("-")}]`;
      try {
        new RegExp(value);
      } catch (ex) {
        return args.map((v) => utils.escapeRegex(v)).join("..");
      }
      return value;
    }, "expandRange");
    var syntaxError = /* @__PURE__ */ __name((type, char) => {
      return `Missing ${type}: "${char}" - use "\\\\${char}" to match literal characters`;
    }, "syntaxError");
    var splitTopLevel = /* @__PURE__ */ __name((input) => {
      const parts = [];
      let bracket = 0;
      let paren = 0;
      let quote = 0;
      let value = "";
      let escaped = false;
      for (const ch of input) {
        if (escaped === true) {
          value += ch;
          escaped = false;
          continue;
        }
        if (ch === "\\") {
          value += ch;
          escaped = true;
          continue;
        }
        if (ch === '"') {
          quote = quote === 1 ? 0 : 1;
          value += ch;
          continue;
        }
        if (quote === 0) {
          if (ch === "[") {
            bracket++;
          } else if (ch === "]" && bracket > 0) {
            bracket--;
          } else if (bracket === 0) {
            if (ch === "(") {
              paren++;
            } else if (ch === ")" && paren > 0) {
              paren--;
            } else if (ch === "|" && paren === 0) {
              parts.push(value);
              value = "";
              continue;
            }
          }
        }
        value += ch;
      }
      parts.push(value);
      return parts;
    }, "splitTopLevel");
    var isPlainBranch = /* @__PURE__ */ __name((branch) => {
      let escaped = false;
      for (const ch of branch) {
        if (escaped === true) {
          escaped = false;
          continue;
        }
        if (ch === "\\") {
          escaped = true;
          continue;
        }
        if (/[?*+@!()[\]{}]/.test(ch)) {
          return false;
        }
      }
      return true;
    }, "isPlainBranch");
    var normalizeSimpleBranch = /* @__PURE__ */ __name((branch) => {
      let value = branch.trim();
      let changed = true;
      while (changed === true) {
        changed = false;
        if (/^@\([^\\()[\]{}|]+\)$/.test(value)) {
          value = value.slice(2, -1);
          changed = true;
        }
      }
      if (!isPlainBranch(value)) {
        return;
      }
      return value.replace(/\\(.)/g, "$1");
    }, "normalizeSimpleBranch");
    var hasRepeatedCharPrefixOverlap = /* @__PURE__ */ __name((branches) => {
      const values = branches.map(normalizeSimpleBranch).filter(Boolean);
      for (let i32 = 0; i32 < values.length; i32++) {
        for (let j32 = i32 + 1; j32 < values.length; j32++) {
          const a32 = values[i32];
          const b32 = values[j32];
          const char = a32[0];
          if (!char || a32 !== char.repeat(a32.length) || b32 !== char.repeat(b32.length)) {
            continue;
          }
          if (a32 === b32 || a32.startsWith(b32) || b32.startsWith(a32)) {
            return true;
          }
        }
      }
      return false;
    }, "hasRepeatedCharPrefixOverlap");
    var parseRepeatedExtglob = /* @__PURE__ */ __name((pattern, requireEnd = true) => {
      if (pattern[0] !== "+" && pattern[0] !== "*" || pattern[1] !== "(") {
        return;
      }
      let bracket = 0;
      let paren = 0;
      let quote = 0;
      let escaped = false;
      for (let i32 = 1; i32 < pattern.length; i32++) {
        const ch = pattern[i32];
        if (escaped === true) {
          escaped = false;
          continue;
        }
        if (ch === "\\") {
          escaped = true;
          continue;
        }
        if (ch === '"') {
          quote = quote === 1 ? 0 : 1;
          continue;
        }
        if (quote === 1) {
          continue;
        }
        if (ch === "[") {
          bracket++;
          continue;
        }
        if (ch === "]" && bracket > 0) {
          bracket--;
          continue;
        }
        if (bracket > 0) {
          continue;
        }
        if (ch === "(") {
          paren++;
          continue;
        }
        if (ch === ")") {
          paren--;
          if (paren === 0) {
            if (requireEnd === true && i32 !== pattern.length - 1) {
              return;
            }
            return {
              type: pattern[0],
              body: pattern.slice(2, i32),
              end: i32
            };
          }
        }
      }
    }, "parseRepeatedExtglob");
    var getStarExtglobSequenceOutput = /* @__PURE__ */ __name((pattern) => {
      let index = 0;
      const chars6 = [];
      while (index < pattern.length) {
        const match = parseRepeatedExtglob(pattern.slice(index), false);
        if (!match || match.type !== "*") {
          return;
        }
        const branches = splitTopLevel(match.body).map((branch2) => branch2.trim());
        if (branches.length !== 1) {
          return;
        }
        const branch = normalizeSimpleBranch(branches[0]);
        if (!branch || branch.length !== 1) {
          return;
        }
        chars6.push(branch);
        index += match.end + 1;
      }
      if (chars6.length < 1) {
        return;
      }
      const source = chars6.length === 1 ? utils.escapeRegex(chars6[0]) : `[${chars6.map((ch) => utils.escapeRegex(ch)).join("")}]`;
      return `${source}*`;
    }, "getStarExtglobSequenceOutput");
    var repeatedExtglobRecursion = /* @__PURE__ */ __name((pattern) => {
      let depth = 0;
      let value = pattern.trim();
      let match = parseRepeatedExtglob(value);
      while (match) {
        depth++;
        value = match.body.trim();
        match = parseRepeatedExtglob(value);
      }
      return depth;
    }, "repeatedExtglobRecursion");
    var analyzeRepeatedExtglob = /* @__PURE__ */ __name((body, options) => {
      if (options.maxExtglobRecursion === false) {
        return { risky: false };
      }
      const max = typeof options.maxExtglobRecursion === "number" ? options.maxExtglobRecursion : constants3.DEFAULT_MAX_EXTGLOB_RECURSION;
      const branches = splitTopLevel(body).map((branch) => branch.trim());
      if (branches.length > 1) {
        if (branches.some((branch) => branch === "") || branches.some((branch) => /^[*?]+$/.test(branch)) || hasRepeatedCharPrefixOverlap(branches)) {
          return { risky: true };
        }
      }
      for (const branch of branches) {
        const safeOutput = getStarExtglobSequenceOutput(branch);
        if (safeOutput) {
          return { risky: true, safeOutput };
        }
        if (repeatedExtglobRecursion(branch) > max) {
          return { risky: true };
        }
      }
      return { risky: false };
    }, "analyzeRepeatedExtglob");
    var parse2 = /* @__PURE__ */ __name((input, options) => {
      if (typeof input !== "string") {
        throw new TypeError("Expected a string");
      }
      input = REPLACEMENTS[input] || input;
      const opts = { ...options };
      const max = typeof opts.maxLength === "number" ? Math.min(MAX_LENGTH, opts.maxLength) : MAX_LENGTH;
      let len = input.length;
      if (len > max) {
        throw new SyntaxError(`Input length: ${len}, exceeds maximum allowed length: ${max}`);
      }
      const bos = { type: "bos", value: "", output: opts.prepend || "" };
      const tokens = [bos];
      const capture = opts.capture ? "" : "?:";
      const PLATFORM_CHARS = constants3.globChars(opts.windows);
      const EXTGLOB_CHARS = constants3.extglobChars(PLATFORM_CHARS);
      const {
        DOT_LITERAL,
        PLUS_LITERAL,
        SLASH_LITERAL,
        ONE_CHAR,
        DOTS_SLASH,
        NO_DOT,
        NO_DOT_SLASH,
        NO_DOTS_SLASH,
        QMARK,
        QMARK_NO_DOT,
        STAR,
        START_ANCHOR
      } = PLATFORM_CHARS;
      const globstar = /* @__PURE__ */ __name((opts2) => {
        return `(${capture}(?:(?!${START_ANCHOR}${opts2.dot ? DOTS_SLASH : DOT_LITERAL}).)*?)`;
      }, "globstar");
      const nodot = opts.dot ? "" : NO_DOT;
      const qmarkNoDot = opts.dot ? QMARK : QMARK_NO_DOT;
      let star = opts.bash === true ? globstar(opts) : STAR;
      if (opts.capture) {
        star = `(${star})`;
      }
      if (typeof opts.noext === "boolean") {
        opts.noextglob = opts.noext;
      }
      const state13 = {
        input,
        index: -1,
        start: 0,
        dot: opts.dot === true,
        consumed: "",
        output: "",
        prefix: "",
        backtrack: false,
        negated: false,
        brackets: 0,
        braces: 0,
        parens: 0,
        quotes: 0,
        globstar: false,
        tokens
      };
      input = utils.removePrefix(input, state13);
      len = input.length;
      const extglobs = [];
      const braces = [];
      const stack = [];
      let prev = bos;
      let value;
      const eos = /* @__PURE__ */ __name(() => state13.index === len - 1, "eos");
      const peek = state13.peek = (n10 = 1) => input[state13.index + n10];
      const advance = state13.advance = () => input[++state13.index] || "";
      const remaining = /* @__PURE__ */ __name(() => input.slice(state13.index + 1), "remaining");
      const consume = /* @__PURE__ */ __name((value2 = "", num = 0) => {
        state13.consumed += value2;
        state13.index += num;
      }, "consume");
      const append = /* @__PURE__ */ __name((token) => {
        state13.output += token.output != null ? token.output : token.value;
        consume(token.value);
      }, "append");
      const negate6 = /* @__PURE__ */ __name(() => {
        let count = 1;
        while (peek() === "!" && (peek(2) !== "(" || peek(3) === "?")) {
          advance();
          state13.start++;
          count++;
        }
        if (count % 2 === 0) {
          return false;
        }
        state13.negated = true;
        state13.start++;
        return true;
      }, "negate");
      const increment = /* @__PURE__ */ __name((type) => {
        state13[type]++;
        stack.push(type);
      }, "increment");
      const decrement = /* @__PURE__ */ __name((type) => {
        state13[type]--;
        stack.pop();
      }, "decrement");
      const push = /* @__PURE__ */ __name((tok) => {
        if (prev.type === "globstar") {
          const isBrace = state13.braces > 0 && (tok.type === "comma" || tok.type === "brace");
          const isExtglob = tok.extglob === true || extglobs.length && (tok.type === "pipe" || tok.type === "paren");
          if (tok.type !== "slash" && tok.type !== "paren" && !isBrace && !isExtglob) {
            state13.output = state13.output.slice(0, -prev.output.length);
            prev.type = "star";
            prev.value = "*";
            prev.output = star;
            state13.output += prev.output;
          }
        }
        if (extglobs.length && tok.type !== "paren") {
          extglobs[extglobs.length - 1].inner += tok.value;
        }
        if (tok.value || tok.output) append(tok);
        if (prev && prev.type === "text" && tok.type === "text") {
          prev.output = (prev.output || prev.value) + tok.value;
          prev.value += tok.value;
          return;
        }
        tok.prev = prev;
        tokens.push(tok);
        prev = tok;
      }, "push");
      const extglobOpen = /* @__PURE__ */ __name((type, value2) => {
        const token = { ...EXTGLOB_CHARS[value2], conditions: 1, inner: "" };
        token.prev = prev;
        token.parens = state13.parens;
        token.output = state13.output;
        token.startIndex = state13.index;
        token.tokensIndex = tokens.length;
        const output = (opts.capture ? "(" : "") + token.open;
        increment("parens");
        push({ type, value: value2, output: state13.output ? "" : ONE_CHAR });
        push({ type: "paren", extglob: true, value: advance(), output });
        extglobs.push(token);
      }, "extglobOpen");
      const extglobClose = /* @__PURE__ */ __name((token) => {
        const literal = input.slice(token.startIndex, state13.index + 1);
        const body = input.slice(token.startIndex + 2, state13.index);
        const analysis = analyzeRepeatedExtglob(body, opts);
        if ((token.type === "plus" || token.type === "star") && analysis.risky) {
          const safeOutput = analysis.safeOutput ? (token.output ? "" : ONE_CHAR) + (opts.capture ? `(${analysis.safeOutput})` : analysis.safeOutput) : void 0;
          const open2 = tokens[token.tokensIndex];
          open2.type = "text";
          open2.value = literal;
          open2.output = safeOutput || utils.escapeRegex(literal);
          for (let i32 = token.tokensIndex + 1; i32 < tokens.length; i32++) {
            tokens[i32].value = "";
            tokens[i32].output = "";
            delete tokens[i32].suffix;
          }
          state13.output = token.output + open2.output;
          state13.backtrack = true;
          push({ type: "paren", extglob: true, value, output: "" });
          decrement("parens");
          return;
        }
        let output = token.close + (opts.capture ? ")" : "");
        let rest;
        if (token.type === "negate") {
          let extglobStar = star;
          if (token.inner && token.inner.length > 1 && token.inner.includes("/")) {
            extglobStar = globstar(opts);
          }
          if (extglobStar !== star || eos() || /^\)+$/.test(remaining())) {
            output = token.close = `)$))${extglobStar}`;
          }
          if (token.inner.includes("*") && (rest = remaining()) && /^\.[^\\/.]+$/.test(rest)) {
            const expression = parse2(rest, { ...options, fastpaths: false }).output;
            output = token.close = `)${expression})${extglobStar})`;
          }
          if (token.prev.type === "bos") {
            state13.negatedExtglob = true;
          }
        }
        push({ type: "paren", extglob: true, value, output });
        decrement("parens");
      }, "extglobClose");
      if (opts.fastpaths !== false && !/(^[*!]|[/()[\]{}"])/.test(input)) {
        let backslashes = false;
        let output = input.replace(REGEX_SPECIAL_CHARS_BACKREF, (m20, esc, chars6, first, rest, index) => {
          if (first === "\\") {
            backslashes = true;
            return m20;
          }
          if (first === "?") {
            if (esc) {
              return esc + first + (rest ? QMARK.repeat(rest.length) : "");
            }
            if (index === 0) {
              return qmarkNoDot + (rest ? QMARK.repeat(rest.length) : "");
            }
            return QMARK.repeat(chars6.length);
          }
          if (first === ".") {
            return DOT_LITERAL.repeat(chars6.length);
          }
          if (first === "*") {
            if (esc) {
              return esc + first + (rest ? star : "");
            }
            return star;
          }
          return esc ? m20 : `\\${m20}`;
        });
        if (backslashes === true) {
          if (opts.unescape === true) {
            output = output.replace(/\\/g, "");
          } else {
            output = output.replace(/\\+/g, (m20) => {
              return m20.length % 2 === 0 ? "\\\\" : m20 ? "\\" : "";
            });
          }
        }
        if (output === input && opts.contains === true) {
          state13.output = input;
          return state13;
        }
        state13.output = utils.wrapOutput(output, state13, options);
        return state13;
      }
      while (!eos()) {
        value = advance();
        if (value === "\0") {
          continue;
        }
        if (value === "\\") {
          const next = peek();
          if (next === "/" && opts.bash !== true) {
            continue;
          }
          if (next === "." || next === ";") {
            continue;
          }
          if (!next) {
            value += "\\";
            push({ type: "text", value });
            continue;
          }
          const match = /^\\+/.exec(remaining());
          let slashes = 0;
          if (match && match[0].length > 2) {
            slashes = match[0].length;
            state13.index += slashes;
            if (slashes % 2 !== 0) {
              value += "\\";
            }
          }
          if (opts.unescape === true) {
            value = advance();
          } else {
            value += advance();
          }
          if (state13.brackets === 0) {
            push({ type: "text", value });
            continue;
          }
        }
        if (state13.brackets > 0 && (value !== "]" || prev.value === "[" || prev.value === "[^")) {
          if (opts.posix !== false && value === ":") {
            const inner = prev.value.slice(1);
            if (inner.includes("[")) {
              prev.posix = true;
              if (inner.includes(":")) {
                const idx = prev.value.lastIndexOf("[");
                const pre = prev.value.slice(0, idx);
                const rest2 = prev.value.slice(idx + 2);
                const posix = POSIX_REGEX_SOURCE[rest2];
                if (posix) {
                  prev.value = pre + posix;
                  state13.backtrack = true;
                  advance();
                  if (!bos.output && tokens.indexOf(prev) === 1) {
                    bos.output = ONE_CHAR;
                  }
                  continue;
                }
              }
            }
          }
          if (value === "[" && peek() !== ":" || value === "-" && peek() === "]") {
            value = `\\${value}`;
          }
          if (value === "]" && (prev.value === "[" || prev.value === "[^")) {
            value = `\\${value}`;
          }
          if (opts.posix === true && value === "!" && prev.value === "[") {
            value = "^";
          }
          prev.value += value;
          append({ value });
          continue;
        }
        if (state13.quotes === 1 && value !== '"') {
          value = utils.escapeRegex(value);
          prev.value += value;
          append({ value });
          continue;
        }
        if (value === '"') {
          state13.quotes = state13.quotes === 1 ? 0 : 1;
          if (opts.keepQuotes === true) {
            push({ type: "text", value });
          }
          continue;
        }
        if (value === "(") {
          increment("parens");
          push({ type: "paren", value });
          continue;
        }
        if (value === ")") {
          if (state13.parens === 0 && opts.strictBrackets === true) {
            throw new SyntaxError(syntaxError("opening", "("));
          }
          const extglob = extglobs[extglobs.length - 1];
          if (extglob && state13.parens === extglob.parens + 1) {
            extglobClose(extglobs.pop());
            continue;
          }
          push({ type: "paren", value, output: state13.parens ? ")" : "\\)" });
          decrement("parens");
          continue;
        }
        if (value === "[") {
          if (opts.nobracket === true || !remaining().includes("]")) {
            if (opts.nobracket !== true && opts.strictBrackets === true) {
              throw new SyntaxError(syntaxError("closing", "]"));
            }
            value = `\\${value}`;
          } else {
            increment("brackets");
          }
          push({ type: "bracket", value });
          continue;
        }
        if (value === "]") {
          if (opts.nobracket === true || prev && prev.type === "bracket" && prev.value.length === 1) {
            push({ type: "text", value, output: `\\${value}` });
            continue;
          }
          if (state13.brackets === 0) {
            if (opts.strictBrackets === true) {
              throw new SyntaxError(syntaxError("opening", "["));
            }
            push({ type: "text", value, output: `\\${value}` });
            continue;
          }
          decrement("brackets");
          const prevValue = prev.value.slice(1);
          if (prev.posix !== true && prevValue[0] === "^" && !prevValue.includes("/")) {
            value = `/${value}`;
          }
          prev.value += value;
          append({ value });
          if (opts.literalBrackets === false || utils.hasRegexChars(prevValue)) {
            continue;
          }
          const escaped = utils.escapeRegex(prev.value);
          state13.output = state13.output.slice(0, -prev.value.length);
          if (opts.literalBrackets === true) {
            state13.output += escaped;
            prev.value = escaped;
            continue;
          }
          prev.value = `(${capture}${escaped}|${prev.value})`;
          state13.output += prev.value;
          continue;
        }
        if (value === "{" && opts.nobrace !== true) {
          increment("braces");
          const open2 = {
            type: "brace",
            value,
            output: "(",
            outputIndex: state13.output.length,
            tokensIndex: state13.tokens.length
          };
          braces.push(open2);
          push(open2);
          continue;
        }
        if (value === "}") {
          const brace = braces[braces.length - 1];
          if (opts.nobrace === true || !brace) {
            push({ type: "text", value, output: value });
            continue;
          }
          let output = ")";
          if (brace.dots === true) {
            const arr = tokens.slice();
            const range7 = [];
            for (let i32 = arr.length - 1; i32 >= 0; i32--) {
              tokens.pop();
              if (arr[i32].type === "brace") {
                break;
              }
              if (arr[i32].type !== "dots") {
                range7.unshift(arr[i32].value);
              }
            }
            output = expandRange(range7, opts);
            state13.backtrack = true;
          }
          if (brace.comma !== true && brace.dots !== true) {
            const out = state13.output.slice(0, brace.outputIndex);
            const toks = state13.tokens.slice(brace.tokensIndex);
            brace.value = brace.output = "\\{";
            value = output = "\\}";
            state13.output = out;
            for (const t of toks) {
              state13.output += t.output || t.value;
            }
          }
          push({ type: "brace", value, output });
          decrement("braces");
          braces.pop();
          continue;
        }
        if (value === "|") {
          if (extglobs.length > 0) {
            extglobs[extglobs.length - 1].conditions++;
          }
          push({ type: "text", value });
          continue;
        }
        if (value === ",") {
          let output = value;
          const brace = braces[braces.length - 1];
          if (brace && stack[stack.length - 1] === "braces") {
            brace.comma = true;
            output = "|";
          }
          push({ type: "comma", value, output });
          continue;
        }
        if (value === "/") {
          if (prev.type === "dot" && state13.index === state13.start + 1) {
            state13.start = state13.index + 1;
            state13.consumed = "";
            state13.output = "";
            tokens.pop();
            prev = bos;
            continue;
          }
          push({ type: "slash", value, output: SLASH_LITERAL });
          continue;
        }
        if (value === ".") {
          if (state13.braces > 0 && prev.type === "dot") {
            if (prev.value === ".") prev.output = DOT_LITERAL;
            const brace = braces[braces.length - 1];
            prev.type = "dots";
            prev.output += value;
            prev.value += value;
            brace.dots = true;
            continue;
          }
          if (state13.braces + state13.parens === 0 && prev.type !== "bos" && prev.type !== "slash") {
            push({ type: "text", value, output: DOT_LITERAL });
            continue;
          }
          push({ type: "dot", value, output: DOT_LITERAL });
          continue;
        }
        if (value === "?") {
          const isGroup = prev && prev.value === "(";
          if (!isGroup && opts.noextglob !== true && peek() === "(" && peek(2) !== "?") {
            extglobOpen("qmark", value);
            continue;
          }
          if (prev && prev.type === "paren") {
            const next = peek();
            let output = value;
            if (prev.value === "(" && !/[!=<:]/.test(next) || next === "<" && !/<([!=]|\w+>)/.test(remaining())) {
              output = `\\${value}`;
            }
            push({ type: "text", value, output });
            continue;
          }
          if (opts.dot !== true && (prev.type === "slash" || prev.type === "bos")) {
            push({ type: "qmark", value, output: QMARK_NO_DOT });
            continue;
          }
          push({ type: "qmark", value, output: QMARK });
          continue;
        }
        if (value === "!") {
          if (opts.noextglob !== true && peek() === "(") {
            if (peek(2) !== "?" || !/[!=<:]/.test(peek(3))) {
              extglobOpen("negate", value);
              continue;
            }
          }
          if (opts.nonegate !== true && state13.index === 0) {
            negate6();
            continue;
          }
        }
        if (value === "+") {
          if (opts.noextglob !== true && peek() === "(" && peek(2) !== "?") {
            extglobOpen("plus", value);
            continue;
          }
          if (prev && prev.value === "(" || opts.regex === false) {
            push({ type: "plus", value, output: PLUS_LITERAL });
            continue;
          }
          if (prev && (prev.type === "bracket" || prev.type === "paren" || prev.type === "brace") || state13.parens > 0) {
            push({ type: "plus", value });
            continue;
          }
          push({ type: "plus", value: PLUS_LITERAL });
          continue;
        }
        if (value === "@") {
          if (opts.noextglob !== true && peek() === "(" && peek(2) !== "?") {
            push({ type: "at", extglob: true, value, output: "" });
            continue;
          }
          push({ type: "text", value });
          continue;
        }
        if (value !== "*") {
          if (value === "$" || value === "^") {
            value = `\\${value}`;
          }
          const match = REGEX_NON_SPECIAL_CHARS.exec(remaining());
          if (match) {
            value += match[0];
            state13.index += match[0].length;
          }
          push({ type: "text", value });
          continue;
        }
        if (prev && (prev.type === "globstar" || prev.star === true)) {
          prev.type = "star";
          prev.star = true;
          prev.value += value;
          prev.output = star;
          state13.backtrack = true;
          state13.globstar = true;
          consume(value);
          continue;
        }
        let rest = remaining();
        if (opts.noextglob !== true && /^\([^?]/.test(rest)) {
          extglobOpen("star", value);
          continue;
        }
        if (prev.type === "star") {
          if (opts.noglobstar === true) {
            consume(value);
            continue;
          }
          const prior = prev.prev;
          const before = prior.prev;
          const isStart = prior.type === "slash" || prior.type === "bos";
          const afterStar = before && (before.type === "star" || before.type === "globstar");
          if (opts.bash === true && (!isStart || rest[0] && rest[0] !== "/")) {
            push({ type: "star", value, output: "" });
            continue;
          }
          const isBrace = state13.braces > 0 && (prior.type === "comma" || prior.type === "brace");
          const isExtglob = extglobs.length && (prior.type === "pipe" || prior.type === "paren");
          if (!isStart && prior.type !== "paren" && !isBrace && !isExtglob) {
            push({ type: "star", value, output: "" });
            continue;
          }
          while (rest.slice(0, 3) === "/**") {
            const after = input[state13.index + 4];
            if (after && after !== "/") {
              break;
            }
            rest = rest.slice(3);
            consume("/**", 3);
          }
          if (prior.type === "bos" && eos()) {
            prev.type = "globstar";
            prev.value += value;
            prev.output = globstar(opts);
            state13.output = prev.output;
            state13.globstar = true;
            consume(value);
            continue;
          }
          if (prior.type === "slash" && prior.prev.type !== "bos" && !afterStar && eos()) {
            state13.output = state13.output.slice(0, -(prior.output + prev.output).length);
            prior.output = `(?:${prior.output}`;
            prev.type = "globstar";
            prev.output = globstar(opts) + (opts.strictSlashes ? ")" : "|$)");
            prev.value += value;
            state13.globstar = true;
            state13.output += prior.output + prev.output;
            consume(value);
            continue;
          }
          if (prior.type === "slash" && prior.prev.type !== "bos" && rest[0] === "/") {
            const end = rest[1] !== void 0 ? "|$" : "";
            state13.output = state13.output.slice(0, -(prior.output + prev.output).length);
            prior.output = `(?:${prior.output}`;
            prev.type = "globstar";
            prev.output = `${globstar(opts)}${SLASH_LITERAL}|${SLASH_LITERAL}${end})`;
            prev.value += value;
            state13.output += prior.output + prev.output;
            state13.globstar = true;
            consume(value + advance());
            push({ type: "slash", value: "/", output: "" });
            continue;
          }
          if (prior.type === "bos" && rest[0] === "/") {
            prev.type = "globstar";
            prev.value += value;
            prev.output = `(?:^|${SLASH_LITERAL}|${globstar(opts)}${SLASH_LITERAL})`;
            state13.output = prev.output;
            state13.globstar = true;
            consume(value + advance());
            push({ type: "slash", value: "/", output: "" });
            continue;
          }
          state13.output = state13.output.slice(0, -prev.output.length);
          prev.type = "globstar";
          prev.output = globstar(opts);
          prev.value += value;
          state13.output += prev.output;
          state13.globstar = true;
          consume(value);
          continue;
        }
        const token = { type: "star", value, output: star };
        if (opts.bash === true) {
          token.output = ".*?";
          if (prev.type === "bos" || prev.type === "slash") {
            token.output = nodot + token.output;
          }
          push(token);
          continue;
        }
        if (prev && (prev.type === "bracket" || prev.type === "paren") && opts.regex === true) {
          token.output = value;
          push(token);
          continue;
        }
        if (state13.index === state13.start || prev.type === "slash" || prev.type === "dot") {
          if (prev.type === "dot") {
            state13.output += NO_DOT_SLASH;
            prev.output += NO_DOT_SLASH;
          } else if (opts.dot === true) {
            state13.output += NO_DOTS_SLASH;
            prev.output += NO_DOTS_SLASH;
          } else {
            state13.output += nodot;
            prev.output += nodot;
          }
          if (peek() !== "*") {
            state13.output += ONE_CHAR;
            prev.output += ONE_CHAR;
          }
        }
        push(token);
      }
      while (state13.brackets > 0) {
        if (opts.strictBrackets === true) throw new SyntaxError(syntaxError("closing", "]"));
        state13.output = utils.escapeLast(state13.output, "[");
        decrement("brackets");
      }
      while (state13.parens > 0) {
        if (opts.strictBrackets === true) throw new SyntaxError(syntaxError("closing", ")"));
        state13.output = utils.escapeLast(state13.output, "(");
        decrement("parens");
      }
      while (state13.braces > 0) {
        if (opts.strictBrackets === true) throw new SyntaxError(syntaxError("closing", "}"));
        state13.output = utils.escapeLast(state13.output, "{");
        decrement("braces");
      }
      if (opts.strictSlashes !== true && (prev.type === "star" || prev.type === "bracket")) {
        push({ type: "maybe_slash", value: "", output: `${SLASH_LITERAL}?` });
      }
      if (state13.backtrack === true) {
        state13.output = "";
        for (const token of state13.tokens) {
          state13.output += token.output != null ? token.output : token.value;
          if (token.suffix) {
            state13.output += token.suffix;
          }
        }
      }
      return state13;
    }, "parse");
    parse2.fastpaths = (input, options) => {
      const opts = { ...options };
      const max = typeof opts.maxLength === "number" ? Math.min(MAX_LENGTH, opts.maxLength) : MAX_LENGTH;
      const len = input.length;
      if (len > max) {
        throw new SyntaxError(`Input length: ${len}, exceeds maximum allowed length: ${max}`);
      }
      input = REPLACEMENTS[input] || input;
      const {
        DOT_LITERAL,
        SLASH_LITERAL,
        ONE_CHAR,
        DOTS_SLASH,
        NO_DOT,
        NO_DOTS,
        NO_DOTS_SLASH,
        STAR,
        START_ANCHOR
      } = constants3.globChars(opts.windows);
      const nodot = opts.dot ? NO_DOTS : NO_DOT;
      const slashDot = opts.dot ? NO_DOTS_SLASH : NO_DOT;
      const capture = opts.capture ? "" : "?:";
      const state13 = { negated: false, prefix: "" };
      let star = opts.bash === true ? ".*?" : STAR;
      if (opts.capture) {
        star = `(${star})`;
      }
      const globstar = /* @__PURE__ */ __name((opts2) => {
        if (opts2.noglobstar === true) return star;
        return `(${capture}(?:(?!${START_ANCHOR}${opts2.dot ? DOTS_SLASH : DOT_LITERAL}).)*?)`;
      }, "globstar");
      const create = /* @__PURE__ */ __name((str) => {
        switch (str) {
          case "*":
            return `${nodot}${ONE_CHAR}${star}`;
          case ".*":
            return `${DOT_LITERAL}${ONE_CHAR}${star}`;
          case "*.*":
            return `${nodot}${star}${DOT_LITERAL}${ONE_CHAR}${star}`;
          case "*/*":
            return `${nodot}${star}${SLASH_LITERAL}${ONE_CHAR}${slashDot}${star}`;
          case "**":
            return nodot + globstar(opts);
          case "**/*":
            return `(?:${nodot}${globstar(opts)}${SLASH_LITERAL})?${slashDot}${ONE_CHAR}${star}`;
          case "**/*.*":
            return `(?:${nodot}${globstar(opts)}${SLASH_LITERAL})?${slashDot}${star}${DOT_LITERAL}${ONE_CHAR}${star}`;
          case "**/.*":
            return `(?:${nodot}${globstar(opts)}${SLASH_LITERAL})?${DOT_LITERAL}${ONE_CHAR}${star}`;
          default: {
            const match = /^(.*?)\.(\w+)$/.exec(str);
            if (!match) return;
            const source2 = create(match[1]);
            if (!source2) return;
            return source2 + DOT_LITERAL + match[2];
          }
        }
      }, "create");
      const output = utils.removePrefix(input, state13);
      let source = create(output);
      if (source && opts.strictSlashes !== true) {
        source += `${SLASH_LITERAL}?`;
      }
      return source;
    };
    module2.exports = parse2;
  }
});

// ../../node_modules/picomatch/lib/picomatch.js
var require_picomatch3 = __commonJS({
  "../../node_modules/picomatch/lib/picomatch.js"(exports2, module2) {
    "use strict";
    var scan = require_scan3();
    var parse2 = require_parse4();
    var utils = require_utils7();
    var constants3 = require_constants5();
    var isObject3 = /* @__PURE__ */ __name((val) => val && typeof val === "object" && !Array.isArray(val), "isObject");
    var picomatch6 = /* @__PURE__ */ __name((glob, options, returnState = false) => {
      if (Array.isArray(glob)) {
        const fns = glob.map((input) => picomatch6(input, options, returnState));
        const arrayMatcher = /* @__PURE__ */ __name((str) => {
          for (const isMatch of fns) {
            const state14 = isMatch(str);
            if (state14) return state14;
          }
          return false;
        }, "arrayMatcher");
        return arrayMatcher;
      }
      const isState = isObject3(glob) && glob.tokens && glob.input;
      if (glob === "" || typeof glob !== "string" && !isState) {
        throw new TypeError("Expected pattern to be a non-empty string");
      }
      const opts = options || {};
      const posix = opts.windows;
      const regex = isState ? picomatch6.compileRe(glob, options) : picomatch6.makeRe(glob, options, false, true);
      const state13 = regex.state;
      delete regex.state;
      let isIgnored = /* @__PURE__ */ __name(() => false, "isIgnored");
      if (opts.ignore) {
        const ignoreOpts = { ...options, ignore: null, onMatch: null, onResult: null };
        isIgnored = picomatch6(opts.ignore, ignoreOpts, returnState);
      }
      const matcher = /* @__PURE__ */ __name((input, returnObject = false) => {
        const { isMatch, match, output } = picomatch6.test(input, regex, options, { glob, posix });
        const result2 = { glob, state: state13, regex, posix, input, output, match, isMatch };
        if (typeof opts.onResult === "function") {
          opts.onResult(result2);
        }
        if (isMatch === false) {
          result2.isMatch = false;
          return returnObject ? result2 : false;
        }
        if (isIgnored(input)) {
          if (typeof opts.onIgnore === "function") {
            opts.onIgnore(result2);
          }
          result2.isMatch = false;
          return returnObject ? result2 : false;
        }
        if (typeof opts.onMatch === "function") {
          opts.onMatch(result2);
        }
        return returnObject ? result2 : true;
      }, "matcher");
      if (returnState) {
        matcher.state = state13;
      }
      return matcher;
    }, "picomatch");
    picomatch6.test = (input, regex, options, { glob, posix } = {}) => {
      if (typeof input !== "string") {
        throw new TypeError("Expected input to be a string");
      }
      if (input === "") {
        return { isMatch: false, output: "" };
      }
      const opts = options || {};
      const format32 = opts.format || (posix ? utils.toPosixSlashes : null);
      let match = input === glob;
      let output = match && format32 ? format32(input) : input;
      if (match === false) {
        output = format32 ? format32(input) : input;
        match = output === glob;
      }
      if (match === false || opts.capture === true) {
        if (opts.matchBase === true || opts.basename === true) {
          match = picomatch6.matchBase(input, regex, options, posix);
        } else {
          match = regex.exec(output);
        }
      }
      return { isMatch: Boolean(match), match, output };
    };
    picomatch6.matchBase = (input, glob, options) => {
      const regex = glob instanceof RegExp ? glob : picomatch6.makeRe(glob, options);
      return regex.test(utils.basename(input));
    };
    picomatch6.isMatch = (str, patterns, options) => picomatch6(patterns, options)(str);
    picomatch6.parse = (pattern, options) => {
      if (Array.isArray(pattern)) return pattern.map((p10) => picomatch6.parse(p10, options));
      return parse2(pattern, { ...options, fastpaths: false });
    };
    picomatch6.scan = (input, options) => scan(input, options);
    picomatch6.compileRe = (state13, options, returnOutput = false, returnState = false) => {
      if (returnOutput === true) {
        return state13.output;
      }
      const opts = options || {};
      const prepend = opts.contains ? "" : "^";
      const append = opts.contains ? "" : "$";
      let source = `${prepend}(?:${state13.output})${append}`;
      if (state13 && state13.negated === true) {
        source = `^(?!${source}).*$`;
      }
      const regex = picomatch6.toRegex(source, options);
      if (returnState === true) {
        regex.state = state13;
      }
      return regex;
    };
    picomatch6.makeRe = (input, options = {}, returnOutput = false, returnState = false) => {
      if (!input || typeof input !== "string") {
        throw new TypeError("Expected a non-empty string");
      }
      let parsed = { negated: false, fastpaths: true };
      if (options.fastpaths !== false && (input[0] === "." || input[0] === "*")) {
        parsed.output = parse2.fastpaths(input, options);
      }
      if (!parsed.output) {
        parsed = parse2(input, options);
      }
      return picomatch6.compileRe(parsed, options, returnOutput, returnState);
    };
    picomatch6.toRegex = (source, options) => {
      try {
        const opts = options || {};
        return new RegExp(source, opts.flags || (opts.nocase ? "i" : ""));
      } catch (err) {
        if (options && options.debug === true) throw err;
        return /$^/;
      }
    };
    picomatch6.constants = constants3;
    module2.exports = picomatch6;
  }
});

// ../../node_modules/picomatch/index.js
var require_picomatch4 = __commonJS({
  "../../node_modules/picomatch/index.js"(exports2, module2) {
    "use strict";
    var pico = require_picomatch3();
    var utils = require_utils7();
    function picomatch6(glob, options, returnState = false) {
      if (options && (options.windows === null || options.windows === void 0)) {
        options = { ...options, windows: utils.isWindows() };
      }
      return pico(glob, options, returnState);
    }
    __name(picomatch6, "picomatch");
    Object.assign(picomatch6, pico);
    module2.exports = picomatch6;
  }
});

// ../@aws-cdk/toolkit-lib/lib/util/glob-matcher.ts
function normalizePattern(pattern) {
  if (pattern.includes("*") || pattern.includes("?") || pattern.includes("[")) {
    return pattern;
  }
  const normalized = pattern.replace(/\/+$/, "");
  return `${normalized}/**`;
}
function directoryPrefixGlobs(pattern) {
  const segments = pattern.split("/");
  const prefixes = [];
  for (let i32 = 1; i32 <= segments.length; i32++) {
    prefixes.push(segments.slice(0, i32).join("/"));
  }
  return prefixes;
}
function createIgnoreMatcher(options) {
  const includePatterns = options.include && options.include.length > 0 ? options.include.map(normalizePattern) : ["**"];
  const excludePatterns = (options.exclude ?? []).map(normalizePattern);
  const rootDir = options.rootDir ? options.rootDir.replace(/\\/g, "/").replace(/\/+$/, "") : void 0;
  const picomatchOptions = {
    dot: true
    // Match dotfiles when pattern explicitly includes them
  };
  const includeMatcher = picomatch(includePatterns, picomatchOptions);
  const directoryMatcher = picomatch(includePatterns.flatMap(directoryPrefixGlobs), picomatchOptions);
  const excludeMatcher = excludePatterns.length > 0 ? picomatch(excludePatterns, picomatchOptions) : () => false;
  return (filePath, stats) => {
    let normalizedPath = filePath.replace(/\\/g, "/");
    if (rootDir) {
      if (normalizedPath.startsWith(rootDir + "/")) {
        normalizedPath = normalizedPath.slice(rootDir.length + 1);
      } else if (normalizedPath === rootDir) {
        return false;
      }
    }
    if (excludeMatcher(normalizedPath)) {
      return true;
    }
    if (stats?.isDirectory()) {
      return !directoryMatcher(normalizedPath);
    }
    if (stats?.isFile()) {
      return !includeMatcher(normalizedPath);
    }
    return !(includeMatcher(normalizedPath) || directoryMatcher(normalizedPath));
  };
}
var picomatch;
var init_glob_matcher = __esm({
  "../@aws-cdk/toolkit-lib/lib/util/glob-matcher.ts"() {
    "use strict";
    picomatch = require_picomatch4();
    __name(normalizePattern, "normalizePattern");
    __name(directoryPrefixGlobs, "directoryPrefixGlobs");
    __name(createIgnoreMatcher, "createIgnoreMatcher");
  }
});

// ../@aws-cdk/toolkit-lib/lib/util/guess-language.ts
function languageDisplayName(language) {
  return DISPLAY_NAMES[language] ?? language;
}
async function guessLanguage(dir) {
  try {
    const files = new Set(await listFiles(dir, 2, ["node_modules"]));
    if (files.has("package.json")) {
      const pjContents = JSON.parse(await fs12.readFile(path12.join(dir, "package.json"), "utf-8"));
      const deps = /* @__PURE__ */ new Set([
        ...Object.keys(pjContents.dependencies ?? {}),
        ...Object.keys(pjContents.devDependencies ?? {})
      ]);
      if (deps.has("typescript") || deps.has("ts-node") || deps.has("tsx") || deps.has("swc")) {
        return "typescript";
      } else {
        return "javascript";
      }
    }
    if (files.has("requirements.txt") || files.has("setup.py") || files.has("pyproject.toml")) {
      return "python";
    }
    if (files.has("pom.xml") || files.has("build.xml") || files.has("settings.gradle")) {
      return "java";
    }
    if (Array.from(files).some((n10) => n10.endsWith(".sln") || n10.endsWith(".csproj") || n10.endsWith(".fsproj") || n10.endsWith(".vbproj"))) {
      return "dotnet";
    }
    if (files.has("go.mod")) {
      return "go";
    }
  } catch {
  }
  return void 0;
}
var path12, fs12, DISPLAY_NAMES;
var init_guess_language = __esm({
  "../@aws-cdk/toolkit-lib/lib/util/guess-language.ts"() {
    "use strict";
    path12 = __toESM(require("path"));
    fs12 = __toESM(require_lib4());
    init_directories();
    DISPLAY_NAMES = {
      typescript: "TypeScript",
      javascript: "JavaScript",
      python: "Python",
      java: "Java",
      dotnet: ".NET",
      go: "Go"
    };
    __name(languageDisplayName, "languageDisplayName");
    __name(guessLanguage, "guessLanguage");
  }
});

// ../@aws-cdk/toolkit-lib/lib/util/json.ts
function getResultObj(jsonObject, identifier, propertiesToReturn) {
  const propsObj = {};
  propertiesToReturn.forEach((propName) => {
    Object.assign(propsObj, { [propName]: findJsonValue(jsonObject, propName) });
  });
  Object.assign(propsObj, { ["Identifier"]: identifier });
  return propsObj;
}
function findJsonValue(jsonObject, path47) {
  const paths = path47.split(".");
  let obj = jsonObject;
  paths.forEach((p10) => {
    obj = obj[p10];
    if (obj === void 0) {
      throw new TypeError(`Cannot read field ${path47}. ${p10} is not found.`);
    }
  });
  return obj;
}
var init_json = __esm({
  "../@aws-cdk/toolkit-lib/lib/util/json.ts"() {
    "use strict";
    __name(getResultObj, "getResultObj");
    __name(findJsonValue, "findJsonValue");
  }
});

// ../@aws-cdk/toolkit-lib/lib/util/net.ts
function humanNetworkError(error4) {
  switch (error4.code) {
    case "ENOTFOUND":
      return `Cannot reach the server. Please check your internet connection or the URL (${error4.hostname}).`;
    case "ECONNREFUSED":
      return `Connection refused. The server at ${error4.address}:${error4.port} is not accepting connections.`;
    case "ECONNRESET":
      return "Connection was suddenly closed by the server. Please try again later.";
    case "ETIMEDOUT":
      return "Connection timed out. The server took too long to respond.";
    case "CERT_HAS_EXPIRED":
      return "The SSL certificate of the server has expired. This could be a security risk.";
    case "UNABLE_TO_VERIFY_LEAF_SIGNATURE":
    case "CERT_SIGNATURE_FAILURE":
    case "ERR_TLS_CERT_ALTNAME_INVALID":
      return "SSL certificate validation failed. This could indicate a security issue or a misconfigured server.";
    default:
      return `Network error: ${error4.message || error4.code || "Unknown error"}`;
  }
}
function humanHttpStatusError(statusCode) {
  switch (statusCode) {
    case 400:
      return "Bad request - the server could not understand the request";
    case 401:
      return "Unauthorized - authentication is required";
    case 403:
      return "Forbidden - you do not have permission to access this resource";
    case 404:
      return "Not found - the requested resource does not exist";
    case 408:
      return "Request timeout - the server timed out waiting for the request";
    case 429:
      return "Too many requests - you have sent too many requests in a given amount of time";
    case 500:
      return "Internal server error - something went wrong on the server";
    case 502:
      return "Bad gateway - the server received an invalid response from an upstream server";
    case 503:
      return "Service unavailable - the server is temporarily unable to handle the request";
    case 504:
      return "Gateway timeout - the server did not receive a timely response from an upstream server";
    default:
      return statusCode >= 500 ? "Server error - something went wrong on the server" : "Client error - something went wrong with the request";
  }
}
var init_net = __esm({
  "../@aws-cdk/toolkit-lib/lib/util/net.ts"() {
    "use strict";
    __name(humanNetworkError, "humanNetworkError");
    __name(humanHttpStatusError, "humanHttpStatusError");
  }
});

// ../@aws-cdk/toolkit-lib/lib/util/types.ts
function isObject(x) {
  return x !== null && typeof x === "object" && !isArray(x);
}
var isArray;
var init_types2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/util/types.ts"() {
    "use strict";
    __name(isObject, "isObject");
    isArray = Array.isArray;
  }
});

// ../@aws-cdk/toolkit-lib/lib/util/objects.ts
function deepClone(x) {
  if (typeof x === "undefined") {
    return void 0;
  }
  if (x === null) {
    return null;
  }
  if (isArray(x)) {
    return x.map(deepClone);
  }
  if (isObject(x)) {
    return makeObject(mapObject(x, (k32, v) => [k32, deepClone(v)]));
  }
  return x;
}
function mapObject(x, fn) {
  const ret = [];
  Object.keys(x).forEach((key) => {
    ret.push(fn(key, x[key]));
  });
  return ret;
}
function makeObject(pairs) {
  const ret = {};
  for (const pair of pairs) {
    ret[pair[0]] = pair[1];
  }
  return ret;
}
function deepGet(x, path47) {
  path47 = path47.slice();
  while (path47.length > 0 && isObject(x)) {
    const key = path47.shift();
    x = x[key];
  }
  return path47.length === 0 ? x : void 0;
}
function deepSet(x, path47, value) {
  path47 = path47.slice();
  if (path47.length === 0) {
    throw new ToolkitError("EmptyPath", "Path may not be empty");
  }
  while (path47.length > 1 && isObject(x)) {
    const key = path47.shift();
    if (isPrototypePollutingKey(key)) {
      continue;
    }
    if (!(key in x)) {
      x[key] = {};
    }
    x = x[key];
  }
  if (!isObject(x)) {
    throw new ToolkitError("ExpectedObject", `Expected an object, got '${x}'`);
  }
  const finalKey = path47[0];
  if (isPrototypePollutingKey(finalKey)) {
    return;
  }
  if (value !== void 0) {
    x[finalKey] = value;
  } else {
    delete x[finalKey];
  }
}
function isPrototypePollutingKey(key) {
  return key === "__proto__" || key === "constructor" || key === "prototype";
}
function deepMerge(...objects) {
  function mergeOne(target, source) {
    for (const key of Object.keys(source)) {
      if (isPrototypePollutingKey(key)) {
        continue;
      }
      const value = source[key];
      if (isObject(value)) {
        if (!isObject(target[key])) {
          target[key] = {};
        }
        mergeOne(target[key], value);
      } else if (typeof value !== "undefined") {
        target[key] = value;
      }
    }
  }
  __name(mergeOne, "mergeOne");
  const others = objects.filter((x) => x != null);
  if (others.length === 0) {
    return {};
  }
  const into = others.splice(0, 1)[0];
  others.forEach((other) => mergeOne(into, other));
  return into;
}
function splitBySize(data3, maxSizeBytes) {
  if (maxSizeBytes < 2) {
    return [void 0, data3];
  }
  const entries = Object.entries(data3);
  return recurse(0, 0);
  function recurse(index, runningTotalSize) {
    if (index >= entries.length) {
      return [data3, void 0];
    }
    const size = runningTotalSize + entrySize(entries[index]);
    return size > maxSizeBytes ? cutAt(index) : recurse(index + 1, size);
  }
  __name(recurse, "recurse");
  function entrySize(entry) {
    return Buffer.byteLength(JSON.stringify(Object.fromEntries([entry])));
  }
  __name(entrySize, "entrySize");
  function cutAt(index) {
    return [
      Object.fromEntries(entries.slice(0, index)),
      Object.fromEntries(entries.slice(index))
    ];
  }
  __name(cutAt, "cutAt");
}
function transformObjectKeys(val, transform, exclude = {}) {
  if (val == null || typeof val !== "object") {
    return val;
  }
  if (Array.isArray(val)) {
    return val.map((input) => transformObjectKeys(input, transform, exclude));
  }
  const ret = {};
  for (const [k32, v] of Object.entries(val)) {
    const childExclude = exclude[k32];
    if (childExclude === true) {
      ret[transform(k32)] = v;
    } else {
      ret[transform(k32)] = transformObjectKeys(v, transform, childExclude);
    }
  }
  return ret;
}
function noUndefined(xs) {
  return Object.fromEntries(Object.entries(xs).filter(([_, v]) => v !== void 0));
}
var init_objects = __esm({
  "../@aws-cdk/toolkit-lib/lib/util/objects.ts"() {
    "use strict";
    init_types2();
    init_toolkit_error();
    __name(deepClone, "deepClone");
    __name(mapObject, "mapObject");
    __name(makeObject, "makeObject");
    __name(deepGet, "deepGet");
    __name(deepSet, "deepSet");
    __name(isPrototypePollutingKey, "isPrototypePollutingKey");
    __name(deepMerge, "deepMerge");
    __name(splitBySize, "splitBySize");
    __name(transformObjectKeys, "transformObjectKeys");
    __name(noUndefined, "noUndefined");
  }
});

// ../@aws-cdk/toolkit-lib/lib/util/parallel.ts
async function parallelPromises(n10, promises5) {
  const ret = new Array();
  let count = 0;
  let error4;
  const queue = [...promises5];
  return new Promise((ok, ko) => {
    tick();
    function tick() {
      if (count === 0 && error4) {
        ko(error4);
        return;
      }
      if (count === 0 && queue.length === 0) {
        ok(ret);
        return;
      }
      while (count < n10 && queue.length > 0 && !error4) {
        const next = queue.shift();
        if (next !== void 0) {
          start(next);
        }
      }
    }
    __name(tick, "tick");
    function start(fn) {
      count += 1;
      fn().then((result2) => {
        ret.push(result2);
      }).catch((e32) => {
        error4 = e32;
      }).finally(() => {
        count -= 1;
        tick();
      });
    }
    __name(start, "start");
  });
}
var init_parallel = __esm({
  "../@aws-cdk/toolkit-lib/lib/util/parallel.ts"() {
    "use strict";
    __name(parallelPromises, "parallelPromises");
  }
});

// ../@aws-cdk/toolkit-lib/lib/util/package-info.ts
function versionNumber() {
  return require(path13.join(bundledPackageRootDir(__dirname), "package.json")).version.replace(/\+[0-9a-f]+$/, "");
}
var path13;
var init_package_info = __esm({
  "../@aws-cdk/toolkit-lib/lib/util/package-info.ts"() {
    "use strict";
    path13 = __toESM(require("path"));
    init_directories();
    __name(versionNumber, "versionNumber");
  }
});

// ../../node_modules/yaml/dist/PlainValue-516d5bc2.js
var require_PlainValue_516d5bc2 = __commonJS({
  "../../node_modules/yaml/dist/PlainValue-516d5bc2.js"(exports2) {
    "use strict";
    var Char = {
      ANCHOR: "&",
      COMMENT: "#",
      TAG: "!",
      DIRECTIVES_END: "-",
      DOCUMENT_END: "."
    };
    var Type = {
      ALIAS: "ALIAS",
      BLANK_LINE: "BLANK_LINE",
      BLOCK_FOLDED: "BLOCK_FOLDED",
      BLOCK_LITERAL: "BLOCK_LITERAL",
      COMMENT: "COMMENT",
      DIRECTIVE: "DIRECTIVE",
      DOCUMENT: "DOCUMENT",
      FLOW_MAP: "FLOW_MAP",
      FLOW_SEQ: "FLOW_SEQ",
      MAP: "MAP",
      MAP_KEY: "MAP_KEY",
      MAP_VALUE: "MAP_VALUE",
      PLAIN: "PLAIN",
      QUOTE_DOUBLE: "QUOTE_DOUBLE",
      QUOTE_SINGLE: "QUOTE_SINGLE",
      SEQ: "SEQ",
      SEQ_ITEM: "SEQ_ITEM"
    };
    var defaultTagPrefix = "tag:yaml.org,2002:";
    var defaultTags = {
      MAP: "tag:yaml.org,2002:map",
      SEQ: "tag:yaml.org,2002:seq",
      STR: "tag:yaml.org,2002:str"
    };
    function findLineStarts(src) {
      const ls = [0];
      let offset = src.indexOf("\n");
      while (offset !== -1) {
        offset += 1;
        ls.push(offset);
        offset = src.indexOf("\n", offset);
      }
      return ls;
    }
    __name(findLineStarts, "findLineStarts");
    function getSrcInfo(cst) {
      let lineStarts, src;
      if (typeof cst === "string") {
        lineStarts = findLineStarts(cst);
        src = cst;
      } else {
        if (Array.isArray(cst)) cst = cst[0];
        if (cst && cst.context) {
          if (!cst.lineStarts) cst.lineStarts = findLineStarts(cst.context.src);
          lineStarts = cst.lineStarts;
          src = cst.context.src;
        }
      }
      return {
        lineStarts,
        src
      };
    }
    __name(getSrcInfo, "getSrcInfo");
    function getLinePos(offset, cst) {
      if (typeof offset !== "number" || offset < 0) return null;
      const {
        lineStarts,
        src
      } = getSrcInfo(cst);
      if (!lineStarts || !src || offset > src.length) return null;
      for (let i32 = 0; i32 < lineStarts.length; ++i32) {
        const start = lineStarts[i32];
        if (offset < start) {
          return {
            line: i32,
            col: offset - lineStarts[i32 - 1] + 1
          };
        }
        if (offset === start) return {
          line: i32 + 1,
          col: 1
        };
      }
      const line = lineStarts.length;
      return {
        line,
        col: offset - lineStarts[line - 1] + 1
      };
    }
    __name(getLinePos, "getLinePos");
    function getLine(line, cst) {
      const {
        lineStarts,
        src
      } = getSrcInfo(cst);
      if (!lineStarts || !(line >= 1) || line > lineStarts.length) return null;
      const start = lineStarts[line - 1];
      let end = lineStarts[line];
      while (end && end > start && src[end - 1] === "\n") --end;
      return src.slice(start, end);
    }
    __name(getLine, "getLine");
    function getPrettyContext({
      start,
      end
    }, cst, maxWidth = 80) {
      let src = getLine(start.line, cst);
      if (!src) return null;
      let {
        col
      } = start;
      if (src.length > maxWidth) {
        if (col <= maxWidth - 10) {
          src = src.substr(0, maxWidth - 1) + "\u2026";
        } else {
          const halfWidth = Math.round(maxWidth / 2);
          if (src.length > col + halfWidth) src = src.substr(0, col + halfWidth - 1) + "\u2026";
          col -= src.length - maxWidth;
          src = "\u2026" + src.substr(1 - maxWidth);
        }
      }
      let errLen = 1;
      let errEnd = "";
      if (end) {
        if (end.line === start.line && col + (end.col - start.col) <= maxWidth + 1) {
          errLen = end.col - start.col;
        } else {
          errLen = Math.min(src.length + 1, maxWidth) - col;
          errEnd = "\u2026";
        }
      }
      const offset = col > 1 ? " ".repeat(col - 1) : "";
      const err = "^".repeat(errLen);
      return `${src}
${offset}${err}${errEnd}`;
    }
    __name(getPrettyContext, "getPrettyContext");
    var Range = class _Range {
      static {
        __name(this, "Range");
      }
      static copy(orig) {
        return new _Range(orig.start, orig.end);
      }
      constructor(start, end) {
        this.start = start;
        this.end = end || start;
      }
      isEmpty() {
        return typeof this.start !== "number" || !this.end || this.end <= this.start;
      }
      /**
       * Set `origStart` and `origEnd` to point to the original source range for
       * this node, which may differ due to dropped CR characters.
       *
       * @param {number[]} cr - Positions of dropped CR characters
       * @param {number} offset - Starting index of `cr` from the last call
       * @returns {number} - The next offset, matching the one found for `origStart`
       */
      setOrigRange(cr, offset) {
        const {
          start,
          end
        } = this;
        if (cr.length === 0 || end <= cr[0]) {
          this.origStart = start;
          this.origEnd = end;
          return offset;
        }
        let i32 = offset;
        while (i32 < cr.length) {
          if (cr[i32] > start) break;
          else ++i32;
        }
        this.origStart = start + i32;
        const nextOffset = i32;
        while (i32 < cr.length) {
          if (cr[i32] >= end) break;
          else ++i32;
        }
        this.origEnd = end + i32;
        return nextOffset;
      }
    };
    var Node2 = class _Node {
      static {
        __name(this, "Node");
      }
      static addStringTerminator(src, offset, str) {
        if (str[str.length - 1] === "\n") return str;
        const next = _Node.endOfWhiteSpace(src, offset);
        return next >= src.length || src[next] === "\n" ? str + "\n" : str;
      }
      // ^(---|...)
      static atDocumentBoundary(src, offset, sep7) {
        const ch0 = src[offset];
        if (!ch0) return true;
        const prev = src[offset - 1];
        if (prev && prev !== "\n") return false;
        if (sep7) {
          if (ch0 !== sep7) return false;
        } else {
          if (ch0 !== Char.DIRECTIVES_END && ch0 !== Char.DOCUMENT_END) return false;
        }
        const ch1 = src[offset + 1];
        const ch2 = src[offset + 2];
        if (ch1 !== ch0 || ch2 !== ch0) return false;
        const ch3 = src[offset + 3];
        return !ch3 || ch3 === "\n" || ch3 === "	" || ch3 === " ";
      }
      static endOfIdentifier(src, offset) {
        let ch = src[offset];
        const isVerbatim = ch === "<";
        const notOk = isVerbatim ? ["\n", "	", " ", ">"] : ["\n", "	", " ", "[", "]", "{", "}", ","];
        while (ch && notOk.indexOf(ch) === -1) ch = src[offset += 1];
        if (isVerbatim && ch === ">") offset += 1;
        return offset;
      }
      static endOfIndent(src, offset) {
        let ch = src[offset];
        while (ch === " ") ch = src[offset += 1];
        return offset;
      }
      static endOfLine(src, offset) {
        let ch = src[offset];
        while (ch && ch !== "\n") ch = src[offset += 1];
        return offset;
      }
      static endOfWhiteSpace(src, offset) {
        let ch = src[offset];
        while (ch === "	" || ch === " ") ch = src[offset += 1];
        return offset;
      }
      static startOfLine(src, offset) {
        let ch = src[offset - 1];
        if (ch === "\n") return offset;
        while (ch && ch !== "\n") ch = src[offset -= 1];
        return offset + 1;
      }
      /**
       * End of indentation, or null if the line's indent level is not more
       * than `indent`
       *
       * @param {string} src
       * @param {number} indent
       * @param {number} lineStart
       * @returns {?number}
       */
      static endOfBlockIndent(src, indent, lineStart) {
        const inEnd = _Node.endOfIndent(src, lineStart);
        if (inEnd > lineStart + indent) {
          return inEnd;
        } else {
          const wsEnd = _Node.endOfWhiteSpace(src, inEnd);
          const ch = src[wsEnd];
          if (!ch || ch === "\n") return wsEnd;
        }
        return null;
      }
      static atBlank(src, offset, endAsBlank) {
        const ch = src[offset];
        return ch === "\n" || ch === "	" || ch === " " || endAsBlank && !ch;
      }
      static nextNodeIsIndented(ch, indentDiff, indicatorAsIndent) {
        if (!ch || indentDiff < 0) return false;
        if (indentDiff > 0) return true;
        return indicatorAsIndent && ch === "-";
      }
      // should be at line or string end, or at next non-whitespace char
      static normalizeOffset(src, offset) {
        const ch = src[offset];
        return !ch ? offset : ch !== "\n" && src[offset - 1] === "\n" ? offset - 1 : _Node.endOfWhiteSpace(src, offset);
      }
      // fold single newline into space, multiple newlines to N - 1 newlines
      // presumes src[offset] === '\n'
      static foldNewline(src, offset, indent) {
        let inCount = 0;
        let error4 = false;
        let fold = "";
        let ch = src[offset + 1];
        while (ch === " " || ch === "	" || ch === "\n") {
          switch (ch) {
            case "\n":
              inCount = 0;
              offset += 1;
              fold += "\n";
              break;
            case "	":
              if (inCount <= indent) error4 = true;
              offset = _Node.endOfWhiteSpace(src, offset + 2) - 1;
              break;
            case " ":
              inCount += 1;
              offset += 1;
              break;
          }
          ch = src[offset + 1];
        }
        if (!fold) fold = " ";
        if (ch && inCount <= indent) error4 = true;
        return {
          fold,
          offset,
          error: error4
        };
      }
      constructor(type, props, context) {
        Object.defineProperty(this, "context", {
          value: context || null,
          writable: true
        });
        this.error = null;
        this.range = null;
        this.valueRange = null;
        this.props = props || [];
        this.type = type;
        this.value = null;
      }
      getPropValue(idx, key, skipKey) {
        if (!this.context) return null;
        const {
          src
        } = this.context;
        const prop = this.props[idx];
        return prop && src[prop.start] === key ? src.slice(prop.start + (skipKey ? 1 : 0), prop.end) : null;
      }
      get anchor() {
        for (let i32 = 0; i32 < this.props.length; ++i32) {
          const anchor = this.getPropValue(i32, Char.ANCHOR, true);
          if (anchor != null) return anchor;
        }
        return null;
      }
      get comment() {
        const comments = [];
        for (let i32 = 0; i32 < this.props.length; ++i32) {
          const comment = this.getPropValue(i32, Char.COMMENT, true);
          if (comment != null) comments.push(comment);
        }
        return comments.length > 0 ? comments.join("\n") : null;
      }
      commentHasRequiredWhitespace(start) {
        const {
          src
        } = this.context;
        if (this.header && start === this.header.end) return false;
        if (!this.valueRange) return false;
        const {
          end
        } = this.valueRange;
        return start !== end || _Node.atBlank(src, end - 1);
      }
      get hasComment() {
        if (this.context) {
          const {
            src
          } = this.context;
          for (let i32 = 0; i32 < this.props.length; ++i32) {
            if (src[this.props[i32].start] === Char.COMMENT) return true;
          }
        }
        return false;
      }
      get hasProps() {
        if (this.context) {
          const {
            src
          } = this.context;
          for (let i32 = 0; i32 < this.props.length; ++i32) {
            if (src[this.props[i32].start] !== Char.COMMENT) return true;
          }
        }
        return false;
      }
      get includesTrailingLines() {
        return false;
      }
      get jsonLike() {
        const jsonLikeTypes = [Type.FLOW_MAP, Type.FLOW_SEQ, Type.QUOTE_DOUBLE, Type.QUOTE_SINGLE];
        return jsonLikeTypes.indexOf(this.type) !== -1;
      }
      get rangeAsLinePos() {
        if (!this.range || !this.context) return void 0;
        const start = getLinePos(this.range.start, this.context.root);
        if (!start) return void 0;
        const end = getLinePos(this.range.end, this.context.root);
        return {
          start,
          end
        };
      }
      get rawValue() {
        if (!this.valueRange || !this.context) return null;
        const {
          start,
          end
        } = this.valueRange;
        return this.context.src.slice(start, end);
      }
      get tag() {
        for (let i32 = 0; i32 < this.props.length; ++i32) {
          const tag3 = this.getPropValue(i32, Char.TAG, false);
          if (tag3 != null) {
            if (tag3[1] === "<") {
              return {
                verbatim: tag3.slice(2, -1)
              };
            } else {
              const [_, handle, suffix] = tag3.match(/^(.*!)([^!]*)$/);
              return {
                handle,
                suffix
              };
            }
          }
        }
        return null;
      }
      get valueRangeContainsNewline() {
        if (!this.valueRange || !this.context) return false;
        const {
          start,
          end
        } = this.valueRange;
        const {
          src
        } = this.context;
        for (let i32 = start; i32 < end; ++i32) {
          if (src[i32] === "\n") return true;
        }
        return false;
      }
      parseComment(start) {
        const {
          src
        } = this.context;
        if (src[start] === Char.COMMENT) {
          const end = _Node.endOfLine(src, start + 1);
          const commentRange = new Range(start, end);
          this.props.push(commentRange);
          return end;
        }
        return start;
      }
      /**
       * Populates the `origStart` and `origEnd` values of all ranges for this
       * node. Extended by child classes to handle descendant nodes.
       *
       * @param {number[]} cr - Positions of dropped CR characters
       * @param {number} offset - Starting index of `cr` from the last call
       * @returns {number} - The next offset, matching the one found for `origStart`
       */
      setOrigRanges(cr, offset) {
        if (this.range) offset = this.range.setOrigRange(cr, offset);
        if (this.valueRange) this.valueRange.setOrigRange(cr, offset);
        this.props.forEach((prop) => prop.setOrigRange(cr, offset));
        return offset;
      }
      toString() {
        const {
          context: {
            src
          },
          range: range7,
          value
        } = this;
        if (value != null) return value;
        const str = src.slice(range7.start, range7.end);
        return _Node.addStringTerminator(src, range7.end, str);
      }
    };
    var YAMLError = class extends Error {
      static {
        __name(this, "YAMLError");
      }
      constructor(name, source, message2) {
        if (!message2 || !(source instanceof Node2)) throw new Error(`Invalid arguments for new ${name}`);
        super();
        this.name = name;
        this.message = message2;
        this.source = source;
      }
      makePretty() {
        if (!this.source) return;
        this.nodeType = this.source.type;
        const cst = this.source.context && this.source.context.root;
        if (typeof this.offset === "number") {
          this.range = new Range(this.offset, this.offset + 1);
          const start = cst && getLinePos(this.offset, cst);
          if (start) {
            const end = {
              line: start.line,
              col: start.col + 1
            };
            this.linePos = {
              start,
              end
            };
          }
          delete this.offset;
        } else {
          this.range = this.source.range;
          this.linePos = this.source.rangeAsLinePos;
        }
        if (this.linePos) {
          const {
            line,
            col
          } = this.linePos.start;
          this.message += ` at line ${line}, column ${col}`;
          const ctx = cst && getPrettyContext(this.linePos, cst);
          if (ctx) this.message += `:

${ctx}
`;
        }
        delete this.source;
      }
    };
    var YAMLReferenceError = class extends YAMLError {
      static {
        __name(this, "YAMLReferenceError");
      }
      constructor(source, message2) {
        super("YAMLReferenceError", source, message2);
      }
    };
    var YAMLSemanticError = class extends YAMLError {
      static {
        __name(this, "YAMLSemanticError");
      }
      constructor(source, message2) {
        super("YAMLSemanticError", source, message2);
      }
    };
    var YAMLSyntaxError = class extends YAMLError {
      static {
        __name(this, "YAMLSyntaxError");
      }
      constructor(source, message2) {
        super("YAMLSyntaxError", source, message2);
      }
    };
    var YAMLWarning = class extends YAMLError {
      static {
        __name(this, "YAMLWarning");
      }
      constructor(source, message2) {
        super("YAMLWarning", source, message2);
      }
    };
    function _defineProperty(e32, r32, t) {
      return (r32 = _toPropertyKey(r32)) in e32 ? Object.defineProperty(e32, r32, {
        value: t,
        enumerable: true,
        configurable: true,
        writable: true
      }) : e32[r32] = t, e32;
    }
    __name(_defineProperty, "_defineProperty");
    function _toPrimitive(t, r32) {
      if ("object" != typeof t || !t) return t;
      var e32 = t[Symbol.toPrimitive];
      if (void 0 !== e32) {
        var i32 = e32.call(t, r32 || "default");
        if ("object" != typeof i32) return i32;
        throw new TypeError("@@toPrimitive must return a primitive value.");
      }
      return ("string" === r32 ? String : Number)(t);
    }
    __name(_toPrimitive, "_toPrimitive");
    function _toPropertyKey(t) {
      var i32 = _toPrimitive(t, "string");
      return "symbol" == typeof i32 ? i32 : i32 + "";
    }
    __name(_toPropertyKey, "_toPropertyKey");
    var PlainValue = class _PlainValue extends Node2 {
      static {
        __name(this, "PlainValue");
      }
      static endOfLine(src, start, inFlow) {
        let ch = src[start];
        let offset = start;
        while (ch && ch !== "\n") {
          if (inFlow && (ch === "[" || ch === "]" || ch === "{" || ch === "}" || ch === ",")) break;
          const next = src[offset + 1];
          if (ch === ":" && (!next || next === "\n" || next === "	" || next === " " || inFlow && next === ",")) break;
          if ((ch === " " || ch === "	") && next === "#") break;
          offset += 1;
          ch = next;
        }
        return offset;
      }
      get strValue() {
        if (!this.valueRange || !this.context) return null;
        let {
          start,
          end
        } = this.valueRange;
        const {
          src
        } = this.context;
        let ch = src[end - 1];
        while (start < end && (ch === "\n" || ch === "	" || ch === " ")) ch = src[--end - 1];
        let str = "";
        for (let i32 = start; i32 < end; ++i32) {
          const ch2 = src[i32];
          if (ch2 === "\n") {
            const {
              fold,
              offset
            } = Node2.foldNewline(src, i32, -1);
            str += fold;
            i32 = offset;
          } else if (ch2 === " " || ch2 === "	") {
            const wsStart = i32;
            let next = src[i32 + 1];
            while (i32 < end && (next === " " || next === "	")) {
              i32 += 1;
              next = src[i32 + 1];
            }
            if (next !== "\n") str += i32 > wsStart ? src.slice(wsStart, i32 + 1) : ch2;
          } else {
            str += ch2;
          }
        }
        const ch0 = src[start];
        switch (ch0) {
          case "	": {
            const msg = "Plain value cannot start with a tab character";
            const errors = [new YAMLSemanticError(this, msg)];
            return {
              errors,
              str
            };
          }
          case "@":
          case "`": {
            const msg = `Plain value cannot start with reserved character ${ch0}`;
            const errors = [new YAMLSemanticError(this, msg)];
            return {
              errors,
              str
            };
          }
          default:
            return str;
        }
      }
      parseBlockValue(start) {
        const {
          indent,
          inFlow,
          src
        } = this.context;
        let offset = start;
        let valueEnd = start;
        for (let ch = src[offset]; ch === "\n"; ch = src[offset]) {
          if (Node2.atDocumentBoundary(src, offset + 1)) break;
          const end = Node2.endOfBlockIndent(src, indent, offset + 1);
          if (end === null || src[end] === "#") break;
          if (src[end] === "\n") {
            offset = end;
          } else {
            valueEnd = _PlainValue.endOfLine(src, end, inFlow);
            offset = valueEnd;
          }
        }
        if (this.valueRange.isEmpty()) this.valueRange.start = start;
        this.valueRange.end = valueEnd;
        return valueEnd;
      }
      /**
       * Parses a plain value from the source
       *
       * Accepted forms are:
       * ```
       * #comment
       *
       * first line
       *
       * first line #comment
       *
       * first line
       * block
       * lines
       *
       * #comment
       * block
       * lines
       * ```
       * where block lines are empty or have an indent level greater than `indent`.
       *
       * @param {ParseContext} context
       * @param {number} start - Index of first character
       * @returns {number} - Index of the character after this scalar, may be `\n`
       */
      parse(context, start) {
        this.context = context;
        const {
          inFlow,
          src
        } = context;
        let offset = start;
        const ch = src[offset];
        if (ch && ch !== "#" && ch !== "\n") {
          offset = _PlainValue.endOfLine(src, start, inFlow);
        }
        this.valueRange = new Range(start, offset);
        offset = Node2.endOfWhiteSpace(src, offset);
        offset = this.parseComment(offset);
        if (!this.hasComment || this.valueRange.isEmpty()) {
          offset = this.parseBlockValue(offset);
        }
        return offset;
      }
    };
    exports2.Char = Char;
    exports2.Node = Node2;
    exports2.PlainValue = PlainValue;
    exports2.Range = Range;
    exports2.Type = Type;
    exports2.YAMLError = YAMLError;
    exports2.YAMLReferenceError = YAMLReferenceError;
    exports2.YAMLSemanticError = YAMLSemanticError;
    exports2.YAMLSyntaxError = YAMLSyntaxError;
    exports2.YAMLWarning = YAMLWarning;
    exports2._defineProperty = _defineProperty;
    exports2.defaultTagPrefix = defaultTagPrefix;
    exports2.defaultTags = defaultTags;
  }
});

// ../../node_modules/yaml/dist/parse-cst.js
var require_parse_cst = __commonJS({
  "../../node_modules/yaml/dist/parse-cst.js"(exports2) {
    "use strict";
    var PlainValue = require_PlainValue_516d5bc2();
    var BlankLine = class extends PlainValue.Node {
      static {
        __name(this, "BlankLine");
      }
      constructor() {
        super(PlainValue.Type.BLANK_LINE);
      }
      /* istanbul ignore next */
      get includesTrailingLines() {
        return true;
      }
      /**
       * Parses a blank line from the source
       *
       * @param {ParseContext} context
       * @param {number} start - Index of first \n character
       * @returns {number} - Index of the character after this
       */
      parse(context, start) {
        this.context = context;
        this.range = new PlainValue.Range(start, start + 1);
        return start + 1;
      }
    };
    var CollectionItem = class extends PlainValue.Node {
      static {
        __name(this, "CollectionItem");
      }
      constructor(type, props) {
        super(type, props);
        this.node = null;
      }
      get includesTrailingLines() {
        return !!this.node && this.node.includesTrailingLines;
      }
      /**
       * @param {ParseContext} context
       * @param {number} start - Index of first character
       * @returns {number} - Index of the character after this
       */
      parse(context, start) {
        this.context = context;
        const {
          parseNode,
          src
        } = context;
        let {
          atLineStart,
          lineStart
        } = context;
        if (!atLineStart && this.type === PlainValue.Type.SEQ_ITEM) this.error = new PlainValue.YAMLSemanticError(this, "Sequence items must not have preceding content on the same line");
        const indent = atLineStart ? start - lineStart : context.indent;
        let offset = PlainValue.Node.endOfWhiteSpace(src, start + 1);
        let ch = src[offset];
        const inlineComment = ch === "#";
        const comments = [];
        let blankLine = null;
        while (ch === "\n" || ch === "#") {
          if (ch === "#") {
            const end2 = PlainValue.Node.endOfLine(src, offset + 1);
            comments.push(new PlainValue.Range(offset, end2));
            offset = end2;
          } else {
            atLineStart = true;
            lineStart = offset + 1;
            const wsEnd = PlainValue.Node.endOfWhiteSpace(src, lineStart);
            if (src[wsEnd] === "\n" && comments.length === 0) {
              blankLine = new BlankLine();
              lineStart = blankLine.parse({
                src
              }, lineStart);
            }
            offset = PlainValue.Node.endOfIndent(src, lineStart);
          }
          ch = src[offset];
        }
        if (PlainValue.Node.nextNodeIsIndented(ch, offset - (lineStart + indent), this.type !== PlainValue.Type.SEQ_ITEM)) {
          this.node = parseNode({
            atLineStart,
            inCollection: false,
            indent,
            lineStart,
            parent: this
          }, offset);
        } else if (ch && lineStart > start + 1) {
          offset = lineStart - 1;
        }
        if (this.node) {
          if (blankLine) {
            const items = context.parent.items || context.parent.contents;
            if (items) items.push(blankLine);
          }
          if (comments.length) Array.prototype.push.apply(this.props, comments);
          offset = this.node.range.end;
        } else {
          if (inlineComment) {
            const c32 = comments[0];
            this.props.push(c32);
            offset = c32.end;
          } else {
            offset = PlainValue.Node.endOfLine(src, start + 1);
          }
        }
        const end = this.node ? this.node.valueRange.end : offset;
        this.valueRange = new PlainValue.Range(start, end);
        return offset;
      }
      setOrigRanges(cr, offset) {
        offset = super.setOrigRanges(cr, offset);
        return this.node ? this.node.setOrigRanges(cr, offset) : offset;
      }
      toString() {
        const {
          context: {
            src
          },
          node,
          range: range7,
          value
        } = this;
        if (value != null) return value;
        const str = node ? src.slice(range7.start, node.range.start) + String(node) : src.slice(range7.start, range7.end);
        return PlainValue.Node.addStringTerminator(src, range7.end, str);
      }
    };
    var Comment = class extends PlainValue.Node {
      static {
        __name(this, "Comment");
      }
      constructor() {
        super(PlainValue.Type.COMMENT);
      }
      /**
       * Parses a comment line from the source
       *
       * @param {ParseContext} context
       * @param {number} start - Index of first character
       * @returns {number} - Index of the character after this scalar
       */
      parse(context, start) {
        this.context = context;
        const offset = this.parseComment(start);
        this.range = new PlainValue.Range(start, offset);
        return offset;
      }
    };
    function grabCollectionEndComments(node) {
      let cnode = node;
      while (cnode instanceof CollectionItem) cnode = cnode.node;
      if (!(cnode instanceof Collection2)) return null;
      const len = cnode.items.length;
      let ci = -1;
      for (let i32 = len - 1; i32 >= 0; --i32) {
        const n10 = cnode.items[i32];
        if (n10.type === PlainValue.Type.COMMENT) {
          const {
            indent,
            lineStart
          } = n10.context;
          if (indent > 0 && n10.range.start >= lineStart + indent) break;
          ci = i32;
        } else if (n10.type === PlainValue.Type.BLANK_LINE) ci = i32;
        else break;
      }
      if (ci === -1) return null;
      const ca = cnode.items.splice(ci, len - ci);
      const prevEnd = ca[0].range.start;
      while (true) {
        cnode.range.end = prevEnd;
        if (cnode.valueRange && cnode.valueRange.end > prevEnd) cnode.valueRange.end = prevEnd;
        if (cnode === node) break;
        cnode = cnode.context.parent;
      }
      return ca;
    }
    __name(grabCollectionEndComments, "grabCollectionEndComments");
    var Collection2 = class _Collection extends PlainValue.Node {
      static {
        __name(this, "Collection");
      }
      static nextContentHasIndent(src, offset, indent) {
        const lineStart = PlainValue.Node.endOfLine(src, offset) + 1;
        offset = PlainValue.Node.endOfWhiteSpace(src, lineStart);
        const ch = src[offset];
        if (!ch) return false;
        if (offset >= lineStart + indent) return true;
        if (ch !== "#" && ch !== "\n") return false;
        return _Collection.nextContentHasIndent(src, offset, indent);
      }
      constructor(firstItem) {
        super(firstItem.type === PlainValue.Type.SEQ_ITEM ? PlainValue.Type.SEQ : PlainValue.Type.MAP);
        for (let i32 = firstItem.props.length - 1; i32 >= 0; --i32) {
          if (firstItem.props[i32].start < firstItem.context.lineStart) {
            this.props = firstItem.props.slice(0, i32 + 1);
            firstItem.props = firstItem.props.slice(i32 + 1);
            const itemRange = firstItem.props[0] || firstItem.valueRange;
            firstItem.range.start = itemRange.start;
            break;
          }
        }
        this.items = [firstItem];
        const ec = grabCollectionEndComments(firstItem);
        if (ec) Array.prototype.push.apply(this.items, ec);
      }
      get includesTrailingLines() {
        return this.items.length > 0;
      }
      /**
       * @param {ParseContext} context
       * @param {number} start - Index of first character
       * @returns {number} - Index of the character after this
       */
      parse(context, start) {
        this.context = context;
        const {
          parseNode,
          src
        } = context;
        let lineStart = PlainValue.Node.startOfLine(src, start);
        const firstItem = this.items[0];
        firstItem.context.parent = this;
        this.valueRange = PlainValue.Range.copy(firstItem.valueRange);
        const indent = firstItem.range.start - firstItem.context.lineStart;
        let offset = start;
        offset = PlainValue.Node.normalizeOffset(src, offset);
        let ch = src[offset];
        let atLineStart = PlainValue.Node.endOfWhiteSpace(src, lineStart) === offset;
        let prevIncludesTrailingLines = false;
        while (ch) {
          while (ch === "\n" || ch === "#") {
            if (atLineStart && ch === "\n" && !prevIncludesTrailingLines) {
              const blankLine = new BlankLine();
              offset = blankLine.parse({
                src
              }, offset);
              this.valueRange.end = offset;
              if (offset >= src.length) {
                ch = null;
                break;
              }
              this.items.push(blankLine);
              offset -= 1;
            } else if (ch === "#") {
              if (offset < lineStart + indent && !_Collection.nextContentHasIndent(src, offset, indent)) {
                return offset;
              }
              const comment = new Comment();
              offset = comment.parse({
                indent,
                lineStart,
                src
              }, offset);
              this.items.push(comment);
              this.valueRange.end = offset;
              if (offset >= src.length) {
                ch = null;
                break;
              }
            }
            lineStart = offset + 1;
            offset = PlainValue.Node.endOfIndent(src, lineStart);
            if (PlainValue.Node.atBlank(src, offset)) {
              const wsEnd = PlainValue.Node.endOfWhiteSpace(src, offset);
              const next = src[wsEnd];
              if (!next || next === "\n" || next === "#") {
                offset = wsEnd;
              }
            }
            ch = src[offset];
            atLineStart = true;
          }
          if (!ch) {
            break;
          }
          if (offset !== lineStart + indent && (atLineStart || ch !== ":")) {
            if (offset < lineStart + indent) {
              if (lineStart > start) offset = lineStart;
              break;
            } else if (!this.error) {
              const msg = "All collection items must start at the same column";
              this.error = new PlainValue.YAMLSyntaxError(this, msg);
            }
          }
          if (firstItem.type === PlainValue.Type.SEQ_ITEM) {
            if (ch !== "-") {
              if (lineStart > start) offset = lineStart;
              break;
            }
          } else if (ch === "-" && !this.error) {
            const next = src[offset + 1];
            if (!next || next === "\n" || next === "	" || next === " ") {
              const msg = "A collection cannot be both a mapping and a sequence";
              this.error = new PlainValue.YAMLSyntaxError(this, msg);
            }
          }
          const node = parseNode({
            atLineStart,
            inCollection: true,
            indent,
            lineStart,
            parent: this
          }, offset);
          if (!node) return offset;
          this.items.push(node);
          this.valueRange.end = node.valueRange.end;
          offset = PlainValue.Node.normalizeOffset(src, node.range.end);
          ch = src[offset];
          atLineStart = false;
          prevIncludesTrailingLines = node.includesTrailingLines;
          if (ch) {
            let ls = offset - 1;
            let prev = src[ls];
            while (prev === " " || prev === "	") prev = src[--ls];
            if (prev === "\n") {
              lineStart = ls + 1;
              atLineStart = true;
            }
          }
          const ec = grabCollectionEndComments(node);
          if (ec) Array.prototype.push.apply(this.items, ec);
        }
        return offset;
      }
      setOrigRanges(cr, offset) {
        offset = super.setOrigRanges(cr, offset);
        this.items.forEach((node) => {
          offset = node.setOrigRanges(cr, offset);
        });
        return offset;
      }
      toString() {
        const {
          context: {
            src
          },
          items,
          range: range7,
          value
        } = this;
        if (value != null) return value;
        let str = src.slice(range7.start, items[0].range.start) + String(items[0]);
        for (let i32 = 1; i32 < items.length; ++i32) {
          const item = items[i32];
          const {
            atLineStart,
            indent
          } = item.context;
          if (atLineStart) for (let i33 = 0; i33 < indent; ++i33) str += " ";
          str += String(item);
        }
        return PlainValue.Node.addStringTerminator(src, range7.end, str);
      }
    };
    var Directive = class extends PlainValue.Node {
      static {
        __name(this, "Directive");
      }
      constructor() {
        super(PlainValue.Type.DIRECTIVE);
        this.name = null;
      }
      get parameters() {
        const raw = this.rawValue;
        return raw ? raw.trim().split(/[ \t]+/) : [];
      }
      parseName(start) {
        const {
          src
        } = this.context;
        let offset = start;
        let ch = src[offset];
        while (ch && ch !== "\n" && ch !== "	" && ch !== " ") ch = src[offset += 1];
        this.name = src.slice(start, offset);
        return offset;
      }
      parseParameters(start) {
        const {
          src
        } = this.context;
        let offset = start;
        let ch = src[offset];
        while (ch && ch !== "\n" && ch !== "#") ch = src[offset += 1];
        this.valueRange = new PlainValue.Range(start, offset);
        return offset;
      }
      parse(context, start) {
        this.context = context;
        let offset = this.parseName(start + 1);
        offset = this.parseParameters(offset);
        offset = this.parseComment(offset);
        this.range = new PlainValue.Range(start, offset);
        return offset;
      }
    };
    var Document = class _Document extends PlainValue.Node {
      static {
        __name(this, "Document");
      }
      static startCommentOrEndBlankLine(src, start) {
        const offset = PlainValue.Node.endOfWhiteSpace(src, start);
        const ch = src[offset];
        return ch === "#" || ch === "\n" ? offset : start;
      }
      constructor() {
        super(PlainValue.Type.DOCUMENT);
        this.directives = null;
        this.contents = null;
        this.directivesEndMarker = null;
        this.documentEndMarker = null;
      }
      parseDirectives(start) {
        const {
          src
        } = this.context;
        this.directives = [];
        let atLineStart = true;
        let hasDirectives = false;
        let offset = start;
        while (!PlainValue.Node.atDocumentBoundary(src, offset, PlainValue.Char.DIRECTIVES_END)) {
          offset = _Document.startCommentOrEndBlankLine(src, offset);
          switch (src[offset]) {
            case "\n":
              if (atLineStart) {
                const blankLine = new BlankLine();
                offset = blankLine.parse({
                  src
                }, offset);
                if (offset < src.length) {
                  this.directives.push(blankLine);
                }
              } else {
                offset += 1;
                atLineStart = true;
              }
              break;
            case "#":
              {
                const comment = new Comment();
                offset = comment.parse({
                  src
                }, offset);
                this.directives.push(comment);
                atLineStart = false;
              }
              break;
            case "%":
              {
                const directive = new Directive();
                offset = directive.parse({
                  parent: this,
                  src
                }, offset);
                this.directives.push(directive);
                hasDirectives = true;
                atLineStart = false;
              }
              break;
            default:
              if (hasDirectives) {
                this.error = new PlainValue.YAMLSemanticError(this, "Missing directives-end indicator line");
              } else if (this.directives.length > 0) {
                this.contents = this.directives;
                this.directives = [];
              }
              return offset;
          }
        }
        if (src[offset]) {
          this.directivesEndMarker = new PlainValue.Range(offset, offset + 3);
          return offset + 3;
        }
        if (hasDirectives) {
          this.error = new PlainValue.YAMLSemanticError(this, "Missing directives-end indicator line");
        } else if (this.directives.length > 0) {
          this.contents = this.directives;
          this.directives = [];
        }
        return offset;
      }
      parseContents(start) {
        const {
          parseNode,
          src
        } = this.context;
        if (!this.contents) this.contents = [];
        let lineStart = start;
        while (src[lineStart - 1] === "-") lineStart -= 1;
        let offset = PlainValue.Node.endOfWhiteSpace(src, start);
        let atLineStart = lineStart === start;
        this.valueRange = new PlainValue.Range(offset);
        while (!PlainValue.Node.atDocumentBoundary(src, offset, PlainValue.Char.DOCUMENT_END)) {
          switch (src[offset]) {
            case "\n":
              if (atLineStart) {
                const blankLine = new BlankLine();
                offset = blankLine.parse({
                  src
                }, offset);
                if (offset < src.length) {
                  this.contents.push(blankLine);
                }
              } else {
                offset += 1;
                atLineStart = true;
              }
              lineStart = offset;
              break;
            case "#":
              {
                const comment = new Comment();
                offset = comment.parse({
                  src
                }, offset);
                this.contents.push(comment);
                atLineStart = false;
              }
              break;
            default: {
              const iEnd = PlainValue.Node.endOfIndent(src, offset);
              const context = {
                atLineStart,
                indent: -1,
                inFlow: false,
                inCollection: false,
                lineStart,
                parent: this
              };
              const node = parseNode(context, iEnd);
              if (!node) return this.valueRange.end = iEnd;
              this.contents.push(node);
              offset = node.range.end;
              atLineStart = false;
              const ec = grabCollectionEndComments(node);
              if (ec) Array.prototype.push.apply(this.contents, ec);
            }
          }
          offset = _Document.startCommentOrEndBlankLine(src, offset);
        }
        this.valueRange.end = offset;
        if (src[offset]) {
          this.documentEndMarker = new PlainValue.Range(offset, offset + 3);
          offset += 3;
          if (src[offset]) {
            offset = PlainValue.Node.endOfWhiteSpace(src, offset);
            if (src[offset] === "#") {
              const comment = new Comment();
              offset = comment.parse({
                src
              }, offset);
              this.contents.push(comment);
            }
            switch (src[offset]) {
              case "\n":
                offset += 1;
                break;
              case void 0:
                break;
              default:
                this.error = new PlainValue.YAMLSyntaxError(this, "Document end marker line cannot have a non-comment suffix");
            }
          }
        }
        return offset;
      }
      /**
       * @param {ParseContext} context
       * @param {number} start - Index of first character
       * @returns {number} - Index of the character after this
       */
      parse(context, start) {
        context.root = this;
        this.context = context;
        const {
          src
        } = context;
        let offset = src.charCodeAt(start) === 65279 ? start + 1 : start;
        offset = this.parseDirectives(offset);
        offset = this.parseContents(offset);
        return offset;
      }
      setOrigRanges(cr, offset) {
        offset = super.setOrigRanges(cr, offset);
        this.directives.forEach((node) => {
          offset = node.setOrigRanges(cr, offset);
        });
        if (this.directivesEndMarker) offset = this.directivesEndMarker.setOrigRange(cr, offset);
        this.contents.forEach((node) => {
          offset = node.setOrigRanges(cr, offset);
        });
        if (this.documentEndMarker) offset = this.documentEndMarker.setOrigRange(cr, offset);
        return offset;
      }
      toString() {
        const {
          contents,
          directives,
          value
        } = this;
        if (value != null) return value;
        let str = directives.join("");
        if (contents.length > 0) {
          if (directives.length > 0 || contents[0].type === PlainValue.Type.COMMENT) str += "---\n";
          str += contents.join("");
        }
        if (str[str.length - 1] !== "\n") str += "\n";
        return str;
      }
    };
    var Alias2 = class extends PlainValue.Node {
      static {
        __name(this, "Alias");
      }
      /**
       * Parses an *alias from the source
       *
       * @param {ParseContext} context
       * @param {number} start - Index of first character
       * @returns {number} - Index of the character after this scalar
       */
      parse(context, start) {
        this.context = context;
        const {
          src
        } = context;
        let offset = PlainValue.Node.endOfIdentifier(src, start + 1);
        this.valueRange = new PlainValue.Range(start + 1, offset);
        offset = PlainValue.Node.endOfWhiteSpace(src, offset);
        offset = this.parseComment(offset);
        return offset;
      }
    };
    var Chomp = {
      CLIP: "CLIP",
      KEEP: "KEEP",
      STRIP: "STRIP"
    };
    var BlockValue = class extends PlainValue.Node {
      static {
        __name(this, "BlockValue");
      }
      constructor(type, props) {
        super(type, props);
        this.blockIndent = null;
        this.chomping = Chomp.CLIP;
        this.header = null;
      }
      get includesTrailingLines() {
        return this.chomping === Chomp.KEEP;
      }
      get strValue() {
        if (!this.valueRange || !this.context) return null;
        let {
          start,
          end
        } = this.valueRange;
        const {
          indent,
          src
        } = this.context;
        if (this.valueRange.isEmpty()) return "";
        let lastNewLine = null;
        let ch = src[end - 1];
        while (ch === "\n" || ch === "	" || ch === " ") {
          end -= 1;
          if (end <= start) {
            if (this.chomping === Chomp.KEEP) break;
            else return "";
          }
          if (ch === "\n") lastNewLine = end;
          ch = src[end - 1];
        }
        let keepStart = end + 1;
        if (lastNewLine) {
          if (this.chomping === Chomp.KEEP) {
            keepStart = lastNewLine;
            end = this.valueRange.end;
          } else {
            end = lastNewLine;
          }
        }
        const bi = indent + this.blockIndent;
        const folded = this.type === PlainValue.Type.BLOCK_FOLDED;
        let atStart = true;
        let str = "";
        let sep7 = "";
        let prevMoreIndented = false;
        for (let i32 = start; i32 < end; ++i32) {
          for (let j32 = 0; j32 < bi; ++j32) {
            if (src[i32] !== " ") break;
            i32 += 1;
          }
          const ch2 = src[i32];
          if (ch2 === "\n") {
            if (sep7 === "\n") str += "\n";
            else sep7 = "\n";
          } else {
            const lineEnd = PlainValue.Node.endOfLine(src, i32);
            const line = src.slice(i32, lineEnd);
            i32 = lineEnd;
            if (folded && (ch2 === " " || ch2 === "	") && i32 < keepStart) {
              if (sep7 === " ") sep7 = "\n";
              else if (!prevMoreIndented && !atStart && sep7 === "\n") sep7 = "\n\n";
              str += sep7 + line;
              sep7 = lineEnd < end && src[lineEnd] || "";
              prevMoreIndented = true;
            } else {
              str += sep7 + line;
              sep7 = folded && i32 < keepStart ? " " : "\n";
              prevMoreIndented = false;
            }
            if (atStart && line !== "") atStart = false;
          }
        }
        return this.chomping === Chomp.STRIP ? str : str + "\n";
      }
      parseBlockHeader(start) {
        const {
          src
        } = this.context;
        let offset = start + 1;
        let bi = "";
        while (true) {
          const ch = src[offset];
          switch (ch) {
            case "-":
              this.chomping = Chomp.STRIP;
              break;
            case "+":
              this.chomping = Chomp.KEEP;
              break;
            case "0":
            case "1":
            case "2":
            case "3":
            case "4":
            case "5":
            case "6":
            case "7":
            case "8":
            case "9":
              bi += ch;
              break;
            default:
              this.blockIndent = Number(bi) || null;
              this.header = new PlainValue.Range(start, offset);
              return offset;
          }
          offset += 1;
        }
      }
      parseBlockValue(start) {
        const {
          indent,
          src
        } = this.context;
        const explicit = !!this.blockIndent;
        let offset = start;
        let valueEnd = start;
        let minBlockIndent = 1;
        for (let ch = src[offset]; ch === "\n"; ch = src[offset]) {
          offset += 1;
          if (PlainValue.Node.atDocumentBoundary(src, offset)) break;
          const end = PlainValue.Node.endOfBlockIndent(src, indent, offset);
          if (end === null) break;
          const ch2 = src[end];
          const lineIndent = end - (offset + indent);
          if (!this.blockIndent) {
            if (src[end] !== "\n") {
              if (lineIndent < minBlockIndent) {
                const msg = "Block scalars with more-indented leading empty lines must use an explicit indentation indicator";
                this.error = new PlainValue.YAMLSemanticError(this, msg);
              }
              this.blockIndent = lineIndent;
            } else if (lineIndent > minBlockIndent) {
              minBlockIndent = lineIndent;
            }
          } else if (ch2 && ch2 !== "\n" && lineIndent < this.blockIndent) {
            if (src[end] === "#") break;
            if (!this.error) {
              const src2 = explicit ? "explicit indentation indicator" : "first line";
              const msg = `Block scalars must not be less indented than their ${src2}`;
              this.error = new PlainValue.YAMLSemanticError(this, msg);
            }
          }
          if (src[end] === "\n") {
            offset = end;
          } else {
            offset = valueEnd = PlainValue.Node.endOfLine(src, end);
          }
        }
        if (this.chomping !== Chomp.KEEP) {
          offset = src[valueEnd] ? valueEnd + 1 : valueEnd;
        }
        this.valueRange = new PlainValue.Range(start + 1, offset);
        return offset;
      }
      /**
       * Parses a block value from the source
       *
       * Accepted forms are:
       * ```
       * BS
       * block
       * lines
       *
       * BS #comment
       * block
       * lines
       * ```
       * where the block style BS matches the regexp `[|>][-+1-9]*` and block lines
       * are empty or have an indent level greater than `indent`.
       *
       * @param {ParseContext} context
       * @param {number} start - Index of first character
       * @returns {number} - Index of the character after this block
       */
      parse(context, start) {
        this.context = context;
        const {
          src
        } = context;
        let offset = this.parseBlockHeader(start);
        offset = PlainValue.Node.endOfWhiteSpace(src, offset);
        offset = this.parseComment(offset);
        offset = this.parseBlockValue(offset);
        return offset;
      }
      setOrigRanges(cr, offset) {
        offset = super.setOrigRanges(cr, offset);
        return this.header ? this.header.setOrigRange(cr, offset) : offset;
      }
    };
    var FlowCollection = class extends PlainValue.Node {
      static {
        __name(this, "FlowCollection");
      }
      constructor(type, props) {
        super(type, props);
        this.items = null;
      }
      prevNodeIsJsonLike(idx = this.items.length) {
        const node = this.items[idx - 1];
        return !!node && (node.jsonLike || node.type === PlainValue.Type.COMMENT && this.prevNodeIsJsonLike(idx - 1));
      }
      /**
       * @param {ParseContext} context
       * @param {number} start - Index of first character
       * @returns {number} - Index of the character after this
       */
      parse(context, start) {
        this.context = context;
        const {
          parseNode,
          src
        } = context;
        let {
          indent,
          lineStart
        } = context;
        let char = src[start];
        this.items = [{
          char,
          offset: start
        }];
        let offset = PlainValue.Node.endOfWhiteSpace(src, start + 1);
        char = src[offset];
        while (char && char !== "]" && char !== "}") {
          switch (char) {
            case "\n":
              {
                lineStart = offset + 1;
                const wsEnd = PlainValue.Node.endOfWhiteSpace(src, lineStart);
                if (src[wsEnd] === "\n") {
                  const blankLine = new BlankLine();
                  lineStart = blankLine.parse({
                    src
                  }, lineStart);
                  this.items.push(blankLine);
                }
                offset = PlainValue.Node.endOfIndent(src, lineStart);
                if (offset <= lineStart + indent) {
                  char = src[offset];
                  if (offset < lineStart + indent || char !== "]" && char !== "}") {
                    const msg = "Insufficient indentation in flow collection";
                    this.error = new PlainValue.YAMLSemanticError(this, msg);
                  }
                }
              }
              break;
            case ",":
              {
                this.items.push({
                  char,
                  offset
                });
                offset += 1;
              }
              break;
            case "#":
              {
                const comment = new Comment();
                offset = comment.parse({
                  src
                }, offset);
                this.items.push(comment);
              }
              break;
            case "?":
            case ":": {
              const next = src[offset + 1];
              if (next === "\n" || next === "	" || next === " " || next === "," || // in-flow : after JSON-like key does not need to be followed by whitespace
              char === ":" && this.prevNodeIsJsonLike()) {
                this.items.push({
                  char,
                  offset
                });
                offset += 1;
                break;
              }
            }
            // fallthrough
            default: {
              const node = parseNode({
                atLineStart: false,
                inCollection: false,
                inFlow: true,
                indent: -1,
                lineStart,
                parent: this
              }, offset);
              if (!node) {
                this.valueRange = new PlainValue.Range(start, offset);
                return offset;
              }
              this.items.push(node);
              offset = PlainValue.Node.normalizeOffset(src, node.range.end);
            }
          }
          offset = PlainValue.Node.endOfWhiteSpace(src, offset);
          char = src[offset];
        }
        this.valueRange = new PlainValue.Range(start, offset + 1);
        if (char) {
          this.items.push({
            char,
            offset
          });
          offset = PlainValue.Node.endOfWhiteSpace(src, offset + 1);
          offset = this.parseComment(offset);
        }
        return offset;
      }
      setOrigRanges(cr, offset) {
        offset = super.setOrigRanges(cr, offset);
        this.items.forEach((node) => {
          if (node instanceof PlainValue.Node) {
            offset = node.setOrigRanges(cr, offset);
          } else if (cr.length === 0) {
            node.origOffset = node.offset;
          } else {
            let i32 = offset;
            while (i32 < cr.length) {
              if (cr[i32] > node.offset) break;
              else ++i32;
            }
            node.origOffset = node.offset + i32;
            offset = i32;
          }
        });
        return offset;
      }
      toString() {
        const {
          context: {
            src
          },
          items,
          range: range7,
          value
        } = this;
        if (value != null) return value;
        const nodes32 = items.filter((item) => item instanceof PlainValue.Node);
        let str = "";
        let prevEnd = range7.start;
        nodes32.forEach((node) => {
          const prefix = src.slice(prevEnd, node.range.start);
          prevEnd = node.range.end;
          str += prefix + String(node);
          if (str[str.length - 1] === "\n" && src[prevEnd - 1] !== "\n" && src[prevEnd] === "\n") {
            prevEnd += 1;
          }
        });
        str += src.slice(prevEnd, range7.end);
        return PlainValue.Node.addStringTerminator(src, range7.end, str);
      }
    };
    var QuoteDouble = class _QuoteDouble extends PlainValue.Node {
      static {
        __name(this, "QuoteDouble");
      }
      static endOfQuote(src, offset) {
        let ch = src[offset];
        while (ch && ch !== '"') {
          offset += ch === "\\" ? 2 : 1;
          ch = src[offset];
        }
        return offset + 1;
      }
      /**
       * @returns {string | { str: string, errors: YAMLSyntaxError[] }}
       */
      get strValue() {
        if (!this.valueRange || !this.context) return null;
        const errors = [];
        const {
          start,
          end
        } = this.valueRange;
        const {
          indent,
          src
        } = this.context;
        if (src[end - 1] !== '"') errors.push(new PlainValue.YAMLSyntaxError(this, 'Missing closing "quote'));
        let str = "";
        for (let i32 = start + 1; i32 < end - 1; ++i32) {
          const ch = src[i32];
          if (ch === "\n") {
            if (PlainValue.Node.atDocumentBoundary(src, i32 + 1)) errors.push(new PlainValue.YAMLSemanticError(this, "Document boundary indicators are not allowed within string values"));
            const {
              fold,
              offset,
              error: error4
            } = PlainValue.Node.foldNewline(src, i32, indent);
            str += fold;
            i32 = offset;
            if (error4) errors.push(new PlainValue.YAMLSemanticError(this, "Multi-line double-quoted string needs to be sufficiently indented"));
          } else if (ch === "\\") {
            i32 += 1;
            switch (src[i32]) {
              case "0":
                str += "\0";
                break;
              // null character
              case "a":
                str += "\x07";
                break;
              // bell character
              case "b":
                str += "\b";
                break;
              // backspace
              case "e":
                str += "\x1B";
                break;
              // escape character
              case "f":
                str += "\f";
                break;
              // form feed
              case "n":
                str += "\n";
                break;
              // line feed
              case "r":
                str += "\r";
                break;
              // carriage return
              case "t":
                str += "	";
                break;
              // horizontal tab
              case "v":
                str += "\v";
                break;
              // vertical tab
              case "N":
                str += "\x85";
                break;
              // Unicode next line
              case "_":
                str += "\xA0";
                break;
              // Unicode non-breaking space
              case "L":
                str += "\u2028";
                break;
              // Unicode line separator
              case "P":
                str += "\u2029";
                break;
              // Unicode paragraph separator
              case " ":
                str += " ";
                break;
              case '"':
                str += '"';
                break;
              case "/":
                str += "/";
                break;
              case "\\":
                str += "\\";
                break;
              case "	":
                str += "	";
                break;
              case "x":
                str += this.parseCharCode(i32 + 1, 2, errors);
                i32 += 2;
                break;
              case "u":
                str += this.parseCharCode(i32 + 1, 4, errors);
                i32 += 4;
                break;
              case "U":
                str += this.parseCharCode(i32 + 1, 8, errors);
                i32 += 8;
                break;
              case "\n":
                while (src[i32 + 1] === " " || src[i32 + 1] === "	") i32 += 1;
                break;
              default:
                errors.push(new PlainValue.YAMLSyntaxError(this, `Invalid escape sequence ${src.substr(i32 - 1, 2)}`));
                str += "\\" + src[i32];
            }
          } else if (ch === " " || ch === "	") {
            const wsStart = i32;
            let next = src[i32 + 1];
            while (next === " " || next === "	") {
              i32 += 1;
              next = src[i32 + 1];
            }
            if (next !== "\n") str += i32 > wsStart ? src.slice(wsStart, i32 + 1) : ch;
          } else {
            str += ch;
          }
        }
        return errors.length > 0 ? {
          errors,
          str
        } : str;
      }
      parseCharCode(offset, length, errors) {
        const {
          src
        } = this.context;
        const cc = src.substr(offset, length);
        const ok = cc.length === length && /^[0-9a-fA-F]+$/.test(cc);
        const code = ok ? parseInt(cc, 16) : NaN;
        if (isNaN(code)) {
          errors.push(new PlainValue.YAMLSyntaxError(this, `Invalid escape sequence ${src.substr(offset - 2, length + 2)}`));
          return src.substr(offset - 2, length + 2);
        }
        return String.fromCodePoint(code);
      }
      /**
       * Parses a "double quoted" value from the source
       *
       * @param {ParseContext} context
       * @param {number} start - Index of first character
       * @returns {number} - Index of the character after this scalar
       */
      parse(context, start) {
        this.context = context;
        const {
          src
        } = context;
        let offset = _QuoteDouble.endOfQuote(src, start + 1);
        this.valueRange = new PlainValue.Range(start, offset);
        offset = PlainValue.Node.endOfWhiteSpace(src, offset);
        offset = this.parseComment(offset);
        return offset;
      }
    };
    var QuoteSingle = class _QuoteSingle extends PlainValue.Node {
      static {
        __name(this, "QuoteSingle");
      }
      static endOfQuote(src, offset) {
        let ch = src[offset];
        while (ch) {
          if (ch === "'") {
            if (src[offset + 1] !== "'") break;
            ch = src[offset += 2];
          } else {
            ch = src[offset += 1];
          }
        }
        return offset + 1;
      }
      /**
       * @returns {string | { str: string, errors: YAMLSyntaxError[] }}
       */
      get strValue() {
        if (!this.valueRange || !this.context) return null;
        const errors = [];
        const {
          start,
          end
        } = this.valueRange;
        const {
          indent,
          src
        } = this.context;
        if (src[end - 1] !== "'") errors.push(new PlainValue.YAMLSyntaxError(this, "Missing closing 'quote"));
        let str = "";
        for (let i32 = start + 1; i32 < end - 1; ++i32) {
          const ch = src[i32];
          if (ch === "\n") {
            if (PlainValue.Node.atDocumentBoundary(src, i32 + 1)) errors.push(new PlainValue.YAMLSemanticError(this, "Document boundary indicators are not allowed within string values"));
            const {
              fold,
              offset,
              error: error4
            } = PlainValue.Node.foldNewline(src, i32, indent);
            str += fold;
            i32 = offset;
            if (error4) errors.push(new PlainValue.YAMLSemanticError(this, "Multi-line single-quoted string needs to be sufficiently indented"));
          } else if (ch === "'") {
            str += ch;
            i32 += 1;
            if (src[i32] !== "'") errors.push(new PlainValue.YAMLSyntaxError(this, "Unescaped single quote? This should not happen."));
          } else if (ch === " " || ch === "	") {
            const wsStart = i32;
            let next = src[i32 + 1];
            while (next === " " || next === "	") {
              i32 += 1;
              next = src[i32 + 1];
            }
            if (next !== "\n") str += i32 > wsStart ? src.slice(wsStart, i32 + 1) : ch;
          } else {
            str += ch;
          }
        }
        return errors.length > 0 ? {
          errors,
          str
        } : str;
      }
      /**
       * Parses a 'single quoted' value from the source
       *
       * @param {ParseContext} context
       * @param {number} start - Index of first character
       * @returns {number} - Index of the character after this scalar
       */
      parse(context, start) {
        this.context = context;
        const {
          src
        } = context;
        let offset = _QuoteSingle.endOfQuote(src, start + 1);
        this.valueRange = new PlainValue.Range(start, offset);
        offset = PlainValue.Node.endOfWhiteSpace(src, offset);
        offset = this.parseComment(offset);
        return offset;
      }
    };
    function createNewNode(type, props) {
      switch (type) {
        case PlainValue.Type.ALIAS:
          return new Alias2(type, props);
        case PlainValue.Type.BLOCK_FOLDED:
        case PlainValue.Type.BLOCK_LITERAL:
          return new BlockValue(type, props);
        case PlainValue.Type.FLOW_MAP:
        case PlainValue.Type.FLOW_SEQ:
          return new FlowCollection(type, props);
        case PlainValue.Type.MAP_KEY:
        case PlainValue.Type.MAP_VALUE:
        case PlainValue.Type.SEQ_ITEM:
          return new CollectionItem(type, props);
        case PlainValue.Type.COMMENT:
        case PlainValue.Type.PLAIN:
          return new PlainValue.PlainValue(type, props);
        case PlainValue.Type.QUOTE_DOUBLE:
          return new QuoteDouble(type, props);
        case PlainValue.Type.QUOTE_SINGLE:
          return new QuoteSingle(type, props);
        /* istanbul ignore next */
        default:
          return null;
      }
    }
    __name(createNewNode, "createNewNode");
    var ParseContext = class _ParseContext {
      static {
        __name(this, "ParseContext");
      }
      static parseType(src, offset, inFlow) {
        switch (src[offset]) {
          case "*":
            return PlainValue.Type.ALIAS;
          case ">":
            return PlainValue.Type.BLOCK_FOLDED;
          case "|":
            return PlainValue.Type.BLOCK_LITERAL;
          case "{":
            return PlainValue.Type.FLOW_MAP;
          case "[":
            return PlainValue.Type.FLOW_SEQ;
          case "?":
            return !inFlow && PlainValue.Node.atBlank(src, offset + 1, true) ? PlainValue.Type.MAP_KEY : PlainValue.Type.PLAIN;
          case ":":
            return !inFlow && PlainValue.Node.atBlank(src, offset + 1, true) ? PlainValue.Type.MAP_VALUE : PlainValue.Type.PLAIN;
          case "-":
            return !inFlow && PlainValue.Node.atBlank(src, offset + 1, true) ? PlainValue.Type.SEQ_ITEM : PlainValue.Type.PLAIN;
          case '"':
            return PlainValue.Type.QUOTE_DOUBLE;
          case "'":
            return PlainValue.Type.QUOTE_SINGLE;
          default:
            return PlainValue.Type.PLAIN;
        }
      }
      constructor(orig = {}, {
        atLineStart,
        inCollection,
        inFlow,
        indent,
        lineStart,
        parent
      } = {}) {
        PlainValue._defineProperty(this, "parseNode", (overlay, start) => {
          if (PlainValue.Node.atDocumentBoundary(this.src, start)) return null;
          const context = new _ParseContext(this, overlay);
          const {
            props,
            type,
            valueStart
          } = context.parseProps(start);
          const node = createNewNode(type, props);
          let offset = start;
          try {
            offset = node.parse(context, valueStart);
          } catch (error4) {
            const msg = error4 instanceof Error ? error4.message : String(error4);
            if (!node.error) node.error = new PlainValue.YAMLSyntaxError(node, msg);
          }
          node.range = new PlainValue.Range(start, offset);
          if (offset <= start) {
            if (!node.error) node.error = new Error(`Node#parse consumed no characters`);
            node.error.parseEnd = offset;
            node.error.source = node;
            node.range.end = start + 1;
          }
          if (context.nodeStartsCollection(node)) {
            if (!node.error && !context.atLineStart && context.parent.type === PlainValue.Type.DOCUMENT) {
              node.error = new PlainValue.YAMLSyntaxError(node, "Block collection must not have preceding content here (e.g. directives-end indicator)");
            }
            const collection = new Collection2(node);
            offset = collection.parse(new _ParseContext(context), offset);
            collection.range = new PlainValue.Range(start, offset);
            return collection;
          }
          return node;
        });
        this.atLineStart = atLineStart != null ? atLineStart : orig.atLineStart || false;
        this.inCollection = inCollection != null ? inCollection : orig.inCollection || false;
        this.inFlow = inFlow != null ? inFlow : orig.inFlow || false;
        this.indent = indent != null ? indent : orig.indent;
        this.lineStart = lineStart != null ? lineStart : orig.lineStart;
        this.parent = parent != null ? parent : orig.parent || {};
        this.root = orig.root;
        this.src = orig.src;
      }
      nodeStartsCollection(node) {
        const {
          inCollection,
          inFlow,
          src
        } = this;
        if (inCollection || inFlow) return false;
        if (node instanceof CollectionItem) return true;
        let offset = node.range.end;
        if (src[offset] === "\n" || src[offset - 1] === "\n") return false;
        offset = PlainValue.Node.endOfWhiteSpace(src, offset);
        return src[offset] === ":";
      }
      // Anchor and tag are before type, which determines the node implementation
      // class; hence this intermediate step.
      parseProps(offset) {
        const {
          inFlow,
          parent,
          src
        } = this;
        const props = [];
        let lineHasProps = false;
        offset = this.atLineStart ? PlainValue.Node.endOfIndent(src, offset) : PlainValue.Node.endOfWhiteSpace(src, offset);
        let ch = src[offset];
        while (ch === PlainValue.Char.ANCHOR || ch === PlainValue.Char.COMMENT || ch === PlainValue.Char.TAG || ch === "\n") {
          if (ch === "\n") {
            let inEnd = offset;
            let lineStart;
            do {
              lineStart = inEnd + 1;
              inEnd = PlainValue.Node.endOfIndent(src, lineStart);
            } while (src[inEnd] === "\n");
            const indentDiff = inEnd - (lineStart + this.indent);
            const noIndicatorAsIndent = parent.type === PlainValue.Type.SEQ_ITEM && parent.context.atLineStart;
            if (src[inEnd] !== "#" && !PlainValue.Node.nextNodeIsIndented(src[inEnd], indentDiff, !noIndicatorAsIndent)) break;
            this.atLineStart = true;
            this.lineStart = lineStart;
            lineHasProps = false;
            offset = inEnd;
          } else if (ch === PlainValue.Char.COMMENT) {
            const end = PlainValue.Node.endOfLine(src, offset + 1);
            props.push(new PlainValue.Range(offset, end));
            offset = end;
          } else {
            let end = PlainValue.Node.endOfIdentifier(src, offset + 1);
            if (ch === PlainValue.Char.TAG && src[end] === "," && /^[a-zA-Z0-9-]+\.[a-zA-Z0-9-]+,\d\d\d\d(-\d\d){0,2}\/\S/.test(src.slice(offset + 1, end + 13))) {
              end = PlainValue.Node.endOfIdentifier(src, end + 5);
            }
            props.push(new PlainValue.Range(offset, end));
            lineHasProps = true;
            offset = PlainValue.Node.endOfWhiteSpace(src, end);
          }
          ch = src[offset];
        }
        if (lineHasProps && ch === ":" && PlainValue.Node.atBlank(src, offset + 1, true)) offset -= 1;
        const type = _ParseContext.parseType(src, offset, inFlow);
        return {
          props,
          type,
          valueStart: offset
        };
      }
    };
    function parse2(src) {
      const cr = [];
      if (src.indexOf("\r") !== -1) {
        src = src.replace(/\r\n?/g, (match, offset2) => {
          if (match.length > 1) cr.push(offset2);
          return "\n";
        });
      }
      const documents = [];
      let offset = 0;
      do {
        const doc = new Document();
        const context = new ParseContext({
          src
        });
        offset = doc.parse(context, offset);
        documents.push(doc);
      } while (offset < src.length);
      documents.setOrigRanges = () => {
        if (cr.length === 0) return false;
        for (let i32 = 1; i32 < cr.length; ++i32) cr[i32] -= i32;
        let crOffset = 0;
        for (let i32 = 0; i32 < documents.length; ++i32) {
          crOffset = documents[i32].setOrigRanges(cr, crOffset);
        }
        cr.splice(0, cr.length);
        return true;
      };
      documents.toString = () => documents.join("...\n");
      return documents;
    }
    __name(parse2, "parse");
    exports2.parse = parse2;
  }
});

// ../../node_modules/yaml/dist/resolveSeq-95613e94.js
var require_resolveSeq_95613e94 = __commonJS({
  "../../node_modules/yaml/dist/resolveSeq-95613e94.js"(exports2) {
    "use strict";
    var PlainValue = require_PlainValue_516d5bc2();
    function addCommentBefore(str, indent, comment) {
      if (!comment) return str;
      const cc = comment.replace(/[\s\S]^/gm, `$&${indent}#`);
      return `#${cc}
${indent}${str}`;
    }
    __name(addCommentBefore, "addCommentBefore");
    function addComment(str, indent, comment) {
      return !comment ? str : comment.indexOf("\n") === -1 ? `${str} #${comment}` : `${str}
` + comment.replace(/^/gm, `${indent || ""}#`);
    }
    __name(addComment, "addComment");
    var Node2 = class {
      static {
        __name(this, "Node");
      }
    };
    function toJSON(value, arg, ctx) {
      if (Array.isArray(value)) return value.map((v, i32) => toJSON(v, String(i32), ctx));
      if (value && typeof value.toJSON === "function") {
        const anchor = ctx && ctx.anchors && ctx.anchors.get(value);
        if (anchor) ctx.onCreate = (res2) => {
          anchor.res = res2;
          delete ctx.onCreate;
        };
        const res = value.toJSON(arg, ctx);
        if (anchor && ctx.onCreate) ctx.onCreate(res);
        return res;
      }
      if ((!ctx || !ctx.keep) && typeof value === "bigint") return Number(value);
      return value;
    }
    __name(toJSON, "toJSON");
    var Scalar2 = class extends Node2 {
      static {
        __name(this, "Scalar");
      }
      constructor(value) {
        super();
        this.value = value;
      }
      toJSON(arg, ctx) {
        return ctx && ctx.keep ? this.value : toJSON(this.value, arg, ctx);
      }
      toString() {
        return String(this.value);
      }
    };
    function collectionFromPath(schema, path47, value) {
      let v = value;
      for (let i32 = path47.length - 1; i32 >= 0; --i32) {
        const k32 = path47[i32];
        if (Number.isInteger(k32) && k32 >= 0) {
          const a32 = [];
          a32[k32] = v;
          v = a32;
        } else {
          const o10 = {};
          Object.defineProperty(o10, k32, {
            value: v,
            writable: true,
            enumerable: true,
            configurable: true
          });
          v = o10;
        }
      }
      return schema.createNode(v, false);
    }
    __name(collectionFromPath, "collectionFromPath");
    var isEmptyPath = /* @__PURE__ */ __name((path47) => path47 == null || typeof path47 === "object" && path47[Symbol.iterator]().next().done, "isEmptyPath");
    var Collection2 = class _Collection extends Node2 {
      static {
        __name(this, "Collection");
      }
      constructor(schema) {
        super();
        PlainValue._defineProperty(this, "items", []);
        this.schema = schema;
      }
      addIn(path47, value) {
        if (isEmptyPath(path47)) this.add(value);
        else {
          const [key, ...rest] = path47;
          const node = this.get(key, true);
          if (node instanceof _Collection) node.addIn(rest, value);
          else if (node === void 0 && this.schema) this.set(key, collectionFromPath(this.schema, rest, value));
          else throw new Error(`Expected YAML collection at ${key}. Remaining path: ${rest}`);
        }
      }
      deleteIn([key, ...rest]) {
        if (rest.length === 0) return this.delete(key);
        const node = this.get(key, true);
        if (node instanceof _Collection) return node.deleteIn(rest);
        else throw new Error(`Expected YAML collection at ${key}. Remaining path: ${rest}`);
      }
      getIn([key, ...rest], keepScalar) {
        const node = this.get(key, true);
        if (rest.length === 0) return !keepScalar && node instanceof Scalar2 ? node.value : node;
        else return node instanceof _Collection ? node.getIn(rest, keepScalar) : void 0;
      }
      hasAllNullValues() {
        return this.items.every((node) => {
          if (!node || node.type !== "PAIR") return false;
          const n10 = node.value;
          return n10 == null || n10 instanceof Scalar2 && n10.value == null && !n10.commentBefore && !n10.comment && !n10.tag;
        });
      }
      hasIn([key, ...rest]) {
        if (rest.length === 0) return this.has(key);
        const node = this.get(key, true);
        return node instanceof _Collection ? node.hasIn(rest) : false;
      }
      setIn([key, ...rest], value) {
        if (rest.length === 0) {
          this.set(key, value);
        } else {
          const node = this.get(key, true);
          if (node instanceof _Collection) node.setIn(rest, value);
          else if (node === void 0 && this.schema) this.set(key, collectionFromPath(this.schema, rest, value));
          else throw new Error(`Expected YAML collection at ${key}. Remaining path: ${rest}`);
        }
      }
      // overridden in implementations
      /* istanbul ignore next */
      toJSON() {
        return null;
      }
      toString(ctx, {
        blockItem,
        flowChars,
        isMap,
        itemIndent
      }, onComment, onChompKeep) {
        const {
          indent,
          indentStep,
          stringify: stringify2
        } = ctx;
        const inFlow = this.type === PlainValue.Type.FLOW_MAP || this.type === PlainValue.Type.FLOW_SEQ || ctx.inFlow;
        if (inFlow) itemIndent += indentStep;
        const allNullValues = isMap && this.hasAllNullValues();
        ctx = Object.assign({}, ctx, {
          allNullValues,
          indent: itemIndent,
          inFlow,
          type: null
        });
        let chompKeep = false;
        let hasItemWithNewLine = false;
        const nodes32 = this.items.reduce((nodes33, item, i32) => {
          let comment;
          if (item) {
            if (!chompKeep && item.spaceBefore) nodes33.push({
              type: "comment",
              str: ""
            });
            if (item.commentBefore) item.commentBefore.match(/^.*$/gm).forEach((line) => {
              nodes33.push({
                type: "comment",
                str: `#${line}`
              });
            });
            if (item.comment) comment = item.comment;
            if (inFlow && (!chompKeep && item.spaceBefore || item.commentBefore || item.comment || item.key && (item.key.commentBefore || item.key.comment) || item.value && (item.value.commentBefore || item.value.comment))) hasItemWithNewLine = true;
          }
          chompKeep = false;
          let str2 = stringify2(item, ctx, () => comment = null, () => chompKeep = true);
          if (inFlow && !hasItemWithNewLine && str2.includes("\n")) hasItemWithNewLine = true;
          if (inFlow && i32 < this.items.length - 1) str2 += ",";
          str2 = addComment(str2, itemIndent, comment);
          if (chompKeep && (comment || inFlow)) chompKeep = false;
          nodes33.push({
            type: "item",
            str: str2
          });
          return nodes33;
        }, []);
        let str;
        if (nodes32.length === 0) {
          str = flowChars.start + flowChars.end;
        } else if (inFlow) {
          const {
            start,
            end
          } = flowChars;
          const strings = nodes32.map((n10) => n10.str);
          if (hasItemWithNewLine || strings.reduce((sum4, str2) => sum4 + str2.length + 2, 2) > _Collection.maxFlowStringSingleLineLength) {
            str = start;
            for (const s of strings) {
              str += s ? `
${indentStep}${indent}${s}` : "\n";
            }
            str += `
${indent}${end}`;
          } else {
            str = `${start} ${strings.join(" ")} ${end}`;
          }
        } else {
          const strings = nodes32.map(blockItem);
          str = strings.shift();
          for (const s of strings) str += s ? `
${indent}${s}` : "\n";
        }
        if (this.comment) {
          str += "\n" + this.comment.replace(/^/gm, `${indent}#`);
          if (onComment) onComment();
        } else if (chompKeep && onChompKeep) onChompKeep();
        return str;
      }
    };
    PlainValue._defineProperty(Collection2, "maxFlowStringSingleLineLength", 60);
    function asItemIndex(key) {
      let idx = key instanceof Scalar2 ? key.value : key;
      if (idx && typeof idx === "string") idx = Number(idx);
      return Number.isInteger(idx) && idx >= 0 ? idx : null;
    }
    __name(asItemIndex, "asItemIndex");
    var YAMLSeq2 = class extends Collection2 {
      static {
        __name(this, "YAMLSeq");
      }
      add(value) {
        this.items.push(value);
      }
      delete(key) {
        const idx = asItemIndex(key);
        if (typeof idx !== "number") return false;
        const del = this.items.splice(idx, 1);
        return del.length > 0;
      }
      get(key, keepScalar) {
        const idx = asItemIndex(key);
        if (typeof idx !== "number") return void 0;
        const it = this.items[idx];
        return !keepScalar && it instanceof Scalar2 ? it.value : it;
      }
      has(key) {
        const idx = asItemIndex(key);
        return typeof idx === "number" && idx < this.items.length;
      }
      set(key, value) {
        const idx = asItemIndex(key);
        if (typeof idx !== "number") throw new Error(`Expected a valid index, not ${key}.`);
        this.items[idx] = value;
      }
      toJSON(_, ctx) {
        const seq = [];
        if (ctx && ctx.onCreate) ctx.onCreate(seq);
        let i32 = 0;
        for (const item of this.items) seq.push(toJSON(item, String(i32++), ctx));
        return seq;
      }
      toString(ctx, onComment, onChompKeep) {
        if (!ctx) return JSON.stringify(this);
        return super.toString(ctx, {
          blockItem: /* @__PURE__ */ __name((n10) => n10.type === "comment" ? n10.str : `- ${n10.str}`, "blockItem"),
          flowChars: {
            start: "[",
            end: "]"
          },
          isMap: false,
          itemIndent: (ctx.indent || "") + "  "
        }, onComment, onChompKeep);
      }
    };
    var stringifyKey = /* @__PURE__ */ __name((key, jsKey, ctx) => {
      if (jsKey === null) return "";
      if (typeof jsKey !== "object") return String(jsKey);
      if (key instanceof Node2 && ctx && ctx.doc) return key.toString({
        anchors: /* @__PURE__ */ Object.create(null),
        doc: ctx.doc,
        indent: "",
        indentStep: ctx.indentStep,
        inFlow: true,
        inStringifyKey: true,
        stringify: ctx.stringify
      });
      return JSON.stringify(jsKey);
    }, "stringifyKey");
    var Pair2 = class _Pair extends Node2 {
      static {
        __name(this, "Pair");
      }
      constructor(key, value = null) {
        super();
        this.key = key;
        this.value = value;
        this.type = _Pair.Type.PAIR;
      }
      get commentBefore() {
        return this.key instanceof Node2 ? this.key.commentBefore : void 0;
      }
      set commentBefore(cb) {
        if (this.key == null) this.key = new Scalar2(null);
        if (this.key instanceof Node2) this.key.commentBefore = cb;
        else {
          const msg = "Pair.commentBefore is an alias for Pair.key.commentBefore. To set it, the key must be a Node.";
          throw new Error(msg);
        }
      }
      addToJSMap(ctx, map5) {
        const key = toJSON(this.key, "", ctx);
        if (map5 instanceof Map) {
          const value = toJSON(this.value, key, ctx);
          map5.set(key, value);
        } else if (map5 instanceof Set) {
          map5.add(key);
        } else {
          const stringKey = stringifyKey(this.key, key, ctx);
          const value = toJSON(this.value, stringKey, ctx);
          if (stringKey in map5) Object.defineProperty(map5, stringKey, {
            value,
            writable: true,
            enumerable: true,
            configurable: true
          });
          else map5[stringKey] = value;
        }
        return map5;
      }
      toJSON(_, ctx) {
        const pair = ctx && ctx.mapAsMap ? /* @__PURE__ */ new Map() : {};
        return this.addToJSMap(ctx, pair);
      }
      toString(ctx, onComment, onChompKeep) {
        if (!ctx || !ctx.doc) return JSON.stringify(this);
        const {
          indent: indentSize,
          indentSeq,
          simpleKeys
        } = ctx.doc.options;
        let {
          key,
          value
        } = this;
        let keyComment = key instanceof Node2 && key.comment;
        if (simpleKeys) {
          if (keyComment) {
            throw new Error("With simple keys, key nodes cannot have comments");
          }
          if (key instanceof Collection2) {
            const msg = "With simple keys, collection cannot be used as a key value";
            throw new Error(msg);
          }
        }
        let explicitKey = !simpleKeys && (!key || keyComment || (key instanceof Node2 ? key instanceof Collection2 || key.type === PlainValue.Type.BLOCK_FOLDED || key.type === PlainValue.Type.BLOCK_LITERAL : typeof key === "object"));
        const {
          doc,
          indent,
          indentStep,
          stringify: stringify2
        } = ctx;
        ctx = Object.assign({}, ctx, {
          implicitKey: !explicitKey,
          indent: indent + indentStep
        });
        let chompKeep = false;
        let str = stringify2(key, ctx, () => keyComment = null, () => chompKeep = true);
        str = addComment(str, ctx.indent, keyComment);
        if (!explicitKey && str.length > 1024) {
          if (simpleKeys) throw new Error("With simple keys, single line scalar must not span more than 1024 characters");
          explicitKey = true;
        }
        if (ctx.allNullValues && !simpleKeys) {
          if (this.comment) {
            str = addComment(str, ctx.indent, this.comment);
            if (onComment) onComment();
          } else if (chompKeep && !keyComment && onChompKeep) onChompKeep();
          return ctx.inFlow && !explicitKey ? str : `? ${str}`;
        }
        str = explicitKey ? `? ${str}
${indent}:` : `${str}:`;
        if (this.comment) {
          str = addComment(str, ctx.indent, this.comment);
          if (onComment) onComment();
        }
        let vcb = "";
        let valueComment = null;
        if (value instanceof Node2) {
          if (value.spaceBefore) vcb = "\n";
          if (value.commentBefore) {
            const cs = value.commentBefore.replace(/^/gm, `${ctx.indent}#`);
            vcb += `
${cs}`;
          }
          valueComment = value.comment;
        } else if (value && typeof value === "object") {
          value = doc.schema.createNode(value, true);
        }
        ctx.implicitKey = false;
        if (!explicitKey && !this.comment && value instanceof Scalar2) ctx.indentAtStart = str.length + 1;
        chompKeep = false;
        if (!indentSeq && indentSize >= 2 && !ctx.inFlow && !explicitKey && value instanceof YAMLSeq2 && value.type !== PlainValue.Type.FLOW_SEQ && !value.tag && !doc.anchors.getName(value)) {
          ctx.indent = ctx.indent.substr(2);
        }
        const valueStr = stringify2(value, ctx, () => valueComment = null, () => chompKeep = true);
        let ws = " ";
        if (vcb || this.comment) {
          ws = `${vcb}
${ctx.indent}`;
        } else if (!explicitKey && value instanceof Collection2) {
          const flow = valueStr[0] === "[" || valueStr[0] === "{";
          if (!flow || valueStr.includes("\n")) ws = `
${ctx.indent}`;
        } else if (valueStr[0] === "\n") ws = "";
        if (chompKeep && !valueComment && onChompKeep) onChompKeep();
        return addComment(str + ws + valueStr, ctx.indent, valueComment);
      }
    };
    PlainValue._defineProperty(Pair2, "Type", {
      PAIR: "PAIR",
      MERGE_PAIR: "MERGE_PAIR"
    });
    var getAliasCount = /* @__PURE__ */ __name((node, anchors) => {
      if (node instanceof Alias2) {
        const anchor = anchors.get(node.source);
        return anchor.count * anchor.aliasCount;
      } else if (node instanceof Collection2) {
        let count = 0;
        for (const item of node.items) {
          const c32 = getAliasCount(item, anchors);
          if (c32 > count) count = c32;
        }
        return count;
      } else if (node instanceof Pair2) {
        const kc = getAliasCount(node.key, anchors);
        const vc = getAliasCount(node.value, anchors);
        return Math.max(kc, vc);
      }
      return 1;
    }, "getAliasCount");
    var Alias2 = class _Alias extends Node2 {
      static {
        __name(this, "Alias");
      }
      static stringify({
        range: range7,
        source
      }, {
        anchors,
        doc,
        implicitKey,
        inStringifyKey
      }) {
        let anchor = Object.keys(anchors).find((a32) => anchors[a32] === source);
        if (!anchor && inStringifyKey) anchor = doc.anchors.getName(source) || doc.anchors.newName();
        if (anchor) return `*${anchor}${implicitKey ? " " : ""}`;
        const msg = doc.anchors.getName(source) ? "Alias node must be after source node" : "Source node not found for alias node";
        throw new Error(`${msg} [${range7}]`);
      }
      constructor(source) {
        super();
        this.source = source;
        this.type = PlainValue.Type.ALIAS;
      }
      set tag(t) {
        throw new Error("Alias nodes cannot have tags");
      }
      toJSON(arg, ctx) {
        if (!ctx) return toJSON(this.source, arg, ctx);
        const {
          anchors,
          maxAliasCount
        } = ctx;
        const anchor = anchors.get(this.source);
        if (!anchor || anchor.res === void 0) {
          const msg = "This should not happen: Alias anchor was not resolved?";
          if (this.cstNode) throw new PlainValue.YAMLReferenceError(this.cstNode, msg);
          else throw new ReferenceError(msg);
        }
        if (maxAliasCount >= 0) {
          anchor.count += 1;
          if (anchor.aliasCount === 0) anchor.aliasCount = getAliasCount(this.source, anchors);
          if (anchor.count * anchor.aliasCount > maxAliasCount) {
            const msg = "Excessive alias count indicates a resource exhaustion attack";
            if (this.cstNode) throw new PlainValue.YAMLReferenceError(this.cstNode, msg);
            else throw new ReferenceError(msg);
          }
        }
        return anchor.res;
      }
      // Only called when stringifying an alias mapping key while constructing
      // Object output.
      toString(ctx) {
        return _Alias.stringify(this, ctx);
      }
    };
    PlainValue._defineProperty(Alias2, "default", true);
    function findPair(items, key) {
      const k32 = key instanceof Scalar2 ? key.value : key;
      for (const it of items) {
        if (it instanceof Pair2) {
          if (it.key === key || it.key === k32) return it;
          if (it.key && it.key.value === k32) return it;
        }
      }
      return void 0;
    }
    __name(findPair, "findPair");
    var YAMLMap2 = class extends Collection2 {
      static {
        __name(this, "YAMLMap");
      }
      add(pair, overwrite) {
        if (!pair) pair = new Pair2(pair);
        else if (!(pair instanceof Pair2)) pair = new Pair2(pair.key || pair, pair.value);
        const prev = findPair(this.items, pair.key);
        const sortEntries = this.schema && this.schema.sortMapEntries;
        if (prev) {
          if (overwrite) prev.value = pair.value;
          else throw new Error(`Key ${pair.key} already set`);
        } else if (sortEntries) {
          const i32 = this.items.findIndex((item) => sortEntries(pair, item) < 0);
          if (i32 === -1) this.items.push(pair);
          else this.items.splice(i32, 0, pair);
        } else {
          this.items.push(pair);
        }
      }
      delete(key) {
        const it = findPair(this.items, key);
        if (!it) return false;
        const del = this.items.splice(this.items.indexOf(it), 1);
        return del.length > 0;
      }
      get(key, keepScalar) {
        const it = findPair(this.items, key);
        const node = it && it.value;
        return !keepScalar && node instanceof Scalar2 ? node.value : node;
      }
      has(key) {
        return !!findPair(this.items, key);
      }
      set(key, value) {
        this.add(new Pair2(key, value), true);
      }
      /**
       * @param {*} arg ignored
       * @param {*} ctx Conversion context, originally set in Document#toJSON()
       * @param {Class} Type If set, forces the returned collection type
       * @returns {*} Instance of Type, Map, or Object
       */
      toJSON(_, ctx, Type) {
        const map5 = Type ? new Type() : ctx && ctx.mapAsMap ? /* @__PURE__ */ new Map() : {};
        if (ctx && ctx.onCreate) ctx.onCreate(map5);
        for (const item of this.items) item.addToJSMap(ctx, map5);
        return map5;
      }
      toString(ctx, onComment, onChompKeep) {
        if (!ctx) return JSON.stringify(this);
        for (const item of this.items) {
          if (!(item instanceof Pair2)) throw new Error(`Map items must all be pairs; found ${JSON.stringify(item)} instead`);
        }
        return super.toString(ctx, {
          blockItem: /* @__PURE__ */ __name((n10) => n10.str, "blockItem"),
          flowChars: {
            start: "{",
            end: "}"
          },
          isMap: true,
          itemIndent: ctx.indent || ""
        }, onComment, onChompKeep);
      }
    };
    var MERGE_KEY = "<<";
    var Merge2 = class extends Pair2 {
      static {
        __name(this, "Merge");
      }
      constructor(pair) {
        if (pair instanceof Pair2) {
          let seq = pair.value;
          if (!(seq instanceof YAMLSeq2)) {
            seq = new YAMLSeq2();
            seq.items.push(pair.value);
            seq.range = pair.value.range;
          }
          super(pair.key, seq);
          this.range = pair.range;
        } else {
          super(new Scalar2(MERGE_KEY), new YAMLSeq2());
        }
        this.type = Pair2.Type.MERGE_PAIR;
      }
      // If the value associated with a merge key is a single mapping node, each of
      // its key/value pairs is inserted into the current mapping, unless the key
      // already exists in it. If the value associated with the merge key is a
      // sequence, then this sequence is expected to contain mapping nodes and each
      // of these nodes is merged in turn according to its order in the sequence.
      // Keys in mapping nodes earlier in the sequence override keys specified in
      // later mapping nodes. -- http://yaml.org/type/merge.html
      addToJSMap(ctx, map5) {
        for (const {
          source
        } of this.value.items) {
          if (!(source instanceof YAMLMap2)) throw new Error("Merge sources must be maps");
          const srcMap = source.toJSON(null, ctx, Map);
          for (const [key, value] of srcMap) {
            if (map5 instanceof Map) {
              if (!map5.has(key)) map5.set(key, value);
            } else if (map5 instanceof Set) {
              map5.add(key);
            } else if (!Object.prototype.hasOwnProperty.call(map5, key)) {
              Object.defineProperty(map5, key, {
                value,
                writable: true,
                enumerable: true,
                configurable: true
              });
            }
          }
        }
        return map5;
      }
      toString(ctx, onComment) {
        const seq = this.value;
        if (seq.items.length > 1) return super.toString(ctx, onComment);
        this.value = seq.items[0];
        const str = super.toString(ctx, onComment);
        this.value = seq;
        return str;
      }
    };
    var binaryOptions2 = {
      defaultType: PlainValue.Type.BLOCK_LITERAL,
      lineWidth: 76
    };
    var boolOptions2 = {
      trueStr: "true",
      falseStr: "false"
    };
    var intOptions2 = {
      asBigInt: false
    };
    var nullOptions2 = {
      nullStr: "null"
    };
    var strOptions2 = {
      defaultType: PlainValue.Type.PLAIN,
      doubleQuoted: {
        jsonEncoding: false,
        minMultiLineLength: 40
      },
      fold: {
        lineWidth: 80,
        minContentWidth: 20
      }
    };
    function resolveScalar(str, tags, scalarFallback) {
      for (const {
        format: format32,
        test,
        resolve: resolve13
      } of tags) {
        if (test) {
          const match = str.match(test);
          if (match) {
            let res = resolve13.apply(null, match);
            if (!(res instanceof Scalar2)) res = new Scalar2(res);
            if (format32) res.format = format32;
            return res;
          }
        }
      }
      if (scalarFallback) str = scalarFallback(str);
      return new Scalar2(str);
    }
    __name(resolveScalar, "resolveScalar");
    var FOLD_FLOW = "flow";
    var FOLD_BLOCK = "block";
    var FOLD_QUOTED = "quoted";
    var consumeMoreIndentedLines = /* @__PURE__ */ __name((text, i32) => {
      let ch = text[i32 + 1];
      while (ch === " " || ch === "	") {
        do {
          ch = text[i32 += 1];
        } while (ch && ch !== "\n");
        ch = text[i32 + 1];
      }
      return i32;
    }, "consumeMoreIndentedLines");
    function foldFlowLines(text, indent, mode, {
      indentAtStart,
      lineWidth = 80,
      minContentWidth = 20,
      onFold,
      onOverflow
    }) {
      if (!lineWidth || lineWidth < 0) return text;
      const endStep = Math.max(1 + minContentWidth, 1 + lineWidth - indent.length);
      if (text.length <= endStep) return text;
      const folds = [];
      const escapedFolds = {};
      let end = lineWidth - indent.length;
      if (typeof indentAtStart === "number") {
        if (indentAtStart > lineWidth - Math.max(2, minContentWidth)) folds.push(0);
        else end = lineWidth - indentAtStart;
      }
      let split4 = void 0;
      let prev = void 0;
      let overflow = false;
      let i32 = -1;
      let escStart = -1;
      let escEnd = -1;
      if (mode === FOLD_BLOCK) {
        i32 = consumeMoreIndentedLines(text, i32);
        if (i32 !== -1) end = i32 + endStep;
      }
      for (let ch; ch = text[i32 += 1]; ) {
        if (mode === FOLD_QUOTED && ch === "\\") {
          escStart = i32;
          switch (text[i32 + 1]) {
            case "x":
              i32 += 3;
              break;
            case "u":
              i32 += 5;
              break;
            case "U":
              i32 += 9;
              break;
            default:
              i32 += 1;
          }
          escEnd = i32;
        }
        if (ch === "\n") {
          if (mode === FOLD_BLOCK) i32 = consumeMoreIndentedLines(text, i32);
          end = i32 + endStep;
          split4 = void 0;
        } else {
          if (ch === " " && prev && prev !== " " && prev !== "\n" && prev !== "	") {
            const next = text[i32 + 1];
            if (next && next !== " " && next !== "\n" && next !== "	") split4 = i32;
          }
          if (i32 >= end) {
            if (split4) {
              folds.push(split4);
              end = split4 + endStep;
              split4 = void 0;
            } else if (mode === FOLD_QUOTED) {
              while (prev === " " || prev === "	") {
                prev = ch;
                ch = text[i32 += 1];
                overflow = true;
              }
              const j32 = i32 > escEnd + 1 ? i32 - 2 : escStart - 1;
              if (escapedFolds[j32]) return text;
              folds.push(j32);
              escapedFolds[j32] = true;
              end = j32 + endStep;
              split4 = void 0;
            } else {
              overflow = true;
            }
          }
        }
        prev = ch;
      }
      if (overflow && onOverflow) onOverflow();
      if (folds.length === 0) return text;
      if (onFold) onFold();
      let res = text.slice(0, folds[0]);
      for (let i33 = 0; i33 < folds.length; ++i33) {
        const fold = folds[i33];
        const end2 = folds[i33 + 1] || text.length;
        if (fold === 0) res = `
${indent}${text.slice(0, end2)}`;
        else {
          if (mode === FOLD_QUOTED && escapedFolds[fold]) res += `${text[fold]}\\`;
          res += `
${indent}${text.slice(fold + 1, end2)}`;
        }
      }
      return res;
    }
    __name(foldFlowLines, "foldFlowLines");
    var getFoldOptions = /* @__PURE__ */ __name(({
      indentAtStart
    }) => indentAtStart ? Object.assign({
      indentAtStart
    }, strOptions2.fold) : strOptions2.fold, "getFoldOptions");
    var containsDocumentMarker = /* @__PURE__ */ __name((str) => /^(%|---|\.\.\.)/m.test(str), "containsDocumentMarker");
    function lineLengthOverLimit(str, lineWidth, indentLength) {
      if (!lineWidth || lineWidth < 0) return false;
      const limit = lineWidth - indentLength;
      const strLen = str.length;
      if (strLen <= limit) return false;
      for (let i32 = 0, start = 0; i32 < strLen; ++i32) {
        if (str[i32] === "\n") {
          if (i32 - start > limit) return true;
          start = i32 + 1;
          if (strLen - start <= limit) return false;
        }
      }
      return true;
    }
    __name(lineLengthOverLimit, "lineLengthOverLimit");
    function doubleQuotedString(value, ctx) {
      const {
        implicitKey
      } = ctx;
      const {
        jsonEncoding,
        minMultiLineLength
      } = strOptions2.doubleQuoted;
      const json = JSON.stringify(value);
      if (jsonEncoding) return json;
      const indent = ctx.indent || (containsDocumentMarker(value) ? "  " : "");
      let str = "";
      let start = 0;
      for (let i32 = 0, ch = json[i32]; ch; ch = json[++i32]) {
        if (ch === " " && json[i32 + 1] === "\\" && json[i32 + 2] === "n") {
          str += json.slice(start, i32) + "\\ ";
          i32 += 1;
          start = i32;
          ch = "\\";
        }
        if (ch === "\\") switch (json[i32 + 1]) {
          case "u":
            {
              str += json.slice(start, i32);
              const code = json.substr(i32 + 2, 4);
              switch (code) {
                case "0000":
                  str += "\\0";
                  break;
                case "0007":
                  str += "\\a";
                  break;
                case "000b":
                  str += "\\v";
                  break;
                case "001b":
                  str += "\\e";
                  break;
                case "0085":
                  str += "\\N";
                  break;
                case "00a0":
                  str += "\\_";
                  break;
                case "2028":
                  str += "\\L";
                  break;
                case "2029":
                  str += "\\P";
                  break;
                default:
                  if (code.substr(0, 2) === "00") str += "\\x" + code.substr(2);
                  else str += json.substr(i32, 6);
              }
              i32 += 5;
              start = i32 + 1;
            }
            break;
          case "n":
            if (implicitKey || json[i32 + 2] === '"' || json.length < minMultiLineLength) {
              i32 += 1;
            } else {
              str += json.slice(start, i32) + "\n\n";
              while (json[i32 + 2] === "\\" && json[i32 + 3] === "n" && json[i32 + 4] !== '"') {
                str += "\n";
                i32 += 2;
              }
              str += indent;
              if (json[i32 + 2] === " ") str += "\\";
              i32 += 1;
              start = i32 + 1;
            }
            break;
          default:
            i32 += 1;
        }
      }
      str = start ? str + json.slice(start) : json;
      return implicitKey ? str : foldFlowLines(str, indent, FOLD_QUOTED, getFoldOptions(ctx));
    }
    __name(doubleQuotedString, "doubleQuotedString");
    function singleQuotedString(value, ctx) {
      if (ctx.implicitKey) {
        if (/\n/.test(value)) return doubleQuotedString(value, ctx);
      } else {
        if (/[ \t]\n|\n[ \t]/.test(value)) return doubleQuotedString(value, ctx);
      }
      const indent = ctx.indent || (containsDocumentMarker(value) ? "  " : "");
      const res = "'" + value.replace(/'/g, "''").replace(/\n+/g, `$&
${indent}`) + "'";
      return ctx.implicitKey ? res : foldFlowLines(res, indent, FOLD_FLOW, getFoldOptions(ctx));
    }
    __name(singleQuotedString, "singleQuotedString");
    function blockString({
      comment,
      type,
      value
    }, ctx, onComment, onChompKeep) {
      if (/\n[\t ]+$/.test(value) || /^\s*$/.test(value)) {
        return doubleQuotedString(value, ctx);
      }
      const indent = ctx.indent || (ctx.forceBlockIndent || containsDocumentMarker(value) ? "  " : "");
      const indentSize = indent ? "2" : "1";
      const literal = type === PlainValue.Type.BLOCK_FOLDED ? false : type === PlainValue.Type.BLOCK_LITERAL ? true : !lineLengthOverLimit(value, strOptions2.fold.lineWidth, indent.length);
      let header = literal ? "|" : ">";
      if (!value) return header + "\n";
      let wsStart = "";
      let wsEnd = "";
      value = value.replace(/[\n\t ]*$/, (ws) => {
        const n10 = ws.indexOf("\n");
        if (n10 === -1) {
          header += "-";
        } else if (value === ws || n10 !== ws.length - 1) {
          header += "+";
          if (onChompKeep) onChompKeep();
        }
        wsEnd = ws.replace(/\n$/, "");
        return "";
      }).replace(/^[\n ]*/, (ws) => {
        if (ws.indexOf(" ") !== -1) header += indentSize;
        const m20 = ws.match(/ +$/);
        if (m20) {
          wsStart = ws.slice(0, -m20[0].length);
          return m20[0];
        } else {
          wsStart = ws;
          return "";
        }
      });
      if (wsEnd) wsEnd = wsEnd.replace(/\n+(?!\n|$)/g, `$&${indent}`);
      if (wsStart) wsStart = wsStart.replace(/\n+/g, `$&${indent}`);
      if (comment) {
        header += " #" + comment.replace(/ ?[\r\n]+/g, " ");
        if (onComment) onComment();
      }
      if (!value) return `${header}${indentSize}
${indent}${wsEnd}`;
      if (literal) {
        value = value.replace(/\n+/g, `$&${indent}`);
        return `${header}
${indent}${wsStart}${value}${wsEnd}`;
      }
      value = value.replace(/\n+/g, "\n$&").replace(/(?:^|\n)([\t ].*)(?:([\n\t ]*)\n(?![\n\t ]))?/g, "$1$2").replace(/\n+/g, `$&${indent}`);
      const body = foldFlowLines(`${wsStart}${value}${wsEnd}`, indent, FOLD_BLOCK, strOptions2.fold);
      return `${header}
${indent}${body}`;
    }
    __name(blockString, "blockString");
    function plainString(item, ctx, onComment, onChompKeep) {
      const {
        comment,
        type,
        value
      } = item;
      const {
        actualString,
        implicitKey,
        indent,
        inFlow
      } = ctx;
      if (implicitKey && /[\n[\]{},]/.test(value) || inFlow && /[[\]{},]/.test(value)) {
        return doubleQuotedString(value, ctx);
      }
      if (!value || /^[\n\t ,[\]{}#&*!|>'"%@`]|^[?-]$|^[?-][ \t]|[\n:][ \t]|[ \t]\n|[\n\t ]#|[\n\t :]$/.test(value)) {
        return implicitKey || inFlow || value.indexOf("\n") === -1 ? value.indexOf('"') !== -1 && value.indexOf("'") === -1 ? singleQuotedString(value, ctx) : doubleQuotedString(value, ctx) : blockString(item, ctx, onComment, onChompKeep);
      }
      if (!implicitKey && !inFlow && type !== PlainValue.Type.PLAIN && value.indexOf("\n") !== -1) {
        return blockString(item, ctx, onComment, onChompKeep);
      }
      if (indent === "" && containsDocumentMarker(value)) {
        ctx.forceBlockIndent = true;
        return blockString(item, ctx, onComment, onChompKeep);
      }
      const str = value.replace(/\n+/g, `$&
${indent}`);
      if (actualString) {
        const {
          tags
        } = ctx.doc.schema;
        const resolved = resolveScalar(str, tags, tags.scalarFallback).value;
        if (typeof resolved !== "string") return doubleQuotedString(value, ctx);
      }
      const body = implicitKey ? str : foldFlowLines(str, indent, FOLD_FLOW, getFoldOptions(ctx));
      if (comment && !inFlow && (body.indexOf("\n") !== -1 || comment.indexOf("\n") !== -1)) {
        if (onComment) onComment();
        return addCommentBefore(body, indent, comment);
      }
      return body;
    }
    __name(plainString, "plainString");
    function stringifyString(item, ctx, onComment, onChompKeep) {
      const {
        defaultType
      } = strOptions2;
      const {
        implicitKey,
        inFlow
      } = ctx;
      let {
        type,
        value
      } = item;
      if (typeof value !== "string") {
        value = String(value);
        item = Object.assign({}, item, {
          value
        });
      }
      const _stringify = /* @__PURE__ */ __name((_type) => {
        switch (_type) {
          case PlainValue.Type.BLOCK_FOLDED:
          case PlainValue.Type.BLOCK_LITERAL:
            return blockString(item, ctx, onComment, onChompKeep);
          case PlainValue.Type.QUOTE_DOUBLE:
            return doubleQuotedString(value, ctx);
          case PlainValue.Type.QUOTE_SINGLE:
            return singleQuotedString(value, ctx);
          case PlainValue.Type.PLAIN:
            return plainString(item, ctx, onComment, onChompKeep);
          default:
            return null;
        }
      }, "_stringify");
      if (type !== PlainValue.Type.QUOTE_DOUBLE && /[\x00-\x08\x0b-\x1f\x7f-\x9f]/.test(value)) {
        type = PlainValue.Type.QUOTE_DOUBLE;
      } else if ((implicitKey || inFlow) && (type === PlainValue.Type.BLOCK_FOLDED || type === PlainValue.Type.BLOCK_LITERAL)) {
        type = PlainValue.Type.QUOTE_DOUBLE;
      }
      let res = _stringify(type);
      if (res === null) {
        res = _stringify(defaultType);
        if (res === null) throw new Error(`Unsupported default string type ${defaultType}`);
      }
      return res;
    }
    __name(stringifyString, "stringifyString");
    function stringifyNumber({
      format: format32,
      minFractionDigits,
      tag: tag3,
      value
    }) {
      if (typeof value === "bigint") return String(value);
      if (!isFinite(value)) return isNaN(value) ? ".nan" : value < 0 ? "-.inf" : ".inf";
      let n10 = JSON.stringify(value);
      if (!format32 && minFractionDigits && (!tag3 || tag3 === "tag:yaml.org,2002:float") && /^\d/.test(n10)) {
        let i32 = n10.indexOf(".");
        if (i32 < 0) {
          i32 = n10.length;
          n10 += ".";
        }
        let d32 = minFractionDigits - (n10.length - i32 - 1);
        while (d32-- > 0) n10 += "0";
      }
      return n10;
    }
    __name(stringifyNumber, "stringifyNumber");
    function checkFlowCollectionEnd(errors, cst) {
      let char, name;
      switch (cst.type) {
        case PlainValue.Type.FLOW_MAP:
          char = "}";
          name = "flow map";
          break;
        case PlainValue.Type.FLOW_SEQ:
          char = "]";
          name = "flow sequence";
          break;
        default:
          errors.push(new PlainValue.YAMLSemanticError(cst, "Not a flow collection!?"));
          return;
      }
      let lastItem;
      for (let i32 = cst.items.length - 1; i32 >= 0; --i32) {
        const item = cst.items[i32];
        if (!item || item.type !== PlainValue.Type.COMMENT) {
          lastItem = item;
          break;
        }
      }
      if (lastItem && lastItem.char !== char) {
        const msg = `Expected ${name} to end with ${char}`;
        let err;
        if (typeof lastItem.offset === "number") {
          err = new PlainValue.YAMLSemanticError(cst, msg);
          err.offset = lastItem.offset + 1;
        } else {
          err = new PlainValue.YAMLSemanticError(lastItem, msg);
          if (lastItem.range && lastItem.range.end) err.offset = lastItem.range.end - lastItem.range.start;
        }
        errors.push(err);
      }
    }
    __name(checkFlowCollectionEnd, "checkFlowCollectionEnd");
    function checkFlowCommentSpace(errors, comment) {
      const prev = comment.context.src[comment.range.start - 1];
      if (prev !== "\n" && prev !== "	" && prev !== " ") {
        const msg = "Comments must be separated from other tokens by white space characters";
        errors.push(new PlainValue.YAMLSemanticError(comment, msg));
      }
    }
    __name(checkFlowCommentSpace, "checkFlowCommentSpace");
    function getLongKeyError(source, key) {
      const sk = String(key);
      const k32 = sk.substr(0, 8) + "..." + sk.substr(-8);
      return new PlainValue.YAMLSemanticError(source, `The "${k32}" key is too long`);
    }
    __name(getLongKeyError, "getLongKeyError");
    function resolveComments(collection, comments) {
      for (const {
        afterKey,
        before,
        comment
      } of comments) {
        let item = collection.items[before];
        if (!item) {
          if (comment !== void 0) {
            if (collection.comment) collection.comment += "\n" + comment;
            else collection.comment = comment;
          }
        } else {
          if (afterKey && item.value) item = item.value;
          if (comment === void 0) {
            if (afterKey || !item.commentBefore) item.spaceBefore = true;
          } else {
            if (item.commentBefore) item.commentBefore += "\n" + comment;
            else item.commentBefore = comment;
          }
        }
      }
    }
    __name(resolveComments, "resolveComments");
    function resolveString(doc, node) {
      const res = node.strValue;
      if (!res) return "";
      if (typeof res === "string") return res;
      res.errors.forEach((error4) => {
        if (!error4.source) error4.source = node;
        doc.errors.push(error4);
      });
      return res.str;
    }
    __name(resolveString, "resolveString");
    function resolveTagHandle(doc, node) {
      const {
        handle,
        suffix
      } = node.tag;
      let prefix = doc.tagPrefixes.find((p10) => p10.handle === handle);
      if (!prefix) {
        const dtp = doc.getDefaults().tagPrefixes;
        if (dtp) prefix = dtp.find((p10) => p10.handle === handle);
        if (!prefix) throw new PlainValue.YAMLSemanticError(node, `The ${handle} tag handle is non-default and was not declared.`);
      }
      if (!suffix) throw new PlainValue.YAMLSemanticError(node, `The ${handle} tag has no suffix.`);
      if (handle === "!" && (doc.version || doc.options.version) === "1.0") {
        if (suffix[0] === "^") {
          doc.warnings.push(new PlainValue.YAMLWarning(node, "YAML 1.0 ^ tag expansion is not supported"));
          return suffix;
        }
        if (/[:/]/.test(suffix)) {
          const vocab = suffix.match(/^([a-z0-9-]+)\/(.*)/i);
          return vocab ? `tag:${vocab[1]}.yaml.org,2002:${vocab[2]}` : `tag:${suffix}`;
        }
      }
      return prefix.prefix + decodeURIComponent(suffix);
    }
    __name(resolveTagHandle, "resolveTagHandle");
    function resolveTagName(doc, node) {
      const {
        tag: tag3,
        type
      } = node;
      let nonSpecific = false;
      if (tag3) {
        const {
          handle,
          suffix,
          verbatim
        } = tag3;
        if (verbatim) {
          if (verbatim !== "!" && verbatim !== "!!") return verbatim;
          const msg = `Verbatim tags aren't resolved, so ${verbatim} is invalid.`;
          doc.errors.push(new PlainValue.YAMLSemanticError(node, msg));
        } else if (handle === "!" && !suffix) {
          nonSpecific = true;
        } else {
          try {
            return resolveTagHandle(doc, node);
          } catch (error4) {
            doc.errors.push(error4);
          }
        }
      }
      switch (type) {
        case PlainValue.Type.BLOCK_FOLDED:
        case PlainValue.Type.BLOCK_LITERAL:
        case PlainValue.Type.QUOTE_DOUBLE:
        case PlainValue.Type.QUOTE_SINGLE:
          return PlainValue.defaultTags.STR;
        case PlainValue.Type.FLOW_MAP:
        case PlainValue.Type.MAP:
          return PlainValue.defaultTags.MAP;
        case PlainValue.Type.FLOW_SEQ:
        case PlainValue.Type.SEQ:
          return PlainValue.defaultTags.SEQ;
        case PlainValue.Type.PLAIN:
          return nonSpecific ? PlainValue.defaultTags.STR : null;
        default:
          return null;
      }
    }
    __name(resolveTagName, "resolveTagName");
    function resolveByTagName(doc, node, tagName) {
      const {
        tags
      } = doc.schema;
      const matchWithTest = [];
      for (const tag3 of tags) {
        if (tag3.tag === tagName) {
          if (tag3.test) matchWithTest.push(tag3);
          else {
            const res = tag3.resolve(doc, node);
            return res instanceof Collection2 ? res : new Scalar2(res);
          }
        }
      }
      const str = resolveString(doc, node);
      if (typeof str === "string" && matchWithTest.length > 0) return resolveScalar(str, matchWithTest, tags.scalarFallback);
      return null;
    }
    __name(resolveByTagName, "resolveByTagName");
    function getFallbackTagName({
      type
    }) {
      switch (type) {
        case PlainValue.Type.FLOW_MAP:
        case PlainValue.Type.MAP:
          return PlainValue.defaultTags.MAP;
        case PlainValue.Type.FLOW_SEQ:
        case PlainValue.Type.SEQ:
          return PlainValue.defaultTags.SEQ;
        default:
          return PlainValue.defaultTags.STR;
      }
    }
    __name(getFallbackTagName, "getFallbackTagName");
    function resolveTag(doc, node, tagName) {
      try {
        const res = resolveByTagName(doc, node, tagName);
        if (res) {
          if (tagName && node.tag) res.tag = tagName;
          return res;
        }
      } catch (error4) {
        if (error4 instanceof PlainValue.YAMLError) {
          if (!error4.source) error4.source = node;
          doc.errors.push(error4);
        } else {
          const msg = error4 instanceof Error ? error4.message : String(error4);
          doc.errors.push(new PlainValue.YAMLSemanticError(node, msg));
        }
        return null;
      }
      try {
        const fallback2 = getFallbackTagName(node);
        if (!fallback2) throw new Error(`The tag ${tagName} is unavailable`);
        const msg = `The tag ${tagName} is unavailable, falling back to ${fallback2}`;
        doc.warnings.push(new PlainValue.YAMLWarning(node, msg));
        const res = resolveByTagName(doc, node, fallback2);
        res.tag = tagName;
        return res;
      } catch (error4) {
        const refError = new PlainValue.YAMLReferenceError(node, error4.message);
        refError.stack = error4.stack;
        doc.errors.push(refError);
        return null;
      }
    }
    __name(resolveTag, "resolveTag");
    var isCollectionItem = /* @__PURE__ */ __name((node) => {
      if (!node) return false;
      const {
        type
      } = node;
      return type === PlainValue.Type.MAP_KEY || type === PlainValue.Type.MAP_VALUE || type === PlainValue.Type.SEQ_ITEM;
    }, "isCollectionItem");
    function resolveNodeProps(errors, node) {
      const comments = {
        before: [],
        after: []
      };
      let hasAnchor = false;
      let hasTag = false;
      const props = isCollectionItem(node.context.parent) ? node.context.parent.props.concat(node.props) : node.props;
      for (const {
        start,
        end
      } of props) {
        switch (node.context.src[start]) {
          case PlainValue.Char.COMMENT: {
            if (!node.commentHasRequiredWhitespace(start)) {
              const msg = "Comments must be separated from other tokens by white space characters";
              errors.push(new PlainValue.YAMLSemanticError(node, msg));
            }
            const {
              header,
              valueRange
            } = node;
            const cc = valueRange && (start > valueRange.start || header && start > header.start) ? comments.after : comments.before;
            cc.push(node.context.src.slice(start + 1, end));
            break;
          }
          // Actual anchor & tag resolution is handled by schema, here we just complain
          case PlainValue.Char.ANCHOR:
            if (hasAnchor) {
              const msg = "A node can have at most one anchor";
              errors.push(new PlainValue.YAMLSemanticError(node, msg));
            }
            hasAnchor = true;
            break;
          case PlainValue.Char.TAG:
            if (hasTag) {
              const msg = "A node can have at most one tag";
              errors.push(new PlainValue.YAMLSemanticError(node, msg));
            }
            hasTag = true;
            break;
        }
      }
      return {
        comments,
        hasAnchor,
        hasTag
      };
    }
    __name(resolveNodeProps, "resolveNodeProps");
    function resolveNodeValue(doc, node) {
      const {
        anchors,
        errors,
        schema
      } = doc;
      if (node.type === PlainValue.Type.ALIAS) {
        const name = node.rawValue;
        const src = anchors.getNode(name);
        if (!src) {
          const msg = `Aliased anchor not found: ${name}`;
          errors.push(new PlainValue.YAMLReferenceError(node, msg));
          return null;
        }
        const res = new Alias2(src);
        anchors._cstAliases.push(res);
        return res;
      }
      const tagName = resolveTagName(doc, node);
      if (tagName) return resolveTag(doc, node, tagName);
      if (node.type !== PlainValue.Type.PLAIN) {
        const msg = `Failed to resolve ${node.type} node here`;
        errors.push(new PlainValue.YAMLSyntaxError(node, msg));
        return null;
      }
      try {
        const str = resolveString(doc, node);
        return resolveScalar(str, schema.tags, schema.tags.scalarFallback);
      } catch (error4) {
        if (!error4.source) error4.source = node;
        errors.push(error4);
        return null;
      }
    }
    __name(resolveNodeValue, "resolveNodeValue");
    function resolveNode(doc, node) {
      if (!node) return null;
      if (node.error) doc.errors.push(node.error);
      const {
        comments,
        hasAnchor,
        hasTag
      } = resolveNodeProps(doc.errors, node);
      if (hasAnchor) {
        const {
          anchors
        } = doc;
        const name = node.anchor;
        const prev = anchors.getNode(name);
        if (prev) anchors.map[anchors.newName(name)] = prev;
        anchors.map[name] = node;
      }
      if (node.type === PlainValue.Type.ALIAS && (hasAnchor || hasTag)) {
        const msg = "An alias node must not specify any properties";
        doc.errors.push(new PlainValue.YAMLSemanticError(node, msg));
      }
      const res = resolveNodeValue(doc, node);
      if (res) {
        res.range = [node.range.start, node.range.end];
        if (doc.options.keepCstNodes) res.cstNode = node;
        if (doc.options.keepNodeTypes) res.type = node.type;
        const cb = comments.before.join("\n");
        if (cb) {
          res.commentBefore = res.commentBefore ? `${res.commentBefore}
${cb}` : cb;
        }
        const ca = comments.after.join("\n");
        if (ca) res.comment = res.comment ? `${res.comment}
${ca}` : ca;
      }
      return node.resolved = res;
    }
    __name(resolveNode, "resolveNode");
    function resolveMap(doc, cst) {
      if (cst.type !== PlainValue.Type.MAP && cst.type !== PlainValue.Type.FLOW_MAP) {
        const msg = `A ${cst.type} node cannot be resolved as a mapping`;
        doc.errors.push(new PlainValue.YAMLSyntaxError(cst, msg));
        return null;
      }
      const {
        comments,
        items
      } = cst.type === PlainValue.Type.FLOW_MAP ? resolveFlowMapItems(doc, cst) : resolveBlockMapItems(doc, cst);
      const map5 = new YAMLMap2();
      map5.items = items;
      resolveComments(map5, comments);
      let hasCollectionKey = false;
      for (let i32 = 0; i32 < items.length; ++i32) {
        const {
          key: iKey
        } = items[i32];
        if (iKey instanceof Collection2) hasCollectionKey = true;
        if (doc.schema.merge && iKey && iKey.value === MERGE_KEY) {
          items[i32] = new Merge2(items[i32]);
          const sources = items[i32].value.items;
          let error4 = null;
          sources.some((node) => {
            if (node instanceof Alias2) {
              const {
                type
              } = node.source;
              if (type === PlainValue.Type.MAP || type === PlainValue.Type.FLOW_MAP) return false;
              return error4 = "Merge nodes aliases can only point to maps";
            }
            return error4 = "Merge nodes can only have Alias nodes as values";
          });
          if (error4) doc.errors.push(new PlainValue.YAMLSemanticError(cst, error4));
        } else {
          for (let j32 = i32 + 1; j32 < items.length; ++j32) {
            const {
              key: jKey
            } = items[j32];
            if (iKey === jKey || iKey && jKey && Object.prototype.hasOwnProperty.call(iKey, "value") && iKey.value === jKey.value) {
              const msg = `Map keys must be unique; "${iKey}" is repeated`;
              doc.errors.push(new PlainValue.YAMLSemanticError(cst, msg));
              break;
            }
          }
        }
      }
      if (hasCollectionKey && !doc.options.mapAsMap) {
        const warn2 = "Keys with collection values will be stringified as YAML due to JS Object restrictions. Use mapAsMap: true to avoid this.";
        doc.warnings.push(new PlainValue.YAMLWarning(cst, warn2));
      }
      cst.resolved = map5;
      return map5;
    }
    __name(resolveMap, "resolveMap");
    var valueHasPairComment = /* @__PURE__ */ __name(({
      context: {
        lineStart,
        node,
        src
      },
      props
    }) => {
      if (props.length === 0) return false;
      const {
        start
      } = props[0];
      if (node && start > node.valueRange.start) return false;
      if (src[start] !== PlainValue.Char.COMMENT) return false;
      for (let i32 = lineStart; i32 < start; ++i32) if (src[i32] === "\n") return false;
      return true;
    }, "valueHasPairComment");
    function resolvePairComment(item, pair) {
      if (!valueHasPairComment(item)) return;
      const comment = item.getPropValue(0, PlainValue.Char.COMMENT, true);
      let found = false;
      const cb = pair.value.commentBefore;
      if (cb && cb.startsWith(comment)) {
        pair.value.commentBefore = cb.substr(comment.length + 1);
        found = true;
      } else {
        const cc = pair.value.comment;
        if (!item.node && cc && cc.startsWith(comment)) {
          pair.value.comment = cc.substr(comment.length + 1);
          found = true;
        }
      }
      if (found) pair.comment = comment;
    }
    __name(resolvePairComment, "resolvePairComment");
    function resolveBlockMapItems(doc, cst) {
      const comments = [];
      const items = [];
      let key = void 0;
      let keyStart = null;
      for (let i32 = 0; i32 < cst.items.length; ++i32) {
        const item = cst.items[i32];
        switch (item.type) {
          case PlainValue.Type.BLANK_LINE:
            comments.push({
              afterKey: !!key,
              before: items.length
            });
            break;
          case PlainValue.Type.COMMENT:
            comments.push({
              afterKey: !!key,
              before: items.length,
              comment: item.comment
            });
            break;
          case PlainValue.Type.MAP_KEY:
            if (key !== void 0) items.push(new Pair2(key));
            if (item.error) doc.errors.push(item.error);
            key = resolveNode(doc, item.node);
            keyStart = null;
            break;
          case PlainValue.Type.MAP_VALUE:
            {
              if (key === void 0) key = null;
              if (item.error) doc.errors.push(item.error);
              if (!item.context.atLineStart && item.node && item.node.type === PlainValue.Type.MAP && !item.node.context.atLineStart) {
                const msg = "Nested mappings are not allowed in compact mappings";
                doc.errors.push(new PlainValue.YAMLSemanticError(item.node, msg));
              }
              let valueNode = item.node;
              if (!valueNode && item.props.length > 0) {
                valueNode = new PlainValue.PlainValue(PlainValue.Type.PLAIN, []);
                valueNode.context = {
                  parent: item,
                  src: item.context.src
                };
                const pos = item.range.start + 1;
                valueNode.range = {
                  start: pos,
                  end: pos
                };
                valueNode.valueRange = {
                  start: pos,
                  end: pos
                };
                if (typeof item.range.origStart === "number") {
                  const origPos = item.range.origStart + 1;
                  valueNode.range.origStart = valueNode.range.origEnd = origPos;
                  valueNode.valueRange.origStart = valueNode.valueRange.origEnd = origPos;
                }
              }
              const pair = new Pair2(key, resolveNode(doc, valueNode));
              resolvePairComment(item, pair);
              items.push(pair);
              if (key && typeof keyStart === "number") {
                if (item.range.start > keyStart + 1024) doc.errors.push(getLongKeyError(cst, key));
              }
              key = void 0;
              keyStart = null;
            }
            break;
          default:
            if (key !== void 0) items.push(new Pair2(key));
            key = resolveNode(doc, item);
            keyStart = item.range.start;
            if (item.error) doc.errors.push(item.error);
            next: for (let j32 = i32 + 1; ; ++j32) {
              const nextItem = cst.items[j32];
              switch (nextItem && nextItem.type) {
                case PlainValue.Type.BLANK_LINE:
                case PlainValue.Type.COMMENT:
                  continue next;
                case PlainValue.Type.MAP_VALUE:
                  break next;
                default: {
                  const msg = "Implicit map keys need to be followed by map values";
                  doc.errors.push(new PlainValue.YAMLSemanticError(item, msg));
                  break next;
                }
              }
            }
            if (item.valueRangeContainsNewline) {
              const msg = "Implicit map keys need to be on a single line";
              doc.errors.push(new PlainValue.YAMLSemanticError(item, msg));
            }
        }
      }
      if (key !== void 0) items.push(new Pair2(key));
      return {
        comments,
        items
      };
    }
    __name(resolveBlockMapItems, "resolveBlockMapItems");
    function resolveFlowMapItems(doc, cst) {
      const comments = [];
      const items = [];
      let key = void 0;
      let explicitKey = false;
      let next = "{";
      for (let i32 = 0; i32 < cst.items.length; ++i32) {
        const item = cst.items[i32];
        if (typeof item.char === "string") {
          const {
            char,
            offset
          } = item;
          if (char === "?" && key === void 0 && !explicitKey) {
            explicitKey = true;
            next = ":";
            continue;
          }
          if (char === ":") {
            if (key === void 0) key = null;
            if (next === ":") {
              next = ",";
              continue;
            }
          } else {
            if (explicitKey) {
              if (key === void 0 && char !== ",") key = null;
              explicitKey = false;
            }
            if (key !== void 0) {
              items.push(new Pair2(key));
              key = void 0;
              if (char === ",") {
                next = ":";
                continue;
              }
            }
          }
          if (char === "}") {
            if (i32 === cst.items.length - 1) continue;
          } else if (char === next) {
            next = ":";
            continue;
          }
          const msg = `Flow map contains an unexpected ${char}`;
          const err = new PlainValue.YAMLSyntaxError(cst, msg);
          err.offset = offset;
          doc.errors.push(err);
        } else if (item.type === PlainValue.Type.BLANK_LINE) {
          comments.push({
            afterKey: !!key,
            before: items.length
          });
        } else if (item.type === PlainValue.Type.COMMENT) {
          checkFlowCommentSpace(doc.errors, item);
          comments.push({
            afterKey: !!key,
            before: items.length,
            comment: item.comment
          });
        } else if (key === void 0) {
          if (next === ",") doc.errors.push(new PlainValue.YAMLSemanticError(item, "Separator , missing in flow map"));
          key = resolveNode(doc, item);
        } else {
          if (next !== ",") doc.errors.push(new PlainValue.YAMLSemanticError(item, "Indicator : missing in flow map entry"));
          items.push(new Pair2(key, resolveNode(doc, item)));
          key = void 0;
          explicitKey = false;
        }
      }
      checkFlowCollectionEnd(doc.errors, cst);
      if (key !== void 0) items.push(new Pair2(key));
      return {
        comments,
        items
      };
    }
    __name(resolveFlowMapItems, "resolveFlowMapItems");
    function resolveSeq(doc, cst) {
      if (cst.type !== PlainValue.Type.SEQ && cst.type !== PlainValue.Type.FLOW_SEQ) {
        const msg = `A ${cst.type} node cannot be resolved as a sequence`;
        doc.errors.push(new PlainValue.YAMLSyntaxError(cst, msg));
        return null;
      }
      const {
        comments,
        items
      } = cst.type === PlainValue.Type.FLOW_SEQ ? resolveFlowSeqItems(doc, cst) : resolveBlockSeqItems(doc, cst);
      const seq = new YAMLSeq2();
      seq.items = items;
      resolveComments(seq, comments);
      if (!doc.options.mapAsMap && items.some((it) => it instanceof Pair2 && it.key instanceof Collection2)) {
        const warn2 = "Keys with collection values will be stringified as YAML due to JS Object restrictions. Use mapAsMap: true to avoid this.";
        doc.warnings.push(new PlainValue.YAMLWarning(cst, warn2));
      }
      cst.resolved = seq;
      return seq;
    }
    __name(resolveSeq, "resolveSeq");
    function resolveBlockSeqItems(doc, cst) {
      const comments = [];
      const items = [];
      for (let i32 = 0; i32 < cst.items.length; ++i32) {
        const item = cst.items[i32];
        switch (item.type) {
          case PlainValue.Type.BLANK_LINE:
            comments.push({
              before: items.length
            });
            break;
          case PlainValue.Type.COMMENT:
            comments.push({
              comment: item.comment,
              before: items.length
            });
            break;
          case PlainValue.Type.SEQ_ITEM:
            if (item.error) doc.errors.push(item.error);
            items.push(resolveNode(doc, item.node));
            if (item.hasProps) {
              const msg = "Sequence items cannot have tags or anchors before the - indicator";
              doc.errors.push(new PlainValue.YAMLSemanticError(item, msg));
            }
            break;
          default:
            if (item.error) doc.errors.push(item.error);
            doc.errors.push(new PlainValue.YAMLSyntaxError(item, `Unexpected ${item.type} node in sequence`));
        }
      }
      return {
        comments,
        items
      };
    }
    __name(resolveBlockSeqItems, "resolveBlockSeqItems");
    function resolveFlowSeqItems(doc, cst) {
      const comments = [];
      const items = [];
      let explicitKey = false;
      let key = void 0;
      let keyStart = null;
      let next = "[";
      let prevItem = null;
      for (let i32 = 0; i32 < cst.items.length; ++i32) {
        const item = cst.items[i32];
        if (typeof item.char === "string") {
          const {
            char,
            offset
          } = item;
          if (char !== ":" && (explicitKey || key !== void 0)) {
            if (explicitKey && key === void 0) key = next ? items.pop() : null;
            items.push(new Pair2(key));
            explicitKey = false;
            key = void 0;
            keyStart = null;
          }
          if (char === next) {
            next = null;
          } else if (!next && char === "?") {
            explicitKey = true;
          } else if (next !== "[" && char === ":" && key === void 0) {
            if (next === ",") {
              key = items.pop();
              if (key instanceof Pair2) {
                const msg = "Chaining flow sequence pairs is invalid";
                const err = new PlainValue.YAMLSemanticError(cst, msg);
                err.offset = offset;
                doc.errors.push(err);
              }
              if (!explicitKey && typeof keyStart === "number") {
                const keyEnd = item.range ? item.range.start : item.offset;
                if (keyEnd > keyStart + 1024) doc.errors.push(getLongKeyError(cst, key));
                const {
                  src
                } = prevItem.context;
                for (let i33 = keyStart; i33 < keyEnd; ++i33) if (src[i33] === "\n") {
                  const msg = "Implicit keys of flow sequence pairs need to be on a single line";
                  doc.errors.push(new PlainValue.YAMLSemanticError(prevItem, msg));
                  break;
                }
              }
            } else {
              key = null;
            }
            keyStart = null;
            explicitKey = false;
            next = null;
          } else if (next === "[" || char !== "]" || i32 < cst.items.length - 1) {
            const msg = `Flow sequence contains an unexpected ${char}`;
            const err = new PlainValue.YAMLSyntaxError(cst, msg);
            err.offset = offset;
            doc.errors.push(err);
          }
        } else if (item.type === PlainValue.Type.BLANK_LINE) {
          comments.push({
            before: items.length
          });
        } else if (item.type === PlainValue.Type.COMMENT) {
          checkFlowCommentSpace(doc.errors, item);
          comments.push({
            comment: item.comment,
            before: items.length
          });
        } else {
          if (next) {
            const msg = `Expected a ${next} in flow sequence`;
            doc.errors.push(new PlainValue.YAMLSemanticError(item, msg));
          }
          const value = resolveNode(doc, item);
          if (key === void 0) {
            items.push(value);
            prevItem = item;
          } else {
            items.push(new Pair2(key, value));
            key = void 0;
          }
          keyStart = item.range.start;
          next = ",";
        }
      }
      checkFlowCollectionEnd(doc.errors, cst);
      if (key !== void 0) items.push(new Pair2(key));
      return {
        comments,
        items
      };
    }
    __name(resolveFlowSeqItems, "resolveFlowSeqItems");
    exports2.Alias = Alias2;
    exports2.Collection = Collection2;
    exports2.Merge = Merge2;
    exports2.Node = Node2;
    exports2.Pair = Pair2;
    exports2.Scalar = Scalar2;
    exports2.YAMLMap = YAMLMap2;
    exports2.YAMLSeq = YAMLSeq2;
    exports2.addComment = addComment;
    exports2.binaryOptions = binaryOptions2;
    exports2.boolOptions = boolOptions2;
    exports2.findPair = findPair;
    exports2.intOptions = intOptions2;
    exports2.isEmptyPath = isEmptyPath;
    exports2.nullOptions = nullOptions2;
    exports2.resolveMap = resolveMap;
    exports2.resolveNode = resolveNode;
    exports2.resolveSeq = resolveSeq;
    exports2.resolveString = resolveString;
    exports2.strOptions = strOptions2;
    exports2.stringifyNumber = stringifyNumber;
    exports2.stringifyString = stringifyString;
    exports2.toJSON = toJSON;
  }
});

// ../../node_modules/yaml/dist/warnings-793925ce.js
var require_warnings_793925ce = __commonJS({
  "../../node_modules/yaml/dist/warnings-793925ce.js"(exports2) {
    "use strict";
    var PlainValue = require_PlainValue_516d5bc2();
    var resolveSeq = require_resolveSeq_95613e94();
    var binary = {
      identify: /* @__PURE__ */ __name((value) => value instanceof Uint8Array, "identify"),
      // Buffer inherits from Uint8Array
      default: false,
      tag: "tag:yaml.org,2002:binary",
      /**
       * Returns a Buffer in node and an Uint8Array in browsers
       *
       * To use the resulting buffer as an image, you'll want to do something like:
       *
       *   const blob = new Blob([buffer], { type: 'image/jpeg' })
       *   document.querySelector('#photo').src = URL.createObjectURL(blob)
       */
      resolve: /* @__PURE__ */ __name((doc, node) => {
        const src = resolveSeq.resolveString(doc, node);
        if (typeof Buffer === "function") {
          return Buffer.from(src, "base64");
        } else if (typeof atob === "function") {
          const str = atob(src.replace(/[\n\r]/g, ""));
          const buffer = new Uint8Array(str.length);
          for (let i32 = 0; i32 < str.length; ++i32) buffer[i32] = str.charCodeAt(i32);
          return buffer;
        } else {
          const msg = "This environment does not support reading binary tags; either Buffer or atob is required";
          doc.errors.push(new PlainValue.YAMLReferenceError(node, msg));
          return null;
        }
      }, "resolve"),
      options: resolveSeq.binaryOptions,
      stringify: /* @__PURE__ */ __name(({
        comment,
        type,
        value
      }, ctx, onComment, onChompKeep) => {
        let src;
        if (typeof Buffer === "function") {
          src = value instanceof Buffer ? value.toString("base64") : Buffer.from(value.buffer).toString("base64");
        } else if (typeof btoa === "function") {
          let s = "";
          for (let i32 = 0; i32 < value.length; ++i32) s += String.fromCharCode(value[i32]);
          src = btoa(s);
        } else {
          throw new Error("This environment does not support writing binary tags; either Buffer or btoa is required");
        }
        if (!type) type = resolveSeq.binaryOptions.defaultType;
        if (type === PlainValue.Type.QUOTE_DOUBLE) {
          value = src;
        } else {
          const {
            lineWidth
          } = resolveSeq.binaryOptions;
          const n10 = Math.ceil(src.length / lineWidth);
          const lines = new Array(n10);
          for (let i32 = 0, o10 = 0; i32 < n10; ++i32, o10 += lineWidth) {
            lines[i32] = src.substr(o10, lineWidth);
          }
          value = lines.join(type === PlainValue.Type.BLOCK_LITERAL ? "\n" : " ");
        }
        return resolveSeq.stringifyString({
          comment,
          type,
          value
        }, ctx, onComment, onChompKeep);
      }, "stringify")
    };
    function parsePairs(doc, cst) {
      const seq = resolveSeq.resolveSeq(doc, cst);
      for (let i32 = 0; i32 < seq.items.length; ++i32) {
        let item = seq.items[i32];
        if (item instanceof resolveSeq.Pair) continue;
        else if (item instanceof resolveSeq.YAMLMap) {
          if (item.items.length > 1) {
            const msg = "Each pair must have its own sequence indicator";
            throw new PlainValue.YAMLSemanticError(cst, msg);
          }
          const pair = item.items[0] || new resolveSeq.Pair();
          if (item.commentBefore) pair.commentBefore = pair.commentBefore ? `${item.commentBefore}
${pair.commentBefore}` : item.commentBefore;
          if (item.comment) pair.comment = pair.comment ? `${item.comment}
${pair.comment}` : item.comment;
          item = pair;
        }
        seq.items[i32] = item instanceof resolveSeq.Pair ? item : new resolveSeq.Pair(item);
      }
      return seq;
    }
    __name(parsePairs, "parsePairs");
    function createPairs(schema, iterable, ctx) {
      const pairs2 = new resolveSeq.YAMLSeq(schema);
      pairs2.tag = "tag:yaml.org,2002:pairs";
      for (const it of iterable) {
        let key, value;
        if (Array.isArray(it)) {
          if (it.length === 2) {
            key = it[0];
            value = it[1];
          } else throw new TypeError(`Expected [key, value] tuple: ${it}`);
        } else if (it && it instanceof Object) {
          const keys = Object.keys(it);
          if (keys.length === 1) {
            key = keys[0];
            value = it[key];
          } else throw new TypeError(`Expected { key: value } tuple: ${it}`);
        } else {
          key = it;
        }
        const pair = schema.createPair(key, value, ctx);
        pairs2.items.push(pair);
      }
      return pairs2;
    }
    __name(createPairs, "createPairs");
    var pairs = {
      default: false,
      tag: "tag:yaml.org,2002:pairs",
      resolve: parsePairs,
      createNode: createPairs
    };
    var YAMLOMap = class _YAMLOMap extends resolveSeq.YAMLSeq {
      static {
        __name(this, "YAMLOMap");
      }
      constructor() {
        super();
        PlainValue._defineProperty(this, "add", resolveSeq.YAMLMap.prototype.add.bind(this));
        PlainValue._defineProperty(this, "delete", resolveSeq.YAMLMap.prototype.delete.bind(this));
        PlainValue._defineProperty(this, "get", resolveSeq.YAMLMap.prototype.get.bind(this));
        PlainValue._defineProperty(this, "has", resolveSeq.YAMLMap.prototype.has.bind(this));
        PlainValue._defineProperty(this, "set", resolveSeq.YAMLMap.prototype.set.bind(this));
        this.tag = _YAMLOMap.tag;
      }
      toJSON(_, ctx) {
        const map5 = /* @__PURE__ */ new Map();
        if (ctx && ctx.onCreate) ctx.onCreate(map5);
        for (const pair of this.items) {
          let key, value;
          if (pair instanceof resolveSeq.Pair) {
            key = resolveSeq.toJSON(pair.key, "", ctx);
            value = resolveSeq.toJSON(pair.value, key, ctx);
          } else {
            key = resolveSeq.toJSON(pair, "", ctx);
          }
          if (map5.has(key)) throw new Error("Ordered maps must not include duplicate keys");
          map5.set(key, value);
        }
        return map5;
      }
    };
    PlainValue._defineProperty(YAMLOMap, "tag", "tag:yaml.org,2002:omap");
    function parseOMap(doc, cst) {
      const pairs2 = parsePairs(doc, cst);
      const seenKeys = [];
      for (const {
        key
      } of pairs2.items) {
        if (key instanceof resolveSeq.Scalar) {
          if (seenKeys.includes(key.value)) {
            const msg = "Ordered maps must not include duplicate keys";
            throw new PlainValue.YAMLSemanticError(cst, msg);
          } else {
            seenKeys.push(key.value);
          }
        }
      }
      return Object.assign(new YAMLOMap(), pairs2);
    }
    __name(parseOMap, "parseOMap");
    function createOMap(schema, iterable, ctx) {
      const pairs2 = createPairs(schema, iterable, ctx);
      const omap2 = new YAMLOMap();
      omap2.items = pairs2.items;
      return omap2;
    }
    __name(createOMap, "createOMap");
    var omap = {
      identify: /* @__PURE__ */ __name((value) => value instanceof Map, "identify"),
      nodeClass: YAMLOMap,
      default: false,
      tag: "tag:yaml.org,2002:omap",
      resolve: parseOMap,
      createNode: createOMap
    };
    var YAMLSet = class _YAMLSet extends resolveSeq.YAMLMap {
      static {
        __name(this, "YAMLSet");
      }
      constructor() {
        super();
        this.tag = _YAMLSet.tag;
      }
      add(key) {
        const pair = key instanceof resolveSeq.Pair ? key : new resolveSeq.Pair(key);
        const prev = resolveSeq.findPair(this.items, pair.key);
        if (!prev) this.items.push(pair);
      }
      get(key, keepPair) {
        const pair = resolveSeq.findPair(this.items, key);
        return !keepPair && pair instanceof resolveSeq.Pair ? pair.key instanceof resolveSeq.Scalar ? pair.key.value : pair.key : pair;
      }
      set(key, value) {
        if (typeof value !== "boolean") throw new Error(`Expected boolean value for set(key, value) in a YAML set, not ${typeof value}`);
        const prev = resolveSeq.findPair(this.items, key);
        if (prev && !value) {
          this.items.splice(this.items.indexOf(prev), 1);
        } else if (!prev && value) {
          this.items.push(new resolveSeq.Pair(key));
        }
      }
      toJSON(_, ctx) {
        return super.toJSON(_, ctx, Set);
      }
      toString(ctx, onComment, onChompKeep) {
        if (!ctx) return JSON.stringify(this);
        if (this.hasAllNullValues()) return super.toString(ctx, onComment, onChompKeep);
        else throw new Error("Set items must all have null values");
      }
    };
    PlainValue._defineProperty(YAMLSet, "tag", "tag:yaml.org,2002:set");
    function parseSet(doc, cst) {
      const map5 = resolveSeq.resolveMap(doc, cst);
      if (!map5.hasAllNullValues()) throw new PlainValue.YAMLSemanticError(cst, "Set items must all have null values");
      return Object.assign(new YAMLSet(), map5);
    }
    __name(parseSet, "parseSet");
    function createSet(schema, iterable, ctx) {
      const set2 = new YAMLSet();
      for (const value of iterable) set2.items.push(schema.createPair(value, null, ctx));
      return set2;
    }
    __name(createSet, "createSet");
    var set = {
      identify: /* @__PURE__ */ __name((value) => value instanceof Set, "identify"),
      nodeClass: YAMLSet,
      default: false,
      tag: "tag:yaml.org,2002:set",
      resolve: parseSet,
      createNode: createSet
    };
    var parseSexagesimal = /* @__PURE__ */ __name((sign, parts) => {
      const n10 = parts.split(":").reduce((n11, p10) => n11 * 60 + Number(p10), 0);
      return sign === "-" ? -n10 : n10;
    }, "parseSexagesimal");
    var stringifySexagesimal = /* @__PURE__ */ __name(({
      value
    }) => {
      if (isNaN(value) || !isFinite(value)) return resolveSeq.stringifyNumber(value);
      let sign = "";
      if (value < 0) {
        sign = "-";
        value = Math.abs(value);
      }
      const parts = [value % 60];
      if (value < 60) {
        parts.unshift(0);
      } else {
        value = Math.round((value - parts[0]) / 60);
        parts.unshift(value % 60);
        if (value >= 60) {
          value = Math.round((value - parts[0]) / 60);
          parts.unshift(value);
        }
      }
      return sign + parts.map((n10) => n10 < 10 ? "0" + String(n10) : String(n10)).join(":").replace(/000000\d*$/, "");
    }, "stringifySexagesimal");
    var intTime = {
      identify: /* @__PURE__ */ __name((value) => typeof value === "number", "identify"),
      default: true,
      tag: "tag:yaml.org,2002:int",
      format: "TIME",
      test: /^([-+]?)([0-9][0-9_]*(?::[0-5]?[0-9])+)$/,
      resolve: /* @__PURE__ */ __name((str, sign, parts) => parseSexagesimal(sign, parts.replace(/_/g, "")), "resolve"),
      stringify: stringifySexagesimal
    };
    var floatTime = {
      identify: /* @__PURE__ */ __name((value) => typeof value === "number", "identify"),
      default: true,
      tag: "tag:yaml.org,2002:float",
      format: "TIME",
      test: /^([-+]?)([0-9][0-9_]*(?::[0-5]?[0-9])+\.[0-9_]*)$/,
      resolve: /* @__PURE__ */ __name((str, sign, parts) => parseSexagesimal(sign, parts.replace(/_/g, "")), "resolve"),
      stringify: stringifySexagesimal
    };
    var timestamp = {
      identify: /* @__PURE__ */ __name((value) => value instanceof Date, "identify"),
      default: true,
      tag: "tag:yaml.org,2002:timestamp",
      // If the time zone is omitted, the timestamp is assumed to be specified in UTC. The time part
      // may be omitted altogether, resulting in a date format. In such a case, the time part is
      // assumed to be 00:00:00Z (start of day, UTC).
      test: RegExp("^(?:([0-9]{4})-([0-9]{1,2})-([0-9]{1,2})(?:(?:t|T|[ \\t]+)([0-9]{1,2}):([0-9]{1,2}):([0-9]{1,2}(\\.[0-9]+)?)(?:[ \\t]*(Z|[-+][012]?[0-9](?::[0-9]{2})?))?)?)$"),
      resolve: /* @__PURE__ */ __name((str, year7, month, day, hour, minute, second, millisec, tz) => {
        if (millisec) millisec = (millisec + "00").substr(1, 3);
        let date7 = Date.UTC(year7, month - 1, day, hour || 0, minute || 0, second || 0, millisec || 0);
        if (tz && tz !== "Z") {
          let d32 = parseSexagesimal(tz[0], tz.slice(1));
          if (Math.abs(d32) < 30) d32 *= 60;
          date7 -= 6e4 * d32;
        }
        return new Date(date7);
      }, "resolve"),
      stringify: /* @__PURE__ */ __name(({
        value
      }) => value.toISOString().replace(/((T00:00)?:00)?\.000Z$/, ""), "stringify")
    };
    function shouldWarn(deprecation) {
      const env3 = typeof process !== "undefined" && process.env || {};
      if (deprecation) {
        if (typeof YAML_SILENCE_DEPRECATION_WARNINGS !== "undefined") return !YAML_SILENCE_DEPRECATION_WARNINGS;
        return !env3.YAML_SILENCE_DEPRECATION_WARNINGS;
      }
      if (typeof YAML_SILENCE_WARNINGS !== "undefined") return !YAML_SILENCE_WARNINGS;
      return !env3.YAML_SILENCE_WARNINGS;
    }
    __name(shouldWarn, "shouldWarn");
    function warn2(warning2, type) {
      if (shouldWarn(false)) {
        const emit = typeof process !== "undefined" && process.emitWarning;
        if (emit) emit(warning2, type);
        else {
          console.warn(type ? `${type}: ${warning2}` : warning2);
        }
      }
    }
    __name(warn2, "warn");
    function warnFileDeprecation(filename) {
      if (shouldWarn(true)) {
        const path47 = filename.replace(/.*yaml[/\\]/i, "").replace(/\.js$/, "").replace(/\\/g, "/");
        warn2(`The endpoint 'yaml/${path47}' will be removed in a future release.`, "DeprecationWarning");
      }
    }
    __name(warnFileDeprecation, "warnFileDeprecation");
    var warned = {};
    function warnOptionDeprecation(name, alternative) {
      if (!warned[name] && shouldWarn(true)) {
        warned[name] = true;
        let msg = `The option '${name}' will be removed in a future release`;
        msg += alternative ? `, use '${alternative}' instead.` : ".";
        warn2(msg, "DeprecationWarning");
      }
    }
    __name(warnOptionDeprecation, "warnOptionDeprecation");
    exports2.binary = binary;
    exports2.floatTime = floatTime;
    exports2.intTime = intTime;
    exports2.omap = omap;
    exports2.pairs = pairs;
    exports2.set = set;
    exports2.timestamp = timestamp;
    exports2.warn = warn2;
    exports2.warnFileDeprecation = warnFileDeprecation;
    exports2.warnOptionDeprecation = warnOptionDeprecation;
  }
});

// ../../node_modules/yaml/dist/Schema-bcc6c2d7.js
var require_Schema_bcc6c2d7 = __commonJS({
  "../../node_modules/yaml/dist/Schema-bcc6c2d7.js"(exports2) {
    "use strict";
    var PlainValue = require_PlainValue_516d5bc2();
    var resolveSeq = require_resolveSeq_95613e94();
    var warnings = require_warnings_793925ce();
    function createMap(schema, obj, ctx) {
      const map6 = new resolveSeq.YAMLMap(schema);
      if (obj instanceof Map) {
        for (const [key, value] of obj) map6.items.push(schema.createPair(key, value, ctx));
      } else if (obj && typeof obj === "object") {
        for (const key of Object.keys(obj)) map6.items.push(schema.createPair(key, obj[key], ctx));
      }
      if (typeof schema.sortMapEntries === "function") {
        map6.items.sort(schema.sortMapEntries);
      }
      return map6;
    }
    __name(createMap, "createMap");
    var map5 = {
      createNode: createMap,
      default: true,
      nodeClass: resolveSeq.YAMLMap,
      tag: "tag:yaml.org,2002:map",
      resolve: resolveSeq.resolveMap
    };
    function createSeq(schema, obj, ctx) {
      const seq2 = new resolveSeq.YAMLSeq(schema);
      if (obj && obj[Symbol.iterator]) {
        for (const it of obj) {
          const v = schema.createNode(it, ctx.wrapScalars, null, ctx);
          seq2.items.push(v);
        }
      }
      return seq2;
    }
    __name(createSeq, "createSeq");
    var seq = {
      createNode: createSeq,
      default: true,
      nodeClass: resolveSeq.YAMLSeq,
      tag: "tag:yaml.org,2002:seq",
      resolve: resolveSeq.resolveSeq
    };
    var string = {
      identify: /* @__PURE__ */ __name((value) => typeof value === "string", "identify"),
      default: true,
      tag: "tag:yaml.org,2002:str",
      resolve: resolveSeq.resolveString,
      stringify(item, ctx, onComment, onChompKeep) {
        ctx = Object.assign({
          actualString: true
        }, ctx);
        return resolveSeq.stringifyString(item, ctx, onComment, onChompKeep);
      },
      options: resolveSeq.strOptions
    };
    var failsafe = [map5, seq, string];
    var intIdentify$2 = /* @__PURE__ */ __name((value) => typeof value === "bigint" || Number.isInteger(value), "intIdentify$2");
    var intResolve$1 = /* @__PURE__ */ __name((src, part, radix) => resolveSeq.intOptions.asBigInt ? BigInt(src) : parseInt(part, radix), "intResolve$1");
    function intStringify$1(node, radix, prefix) {
      const {
        value
      } = node;
      if (intIdentify$2(value) && value >= 0) return prefix + value.toString(radix);
      return resolveSeq.stringifyNumber(node);
    }
    __name(intStringify$1, "intStringify$1");
    var nullObj = {
      identify: /* @__PURE__ */ __name((value) => value == null, "identify"),
      createNode: /* @__PURE__ */ __name((schema, value, ctx) => ctx.wrapScalars ? new resolveSeq.Scalar(null) : null, "createNode"),
      default: true,
      tag: "tag:yaml.org,2002:null",
      test: /^(?:~|[Nn]ull|NULL)?$/,
      resolve: /* @__PURE__ */ __name(() => null, "resolve"),
      options: resolveSeq.nullOptions,
      stringify: /* @__PURE__ */ __name(() => resolveSeq.nullOptions.nullStr, "stringify")
    };
    var boolObj = {
      identify: /* @__PURE__ */ __name((value) => typeof value === "boolean", "identify"),
      default: true,
      tag: "tag:yaml.org,2002:bool",
      test: /^(?:[Tt]rue|TRUE|[Ff]alse|FALSE)$/,
      resolve: /* @__PURE__ */ __name((str) => str[0] === "t" || str[0] === "T", "resolve"),
      options: resolveSeq.boolOptions,
      stringify: /* @__PURE__ */ __name(({
        value
      }) => value ? resolveSeq.boolOptions.trueStr : resolveSeq.boolOptions.falseStr, "stringify")
    };
    var octObj = {
      identify: /* @__PURE__ */ __name((value) => intIdentify$2(value) && value >= 0, "identify"),
      default: true,
      tag: "tag:yaml.org,2002:int",
      format: "OCT",
      test: /^0o([0-7]+)$/,
      resolve: /* @__PURE__ */ __name((str, oct) => intResolve$1(str, oct, 8), "resolve"),
      options: resolveSeq.intOptions,
      stringify: /* @__PURE__ */ __name((node) => intStringify$1(node, 8, "0o"), "stringify")
    };
    var intObj = {
      identify: intIdentify$2,
      default: true,
      tag: "tag:yaml.org,2002:int",
      test: /^[-+]?[0-9]+$/,
      resolve: /* @__PURE__ */ __name((str) => intResolve$1(str, str, 10), "resolve"),
      options: resolveSeq.intOptions,
      stringify: resolveSeq.stringifyNumber
    };
    var hexObj = {
      identify: /* @__PURE__ */ __name((value) => intIdentify$2(value) && value >= 0, "identify"),
      default: true,
      tag: "tag:yaml.org,2002:int",
      format: "HEX",
      test: /^0x([0-9a-fA-F]+)$/,
      resolve: /* @__PURE__ */ __name((str, hex) => intResolve$1(str, hex, 16), "resolve"),
      options: resolveSeq.intOptions,
      stringify: /* @__PURE__ */ __name((node) => intStringify$1(node, 16, "0x"), "stringify")
    };
    var nanObj = {
      identify: /* @__PURE__ */ __name((value) => typeof value === "number", "identify"),
      default: true,
      tag: "tag:yaml.org,2002:float",
      test: /^(?:[-+]?\.inf|(\.nan))$/i,
      resolve: /* @__PURE__ */ __name((str, nan) => nan ? NaN : str[0] === "-" ? Number.NEGATIVE_INFINITY : Number.POSITIVE_INFINITY, "resolve"),
      stringify: resolveSeq.stringifyNumber
    };
    var expObj = {
      identify: /* @__PURE__ */ __name((value) => typeof value === "number", "identify"),
      default: true,
      tag: "tag:yaml.org,2002:float",
      format: "EXP",
      test: /^[-+]?(?:\.[0-9]+|[0-9]+(?:\.[0-9]*)?)[eE][-+]?[0-9]+$/,
      resolve: /* @__PURE__ */ __name((str) => parseFloat(str), "resolve"),
      stringify: /* @__PURE__ */ __name(({
        value
      }) => Number(value).toExponential(), "stringify")
    };
    var floatObj = {
      identify: /* @__PURE__ */ __name((value) => typeof value === "number", "identify"),
      default: true,
      tag: "tag:yaml.org,2002:float",
      test: /^[-+]?(?:\.([0-9]+)|[0-9]+\.([0-9]*))$/,
      resolve(str, frac1, frac2) {
        const frac = frac1 || frac2;
        const node = new resolveSeq.Scalar(parseFloat(str));
        if (frac && frac[frac.length - 1] === "0") node.minFractionDigits = frac.length;
        return node;
      },
      stringify: resolveSeq.stringifyNumber
    };
    var core = failsafe.concat([nullObj, boolObj, octObj, intObj, hexObj, nanObj, expObj, floatObj]);
    var intIdentify$1 = /* @__PURE__ */ __name((value) => typeof value === "bigint" || Number.isInteger(value), "intIdentify$1");
    var stringifyJSON = /* @__PURE__ */ __name(({
      value
    }) => JSON.stringify(value), "stringifyJSON");
    var json = [map5, seq, {
      identify: /* @__PURE__ */ __name((value) => typeof value === "string", "identify"),
      default: true,
      tag: "tag:yaml.org,2002:str",
      resolve: resolveSeq.resolveString,
      stringify: stringifyJSON
    }, {
      identify: /* @__PURE__ */ __name((value) => value == null, "identify"),
      createNode: /* @__PURE__ */ __name((schema, value, ctx) => ctx.wrapScalars ? new resolveSeq.Scalar(null) : null, "createNode"),
      default: true,
      tag: "tag:yaml.org,2002:null",
      test: /^null$/,
      resolve: /* @__PURE__ */ __name(() => null, "resolve"),
      stringify: stringifyJSON
    }, {
      identify: /* @__PURE__ */ __name((value) => typeof value === "boolean", "identify"),
      default: true,
      tag: "tag:yaml.org,2002:bool",
      test: /^true|false$/,
      resolve: /* @__PURE__ */ __name((str) => str === "true", "resolve"),
      stringify: stringifyJSON
    }, {
      identify: intIdentify$1,
      default: true,
      tag: "tag:yaml.org,2002:int",
      test: /^-?(?:0|[1-9][0-9]*)$/,
      resolve: /* @__PURE__ */ __name((str) => resolveSeq.intOptions.asBigInt ? BigInt(str) : parseInt(str, 10), "resolve"),
      stringify: /* @__PURE__ */ __name(({
        value
      }) => intIdentify$1(value) ? value.toString() : JSON.stringify(value), "stringify")
    }, {
      identify: /* @__PURE__ */ __name((value) => typeof value === "number", "identify"),
      default: true,
      tag: "tag:yaml.org,2002:float",
      test: /^-?(?:0|[1-9][0-9]*)(?:\.[0-9]*)?(?:[eE][-+]?[0-9]+)?$/,
      resolve: /* @__PURE__ */ __name((str) => parseFloat(str), "resolve"),
      stringify: stringifyJSON
    }];
    json.scalarFallback = (str) => {
      throw new SyntaxError(`Unresolved plain scalar ${JSON.stringify(str)}`);
    };
    var boolStringify = /* @__PURE__ */ __name(({
      value
    }) => value ? resolveSeq.boolOptions.trueStr : resolveSeq.boolOptions.falseStr, "boolStringify");
    var intIdentify = /* @__PURE__ */ __name((value) => typeof value === "bigint" || Number.isInteger(value), "intIdentify");
    function intResolve(sign, src, radix) {
      let str = src.replace(/_/g, "");
      if (resolveSeq.intOptions.asBigInt) {
        switch (radix) {
          case 2:
            str = `0b${str}`;
            break;
          case 8:
            str = `0o${str}`;
            break;
          case 16:
            str = `0x${str}`;
            break;
        }
        const n11 = BigInt(str);
        return sign === "-" ? BigInt(-1) * n11 : n11;
      }
      const n10 = parseInt(str, radix);
      return sign === "-" ? -1 * n10 : n10;
    }
    __name(intResolve, "intResolve");
    function intStringify(node, radix, prefix) {
      const {
        value
      } = node;
      if (intIdentify(value)) {
        const str = value.toString(radix);
        return value < 0 ? "-" + prefix + str.substr(1) : prefix + str;
      }
      return resolveSeq.stringifyNumber(node);
    }
    __name(intStringify, "intStringify");
    var yaml11 = failsafe.concat([{
      identify: /* @__PURE__ */ __name((value) => value == null, "identify"),
      createNode: /* @__PURE__ */ __name((schema, value, ctx) => ctx.wrapScalars ? new resolveSeq.Scalar(null) : null, "createNode"),
      default: true,
      tag: "tag:yaml.org,2002:null",
      test: /^(?:~|[Nn]ull|NULL)?$/,
      resolve: /* @__PURE__ */ __name(() => null, "resolve"),
      options: resolveSeq.nullOptions,
      stringify: /* @__PURE__ */ __name(() => resolveSeq.nullOptions.nullStr, "stringify")
    }, {
      identify: /* @__PURE__ */ __name((value) => typeof value === "boolean", "identify"),
      default: true,
      tag: "tag:yaml.org,2002:bool",
      test: /^(?:Y|y|[Yy]es|YES|[Tt]rue|TRUE|[Oo]n|ON)$/,
      resolve: /* @__PURE__ */ __name(() => true, "resolve"),
      options: resolveSeq.boolOptions,
      stringify: boolStringify
    }, {
      identify: /* @__PURE__ */ __name((value) => typeof value === "boolean", "identify"),
      default: true,
      tag: "tag:yaml.org,2002:bool",
      test: /^(?:N|n|[Nn]o|NO|[Ff]alse|FALSE|[Oo]ff|OFF)$/i,
      resolve: /* @__PURE__ */ __name(() => false, "resolve"),
      options: resolveSeq.boolOptions,
      stringify: boolStringify
    }, {
      identify: intIdentify,
      default: true,
      tag: "tag:yaml.org,2002:int",
      format: "BIN",
      test: /^([-+]?)0b([0-1_]+)$/,
      resolve: /* @__PURE__ */ __name((str, sign, bin) => intResolve(sign, bin, 2), "resolve"),
      stringify: /* @__PURE__ */ __name((node) => intStringify(node, 2, "0b"), "stringify")
    }, {
      identify: intIdentify,
      default: true,
      tag: "tag:yaml.org,2002:int",
      format: "OCT",
      test: /^([-+]?)0([0-7_]+)$/,
      resolve: /* @__PURE__ */ __name((str, sign, oct) => intResolve(sign, oct, 8), "resolve"),
      stringify: /* @__PURE__ */ __name((node) => intStringify(node, 8, "0"), "stringify")
    }, {
      identify: intIdentify,
      default: true,
      tag: "tag:yaml.org,2002:int",
      test: /^([-+]?)([0-9][0-9_]*)$/,
      resolve: /* @__PURE__ */ __name((str, sign, abs) => intResolve(sign, abs, 10), "resolve"),
      stringify: resolveSeq.stringifyNumber
    }, {
      identify: intIdentify,
      default: true,
      tag: "tag:yaml.org,2002:int",
      format: "HEX",
      test: /^([-+]?)0x([0-9a-fA-F_]+)$/,
      resolve: /* @__PURE__ */ __name((str, sign, hex) => intResolve(sign, hex, 16), "resolve"),
      stringify: /* @__PURE__ */ __name((node) => intStringify(node, 16, "0x"), "stringify")
    }, {
      identify: /* @__PURE__ */ __name((value) => typeof value === "number", "identify"),
      default: true,
      tag: "tag:yaml.org,2002:float",
      test: /^(?:[-+]?\.inf|(\.nan))$/i,
      resolve: /* @__PURE__ */ __name((str, nan) => nan ? NaN : str[0] === "-" ? Number.NEGATIVE_INFINITY : Number.POSITIVE_INFINITY, "resolve"),
      stringify: resolveSeq.stringifyNumber
    }, {
      identify: /* @__PURE__ */ __name((value) => typeof value === "number", "identify"),
      default: true,
      tag: "tag:yaml.org,2002:float",
      format: "EXP",
      test: /^[-+]?([0-9][0-9_]*)?(\.[0-9_]*)?[eE][-+]?[0-9]+$/,
      resolve: /* @__PURE__ */ __name((str) => parseFloat(str.replace(/_/g, "")), "resolve"),
      stringify: /* @__PURE__ */ __name(({
        value
      }) => Number(value).toExponential(), "stringify")
    }, {
      identify: /* @__PURE__ */ __name((value) => typeof value === "number", "identify"),
      default: true,
      tag: "tag:yaml.org,2002:float",
      test: /^[-+]?(?:[0-9][0-9_]*)?\.([0-9_]*)$/,
      resolve(str, frac) {
        const node = new resolveSeq.Scalar(parseFloat(str.replace(/_/g, "")));
        if (frac) {
          const f32 = frac.replace(/_/g, "");
          if (f32[f32.length - 1] === "0") node.minFractionDigits = f32.length;
        }
        return node;
      },
      stringify: resolveSeq.stringifyNumber
    }], warnings.binary, warnings.omap, warnings.pairs, warnings.set, warnings.intTime, warnings.floatTime, warnings.timestamp);
    var schemas = {
      core,
      failsafe,
      json,
      yaml11
    };
    var tags = {
      binary: warnings.binary,
      bool: boolObj,
      float: floatObj,
      floatExp: expObj,
      floatNaN: nanObj,
      floatTime: warnings.floatTime,
      int: intObj,
      intHex: hexObj,
      intOct: octObj,
      intTime: warnings.intTime,
      map: map5,
      null: nullObj,
      omap: warnings.omap,
      pairs: warnings.pairs,
      seq,
      set: warnings.set,
      timestamp: warnings.timestamp
    };
    function findTagObject(value, tagName, tags2) {
      if (tagName) {
        const match = tags2.filter((t) => t.tag === tagName);
        const tagObj = match.find((t) => !t.format) || match[0];
        if (!tagObj) throw new Error(`Tag ${tagName} not found`);
        return tagObj;
      }
      return tags2.find((t) => (t.identify && t.identify(value) || t.class && value instanceof t.class) && !t.format);
    }
    __name(findTagObject, "findTagObject");
    function createNode(value, tagName, ctx) {
      if (value instanceof resolveSeq.Node) return value;
      const {
        defaultPrefix,
        onTagObj,
        prevObjects,
        schema,
        wrapScalars
      } = ctx;
      if (tagName && tagName.startsWith("!!")) tagName = defaultPrefix + tagName.slice(2);
      let tagObj = findTagObject(value, tagName, schema.tags);
      if (!tagObj) {
        if (typeof value.toJSON === "function") value = value.toJSON();
        if (!value || typeof value !== "object") return wrapScalars ? new resolveSeq.Scalar(value) : value;
        tagObj = value instanceof Map ? map5 : value[Symbol.iterator] ? seq : map5;
      }
      if (onTagObj) {
        onTagObj(tagObj);
        delete ctx.onTagObj;
      }
      const obj = {
        value: void 0,
        node: void 0
      };
      if (value && typeof value === "object" && prevObjects) {
        const prev = prevObjects.get(value);
        if (prev) {
          const alias = new resolveSeq.Alias(prev);
          ctx.aliasNodes.push(alias);
          return alias;
        }
        obj.value = value;
        prevObjects.set(value, obj);
      }
      obj.node = tagObj.createNode ? tagObj.createNode(ctx.schema, value, ctx) : wrapScalars ? new resolveSeq.Scalar(value) : value;
      if (tagName && obj.node instanceof resolveSeq.Node) obj.node.tag = tagName;
      return obj.node;
    }
    __name(createNode, "createNode");
    function getSchemaTags(schemas2, knownTags, customTags, schemaId) {
      let tags2 = schemas2[schemaId.replace(/\W/g, "")];
      if (!tags2) {
        const keys = Object.keys(schemas2).map((key) => JSON.stringify(key)).join(", ");
        throw new Error(`Unknown schema "${schemaId}"; use one of ${keys}`);
      }
      if (Array.isArray(customTags)) {
        for (const tag3 of customTags) tags2 = tags2.concat(tag3);
      } else if (typeof customTags === "function") {
        tags2 = customTags(tags2.slice());
      }
      for (let i32 = 0; i32 < tags2.length; ++i32) {
        const tag3 = tags2[i32];
        if (typeof tag3 === "string") {
          const tagObj = knownTags[tag3];
          if (!tagObj) {
            const keys = Object.keys(knownTags).map((key) => JSON.stringify(key)).join(", ");
            throw new Error(`Unknown custom tag "${tag3}"; use one of ${keys}`);
          }
          tags2[i32] = tagObj;
        }
      }
      return tags2;
    }
    __name(getSchemaTags, "getSchemaTags");
    var sortMapEntriesByKey = /* @__PURE__ */ __name((a32, b32) => a32.key < b32.key ? -1 : a32.key > b32.key ? 1 : 0, "sortMapEntriesByKey");
    var Schema4 = class _Schema {
      static {
        __name(this, "Schema");
      }
      // TODO: remove in v2
      constructor({
        customTags,
        merge: merge3,
        schema,
        sortMapEntries,
        tags: deprecatedCustomTags
      }) {
        this.merge = !!merge3;
        this.name = schema;
        this.sortMapEntries = sortMapEntries === true ? sortMapEntriesByKey : sortMapEntries || null;
        if (!customTags && deprecatedCustomTags) warnings.warnOptionDeprecation("tags", "customTags");
        this.tags = getSchemaTags(schemas, tags, customTags || deprecatedCustomTags, schema);
      }
      createNode(value, wrapScalars, tagName, ctx) {
        const baseCtx = {
          defaultPrefix: _Schema.defaultPrefix,
          schema: this,
          wrapScalars
        };
        const createCtx = ctx ? Object.assign(ctx, baseCtx) : baseCtx;
        return createNode(value, tagName, createCtx);
      }
      createPair(key, value, ctx) {
        if (!ctx) ctx = {
          wrapScalars: true
        };
        const k32 = this.createNode(key, ctx.wrapScalars, null, ctx);
        const v = this.createNode(value, ctx.wrapScalars, null, ctx);
        return new resolveSeq.Pair(k32, v);
      }
    };
    PlainValue._defineProperty(Schema4, "defaultPrefix", PlainValue.defaultTagPrefix);
    PlainValue._defineProperty(Schema4, "defaultTags", PlainValue.defaultTags);
    exports2.Schema = Schema4;
  }
});

// ../../node_modules/yaml/dist/Document-a8d0fbf9.js
var require_Document_a8d0fbf9 = __commonJS({
  "../../node_modules/yaml/dist/Document-a8d0fbf9.js"(exports2) {
    "use strict";
    var PlainValue = require_PlainValue_516d5bc2();
    var resolveSeq = require_resolveSeq_95613e94();
    var Schema4 = require_Schema_bcc6c2d7();
    var defaultOptions2 = {
      anchorPrefix: "a",
      customTags: null,
      indent: 2,
      indentSeq: true,
      keepCstNodes: false,
      keepNodeTypes: true,
      keepBlobsInJSON: true,
      mapAsMap: false,
      maxAliasCount: 100,
      prettyErrors: false,
      // TODO Set true in v2
      simpleKeys: false,
      version: "1.2"
    };
    var scalarOptions = {
      get binary() {
        return resolveSeq.binaryOptions;
      },
      set binary(opt) {
        Object.assign(resolveSeq.binaryOptions, opt);
      },
      get bool() {
        return resolveSeq.boolOptions;
      },
      set bool(opt) {
        Object.assign(resolveSeq.boolOptions, opt);
      },
      get int() {
        return resolveSeq.intOptions;
      },
      set int(opt) {
        Object.assign(resolveSeq.intOptions, opt);
      },
      get null() {
        return resolveSeq.nullOptions;
      },
      set null(opt) {
        Object.assign(resolveSeq.nullOptions, opt);
      },
      get str() {
        return resolveSeq.strOptions;
      },
      set str(opt) {
        Object.assign(resolveSeq.strOptions, opt);
      }
    };
    var documentOptions = {
      "1.0": {
        schema: "yaml-1.1",
        merge: true,
        tagPrefixes: [{
          handle: "!",
          prefix: PlainValue.defaultTagPrefix
        }, {
          handle: "!!",
          prefix: "tag:private.yaml.org,2002:"
        }]
      },
      1.1: {
        schema: "yaml-1.1",
        merge: true,
        tagPrefixes: [{
          handle: "!",
          prefix: "!"
        }, {
          handle: "!!",
          prefix: PlainValue.defaultTagPrefix
        }]
      },
      1.2: {
        schema: "core",
        merge: false,
        tagPrefixes: [{
          handle: "!",
          prefix: "!"
        }, {
          handle: "!!",
          prefix: PlainValue.defaultTagPrefix
        }]
      }
    };
    function stringifyTag(doc, tag3) {
      if ((doc.version || doc.options.version) === "1.0") {
        const priv = tag3.match(/^tag:private\.yaml\.org,2002:([^:/]+)$/);
        if (priv) return "!" + priv[1];
        const vocab = tag3.match(/^tag:([a-zA-Z0-9-]+)\.yaml\.org,2002:(.*)/);
        return vocab ? `!${vocab[1]}/${vocab[2]}` : `!${tag3.replace(/^tag:/, "")}`;
      }
      let p10 = doc.tagPrefixes.find((p11) => tag3.indexOf(p11.prefix) === 0);
      if (!p10) {
        const dtp = doc.getDefaults().tagPrefixes;
        p10 = dtp && dtp.find((p11) => tag3.indexOf(p11.prefix) === 0);
      }
      if (!p10) return tag3[0] === "!" ? tag3 : `!<${tag3}>`;
      const suffix = tag3.substr(p10.prefix.length).replace(/[!,[\]{}]/g, (ch) => ({
        "!": "%21",
        ",": "%2C",
        "[": "%5B",
        "]": "%5D",
        "{": "%7B",
        "}": "%7D"
      })[ch]);
      return p10.handle + suffix;
    }
    __name(stringifyTag, "stringifyTag");
    function getTagObject(tags, item) {
      if (item instanceof resolveSeq.Alias) return resolveSeq.Alias;
      if (item.tag) {
        const match = tags.filter((t) => t.tag === item.tag);
        if (match.length > 0) return match.find((t) => t.format === item.format) || match[0];
      }
      let tagObj, obj;
      if (item instanceof resolveSeq.Scalar) {
        obj = item.value;
        const match = tags.filter((t) => t.identify && t.identify(obj) || t.class && obj instanceof t.class);
        tagObj = match.find((t) => t.format === item.format) || match.find((t) => !t.format);
      } else {
        obj = item;
        tagObj = tags.find((t) => t.nodeClass && obj instanceof t.nodeClass);
      }
      if (!tagObj) {
        const name = obj && obj.constructor ? obj.constructor.name : typeof obj;
        throw new Error(`Tag not resolved for ${name} value`);
      }
      return tagObj;
    }
    __name(getTagObject, "getTagObject");
    function stringifyProps(node, tagObj, {
      anchors,
      doc
    }) {
      const props = [];
      const anchor = doc.anchors.getName(node);
      if (anchor) {
        anchors[anchor] = node;
        props.push(`&${anchor}`);
      }
      if (node.tag) {
        props.push(stringifyTag(doc, node.tag));
      } else if (!tagObj.default) {
        props.push(stringifyTag(doc, tagObj.tag));
      }
      return props.join(" ");
    }
    __name(stringifyProps, "stringifyProps");
    function stringify2(item, ctx, onComment, onChompKeep) {
      const {
        anchors,
        schema
      } = ctx.doc;
      let tagObj;
      if (!(item instanceof resolveSeq.Node)) {
        const createCtx = {
          aliasNodes: [],
          onTagObj: /* @__PURE__ */ __name((o10) => tagObj = o10, "onTagObj"),
          prevObjects: /* @__PURE__ */ new Map()
        };
        item = schema.createNode(item, true, null, createCtx);
        for (const alias of createCtx.aliasNodes) {
          alias.source = alias.source.node;
          let name = anchors.getName(alias.source);
          if (!name) {
            name = anchors.newName();
            anchors.map[name] = alias.source;
          }
        }
      }
      if (item instanceof resolveSeq.Pair) return item.toString(ctx, onComment, onChompKeep);
      if (!tagObj) tagObj = getTagObject(schema.tags, item);
      const props = stringifyProps(item, tagObj, ctx);
      if (props.length > 0) ctx.indentAtStart = (ctx.indentAtStart || 0) + props.length + 1;
      const str = typeof tagObj.stringify === "function" ? tagObj.stringify(item, ctx, onComment, onChompKeep) : item instanceof resolveSeq.Scalar ? resolveSeq.stringifyString(item, ctx, onComment, onChompKeep) : item.toString(ctx, onComment, onChompKeep);
      if (!props) return str;
      return item instanceof resolveSeq.Scalar || str[0] === "{" || str[0] === "[" ? `${props} ${str}` : `${props}
${ctx.indent}${str}`;
    }
    __name(stringify2, "stringify");
    var Anchors = class _Anchors {
      static {
        __name(this, "Anchors");
      }
      static validAnchorNode(node) {
        return node instanceof resolveSeq.Scalar || node instanceof resolveSeq.YAMLSeq || node instanceof resolveSeq.YAMLMap;
      }
      constructor(prefix) {
        PlainValue._defineProperty(this, "map", /* @__PURE__ */ Object.create(null));
        this.prefix = prefix;
      }
      createAlias(node, name) {
        this.setAnchor(node, name);
        return new resolveSeq.Alias(node);
      }
      createMergePair(...sources) {
        const merge3 = new resolveSeq.Merge();
        merge3.value.items = sources.map((s) => {
          if (s instanceof resolveSeq.Alias) {
            if (s.source instanceof resolveSeq.YAMLMap) return s;
          } else if (s instanceof resolveSeq.YAMLMap) {
            return this.createAlias(s);
          }
          throw new Error("Merge sources must be Map nodes or their Aliases");
        });
        return merge3;
      }
      getName(node) {
        const {
          map: map5
        } = this;
        return Object.keys(map5).find((a32) => map5[a32] === node);
      }
      getNames() {
        return Object.keys(this.map);
      }
      getNode(name) {
        return this.map[name];
      }
      newName(prefix) {
        if (!prefix) prefix = this.prefix;
        const names = Object.keys(this.map);
        for (let i32 = 1; true; ++i32) {
          const name = `${prefix}${i32}`;
          if (!names.includes(name)) return name;
        }
      }
      // During parsing, map & aliases contain CST nodes
      resolveNodes() {
        const {
          map: map5,
          _cstAliases
        } = this;
        Object.keys(map5).forEach((a32) => {
          map5[a32] = map5[a32].resolved;
        });
        _cstAliases.forEach((a32) => {
          a32.source = a32.source.resolved;
        });
        delete this._cstAliases;
      }
      setAnchor(node, name) {
        if (node != null && !_Anchors.validAnchorNode(node)) {
          throw new Error("Anchors may only be set for Scalar, Seq and Map nodes");
        }
        if (name && /[\x00-\x19\s,[\]{}]/.test(name)) {
          throw new Error("Anchor names must not contain whitespace or control characters");
        }
        const {
          map: map5
        } = this;
        const prev = node && Object.keys(map5).find((a32) => map5[a32] === node);
        if (prev) {
          if (!name) {
            return prev;
          } else if (prev !== name) {
            delete map5[prev];
            map5[name] = node;
          }
        } else {
          if (!name) {
            if (!node) return null;
            name = this.newName();
          }
          map5[name] = node;
        }
        return name;
      }
    };
    var visit = /* @__PURE__ */ __name((node, tags) => {
      if (node && typeof node === "object") {
        const {
          tag: tag3
        } = node;
        if (node instanceof resolveSeq.Collection) {
          if (tag3) tags[tag3] = true;
          node.items.forEach((n10) => visit(n10, tags));
        } else if (node instanceof resolveSeq.Pair) {
          visit(node.key, tags);
          visit(node.value, tags);
        } else if (node instanceof resolveSeq.Scalar) {
          if (tag3) tags[tag3] = true;
        }
      }
      return tags;
    }, "visit");
    var listTagNames = /* @__PURE__ */ __name((node) => Object.keys(visit(node, {})), "listTagNames");
    function parseContents(doc, contents) {
      const comments = {
        before: [],
        after: []
      };
      let body = void 0;
      let spaceBefore = false;
      for (const node of contents) {
        if (node.valueRange) {
          if (body !== void 0) {
            const msg = "Document contains trailing content not separated by a ... or --- line";
            doc.errors.push(new PlainValue.YAMLSyntaxError(node, msg));
            break;
          }
          const res = resolveSeq.resolveNode(doc, node);
          if (spaceBefore) {
            res.spaceBefore = true;
            spaceBefore = false;
          }
          body = res;
        } else if (node.comment !== null) {
          const cc = body === void 0 ? comments.before : comments.after;
          cc.push(node.comment);
        } else if (node.type === PlainValue.Type.BLANK_LINE) {
          spaceBefore = true;
          if (body === void 0 && comments.before.length > 0 && !doc.commentBefore) {
            doc.commentBefore = comments.before.join("\n");
            comments.before = [];
          }
        }
      }
      doc.contents = body || null;
      if (!body) {
        doc.comment = comments.before.concat(comments.after).join("\n") || null;
      } else {
        const cb = comments.before.join("\n");
        if (cb) {
          const cbNode = body instanceof resolveSeq.Collection && body.items[0] ? body.items[0] : body;
          cbNode.commentBefore = cbNode.commentBefore ? `${cb}
${cbNode.commentBefore}` : cb;
        }
        doc.comment = comments.after.join("\n") || null;
      }
    }
    __name(parseContents, "parseContents");
    function resolveTagDirective({
      tagPrefixes
    }, directive) {
      const [handle, prefix] = directive.parameters;
      if (!handle || !prefix) {
        const msg = "Insufficient parameters given for %TAG directive";
        throw new PlainValue.YAMLSemanticError(directive, msg);
      }
      if (tagPrefixes.some((p10) => p10.handle === handle)) {
        const msg = "The %TAG directive must only be given at most once per handle in the same document.";
        throw new PlainValue.YAMLSemanticError(directive, msg);
      }
      return {
        handle,
        prefix
      };
    }
    __name(resolveTagDirective, "resolveTagDirective");
    function resolveYamlDirective(doc, directive) {
      let [version] = directive.parameters;
      if (directive.name === "YAML:1.0") version = "1.0";
      if (!version) {
        const msg = "Insufficient parameters given for %YAML directive";
        throw new PlainValue.YAMLSemanticError(directive, msg);
      }
      if (!documentOptions[version]) {
        const v0 = doc.version || doc.options.version;
        const msg = `Document will be parsed as YAML ${v0} rather than YAML ${version}`;
        doc.warnings.push(new PlainValue.YAMLWarning(directive, msg));
      }
      return version;
    }
    __name(resolveYamlDirective, "resolveYamlDirective");
    function parseDirectives(doc, directives, prevDoc) {
      const directiveComments = [];
      let hasDirectives = false;
      for (const directive of directives) {
        const {
          comment,
          name
        } = directive;
        switch (name) {
          case "TAG":
            try {
              doc.tagPrefixes.push(resolveTagDirective(doc, directive));
            } catch (error4) {
              doc.errors.push(error4);
            }
            hasDirectives = true;
            break;
          case "YAML":
          case "YAML:1.0":
            if (doc.version) {
              const msg = "The %YAML directive must only be given at most once per document.";
              doc.errors.push(new PlainValue.YAMLSemanticError(directive, msg));
            }
            try {
              doc.version = resolveYamlDirective(doc, directive);
            } catch (error4) {
              doc.errors.push(error4);
            }
            hasDirectives = true;
            break;
          default:
            if (name) {
              const msg = `YAML only supports %TAG and %YAML directives, and not %${name}`;
              doc.warnings.push(new PlainValue.YAMLWarning(directive, msg));
            }
        }
        if (comment) directiveComments.push(comment);
      }
      if (prevDoc && !hasDirectives && "1.1" === (doc.version || prevDoc.version || doc.options.version)) {
        const copyTagPrefix = /* @__PURE__ */ __name(({
          handle,
          prefix
        }) => ({
          handle,
          prefix
        }), "copyTagPrefix");
        doc.tagPrefixes = prevDoc.tagPrefixes.map(copyTagPrefix);
        doc.version = prevDoc.version;
      }
      doc.commentBefore = directiveComments.join("\n") || null;
    }
    __name(parseDirectives, "parseDirectives");
    function assertCollection(contents) {
      if (contents instanceof resolveSeq.Collection) return true;
      throw new Error("Expected a YAML collection as document contents");
    }
    __name(assertCollection, "assertCollection");
    var Document = class _Document {
      static {
        __name(this, "Document");
      }
      constructor(options) {
        this.anchors = new Anchors(options.anchorPrefix);
        this.commentBefore = null;
        this.comment = null;
        this.contents = null;
        this.directivesEndMarker = null;
        this.errors = [];
        this.options = options;
        this.schema = null;
        this.tagPrefixes = [];
        this.version = null;
        this.warnings = [];
      }
      add(value) {
        assertCollection(this.contents);
        return this.contents.add(value);
      }
      addIn(path47, value) {
        assertCollection(this.contents);
        this.contents.addIn(path47, value);
      }
      delete(key) {
        assertCollection(this.contents);
        return this.contents.delete(key);
      }
      deleteIn(path47) {
        if (resolveSeq.isEmptyPath(path47)) {
          if (this.contents == null) return false;
          this.contents = null;
          return true;
        }
        assertCollection(this.contents);
        return this.contents.deleteIn(path47);
      }
      getDefaults() {
        return _Document.defaults[this.version] || _Document.defaults[this.options.version] || {};
      }
      get(key, keepScalar) {
        return this.contents instanceof resolveSeq.Collection ? this.contents.get(key, keepScalar) : void 0;
      }
      getIn(path47, keepScalar) {
        if (resolveSeq.isEmptyPath(path47)) return !keepScalar && this.contents instanceof resolveSeq.Scalar ? this.contents.value : this.contents;
        return this.contents instanceof resolveSeq.Collection ? this.contents.getIn(path47, keepScalar) : void 0;
      }
      has(key) {
        return this.contents instanceof resolveSeq.Collection ? this.contents.has(key) : false;
      }
      hasIn(path47) {
        if (resolveSeq.isEmptyPath(path47)) return this.contents !== void 0;
        return this.contents instanceof resolveSeq.Collection ? this.contents.hasIn(path47) : false;
      }
      set(key, value) {
        assertCollection(this.contents);
        this.contents.set(key, value);
      }
      setIn(path47, value) {
        if (resolveSeq.isEmptyPath(path47)) this.contents = value;
        else {
          assertCollection(this.contents);
          this.contents.setIn(path47, value);
        }
      }
      setSchema(id, customTags) {
        if (!id && !customTags && this.schema) return;
        if (typeof id === "number") id = id.toFixed(1);
        if (id === "1.0" || id === "1.1" || id === "1.2") {
          if (this.version) this.version = id;
          else this.options.version = id;
          delete this.options.schema;
        } else if (id && typeof id === "string") {
          this.options.schema = id;
        }
        if (Array.isArray(customTags)) this.options.customTags = customTags;
        const opt = Object.assign({}, this.getDefaults(), this.options);
        this.schema = new Schema4.Schema(opt);
      }
      parse(node, prevDoc) {
        if (this.options.keepCstNodes) this.cstNode = node;
        if (this.options.keepNodeTypes) this.type = "DOCUMENT";
        const {
          directives = [],
          contents = [],
          directivesEndMarker,
          error: error4,
          valueRange
        } = node;
        if (error4) {
          if (!error4.source) error4.source = this;
          this.errors.push(error4);
        }
        parseDirectives(this, directives, prevDoc);
        if (directivesEndMarker) this.directivesEndMarker = true;
        this.range = valueRange ? [valueRange.start, valueRange.end] : null;
        this.setSchema();
        this.anchors._cstAliases = [];
        parseContents(this, contents);
        this.anchors.resolveNodes();
        if (this.options.prettyErrors) {
          for (const error5 of this.errors) if (error5 instanceof PlainValue.YAMLError) error5.makePretty();
          for (const warn2 of this.warnings) if (warn2 instanceof PlainValue.YAMLError) warn2.makePretty();
        }
        return this;
      }
      listNonDefaultTags() {
        return listTagNames(this.contents).filter((t) => t.indexOf(Schema4.Schema.defaultPrefix) !== 0);
      }
      setTagPrefix(handle, prefix) {
        if (handle[0] !== "!" || handle[handle.length - 1] !== "!") throw new Error("Handle must start and end with !");
        if (prefix) {
          const prev = this.tagPrefixes.find((p10) => p10.handle === handle);
          if (prev) prev.prefix = prefix;
          else this.tagPrefixes.push({
            handle,
            prefix
          });
        } else {
          this.tagPrefixes = this.tagPrefixes.filter((p10) => p10.handle !== handle);
        }
      }
      toJSON(arg, onAnchor) {
        const {
          keepBlobsInJSON,
          mapAsMap,
          maxAliasCount
        } = this.options;
        const keep = keepBlobsInJSON && (typeof arg !== "string" || !(this.contents instanceof resolveSeq.Scalar));
        const ctx = {
          doc: this,
          indentStep: "  ",
          keep,
          mapAsMap: keep && !!mapAsMap,
          maxAliasCount,
          stringify: stringify2
          // Requiring directly in Pair would create circular dependencies
        };
        const anchorNames = Object.keys(this.anchors.map);
        if (anchorNames.length > 0) ctx.anchors = new Map(anchorNames.map((name) => [this.anchors.map[name], {
          alias: [],
          aliasCount: 0,
          count: 1
        }]));
        const res = resolveSeq.toJSON(this.contents, arg, ctx);
        if (typeof onAnchor === "function" && ctx.anchors) for (const {
          count,
          res: res2
        } of ctx.anchors.values()) onAnchor(res2, count);
        return res;
      }
      toString() {
        if (this.errors.length > 0) throw new Error("Document with errors cannot be stringified");
        const indentSize = this.options.indent;
        if (!Number.isInteger(indentSize) || indentSize <= 0) {
          const s = JSON.stringify(indentSize);
          throw new Error(`"indent" option must be a positive integer, not ${s}`);
        }
        this.setSchema();
        const lines = [];
        let hasDirectives = false;
        if (this.version) {
          let vd = "%YAML 1.2";
          if (this.schema.name === "yaml-1.1") {
            if (this.version === "1.0") vd = "%YAML:1.0";
            else if (this.version === "1.1") vd = "%YAML 1.1";
          }
          lines.push(vd);
          hasDirectives = true;
        }
        const tagNames = this.listNonDefaultTags();
        this.tagPrefixes.forEach(({
          handle,
          prefix
        }) => {
          if (tagNames.some((t) => t.indexOf(prefix) === 0)) {
            lines.push(`%TAG ${handle} ${prefix}`);
            hasDirectives = true;
          }
        });
        if (hasDirectives || this.directivesEndMarker) lines.push("---");
        if (this.commentBefore) {
          if (hasDirectives || !this.directivesEndMarker) lines.unshift("");
          lines.unshift(this.commentBefore.replace(/^/gm, "#"));
        }
        const ctx = {
          anchors: /* @__PURE__ */ Object.create(null),
          doc: this,
          indent: "",
          indentStep: " ".repeat(indentSize),
          stringify: stringify2
          // Requiring directly in nodes would create circular dependencies
        };
        let chompKeep = false;
        let contentComment = null;
        if (this.contents) {
          if (this.contents instanceof resolveSeq.Node) {
            if (this.contents.spaceBefore && (hasDirectives || this.directivesEndMarker)) lines.push("");
            if (this.contents.commentBefore) lines.push(this.contents.commentBefore.replace(/^/gm, "#"));
            ctx.forceBlockIndent = !!this.comment;
            contentComment = this.contents.comment;
          }
          const onChompKeep = contentComment ? null : () => chompKeep = true;
          const body = stringify2(this.contents, ctx, () => contentComment = null, onChompKeep);
          lines.push(resolveSeq.addComment(body, "", contentComment));
        } else if (this.contents !== void 0) {
          lines.push(stringify2(this.contents, ctx));
        }
        if (this.comment) {
          if ((!chompKeep || contentComment) && lines[lines.length - 1] !== "") lines.push("");
          lines.push(this.comment.replace(/^/gm, "#"));
        }
        return lines.join("\n") + "\n";
      }
    };
    PlainValue._defineProperty(Document, "defaults", documentOptions);
    exports2.Document = Document;
    exports2.defaultOptions = defaultOptions2;
    exports2.scalarOptions = scalarOptions;
  }
});

// ../../node_modules/yaml/dist/index.js
var require_dist2 = __commonJS({
  "../../node_modules/yaml/dist/index.js"(exports2) {
    "use strict";
    var parseCst = require_parse_cst();
    var Document$1 = require_Document_a8d0fbf9();
    var Schema4 = require_Schema_bcc6c2d7();
    var PlainValue = require_PlainValue_516d5bc2();
    var warnings = require_warnings_793925ce();
    require_resolveSeq_95613e94();
    function createNode(value, wrapScalars = true, tag3) {
      if (tag3 === void 0 && typeof wrapScalars === "string") {
        tag3 = wrapScalars;
        wrapScalars = true;
      }
      const options = Object.assign({}, Document$1.Document.defaults[Document$1.defaultOptions.version], Document$1.defaultOptions);
      const schema = new Schema4.Schema(options);
      return schema.createNode(value, wrapScalars, tag3);
    }
    __name(createNode, "createNode");
    var Document = class extends Document$1.Document {
      static {
        __name(this, "Document");
      }
      constructor(options) {
        super(Object.assign({}, Document$1.defaultOptions, options));
      }
    };
    function parseAllDocuments(src, options) {
      const stream = [];
      let prev;
      for (const cstDoc of parseCst.parse(src)) {
        const doc = new Document(options);
        doc.parse(cstDoc, prev);
        stream.push(doc);
        prev = doc;
      }
      return stream;
    }
    __name(parseAllDocuments, "parseAllDocuments");
    function parseDocument(src, options) {
      const cst = parseCst.parse(src);
      const doc = new Document(options).parse(cst[0]);
      if (cst.length > 1) {
        const errMsg = "Source contains multiple documents; please use YAML.parseAllDocuments()";
        doc.errors.unshift(new PlainValue.YAMLSemanticError(cst[1], errMsg));
      }
      return doc;
    }
    __name(parseDocument, "parseDocument");
    function parse2(src, options) {
      const doc = parseDocument(src, options);
      doc.warnings.forEach((warning2) => warnings.warn(warning2));
      if (doc.errors.length > 0) throw doc.errors[0];
      return doc.toJSON();
    }
    __name(parse2, "parse");
    function stringify2(value, options) {
      const doc = new Document(options);
      doc.contents = value;
      return String(doc);
    }
    __name(stringify2, "stringify");
    var YAML = {
      createNode,
      defaultOptions: Document$1.defaultOptions,
      Document,
      parse: parse2,
      parseAllDocuments,
      parseCST: parseCst.parse,
      parseDocument,
      scalarOptions: Document$1.scalarOptions,
      stringify: stringify2
    };
    exports2.YAML = YAML;
  }
});

// ../../node_modules/yaml/index.js
var require_yaml = __commonJS({
  "../../node_modules/yaml/index.js"(exports2, module2) {
    module2.exports = require_dist2().YAML;
  }
});

// ../../node_modules/yaml/dist/types.js
var require_types = __commonJS({
  "../../node_modules/yaml/dist/types.js"(exports2) {
    "use strict";
    var resolveSeq = require_resolveSeq_95613e94();
    var Schema4 = require_Schema_bcc6c2d7();
    require_PlainValue_516d5bc2();
    require_warnings_793925ce();
    exports2.Alias = resolveSeq.Alias;
    exports2.Collection = resolveSeq.Collection;
    exports2.Merge = resolveSeq.Merge;
    exports2.Node = resolveSeq.Node;
    exports2.Pair = resolveSeq.Pair;
    exports2.Scalar = resolveSeq.Scalar;
    exports2.YAMLMap = resolveSeq.YAMLMap;
    exports2.YAMLSeq = resolveSeq.YAMLSeq;
    exports2.binaryOptions = resolveSeq.binaryOptions;
    exports2.boolOptions = resolveSeq.boolOptions;
    exports2.intOptions = resolveSeq.intOptions;
    exports2.nullOptions = resolveSeq.nullOptions;
    exports2.strOptions = resolveSeq.strOptions;
    exports2.Schema = Schema4.Schema;
  }
});

// ../../node_modules/yaml/types.mjs
var import_types20, binaryOptions, boolOptions, intOptions, nullOptions, strOptions, Schema2, Alias, Collection, Merge, Node, Pair, Scalar, YAMLMap, YAMLSeq;
var init_types3 = __esm({
  "../../node_modules/yaml/types.mjs"() {
    import_types20 = __toESM(require_types(), 1);
    binaryOptions = import_types20.default.binaryOptions;
    boolOptions = import_types20.default.boolOptions;
    intOptions = import_types20.default.intOptions;
    nullOptions = import_types20.default.nullOptions;
    strOptions = import_types20.default.strOptions;
    Schema2 = import_types20.default.Schema;
    Alias = import_types20.default.Alias;
    Collection = import_types20.default.Collection;
    Merge = import_types20.default.Merge;
    Node = import_types20.default.Node;
    Pair = import_types20.default.Pair;
    Scalar = import_types20.default.Scalar;
    YAMLMap = import_types20.default.YAMLMap;
    YAMLSeq = import_types20.default.YAMLSeq;
  }
});

// ../@aws-cdk/toolkit-lib/lib/util/yaml-cfn.ts
function serialize(obj) {
  const oldFold = strOptions.fold.lineWidth;
  try {
    strOptions.fold.lineWidth = 0;
    return yaml.stringify(obj, { schema: "yaml-1.1" });
  } finally {
    strOptions.fold.lineWidth = oldFold;
  }
}
function deserialize(str) {
  return parseYamlStrWithCfnTags(str);
}
function makeTagForCfnIntrinsic(intrinsicName, addFnPrefix) {
  return {
    identify(value) {
      return typeof value === "string";
    },
    tag: `!${intrinsicName}`,
    resolve: /* @__PURE__ */ __name((_doc, cstNode) => {
      const ret = {};
      ret[addFnPrefix ? `Fn::${intrinsicName}` : intrinsicName] = // the +1 is to account for the ! the short form begins with
      parseYamlStrWithCfnTags(cstNode.toString().substring(intrinsicName.length + 1));
      return ret;
    }, "resolve")
  };
}
function parseYamlStrWithCfnTags(text) {
  return yaml.parse(text, {
    customTags: shortForms,
    schema: "core"
  });
}
var yaml, shortForms;
var init_yaml_cfn = __esm({
  "../@aws-cdk/toolkit-lib/lib/util/yaml-cfn.ts"() {
    "use strict";
    yaml = __toESM(require_yaml());
    init_types3();
    __name(serialize, "serialize");
    __name(deserialize, "deserialize");
    __name(makeTagForCfnIntrinsic, "makeTagForCfnIntrinsic");
    shortForms = [
      "Base64",
      "Cidr",
      "FindInMap",
      "GetAZs",
      "ImportValue",
      "Join",
      "Sub",
      "Select",
      "Split",
      "Transform",
      "And",
      "Equals",
      "If",
      "Not",
      "Or",
      "GetAtt"
    ].map((name) => makeTagForCfnIntrinsic(name, true)).concat(
      makeTagForCfnIntrinsic("Ref", false),
      makeTagForCfnIntrinsic("Condition", false)
    );
    __name(parseYamlStrWithCfnTags, "parseYamlStrWithCfnTags");
  }
});

// ../@aws-cdk/toolkit-lib/lib/util/serialize.ts
function toYAML(obj) {
  return serialize(obj);
}
function deserializeStructure(str) {
  return deserialize(str);
}
function serializeStructure(object, json) {
  if (json) {
    return JSON.stringify(object, void 0, 2);
  } else {
    return toYAML(object);
  }
}
async function loadStructuredFile(fileName) {
  const contents = await fs13.readFile(fileName, { encoding: "utf-8" });
  return deserializeStructure(contents);
}
function obscureTemplate(template = {}) {
  if (template.Rules) {
    if (template.Rules.CheckBootstrapVersion) {
      if (Object.keys(template.Rules).length > 1) {
        delete template.Rules.CheckBootstrapVersion;
      } else {
        delete template.Rules;
      }
    }
  }
  return template;
}
function isJsonBuffer(value) {
  return typeof value === "object" && "type" in value && value.type === "Buffer" && "data" in value && Array.isArray(value.data);
}
function replacerBufferWithInfo(_key, value) {
  if (isJsonBuffer(value)) {
    return `<Buffer: ${formatBytes(value.data.length)}>`;
  }
  return value;
}
var fs13;
var init_serialize = __esm({
  "../@aws-cdk/toolkit-lib/lib/util/serialize.ts"() {
    "use strict";
    fs13 = __toESM(require("fs/promises"));
    init_bytes();
    init_yaml_cfn();
    __name(toYAML, "toYAML");
    __name(deserializeStructure, "deserializeStructure");
    __name(serializeStructure, "serializeStructure");
    __name(loadStructuredFile, "loadStructuredFile");
    __name(obscureTemplate, "obscureTemplate");
    __name(isJsonBuffer, "isJsonBuffer");
    __name(replacerBufferWithInfo, "replacerBufferWithInfo");
  }
});

// ../@aws-cdk/toolkit-lib/lib/util/string-manipulation.ts
function padLeft(n10, x, char = " ") {
  return char.repeat(Math.max(0, n10 - x.length)) + x;
}
function padRight(n10, x, char = " ") {
  return x + char.repeat(Math.max(0, n10 - x.length));
}
function formatTime(num) {
  return roundPercentage(millisecondsToSeconds(num));
}
function roundPercentage(num) {
  return Math.round(100 * num) / 100;
}
function millisecondsToSeconds(num) {
  return num / 1e3;
}
function lowerCaseFirstCharacter(str) {
  return str.length > 0 ? `${str[0].toLowerCase()}${str.slice(1)}` : str;
}
function formatReason(reason, fallback2 = "No reason provided") {
  return reason?.trim() || fallback2;
}
var init_string_manipulation = __esm({
  "../@aws-cdk/toolkit-lib/lib/util/string-manipulation.ts"() {
    "use strict";
    __name(padLeft, "padLeft");
    __name(padRight, "padRight");
    __name(formatTime, "formatTime");
    __name(roundPercentage, "roundPercentage");
    __name(millisecondsToSeconds, "millisecondsToSeconds");
    __name(lowerCaseFirstCharacter, "lowerCaseFirstCharacter");
    __name(formatReason, "formatReason");
  }
});

// ../@aws-cdk/toolkit-lib/lib/util/type-brands.ts
var init_type_brands = __esm({
  "../@aws-cdk/toolkit-lib/lib/util/type-brands.ts"() {
    "use strict";
  }
});

// ../../node_modules/semver/internal/constants.js
var require_constants6 = __commonJS({
  "../../node_modules/semver/internal/constants.js"(exports2, module2) {
    "use strict";
    var SEMVER_SPEC_VERSION = "2.0.0";
    var MAX_LENGTH = 256;
    var MAX_SAFE_INTEGER = Number.MAX_SAFE_INTEGER || /* istanbul ignore next */
    9007199254740991;
    var MAX_SAFE_COMPONENT_LENGTH = 16;
    var MAX_SAFE_BUILD_LENGTH = MAX_LENGTH - 6;
    var RELEASE_TYPES = [
      "major",
      "premajor",
      "minor",
      "preminor",
      "patch",
      "prepatch",
      "prerelease"
    ];
    module2.exports = {
      MAX_LENGTH,
      MAX_SAFE_COMPONENT_LENGTH,
      MAX_SAFE_BUILD_LENGTH,
      MAX_SAFE_INTEGER,
      RELEASE_TYPES,
      SEMVER_SPEC_VERSION,
      FLAG_INCLUDE_PRERELEASE: 1,
      FLAG_LOOSE: 2
    };
  }
});

// ../../node_modules/semver/internal/debug.js
var require_debug2 = __commonJS({
  "../../node_modules/semver/internal/debug.js"(exports2, module2) {
    "use strict";
    var debug2 = typeof process === "object" && process.env && process.env.NODE_DEBUG && /\bsemver\b/i.test(process.env.NODE_DEBUG) ? (...args) => console.error("SEMVER", ...args) : () => {
    };
    module2.exports = debug2;
  }
});

// ../../node_modules/semver/internal/re.js
var require_re2 = __commonJS({
  "../../node_modules/semver/internal/re.js"(exports2, module2) {
    "use strict";
    var {
      MAX_SAFE_COMPONENT_LENGTH,
      MAX_SAFE_BUILD_LENGTH,
      MAX_LENGTH
    } = require_constants6();
    var debug2 = require_debug2();
    exports2 = module2.exports = {};
    var re = exports2.re = [];
    var safeRe = exports2.safeRe = [];
    var src = exports2.src = [];
    var safeSrc = exports2.safeSrc = [];
    var t = exports2.t = {};
    var R = 0;
    var LETTERDASHNUMBER = "[a-zA-Z0-9-]";
    var safeRegexReplacements = [
      ["\\s", 1],
      ["\\d", MAX_LENGTH],
      [LETTERDASHNUMBER, MAX_SAFE_BUILD_LENGTH]
    ];
    var makeSafeRegex = /* @__PURE__ */ __name((value) => {
      for (const [token, max] of safeRegexReplacements) {
        value = value.split(`${token}*`).join(`${token}{0,${max}}`).split(`${token}+`).join(`${token}{1,${max}}`);
      }
      return value;
    }, "makeSafeRegex");
    var createToken = /* @__PURE__ */ __name((name, value, isGlobal) => {
      const safe = makeSafeRegex(value);
      const index = R++;
      debug2(name, index, value);
      t[name] = index;
      src[index] = value;
      safeSrc[index] = safe;
      re[index] = new RegExp(value, isGlobal ? "g" : void 0);
      safeRe[index] = new RegExp(safe, isGlobal ? "g" : void 0);
    }, "createToken");
    createToken("NUMERICIDENTIFIER", "0|[1-9]\\d*");
    createToken("NUMERICIDENTIFIERLOOSE", "\\d+");
    createToken("NONNUMERICIDENTIFIER", `\\d*[a-zA-Z-]${LETTERDASHNUMBER}*`);
    createToken("MAINVERSION", `(${src[t.NUMERICIDENTIFIER]})\\.(${src[t.NUMERICIDENTIFIER]})\\.(${src[t.NUMERICIDENTIFIER]})`);
    createToken("MAINVERSIONLOOSE", `(${src[t.NUMERICIDENTIFIERLOOSE]})\\.(${src[t.NUMERICIDENTIFIERLOOSE]})\\.(${src[t.NUMERICIDENTIFIERLOOSE]})`);
    createToken("PRERELEASEIDENTIFIER", `(?:${src[t.NONNUMERICIDENTIFIER]}|${src[t.NUMERICIDENTIFIER]})`);
    createToken("PRERELEASEIDENTIFIERLOOSE", `(?:${src[t.NONNUMERICIDENTIFIER]}|${src[t.NUMERICIDENTIFIERLOOSE]})`);
    createToken("PRERELEASE", `(?:-(${src[t.PRERELEASEIDENTIFIER]}(?:\\.${src[t.PRERELEASEIDENTIFIER]})*))`);
    createToken("PRERELEASELOOSE", `(?:-?(${src[t.PRERELEASEIDENTIFIERLOOSE]}(?:\\.${src[t.PRERELEASEIDENTIFIERLOOSE]})*))`);
    createToken("BUILDIDENTIFIER", `${LETTERDASHNUMBER}+`);
    createToken("BUILD", `(?:\\+(${src[t.BUILDIDENTIFIER]}(?:\\.${src[t.BUILDIDENTIFIER]})*))`);
    createToken("FULLPLAIN", `v?${src[t.MAINVERSION]}${src[t.PRERELEASE]}?${src[t.BUILD]}?`);
    createToken("FULL", `^${src[t.FULLPLAIN]}$`);
    createToken("LOOSEPLAIN", `[v=\\s]*${src[t.MAINVERSIONLOOSE]}${src[t.PRERELEASELOOSE]}?${src[t.BUILD]}?`);
    createToken("LOOSE", `^${src[t.LOOSEPLAIN]}$`);
    createToken("GTLT", "((?:<|>)?=?)");
    createToken("XRANGEIDENTIFIERLOOSE", `${src[t.NUMERICIDENTIFIERLOOSE]}|x|X|\\*`);
    createToken("XRANGEIDENTIFIER", `${src[t.NUMERICIDENTIFIER]}|x|X|\\*`);
    createToken("XRANGEPLAIN", `[v=\\s]*(${src[t.XRANGEIDENTIFIER]})(?:\\.(${src[t.XRANGEIDENTIFIER]})(?:\\.(${src[t.XRANGEIDENTIFIER]})(?:${src[t.PRERELEASE]})?${src[t.BUILD]}?)?)?`);
    createToken("XRANGEPLAINLOOSE", `[v=\\s]*(${src[t.XRANGEIDENTIFIERLOOSE]})(?:\\.(${src[t.XRANGEIDENTIFIERLOOSE]})(?:\\.(${src[t.XRANGEIDENTIFIERLOOSE]})(?:${src[t.PRERELEASELOOSE]})?${src[t.BUILD]}?)?)?`);
    createToken("XRANGE", `^${src[t.GTLT]}\\s*${src[t.XRANGEPLAIN]}$`);
    createToken("XRANGELOOSE", `^${src[t.GTLT]}\\s*${src[t.XRANGEPLAINLOOSE]}$`);
    createToken("COERCEPLAIN", `${"(^|[^\\d])(\\d{1,"}${MAX_SAFE_COMPONENT_LENGTH}})(?:\\.(\\d{1,${MAX_SAFE_COMPONENT_LENGTH}}))?(?:\\.(\\d{1,${MAX_SAFE_COMPONENT_LENGTH}}))?`);
    createToken("COERCE", `${src[t.COERCEPLAIN]}(?:$|[^\\d])`);
    createToken("COERCEFULL", src[t.COERCEPLAIN] + `(?:${src[t.PRERELEASE]})?(?:${src[t.BUILD]})?(?:$|[^\\d])`);
    createToken("COERCERTL", src[t.COERCE], true);
    createToken("COERCERTLFULL", src[t.COERCEFULL], true);
    createToken("LONETILDE", "(?:~>?)");
    createToken("TILDETRIM", `(\\s*)${src[t.LONETILDE]}\\s+`, true);
    exports2.tildeTrimReplace = "$1~";
    createToken("TILDE", `^${src[t.LONETILDE]}${src[t.XRANGEPLAIN]}$`);
    createToken("TILDELOOSE", `^${src[t.LONETILDE]}${src[t.XRANGEPLAINLOOSE]}$`);
    createToken("LONECARET", "(?:\\^)");
    createToken("CARETTRIM", `(\\s*)${src[t.LONECARET]}\\s+`, true);
    exports2.caretTrimReplace = "$1^";
    createToken("CARET", `^${src[t.LONECARET]}${src[t.XRANGEPLAIN]}$`);
    createToken("CARETLOOSE", `^${src[t.LONECARET]}${src[t.XRANGEPLAINLOOSE]}$`);
    createToken("COMPARATORLOOSE", `^${src[t.GTLT]}\\s*(${src[t.LOOSEPLAIN]})$|^$`);
    createToken("COMPARATOR", `^${src[t.GTLT]}\\s*(${src[t.FULLPLAIN]})$|^$`);
    createToken("COMPARATORTRIM", `(\\s*)${src[t.GTLT]}\\s*(${src[t.LOOSEPLAIN]}|${src[t.XRANGEPLAIN]})`, true);
    exports2.comparatorTrimReplace = "$1$2$3";
    createToken("HYPHENRANGE", `^\\s*(${src[t.XRANGEPLAIN]})\\s+-\\s+(${src[t.XRANGEPLAIN]})\\s*$`);
    createToken("HYPHENRANGELOOSE", `^\\s*(${src[t.XRANGEPLAINLOOSE]})\\s+-\\s+(${src[t.XRANGEPLAINLOOSE]})\\s*$`);
    createToken("STAR", "(<|>)?=?\\s*\\*");
    createToken("GTE0", "^\\s*>=\\s*0\\.0\\.0\\s*$");
    createToken("GTE0PRE", "^\\s*>=\\s*0\\.0\\.0-0\\s*$");
  }
});

// ../../node_modules/semver/internal/parse-options.js
var require_parse_options2 = __commonJS({
  "../../node_modules/semver/internal/parse-options.js"(exports2, module2) {
    "use strict";
    var looseOption = Object.freeze({ loose: true });
    var emptyOpts = Object.freeze({});
    var parseOptions = /* @__PURE__ */ __name((options) => {
      if (!options) {
        return emptyOpts;
      }
      if (typeof options !== "object") {
        return looseOption;
      }
      return options;
    }, "parseOptions");
    module2.exports = parseOptions;
  }
});

// ../../node_modules/semver/internal/identifiers.js
var require_identifiers2 = __commonJS({
  "../../node_modules/semver/internal/identifiers.js"(exports2, module2) {
    "use strict";
    var numeric = /^[0-9]+$/;
    var compareIdentifiers = /* @__PURE__ */ __name((a32, b32) => {
      if (typeof a32 === "number" && typeof b32 === "number") {
        return a32 === b32 ? 0 : a32 < b32 ? -1 : 1;
      }
      const anum = numeric.test(a32);
      const bnum = numeric.test(b32);
      if (anum && bnum) {
        a32 = +a32;
        b32 = +b32;
      }
      return a32 === b32 ? 0 : anum && !bnum ? -1 : bnum && !anum ? 1 : a32 < b32 ? -1 : 1;
    }, "compareIdentifiers");
    var rcompareIdentifiers = /* @__PURE__ */ __name((a32, b32) => compareIdentifiers(b32, a32), "rcompareIdentifiers");
    module2.exports = {
      compareIdentifiers,
      rcompareIdentifiers
    };
  }
});

// ../../node_modules/semver/classes/semver.js
var require_semver3 = __commonJS({
  "../../node_modules/semver/classes/semver.js"(exports2, module2) {
    "use strict";
    var debug2 = require_debug2();
    var { MAX_LENGTH, MAX_SAFE_INTEGER } = require_constants6();
    var { safeRe: re, t } = require_re2();
    var parseOptions = require_parse_options2();
    var { compareIdentifiers } = require_identifiers2();
    var isPrereleaseIdentifier = /* @__PURE__ */ __name((prerelease, identifier) => {
      const identifiers = identifier.split(".");
      if (identifiers.length > prerelease.length) {
        return false;
      }
      for (let i32 = 0; i32 < identifiers.length; i32++) {
        if (compareIdentifiers(prerelease[i32], identifiers[i32]) !== 0) {
          return false;
        }
      }
      return true;
    }, "isPrereleaseIdentifier");
    var SemVer = class _SemVer {
      static {
        __name(this, "SemVer");
      }
      constructor(version, options) {
        options = parseOptions(options);
        if (version instanceof _SemVer) {
          if (version.loose === !!options.loose && version.includePrerelease === !!options.includePrerelease) {
            return version;
          } else {
            version = version.version;
          }
        } else if (typeof version !== "string") {
          throw new TypeError(`Invalid version. Must be a string. Got type "${typeof version}".`);
        }
        if (version.length > MAX_LENGTH) {
          throw new TypeError(
            `version is longer than ${MAX_LENGTH} characters`
          );
        }
        debug2("SemVer", version, options);
        this.options = options;
        this.loose = !!options.loose;
        this.includePrerelease = !!options.includePrerelease;
        const m20 = version.trim().match(options.loose ? re[t.LOOSE] : re[t.FULL]);
        if (!m20) {
          throw new TypeError(`Invalid Version: ${version}`);
        }
        this.raw = version;
        this.major = +m20[1];
        this.minor = +m20[2];
        this.patch = +m20[3];
        if (this.major > MAX_SAFE_INTEGER || this.major < 0) {
          throw new TypeError("Invalid major version");
        }
        if (this.minor > MAX_SAFE_INTEGER || this.minor < 0) {
          throw new TypeError("Invalid minor version");
        }
        if (this.patch > MAX_SAFE_INTEGER || this.patch < 0) {
          throw new TypeError("Invalid patch version");
        }
        if (!m20[4]) {
          this.prerelease = [];
        } else {
          this.prerelease = m20[4].split(".").map((id) => {
            if (/^[0-9]+$/.test(id)) {
              const num = +id;
              if (num >= 0 && num < MAX_SAFE_INTEGER) {
                return num;
              }
            }
            return id;
          });
        }
        this.build = m20[5] ? m20[5].split(".") : [];
        this.format();
      }
      format() {
        this.version = `${this.major}.${this.minor}.${this.patch}`;
        if (this.prerelease.length) {
          this.version += `-${this.prerelease.join(".")}`;
        }
        return this.version;
      }
      toString() {
        return this.version;
      }
      compare(other) {
        debug2("SemVer.compare", this.version, this.options, other);
        if (!(other instanceof _SemVer)) {
          if (typeof other === "string" && other === this.version) {
            return 0;
          }
          other = new _SemVer(other, this.options);
        }
        if (other.version === this.version) {
          return 0;
        }
        return this.compareMain(other) || this.comparePre(other);
      }
      compareMain(other) {
        if (!(other instanceof _SemVer)) {
          other = new _SemVer(other, this.options);
        }
        if (this.major < other.major) {
          return -1;
        }
        if (this.major > other.major) {
          return 1;
        }
        if (this.minor < other.minor) {
          return -1;
        }
        if (this.minor > other.minor) {
          return 1;
        }
        if (this.patch < other.patch) {
          return -1;
        }
        if (this.patch > other.patch) {
          return 1;
        }
        return 0;
      }
      comparePre(other) {
        if (!(other instanceof _SemVer)) {
          other = new _SemVer(other, this.options);
        }
        if (this.prerelease.length && !other.prerelease.length) {
          return -1;
        } else if (!this.prerelease.length && other.prerelease.length) {
          return 1;
        } else if (!this.prerelease.length && !other.prerelease.length) {
          return 0;
        }
        let i32 = 0;
        do {
          const a32 = this.prerelease[i32];
          const b32 = other.prerelease[i32];
          debug2("prerelease compare", i32, a32, b32);
          if (a32 === void 0 && b32 === void 0) {
            return 0;
          } else if (b32 === void 0) {
            return 1;
          } else if (a32 === void 0) {
            return -1;
          } else if (a32 === b32) {
            continue;
          } else {
            return compareIdentifiers(a32, b32);
          }
        } while (++i32);
      }
      compareBuild(other) {
        if (!(other instanceof _SemVer)) {
          other = new _SemVer(other, this.options);
        }
        let i32 = 0;
        do {
          const a32 = this.build[i32];
          const b32 = other.build[i32];
          debug2("build compare", i32, a32, b32);
          if (a32 === void 0 && b32 === void 0) {
            return 0;
          } else if (b32 === void 0) {
            return 1;
          } else if (a32 === void 0) {
            return -1;
          } else if (a32 === b32) {
            continue;
          } else {
            return compareIdentifiers(a32, b32);
          }
        } while (++i32);
      }
      // preminor will bump the version up to the next minor release, and immediately
      // down to pre-release. premajor and prepatch work the same way.
      inc(release3, identifier, identifierBase) {
        if (release3.startsWith("pre")) {
          if (!identifier && identifierBase === false) {
            throw new Error("invalid increment argument: identifier is empty");
          }
          if (identifier) {
            const match = `-${identifier}`.match(this.options.loose ? re[t.PRERELEASELOOSE] : re[t.PRERELEASE]);
            if (!match || match[1] !== identifier) {
              throw new Error(`invalid identifier: ${identifier}`);
            }
          }
        }
        switch (release3) {
          case "premajor":
            this.prerelease.length = 0;
            this.patch = 0;
            this.minor = 0;
            this.major++;
            this.inc("pre", identifier, identifierBase);
            break;
          case "preminor":
            this.prerelease.length = 0;
            this.patch = 0;
            this.minor++;
            this.inc("pre", identifier, identifierBase);
            break;
          case "prepatch":
            this.prerelease.length = 0;
            this.inc("patch", identifier, identifierBase);
            this.inc("pre", identifier, identifierBase);
            break;
          // If the input is a non-prerelease version, this acts the same as
          // prepatch.
          case "prerelease":
            if (this.prerelease.length === 0) {
              this.inc("patch", identifier, identifierBase);
            }
            this.inc("pre", identifier, identifierBase);
            break;
          case "release":
            if (this.prerelease.length === 0) {
              throw new Error(`version ${this.raw} is not a prerelease`);
            }
            this.prerelease.length = 0;
            break;
          case "major":
            if (this.minor !== 0 || this.patch !== 0 || this.prerelease.length === 0) {
              this.major++;
            }
            this.minor = 0;
            this.patch = 0;
            this.prerelease = [];
            break;
          case "minor":
            if (this.patch !== 0 || this.prerelease.length === 0) {
              this.minor++;
            }
            this.patch = 0;
            this.prerelease = [];
            break;
          case "patch":
            if (this.prerelease.length === 0) {
              this.patch++;
            }
            this.prerelease = [];
            break;
          // This probably shouldn't be used publicly.
          // 1.0.0 'pre' would become 1.0.0-0 which is the wrong direction.
          case "pre": {
            const base = Number(identifierBase) ? 1 : 0;
            if (this.prerelease.length === 0) {
              this.prerelease = [base];
            } else {
              let i32 = this.prerelease.length;
              while (--i32 >= 0) {
                if (typeof this.prerelease[i32] === "number") {
                  this.prerelease[i32]++;
                  i32 = -2;
                }
              }
              if (i32 === -1) {
                if (identifier === this.prerelease.join(".") && identifierBase === false) {
                  throw new Error("invalid increment argument: identifier already exists");
                }
                this.prerelease.push(base);
              }
            }
            if (identifier) {
              let prerelease = [identifier, base];
              if (identifierBase === false) {
                prerelease = [identifier];
              }
              if (isPrereleaseIdentifier(this.prerelease, identifier)) {
                const prereleaseBase = this.prerelease[identifier.split(".").length];
                if (isNaN(prereleaseBase)) {
                  this.prerelease = prerelease;
                }
              } else {
                this.prerelease = prerelease;
              }
            }
            break;
          }
          default:
            throw new Error(`invalid increment argument: ${release3}`);
        }
        this.raw = this.format();
        if (this.build.length) {
          this.raw += `+${this.build.join(".")}`;
        }
        return this;
      }
    };
    module2.exports = SemVer;
  }
});

// ../../node_modules/semver/functions/parse.js
var require_parse5 = __commonJS({
  "../../node_modules/semver/functions/parse.js"(exports2, module2) {
    "use strict";
    var SemVer = require_semver3();
    var parse2 = /* @__PURE__ */ __name((version, options, throwErrors = false) => {
      if (version instanceof SemVer) {
        return version;
      }
      try {
        return new SemVer(version, options);
      } catch (er) {
        if (!throwErrors) {
          return null;
        }
        throw er;
      }
    }, "parse");
    module2.exports = parse2;
  }
});

// ../../node_modules/semver/functions/valid.js
var require_valid3 = __commonJS({
  "../../node_modules/semver/functions/valid.js"(exports2, module2) {
    "use strict";
    var parse2 = require_parse5();
    var valid3 = /* @__PURE__ */ __name((version, options) => {
      const v = parse2(version, options);
      return v ? v.version : null;
    }, "valid");
    module2.exports = valid3;
  }
});

// ../../node_modules/semver/functions/clean.js
var require_clean2 = __commonJS({
  "../../node_modules/semver/functions/clean.js"(exports2, module2) {
    "use strict";
    var parse2 = require_parse5();
    var clean = /* @__PURE__ */ __name((version, options) => {
      const s = parse2(version.trim().replace(/^[=v]+/, ""), options);
      return s ? s.version : null;
    }, "clean");
    module2.exports = clean;
  }
});

// ../../node_modules/semver/functions/inc.js
var require_inc2 = __commonJS({
  "../../node_modules/semver/functions/inc.js"(exports2, module2) {
    "use strict";
    var SemVer = require_semver3();
    var inc = /* @__PURE__ */ __name((version, release3, options, identifier, identifierBase) => {
      if (typeof options === "string") {
        identifierBase = identifier;
        identifier = options;
        options = void 0;
      }
      try {
        return new SemVer(
          version instanceof SemVer ? version.version : version,
          options
        ).inc(release3, identifier, identifierBase).version;
      } catch (er) {
        return null;
      }
    }, "inc");
    module2.exports = inc;
  }
});

// ../../node_modules/semver/functions/diff.js
var require_diff2 = __commonJS({
  "../../node_modules/semver/functions/diff.js"(exports2, module2) {
    "use strict";
    var parse2 = require_parse5();
    var diff = /* @__PURE__ */ __name((version1, version2) => {
      const v1 = parse2(version1, null, true);
      const v2 = parse2(version2, null, true);
      const comparison = v1.compare(v2);
      if (comparison === 0) {
        return null;
      }
      const v1Higher = comparison > 0;
      const highVersion = v1Higher ? v1 : v2;
      const lowVersion = v1Higher ? v2 : v1;
      const highHasPre = !!highVersion.prerelease.length;
      const lowHasPre = !!lowVersion.prerelease.length;
      if (lowHasPre && !highHasPre) {
        if (!lowVersion.patch && !lowVersion.minor) {
          return "major";
        }
        if (lowVersion.compareMain(highVersion) === 0) {
          if (lowVersion.minor && !lowVersion.patch) {
            return "minor";
          }
          return "patch";
        }
      }
      const prefix = highHasPre ? "pre" : "";
      if (v1.major !== v2.major) {
        return prefix + "major";
      }
      if (v1.minor !== v2.minor) {
        return prefix + "minor";
      }
      if (v1.patch !== v2.patch) {
        return prefix + "patch";
      }
      return "prerelease";
    }, "diff");
    module2.exports = diff;
  }
});

// ../../node_modules/semver/functions/major.js
var require_major2 = __commonJS({
  "../../node_modules/semver/functions/major.js"(exports2, module2) {
    "use strict";
    var SemVer = require_semver3();
    var major6 = /* @__PURE__ */ __name((a32, loose) => new SemVer(a32, loose).major, "major");
    module2.exports = major6;
  }
});

// ../../node_modules/semver/functions/minor.js
var require_minor2 = __commonJS({
  "../../node_modules/semver/functions/minor.js"(exports2, module2) {
    "use strict";
    var SemVer = require_semver3();
    var minor = /* @__PURE__ */ __name((a32, loose) => new SemVer(a32, loose).minor, "minor");
    module2.exports = minor;
  }
});

// ../../node_modules/semver/functions/patch.js
var require_patch2 = __commonJS({
  "../../node_modules/semver/functions/patch.js"(exports2, module2) {
    "use strict";
    var SemVer = require_semver3();
    var patch = /* @__PURE__ */ __name((a32, loose) => new SemVer(a32, loose).patch, "patch");
    module2.exports = patch;
  }
});

// ../../node_modules/semver/functions/prerelease.js
var require_prerelease2 = __commonJS({
  "../../node_modules/semver/functions/prerelease.js"(exports2, module2) {
    "use strict";
    var parse2 = require_parse5();
    var prerelease = /* @__PURE__ */ __name((version, options) => {
      const parsed = parse2(version, options);
      return parsed && parsed.prerelease.length ? parsed.prerelease : null;
    }, "prerelease");
    module2.exports = prerelease;
  }
});

// ../../node_modules/semver/functions/compare.js
var require_compare2 = __commonJS({
  "../../node_modules/semver/functions/compare.js"(exports2, module2) {
    "use strict";
    var SemVer = require_semver3();
    var compare2 = /* @__PURE__ */ __name((a32, b32, loose) => new SemVer(a32, loose).compare(new SemVer(b32, loose)), "compare");
    module2.exports = compare2;
  }
});

// ../../node_modules/semver/functions/rcompare.js
var require_rcompare2 = __commonJS({
  "../../node_modules/semver/functions/rcompare.js"(exports2, module2) {
    "use strict";
    var compare2 = require_compare2();
    var rcompare = /* @__PURE__ */ __name((a32, b32, loose) => compare2(b32, a32, loose), "rcompare");
    module2.exports = rcompare;
  }
});

// ../../node_modules/semver/functions/compare-loose.js
var require_compare_loose2 = __commonJS({
  "../../node_modules/semver/functions/compare-loose.js"(exports2, module2) {
    "use strict";
    var compare2 = require_compare2();
    var compareLoose = /* @__PURE__ */ __name((a32, b32) => compare2(a32, b32, true), "compareLoose");
    module2.exports = compareLoose;
  }
});

// ../../node_modules/semver/functions/compare-build.js
var require_compare_build2 = __commonJS({
  "../../node_modules/semver/functions/compare-build.js"(exports2, module2) {
    "use strict";
    var SemVer = require_semver3();
    var compareBuild = /* @__PURE__ */ __name((a32, b32, loose) => {
      const versionA = new SemVer(a32, loose);
      const versionB = new SemVer(b32, loose);
      return versionA.compare(versionB) || versionA.compareBuild(versionB);
    }, "compareBuild");
    module2.exports = compareBuild;
  }
});

// ../../node_modules/semver/functions/sort.js
var require_sort2 = __commonJS({
  "../../node_modules/semver/functions/sort.js"(exports2, module2) {
    "use strict";
    var compareBuild = require_compare_build2();
    var sort = /* @__PURE__ */ __name((list3, loose) => list3.sort((a32, b32) => compareBuild(a32, b32, loose)), "sort");
    module2.exports = sort;
  }
});

// ../../node_modules/semver/functions/rsort.js
var require_rsort2 = __commonJS({
  "../../node_modules/semver/functions/rsort.js"(exports2, module2) {
    "use strict";
    var compareBuild = require_compare_build2();
    var rsort = /* @__PURE__ */ __name((list3, loose) => list3.sort((a32, b32) => compareBuild(b32, a32, loose)), "rsort");
    module2.exports = rsort;
  }
});

// ../../node_modules/semver/functions/gt.js
var require_gt2 = __commonJS({
  "../../node_modules/semver/functions/gt.js"(exports2, module2) {
    "use strict";
    var compare2 = require_compare2();
    var gt = /* @__PURE__ */ __name((a32, b32, loose) => compare2(a32, b32, loose) > 0, "gt");
    module2.exports = gt;
  }
});

// ../../node_modules/semver/functions/lt.js
var require_lt2 = __commonJS({
  "../../node_modules/semver/functions/lt.js"(exports2, module2) {
    "use strict";
    var compare2 = require_compare2();
    var lt = /* @__PURE__ */ __name((a32, b32, loose) => compare2(a32, b32, loose) < 0, "lt");
    module2.exports = lt;
  }
});

// ../../node_modules/semver/functions/eq.js
var require_eq2 = __commonJS({
  "../../node_modules/semver/functions/eq.js"(exports2, module2) {
    "use strict";
    var compare2 = require_compare2();
    var eq2 = /* @__PURE__ */ __name((a32, b32, loose) => compare2(a32, b32, loose) === 0, "eq");
    module2.exports = eq2;
  }
});

// ../../node_modules/semver/functions/neq.js
var require_neq2 = __commonJS({
  "../../node_modules/semver/functions/neq.js"(exports2, module2) {
    "use strict";
    var compare2 = require_compare2();
    var neq = /* @__PURE__ */ __name((a32, b32, loose) => compare2(a32, b32, loose) !== 0, "neq");
    module2.exports = neq;
  }
});

// ../../node_modules/semver/functions/gte.js
var require_gte2 = __commonJS({
  "../../node_modules/semver/functions/gte.js"(exports2, module2) {
    "use strict";
    var compare2 = require_compare2();
    var gte = /* @__PURE__ */ __name((a32, b32, loose) => compare2(a32, b32, loose) >= 0, "gte");
    module2.exports = gte;
  }
});

// ../../node_modules/semver/functions/lte.js
var require_lte2 = __commonJS({
  "../../node_modules/semver/functions/lte.js"(exports2, module2) {
    "use strict";
    var compare2 = require_compare2();
    var lte2 = /* @__PURE__ */ __name((a32, b32, loose) => compare2(a32, b32, loose) <= 0, "lte");
    module2.exports = lte2;
  }
});

// ../../node_modules/semver/functions/cmp.js
var require_cmp2 = __commonJS({
  "../../node_modules/semver/functions/cmp.js"(exports2, module2) {
    "use strict";
    var eq2 = require_eq2();
    var neq = require_neq2();
    var gt = require_gt2();
    var gte = require_gte2();
    var lt = require_lt2();
    var lte2 = require_lte2();
    var cmp = /* @__PURE__ */ __name((a32, op3, b32, loose) => {
      switch (op3) {
        case "===":
          if (typeof a32 === "object") {
            a32 = a32.version;
          }
          if (typeof b32 === "object") {
            b32 = b32.version;
          }
          return a32 === b32;
        case "!==":
          if (typeof a32 === "object") {
            a32 = a32.version;
          }
          if (typeof b32 === "object") {
            b32 = b32.version;
          }
          return a32 !== b32;
        case "":
        case "=":
        case "==":
          return eq2(a32, b32, loose);
        case "!=":
          return neq(a32, b32, loose);
        case ">":
          return gt(a32, b32, loose);
        case ">=":
          return gte(a32, b32, loose);
        case "<":
          return lt(a32, b32, loose);
        case "<=":
          return lte2(a32, b32, loose);
        default:
          throw new TypeError(`Invalid operator: ${op3}`);
      }
    }, "cmp");
    module2.exports = cmp;
  }
});

// ../../node_modules/semver/functions/coerce.js
var require_coerce2 = __commonJS({
  "../../node_modules/semver/functions/coerce.js"(exports2, module2) {
    "use strict";
    var SemVer = require_semver3();
    var parse2 = require_parse5();
    var { safeRe: re, t } = require_re2();
    var coerce2 = /* @__PURE__ */ __name((version, options) => {
      if (version instanceof SemVer) {
        return version;
      }
      if (typeof version === "number") {
        version = String(version);
      }
      if (typeof version !== "string") {
        return null;
      }
      options = options || {};
      let match = null;
      if (!options.rtl) {
        match = version.match(options.includePrerelease ? re[t.COERCEFULL] : re[t.COERCE]);
      } else {
        const coerceRtlRegex = options.includePrerelease ? re[t.COERCERTLFULL] : re[t.COERCERTL];
        let next;
        while ((next = coerceRtlRegex.exec(version)) && (!match || match.index + match[0].length !== version.length)) {
          if (!match || next.index + next[0].length !== match.index + match[0].length) {
            match = next;
          }
          coerceRtlRegex.lastIndex = next.index + next[1].length + next[2].length;
        }
        coerceRtlRegex.lastIndex = -1;
      }
      if (match === null) {
        return null;
      }
      const major6 = match[2];
      const minor = match[3] || "0";
      const patch = match[4] || "0";
      const prerelease = options.includePrerelease && match[5] ? `-${match[5]}` : "";
      const build = options.includePrerelease && match[6] ? `+${match[6]}` : "";
      return parse2(`${major6}.${minor}.${patch}${prerelease}${build}`, options);
    }, "coerce");
    module2.exports = coerce2;
  }
});

// ../../node_modules/semver/functions/truncate.js
var require_truncate2 = __commonJS({
  "../../node_modules/semver/functions/truncate.js"(exports2, module2) {
    "use strict";
    var parse2 = require_parse5();
    var constants3 = require_constants6();
    var SemVer = require_semver3();
    var truncate = /* @__PURE__ */ __name((version, truncation, options) => {
      if (!constants3.RELEASE_TYPES.includes(truncation)) {
        return null;
      }
      const clonedVersion = cloneInputVersion(version, options);
      return clonedVersion && doTruncation(clonedVersion, truncation);
    }, "truncate");
    var cloneInputVersion = /* @__PURE__ */ __name((version, options) => {
      const versionStringToParse = version instanceof SemVer ? version.version : version;
      return parse2(versionStringToParse, options);
    }, "cloneInputVersion");
    var doTruncation = /* @__PURE__ */ __name((version, truncation) => {
      if (isPrerelease(truncation)) {
        return version.version;
      }
      version.prerelease = [];
      switch (truncation) {
        case "major":
          version.minor = 0;
          version.patch = 0;
          break;
        case "minor":
          version.patch = 0;
          break;
      }
      return version.format();
    }, "doTruncation");
    var isPrerelease = /* @__PURE__ */ __name((type) => {
      return type.startsWith("pre");
    }, "isPrerelease");
    module2.exports = truncate;
  }
});

// ../../node_modules/semver/internal/lrucache.js
var require_lrucache2 = __commonJS({
  "../../node_modules/semver/internal/lrucache.js"(exports2, module2) {
    "use strict";
    var LRUCache = class {
      static {
        __name(this, "LRUCache");
      }
      constructor() {
        this.max = 1e3;
        this.map = /* @__PURE__ */ new Map();
      }
      get(key) {
        const value = this.map.get(key);
        if (value === void 0) {
          return void 0;
        } else {
          this.map.delete(key);
          this.map.set(key, value);
          return value;
        }
      }
      delete(key) {
        return this.map.delete(key);
      }
      set(key, value) {
        const deleted = this.delete(key);
        if (!deleted && value !== void 0) {
          if (this.map.size >= this.max) {
            const firstKey = this.map.keys().next().value;
            this.delete(firstKey);
          }
          this.map.set(key, value);
        }
        return this;
      }
    };
    module2.exports = LRUCache;
  }
});

// ../../node_modules/semver/classes/range.js
var require_range2 = __commonJS({
  "../../node_modules/semver/classes/range.js"(exports2, module2) {
    "use strict";
    var SPACE_CHARACTERS = /\s+/g;
    var Range = class _Range {
      static {
        __name(this, "Range");
      }
      constructor(range7, options) {
        options = parseOptions(options);
        if (range7 instanceof _Range) {
          if (range7.loose === !!options.loose && range7.includePrerelease === !!options.includePrerelease) {
            return range7;
          } else {
            return new _Range(range7.raw, options);
          }
        }
        if (range7 instanceof Comparator) {
          this.raw = range7.value;
          this.set = [[range7]];
          this.formatted = void 0;
          return this;
        }
        this.options = options;
        this.loose = !!options.loose;
        this.includePrerelease = !!options.includePrerelease;
        this.raw = range7.trim().replace(SPACE_CHARACTERS, " ");
        this.set = this.raw.split("||").map((r32) => this.parseRange(r32.trim())).filter((c32) => c32.length);
        if (!this.set.length) {
          throw new TypeError(`Invalid SemVer Range: ${this.raw}`);
        }
        if (this.set.length > 1) {
          const first = this.set[0];
          this.set = this.set.filter((c32) => !isNullSet(c32[0]));
          if (this.set.length === 0) {
            this.set = [first];
          } else if (this.set.length > 1) {
            for (const c32 of this.set) {
              if (c32.length === 1 && isAny(c32[0])) {
                this.set = [c32];
                break;
              }
            }
          }
        }
        this.formatted = void 0;
      }
      get range() {
        if (this.formatted === void 0) {
          this.formatted = "";
          for (let i32 = 0; i32 < this.set.length; i32++) {
            if (i32 > 0) {
              this.formatted += "||";
            }
            const comps = this.set[i32];
            for (let k32 = 0; k32 < comps.length; k32++) {
              if (k32 > 0) {
                this.formatted += " ";
              }
              this.formatted += comps[k32].toString().trim();
            }
          }
        }
        return this.formatted;
      }
      format() {
        return this.range;
      }
      toString() {
        return this.range;
      }
      parseRange(range7) {
        range7 = range7.replace(BUILDSTRIPRE, "");
        const memoOpts = (this.options.includePrerelease && FLAG_INCLUDE_PRERELEASE) | (this.options.loose && FLAG_LOOSE);
        const memoKey = memoOpts + ":" + range7;
        const cached3 = cache32.get(memoKey);
        if (cached3) {
          return cached3;
        }
        const loose = this.options.loose;
        const hr = loose ? re[t.HYPHENRANGELOOSE] : re[t.HYPHENRANGE];
        range7 = range7.replace(hr, hyphenReplace(this.options.includePrerelease));
        debug2("hyphen replace", range7);
        range7 = range7.replace(re[t.COMPARATORTRIM], comparatorTrimReplace);
        debug2("comparator trim", range7);
        range7 = range7.replace(re[t.TILDETRIM], tildeTrimReplace);
        debug2("tilde trim", range7);
        range7 = range7.replace(re[t.CARETTRIM], caretTrimReplace);
        debug2("caret trim", range7);
        let rangeList = range7.split(" ").map((comp) => parseComparator(comp, this.options)).join(" ").split(/\s+/).map((comp) => replaceGTE0(comp, this.options));
        if (loose) {
          rangeList = rangeList.filter((comp) => {
            debug2("loose invalid filter", comp, this.options);
            return !!comp.match(re[t.COMPARATORLOOSE]);
          });
        }
        debug2("range list", rangeList);
        const rangeMap = /* @__PURE__ */ new Map();
        const comparators = rangeList.map((comp) => new Comparator(comp, this.options));
        for (const comp of comparators) {
          if (isNullSet(comp)) {
            return [comp];
          }
          rangeMap.set(comp.value, comp);
        }
        if (rangeMap.size > 1 && rangeMap.has("")) {
          rangeMap.delete("");
        }
        const result2 = [...rangeMap.values()];
        cache32.set(memoKey, result2);
        return result2;
      }
      intersects(range7, options) {
        if (!(range7 instanceof _Range)) {
          throw new TypeError("a Range is required");
        }
        return this.set.some((thisComparators) => {
          return isSatisfiable(thisComparators, options) && range7.set.some((rangeComparators) => {
            return isSatisfiable(rangeComparators, options) && thisComparators.every((thisComparator) => {
              return rangeComparators.every((rangeComparator) => {
                return thisComparator.intersects(rangeComparator, options);
              });
            });
          });
        });
      }
      // if ANY of the sets match ALL of its comparators, then pass
      test(version) {
        if (!version) {
          return false;
        }
        if (typeof version === "string") {
          try {
            version = new SemVer(version, this.options);
          } catch (er) {
            return false;
          }
        }
        for (let i32 = 0; i32 < this.set.length; i32++) {
          if (testSet(this.set[i32], version, this.options)) {
            return true;
          }
        }
        return false;
      }
    };
    module2.exports = Range;
    var LRU = require_lrucache2();
    var cache32 = new LRU();
    var parseOptions = require_parse_options2();
    var Comparator = require_comparator2();
    var debug2 = require_debug2();
    var SemVer = require_semver3();
    var {
      safeRe: re,
      src,
      t,
      comparatorTrimReplace,
      tildeTrimReplace,
      caretTrimReplace
    } = require_re2();
    var { FLAG_INCLUDE_PRERELEASE, FLAG_LOOSE } = require_constants6();
    var BUILDSTRIPRE = new RegExp(src[t.BUILD], "g");
    var isNullSet = /* @__PURE__ */ __name((c32) => c32.value === "<0.0.0-0", "isNullSet");
    var isAny = /* @__PURE__ */ __name((c32) => c32.value === "", "isAny");
    var isSatisfiable = /* @__PURE__ */ __name((comparators, options) => {
      let result2 = true;
      const remainingComparators = comparators.slice();
      let testComparator = remainingComparators.pop();
      while (result2 && remainingComparators.length) {
        result2 = remainingComparators.every((otherComparator) => {
          return testComparator.intersects(otherComparator, options);
        });
        testComparator = remainingComparators.pop();
      }
      return result2;
    }, "isSatisfiable");
    var parseComparator = /* @__PURE__ */ __name((comp, options) => {
      comp = comp.replace(re[t.BUILD], "");
      debug2("comp", comp, options);
      comp = replaceCarets(comp, options);
      debug2("caret", comp);
      comp = replaceTildes(comp, options);
      debug2("tildes", comp);
      comp = replaceXRanges(comp, options);
      debug2("xrange", comp);
      comp = replaceStars(comp, options);
      debug2("stars", comp);
      return comp;
    }, "parseComparator");
    var isX = /* @__PURE__ */ __name((id) => !id || id.toLowerCase() === "x" || id === "*", "isX");
    var invalidXRangeOrder = /* @__PURE__ */ __name((M, m20, p10) => isX(M) && !isX(m20) || isX(m20) && p10 && !isX(p10), "invalidXRangeOrder");
    var replaceTildes = /* @__PURE__ */ __name((comp, options) => {
      return comp.trim().split(/\s+/).map((c32) => replaceTilde(c32, options)).join(" ");
    }, "replaceTildes");
    var replaceTilde = /* @__PURE__ */ __name((comp, options) => {
      const r32 = options.loose ? re[t.TILDELOOSE] : re[t.TILDE];
      return comp.replace(r32, (_, M, m20, p10, pr) => {
        debug2("tilde", comp, _, M, m20, p10, pr);
        let ret;
        if (isX(M)) {
          ret = "";
        } else if (isX(m20)) {
          ret = `>=${M}.0.0 <${+M + 1}.0.0-0`;
        } else if (isX(p10)) {
          ret = `>=${M}.${m20}.0 <${M}.${+m20 + 1}.0-0`;
        } else if (pr) {
          debug2("replaceTilde pr", pr);
          ret = `>=${M}.${m20}.${p10}-${pr} <${M}.${+m20 + 1}.0-0`;
        } else {
          ret = `>=${M}.${m20}.${p10} <${M}.${+m20 + 1}.0-0`;
        }
        debug2("tilde return", ret);
        return ret;
      });
    }, "replaceTilde");
    var replaceCarets = /* @__PURE__ */ __name((comp, options) => {
      return comp.trim().split(/\s+/).map((c32) => replaceCaret(c32, options)).join(" ");
    }, "replaceCarets");
    var replaceCaret = /* @__PURE__ */ __name((comp, options) => {
      debug2("caret", comp, options);
      const r32 = options.loose ? re[t.CARETLOOSE] : re[t.CARET];
      const z = options.includePrerelease ? "-0" : "";
      return comp.replace(r32, (_, M, m20, p10, pr) => {
        debug2("caret", comp, _, M, m20, p10, pr);
        let ret;
        if (isX(M)) {
          ret = "";
        } else if (isX(m20)) {
          ret = `>=${M}.0.0${z} <${+M + 1}.0.0-0`;
        } else if (isX(p10)) {
          if (M === "0") {
            ret = `>=${M}.${m20}.0${z} <${M}.${+m20 + 1}.0-0`;
          } else {
            ret = `>=${M}.${m20}.0${z} <${+M + 1}.0.0-0`;
          }
        } else if (pr) {
          debug2("replaceCaret pr", pr);
          if (M === "0") {
            if (m20 === "0") {
              ret = `>=${M}.${m20}.${p10}-${pr} <${M}.${m20}.${+p10 + 1}-0`;
            } else {
              ret = `>=${M}.${m20}.${p10}-${pr} <${M}.${+m20 + 1}.0-0`;
            }
          } else {
            ret = `>=${M}.${m20}.${p10}-${pr} <${+M + 1}.0.0-0`;
          }
        } else {
          debug2("no pr");
          if (M === "0") {
            if (m20 === "0") {
              ret = `>=${M}.${m20}.${p10} <${M}.${m20}.${+p10 + 1}-0`;
            } else {
              ret = `>=${M}.${m20}.${p10} <${M}.${+m20 + 1}.0-0`;
            }
          } else {
            ret = `>=${M}.${m20}.${p10} <${+M + 1}.0.0-0`;
          }
        }
        debug2("caret return", ret);
        return ret;
      });
    }, "replaceCaret");
    var replaceXRanges = /* @__PURE__ */ __name((comp, options) => {
      debug2("replaceXRanges", comp, options);
      return comp.split(/\s+/).map((c32) => replaceXRange(c32, options)).join(" ");
    }, "replaceXRanges");
    var replaceXRange = /* @__PURE__ */ __name((comp, options) => {
      comp = comp.trim();
      const r32 = options.loose ? re[t.XRANGELOOSE] : re[t.XRANGE];
      return comp.replace(r32, (ret, gtlt, M, m20, p10, pr) => {
        debug2("xRange", comp, ret, gtlt, M, m20, p10, pr);
        if (invalidXRangeOrder(M, m20, p10)) {
          return comp;
        }
        const xM = isX(M);
        const xm = xM || isX(m20);
        const xp = xm || isX(p10);
        const anyX = xp;
        if (gtlt === "=" && anyX) {
          gtlt = "";
        }
        pr = options.includePrerelease ? "-0" : "";
        if (xM) {
          if (gtlt === ">" || gtlt === "<") {
            ret = "<0.0.0-0";
          } else {
            ret = "*";
          }
        } else if (gtlt && anyX) {
          if (xm) {
            m20 = 0;
          }
          p10 = 0;
          if (gtlt === ">") {
            gtlt = ">=";
            if (xm) {
              M = +M + 1;
              m20 = 0;
              p10 = 0;
            } else {
              m20 = +m20 + 1;
              p10 = 0;
            }
          } else if (gtlt === "<=") {
            gtlt = "<";
            if (xm) {
              M = +M + 1;
            } else {
              m20 = +m20 + 1;
            }
          }
          if (gtlt === "<") {
            pr = "-0";
          }
          ret = `${gtlt + M}.${m20}.${p10}${pr}`;
        } else if (xm) {
          ret = `>=${M}.0.0${pr} <${+M + 1}.0.0-0`;
        } else if (xp) {
          ret = `>=${M}.${m20}.0${pr} <${M}.${+m20 + 1}.0-0`;
        }
        debug2("xRange return", ret);
        return ret;
      });
    }, "replaceXRange");
    var replaceStars = /* @__PURE__ */ __name((comp, options) => {
      debug2("replaceStars", comp, options);
      return comp.trim().replace(re[t.STAR], "");
    }, "replaceStars");
    var replaceGTE0 = /* @__PURE__ */ __name((comp, options) => {
      debug2("replaceGTE0", comp, options);
      return comp.trim().replace(re[options.includePrerelease ? t.GTE0PRE : t.GTE0], "");
    }, "replaceGTE0");
    var hyphenReplace = /* @__PURE__ */ __name((incPr) => ($0, from, fM, fm, fp, fpr, fb, to, tM, tm, tp, tpr) => {
      if (isX(fM)) {
        from = "";
      } else if (isX(fm)) {
        from = `>=${fM}.0.0${incPr ? "-0" : ""}`;
      } else if (isX(fp)) {
        from = `>=${fM}.${fm}.0${incPr ? "-0" : ""}`;
      } else if (fpr) {
        from = `>=${from}`;
      } else {
        from = `>=${from}${incPr ? "-0" : ""}`;
      }
      if (isX(tM)) {
        to = "";
      } else if (isX(tm)) {
        to = `<${+tM + 1}.0.0-0`;
      } else if (isX(tp)) {
        to = `<${tM}.${+tm + 1}.0-0`;
      } else if (tpr) {
        to = `<=${tM}.${tm}.${tp}-${tpr}`;
      } else if (incPr) {
        to = `<${tM}.${tm}.${+tp + 1}-0`;
      } else {
        to = `<=${to}`;
      }
      return `${from} ${to}`.trim();
    }, "hyphenReplace");
    var testSet = /* @__PURE__ */ __name((set, version, options) => {
      for (let i32 = 0; i32 < set.length; i32++) {
        if (!set[i32].test(version)) {
          return false;
        }
      }
      if (version.prerelease.length && !options.includePrerelease) {
        for (let i32 = 0; i32 < set.length; i32++) {
          debug2(set[i32].semver);
          if (set[i32].semver === Comparator.ANY) {
            continue;
          }
          if (set[i32].semver.prerelease.length > 0) {
            const allowed = set[i32].semver;
            if (allowed.major === version.major && allowed.minor === version.minor && allowed.patch === version.patch) {
              return true;
            }
          }
        }
        return false;
      }
      return true;
    }, "testSet");
  }
});

// ../../node_modules/semver/classes/comparator.js
var require_comparator2 = __commonJS({
  "../../node_modules/semver/classes/comparator.js"(exports2, module2) {
    "use strict";
    var ANY = /* @__PURE__ */ Symbol("SemVer ANY");
    var Comparator = class _Comparator {
      static {
        __name(this, "Comparator");
      }
      static get ANY() {
        return ANY;
      }
      constructor(comp, options) {
        options = parseOptions(options);
        if (comp instanceof _Comparator) {
          if (comp.loose === !!options.loose) {
            return comp;
          } else {
            comp = comp.value;
          }
        }
        comp = comp.trim().split(/\s+/).join(" ");
        debug2("comparator", comp, options);
        this.options = options;
        this.loose = !!options.loose;
        this.parse(comp);
        if (this.semver === ANY) {
          this.value = "";
        } else {
          this.value = this.operator + this.semver.version;
        }
        debug2("comp", this);
      }
      parse(comp) {
        const r32 = this.options.loose ? re[t.COMPARATORLOOSE] : re[t.COMPARATOR];
        const m20 = comp.match(r32);
        if (!m20) {
          throw new TypeError(`Invalid comparator: ${comp}`);
        }
        this.operator = m20[1] !== void 0 ? m20[1] : "";
        if (this.operator === "=") {
          this.operator = "";
        }
        if (!m20[2]) {
          this.semver = ANY;
        } else {
          this.semver = new SemVer(m20[2], this.options.loose);
        }
      }
      toString() {
        return this.value;
      }
      test(version) {
        debug2("Comparator.test", version, this.options.loose);
        if (this.semver === ANY || version === ANY) {
          return true;
        }
        if (typeof version === "string") {
          try {
            version = new SemVer(version, this.options);
          } catch (er) {
            return false;
          }
        }
        return cmp(version, this.operator, this.semver, this.options);
      }
      intersects(comp, options) {
        if (!(comp instanceof _Comparator)) {
          throw new TypeError("a Comparator is required");
        }
        if (this.operator === "") {
          if (this.value === "") {
            return true;
          }
          return new Range(comp.value, options).test(this.value);
        } else if (comp.operator === "") {
          if (comp.value === "") {
            return true;
          }
          return new Range(this.value, options).test(comp.semver);
        }
        options = parseOptions(options);
        if (options.includePrerelease && (this.value === "<0.0.0-0" || comp.value === "<0.0.0-0")) {
          return false;
        }
        if (!options.includePrerelease && (this.value.startsWith("<0.0.0") || comp.value.startsWith("<0.0.0"))) {
          return false;
        }
        if (this.operator.startsWith(">") && comp.operator.startsWith(">")) {
          return true;
        }
        if (this.operator.startsWith("<") && comp.operator.startsWith("<")) {
          return true;
        }
        if (this.semver.version === comp.semver.version && this.operator.includes("=") && comp.operator.includes("=")) {
          return true;
        }
        if (cmp(this.semver, "<", comp.semver, options) && this.operator.startsWith(">") && comp.operator.startsWith("<")) {
          return true;
        }
        if (cmp(this.semver, ">", comp.semver, options) && this.operator.startsWith("<") && comp.operator.startsWith(">")) {
          return true;
        }
        return false;
      }
    };
    module2.exports = Comparator;
    var parseOptions = require_parse_options2();
    var { safeRe: re, t } = require_re2();
    var cmp = require_cmp2();
    var debug2 = require_debug2();
    var SemVer = require_semver3();
    var Range = require_range2();
  }
});

// ../../node_modules/semver/functions/satisfies.js
var require_satisfies2 = __commonJS({
  "../../node_modules/semver/functions/satisfies.js"(exports2, module2) {
    "use strict";
    var Range = require_range2();
    var satisfies2 = /* @__PURE__ */ __name((version, range7, options) => {
      try {
        range7 = new Range(range7, options);
      } catch (er) {
        return false;
      }
      return range7.test(version);
    }, "satisfies");
    module2.exports = satisfies2;
  }
});

// ../../node_modules/semver/ranges/to-comparators.js
var require_to_comparators2 = __commonJS({
  "../../node_modules/semver/ranges/to-comparators.js"(exports2, module2) {
    "use strict";
    var Range = require_range2();
    var toComparators = /* @__PURE__ */ __name((range7, options) => new Range(range7, options).set.map((comp) => comp.map((c32) => c32.value).join(" ").trim().split(" ")), "toComparators");
    module2.exports = toComparators;
  }
});

// ../../node_modules/semver/ranges/max-satisfying.js
var require_max_satisfying2 = __commonJS({
  "../../node_modules/semver/ranges/max-satisfying.js"(exports2, module2) {
    "use strict";
    var SemVer = require_semver3();
    var Range = require_range2();
    var maxSatisfying = /* @__PURE__ */ __name((versions2, range7, options) => {
      let max = null;
      let maxSV = null;
      let rangeObj = null;
      try {
        rangeObj = new Range(range7, options);
      } catch (er) {
        return null;
      }
      versions2.forEach((v) => {
        if (rangeObj.test(v)) {
          if (!max || maxSV.compare(v) === -1) {
            max = v;
            maxSV = new SemVer(max, options);
          }
        }
      });
      return max;
    }, "maxSatisfying");
    module2.exports = maxSatisfying;
  }
});

// ../../node_modules/semver/ranges/min-satisfying.js
var require_min_satisfying2 = __commonJS({
  "../../node_modules/semver/ranges/min-satisfying.js"(exports2, module2) {
    "use strict";
    var SemVer = require_semver3();
    var Range = require_range2();
    var minSatisfying = /* @__PURE__ */ __name((versions2, range7, options) => {
      let min = null;
      let minSV = null;
      let rangeObj = null;
      try {
        rangeObj = new Range(range7, options);
      } catch (er) {
        return null;
      }
      versions2.forEach((v) => {
        if (rangeObj.test(v)) {
          if (!min || minSV.compare(v) === 1) {
            min = v;
            minSV = new SemVer(min, options);
          }
        }
      });
      return min;
    }, "minSatisfying");
    module2.exports = minSatisfying;
  }
});

// ../../node_modules/semver/ranges/min-version.js
var require_min_version2 = __commonJS({
  "../../node_modules/semver/ranges/min-version.js"(exports2, module2) {
    "use strict";
    var SemVer = require_semver3();
    var Range = require_range2();
    var gt = require_gt2();
    var minVersion = /* @__PURE__ */ __name((range7, loose) => {
      range7 = new Range(range7, loose);
      let minver = new SemVer("0.0.0");
      if (range7.test(minver)) {
        return minver;
      }
      minver = new SemVer("0.0.0-0");
      if (range7.test(minver)) {
        return minver;
      }
      minver = null;
      for (let i32 = 0; i32 < range7.set.length; ++i32) {
        const comparators = range7.set[i32];
        let setMin = null;
        comparators.forEach((comparator) => {
          const compver = new SemVer(comparator.semver.version);
          switch (comparator.operator) {
            case ">":
              if (compver.prerelease.length === 0) {
                compver.patch++;
              } else {
                compver.prerelease.push(0);
              }
              compver.raw = compver.format();
            /* fallthrough */
            case "":
            case ">=":
              if (!setMin || gt(compver, setMin)) {
                setMin = compver;
              }
              break;
            case "<":
            case "<=":
              break;
            /* istanbul ignore next */
            default:
              throw new Error(`Unexpected operation: ${comparator.operator}`);
          }
        });
        if (setMin && (!minver || gt(minver, setMin))) {
          minver = setMin;
        }
      }
      if (minver && range7.test(minver)) {
        return minver;
      }
      return null;
    }, "minVersion");
    module2.exports = minVersion;
  }
});

// ../../node_modules/semver/ranges/valid.js
var require_valid4 = __commonJS({
  "../../node_modules/semver/ranges/valid.js"(exports2, module2) {
    "use strict";
    var Range = require_range2();
    var validRange = /* @__PURE__ */ __name((range7, options) => {
      try {
        return new Range(range7, options).range || "*";
      } catch (er) {
        return null;
      }
    }, "validRange");
    module2.exports = validRange;
  }
});

// ../../node_modules/semver/ranges/outside.js
var require_outside2 = __commonJS({
  "../../node_modules/semver/ranges/outside.js"(exports2, module2) {
    "use strict";
    var SemVer = require_semver3();
    var Comparator = require_comparator2();
    var { ANY } = Comparator;
    var Range = require_range2();
    var satisfies2 = require_satisfies2();
    var gt = require_gt2();
    var lt = require_lt2();
    var lte2 = require_lte2();
    var gte = require_gte2();
    var outside = /* @__PURE__ */ __name((version, range7, hilo, options) => {
      version = new SemVer(version, options);
      range7 = new Range(range7, options);
      let gtfn, ltefn, ltfn, comp, ecomp;
      switch (hilo) {
        case ">":
          gtfn = gt;
          ltefn = lte2;
          ltfn = lt;
          comp = ">";
          ecomp = ">=";
          break;
        case "<":
          gtfn = lt;
          ltefn = gte;
          ltfn = gt;
          comp = "<";
          ecomp = "<=";
          break;
        default:
          throw new TypeError('Must provide a hilo val of "<" or ">"');
      }
      if (satisfies2(version, range7, options)) {
        return false;
      }
      for (let i32 = 0; i32 < range7.set.length; ++i32) {
        const comparators = range7.set[i32];
        let high = null;
        let low = null;
        comparators.forEach((comparator) => {
          if (comparator.semver === ANY) {
            comparator = new Comparator(">=0.0.0");
          }
          high = high || comparator;
          low = low || comparator;
          if (gtfn(comparator.semver, high.semver, options)) {
            high = comparator;
          } else if (ltfn(comparator.semver, low.semver, options)) {
            low = comparator;
          }
        });
        if (high.operator === comp || high.operator === ecomp) {
          return false;
        }
        if ((!low.operator || low.operator === comp) && ltefn(version, low.semver)) {
          return false;
        } else if (low.operator === ecomp && ltfn(version, low.semver)) {
          return false;
        }
      }
      return true;
    }, "outside");
    module2.exports = outside;
  }
});

// ../../node_modules/semver/ranges/gtr.js
var require_gtr2 = __commonJS({
  "../../node_modules/semver/ranges/gtr.js"(exports2, module2) {
    "use strict";
    var outside = require_outside2();
    var gtr = /* @__PURE__ */ __name((version, range7, options) => outside(version, range7, ">", options), "gtr");
    module2.exports = gtr;
  }
});

// ../../node_modules/semver/ranges/ltr.js
var require_ltr2 = __commonJS({
  "../../node_modules/semver/ranges/ltr.js"(exports2, module2) {
    "use strict";
    var outside = require_outside2();
    var ltr = /* @__PURE__ */ __name((version, range7, options) => outside(version, range7, "<", options), "ltr");
    module2.exports = ltr;
  }
});

// ../../node_modules/semver/ranges/intersects.js
var require_intersects2 = __commonJS({
  "../../node_modules/semver/ranges/intersects.js"(exports2, module2) {
    "use strict";
    var Range = require_range2();
    var intersects = /* @__PURE__ */ __name((r1, r210, options) => {
      r1 = new Range(r1, options);
      r210 = new Range(r210, options);
      return r1.intersects(r210, options);
    }, "intersects");
    module2.exports = intersects;
  }
});

// ../../node_modules/semver/ranges/simplify.js
var require_simplify2 = __commonJS({
  "../../node_modules/semver/ranges/simplify.js"(exports2, module2) {
    "use strict";
    var satisfies2 = require_satisfies2();
    var compare2 = require_compare2();
    module2.exports = (versions2, range7, options) => {
      const set = [];
      let first = null;
      let prev = null;
      const v = versions2.sort((a32, b32) => compare2(a32, b32, options));
      for (const version of v) {
        const included = satisfies2(version, range7, options);
        if (included) {
          prev = version;
          if (!first) {
            first = version;
          }
        } else {
          if (prev) {
            set.push([first, prev]);
          }
          prev = null;
          first = null;
        }
      }
      if (first) {
        set.push([first, null]);
      }
      const ranges = [];
      for (const [min, max] of set) {
        if (min === max) {
          ranges.push(min);
        } else if (!max && min === v[0]) {
          ranges.push("*");
        } else if (!max) {
          ranges.push(`>=${min}`);
        } else if (min === v[0]) {
          ranges.push(`<=${max}`);
        } else {
          ranges.push(`${min} - ${max}`);
        }
      }
      const simplified = ranges.join(" || ");
      const original = typeof range7.raw === "string" ? range7.raw : String(range7);
      return simplified.length < original.length ? simplified : range7;
    };
  }
});

// ../../node_modules/semver/ranges/subset.js
var require_subset2 = __commonJS({
  "../../node_modules/semver/ranges/subset.js"(exports2, module2) {
    "use strict";
    var Range = require_range2();
    var Comparator = require_comparator2();
    var { ANY } = Comparator;
    var satisfies2 = require_satisfies2();
    var compare2 = require_compare2();
    var subset = /* @__PURE__ */ __name((sub, dom, options = {}) => {
      if (sub === dom) {
        return true;
      }
      sub = new Range(sub, options);
      dom = new Range(dom, options);
      let sawNonNull = false;
      OUTER: for (const simpleSub of sub.set) {
        for (const simpleDom of dom.set) {
          const isSub = simpleSubset(simpleSub, simpleDom, options);
          sawNonNull = sawNonNull || isSub !== null;
          if (isSub) {
            continue OUTER;
          }
        }
        if (sawNonNull) {
          return false;
        }
      }
      return true;
    }, "subset");
    var minimumVersionWithPreRelease = [new Comparator(">=0.0.0-0")];
    var minimumVersion = [new Comparator(">=0.0.0")];
    var simpleSubset = /* @__PURE__ */ __name((sub, dom, options) => {
      if (sub === dom) {
        return true;
      }
      if (sub.length === 1 && sub[0].semver === ANY) {
        if (dom.length === 1 && dom[0].semver === ANY) {
          return true;
        } else if (options.includePrerelease) {
          sub = minimumVersionWithPreRelease;
        } else {
          sub = minimumVersion;
        }
      }
      if (dom.length === 1 && dom[0].semver === ANY) {
        if (options.includePrerelease) {
          return true;
        } else {
          dom = minimumVersion;
        }
      }
      const eqSet = /* @__PURE__ */ new Set();
      let gt, lt;
      for (const c32 of sub) {
        if (c32.operator === ">" || c32.operator === ">=") {
          gt = higherGT(gt, c32, options);
        } else if (c32.operator === "<" || c32.operator === "<=") {
          lt = lowerLT(lt, c32, options);
        } else {
          eqSet.add(c32.semver);
        }
      }
      if (eqSet.size > 1) {
        return null;
      }
      let gtltComp;
      if (gt && lt) {
        gtltComp = compare2(gt.semver, lt.semver, options);
        if (gtltComp > 0) {
          return null;
        } else if (gtltComp === 0 && (gt.operator !== ">=" || lt.operator !== "<=")) {
          return null;
        }
      }
      for (const eq2 of eqSet) {
        if (gt && !satisfies2(eq2, String(gt), options)) {
          return null;
        }
        if (lt && !satisfies2(eq2, String(lt), options)) {
          return null;
        }
        for (const c32 of dom) {
          if (!satisfies2(eq2, String(c32), options)) {
            return false;
          }
        }
        return true;
      }
      let higher, lower;
      let hasDomLT, hasDomGT;
      let needDomLTPre = lt && !options.includePrerelease && lt.semver.prerelease.length ? lt.semver : false;
      let needDomGTPre = gt && !options.includePrerelease && gt.semver.prerelease.length ? gt.semver : false;
      if (needDomLTPre && needDomLTPre.prerelease.length === 1 && lt.operator === "<" && needDomLTPre.prerelease[0] === 0) {
        needDomLTPre = false;
      }
      for (const c32 of dom) {
        hasDomGT = hasDomGT || c32.operator === ">" || c32.operator === ">=";
        hasDomLT = hasDomLT || c32.operator === "<" || c32.operator === "<=";
        if (gt) {
          if (needDomGTPre) {
            if (c32.semver.prerelease && c32.semver.prerelease.length && c32.semver.major === needDomGTPre.major && c32.semver.minor === needDomGTPre.minor && c32.semver.patch === needDomGTPre.patch) {
              needDomGTPre = false;
            }
          }
          if (c32.operator === ">" || c32.operator === ">=") {
            higher = higherGT(gt, c32, options);
            if (higher === c32 && higher !== gt) {
              return false;
            }
          } else if (gt.operator === ">=" && !c32.test(gt.semver)) {
            return false;
          }
        }
        if (lt) {
          if (needDomLTPre) {
            if (c32.semver.prerelease && c32.semver.prerelease.length && c32.semver.major === needDomLTPre.major && c32.semver.minor === needDomLTPre.minor && c32.semver.patch === needDomLTPre.patch) {
              needDomLTPre = false;
            }
          }
          if (c32.operator === "<" || c32.operator === "<=") {
            lower = lowerLT(lt, c32, options);
            if (lower === c32 && lower !== lt) {
              return false;
            }
          } else if (lt.operator === "<=" && !c32.test(lt.semver)) {
            return false;
          }
        }
        if (!c32.operator && (lt || gt) && gtltComp !== 0) {
          return false;
        }
      }
      if (gt && hasDomLT && !lt && gtltComp !== 0) {
        return false;
      }
      if (lt && hasDomGT && !gt && gtltComp !== 0) {
        return false;
      }
      if (needDomGTPre || needDomLTPre) {
        return false;
      }
      return true;
    }, "simpleSubset");
    var higherGT = /* @__PURE__ */ __name((a32, b32, options) => {
      if (!a32) {
        return b32;
      }
      const comp = compare2(a32.semver, b32.semver, options);
      return comp > 0 ? a32 : comp < 0 ? b32 : b32.operator === ">" && a32.operator === ">=" ? b32 : a32;
    }, "higherGT");
    var lowerLT = /* @__PURE__ */ __name((a32, b32, options) => {
      if (!a32) {
        return b32;
      }
      const comp = compare2(a32.semver, b32.semver, options);
      return comp < 0 ? a32 : comp > 0 ? b32 : b32.operator === "<" && a32.operator === "<=" ? b32 : a32;
    }, "lowerLT");
    module2.exports = subset;
  }
});

// ../../node_modules/semver/index.js
var require_semver4 = __commonJS({
  "../../node_modules/semver/index.js"(exports2, module2) {
    "use strict";
    var internalRe = require_re2();
    var constants3 = require_constants6();
    var SemVer = require_semver3();
    var identifiers = require_identifiers2();
    var parse2 = require_parse5();
    var valid3 = require_valid3();
    var clean = require_clean2();
    var inc = require_inc2();
    var diff = require_diff2();
    var major6 = require_major2();
    var minor = require_minor2();
    var patch = require_patch2();
    var prerelease = require_prerelease2();
    var compare2 = require_compare2();
    var rcompare = require_rcompare2();
    var compareLoose = require_compare_loose2();
    var compareBuild = require_compare_build2();
    var sort = require_sort2();
    var rsort = require_rsort2();
    var gt = require_gt2();
    var lt = require_lt2();
    var eq2 = require_eq2();
    var neq = require_neq2();
    var gte = require_gte2();
    var lte2 = require_lte2();
    var cmp = require_cmp2();
    var coerce2 = require_coerce2();
    var truncate = require_truncate2();
    var Comparator = require_comparator2();
    var Range = require_range2();
    var satisfies2 = require_satisfies2();
    var toComparators = require_to_comparators2();
    var maxSatisfying = require_max_satisfying2();
    var minSatisfying = require_min_satisfying2();
    var minVersion = require_min_version2();
    var validRange = require_valid4();
    var outside = require_outside2();
    var gtr = require_gtr2();
    var ltr = require_ltr2();
    var intersects = require_intersects2();
    var simplifyRange = require_simplify2();
    var subset = require_subset2();
    module2.exports = {
      parse: parse2,
      valid: valid3,
      clean,
      inc,
      diff,
      major: major6,
      minor,
      patch,
      prerelease,
      compare: compare2,
      rcompare,
      compareLoose,
      compareBuild,
      sort,
      rsort,
      gt,
      lt,
      eq: eq2,
      neq,
      gte,
      lte: lte2,
      cmp,
      coerce: coerce2,
      truncate,
      Comparator,
      Range,
      satisfies: satisfies2,
      toComparators,
      maxSatisfying,
      minSatisfying,
      minVersion,
      validRange,
      outside,
      gtr,
      ltr,
      intersects,
      simplifyRange,
      subset,
      SemVer,
      re: internalRe.re,
      src: internalRe.src,
      tokens: internalRe.t,
      SEMVER_SPEC_VERSION: constants3.SEMVER_SPEC_VERSION,
      RELEASE_TYPES: constants3.RELEASE_TYPES,
      compareIdentifiers: identifiers.compareIdentifiers,
      rcompareIdentifiers: identifiers.rcompareIdentifiers
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/util/version-range.ts
function rangeFromSemver(ver, targetType) {
  const re = ver.match(/^([^\d]*)([\d.]*)[^\s]*$/);
  if (!re || !semver2.valid(re[2])) {
    throw new ToolkitError("InvalidSemverRange", "not a semver or unsupported range syntax");
  }
  const prefixPart = re[1];
  const verPart = re[2];
  switch (targetType) {
    // NuGet normally installs the lowest version in the range
    // That's okay for aws-cdk-lib where we always specify the lowest version
    // For constructs, we rather want people to use the highest version
    // The only way to do this is to specify this as <MAJOR>.*
    // see https://learn.microsoft.com/en-us/nuget/concepts/package-versioning
    case "major.*":
      switch (prefixPart) {
        case "":
          return ver;
        case "^":
          return `${semver2.major(verPart)}.*`;
        default:
          throw new ToolkitError("UnsupportedRangeSyntax", `unsupported range syntax - ${prefixPart}`);
      }
    case "bracket":
      switch (prefixPart) {
        case "":
          return ver;
        case "^":
          return `[${verPart},${semver2.major(verPart) + 1}.0.0)`;
        default:
          throw new ToolkitError("UnsupportedRangeSyntax", `unsupported range syntax - ${prefixPart}`);
      }
    case "pep":
      switch (prefixPart) {
        case "":
          return `==${ver}`;
        case "^":
          return `>=${verPart},<${semver2.major(verPart) + 1}.0.0`;
        default:
          throw new ToolkitError("UnsupportedRangeSyntax", `unsupported range syntax - ${prefixPart}`);
      }
  }
}
function stripCaret(ver) {
  return ver.startsWith("^") ? ver.slice(1) : ver;
}
var semver2;
var init_version_range = __esm({
  "../@aws-cdk/toolkit-lib/lib/util/version-range.ts"() {
    "use strict";
    semver2 = __toESM(require_semver4());
    init_toolkit_error();
    __name(rangeFromSemver, "rangeFromSemver");
    __name(stripCaret, "stripCaret");
  }
});

// ../@aws-cdk/toolkit-lib/lib/util/index.ts
var init_util3 = __esm({
  "../@aws-cdk/toolkit-lib/lib/util/index.ts"() {
    "use strict";
    init_arrays();
    init_bool();
    init_bytes();
    init_cloudformation();
    init_content_hash();
    init_directories();
    init_format_error();
    init_glob_matcher();
    init_guess_language();
    init_json();
    init_net();
    init_objects();
    init_parallel();
    init_package_info();
    init_serialize();
    init_string_manipulation();
    init_type_brands();
    init_types2();
    init_version_range();
    init_yaml_cfn();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/io/private/span.ts
function parseArgs(first, second) {
  const firstIsMessage = typeof first === "string";
  const message2 = firstIsMessage || second ? first : void 0;
  const payload3 = firstIsMessage || second ? second : first;
  return {
    message: message2,
    payload: payload3
  };
}
function withSpanId(span, message2) {
  return {
    ...message2,
    span
  };
}
var import_dispose_polyfill, import_node_crypto3, util2, SpanMaker, MessageSpan;
var init_span = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/io/private/span.ts"() {
    "use strict";
    import_dispose_polyfill = __toESM(require_dispose_polyfill());
    import_node_crypto3 = require("node:crypto");
    util2 = __toESM(require("node:util"));
    init_util3();
    SpanMaker = class {
      static {
        __name(this, "SpanMaker");
      }
      definition;
      ioHelper;
      makeHelper;
      constructor(ioHelper, definition, makeHelper) {
        this.definition = definition;
        this.ioHelper = ioHelper;
        this.makeHelper = makeHelper;
      }
      async begin(a32, b32) {
        const span = new MessageSpan(this.ioHelper, this.definition, this.makeHelper);
        const startInput = parseArgs(a32, b32);
        const startMsg = startInput.message ?? `Starting ${this.definition.name} ...`;
        const startPayload = startInput.payload;
        await span.notify(this.definition.start.msg(startMsg, startPayload));
        return span;
      }
    };
    MessageSpan = class {
      static {
        __name(this, "MessageSpan");
      }
      asHelper;
      definition;
      ioHelper;
      spanId;
      startTime;
      timingMsgTemplate;
      counters = {};
      openTimers = /* @__PURE__ */ new Set();
      constructor(ioHelper, definition, makeHelper) {
        this.definition = definition;
        this.ioHelper = ioHelper;
        this.spanId = (0, import_node_crypto3.randomUUID)();
        this.startTime = (/* @__PURE__ */ new Date()).getTime();
        this.timingMsgTemplate = "\n\u2728  %s time: %ds\n";
        this.asHelper = makeHelper(this);
      }
      get defaults() {
        return this.asHelper.defaults;
      }
      async elapsedTime() {
        return this.time();
      }
      async timing(maker, message2) {
        const duration = this.time();
        const timingMsg = message2 ? message2 : util2.format(this.timingMsgTemplate, this.definition.name, duration.asSec);
        await this.notify(maker.msg(timingMsg, {
          duration: duration.asMs
        }));
        return duration;
      }
      async notify(msg) {
        return this.ioHelper.notify(withSpanId(this.spanId, msg));
      }
      async end(x, y) {
        const duration = this.time();
        for (const t of this.openTimers) {
          t.stop();
        }
        this.openTimers.clear();
        const endInput = parseArgs(x, y);
        const endMsg = endInput.message ?? util2.format(this.timingMsgTemplate, this.definition.name, duration.asSec);
        const endPayload = endInput.payload;
        await this.notify(this.definition.end.msg(
          endMsg,
          {
            duration: duration.asMs,
            ...Object.keys(this.counters).length > 0 ? { counters: this.counters } : {},
            ...endPayload
          }
        ));
        return duration;
      }
      incCounter(name, delta = 1) {
        this.counters[name] = (this.counters[name] ?? 0) + delta;
      }
      async requestResponse(msg) {
        return this.ioHelper.requestResponse(withSpanId(this.spanId, msg));
      }
      startTimer(name) {
        const start = Date.now();
        const t = {
          stop: /* @__PURE__ */ __name(() => {
            this.openTimers.delete(t);
            this.addTimer(name, Math.floor(Date.now() - start));
          }, "stop"),
          [Symbol.dispose]() {
            this.stop();
          }
        };
        this.openTimers.add(t);
        return t;
      }
      addTimer(name, durationMs) {
        this.incCounter(`${name}_ms`, Math.floor(durationMs));
        this.incCounter(`${name}_cnt`, 1);
      }
      time() {
        const elapsedTime = (/* @__PURE__ */ new Date()).getTime() - this.startTime;
        return {
          asMs: elapsedTime,
          asSec: formatTime(elapsedTime)
        };
      }
    };
    __name(parseArgs, "parseArgs");
    __name(withSpanId, "withSpanId");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/io/private/io-helper.ts
function asIoHelper(ioHost, action) {
  return IoHelper.fromIoHost(ioHost, action);
}
var IoHelper;
var init_io_helper = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/io/private/io-helper.ts"() {
    "use strict";
    init_io_default_messages();
    init_span();
    IoHelper = class _IoHelper {
      static {
        __name(this, "IoHelper");
      }
      static fromIoHost(ioHost, action) {
        return new _IoHelper({
          notify: /* @__PURE__ */ __name((msg) => ioHost.notify({
            ...msg,
            action
          }), "notify"),
          requestResponse: /* @__PURE__ */ __name((msg) => ioHost.requestResponse({
            ...msg,
            action
          }), "requestResponse")
        });
      }
      static fromActionAwareIoHost(ioHost) {
        return new _IoHelper(ioHost);
      }
      /**
       * Simplified access to emit default messages.
       */
      defaults;
      ioHost;
      constructor(ioHost) {
        this.ioHost = ioHost;
        this.defaults = new IoDefaultMessages(this);
      }
      /**
       * Forward a message to the IoHost, while injection the current action
       */
      notify(msg) {
        return this.ioHost.notify(msg);
      }
      /**
       * Forward a request to the IoHost, while injection the current action
       */
      requestResponse(msg) {
        return this.ioHost.requestResponse(msg);
      }
      /**
       * Create a new marker from a given registry entry
       */
      span(definition) {
        return new SpanMaker(this, definition, (ioHost) => _IoHelper.fromActionAwareIoHost(ioHost));
      }
    };
    __name(asIoHelper, "asIoHelper");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/io/private/level-priority.ts
function compareFn(a32, b32) {
  return orderedLevels[a32] - orderedLevels[b32];
}
function isMessageRelevantForLevel(msg, level) {
  return compareFn(msg.level, level) >= 0;
}
var levels, orderedLevels;
var init_level_priority = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/io/private/level-priority.ts"() {
    "use strict";
    levels = [
      "trace",
      "debug",
      "info",
      "warn",
      "result",
      "error"
    ];
    orderedLevels = Object.fromEntries(Object.entries(levels).map((a32) => a32.reverse()));
    __name(compareFn, "compareFn");
    __name(isMessageRelevantForLevel, "isMessageRelevantForLevel");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/io/private/message-maker.ts
function message(level, details) {
  const maker = /* @__PURE__ */ __name((text, data3) => ({
    time: /* @__PURE__ */ new Date(),
    level,
    code: details.code,
    message: text,
    data: data3
  }), "maker");
  return {
    ...details,
    level,
    msg: maker,
    is: /* @__PURE__ */ __name((m20) => m20.code === details.code, "is")
  };
}
function request(level, details) {
  const maker = /* @__PURE__ */ __name((text, data3) => ({
    time: /* @__PURE__ */ new Date(),
    level,
    code: details.code,
    message: text,
    data: data3,
    defaultResponse: details.defaultResponse
  }), "maker");
  return {
    ...details,
    level,
    req: maker
  };
}
function question(details) {
  const level = "info";
  const maker = /* @__PURE__ */ __name((text, data3, defaultResponse) => ({
    time: /* @__PURE__ */ new Date(),
    level,
    code: details.code,
    message: text,
    data: data3,
    defaultResponse
  }), "maker");
  return {
    ...details,
    level,
    req: maker
  };
}
var trace, debug, info, warn, error2, result, confirm;
var init_message_maker = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/io/private/message-maker.ts"() {
    "use strict";
    __name(message, "message");
    trace = /* @__PURE__ */ __name((details) => message("trace", details), "trace");
    debug = /* @__PURE__ */ __name((details) => message("debug", details), "debug");
    info = /* @__PURE__ */ __name((details) => message("info", details), "info");
    warn = /* @__PURE__ */ __name((details) => message("warn", details), "warn");
    error2 = /* @__PURE__ */ __name((details) => message("error", details), "error");
    result = /* @__PURE__ */ __name((details) => message("result", details), "result");
    __name(request, "request");
    confirm = /* @__PURE__ */ __name((details) => request("info", {
      ...details,
      defaultResponse: true
    }), "confirm");
    __name(question, "question");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/io/private/messages.ts
var IO, SPAN;
var init_messages = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/io/private/messages.ts"() {
    "use strict";
    init_message_maker();
    IO = {
      // warnings & errors
      CDK_TOOLKIT_W0100: warn({
        code: "CDK_TOOLKIT_W0100",
        description: "Credential plugin warnings"
      }),
      // 1: Synth (1xxx)
      CDK_TOOLKIT_I1000: info({
        code: "CDK_TOOLKIT_I1000",
        description: "Provides synthesis times.",
        interface: "Operation"
      }),
      CDK_TOOLKIT_I1001: trace({
        code: "CDK_TOOLKIT_I1001",
        description: "Cloud Assembly synthesis is starting",
        interface: "StackSelectionDetails"
      }),
      CDK_TOOLKIT_I1901: result({
        code: "CDK_TOOLKIT_I1901",
        description: "Provides stack data",
        interface: "StackAndAssemblyData"
      }),
      CDK_TOOLKIT_I1902: result({
        code: "CDK_TOOLKIT_I1902",
        description: "Successfully deployed stacks",
        interface: "AssemblyData"
      }),
      // 2: List (2xxx)
      CDK_TOOLKIT_I2901: result({
        code: "CDK_TOOLKIT_I2901",
        description: "Provides details on the selected stacks and their dependencies",
        interface: "StackDetailsPayload"
      }),
      // 3: Import & Migrate
      CDK_TOOLKIT_I3100: confirm({
        code: "CDK_TOOLKIT_I3100",
        description: "Confirm the import of a specific resource",
        interface: "ResourceImportRequest"
      }),
      CDK_TOOLKIT_I3110: question({
        code: "CDK_TOOLKIT_I3110",
        description: "Additional information is needed to identify a resource",
        interface: "ResourceIdentificationRequest"
      }),
      CDK_TOOLKIT_E3900: error2({
        code: "CDK_TOOLKIT_E3900",
        description: "Resource import failed",
        interface: "ErrorPayload"
      }),
      // 4: Diff (40xx - 44xx)
      CDK_TOOLKIT_I4000: trace({
        code: "CDK_TOOLKIT_I4000",
        description: "Diff stacks is starting",
        interface: "StackSelectionDetails"
      }),
      CDK_TOOLKIT_I4001: result({
        code: "CDK_TOOLKIT_I4001",
        description: "Output of the diff command",
        interface: "DiffResult"
      }),
      CDK_TOOLKIT_I4002: result({
        code: "CDK_TOOLKIT_I4002",
        description: "The diff for a single stack",
        interface: "StackDiff"
      }),
      // 4: Drift (45xx - 49xx)
      CDK_TOOLKIT_I4500: trace({
        code: "CDK_TOOLKIT_I4500",
        description: "Drift detection is starting",
        interface: "StackSelectionDetails"
      }),
      CDK_TOOLKIT_I4509: result({
        code: "CDK_TOOLKIT_I4592",
        description: "Results of the drift",
        interface: "Duration"
      }),
      CDK_TOOLKIT_I4590: result({
        code: "CDK_TOOLKIT_I4590",
        description: "Results of a stack drift",
        interface: "DriftResultPayload"
      }),
      CDK_TOOLKIT_W4591: warn({
        code: "CDK_TOOLKIT_W4591",
        description: "Missing drift result fort a stack.",
        interface: "SingleStack"
      }),
      // 5: Deploy & Watch (5xxx)
      CDK_TOOLKIT_I5000: info({
        code: "CDK_TOOLKIT_I5000",
        description: "Provides deployment times",
        interface: "Duration"
      }),
      CDK_TOOLKIT_I5001: info({
        code: "CDK_TOOLKIT_I5001",
        description: "Provides total time in deploy action, including synth and rollback",
        interface: "Duration"
      }),
      CDK_TOOLKIT_I5002: info({
        code: "CDK_TOOLKIT_I5002",
        description: "Provides time for resource migration",
        interface: "Duration"
      }),
      CDK_TOOLKIT_W5021: warn({
        code: "CDK_TOOLKIT_W5021",
        description: "Empty non-existent stack, deployment is skipped"
      }),
      CDK_TOOLKIT_W5022: warn({
        code: "CDK_TOOLKIT_W5022",
        description: "Empty existing stack, stack will be destroyed"
      }),
      CDK_TOOLKIT_I5031: info({
        code: "CDK_TOOLKIT_I5031",
        description: "Informs about any log groups that are traced as part of the deployment"
      }),
      CDK_TOOLKIT_I5032: debug({
        code: "CDK_TOOLKIT_I5032",
        description: "Start monitoring log groups",
        interface: "CloudWatchLogMonitorControlEvent"
      }),
      CDK_TOOLKIT_I5033: info({
        code: "CDK_TOOLKIT_I5033",
        description: "A log event received from Cloud Watch",
        interface: "CloudWatchLogEvent"
      }),
      CDK_TOOLKIT_I5034: debug({
        code: "CDK_TOOLKIT_I5034",
        description: "Stop monitoring log groups",
        interface: "CloudWatchLogMonitorControlEvent"
      }),
      CDK_TOOLKIT_E5035: error2({
        code: "CDK_TOOLKIT_E5035",
        description: "A log monitoring error",
        interface: "ErrorPayload"
      }),
      CDK_TOOLKIT_I5050: confirm({
        code: "CDK_TOOLKIT_I5050",
        description: "Confirm rollback during deployment",
        interface: "ConfirmationRequest"
      }),
      CDK_TOOLKIT_I5060: confirm({
        code: "CDK_TOOLKIT_I5060",
        description: "Confirm deploy security sensitive changes",
        interface: "DeployConfirmationRequest"
      }),
      CDK_TOOLKIT_I5100: info({
        code: "CDK_TOOLKIT_I5100",
        description: "Stack deploy progress",
        interface: "StackDeployProgress"
      }),
      // Assets (52xx)
      CDK_TOOLKIT_I5210: trace({
        code: "CDK_TOOLKIT_I5210",
        description: "Started building a specific asset",
        interface: "BuildAsset"
      }),
      CDK_TOOLKIT_I5211: trace({
        code: "CDK_TOOLKIT_I5211",
        description: "Building the asset has completed",
        interface: "Duration"
      }),
      CDK_TOOLKIT_I5220: trace({
        code: "CDK_TOOLKIT_I5220",
        description: "Started publishing a specific asset",
        interface: "PublishAsset"
      }),
      CDK_TOOLKIT_I5221: trace({
        code: "CDK_TOOLKIT_I5221",
        description: "Publishing the asset has completed",
        interface: "Duration"
      }),
      CDK_ASSETS_I5270: info({
        code: "CDK_ASSETS_I5270",
        description: "Publishing the asset has started",
        interface: "PublishAssetEvent"
      }),
      CDK_ASSETS_I5271: debug({
        code: "CDK_ASSETS_I5271",
        description: "Debug messaged emitted during publishing of the asset",
        interface: "PublishAssetEvent"
      }),
      CDK_ASSETS_I5275: info({
        code: "CDK_ASSETS_I5275",
        description: "Publishing the asset has completed successfully",
        interface: "PublishAssetEvent"
      }),
      CDK_ASSETS_E5279: error2({
        code: "CDK_ASSETS_E5279",
        description: "There was an error while publishing the asset",
        interface: "PublishAssetEvent"
      }),
      // Watch (53xx)
      CDK_TOOLKIT_I5310: debug({
        code: "CDK_TOOLKIT_I5310",
        description: "The computed settings used for file watching",
        interface: "WatchSettings"
      }),
      CDK_TOOLKIT_I5311: info({
        code: "CDK_TOOLKIT_I5311",
        description: "File watching started",
        interface: "FileWatchEvent"
      }),
      CDK_TOOLKIT_I5312: info({
        code: "CDK_TOOLKIT_I5312",
        description: "File event detected, starting deployment",
        interface: "FileWatchEvent"
      }),
      CDK_TOOLKIT_I5313: info({
        code: "CDK_TOOLKIT_I5313",
        description: "File event detected during active deployment, changes are queued",
        interface: "FileWatchEvent"
      }),
      CDK_TOOLKIT_I5314: info({
        code: "CDK_TOOLKIT_I5314",
        description: "Initial watch deployment started"
      }),
      CDK_TOOLKIT_I5315: info({
        code: "CDK_TOOLKIT_I5315",
        description: "Queued watch deployment started"
      }),
      // Hotswap (54xx)
      CDK_TOOLKIT_I5400: trace({
        code: "CDK_TOOLKIT_I5400",
        description: "Attempting a hotswap deployment",
        interface: "HotswapDeploymentAttempt"
      }),
      CDK_TOOLKIT_I5401: trace({
        code: "CDK_TOOLKIT_I5401",
        description: "Computed details for the hotswap deployment",
        interface: "HotswapDeploymentDetails"
      }),
      CDK_TOOLKIT_I5402: info({
        code: "CDK_TOOLKIT_I5402",
        description: "A hotswappable change is processed as part of a hotswap deployment",
        interface: "HotswappableChange"
      }),
      CDK_TOOLKIT_I5403: info({
        code: "CDK_TOOLKIT_I5403",
        description: "The hotswappable change has completed processing",
        interface: "HotswappableChange"
      }),
      CDK_TOOLKIT_I5410: info({
        code: "CDK_TOOLKIT_I5410",
        description: "Hotswap deployment has ended, a full deployment might still follow if needed",
        interface: "HotswapResult"
      }),
      // Stack Monitor (55xx)
      CDK_TOOLKIT_I5501: info({
        code: "CDK_TOOLKIT_I5501",
        description: "Stack Monitoring: Start monitoring of a single stack",
        interface: "StackMonitoringControlEvent"
      }),
      CDK_TOOLKIT_I5502: info({
        code: "CDK_TOOLKIT_I5502",
        description: "Stack Monitoring: Activity event for a single stack",
        interface: "StackActivity"
      }),
      CDK_TOOLKIT_I5503: info({
        code: "CDK_TOOLKIT_I5503",
        description: "Stack Monitoring: Finished monitoring of a single stack",
        interface: "StackMonitoringControlEvent"
      }),
      // Success (59xx)
      CDK_TOOLKIT_I5900: result({
        code: "CDK_TOOLKIT_I5900",
        description: "Deployment results on success",
        interface: "SuccessfulDeployStackResult"
      }),
      CDK_TOOLKIT_I5901: info({
        code: "CDK_TOOLKIT_I5901",
        description: "Generic deployment success messages"
      }),
      CDK_TOOLKIT_W5400: warn({
        code: "CDK_TOOLKIT_W5400",
        description: "Hotswap disclosure message"
      }),
      CDK_TOOLKIT_E5001: error2({
        code: "CDK_TOOLKIT_E5001",
        description: "No stacks found"
      }),
      CDK_TOOLKIT_E5500: error2({
        code: "CDK_TOOLKIT_E5500",
        description: "Stack Monitoring error",
        interface: "ErrorPayload"
      }),
      // 6: Rollback (6xxx)
      CDK_TOOLKIT_I6000: info({
        code: "CDK_TOOLKIT_I6000",
        description: "Provides rollback times",
        interface: "Duration"
      }),
      CDK_TOOLKIT_I6100: info({
        code: "CDK_TOOLKIT_I6100",
        description: "Stack rollback progress",
        interface: "StackRollbackProgress"
      }),
      CDK_TOOLKIT_E6001: error2({
        code: "CDK_TOOLKIT_E6001",
        description: "No stacks found"
      }),
      CDK_TOOLKIT_E6900: error2({
        code: "CDK_TOOLKIT_E6900",
        description: "Rollback failed",
        interface: "ErrorPayload"
      }),
      // 7: Destroy (7xxx)
      CDK_TOOLKIT_I7000: info({
        code: "CDK_TOOLKIT_I7000",
        description: "Provides destroy times",
        interface: "Duration"
      }),
      CDK_TOOLKIT_I7001: trace({
        code: "CDK_TOOLKIT_I7001",
        description: "Provides destroy time for a single stack",
        interface: "Duration"
      }),
      CDK_TOOLKIT_I7010: confirm({
        code: "CDK_TOOLKIT_I7010",
        description: "Confirm destroy stacks",
        interface: "ConfirmationRequest"
      }),
      CDK_TOOLKIT_I7100: info({
        code: "CDK_TOOLKIT_I7100",
        description: "Stack destroy progress",
        interface: "StackDestroyProgress"
      }),
      CDK_TOOLKIT_I7101: trace({
        code: "CDK_TOOLKIT_I7101",
        description: "Start stack destroying",
        interface: "StackDestroy"
      }),
      CDK_TOOLKIT_I7900: result({
        code: "CDK_TOOLKIT_I7900",
        description: "Stack deletion succeeded",
        interface: "cxapi.CloudFormationStackArtifact"
      }),
      CDK_TOOLKIT_E7010: error2({
        code: "CDK_TOOLKIT_E7010",
        description: "Action was aborted due to negative confirmation of request"
      }),
      CDK_TOOLKIT_E7900: error2({
        code: "CDK_TOOLKIT_E7900",
        description: "Stack deletion failed",
        interface: "ErrorPayload"
      }),
      // 8. Refactor (8xxx)
      CDK_TOOLKIT_E8900: error2({
        code: "CDK_TOOLKIT_E8900",
        description: "Stack refactor failed",
        interface: "ErrorPayload"
      }),
      CDK_TOOLKIT_I8900: result({
        code: "CDK_TOOLKIT_I8900",
        description: "Refactor result",
        interface: "RefactorResult"
      }),
      CDK_TOOLKIT_I8910: confirm({
        code: "CDK_TOOLKIT_I8910",
        description: "Confirm refactor",
        interface: "ConfirmationRequest"
      }),
      CDK_TOOLKIT_W8010: warn({
        code: "CDK_TOOLKIT_W8010",
        description: "Refactor execution not yet supported"
      }),
      // Orphan (88xx)
      CDK_TOOLKIT_I8810: confirm({
        code: "CDK_TOOLKIT_I8810",
        description: "Confirm orphan resources",
        interface: "ConfirmationRequest"
      }),
      // 9: Bootstrap, gc, flags & publish (9xxx)
      CDK_TOOLKIT_I9000: info({
        code: "CDK_TOOLKIT_I9000",
        description: "Provides bootstrap times",
        interface: "Duration"
      }),
      CDK_TOOLKIT_I9100: info({
        code: "CDK_TOOLKIT_I9100",
        description: "Bootstrap progress",
        interface: "BootstrapEnvironmentProgress"
      }),
      // gc (92xx)
      CDK_TOOLKIT_I9210: question({
        code: "CDK_TOOLKIT_I9210",
        description: "Confirm the deletion of a batch of assets",
        interface: "AssetBatchDeletionRequest"
      }),
      CDK_TOOLKIT_I9900: result({
        code: "CDK_TOOLKIT_I9900",
        description: "Bootstrap results on success",
        interface: "cxapi.Environment"
      }),
      CDK_TOOLKIT_E9900: error2({
        code: "CDK_TOOLKIT_E9900",
        description: "Bootstrap failed",
        interface: "ErrorPayload"
      }),
      // flags (93xx)
      CDK_TOOLKIT_I9300: info({
        code: "CDK_TOOLKIT_I9300",
        description: "Confirm the feature flag configuration changes",
        interface: "FeatureFlagChangeRequest"
      }),
      // publish (94xx)
      CDK_TOOLKIT_I9400: info({
        code: "CDK_TOOLKIT_I9400",
        description: "All assets are already published"
      }),
      CDK_TOOLKIT_I9401: info({
        code: "CDK_TOOLKIT_I9401",
        description: "Publishing assets",
        interface: "AssetsPayload"
      }),
      CDK_TOOLKIT_I9402: result({
        code: "CDK_TOOLKIT_I9402",
        description: "Publish assets results on success",
        interface: "AssetsPayload"
      }),
      // diagnose (95xx)
      CDK_TOOLKIT_I9500: info({
        code: "CDK_TOOLKIT_I9500",
        description: "Stack diagnosis (no problems found)",
        interface: "DiagnosedStack"
      }),
      CDK_TOOLKIT_E9500: error2({
        code: "CDK_TOOLKIT_E9500",
        description: "Stack diagnosis (problems found)",
        interface: "DiagnosedStack"
      }),
      CDK_TOOLKIT_W9501: warn({
        code: "CDK_TOOLKIT_W9501",
        description: "Stack diagnosis (diagnosis could not be performed)",
        interface: "DiagnosedStack"
      }),
      // validate (96xx)
      CDK_TOOLKIT_I9600: info({
        code: "CDK_TOOLKIT_I9600",
        description: "Validation did not find any problems",
        interface: "ValidateResult"
      }),
      CDK_TOOLKIT_E9600: error2({
        code: "CDK_TOOLKIT_E9600",
        description: "Policy validation failed",
        interface: "ValidateResult"
      }),
      CDK_TOOLKIT_I9601: info({
        code: "CDK_TOOLKIT_I9601",
        description: "No policy validation report found"
      }),
      CDK_TOOLKIT_W9602: warn({
        code: "CDK_TOOLKIT_W9602",
        description: "Online validation could not be completed for a stack"
      }),
      // Notices
      CDK_TOOLKIT_I0100: info({
        code: "CDK_TOOLKIT_I0100",
        description: "Notices decoration (the header or footer of a list of notices)"
      }),
      CDK_TOOLKIT_W0101: warn({
        code: "CDK_TOOLKIT_W0101",
        description: "A notice that is marked as a warning"
      }),
      CDK_TOOLKIT_E0101: error2({
        code: "CDK_TOOLKIT_E0101",
        description: "A notice that is marked as an error"
      }),
      CDK_TOOLKIT_I0101: info({
        code: "CDK_TOOLKIT_I0101",
        description: "A notice that is marked as informational"
      }),
      // Assembly codes
      CDK_ASSEMBLY_I0010: debug({
        code: "CDK_ASSEMBLY_I0010",
        description: "Generic environment preparation debug messages"
      }),
      CDK_ASSEMBLY_W0010: warn({
        code: "CDK_ASSEMBLY_W0010",
        description: "Emitted if the found framework version does not support context overflow"
      }),
      CDK_ASSEMBLY_I0042: debug({
        code: "CDK_ASSEMBLY_I0042",
        description: "Writing context updates",
        interface: "UpdatedContext"
      }),
      CDK_ASSEMBLY_I0240: debug({
        code: "CDK_ASSEMBLY_I0240",
        description: "Context lookup was stopped as no further progress was made. ",
        interface: "MissingContext"
      }),
      CDK_ASSEMBLY_I0241: debug({
        code: "CDK_ASSEMBLY_I0241",
        description: "Fetching missing context. This is an iterative message that may appear multiple times with different missing keys.",
        interface: "MissingContext"
      }),
      CDK_ASSEMBLY_I1000: debug({
        code: "CDK_ASSEMBLY_I1000",
        description: "Cloud assembly output starts"
      }),
      CDK_ASSEMBLY_I1001: info({
        code: "CDK_ASSEMBLY_I1001",
        description: "Output lines emitted by the cloud assembly to stdout"
      }),
      CDK_ASSEMBLY_E1002: error2({
        code: "CDK_ASSEMBLY_E1002",
        description: "Output lines emitted by the cloud assembly to stderr"
      }),
      CDK_ASSEMBLY_I1003: info({
        code: "CDK_ASSEMBLY_I1003",
        description: "Cloud assembly output finished"
      }),
      CDK_ASSEMBLY_E1111: error2({
        code: "CDK_ASSEMBLY_E1111",
        description: "Incompatible CDK CLI version. Upgrade needed.",
        interface: "ErrorPayload"
      }),
      CDK_ASSEMBLY_I0150: debug({
        code: "CDK_ASSEMBLY_I0150",
        description: "Indicates the use of a pre-synthesized cloud assembly directory"
      }),
      CDK_ASSEMBLY_I0300: info({
        code: "CDK_ASSEMBLY_I0300",
        description: "An info message emitted by a Context Provider",
        interface: "ContextProviderMessageSource"
      }),
      CDK_ASSEMBLY_I0301: debug({
        code: "CDK_ASSEMBLY_I0301",
        description: "A debug message emitted by a Context Provider",
        interface: "ContextProviderMessageSource"
      }),
      // Assembly Annotations
      CDK_ASSEMBLY_I9999: info({
        code: "CDK_ASSEMBLY_I9999",
        description: "Annotations emitted by the cloud assembly",
        interface: "cxapi.SynthesisMessage"
      }),
      CDK_ASSEMBLY_W9999: warn({
        code: "CDK_ASSEMBLY_W9999",
        description: "Warnings emitted by the cloud assembly",
        interface: "cxapi.SynthesisMessage"
      }),
      CDK_ASSEMBLY_E9999: error2({
        code: "CDK_ASSEMBLY_E9999",
        description: "Errors emitted by the cloud assembly",
        interface: "cxapi.SynthesisMessage"
      }),
      // SDK codes
      CDK_SDK_I0100: trace({
        code: "CDK_SDK_I0100",
        description: "An SDK trace. SDK traces are emitted as traces to the IoHost, but contain the original SDK logging level.",
        interface: "SdkTrace"
      }),
      CDK_SDK_I1100: question({
        code: "CDK_SDK_I1100",
        description: "Get an MFA token for an MFA device.",
        interface: "MfaTokenRequest"
      })
    };
    SPAN = {
      SYNTH_ASSEMBLY: {
        name: "Synthesis",
        start: IO.CDK_TOOLKIT_I1001,
        end: IO.CDK_TOOLKIT_I1000
      },
      DEPLOY_STACK: {
        name: "Deployment",
        start: IO.CDK_TOOLKIT_I5100,
        end: IO.CDK_TOOLKIT_I5001
      },
      ROLLBACK_STACK: {
        name: "Rollback",
        start: IO.CDK_TOOLKIT_I6100,
        end: IO.CDK_TOOLKIT_I6000
      },
      DIFF_STACK: {
        name: "Diff",
        start: IO.CDK_TOOLKIT_I4000,
        end: IO.CDK_TOOLKIT_I4001
      },
      DRIFT_APP: {
        name: "Drift",
        start: IO.CDK_TOOLKIT_I4000,
        end: IO.CDK_TOOLKIT_I4509
      },
      DESTROY_STACK: {
        name: "Destroy",
        start: IO.CDK_TOOLKIT_I7100,
        end: IO.CDK_TOOLKIT_I7001
      },
      DESTROY_ACTION: {
        name: "Destroy",
        start: IO.CDK_TOOLKIT_I7101,
        end: IO.CDK_TOOLKIT_I7000
      },
      BOOTSTRAP_SINGLE: {
        name: "Bootstrap",
        start: IO.CDK_TOOLKIT_I9100,
        end: IO.CDK_TOOLKIT_I9000
      },
      BUILD_ASSET: {
        name: "Build Asset",
        start: IO.CDK_TOOLKIT_I5210,
        end: IO.CDK_TOOLKIT_I5211
      },
      PUBLISH_ASSET: {
        name: "Publish Asset",
        start: IO.CDK_TOOLKIT_I5220,
        end: IO.CDK_TOOLKIT_I5221
      },
      HOTSWAP: {
        name: "hotswap-deployment",
        start: IO.CDK_TOOLKIT_I5400,
        end: IO.CDK_TOOLKIT_I5410
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/io/private/types.ts
var init_types4 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/io/private/types.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/io/private/index.ts
var init_private = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/io/private/index.ts"() {
    "use strict";
    init_io_host_wrappers();
    init_io_helper();
    init_io_default_messages();
    init_level_priority();
    init_span();
    init_message_maker();
    init_messages();
    init_types4();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/plugin/context-provider-plugin.ts
function isContextProviderPlugin(x) {
  return typeof x === "object" && !!x && !!x.getValue;
}
var init_context_provider_plugin = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/plugin/context-provider-plugin.ts"() {
    "use strict";
    __name(isContextProviderPlugin, "isContextProviderPlugin");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/plugin/plugin.ts
var import_util5, PluginHost;
var init_plugin = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/plugin/plugin.ts"() {
    "use strict";
    import_util5 = require("util");
    init_context_provider_plugin();
    init_toolkit_error();
    init_private();
    PluginHost = class {
      static {
        __name(this, "PluginHost");
      }
      /**
       * Access the currently registered CredentialProviderSources. New sources can
       * be registered using the +registerCredentialProviderSource+ method.
       */
      credentialProviderSources = new Array();
      contextProviderPlugins = {};
      ioHost;
      alreadyLoaded = /* @__PURE__ */ new Set();
      /**
       * Loads a plug-in into this PluginHost.
       *
       * Will use `require.resolve()` to get the most accurate representation of what
       * code will get loaded in error messages. As such, it will not work in
       * unit tests with Jest virtual modules becauase of \<https://github.com/jestjs/jest/issues/9543\>.
       *
       * @param moduleSpec - the specification (path or name) of the plug-in module to be loaded.
       * @param ioHost - the I/O host to use for printing progress information
       */
      async load(moduleSpec, ioHost) {
        const resolved = this._doResolve(moduleSpec);
        if (ioHost) {
          await IoHelper.fromIoHost(ioHost, "init").defaults.debug(`Loading plug-in: ${resolved} from ${moduleSpec}`);
        }
        return this._doLoad(resolved);
      }
      /**
       * Do the resolving of a module string to an actual path
       */
      _doResolve(moduleSpec) {
        try {
          return require.resolve(moduleSpec);
        } catch (e32) {
          throw new ToolkitError("PluginResolveFailed", `Unable to resolve plug-in: Cannot find module '${moduleSpec}': ${e32}`);
        }
      }
      /**
       * Do the loading given an already-resolved module name
       *
       * @internal
       */
      _doLoad(resolved) {
        try {
          if (this.alreadyLoaded.has(resolved)) {
            return;
          }
          const plugin = require(resolved);
          if (!isPlugin(plugin)) {
            throw new ToolkitError("InvalidPlugin", `Module ${resolved} is not a valid plug-in, or has an unsupported version.`);
          }
          if (plugin.init) {
            plugin.init(this);
          }
          this.alreadyLoaded.add(resolved);
        } catch (e32) {
          throw ToolkitError.withCause("PluginLoadFailed", `Unable to load plug-in '${resolved}'`, e32);
        }
        function isPlugin(x) {
          return x != null && x.version === "1";
        }
        __name(isPlugin, "isPlugin");
      }
      /**
       * Allows plug-ins to register new CredentialProviderSources.
       *
       * @param source - a new CredentialProviderSource to register.
       */
      registerCredentialProviderSource(source) {
        this.credentialProviderSources.push(source);
      }
      /**
       * (EXPERIMENTAL) Allow plugins to register context providers
       *
       * Context providers are objects with the following method:
       *
       * ```ts
       *   getValue(args: {[key: string]: any}): Promise<any>;
       * ```
       *
       * Currently, they cannot reuse the CDK's authentication mechanisms, so they
       * must be prepared to either not make AWS calls or use their own source of
       * AWS credentials.
       *
       * This feature is experimental, and only intended to be used internally at Amazon
       * as a trial.
       *
       * After registering with 'my-plugin-name', the provider must be addressed as follows:
       *
       * ```ts
       * const value = ContextProvider.getValue(this, {
       *   providerName: 'plugin',
       *   props: {
       *     pluginName: 'my-plugin-name',
       *     myParameter1: 'xyz',
       *   },
       *   includeEnvironment: true | false,
       *   dummyValue: 'what-to-return-on-the-first-pass',
       * })
       * ```
       *
       * @experimental
       */
      registerContextProviderAlpha(pluginProviderName, provider) {
        if (!isContextProviderPlugin(provider)) {
          throw new ToolkitError("InvalidContextProvider", `Object you gave me does not look like a ContextProviderPlugin: ${(0, import_util5.inspect)(provider)}`);
        }
        this.contextProviderPlugins[pluginProviderName] = provider;
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/plugin/mode.ts
var Mode;
var init_mode = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/plugin/mode.ts"() {
    "use strict";
    Mode = /* @__PURE__ */ ((Mode2) => {
      Mode2[Mode2["ForReading"] = 0] = "ForReading";
      Mode2[Mode2["ForWriting"] = 1] = "ForWriting";
      return Mode2;
    })(Mode || {});
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/plugin/index.ts
var plugin_exports = {};
__export(plugin_exports, {
  Mode: () => Mode,
  PluginHost: () => PluginHost,
  isContextProviderPlugin: () => isContextProviderPlugin
});
var init_plugin2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/plugin/index.ts"() {
    "use strict";
    init_plugin();
    init_mode();
    init_context_provider_plugin();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/deployments/asset-publishing.ts
async function publishAssets(manifest, sdk, targetEnv, options, ioHelper) {
  if (targetEnv.account === void 0 || targetEnv.account === import_cloud_assembly_api2.UNKNOWN_ACCOUNT || targetEnv.region === void 0 || targetEnv.account === import_cloud_assembly_api2.UNKNOWN_REGION) {
    throw new ToolkitError("UnresolvedEnvironment", `Asset publishing requires resolved account and region, got ${JSON.stringify(targetEnv)}`);
  }
  const publisher = new import_cdk_assets_lib2.AssetPublishing(manifest, {
    aws: new PublishingAws(sdk, targetEnv),
    progressListener: new PublishingProgressListener(ioHelper),
    throwOnError: false,
    publishInParallel: options.parallel ?? true,
    buildAssets: true,
    publishAssets: true
  });
  await publisher.publish({ allowCrossAccount: options.allowCrossAccount });
  if (publisher.hasFailures) {
    throw new ToolkitError("AssetPublishFailed", "Failed to publish one or more assets. See the error messages above for more information.");
  }
}
var import_cdk_assets_lib2, import_cloud_assembly_api2, PublishingAws, EVENT_TO_MSG_MAKER, BasePublishProgressListener, PublishingProgressListener;
var init_asset_publishing = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/deployments/asset-publishing.ts"() {
    "use strict";
    import_cdk_assets_lib2 = __toESM(require_lib5());
    import_cloud_assembly_api2 = __toESM(require_lib3());
    init_toolkit_error();
    init_private();
    init_plugin2();
    __name(publishAssets, "publishAssets");
    PublishingAws = class {
      constructor(aws, targetEnv) {
        this.aws = aws;
        this.targetEnv = targetEnv;
      }
      aws;
      targetEnv;
      static {
        __name(this, "PublishingAws");
      }
      sdkCache = /* @__PURE__ */ new Map();
      async discoverPartition() {
        return await this.aws.baseCredentialsPartition(this.targetEnv, 1 /* ForWriting */) ?? "aws";
      }
      async discoverDefaultRegion() {
        return this.targetEnv.region;
      }
      async discoverCurrentAccount() {
        const account = await this.aws.defaultAccount();
        return account ?? {
          accountId: "<unknown account>",
          partition: "aws"
        };
      }
      async discoverTargetAccount(options) {
        return (await this.sdk(options)).currentAccount();
      }
      async s3Client(options) {
        return (await this.sdk(options)).s3();
      }
      async ecrClient(options) {
        return (await this.sdk(options)).ecr();
      }
      async secretsManagerClient(options) {
        return (await this.sdk(options)).secretsManager();
      }
      /**
       * Get an SDK appropriate for the given client options
       */
      async sdk(options) {
        const env3 = {
          ...this.targetEnv,
          region: options.region ?? this.targetEnv.region
          // Default: same region as the stack
        };
        const cacheKeyMap = {
          env: env3,
          // region, name, account
          assumeRuleArn: options.assumeRoleArn,
          assumeRoleExternalId: options.assumeRoleExternalId
        };
        if (options.assumeRoleAdditionalOptions) {
          cacheKeyMap.assumeRoleAdditionalOptions = options.assumeRoleAdditionalOptions;
        }
        const cacheKey = JSON.stringify(cacheKeyMap);
        const maybeSdk = this.sdkCache.get(cacheKey);
        if (maybeSdk) {
          return maybeSdk;
        }
        const sdk = (await this.aws.forEnvironment(
          env3,
          1 /* ForWriting */,
          {
            assumeRoleArn: options.assumeRoleArn,
            assumeRoleExternalId: options.assumeRoleExternalId,
            assumeRoleAdditionalOptions: options.assumeRoleAdditionalOptions
          }
        )).sdk;
        this.sdkCache.set(cacheKey, sdk);
        return sdk;
      }
    };
    EVENT_TO_MSG_MAKER = {
      // tracked events
      start: IO.CDK_ASSETS_I5270,
      success: IO.CDK_ASSETS_I5275,
      fail: IO.CDK_ASSETS_E5279,
      // debug events
      build: IO.CDK_ASSETS_I5271,
      cached: IO.CDK_ASSETS_I5271,
      check: IO.CDK_ASSETS_I5271,
      debug: IO.CDK_ASSETS_I5271,
      found: IO.CDK_ASSETS_I5271,
      upload: IO.CDK_ASSETS_I5271,
      shell_open: IO.CDK_ASSETS_I5271,
      // dropped events
      shell_stderr: false,
      shell_stdout: false,
      shell_close: false
    };
    BasePublishProgressListener = class {
      static {
        __name(this, "BasePublishProgressListener");
      }
      ioHelper;
      constructor(ioHelper) {
        this.ioHelper = ioHelper;
      }
      onPublishEvent(type, event) {
        const io = EVENT_TO_MSG_MAKER[type];
        if (io) {
          const message2 = this.getMessage(type, event);
          void this.ioHelper.notify(io.msg(message2, {
            type,
            message: message2,
            progressPercentage: event.percentComplete,
            asset: event.currentAsset
          }));
        }
      }
    };
    PublishingProgressListener = class extends BasePublishProgressListener {
      static {
        __name(this, "PublishingProgressListener");
      }
      getMessage(type, event) {
        return `[${event.percentComplete}%] ${type}: ${event.message}`;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/client/emitWarningIfUnsupportedVersion.js
var state8, emitWarningIfUnsupportedVersion23;
var init_emitWarningIfUnsupportedVersion8 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/client/emitWarningIfUnsupportedVersion.js"() {
    state8 = {
      warningEmitted: false
    };
    emitWarningIfUnsupportedVersion23 = /* @__PURE__ */ __name((version) => {
      if (version && !state8.warningEmitted) {
        if (process.env.AWS_SDK_JS_NODE_VERSION_SUPPORT_WARNING_DISABLED === "true") {
          state8.warningEmitted = true;
          return;
        }
        const userMajorVersion = parseInt(version.substring(1, version.indexOf(".")));
        const vv = 22;
        if (userMajorVersion < vv) {
          state8.warningEmitted = true;
          process.emitWarning(`NodeVersionSupportWarning: The AWS SDK for JavaScript (v3)
versions published after the first week of January 2027
will require node >=${vv}. You are running node ${version}.

To continue receiving updates to AWS services, bug fixes,
and security updates please upgrade to node >=${vv}.

More information can be found at: https://a.co/c895JFp`);
        }
      }
    }, "emitWarningIfUnsupportedVersion");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/client/longPollMiddleware.js
var longPollMiddleware8, longPollMiddlewareOptions8, getLongPollPlugin8;
var init_longPollMiddleware8 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/client/longPollMiddleware.js"() {
    longPollMiddleware8 = /* @__PURE__ */ __name(() => (next, context) => async (args) => {
      context.__retryLongPoll = true;
      return next(args);
    }, "longPollMiddleware");
    longPollMiddlewareOptions8 = {
      name: "longPollMiddleware",
      tags: ["RETRY"],
      step: "initialize",
      override: true
    };
    getLongPollPlugin8 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(longPollMiddleware8(), longPollMiddlewareOptions8);
      }, "applyToStack")
    }), "getLongPollPlugin");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/client/setCredentialFeature.js
function setCredentialFeature8(credentials, feature, value) {
  if (!credentials.$source) {
    credentials.$source = {};
  }
  credentials.$source[feature] = value;
  return credentials;
}
var init_setCredentialFeature8 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/client/setCredentialFeature.js"() {
    __name(setCredentialFeature8, "setCredentialFeature");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/client/setFeature.js
function setFeature10(context, feature, value) {
  if (!context.__aws_sdk_context) {
    context.__aws_sdk_context = {
      features: {}
    };
  } else if (!context.__aws_sdk_context.features) {
    context.__aws_sdk_context.features = {};
  }
  context.__aws_sdk_context.features[feature] = value;
}
var import_util_retry23;
var init_setFeature9 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/client/setFeature.js"() {
    import_util_retry23 = __toESM(require_dist_cjs22());
    import_util_retry23.Retry.v2026 ||= typeof process === "object" && process.env?.AWS_NEW_RETRIES_2026 === "true";
    __name(setFeature10, "setFeature");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/client/setTokenFeature.js
function setTokenFeature8(token, feature, value) {
  if (!token.$source) {
    token.$source = {};
  }
  token.$source[feature] = value;
  return token;
}
var init_setTokenFeature8 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/client/setTokenFeature.js"() {
    __name(setTokenFeature8, "setTokenFeature");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/client/index.js
var client_exports8 = {};
__export(client_exports8, {
  emitWarningIfUnsupportedVersion: () => emitWarningIfUnsupportedVersion23,
  getLongPollPlugin: () => getLongPollPlugin8,
  setCredentialFeature: () => setCredentialFeature8,
  setFeature: () => setFeature10,
  setTokenFeature: () => setTokenFeature8,
  state: () => state8
});
var init_client10 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/client/index.js"() {
    init_emitWarningIfUnsupportedVersion8();
    init_longPollMiddleware8();
    init_setCredentialFeature8();
    init_setFeature9();
    init_setTokenFeature8();
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/middleware-user-agent/dist-cjs/index.js
var require_dist_cjs127 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/middleware-user-agent/dist-cjs/index.js"(exports2) {
    "use strict";
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var utilEndpoints = require_dist_cjs21();
    var protocolHttp = require_dist_cjs2();
    var client = (init_client10(), __toCommonJS(client_exports8));
    var utilRetry = require_dist_cjs22();
    var DEFAULT_UA_APP_ID2 = void 0;
    function isValidUserAgentAppId2(appId) {
      if (appId === void 0) {
        return true;
      }
      return typeof appId === "string" && appId.length <= 50;
    }
    __name(isValidUserAgentAppId2, "isValidUserAgentAppId");
    function resolveUserAgentConfig29(input) {
      const normalizedAppIdProvider = core.normalizeProvider(input.userAgentAppId ?? DEFAULT_UA_APP_ID2);
      const { customUserAgent } = input;
      return Object.assign(input, {
        customUserAgent: typeof customUserAgent === "string" ? [[customUserAgent]] : customUserAgent,
        userAgentAppId: /* @__PURE__ */ __name(async () => {
          const appId = await normalizedAppIdProvider();
          if (!isValidUserAgentAppId2(appId)) {
            const logger5 = input.logger?.constructor?.name === "NoOpLogger" || !input.logger ? console : input.logger;
            if (typeof appId !== "string") {
              logger5?.warn("userAgentAppId must be a string or undefined.");
            } else if (appId.length > 50) {
              logger5?.warn("The provided userAgentAppId exceeds the maximum length of 50 characters.");
            }
          }
          return appId;
        }, "userAgentAppId")
      });
    }
    __name(resolveUserAgentConfig29, "resolveUserAgentConfig");
    var ACCOUNT_ID_ENDPOINT_REGEX2 = /\d{12}\.ddb/;
    async function checkFeatures2(context, config2, args) {
      const request4 = args.request;
      if (request4?.headers?.["smithy-protocol"] === "rpc-v2-cbor") {
        client.setFeature(context, "PROTOCOL_RPC_V2_CBOR", "M");
      }
      if (typeof config2.retryStrategy === "function") {
        const retryStrategy = await config2.retryStrategy();
        if (typeof retryStrategy.mode === "string") {
          switch (retryStrategy.mode) {
            case utilRetry.RETRY_MODES.ADAPTIVE:
              client.setFeature(context, "RETRY_MODE_ADAPTIVE", "F");
              break;
            case utilRetry.RETRY_MODES.STANDARD:
              client.setFeature(context, "RETRY_MODE_STANDARD", "E");
              break;
          }
        }
      }
      if (typeof config2.accountIdEndpointMode === "function") {
        const endpointV2 = context.endpointV2;
        if (String(endpointV2?.url?.hostname).match(ACCOUNT_ID_ENDPOINT_REGEX2)) {
          client.setFeature(context, "ACCOUNT_ID_ENDPOINT", "O");
        }
        switch (await config2.accountIdEndpointMode?.()) {
          case "disabled":
            client.setFeature(context, "ACCOUNT_ID_MODE_DISABLED", "Q");
            break;
          case "preferred":
            client.setFeature(context, "ACCOUNT_ID_MODE_PREFERRED", "P");
            break;
          case "required":
            client.setFeature(context, "ACCOUNT_ID_MODE_REQUIRED", "R");
            break;
        }
      }
      const identity = context.__smithy_context?.selectedHttpAuthScheme?.identity;
      if (identity?.$source) {
        const credentials = identity;
        if (credentials.accountId) {
          client.setFeature(context, "RESOLVED_ACCOUNT_ID", "T");
        }
        for (const [key, value] of Object.entries(credentials.$source ?? {})) {
          client.setFeature(context, key, value);
        }
      }
    }
    __name(checkFeatures2, "checkFeatures");
    var USER_AGENT3 = "user-agent";
    var X_AMZ_USER_AGENT2 = "x-amz-user-agent";
    var SPACE2 = " ";
    var UA_NAME_SEPARATOR2 = "/";
    var UA_NAME_ESCAPE_REGEX2 = /[^!$%&'*+\-.^_`|~\w]/g;
    var UA_VALUE_ESCAPE_REGEX2 = /[^!$%&'*+\-.^_`|~\w#]/g;
    var UA_ESCAPE_CHAR2 = "-";
    var BYTE_LIMIT2 = 1024;
    function encodeFeatures2(features) {
      let buffer = "";
      for (const key in features) {
        const val = features[key];
        if (buffer.length + val.length + 1 <= BYTE_LIMIT2) {
          if (buffer.length) {
            buffer += "," + val;
          } else {
            buffer += val;
          }
          continue;
        }
        break;
      }
      return buffer;
    }
    __name(encodeFeatures2, "encodeFeatures");
    var userAgentMiddleware2 = /* @__PURE__ */ __name((options) => (next, context) => async (args) => {
      const { request: request4 } = args;
      if (!protocolHttp.HttpRequest.isInstance(request4)) {
        return next(args);
      }
      const { headers } = request4;
      const userAgent = context?.userAgent?.map(escapeUserAgent2) || [];
      const defaultUserAgent2 = (await options.defaultUserAgentProvider()).map(escapeUserAgent2);
      await checkFeatures2(context, options, args);
      const awsContext = context;
      defaultUserAgent2.push(`m/${encodeFeatures2(Object.assign({}, context.__smithy_context?.features, awsContext.__aws_sdk_context?.features))}`);
      const customUserAgent = options?.customUserAgent?.map(escapeUserAgent2) || [];
      const appId = await options.userAgentAppId();
      if (appId) {
        defaultUserAgent2.push(escapeUserAgent2([`app`, `${appId}`]));
      }
      const prefix = utilEndpoints.getUserAgentPrefix();
      const sdkUserAgentValue = (prefix ? [prefix] : []).concat([...defaultUserAgent2, ...userAgent, ...customUserAgent]).join(SPACE2);
      const normalUAValue = [
        ...defaultUserAgent2.filter((section) => section.startsWith("aws-sdk-")),
        ...customUserAgent
      ].join(SPACE2);
      if (options.runtime !== "browser") {
        if (normalUAValue) {
          headers[X_AMZ_USER_AGENT2] = headers[X_AMZ_USER_AGENT2] ? `${headers[USER_AGENT3]} ${normalUAValue}` : normalUAValue;
        }
        headers[USER_AGENT3] = sdkUserAgentValue;
      } else {
        headers[X_AMZ_USER_AGENT2] = sdkUserAgentValue;
      }
      return next({
        ...args,
        request: request4
      });
    }, "userAgentMiddleware");
    var escapeUserAgent2 = /* @__PURE__ */ __name((userAgentPair) => {
      const name = userAgentPair[0].split(UA_NAME_SEPARATOR2).map((part) => part.replace(UA_NAME_ESCAPE_REGEX2, UA_ESCAPE_CHAR2)).join(UA_NAME_SEPARATOR2);
      const version = userAgentPair[1]?.replace(UA_VALUE_ESCAPE_REGEX2, UA_ESCAPE_CHAR2);
      const prefixSeparatorIndex = name.indexOf(UA_NAME_SEPARATOR2);
      const prefix = name.substring(0, prefixSeparatorIndex);
      let uaName = name.substring(prefixSeparatorIndex + 1);
      if (prefix === "api") {
        uaName = uaName.toLowerCase();
      }
      return [prefix, uaName, version].filter((item) => item && item.length > 0).reduce((acc, item, index) => {
        switch (index) {
          case 0:
            return item;
          case 1:
            return `${acc}/${item}`;
          default:
            return `${acc}#${item}`;
        }
      }, "");
    }, "escapeUserAgent");
    var getUserAgentMiddlewareOptions2 = {
      name: "getUserAgentMiddleware",
      step: "build",
      priority: "low",
      tags: ["SET_USER_AGENT", "USER_AGENT"],
      override: true
    };
    var getUserAgentPlugin29 = /* @__PURE__ */ __name((config2) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(userAgentMiddleware2(config2), getUserAgentMiddlewareOptions2);
      }, "applyToStack")
    }), "getUserAgentPlugin");
    exports2.DEFAULT_UA_APP_ID = DEFAULT_UA_APP_ID2;
    exports2.getUserAgentMiddlewareOptions = getUserAgentMiddlewareOptions2;
    exports2.getUserAgentPlugin = getUserAgentPlugin29;
    exports2.resolveUserAgentConfig = resolveUserAgentConfig29;
    exports2.userAgentMiddleware = userAgentMiddleware2;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/middleware-retry/dist-cjs/isStreamingPayload/isStreamingPayload.js
var require_isStreamingPayload6 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/middleware-retry/dist-cjs/isStreamingPayload/isStreamingPayload.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isStreamingPayload = void 0;
    var stream_1 = require("stream");
    var isStreamingPayload3 = /* @__PURE__ */ __name((request4) => request4?.body instanceof stream_1.Readable || typeof ReadableStream !== "undefined" && request4?.body instanceof ReadableStream, "isStreamingPayload");
    exports2.isStreamingPayload = isStreamingPayload3;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/middleware-retry/dist-cjs/index.js
var require_dist_cjs128 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/middleware-retry/dist-cjs/index.js"(exports2) {
    "use strict";
    var utilRetry = require_dist_cjs22();
    var protocolHttp = require_dist_cjs2();
    var serviceErrorClassification = require_dist_cjs32();
    var uuid = require_dist_cjs19();
    var utilMiddleware = require_dist_cjs6();
    var smithyClient = require_dist_cjs34();
    var isStreamingPayload3 = require_isStreamingPayload6();
    var serde = (init_serde(), __toCommonJS(serde_exports));
    var asSdkError3 = /* @__PURE__ */ __name((error4) => {
      if (error4 instanceof Error)
        return error4;
      if (error4 instanceof Object)
        return Object.assign(new Error(), error4);
      if (typeof error4 === "string")
        return new Error(error4);
      return new Error(`AWS SDK error wrapper for ${error4}`);
    }, "asSdkError");
    var getDefaultRetryQuota3 = /* @__PURE__ */ __name((initialRetryTokens, options) => {
      const MAX_CAPACITY = initialRetryTokens;
      const noRetryIncrement = utilRetry.NO_RETRY_INCREMENT;
      const retryCost = utilRetry.RETRY_COST;
      const timeoutRetryCost = utilRetry.TIMEOUT_RETRY_COST;
      let availableCapacity = initialRetryTokens;
      const getCapacityAmount = /* @__PURE__ */ __name((error4) => error4.name === "TimeoutError" ? timeoutRetryCost : retryCost, "getCapacityAmount");
      const hasRetryTokens = /* @__PURE__ */ __name((error4) => getCapacityAmount(error4) <= availableCapacity, "hasRetryTokens");
      const retrieveRetryTokens = /* @__PURE__ */ __name((error4) => {
        if (!hasRetryTokens(error4)) {
          throw new Error("No retry token available");
        }
        const capacityAmount = getCapacityAmount(error4);
        availableCapacity -= capacityAmount;
        return capacityAmount;
      }, "retrieveRetryTokens");
      const releaseRetryTokens = /* @__PURE__ */ __name((capacityReleaseAmount) => {
        availableCapacity += capacityReleaseAmount ?? noRetryIncrement;
        availableCapacity = Math.min(availableCapacity, MAX_CAPACITY);
      }, "releaseRetryTokens");
      return Object.freeze({
        hasRetryTokens,
        retrieveRetryTokens,
        releaseRetryTokens
      });
    }, "getDefaultRetryQuota");
    var defaultDelayDecider3 = /* @__PURE__ */ __name((delayBase, attempts) => Math.floor(Math.min(utilRetry.MAXIMUM_RETRY_DELAY, Math.random() * 2 ** attempts * delayBase)), "defaultDelayDecider");
    var defaultRetryDecider3 = /* @__PURE__ */ __name((error4) => {
      if (!error4) {
        return false;
      }
      return serviceErrorClassification.isRetryableByTrait(error4) || serviceErrorClassification.isClockSkewError(error4) || serviceErrorClassification.isThrottlingError(error4) || serviceErrorClassification.isTransientError(error4);
    }, "defaultRetryDecider");
    var StandardRetryStrategy5 = class {
      static {
        __name(this, "StandardRetryStrategy");
      }
      maxAttemptsProvider;
      retryDecider;
      delayDecider;
      retryQuota;
      mode = utilRetry.RETRY_MODES.STANDARD;
      constructor(maxAttemptsProvider, options) {
        this.maxAttemptsProvider = maxAttemptsProvider;
        this.retryDecider = options?.retryDecider ?? defaultRetryDecider3;
        this.delayDecider = options?.delayDecider ?? defaultDelayDecider3;
        this.retryQuota = options?.retryQuota ?? getDefaultRetryQuota3(utilRetry.INITIAL_RETRY_TOKENS);
      }
      shouldRetry(error4, attempts, maxAttempts) {
        return attempts < maxAttempts && this.retryDecider(error4) && this.retryQuota.hasRetryTokens(error4);
      }
      async getMaxAttempts() {
        let maxAttempts;
        try {
          maxAttempts = await this.maxAttemptsProvider();
        } catch (error4) {
          maxAttempts = utilRetry.DEFAULT_MAX_ATTEMPTS;
        }
        return maxAttempts;
      }
      async retry(next, args, options) {
        let retryTokenAmount;
        let attempts = 0;
        let totalDelay = 0;
        const maxAttempts = await this.getMaxAttempts();
        const { request: request4 } = args;
        if (protocolHttp.HttpRequest.isInstance(request4)) {
          request4.headers[utilRetry.INVOCATION_ID_HEADER] = uuid.v4();
        }
        while (true) {
          try {
            if (protocolHttp.HttpRequest.isInstance(request4)) {
              request4.headers[utilRetry.REQUEST_HEADER] = `attempt=${attempts + 1}; max=${maxAttempts}`;
            }
            if (options?.beforeRequest) {
              await options.beforeRequest();
            }
            const { response, output } = await next(args);
            if (options?.afterRequest) {
              options.afterRequest(response);
            }
            this.retryQuota.releaseRetryTokens(retryTokenAmount);
            output.$metadata.attempts = attempts + 1;
            output.$metadata.totalRetryDelay = totalDelay;
            return { response, output };
          } catch (e32) {
            const err = asSdkError3(e32);
            attempts++;
            if (this.shouldRetry(err, attempts, maxAttempts)) {
              retryTokenAmount = this.retryQuota.retrieveRetryTokens(err);
              const delayFromDecider = this.delayDecider(serviceErrorClassification.isThrottlingError(err) ? utilRetry.THROTTLING_RETRY_DELAY_BASE : utilRetry.DEFAULT_RETRY_DELAY_BASE, attempts);
              const delayFromResponse = getDelayFromRetryAfterHeader3(err.$response);
              const delay = Math.max(delayFromResponse || 0, delayFromDecider);
              totalDelay += delay;
              await new Promise((resolve13) => setTimeout(resolve13, delay));
              continue;
            }
            if (!err.$metadata) {
              err.$metadata = {};
            }
            err.$metadata.attempts = attempts;
            err.$metadata.totalRetryDelay = totalDelay;
            throw err;
          }
        }
      }
    };
    var getDelayFromRetryAfterHeader3 = /* @__PURE__ */ __name((response) => {
      if (!protocolHttp.HttpResponse.isInstance(response))
        return;
      const retryAfterHeaderName = Object.keys(response.headers).find((key) => key.toLowerCase() === "retry-after");
      if (!retryAfterHeaderName)
        return;
      const retryAfter = response.headers[retryAfterHeaderName];
      const retryAfterSeconds = Number(retryAfter);
      if (!Number.isNaN(retryAfterSeconds))
        return retryAfterSeconds * 1e3;
      const retryAfterDate = new Date(retryAfter);
      return retryAfterDate.getTime() - Date.now();
    }, "getDelayFromRetryAfterHeader");
    var AdaptiveRetryStrategy5 = class extends StandardRetryStrategy5 {
      static {
        __name(this, "AdaptiveRetryStrategy");
      }
      rateLimiter;
      constructor(maxAttemptsProvider, options) {
        const { rateLimiter, ...superOptions } = options ?? {};
        super(maxAttemptsProvider, superOptions);
        this.rateLimiter = rateLimiter ?? new utilRetry.DefaultRateLimiter();
        this.mode = utilRetry.RETRY_MODES.ADAPTIVE;
      }
      async retry(next, args) {
        return super.retry(next, args, {
          beforeRequest: /* @__PURE__ */ __name(async () => {
            return this.rateLimiter.getSendToken();
          }, "beforeRequest"),
          afterRequest: /* @__PURE__ */ __name((response) => {
            this.rateLimiter.updateClientSendingRate(response);
          }, "afterRequest")
        });
      }
    };
    var ENV_MAX_ATTEMPTS3 = "AWS_MAX_ATTEMPTS";
    var CONFIG_MAX_ATTEMPTS3 = "max_attempts";
    var NODE_MAX_ATTEMPT_CONFIG_OPTIONS30 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => {
        const value = env3[ENV_MAX_ATTEMPTS3];
        if (!value)
          return void 0;
        const maxAttempt = parseInt(value);
        if (Number.isNaN(maxAttempt)) {
          throw new Error(`Environment variable ${ENV_MAX_ATTEMPTS3} mast be a number, got "${value}"`);
        }
        return maxAttempt;
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => {
        const value = profile[CONFIG_MAX_ATTEMPTS3];
        if (!value)
          return void 0;
        const maxAttempt = parseInt(value);
        if (Number.isNaN(maxAttempt)) {
          throw new Error(`Shared config file entry ${CONFIG_MAX_ATTEMPTS3} mast be a number, got "${value}"`);
        }
        return maxAttempt;
      }, "configFileSelector"),
      default: utilRetry.DEFAULT_MAX_ATTEMPTS
    };
    var resolveRetryConfig30 = /* @__PURE__ */ __name((input) => {
      const { retryStrategy, retryMode } = input;
      const maxAttempts = utilMiddleware.normalizeProvider(input.maxAttempts ?? utilRetry.DEFAULT_MAX_ATTEMPTS);
      let controller = retryStrategy ? Promise.resolve(retryStrategy) : void 0;
      const getDefault = /* @__PURE__ */ __name(async () => await utilMiddleware.normalizeProvider(retryMode)() === utilRetry.RETRY_MODES.ADAPTIVE ? new utilRetry.AdaptiveRetryStrategy(maxAttempts) : new utilRetry.StandardRetryStrategy(maxAttempts), "getDefault");
      return Object.assign(input, {
        maxAttempts,
        retryStrategy: /* @__PURE__ */ __name(() => controller ??= getDefault(), "retryStrategy")
      });
    }, "resolveRetryConfig");
    var ENV_RETRY_MODE3 = "AWS_RETRY_MODE";
    var CONFIG_RETRY_MODE3 = "retry_mode";
    var NODE_RETRY_MODE_CONFIG_OPTIONS30 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[ENV_RETRY_MODE3], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[CONFIG_RETRY_MODE3], "configFileSelector"),
      default: utilRetry.DEFAULT_RETRY_MODE
    };
    var omitRetryHeadersMiddleware3 = /* @__PURE__ */ __name(() => (next) => async (args) => {
      const { request: request4 } = args;
      if (protocolHttp.HttpRequest.isInstance(request4)) {
        delete request4.headers[utilRetry.INVOCATION_ID_HEADER];
        delete request4.headers[utilRetry.REQUEST_HEADER];
      }
      return next(args);
    }, "omitRetryHeadersMiddleware");
    var omitRetryHeadersMiddlewareOptions3 = {
      name: "omitRetryHeadersMiddleware",
      tags: ["RETRY", "HEADERS", "OMIT_RETRY_HEADERS"],
      relation: "before",
      toMiddleware: "awsAuthMiddleware",
      override: true
    };
    var getOmitRetryHeadersPlugin3 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.addRelativeTo(omitRetryHeadersMiddleware3(), omitRetryHeadersMiddlewareOptions3);
      }, "applyToStack")
    }), "getOmitRetryHeadersPlugin");
    function parseRetryAfterHeader3(response, logger5) {
      if (!protocolHttp.HttpResponse.isInstance(response)) {
        return;
      }
      for (const header of Object.keys(response.headers)) {
        const h32 = header.toLowerCase();
        if (h32 === "retry-after") {
          const retryAfter = response.headers[header];
          let retryAfterSeconds = NaN;
          if (retryAfter.endsWith("GMT")) {
            try {
              const date7 = serde.parseRfc7231DateTime(retryAfter);
              retryAfterSeconds = (date7.getTime() - Date.now()) / 1e3;
            } catch (e32) {
              logger5?.trace?.("Failed to parse retry-after header");
              logger5?.trace?.(e32);
            }
          } else if (retryAfter.match(/ GMT, ((\d+)|(\d+\.\d+))$/)) {
            retryAfterSeconds = Number(retryAfter.match(/ GMT, ([\d.]+)$/)?.[1]);
          } else if (retryAfter.match(/^((\d+)|(\d+\.\d+))$/)) {
            retryAfterSeconds = Number(retryAfter);
          } else if (Date.parse(retryAfter) >= Date.now()) {
            retryAfterSeconds = (Date.parse(retryAfter) - Date.now()) / 1e3;
          }
          if (isNaN(retryAfterSeconds)) {
            return;
          }
          return new Date(Date.now() + retryAfterSeconds * 1e3);
        } else if (h32 === "x-amz-retry-after") {
          const v = response.headers[header];
          const backoffMilliseconds = Number(v);
          if (isNaN(backoffMilliseconds)) {
            logger5?.trace?.(`Failed to parse x-amz-retry-after=${v}`);
            return;
          }
          return new Date(Date.now() + backoffMilliseconds);
        }
      }
    }
    __name(parseRetryAfterHeader3, "parseRetryAfterHeader");
    function getRetryAfterHint3(response, logger5) {
      return parseRetryAfterHeader3(response, logger5);
    }
    __name(getRetryAfterHint3, "getRetryAfterHint");
    var retryMiddleware3 = /* @__PURE__ */ __name((options) => (next, context) => async (args) => {
      let retryStrategy = await options.retryStrategy();
      const maxAttempts = await options.maxAttempts();
      if (isRetryStrategyV23(retryStrategy)) {
        retryStrategy = retryStrategy;
        let retryToken = await retryStrategy.acquireInitialRetryToken((context["partition_id"] ?? "") + (context.__retryLongPoll ? ":longpoll" : ""));
        let lastError = new Error();
        let attempts = 0;
        let totalRetryDelay = 0;
        const { request: request4 } = args;
        const isRequest = protocolHttp.HttpRequest.isInstance(request4);
        if (isRequest) {
          request4.headers[utilRetry.INVOCATION_ID_HEADER] = uuid.v4();
        }
        while (true) {
          try {
            if (isRequest) {
              request4.headers[utilRetry.REQUEST_HEADER] = `attempt=${attempts + 1}; max=${maxAttempts}`;
            }
            const { response, output } = await next(args);
            retryStrategy.recordSuccess(retryToken);
            output.$metadata.attempts = attempts + 1;
            output.$metadata.totalRetryDelay = totalRetryDelay;
            return { response, output };
          } catch (e32) {
            const retryErrorInfo = getRetryErrorInfo3(e32, options.logger);
            lastError = asSdkError3(e32);
            if (isRequest && isStreamingPayload3.isStreamingPayload(request4)) {
              (context.logger instanceof smithyClient.NoOpLogger ? console : context.logger)?.warn("An error was encountered in a non-retryable streaming request.");
              throw lastError;
            }
            try {
              retryToken = await retryStrategy.refreshRetryTokenForRetry(retryToken, retryErrorInfo);
            } catch (refreshError) {
              if (typeof refreshError.$backoff === "number") {
                await cooldown3(refreshError.$backoff);
              }
              if (!lastError.$metadata) {
                lastError.$metadata = {};
              }
              lastError.$metadata.attempts = attempts + 1;
              lastError.$metadata.totalRetryDelay = totalRetryDelay;
              throw lastError;
            }
            attempts = retryToken.getRetryCount();
            const delay = retryToken.getRetryDelay();
            totalRetryDelay += delay;
            await cooldown3(delay);
          }
        }
      } else {
        retryStrategy = retryStrategy;
        if (retryStrategy?.mode) {
          context.userAgent = [...context.userAgent || [], ["cfg/retry-mode", retryStrategy.mode]];
        }
        return retryStrategy.retry(next, args);
      }
    }, "retryMiddleware");
    var cooldown3 = /* @__PURE__ */ __name((ms) => new Promise((resolve13) => setTimeout(resolve13, ms)), "cooldown");
    var isRetryStrategyV23 = /* @__PURE__ */ __name((retryStrategy) => typeof retryStrategy.acquireInitialRetryToken !== "undefined" && typeof retryStrategy.refreshRetryTokenForRetry !== "undefined" && typeof retryStrategy.recordSuccess !== "undefined", "isRetryStrategyV2");
    var getRetryErrorInfo3 = /* @__PURE__ */ __name((error4, logger5) => {
      const errorInfo = {
        error: error4,
        errorType: getRetryErrorType3(error4)
      };
      const retryAfterHint = parseRetryAfterHeader3(error4.$response, logger5);
      if (retryAfterHint) {
        errorInfo.retryAfterHint = retryAfterHint;
      }
      return errorInfo;
    }, "getRetryErrorInfo");
    var getRetryErrorType3 = /* @__PURE__ */ __name((error4) => {
      if (serviceErrorClassification.isThrottlingError(error4))
        return "THROTTLING";
      if (serviceErrorClassification.isTransientError(error4))
        return "TRANSIENT";
      if (serviceErrorClassification.isServerError(error4))
        return "SERVER_ERROR";
      return "CLIENT_ERROR";
    }, "getRetryErrorType");
    var retryMiddlewareOptions3 = {
      name: "retryMiddleware",
      tags: ["RETRY"],
      step: "finalizeRequest",
      priority: "high",
      override: true
    };
    var getRetryPlugin30 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(retryMiddleware3(options), retryMiddlewareOptions3);
      }, "applyToStack")
    }), "getRetryPlugin");
    exports2.AdaptiveRetryStrategy = AdaptiveRetryStrategy5;
    exports2.CONFIG_MAX_ATTEMPTS = CONFIG_MAX_ATTEMPTS3;
    exports2.CONFIG_RETRY_MODE = CONFIG_RETRY_MODE3;
    exports2.ENV_MAX_ATTEMPTS = ENV_MAX_ATTEMPTS3;
    exports2.ENV_RETRY_MODE = ENV_RETRY_MODE3;
    exports2.NODE_MAX_ATTEMPT_CONFIG_OPTIONS = NODE_MAX_ATTEMPT_CONFIG_OPTIONS30;
    exports2.NODE_RETRY_MODE_CONFIG_OPTIONS = NODE_RETRY_MODE_CONFIG_OPTIONS30;
    exports2.StandardRetryStrategy = StandardRetryStrategy5;
    exports2.defaultDelayDecider = defaultDelayDecider3;
    exports2.defaultRetryDecider = defaultRetryDecider3;
    exports2.getOmitRetryHeadersPlugin = getOmitRetryHeadersPlugin3;
    exports2.getRetryAfterHint = getRetryAfterHint3;
    exports2.getRetryPlugin = getRetryPlugin30;
    exports2.omitRetryHeadersMiddleware = omitRetryHeadersMiddleware3;
    exports2.omitRetryHeadersMiddlewareOptions = omitRetryHeadersMiddlewareOptions3;
    exports2.resolveRetryConfig = resolveRetryConfig30;
    exports2.retryMiddleware = retryMiddleware3;
    exports2.retryMiddlewareOptions = retryMiddlewareOptions3;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getDateHeader.js
var import_protocol_http39, getDateHeader6;
var init_getDateHeader6 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getDateHeader.js"() {
    import_protocol_http39 = __toESM(require_dist_cjs2());
    getDateHeader6 = /* @__PURE__ */ __name((response) => import_protocol_http39.HttpResponse.isInstance(response) ? response.headers?.date ?? response.headers?.Date : void 0, "getDateHeader");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getSkewCorrectedDate.js
var getSkewCorrectedDate6;
var init_getSkewCorrectedDate6 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getSkewCorrectedDate.js"() {
    getSkewCorrectedDate6 = /* @__PURE__ */ __name((systemClockOffset) => new Date(Date.now() + systemClockOffset), "getSkewCorrectedDate");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/isClockSkewed.js
var isClockSkewed6;
var init_isClockSkewed6 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/isClockSkewed.js"() {
    init_getSkewCorrectedDate6();
    isClockSkewed6 = /* @__PURE__ */ __name((clockTime, systemClockOffset) => Math.abs(getSkewCorrectedDate6(systemClockOffset).getTime() - clockTime) >= 3e5, "isClockSkewed");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getUpdatedSystemClockOffset.js
var getUpdatedSystemClockOffset6;
var init_getUpdatedSystemClockOffset6 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getUpdatedSystemClockOffset.js"() {
    init_isClockSkewed6();
    getUpdatedSystemClockOffset6 = /* @__PURE__ */ __name((clockTime, currentSystemClockOffset) => {
      const clockTimeInMs = Date.parse(clockTime);
      if (isClockSkewed6(clockTimeInMs, currentSystemClockOffset)) {
        return clockTimeInMs - Date.now();
      }
      return currentSystemClockOffset;
    }, "getUpdatedSystemClockOffset");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/index.js
var init_utils8 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/index.js"() {
    init_getDateHeader6();
    init_getSkewCorrectedDate6();
    init_getUpdatedSystemClockOffset6();
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4Signer.js
var import_protocol_http40, throwSigningPropertyError6, validateSigningProperties6, AwsSdkSigV4Signer6, AWSSDKSigV4Signer6;
var init_AwsSdkSigV4Signer6 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4Signer.js"() {
    import_protocol_http40 = __toESM(require_dist_cjs2());
    init_utils8();
    throwSigningPropertyError6 = /* @__PURE__ */ __name((name, property) => {
      if (!property) {
        throw new Error(`Property \`${name}\` is not resolved for AWS SDK SigV4Auth`);
      }
      return property;
    }, "throwSigningPropertyError");
    validateSigningProperties6 = /* @__PURE__ */ __name(async (signingProperties) => {
      const context = throwSigningPropertyError6("context", signingProperties.context);
      const config2 = throwSigningPropertyError6("config", signingProperties.config);
      const authScheme = context.endpointV2?.properties?.authSchemes?.[0];
      const signerFunction = throwSigningPropertyError6("signer", config2.signer);
      const signer = await signerFunction(authScheme);
      const signingRegion = signingProperties?.signingRegion;
      const signingRegionSet = signingProperties?.signingRegionSet;
      const signingName = signingProperties?.signingName;
      return {
        config: config2,
        signer,
        signingRegion,
        signingRegionSet,
        signingName
      };
    }, "validateSigningProperties");
    AwsSdkSigV4Signer6 = class {
      static {
        __name(this, "AwsSdkSigV4Signer");
      }
      async sign(httpRequest, identity, signingProperties) {
        if (!import_protocol_http40.HttpRequest.isInstance(httpRequest)) {
          throw new Error("The request is not an instance of `HttpRequest` and cannot be signed");
        }
        const validatedProps = await validateSigningProperties6(signingProperties);
        const { config: config2, signer } = validatedProps;
        let { signingRegion, signingName } = validatedProps;
        const handlerExecutionContext = signingProperties.context;
        if (handlerExecutionContext?.authSchemes?.length ?? 0 > 1) {
          const [first, second] = handlerExecutionContext.authSchemes;
          if (first?.name === "sigv4a" && second?.name === "sigv4") {
            signingRegion = second?.signingRegion ?? signingRegion;
            signingName = second?.signingName ?? signingName;
          }
        }
        const signedRequest = await signer.sign(httpRequest, {
          signingDate: getSkewCorrectedDate6(config2.systemClockOffset),
          signingRegion,
          signingService: signingName
        });
        return signedRequest;
      }
      errorHandler(signingProperties) {
        return (error4) => {
          const serverTime = error4.ServerTime ?? getDateHeader6(error4.$response);
          if (serverTime) {
            const config2 = throwSigningPropertyError6("config", signingProperties.config);
            const initialSystemClockOffset = config2.systemClockOffset;
            config2.systemClockOffset = getUpdatedSystemClockOffset6(serverTime, config2.systemClockOffset);
            const clockSkewCorrected = config2.systemClockOffset !== initialSystemClockOffset;
            if (clockSkewCorrected && error4.$metadata) {
              error4.$metadata.clockSkewCorrected = true;
            }
          }
          throw error4;
        };
      }
      successHandler(httpResponse, signingProperties) {
        const dateHeader = getDateHeader6(httpResponse);
        if (dateHeader) {
          const config2 = throwSigningPropertyError6("config", signingProperties.config);
          config2.systemClockOffset = getUpdatedSystemClockOffset6(dateHeader, config2.systemClockOffset);
        }
      }
    };
    AWSSDKSigV4Signer6 = AwsSdkSigV4Signer6;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4ASigner.js
var import_protocol_http41, AwsSdkSigV4ASigner6;
var init_AwsSdkSigV4ASigner6 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4ASigner.js"() {
    import_protocol_http41 = __toESM(require_dist_cjs2());
    init_utils8();
    init_AwsSdkSigV4Signer6();
    AwsSdkSigV4ASigner6 = class extends AwsSdkSigV4Signer6 {
      static {
        __name(this, "AwsSdkSigV4ASigner");
      }
      async sign(httpRequest, identity, signingProperties) {
        if (!import_protocol_http41.HttpRequest.isInstance(httpRequest)) {
          throw new Error("The request is not an instance of `HttpRequest` and cannot be signed");
        }
        const { config: config2, signer, signingRegion, signingRegionSet, signingName } = await validateSigningProperties6(signingProperties);
        const configResolvedSigningRegionSet = await config2.sigv4aSigningRegionSet?.();
        const multiRegionOverride = (configResolvedSigningRegionSet ?? signingRegionSet ?? [signingRegion]).join(",");
        const signedRequest = await signer.sign(httpRequest, {
          signingDate: getSkewCorrectedDate6(config2.systemClockOffset),
          signingRegion: multiRegionOverride,
          signingService: signingName
        });
        return signedRequest;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getArrayForCommaSeparatedString.js
var getArrayForCommaSeparatedString6;
var init_getArrayForCommaSeparatedString6 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getArrayForCommaSeparatedString.js"() {
    getArrayForCommaSeparatedString6 = /* @__PURE__ */ __name((str) => typeof str === "string" && str.length > 0 ? str.split(",").map((item) => item.trim()) : [], "getArrayForCommaSeparatedString");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getBearerTokenEnvKey.js
var getBearerTokenEnvKey6;
var init_getBearerTokenEnvKey6 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getBearerTokenEnvKey.js"() {
    getBearerTokenEnvKey6 = /* @__PURE__ */ __name((signingName) => `AWS_BEARER_TOKEN_${signingName.replace(/[\s-]/g, "_").toUpperCase()}`, "getBearerTokenEnvKey");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/NODE_AUTH_SCHEME_PREFERENCE_OPTIONS.js
var NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY6, NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY6, NODE_AUTH_SCHEME_PREFERENCE_OPTIONS6;
var init_NODE_AUTH_SCHEME_PREFERENCE_OPTIONS6 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/NODE_AUTH_SCHEME_PREFERENCE_OPTIONS.js"() {
    init_getArrayForCommaSeparatedString6();
    init_getBearerTokenEnvKey6();
    NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY6 = "AWS_AUTH_SCHEME_PREFERENCE";
    NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY6 = "auth_scheme_preference";
    NODE_AUTH_SCHEME_PREFERENCE_OPTIONS6 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3, options) => {
        if (options?.signingName) {
          const bearerTokenKey = getBearerTokenEnvKey6(options.signingName);
          if (bearerTokenKey in env3)
            return ["httpBearerAuth"];
        }
        if (!(NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY6 in env3))
          return void 0;
        return getArrayForCommaSeparatedString6(env3[NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY6]);
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => {
        if (!(NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY6 in profile))
          return void 0;
        return getArrayForCommaSeparatedString6(profile[NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY6]);
      }, "configFileSelector"),
      default: []
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4AConfig.js
var import_property_provider6, resolveAwsSdkSigV4AConfig6, NODE_SIGV4A_CONFIG_OPTIONS6;
var init_resolveAwsSdkSigV4AConfig6 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4AConfig.js"() {
    init_dist_es();
    import_property_provider6 = __toESM(require_dist_cjs27());
    resolveAwsSdkSigV4AConfig6 = /* @__PURE__ */ __name((config2) => {
      config2.sigv4aSigningRegionSet = normalizeProvider(config2.sigv4aSigningRegionSet);
      return config2;
    }, "resolveAwsSdkSigV4AConfig");
    NODE_SIGV4A_CONFIG_OPTIONS6 = {
      environmentVariableSelector(env3) {
        if (env3.AWS_SIGV4A_SIGNING_REGION_SET) {
          return env3.AWS_SIGV4A_SIGNING_REGION_SET.split(",").map((_) => _.trim());
        }
        throw new import_property_provider6.ProviderError("AWS_SIGV4A_SIGNING_REGION_SET not set in env.", {
          tryNextLink: true
        });
      },
      configFileSelector(profile) {
        if (profile.sigv4a_signing_region_set) {
          return (profile.sigv4a_signing_region_set ?? "").split(",").map((_) => _.trim());
        }
        throw new import_property_provider6.ProviderError("sigv4a_signing_region_set not set in profile.", {
          tryNextLink: true
        });
      },
      default: void 0
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4Config.js
function normalizeCredentialProvider6(config2, { credentials, credentialDefaultProvider }) {
  let credentialsProvider;
  if (credentials) {
    if (!credentials?.memoized) {
      credentialsProvider = memoizeIdentityProvider(credentials, isIdentityExpired, doesIdentityRequireRefresh);
    } else {
      credentialsProvider = credentials;
    }
  } else {
    if (credentialDefaultProvider) {
      credentialsProvider = normalizeProvider(credentialDefaultProvider(Object.assign({}, config2, {
        parentClientConfig: config2
      })));
    } else {
      credentialsProvider = /* @__PURE__ */ __name(async () => {
        throw new Error("@aws-sdk/core::resolveAwsSdkSigV4Config - `credentials` not provided and no credentialDefaultProvider was configured.");
      }, "credentialsProvider");
    }
  }
  credentialsProvider.memoized = true;
  return credentialsProvider;
}
function bindCallerConfig6(config2, credentialsProvider) {
  if (credentialsProvider.configBound) {
    return credentialsProvider;
  }
  const fn = /* @__PURE__ */ __name(async (options) => credentialsProvider({ ...options, callerClientConfig: config2 }), "fn");
  fn.memoized = credentialsProvider.memoized;
  fn.configBound = true;
  return fn;
}
var import_signature_v46, resolveAwsSdkSigV4Config6, resolveAWSSDKSigV4Config6;
var init_resolveAwsSdkSigV4Config6 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4Config.js"() {
    init_client10();
    init_dist_es();
    import_signature_v46 = __toESM(require_dist_cjs36());
    resolveAwsSdkSigV4Config6 = /* @__PURE__ */ __name((config2) => {
      let inputCredentials = config2.credentials;
      let isUserSupplied = !!config2.credentials;
      let resolvedCredentials = void 0;
      Object.defineProperty(config2, "credentials", {
        set(credentials) {
          if (credentials && credentials !== inputCredentials && credentials !== resolvedCredentials) {
            isUserSupplied = true;
          }
          inputCredentials = credentials;
          const memoizedProvider = normalizeCredentialProvider6(config2, {
            credentials: inputCredentials,
            credentialDefaultProvider: config2.credentialDefaultProvider
          });
          const boundProvider = bindCallerConfig6(config2, memoizedProvider);
          if (isUserSupplied && !boundProvider.attributed) {
            const isCredentialObject = typeof inputCredentials === "object" && inputCredentials !== null;
            resolvedCredentials = /* @__PURE__ */ __name(async (options) => {
              const creds = await boundProvider(options);
              const attributedCreds = creds;
              if (isCredentialObject && (!attributedCreds.$source || Object.keys(attributedCreds.$source).length === 0)) {
                return setCredentialFeature8(attributedCreds, "CREDENTIALS_CODE", "e");
              }
              return attributedCreds;
            }, "resolvedCredentials");
            resolvedCredentials.memoized = boundProvider.memoized;
            resolvedCredentials.configBound = boundProvider.configBound;
            resolvedCredentials.attributed = true;
          } else {
            resolvedCredentials = boundProvider;
          }
        },
        get() {
          return resolvedCredentials;
        },
        enumerable: true,
        configurable: true
      });
      config2.credentials = inputCredentials;
      const { signingEscapePath = true, systemClockOffset = config2.systemClockOffset || 0, sha256 } = config2;
      let signer;
      if (config2.signer) {
        signer = normalizeProvider(config2.signer);
      } else if (config2.regionInfoProvider) {
        signer = /* @__PURE__ */ __name(() => normalizeProvider(config2.region)().then(async (region) => [
          await config2.regionInfoProvider(region, {
            useFipsEndpoint: await config2.useFipsEndpoint(),
            useDualstackEndpoint: await config2.useDualstackEndpoint()
          }) || {},
          region
        ]).then(([regionInfo, region]) => {
          const { signingRegion, signingService } = regionInfo;
          config2.signingRegion = config2.signingRegion || signingRegion || region;
          config2.signingName = config2.signingName || signingService || config2.serviceId;
          const params = {
            ...config2,
            credentials: config2.credentials,
            region: config2.signingRegion,
            service: config2.signingName,
            sha256,
            uriEscapePath: signingEscapePath
          };
          const SignerCtor = config2.signerConstructor || import_signature_v46.SignatureV4;
          return new SignerCtor(params);
        }), "signer");
      } else {
        signer = /* @__PURE__ */ __name(async (authScheme) => {
          authScheme = Object.assign({}, {
            name: "sigv4",
            signingName: config2.signingName || config2.defaultSigningName,
            signingRegion: await normalizeProvider(config2.region)(),
            properties: {}
          }, authScheme);
          const signingRegion = authScheme.signingRegion;
          const signingService = authScheme.signingName;
          config2.signingRegion = config2.signingRegion || signingRegion;
          config2.signingName = config2.signingName || signingService || config2.serviceId;
          const params = {
            ...config2,
            credentials: config2.credentials,
            region: config2.signingRegion,
            service: config2.signingName,
            sha256,
            uriEscapePath: signingEscapePath
          };
          const SignerCtor = config2.signerConstructor || import_signature_v46.SignatureV4;
          return new SignerCtor(params);
        }, "signer");
      }
      const resolvedConfig = Object.assign(config2, {
        systemClockOffset,
        signingEscapePath,
        signer
      });
      return resolvedConfig;
    }, "resolveAwsSdkSigV4Config");
    resolveAWSSDKSigV4Config6 = resolveAwsSdkSigV4Config6;
    __name(normalizeCredentialProvider6, "normalizeCredentialProvider");
    __name(bindCallerConfig6, "bindCallerConfig");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/index.js
var init_aws_sdk6 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/index.js"() {
    init_AwsSdkSigV4Signer6();
    init_AwsSdkSigV4ASigner6();
    init_NODE_AUTH_SCHEME_PREFERENCE_OPTIONS6();
    init_resolveAwsSdkSigV4AConfig6();
    init_resolveAwsSdkSigV4Config6();
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/index.js
var httpAuthSchemes_exports6 = {};
__export(httpAuthSchemes_exports6, {
  AWSSDKSigV4Signer: () => AWSSDKSigV4Signer6,
  AwsSdkSigV4ASigner: () => AwsSdkSigV4ASigner6,
  AwsSdkSigV4Signer: () => AwsSdkSigV4Signer6,
  NODE_AUTH_SCHEME_PREFERENCE_OPTIONS: () => NODE_AUTH_SCHEME_PREFERENCE_OPTIONS6,
  NODE_SIGV4A_CONFIG_OPTIONS: () => NODE_SIGV4A_CONFIG_OPTIONS6,
  getBearerTokenEnvKey: () => getBearerTokenEnvKey6,
  resolveAWSSDKSigV4Config: () => resolveAWSSDKSigV4Config6,
  resolveAwsSdkSigV4AConfig: () => resolveAwsSdkSigV4AConfig6,
  resolveAwsSdkSigV4Config: () => resolveAwsSdkSigV4Config6,
  validateSigningProperties: () => validateSigningProperties6
});
var init_httpAuthSchemes7 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/index.js"() {
    init_aws_sdk6();
    init_getBearerTokenEnvKey6();
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/dist-cjs/auth/httpAuthSchemeProvider.js
var require_httpAuthSchemeProvider5 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/dist-cjs/auth/httpAuthSchemeProvider.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.resolveHttpAuthSchemeConfig = exports2.defaultCloudFormationHttpAuthSchemeProvider = exports2.defaultCloudFormationHttpAuthSchemeParametersProvider = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes7(), __toCommonJS(httpAuthSchemes_exports6));
    var util_middleware_1 = require_dist_cjs6();
    var defaultCloudFormationHttpAuthSchemeParametersProvider = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, util_middleware_1.getSmithyContext)(context).operation,
        region: await (0, util_middleware_1.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultCloudFormationHttpAuthSchemeParametersProvider");
    exports2.defaultCloudFormationHttpAuthSchemeParametersProvider = defaultCloudFormationHttpAuthSchemeParametersProvider;
    function createAwsAuthSigv4HttpAuthOption32(authParameters) {
      return {
        schemeId: "aws.auth#sigv4",
        signingProperties: {
          name: "cloudformation",
          region: authParameters.region
        },
        propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
          signingProperties: {
            config: config2,
            context
          }
        }), "propertiesExtractor")
      };
    }
    __name(createAwsAuthSigv4HttpAuthOption32, "createAwsAuthSigv4HttpAuthOption");
    var defaultCloudFormationHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption32(authParameters));
        }
      }
      return options;
    }, "defaultCloudFormationHttpAuthSchemeProvider");
    exports2.defaultCloudFormationHttpAuthSchemeProvider = defaultCloudFormationHttpAuthSchemeProvider;
    var resolveHttpAuthSchemeConfig32 = /* @__PURE__ */ __name((config2) => {
      const config_0 = (0, httpAuthSchemes_1.resolveAwsSdkSigV4Config)(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, util_middleware_1.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
    exports2.resolveHttpAuthSchemeConfig = resolveHttpAuthSchemeConfig32;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/package.json
var require_package5 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/package.json"(exports2, module2) {
    module2.exports = {
      name: "@aws-sdk/client-cloudformation",
      description: "AWS SDK for JavaScript Cloudformation Client for Node.js, Browser and React Native",
      version: "3.1041.0",
      scripts: {
        build: "concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline client-cloudformation",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        "extract:docs": "api-extractor run --local",
        "generate:client": "node ../../scripts/generate-clients/single-service --solo cloudformation",
        "test:e2e": "yarn g:vitest run -c vitest.config.e2e.mts",
        "test:e2e:watch": "yarn g:vitest watch -c vitest.config.e2e.mts",
        "test:index": "tsc --noEmit ./test/index-types.ts && node ./test/index-objects.spec.mjs"
      },
      main: "./dist-cjs/index.js",
      types: "./dist-types/index.d.ts",
      module: "./dist-es/index.js",
      sideEffects: false,
      dependencies: {
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.8",
        "@aws-sdk/credential-provider-node": "^3.972.39",
        "@aws-sdk/middleware-host-header": "^3.972.10",
        "@aws-sdk/middleware-logger": "^3.972.10",
        "@aws-sdk/middleware-recursion-detection": "^3.972.11",
        "@aws-sdk/middleware-user-agent": "^3.972.38",
        "@aws-sdk/region-config-resolver": "^3.972.13",
        "@aws-sdk/types": "^3.973.8",
        "@aws-sdk/util-endpoints": "^3.996.8",
        "@aws-sdk/util-user-agent-browser": "^3.972.10",
        "@aws-sdk/util-user-agent-node": "^3.973.24",
        "@smithy/config-resolver": "^4.4.17",
        "@smithy/core": "^3.23.17",
        "@smithy/fetch-http-handler": "^5.3.17",
        "@smithy/hash-node": "^4.2.14",
        "@smithy/invalid-dependency": "^4.2.14",
        "@smithy/middleware-content-length": "^4.2.14",
        "@smithy/middleware-endpoint": "^4.4.32",
        "@smithy/middleware-retry": "^4.5.7",
        "@smithy/middleware-serde": "^4.2.20",
        "@smithy/middleware-stack": "^4.2.14",
        "@smithy/node-config-provider": "^4.3.14",
        "@smithy/node-http-handler": "^4.6.1",
        "@smithy/protocol-http": "^5.3.14",
        "@smithy/smithy-client": "^4.12.13",
        "@smithy/types": "^4.14.1",
        "@smithy/url-parser": "^4.2.14",
        "@smithy/util-base64": "^4.3.2",
        "@smithy/util-body-length-browser": "^4.2.2",
        "@smithy/util-body-length-node": "^4.2.3",
        "@smithy/util-defaults-mode-browser": "^4.3.49",
        "@smithy/util-defaults-mode-node": "^4.2.54",
        "@smithy/util-endpoints": "^3.4.2",
        "@smithy/util-middleware": "^4.2.14",
        "@smithy/util-retry": "^4.3.6",
        "@smithy/util-utf8": "^4.2.2",
        "@smithy/util-waiter": "^4.3.0",
        tslib: "^2.6.2"
      },
      devDependencies: {
        "@tsconfig/node20": "20.1.8",
        "@types/node": "^20.14.8",
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3"
      },
      engines: {
        node: ">=20.0.0"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "dist-*/**"
      ],
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      browser: {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.browser"
      },
      "react-native": {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.native"
      },
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/clients/client-cloudformation",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "clients/client-cloudformation"
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-env/dist-cjs/index.js
var require_dist_cjs129 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-env/dist-cjs/index.js"(exports2) {
    "use strict";
    var client = (init_client10(), __toCommonJS(client_exports8));
    var propertyProvider = require_dist_cjs27();
    var ENV_KEY = "AWS_ACCESS_KEY_ID";
    var ENV_SECRET = "AWS_SECRET_ACCESS_KEY";
    var ENV_SESSION = "AWS_SESSION_TOKEN";
    var ENV_EXPIRATION = "AWS_CREDENTIAL_EXPIRATION";
    var ENV_CREDENTIAL_SCOPE = "AWS_CREDENTIAL_SCOPE";
    var ENV_ACCOUNT_ID = "AWS_ACCOUNT_ID";
    var fromEnv6 = /* @__PURE__ */ __name((init) => async () => {
      init?.logger?.debug("@aws-sdk/credential-provider-env - fromEnv");
      const accessKeyId = process.env[ENV_KEY];
      const secretAccessKey = process.env[ENV_SECRET];
      const sessionToken = process.env[ENV_SESSION];
      const expiry = process.env[ENV_EXPIRATION];
      const credentialScope = process.env[ENV_CREDENTIAL_SCOPE];
      const accountId = process.env[ENV_ACCOUNT_ID];
      if (accessKeyId && secretAccessKey) {
        const credentials = {
          accessKeyId,
          secretAccessKey,
          ...sessionToken && { sessionToken },
          ...expiry && { expiration: new Date(expiry) },
          ...credentialScope && { credentialScope },
          ...accountId && { accountId }
        };
        client.setCredentialFeature(credentials, "CREDENTIALS_ENV_VARS", "g");
        return credentials;
      }
      throw new propertyProvider.CredentialsProviderError("Unable to find environment variable credentials.", { logger: init?.logger });
    }, "fromEnv");
    exports2.ENV_ACCOUNT_ID = ENV_ACCOUNT_ID;
    exports2.ENV_CREDENTIAL_SCOPE = ENV_CREDENTIAL_SCOPE;
    exports2.ENV_EXPIRATION = ENV_EXPIRATION;
    exports2.ENV_KEY = ENV_KEY;
    exports2.ENV_SECRET = ENV_SECRET;
    exports2.ENV_SESSION = ENV_SESSION;
    exports2.fromEnv = fromEnv6;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/checkUrl.js
var require_checkUrl5 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/checkUrl.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.checkUrl = void 0;
    var property_provider_1 = require_dist_cjs27();
    var ECS_CONTAINER_HOST = "169.254.170.2";
    var EKS_CONTAINER_HOST_IPv4 = "169.254.170.23";
    var EKS_CONTAINER_HOST_IPv6 = "[fd00:ec2::23]";
    var checkUrl = /* @__PURE__ */ __name((url, logger5) => {
      if (url.protocol === "https:") {
        return;
      }
      if (url.hostname === ECS_CONTAINER_HOST || url.hostname === EKS_CONTAINER_HOST_IPv4 || url.hostname === EKS_CONTAINER_HOST_IPv6) {
        return;
      }
      if (url.hostname.includes("[")) {
        if (url.hostname === "[::1]" || url.hostname === "[0000:0000:0000:0000:0000:0000:0000:0001]") {
          return;
        }
      } else {
        if (url.hostname === "localhost") {
          return;
        }
        const ipComponents = url.hostname.split(".");
        const inRange = /* @__PURE__ */ __name((component) => {
          const num = parseInt(component, 10);
          return 0 <= num && num <= 255;
        }, "inRange");
        if (ipComponents[0] === "127" && inRange(ipComponents[1]) && inRange(ipComponents[2]) && inRange(ipComponents[3]) && ipComponents.length === 4) {
          return;
        }
      }
      throw new property_provider_1.CredentialsProviderError(`URL not accepted. It must either be HTTPS or match one of the following:
  - loopback CIDR 127.0.0.0/8 or [::1/128]
  - ECS container host 169.254.170.2
  - EKS container host 169.254.170.23 or [fd00:ec2::23]`, { logger: logger5 });
    }, "checkUrl");
    exports2.checkUrl = checkUrl;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.js
var require_ChecksumStream7 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ChecksumStream = void 0;
    var util_base64_1 = require_dist_cjs10();
    var stream_1 = require("stream");
    var ChecksumStream5 = class extends stream_1.Duplex {
      static {
        __name(this, "ChecksumStream");
      }
      expectedChecksum;
      checksumSourceLocation;
      checksum;
      source;
      base64Encoder;
      pendingCallback = null;
      constructor({ expectedChecksum, checksum, source, checksumSourceLocation, base64Encoder }) {
        super();
        if (typeof source.pipe === "function") {
          this.source = source;
        } else {
          throw new Error(`@smithy/util-stream: unsupported source type ${source?.constructor?.name ?? source} in ChecksumStream.`);
        }
        this.base64Encoder = base64Encoder ?? util_base64_1.toBase64;
        this.expectedChecksum = expectedChecksum;
        this.checksum = checksum;
        this.checksumSourceLocation = checksumSourceLocation;
        this.source.pipe(this);
      }
      _read(size) {
        if (this.pendingCallback) {
          const callback = this.pendingCallback;
          this.pendingCallback = null;
          callback();
        }
      }
      _write(chunk, encoding, callback) {
        try {
          this.checksum.update(chunk);
          const canPushMore = this.push(chunk);
          if (!canPushMore) {
            this.pendingCallback = callback;
            return;
          }
        } catch (e32) {
          return callback(e32);
        }
        return callback();
      }
      async _final(callback) {
        try {
          const digest = await this.checksum.digest();
          const received = this.base64Encoder(digest);
          if (this.expectedChecksum !== received) {
            return callback(new Error(`Checksum mismatch: expected "${this.expectedChecksum}" but received "${received}" in response header "${this.checksumSourceLocation}".`));
          }
        } catch (e32) {
          return callback(e32);
        }
        this.push(null);
        return callback();
      }
    };
    exports2.ChecksumStream = ChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/stream-type-check.js
var require_stream_type_check7 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/stream-type-check.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isBlob = exports2.isReadableStream = void 0;
    var isReadableStream6 = /* @__PURE__ */ __name((stream) => typeof ReadableStream === "function" && (stream?.constructor?.name === ReadableStream.name || stream instanceof ReadableStream), "isReadableStream");
    exports2.isReadableStream = isReadableStream6;
    var isBlob3 = /* @__PURE__ */ __name((blob) => {
      return typeof Blob === "function" && (blob?.constructor?.name === Blob.name || blob instanceof Blob);
    }, "isBlob");
    exports2.isBlob = isBlob3;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.browser.js
var require_ChecksumStream_browser7 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ChecksumStream = void 0;
    var ReadableStreamRef3 = typeof ReadableStream === "function" ? ReadableStream : function() {
    };
    var ChecksumStream5 = class extends ReadableStreamRef3 {
      static {
        __name(this, "ChecksumStream");
      }
    };
    exports2.ChecksumStream = ChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.browser.js
var require_createChecksumStream_browser7 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createChecksumStream = void 0;
    var util_base64_1 = require_dist_cjs10();
    var stream_type_check_1 = require_stream_type_check7();
    var ChecksumStream_browser_1 = require_ChecksumStream_browser7();
    var createChecksumStream5 = /* @__PURE__ */ __name(({ expectedChecksum, checksum, source, checksumSourceLocation, base64Encoder }) => {
      if (!(0, stream_type_check_1.isReadableStream)(source)) {
        throw new Error(`@smithy/util-stream: unsupported source type ${source?.constructor?.name ?? source} in ChecksumStream.`);
      }
      const encoder = base64Encoder ?? util_base64_1.toBase64;
      if (typeof TransformStream !== "function") {
        throw new Error("@smithy/util-stream: unable to instantiate ChecksumStream because API unavailable: ReadableStream/TransformStream.");
      }
      const transform = new TransformStream({
        start() {
        },
        async transform(chunk, controller) {
          checksum.update(chunk);
          controller.enqueue(chunk);
        },
        async flush(controller) {
          const digest = await checksum.digest();
          const received = encoder(digest);
          if (expectedChecksum !== received) {
            const error4 = new Error(`Checksum mismatch: expected "${expectedChecksum}" but received "${received}" in response header "${checksumSourceLocation}".`);
            controller.error(error4);
          } else {
            controller.terminate();
          }
        }
      });
      source.pipeThrough(transform);
      const readable = transform.readable;
      Object.setPrototypeOf(readable, ChecksumStream_browser_1.ChecksumStream.prototype);
      return readable;
    }, "createChecksumStream");
    exports2.createChecksumStream = createChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.js
var require_createChecksumStream7 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createChecksumStream = createChecksumStream5;
    var stream_type_check_1 = require_stream_type_check7();
    var ChecksumStream_1 = require_ChecksumStream7();
    var createChecksumStream_browser_1 = require_createChecksumStream_browser7();
    function createChecksumStream5(init) {
      if (typeof ReadableStream === "function" && (0, stream_type_check_1.isReadableStream)(init.source)) {
        return (0, createChecksumStream_browser_1.createChecksumStream)(init);
      }
      return new ChecksumStream_1.ChecksumStream(init);
    }
    __name(createChecksumStream5, "createChecksumStream");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/ByteArrayCollector.js
var require_ByteArrayCollector7 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/ByteArrayCollector.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ByteArrayCollector = void 0;
    var ByteArrayCollector3 = class {
      static {
        __name(this, "ByteArrayCollector");
      }
      allocByteArray;
      byteLength = 0;
      byteArrays = [];
      constructor(allocByteArray) {
        this.allocByteArray = allocByteArray;
      }
      push(byteArray) {
        this.byteArrays.push(byteArray);
        this.byteLength += byteArray.byteLength;
      }
      flush() {
        if (this.byteArrays.length === 1) {
          const bytes = this.byteArrays[0];
          this.reset();
          return bytes;
        }
        const aggregation = this.allocByteArray(this.byteLength);
        let cursor3 = 0;
        for (let i32 = 0; i32 < this.byteArrays.length; ++i32) {
          const bytes = this.byteArrays[i32];
          aggregation.set(bytes, cursor3);
          cursor3 += bytes.byteLength;
        }
        this.reset();
        return aggregation;
      }
      reset() {
        this.byteArrays = [];
        this.byteLength = 0;
      }
    };
    exports2.ByteArrayCollector = ByteArrayCollector3;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadableStream.js
var require_createBufferedReadableStream7 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadableStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createBufferedReadable = void 0;
    exports2.createBufferedReadableStream = createBufferedReadableStream3;
    exports2.merge = merge3;
    exports2.flush = flush3;
    exports2.sizeOf = sizeOf3;
    exports2.modeOf = modeOf3;
    var ByteArrayCollector_1 = require_ByteArrayCollector7();
    function createBufferedReadableStream3(upstream, size, logger5) {
      const reader = upstream.getReader();
      let streamBufferingLoggedWarning = false;
      let bytesSeen = 0;
      const buffers = ["", new ByteArrayCollector_1.ByteArrayCollector((size2) => new Uint8Array(size2))];
      let mode = -1;
      const pull = /* @__PURE__ */ __name(async (controller) => {
        const { value, done } = await reader.read();
        const chunk = value;
        if (done) {
          if (mode !== -1) {
            const remainder = flush3(buffers, mode);
            if (sizeOf3(remainder) > 0) {
              controller.enqueue(remainder);
            }
          }
          controller.close();
        } else {
          const chunkMode = modeOf3(chunk, false);
          if (mode !== chunkMode) {
            if (mode >= 0) {
              controller.enqueue(flush3(buffers, mode));
            }
            mode = chunkMode;
          }
          if (mode === -1) {
            controller.enqueue(chunk);
            return;
          }
          const chunkSize = sizeOf3(chunk);
          bytesSeen += chunkSize;
          const bufferSize = sizeOf3(buffers[mode]);
          if (chunkSize >= size && bufferSize === 0) {
            controller.enqueue(chunk);
          } else {
            const newSize = merge3(buffers, mode, chunk);
            if (!streamBufferingLoggedWarning && bytesSeen > size * 2) {
              streamBufferingLoggedWarning = true;
              logger5?.warn(`@smithy/util-stream - stream chunk size ${chunkSize} is below threshold of ${size}, automatically buffering.`);
            }
            if (newSize >= size) {
              controller.enqueue(flush3(buffers, mode));
            } else {
              await pull(controller);
            }
          }
        }
      }, "pull");
      return new ReadableStream({
        pull
      });
    }
    __name(createBufferedReadableStream3, "createBufferedReadableStream");
    exports2.createBufferedReadable = createBufferedReadableStream3;
    function merge3(buffers, mode, chunk) {
      switch (mode) {
        case 0:
          buffers[0] += chunk;
          return sizeOf3(buffers[0]);
        case 1:
        case 2:
          buffers[mode].push(chunk);
          return sizeOf3(buffers[mode]);
      }
    }
    __name(merge3, "merge");
    function flush3(buffers, mode) {
      switch (mode) {
        case 0:
          const s = buffers[0];
          buffers[0] = "";
          return s;
        case 1:
        case 2:
          return buffers[mode].flush();
      }
      throw new Error(`@smithy/util-stream - invalid index ${mode} given to flush()`);
    }
    __name(flush3, "flush");
    function sizeOf3(chunk) {
      return chunk?.byteLength ?? chunk?.length ?? 0;
    }
    __name(sizeOf3, "sizeOf");
    function modeOf3(chunk, allowBuffer = true) {
      if (allowBuffer && typeof Buffer !== "undefined" && chunk instanceof Buffer) {
        return 2;
      }
      if (chunk instanceof Uint8Array) {
        return 1;
      }
      if (typeof chunk === "string") {
        return 0;
      }
      return -1;
    }
    __name(modeOf3, "modeOf");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadable.js
var require_createBufferedReadable7 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadable.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createBufferedReadable = createBufferedReadable3;
    var node_stream_1 = require("node:stream");
    var ByteArrayCollector_1 = require_ByteArrayCollector7();
    var createBufferedReadableStream_1 = require_createBufferedReadableStream7();
    var stream_type_check_1 = require_stream_type_check7();
    function createBufferedReadable3(upstream, size, logger5) {
      if ((0, stream_type_check_1.isReadableStream)(upstream)) {
        return (0, createBufferedReadableStream_1.createBufferedReadableStream)(upstream, size, logger5);
      }
      const downstream = new node_stream_1.Readable({ read() {
      } });
      let streamBufferingLoggedWarning = false;
      let bytesSeen = 0;
      const buffers = [
        "",
        new ByteArrayCollector_1.ByteArrayCollector((size2) => new Uint8Array(size2)),
        new ByteArrayCollector_1.ByteArrayCollector((size2) => Buffer.from(new Uint8Array(size2)))
      ];
      let mode = -1;
      upstream.on("data", (chunk) => {
        const chunkMode = (0, createBufferedReadableStream_1.modeOf)(chunk, true);
        if (mode !== chunkMode) {
          if (mode >= 0) {
            downstream.push((0, createBufferedReadableStream_1.flush)(buffers, mode));
          }
          mode = chunkMode;
        }
        if (mode === -1) {
          downstream.push(chunk);
          return;
        }
        const chunkSize = (0, createBufferedReadableStream_1.sizeOf)(chunk);
        bytesSeen += chunkSize;
        const bufferSize = (0, createBufferedReadableStream_1.sizeOf)(buffers[mode]);
        if (chunkSize >= size && bufferSize === 0) {
          downstream.push(chunk);
        } else {
          const newSize = (0, createBufferedReadableStream_1.merge)(buffers, mode, chunk);
          if (!streamBufferingLoggedWarning && bytesSeen > size * 2) {
            streamBufferingLoggedWarning = true;
            logger5?.warn(`@smithy/util-stream - stream chunk size ${chunkSize} is below threshold of ${size}, automatically buffering.`);
          }
          if (newSize >= size) {
            downstream.push((0, createBufferedReadableStream_1.flush)(buffers, mode));
          }
        }
      });
      upstream.on("end", () => {
        if (mode !== -1) {
          const remainder = (0, createBufferedReadableStream_1.flush)(buffers, mode);
          if ((0, createBufferedReadableStream_1.sizeOf)(remainder) > 0) {
            downstream.push(remainder);
          }
        }
        downstream.push(null);
      });
      return downstream;
    }
    __name(createBufferedReadable3, "createBufferedReadable");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.browser.js
var require_getAwsChunkedEncodingStream_browser7 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getAwsChunkedEncodingStream = void 0;
    var getAwsChunkedEncodingStream5 = /* @__PURE__ */ __name((readableStream, options) => {
      const { base64Encoder, bodyLengthChecker, checksumAlgorithmFn, checksumLocationName, streamHasher } = options;
      const checksumRequired = base64Encoder !== void 0 && bodyLengthChecker !== void 0 && checksumAlgorithmFn !== void 0 && checksumLocationName !== void 0 && streamHasher !== void 0;
      const digest = checksumRequired ? streamHasher(checksumAlgorithmFn, readableStream) : void 0;
      const reader = readableStream.getReader();
      return new ReadableStream({
        async pull(controller) {
          const { value, done } = await reader.read();
          if (done) {
            controller.enqueue(`0\r
`);
            if (checksumRequired) {
              const checksum = base64Encoder(await digest);
              controller.enqueue(`${checksumLocationName}:${checksum}\r
`);
              controller.enqueue(`\r
`);
            }
            controller.close();
          } else {
            controller.enqueue(`${(bodyLengthChecker(value) || 0).toString(16)}\r
${value}\r
`);
          }
        }
      });
    }, "getAwsChunkedEncodingStream");
    exports2.getAwsChunkedEncodingStream = getAwsChunkedEncodingStream5;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.js
var require_getAwsChunkedEncodingStream7 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getAwsChunkedEncodingStream = getAwsChunkedEncodingStream5;
    var node_stream_1 = require("node:stream");
    var getAwsChunkedEncodingStream_browser_1 = require_getAwsChunkedEncodingStream_browser7();
    var stream_type_check_1 = require_stream_type_check7();
    function getAwsChunkedEncodingStream5(stream, options) {
      const readable = stream;
      const readableStream = stream;
      if ((0, stream_type_check_1.isReadableStream)(readableStream)) {
        return (0, getAwsChunkedEncodingStream_browser_1.getAwsChunkedEncodingStream)(readableStream, options);
      }
      const { base64Encoder, bodyLengthChecker, checksumAlgorithmFn, checksumLocationName, streamHasher } = options;
      const checksumRequired = base64Encoder !== void 0 && checksumAlgorithmFn !== void 0 && checksumLocationName !== void 0 && streamHasher !== void 0;
      const digest = checksumRequired ? streamHasher(checksumAlgorithmFn, readable) : void 0;
      const awsChunkedEncodingStream = new node_stream_1.Readable({
        read: /* @__PURE__ */ __name(() => {
        }, "read")
      });
      readable.on("data", (data3) => {
        const length = bodyLengthChecker(data3) || 0;
        if (length === 0) {
          return;
        }
        awsChunkedEncodingStream.push(`${length.toString(16)}\r
`);
        awsChunkedEncodingStream.push(data3);
        awsChunkedEncodingStream.push("\r\n");
      });
      readable.on("end", async () => {
        awsChunkedEncodingStream.push(`0\r
`);
        if (checksumRequired) {
          const checksum = base64Encoder(await digest);
          awsChunkedEncodingStream.push(`${checksumLocationName}:${checksum}\r
`);
          awsChunkedEncodingStream.push(`\r
`);
        }
        awsChunkedEncodingStream.push(null);
      });
      return awsChunkedEncodingStream;
    }
    __name(getAwsChunkedEncodingStream5, "getAwsChunkedEncodingStream");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/headStream.browser.js
var require_headStream_browser7 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/headStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.headStream = headStream5;
    async function headStream5(stream, bytes) {
      let byteLengthCounter = 0;
      const chunks2 = [];
      const reader = stream.getReader();
      let isDone = false;
      while (!isDone) {
        const { done, value } = await reader.read();
        if (value) {
          chunks2.push(value);
          byteLengthCounter += value?.byteLength ?? 0;
        }
        if (byteLengthCounter >= bytes) {
          break;
        }
        isDone = done;
      }
      reader.releaseLock();
      const collected = new Uint8Array(Math.min(bytes, byteLengthCounter));
      let offset = 0;
      for (const chunk of chunks2) {
        if (chunk.byteLength > collected.byteLength - offset) {
          collected.set(chunk.subarray(0, collected.byteLength - offset), offset);
          break;
        } else {
          collected.set(chunk, offset);
        }
        offset += chunk.length;
      }
      return collected;
    }
    __name(headStream5, "headStream");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/headStream.js
var require_headStream7 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/headStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.headStream = void 0;
    var stream_1 = require("stream");
    var headStream_browser_1 = require_headStream_browser7();
    var stream_type_check_1 = require_stream_type_check7();
    var headStream5 = /* @__PURE__ */ __name((stream, bytes) => {
      if ((0, stream_type_check_1.isReadableStream)(stream)) {
        return (0, headStream_browser_1.headStream)(stream, bytes);
      }
      return new Promise((resolve13, reject) => {
        const collector = new Collector8();
        collector.limit = bytes;
        stream.pipe(collector);
        stream.on("error", (err) => {
          collector.end();
          reject(err);
        });
        collector.on("error", reject);
        collector.on("finish", function() {
          const bytes2 = new Uint8Array(Buffer.concat(this.buffers));
          resolve13(bytes2);
        });
      });
    }, "headStream");
    exports2.headStream = headStream5;
    var Collector8 = class extends stream_1.Writable {
      static {
        __name(this, "Collector");
      }
      buffers = [];
      limit = Infinity;
      bytesBuffered = 0;
      _write(chunk, encoding, callback) {
        this.buffers.push(chunk);
        this.bytesBuffered += chunk.byteLength ?? 0;
        if (this.bytesBuffered >= this.limit) {
          const excess = this.bytesBuffered - this.limit;
          const tailBuffer = this.buffers[this.buffers.length - 1];
          this.buffers[this.buffers.length - 1] = tailBuffer.subarray(0, tailBuffer.byteLength - excess);
          this.emit("finish");
        }
        callback();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.browser.js
var require_sdk_stream_mixin_browser7 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.sdkStreamMixin = void 0;
    var fetch_http_handler_1 = require_dist_cjs14();
    var util_base64_1 = require_dist_cjs10();
    var util_hex_encoding_1 = require_dist_cjs15();
    var util_utf8_1 = require_dist_cjs9();
    var stream_type_check_1 = require_stream_type_check7();
    var ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11 = "The stream has already been transformed.";
    var sdkStreamMixin12 = /* @__PURE__ */ __name((stream) => {
      if (!isBlobInstance6(stream) && !(0, stream_type_check_1.isReadableStream)(stream)) {
        const name = stream?.__proto__?.constructor?.name || stream;
        throw new Error(`Unexpected stream implementation, expect Blob or ReadableStream, got ${name}`);
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
        }
        transformed = true;
        return await (0, fetch_http_handler_1.streamCollector)(stream);
      }, "transformToByteArray");
      const blobToWebStream = /* @__PURE__ */ __name((blob) => {
        if (typeof blob.stream !== "function") {
          throw new Error("Cannot transform payload Blob to web stream. Please make sure the Blob.stream() is polyfilled.\nIf you are using React Native, this API is not yet supported, see: https://react-native.canny.io/feature-requests/p/fetch-streaming-body");
        }
        return blob.stream();
      }, "blobToWebStream");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === "base64") {
            return (0, util_base64_1.toBase64)(buf);
          } else if (encoding === "hex") {
            return (0, util_hex_encoding_1.toHex)(buf);
          } else if (encoding === void 0 || encoding === "utf8" || encoding === "utf-8") {
            return (0, util_utf8_1.toUtf8)(buf);
          } else if (typeof TextDecoder === "function") {
            return new TextDecoder(encoding).decode(buf);
          } else {
            throw new Error("TextDecoder is not available, please make sure polyfill is provided.");
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
          }
          transformed = true;
          if (isBlobInstance6(stream)) {
            return blobToWebStream(stream);
          } else if ((0, stream_type_check_1.isReadableStream)(stream)) {
            return stream;
          } else {
            throw new Error(`Cannot transform payload to web stream, got ${stream}`);
          }
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
    exports2.sdkStreamMixin = sdkStreamMixin12;
    var isBlobInstance6 = /* @__PURE__ */ __name((stream) => typeof Blob === "function" && stream instanceof Blob, "isBlobInstance");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.js
var require_sdk_stream_mixin7 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.sdkStreamMixin = void 0;
    var node_http_handler_1 = require_dist_cjs13();
    var util_buffer_from_1 = require_dist_cjs8();
    var stream_1 = require("stream");
    var sdk_stream_mixin_browser_1 = require_sdk_stream_mixin_browser7();
    var ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11 = "The stream has already been transformed.";
    var sdkStreamMixin12 = /* @__PURE__ */ __name((stream) => {
      if (!(stream instanceof stream_1.Readable)) {
        try {
          return (0, sdk_stream_mixin_browser_1.sdkStreamMixin)(stream);
        } catch (e32) {
          const name = stream?.__proto__?.constructor?.name || stream;
          throw new Error(`Unexpected stream implementation, expect Stream.Readable instance, got ${name}`);
        }
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
        }
        transformed = true;
        return await (0, node_http_handler_1.streamCollector)(stream);
      }, "transformToByteArray");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === void 0 || Buffer.isEncoding(encoding)) {
            return (0, util_buffer_from_1.fromArrayBuffer)(buf.buffer, buf.byteOffset, buf.byteLength).toString(encoding);
          } else {
            const decoder = new TextDecoder(encoding);
            return decoder.decode(buf);
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
          }
          if (stream.readableFlowing !== null) {
            throw new Error("The stream has been consumed by other callbacks.");
          }
          if (typeof stream_1.Readable.toWeb !== "function") {
            throw new Error("Readable.toWeb() is not supported. Please ensure a polyfill is available.");
          }
          transformed = true;
          return stream_1.Readable.toWeb(stream);
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
    exports2.sdkStreamMixin = sdkStreamMixin12;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/splitStream.browser.js
var require_splitStream_browser7 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/splitStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.splitStream = splitStream5;
    async function splitStream5(stream) {
      if (typeof stream.stream === "function") {
        stream = stream.stream();
      }
      const readableStream = stream;
      return readableStream.tee();
    }
    __name(splitStream5, "splitStream");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/splitStream.js
var require_splitStream7 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/splitStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.splitStream = splitStream5;
    var stream_1 = require("stream");
    var splitStream_browser_1 = require_splitStream_browser7();
    var stream_type_check_1 = require_stream_type_check7();
    async function splitStream5(stream) {
      if ((0, stream_type_check_1.isReadableStream)(stream) || (0, stream_type_check_1.isBlob)(stream)) {
        return (0, splitStream_browser_1.splitStream)(stream);
      }
      const stream1 = new stream_1.PassThrough();
      const stream2 = new stream_1.PassThrough();
      stream.pipe(stream1);
      stream.pipe(stream2);
      return [stream1, stream2];
    }
    __name(splitStream5, "splitStream");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/index.js
var require_dist_cjs130 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-stream/dist-cjs/index.js"(exports2) {
    "use strict";
    var utilBase64 = require_dist_cjs10();
    var utilUtf8 = require_dist_cjs9();
    var ChecksumStream5 = require_ChecksumStream7();
    var createChecksumStream5 = require_createChecksumStream7();
    var createBufferedReadable3 = require_createBufferedReadable7();
    var getAwsChunkedEncodingStream5 = require_getAwsChunkedEncodingStream7();
    var headStream5 = require_headStream7();
    var sdkStreamMixin12 = require_sdk_stream_mixin7();
    var splitStream5 = require_splitStream7();
    var streamTypeCheck = require_stream_type_check7();
    var Uint8ArrayBlobAdapter8 = class _Uint8ArrayBlobAdapter extends Uint8Array {
      static {
        __name(this, "Uint8ArrayBlobAdapter");
      }
      static fromString(source, encoding = "utf-8") {
        if (typeof source === "string") {
          if (encoding === "base64") {
            return _Uint8ArrayBlobAdapter.mutate(utilBase64.fromBase64(source));
          }
          return _Uint8ArrayBlobAdapter.mutate(utilUtf8.fromUtf8(source));
        }
        throw new Error(`Unsupported conversion from ${typeof source} to Uint8ArrayBlobAdapter.`);
      }
      static mutate(source) {
        Object.setPrototypeOf(source, _Uint8ArrayBlobAdapter.prototype);
        return source;
      }
      transformToString(encoding = "utf-8") {
        if (encoding === "base64") {
          return utilBase64.toBase64(this);
        }
        return utilUtf8.toUtf8(this);
      }
    };
    exports2.isBlob = streamTypeCheck.isBlob;
    exports2.isReadableStream = streamTypeCheck.isReadableStream;
    exports2.Uint8ArrayBlobAdapter = Uint8ArrayBlobAdapter8;
    Object.prototype.hasOwnProperty.call(ChecksumStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: ChecksumStream5["__proto__"]
    });
    Object.keys(ChecksumStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = ChecksumStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(createChecksumStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: createChecksumStream5["__proto__"]
    });
    Object.keys(createChecksumStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = createChecksumStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(createBufferedReadable3, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: createBufferedReadable3["__proto__"]
    });
    Object.keys(createBufferedReadable3).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = createBufferedReadable3[k32];
    });
    Object.prototype.hasOwnProperty.call(getAwsChunkedEncodingStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: getAwsChunkedEncodingStream5["__proto__"]
    });
    Object.keys(getAwsChunkedEncodingStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = getAwsChunkedEncodingStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(headStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: headStream5["__proto__"]
    });
    Object.keys(headStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = headStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(sdkStreamMixin12, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: sdkStreamMixin12["__proto__"]
    });
    Object.keys(sdkStreamMixin12).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = sdkStreamMixin12[k32];
    });
    Object.prototype.hasOwnProperty.call(splitStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: splitStream5["__proto__"]
    });
    Object.keys(splitStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = splitStream5[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/requestHelpers.js
var require_requestHelpers5 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/requestHelpers.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createGetRequest = createGetRequest;
    exports2.getCredentials = getCredentials;
    var property_provider_1 = require_dist_cjs27();
    var protocol_http_1 = require_dist_cjs2();
    var smithy_client_1 = require_dist_cjs34();
    var util_stream_1 = require_dist_cjs130();
    function createGetRequest(url) {
      return new protocol_http_1.HttpRequest({
        protocol: url.protocol,
        hostname: url.hostname,
        port: Number(url.port),
        path: url.pathname,
        query: Array.from(url.searchParams.entries()).reduce((acc, [k32, v]) => {
          acc[k32] = v;
          return acc;
        }, {}),
        fragment: url.hash
      });
    }
    __name(createGetRequest, "createGetRequest");
    async function getCredentials(response, logger5) {
      const stream = (0, util_stream_1.sdkStreamMixin)(response.body);
      const str = await stream.transformToString();
      if (response.statusCode === 200) {
        const parsed = JSON.parse(str);
        if (typeof parsed.AccessKeyId !== "string" || typeof parsed.SecretAccessKey !== "string" || typeof parsed.Token !== "string" || typeof parsed.Expiration !== "string") {
          throw new property_provider_1.CredentialsProviderError("HTTP credential provider response not of the required format, an object matching: { AccessKeyId: string, SecretAccessKey: string, Token: string, Expiration: string(rfc3339) }", { logger: logger5 });
        }
        return {
          accessKeyId: parsed.AccessKeyId,
          secretAccessKey: parsed.SecretAccessKey,
          sessionToken: parsed.Token,
          expiration: (0, smithy_client_1.parseRfc3339DateTime)(parsed.Expiration)
        };
      }
      if (response.statusCode >= 400 && response.statusCode < 500) {
        let parsedBody = {};
        try {
          parsedBody = JSON.parse(str);
        } catch (e32) {
        }
        throw Object.assign(new property_provider_1.CredentialsProviderError(`Server responded with status: ${response.statusCode}`, { logger: logger5 }), {
          Code: parsedBody.Code,
          Message: parsedBody.Message
        });
      }
      throw new property_provider_1.CredentialsProviderError(`Server responded with status: ${response.statusCode}`, { logger: logger5 });
    }
    __name(getCredentials, "getCredentials");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/retry-wrapper.js
var require_retry_wrapper5 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/retry-wrapper.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.retryWrapper = void 0;
    var retryWrapper = /* @__PURE__ */ __name((toRetry, maxRetries, delayMs) => {
      return async () => {
        for (let i32 = 0; i32 < maxRetries; ++i32) {
          try {
            return await toRetry();
          } catch (e32) {
            await new Promise((resolve13) => setTimeout(resolve13, delayMs));
          }
        }
        return await toRetry();
      };
    }, "retryWrapper");
    exports2.retryWrapper = retryWrapper;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/fromHttp.js
var require_fromHttp5 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/fromHttp.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromHttp = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var client_1 = (init_client10(), __toCommonJS(client_exports8));
    var node_http_handler_1 = require_dist_cjs13();
    var property_provider_1 = require_dist_cjs27();
    var promises_1 = tslib_1.__importDefault(require("node:fs/promises"));
    var checkUrl_1 = require_checkUrl5();
    var requestHelpers_1 = require_requestHelpers5();
    var retry_wrapper_1 = require_retry_wrapper5();
    var AWS_CONTAINER_CREDENTIALS_RELATIVE_URI = "AWS_CONTAINER_CREDENTIALS_RELATIVE_URI";
    var DEFAULT_LINK_LOCAL_HOST = "http://169.254.170.2";
    var AWS_CONTAINER_CREDENTIALS_FULL_URI = "AWS_CONTAINER_CREDENTIALS_FULL_URI";
    var AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE = "AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE";
    var AWS_CONTAINER_AUTHORIZATION_TOKEN = "AWS_CONTAINER_AUTHORIZATION_TOKEN";
    var fromHttp = /* @__PURE__ */ __name((options = {}) => {
      options.logger?.debug("@aws-sdk/credential-provider-http - fromHttp");
      let host;
      const relative5 = options.awsContainerCredentialsRelativeUri ?? process.env[AWS_CONTAINER_CREDENTIALS_RELATIVE_URI];
      const full = options.awsContainerCredentialsFullUri ?? process.env[AWS_CONTAINER_CREDENTIALS_FULL_URI];
      const token = options.awsContainerAuthorizationToken ?? process.env[AWS_CONTAINER_AUTHORIZATION_TOKEN];
      const tokenFile = options.awsContainerAuthorizationTokenFile ?? process.env[AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE];
      const warn2 = options.logger?.constructor?.name === "NoOpLogger" || !options.logger?.warn ? console.warn : options.logger.warn.bind(options.logger);
      if (relative5 && full) {
        warn2("@aws-sdk/credential-provider-http: you have set both awsContainerCredentialsRelativeUri and awsContainerCredentialsFullUri.");
        warn2("awsContainerCredentialsFullUri will take precedence.");
      }
      if (token && tokenFile) {
        warn2("@aws-sdk/credential-provider-http: you have set both awsContainerAuthorizationToken and awsContainerAuthorizationTokenFile.");
        warn2("awsContainerAuthorizationToken will take precedence.");
      }
      if (full) {
        host = full;
      } else if (relative5) {
        host = `${DEFAULT_LINK_LOCAL_HOST}${relative5}`;
      } else {
        throw new property_provider_1.CredentialsProviderError(`No HTTP credential provider host provided.
Set AWS_CONTAINER_CREDENTIALS_FULL_URI or AWS_CONTAINER_CREDENTIALS_RELATIVE_URI.`, { logger: options.logger });
      }
      const url = new URL(host);
      (0, checkUrl_1.checkUrl)(url, options.logger);
      const requestHandler = node_http_handler_1.NodeHttpHandler.create({
        requestTimeout: options.timeout ?? 1e3,
        connectionTimeout: options.timeout ?? 1e3
      });
      return (0, retry_wrapper_1.retryWrapper)(async () => {
        const request4 = (0, requestHelpers_1.createGetRequest)(url);
        if (token) {
          request4.headers.Authorization = token;
        } else if (tokenFile) {
          request4.headers.Authorization = (await promises_1.default.readFile(tokenFile)).toString();
        }
        try {
          const result2 = await requestHandler.handle(request4);
          return (0, requestHelpers_1.getCredentials)(result2.response).then((creds) => (0, client_1.setCredentialFeature)(creds, "CREDENTIALS_HTTP", "z"));
        } catch (e32) {
          throw new property_provider_1.CredentialsProviderError(String(e32), { logger: options.logger });
        }
      }, options.maxRetries ?? 3, options.timeout ?? 1e3);
    }, "fromHttp");
    exports2.fromHttp = fromHttp;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-http/dist-cjs/index.js
var require_dist_cjs131 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-http/dist-cjs/index.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromHttp = void 0;
    var fromHttp_1 = require_fromHttp5();
    Object.defineProperty(exports2, "fromHttp", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return fromHttp_1.fromHttp;
    }, "get") });
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption16(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "awsssoportal",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption16(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var import_util_middleware21, defaultSSOHttpAuthSchemeParametersProvider5, defaultSSOHttpAuthSchemeProvider5, resolveHttpAuthSchemeConfig16;
var init_httpAuthSchemeProvider16 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes7();
    import_util_middleware21 = __toESM(require_dist_cjs6());
    defaultSSOHttpAuthSchemeParametersProvider5 = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, import_util_middleware21.getSmithyContext)(context).operation,
        region: await (0, import_util_middleware21.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultSSOHttpAuthSchemeParametersProvider");
    __name(createAwsAuthSigv4HttpAuthOption16, "createAwsAuthSigv4HttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption16, "createSmithyApiNoAuthHttpAuthOption");
    defaultSSOHttpAuthSchemeProvider5 = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "GetRoleCredentials": {
          options.push(createSmithyApiNoAuthHttpAuthOption16(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption16(authParameters));
        }
      }
      return options;
    }, "defaultSSOHttpAuthSchemeProvider");
    resolveHttpAuthSchemeConfig16 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveAwsSdkSigV4Config6(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, import_util_middleware21.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/EndpointParameters.js
var resolveClientEndpointParameters16, commonParams16;
var init_EndpointParameters16 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters16 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "awsssoportal"
      });
    }, "resolveClientEndpointParameters");
    commonParams16 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/package.json
var package_default6;
var init_package6 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/package.json"() {
    package_default6 = {
      name: "@aws-sdk/nested-clients",
      version: "3.997.6",
      description: "Nested clients for AWS SDK packages.",
      main: "./dist-cjs/index.js",
      module: "./dist-es/index.js",
      types: "./dist-types/index.d.ts",
      scripts: {
        build: "yarn lint && concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline nested-clients",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        lint: "node ../../scripts/validation/submodules-linter.js --pkg nested-clients",
        test: "yarn g:vitest run",
        "test:watch": "yarn g:vitest watch"
      },
      engines: {
        node: ">=20.0.0"
      },
      sideEffects: false,
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      dependencies: {
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.8",
        "@aws-sdk/middleware-host-header": "^3.972.10",
        "@aws-sdk/middleware-logger": "^3.972.10",
        "@aws-sdk/middleware-recursion-detection": "^3.972.11",
        "@aws-sdk/middleware-user-agent": "^3.972.38",
        "@aws-sdk/region-config-resolver": "^3.972.13",
        "@aws-sdk/signature-v4-multi-region": "^3.996.25",
        "@aws-sdk/types": "^3.973.8",
        "@aws-sdk/util-endpoints": "^3.996.8",
        "@aws-sdk/util-user-agent-browser": "^3.972.10",
        "@aws-sdk/util-user-agent-node": "^3.973.24",
        "@smithy/config-resolver": "^4.4.17",
        "@smithy/core": "^3.23.17",
        "@smithy/fetch-http-handler": "^5.3.17",
        "@smithy/hash-node": "^4.2.14",
        "@smithy/invalid-dependency": "^4.2.14",
        "@smithy/middleware-content-length": "^4.2.14",
        "@smithy/middleware-endpoint": "^4.4.32",
        "@smithy/middleware-retry": "^4.5.7",
        "@smithy/middleware-serde": "^4.2.20",
        "@smithy/middleware-stack": "^4.2.14",
        "@smithy/node-config-provider": "^4.3.14",
        "@smithy/node-http-handler": "^4.6.1",
        "@smithy/protocol-http": "^5.3.14",
        "@smithy/smithy-client": "^4.12.13",
        "@smithy/types": "^4.14.1",
        "@smithy/url-parser": "^4.2.14",
        "@smithy/util-base64": "^4.3.2",
        "@smithy/util-body-length-browser": "^4.2.2",
        "@smithy/util-body-length-node": "^4.2.3",
        "@smithy/util-defaults-mode-browser": "^4.3.49",
        "@smithy/util-defaults-mode-node": "^4.2.54",
        "@smithy/util-endpoints": "^3.4.2",
        "@smithy/util-middleware": "^4.2.14",
        "@smithy/util-retry": "^4.3.6",
        "@smithy/util-utf8": "^4.2.2",
        tslib: "^2.6.2"
      },
      devDependencies: {
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "./cognito-identity.d.ts",
        "./cognito-identity.js",
        "./signin.d.ts",
        "./signin.js",
        "./sso-oidc.d.ts",
        "./sso-oidc.js",
        "./sso.d.ts",
        "./sso.js",
        "./sts.d.ts",
        "./sts.js",
        "dist-*/**"
      ],
      browser: {
        "./dist-es/submodules/cognito-identity/runtimeConfig": "./dist-es/submodules/cognito-identity/runtimeConfig.browser",
        "./dist-es/submodules/signin/runtimeConfig": "./dist-es/submodules/signin/runtimeConfig.browser",
        "./dist-es/submodules/sso-oidc/runtimeConfig": "./dist-es/submodules/sso-oidc/runtimeConfig.browser",
        "./dist-es/submodules/sso/runtimeConfig": "./dist-es/submodules/sso/runtimeConfig.browser",
        "./dist-es/submodules/sts/runtimeConfig": "./dist-es/submodules/sts/runtimeConfig.browser"
      },
      "react-native": {},
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/packages/nested-clients",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "packages/nested-clients"
      },
      exports: {
        "./package.json": "./package.json",
        "./sso-oidc": {
          types: "./dist-types/submodules/sso-oidc/index.d.ts",
          module: "./dist-es/submodules/sso-oidc/index.js",
          node: "./dist-cjs/submodules/sso-oidc/index.js",
          import: "./dist-es/submodules/sso-oidc/index.js",
          require: "./dist-cjs/submodules/sso-oidc/index.js"
        },
        "./sts": {
          types: "./dist-types/submodules/sts/index.d.ts",
          module: "./dist-es/submodules/sts/index.js",
          node: "./dist-cjs/submodules/sts/index.js",
          import: "./dist-es/submodules/sts/index.js",
          require: "./dist-cjs/submodules/sts/index.js"
        },
        "./signin": {
          types: "./dist-types/submodules/signin/index.d.ts",
          module: "./dist-es/submodules/signin/index.js",
          node: "./dist-cjs/submodules/signin/index.js",
          import: "./dist-es/submodules/signin/index.js",
          require: "./dist-cjs/submodules/signin/index.js"
        },
        "./cognito-identity": {
          types: "./dist-types/submodules/cognito-identity/index.d.ts",
          module: "./dist-es/submodules/cognito-identity/index.js",
          node: "./dist-cjs/submodules/cognito-identity/index.js",
          import: "./dist-es/submodules/cognito-identity/index.js",
          require: "./dist-cjs/submodules/cognito-identity/index.js"
        },
        "./sso": {
          types: "./dist-types/submodules/sso/index.d.ts",
          module: "./dist-es/submodules/sso/index.js",
          node: "./dist-cjs/submodules/sso/index.js",
          import: "./dist-es/submodules/sso/index.js",
          require: "./dist-cjs/submodules/sso/index.js"
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/util-user-agent-node/dist-cjs/index.js
var require_dist_cjs132 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/util-user-agent-node/dist-cjs/index.js"(exports2) {
    "use strict";
    var node_os = require("node:os");
    var node_process = require("node:process");
    var utilConfigProvider = require_dist_cjs24();
    var promises5 = require("node:fs/promises");
    var node_path = require("node:path");
    var middlewareUserAgent = require_dist_cjs127();
    var getRuntimeUserAgentPair2 = /* @__PURE__ */ __name(() => {
      const runtimesToCheck = ["deno", "bun", "llrt"];
      for (const runtime of runtimesToCheck) {
        if (node_process.versions[runtime]) {
          return [`md/${runtime}`, node_process.versions[runtime]];
        }
      }
      return ["md/nodejs", node_process.versions.node];
    }, "getRuntimeUserAgentPair");
    var getNodeModulesParentDirs2 = /* @__PURE__ */ __name((dirname14) => {
      const cwd = process.cwd();
      if (!dirname14) {
        return [cwd];
      }
      const normalizedPath = node_path.normalize(dirname14);
      const parts = normalizedPath.split(node_path.sep);
      const nodeModulesIndex = parts.indexOf("node_modules");
      const parentDir = nodeModulesIndex !== -1 ? parts.slice(0, nodeModulesIndex).join(node_path.sep) : normalizedPath;
      if (cwd === parentDir) {
        return [cwd];
      }
      return [parentDir, cwd];
    }, "getNodeModulesParentDirs");
    var SEMVER_REGEX2 = /^(0|[1-9]\d*)\.(0|[1-9]\d*)\.(0|[1-9]\d*)(?:-((?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*)(?:\.(?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*))*))?(?:\+[0-9a-zA-Z-]+(?:\.[0-9a-zA-Z-]+)*)?$/;
    var getSanitizedTypeScriptVersion2 = /* @__PURE__ */ __name((version = "") => {
      const match = version.match(SEMVER_REGEX2);
      if (!match) {
        return void 0;
      }
      const [major6, minor, patch, prerelease] = [match[1], match[2], match[3], match[4]];
      return prerelease ? `${major6}.${minor}.${patch}-${prerelease}` : `${major6}.${minor}.${patch}`;
    }, "getSanitizedTypeScriptVersion");
    var ALLOWED_PREFIXES2 = ["^", "~", ">=", "<=", ">", "<"];
    var ALLOWED_DIST_TAGS2 = ["latest", "beta", "dev", "rc", "insiders", "next"];
    var getSanitizedDevTypeScriptVersion2 = /* @__PURE__ */ __name((version = "") => {
      if (ALLOWED_DIST_TAGS2.includes(version)) {
        return version;
      }
      const prefix = ALLOWED_PREFIXES2.find((p10) => version.startsWith(p10)) ?? "";
      const sanitizedTypeScriptVersion = getSanitizedTypeScriptVersion2(version.slice(prefix.length));
      if (!sanitizedTypeScriptVersion) {
        return void 0;
      }
      return `${prefix}${sanitizedTypeScriptVersion}`;
    }, "getSanitizedDevTypeScriptVersion");
    var tscVersion2;
    var TS_PACKAGE_JSON2 = node_path.join("node_modules", "typescript", "package.json");
    var getTypeScriptUserAgentPair2 = /* @__PURE__ */ __name(async () => {
      if (tscVersion2 === null) {
        return void 0;
      } else if (typeof tscVersion2 === "string") {
        return ["md/tsc", tscVersion2];
      }
      let isTypeScriptDetectionDisabled = false;
      try {
        isTypeScriptDetectionDisabled = utilConfigProvider.booleanSelector(process.env, "AWS_SDK_JS_TYPESCRIPT_DETECTION_DISABLED", utilConfigProvider.SelectorType.ENV) || false;
      } catch {
      }
      if (isTypeScriptDetectionDisabled) {
        tscVersion2 = null;
        return void 0;
      }
      const dirname14 = typeof __dirname !== "undefined" ? __dirname : void 0;
      const nodeModulesParentDirs = getNodeModulesParentDirs2(dirname14);
      let versionFromApp;
      for (const nodeModulesParentDir of nodeModulesParentDirs) {
        try {
          const appPackageJsonPath = node_path.join(nodeModulesParentDir, "package.json");
          const packageJson = await promises5.readFile(appPackageJsonPath, "utf-8");
          const { dependencies, devDependencies } = JSON.parse(packageJson);
          const version = devDependencies?.typescript ?? dependencies?.typescript;
          if (typeof version !== "string") {
            continue;
          }
          versionFromApp = version;
          break;
        } catch {
        }
      }
      if (!versionFromApp) {
        tscVersion2 = null;
        return void 0;
      }
      let versionFromNodeModules;
      for (const nodeModulesParentDir of nodeModulesParentDirs) {
        try {
          const tsPackageJsonPath = node_path.join(nodeModulesParentDir, TS_PACKAGE_JSON2);
          const packageJson = await promises5.readFile(tsPackageJsonPath, "utf-8");
          const { version } = JSON.parse(packageJson);
          const sanitizedVersion2 = getSanitizedTypeScriptVersion2(version);
          if (typeof sanitizedVersion2 !== "string") {
            continue;
          }
          versionFromNodeModules = sanitizedVersion2;
          break;
        } catch {
        }
      }
      if (versionFromNodeModules) {
        tscVersion2 = versionFromNodeModules;
        return ["md/tsc", tscVersion2];
      }
      const sanitizedVersion = getSanitizedDevTypeScriptVersion2(versionFromApp);
      if (typeof sanitizedVersion !== "string") {
        tscVersion2 = null;
        return void 0;
      }
      tscVersion2 = `dev_${sanitizedVersion}`;
      return ["md/tsc", tscVersion2];
    }, "getTypeScriptUserAgentPair");
    var crtAvailability2 = {
      isCrtAvailable: false
    };
    var isCrtAvailable2 = /* @__PURE__ */ __name(() => {
      if (crtAvailability2.isCrtAvailable) {
        return ["md/crt-avail"];
      }
      return null;
    }, "isCrtAvailable");
    var createDefaultUserAgentProvider29 = /* @__PURE__ */ __name(({ serviceId, clientVersion }) => {
      const runtimeUserAgentPair = getRuntimeUserAgentPair2();
      return async (config2) => {
        const sections = [
          ["aws-sdk-js", clientVersion],
          ["ua", "2.1"],
          [`os/${node_os.platform()}`, node_os.release()],
          ["lang/js"],
          runtimeUserAgentPair
        ];
        const typescriptUserAgentPair = await getTypeScriptUserAgentPair2();
        if (typescriptUserAgentPair) {
          sections.push(typescriptUserAgentPair);
        }
        const crtAvailable = isCrtAvailable2();
        if (crtAvailable) {
          sections.push(crtAvailable);
        }
        if (serviceId) {
          sections.push([`api/${serviceId}`, clientVersion]);
        }
        if (node_process.env.AWS_EXECUTION_ENV) {
          sections.push([`exec-env/${node_process.env.AWS_EXECUTION_ENV}`]);
        }
        const appId = await config2?.userAgentAppId?.();
        const resolvedUserAgent = appId ? [...sections, [`app/${appId}`]] : [...sections];
        return resolvedUserAgent;
      };
    }, "createDefaultUserAgentProvider");
    var defaultUserAgent2 = createDefaultUserAgentProvider29;
    var UA_APP_ID_ENV_NAME2 = "AWS_SDK_UA_APP_ID";
    var UA_APP_ID_INI_NAME2 = "sdk_ua_app_id";
    var UA_APP_ID_INI_NAME_DEPRECATED2 = "sdk-ua-app-id";
    var NODE_APP_ID_CONFIG_OPTIONS29 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[UA_APP_ID_ENV_NAME2], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[UA_APP_ID_INI_NAME2] ?? profile[UA_APP_ID_INI_NAME_DEPRECATED2], "configFileSelector"),
      default: middlewareUserAgent.DEFAULT_UA_APP_ID
    };
    exports2.NODE_APP_ID_CONFIG_OPTIONS = NODE_APP_ID_CONFIG_OPTIONS29;
    exports2.UA_APP_ID_ENV_NAME = UA_APP_ID_ENV_NAME2;
    exports2.UA_APP_ID_INI_NAME = UA_APP_ID_INI_NAME2;
    exports2.createDefaultUserAgentProvider = createDefaultUserAgentProvider29;
    exports2.crtAvailability = crtAvailability2;
    exports2.defaultUserAgent = defaultUserAgent2;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ProtocolLib.js
var import_smithy_client145, ProtocolLib7;
var init_ProtocolLib7 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ProtocolLib.js"() {
    init_schema4();
    import_smithy_client145 = __toESM(require_dist_cjs34());
    ProtocolLib7 = class {
      static {
        __name(this, "ProtocolLib");
      }
      queryCompat;
      errorRegistry;
      constructor(queryCompat = false) {
        this.queryCompat = queryCompat;
      }
      resolveRestContentType(defaultContentType, inputSchema) {
        const members = inputSchema.getMemberSchemas();
        const httpPayloadMember = Object.values(members).find((m20) => {
          return !!m20.getMergedTraits().httpPayload;
        });
        if (httpPayloadMember) {
          const mediaType = httpPayloadMember.getMergedTraits().mediaType;
          if (mediaType) {
            return mediaType;
          } else if (httpPayloadMember.isStringSchema()) {
            return "text/plain";
          } else if (httpPayloadMember.isBlobSchema()) {
            return "application/octet-stream";
          } else {
            return defaultContentType;
          }
        } else if (!inputSchema.isUnitSchema()) {
          const hasBody = Object.values(members).find((m20) => {
            const { httpQuery, httpQueryParams, httpHeader, httpLabel, httpPrefixHeaders } = m20.getMergedTraits();
            const noPrefixHeaders = httpPrefixHeaders === void 0;
            return !httpQuery && !httpQueryParams && !httpHeader && !httpLabel && noPrefixHeaders;
          });
          if (hasBody) {
            return defaultContentType;
          }
        }
      }
      async getErrorSchemaOrThrowBaseException(errorIdentifier, defaultNamespace, response, dataObject, metadata, getErrorSchema) {
        let errorName = errorIdentifier;
        if (errorIdentifier.includes("#")) {
          [, errorName] = errorIdentifier.split("#");
        }
        const errorMetadata = {
          $metadata: metadata,
          $fault: response.statusCode < 500 ? "client" : "server"
        };
        if (!this.errorRegistry) {
          throw new Error("@aws-sdk/core/protocols - error handler not initialized.");
        }
        try {
          const errorSchema = getErrorSchema?.(this.errorRegistry, errorName) ?? this.errorRegistry.getSchema(errorIdentifier);
          return { errorSchema, errorMetadata };
        } catch (e32) {
          dataObject.message = dataObject.message ?? dataObject.Message ?? "UnknownError";
          const synthetic = this.errorRegistry;
          const baseExceptionSchema = synthetic.getBaseException();
          if (baseExceptionSchema) {
            const ErrorCtor = synthetic.getErrorCtor(baseExceptionSchema) ?? Error;
            throw this.decorateServiceException(Object.assign(new ErrorCtor({ name: errorName }), errorMetadata), dataObject);
          }
          const d32 = dataObject;
          const message2 = d32?.message ?? d32?.Message ?? d32?.Error?.Message ?? d32?.Error?.message;
          throw this.decorateServiceException(Object.assign(new Error(message2), {
            name: errorName
          }, errorMetadata), dataObject);
        }
      }
      compose(composite, errorIdentifier, defaultNamespace) {
        let namespace = defaultNamespace;
        if (errorIdentifier.includes("#")) {
          [namespace] = errorIdentifier.split("#");
        }
        const staticRegistry = TypeRegistry.for(namespace);
        const defaultSyntheticRegistry = TypeRegistry.for("smithy.ts.sdk.synthetic." + defaultNamespace);
        composite.copyFrom(staticRegistry);
        composite.copyFrom(defaultSyntheticRegistry);
        this.errorRegistry = composite;
      }
      decorateServiceException(exception, additions = {}) {
        if (this.queryCompat) {
          const msg = exception.Message ?? additions.Message;
          const error4 = (0, import_smithy_client145.decorateServiceException)(exception, additions);
          if (msg) {
            error4.message = msg;
          }
          const errorObj = error4.Error ?? {};
          errorObj.Type = error4.Error?.Type;
          errorObj.Code = error4.Error?.Code;
          errorObj.Message = error4.Error?.message ?? error4.Error?.Message ?? msg;
          error4.Error = errorObj;
          const reqId = error4.$metadata.requestId;
          if (reqId) {
            error4.RequestId = reqId;
          }
          return error4;
        }
        return (0, import_smithy_client145.decorateServiceException)(exception, additions);
      }
      setQueryCompatError(output, response) {
        const queryErrorHeader = response.headers?.["x-amzn-query-error"];
        if (output !== void 0 && queryErrorHeader != null) {
          const [Code, Type] = queryErrorHeader.split(";");
          const keys = Object.keys(output);
          const Error2 = {
            Code,
            Type
          };
          output.Code = Code;
          output.Type = Type;
          for (let i32 = 0; i32 < keys.length; i32++) {
            const k32 = keys[i32];
            Error2[k32 === "message" ? "Message" : k32] = output[k32];
          }
          delete Error2.__type;
          output.Error = Error2;
        }
      }
      queryCompatOutput(queryCompatErrorData, errorData) {
        if (queryCompatErrorData.Error) {
          errorData.Error = queryCompatErrorData.Error;
        }
        if (queryCompatErrorData.Type) {
          errorData.Type = queryCompatErrorData.Type;
        }
        if (queryCompatErrorData.Code) {
          errorData.Code = queryCompatErrorData.Code;
        }
      }
      findQueryCompatibleError(registry, errorName) {
        try {
          return registry.getSchema(errorName);
        } catch (e32) {
          return registry.find((schema) => NormalizedSchema.of(schema).getMergedTraits().awsQueryError?.[0] === errorName);
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/cbor/AwsSmithyRpcV2CborProtocol.js
var AwsSmithyRpcV2CborProtocol5;
var init_AwsSmithyRpcV2CborProtocol7 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/cbor/AwsSmithyRpcV2CborProtocol.js"() {
    init_cbor2();
    init_schema4();
    init_ProtocolLib7();
    AwsSmithyRpcV2CborProtocol5 = class extends SmithyRpcV2CborProtocol {
      static {
        __name(this, "AwsSmithyRpcV2CborProtocol");
      }
      awsQueryCompatible;
      mixin;
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, awsQueryCompatible }) {
        super({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32 });
        this.awsQueryCompatible = !!awsQueryCompatible;
        this.mixin = new ProtocolLib7(this.awsQueryCompatible);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        if (this.awsQueryCompatible) {
          request4.headers["x-amzn-query-mode"] = "true";
        }
        return request4;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        if (this.awsQueryCompatible) {
          this.mixin.setQueryCompatError(dataObject, response);
        }
        const errorName = (() => {
          const compatHeader = response.headers["x-amzn-query-error"];
          if (compatHeader && this.awsQueryCompatible) {
            return compatHeader.split(";")[0];
          }
          return loadSmithyRpcV2CborErrorCode(response, dataObject) ?? "Unknown";
        })();
        this.mixin.compose(this.compositeErrorRegistry, errorName, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorName, this.options.defaultNamespace, response, dataObject, metadata, this.awsQueryCompatible ? this.mixin.findQueryCompatibleError : void 0);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        const output = {};
        for (const [name, member7] of ns.structIterator()) {
          if (dataObject[name] != null) {
            output[name] = this.deserializer.readValue(member7, dataObject[name]);
          }
        }
        if (this.awsQueryCompatible) {
          this.mixin.queryCompatOutput(dataObject, output);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/coercing-serializers.js
var _toStr5, _toBool5, _toNum5;
var init_coercing_serializers7 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/coercing-serializers.js"() {
    _toStr5 = /* @__PURE__ */ __name((val) => {
      if (val == null) {
        return val;
      }
      if (typeof val === "number" || typeof val === "bigint") {
        const warning2 = new Error(`Received number ${val} where a string was expected.`);
        warning2.name = "Warning";
        console.warn(warning2);
        return String(val);
      }
      if (typeof val === "boolean") {
        const warning2 = new Error(`Received boolean ${val} where a string was expected.`);
        warning2.name = "Warning";
        console.warn(warning2);
        return String(val);
      }
      return val;
    }, "_toStr");
    _toBool5 = /* @__PURE__ */ __name((val) => {
      if (val == null) {
        return val;
      }
      if (typeof val === "number") {
      }
      if (typeof val === "string") {
        const lowercase = val.toLowerCase();
        if (val !== "" && lowercase !== "false" && lowercase !== "true") {
          const warning2 = new Error(`Received string "${val}" where a boolean was expected.`);
          warning2.name = "Warning";
          console.warn(warning2);
        }
        return val !== "" && lowercase !== "false";
      }
      return val;
    }, "_toBool");
    _toNum5 = /* @__PURE__ */ __name((val) => {
      if (val == null) {
        return val;
      }
      if (typeof val === "boolean") {
      }
      if (typeof val === "string") {
        const num = Number(val);
        if (num.toString() !== val) {
          const warning2 = new Error(`Received string "${val}" where a number was expected.`);
          warning2.name = "Warning";
          console.warn(warning2);
          return val;
        }
        return num;
      }
      return val;
    }, "_toNum");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ConfigurableSerdeContext.js
var SerdeContextConfig7;
var init_ConfigurableSerdeContext7 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ConfigurableSerdeContext.js"() {
    SerdeContextConfig7 = class {
      static {
        __name(this, "SerdeContextConfig");
      }
      serdeContext;
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/UnionSerde.js
var UnionSerde7;
var init_UnionSerde7 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/UnionSerde.js"() {
    UnionSerde7 = class {
      static {
        __name(this, "UnionSerde");
      }
      from;
      to;
      keys;
      constructor(from, to) {
        this.from = from;
        this.to = to;
        const keys = Object.keys(this.from);
        const set = new Set(keys);
        set.delete("__type");
        this.keys = set;
      }
      mark(key) {
        this.keys.delete(key);
      }
      hasUnknown() {
        return this.keys.size === 1 && Object.keys(this.to).length === 0;
      }
      writeUnknown() {
        if (this.hasUnknown()) {
          const k32 = this.keys.values().next().value;
          const v = this.from[k32];
          this.to.$unknown = [k32, v];
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReviver.js
function jsonReviver7(key, value, context) {
  if (context?.source) {
    const numericString = context.source;
    if (typeof value === "number") {
      if (value > Number.MAX_SAFE_INTEGER || value < Number.MIN_SAFE_INTEGER || numericString !== String(value)) {
        const isFractional = numericString.includes(".");
        if (isFractional) {
          return new NumericValue(numericString, "bigDecimal");
        } else {
          return BigInt(numericString);
        }
      }
    }
  }
  return value;
}
var init_jsonReviver7 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReviver.js"() {
    init_serde();
    __name(jsonReviver7, "jsonReviver");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/common.js
var import_smithy_client146, import_util_utf832, collectBodyString7;
var init_common8 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/common.js"() {
    import_smithy_client146 = __toESM(require_dist_cjs34());
    import_util_utf832 = __toESM(require_dist_cjs9());
    collectBodyString7 = /* @__PURE__ */ __name((streamBody, context) => (0, import_smithy_client146.collectBody)(streamBody, context).then((body) => (context?.utf8Encoder ?? import_util_utf832.toUtf8)(body)), "collectBodyString");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/parseJsonBody.js
var parseJsonBody7, parseJsonErrorBody5, findKey7, sanitizeErrorCode7, loadRestJsonErrorCode7;
var init_parseJsonBody7 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/parseJsonBody.js"() {
    init_common8();
    parseJsonBody7 = /* @__PURE__ */ __name((streamBody, context) => collectBodyString7(streamBody, context).then((encoded) => {
      if (encoded.length) {
        try {
          return JSON.parse(encoded);
        } catch (e32) {
          if (e32?.name === "SyntaxError") {
            Object.defineProperty(e32, "$responseBodyText", {
              value: encoded
            });
          }
          throw e32;
        }
      }
      return {};
    }), "parseJsonBody");
    parseJsonErrorBody5 = /* @__PURE__ */ __name(async (errorBody, context) => {
      const value = await parseJsonBody7(errorBody, context);
      value.message = value.message ?? value.Message;
      return value;
    }, "parseJsonErrorBody");
    findKey7 = /* @__PURE__ */ __name((object, key) => Object.keys(object).find((k32) => k32.toLowerCase() === key.toLowerCase()), "findKey");
    sanitizeErrorCode7 = /* @__PURE__ */ __name((rawValue) => {
      let cleanValue = rawValue;
      if (typeof cleanValue === "number") {
        cleanValue = cleanValue.toString();
      }
      if (cleanValue.indexOf(",") >= 0) {
        cleanValue = cleanValue.split(",")[0];
      }
      if (cleanValue.indexOf(":") >= 0) {
        cleanValue = cleanValue.split(":")[0];
      }
      if (cleanValue.indexOf("#") >= 0) {
        cleanValue = cleanValue.split("#")[1];
      }
      return cleanValue;
    }, "sanitizeErrorCode");
    loadRestJsonErrorCode7 = /* @__PURE__ */ __name((output, data3) => {
      const headerKey = findKey7(output.headers, "x-amzn-errortype");
      if (headerKey !== void 0) {
        return sanitizeErrorCode7(output.headers[headerKey]);
      }
      if (data3 && typeof data3 === "object") {
        const codeKey = findKey7(data3, "code");
        if (codeKey && data3[codeKey] !== void 0) {
          return sanitizeErrorCode7(data3[codeKey]);
        }
        if (data3["__type"] !== void 0) {
          return sanitizeErrorCode7(data3["__type"]);
        }
      }
    }, "loadRestJsonErrorCode");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeDeserializer.js
var import_util_base6440, JsonShapeDeserializer7;
var init_JsonShapeDeserializer7 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeDeserializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_util_base6440 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext7();
    init_UnionSerde7();
    init_jsonReviver7();
    init_parseJsonBody7();
    JsonShapeDeserializer7 = class extends SerdeContextConfig7 {
      static {
        __name(this, "JsonShapeDeserializer");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      async read(schema, data3) {
        return this._read(schema, typeof data3 === "string" ? JSON.parse(data3, jsonReviver7) : await parseJsonBody7(data3, this.serdeContext));
      }
      readObject(schema, data3) {
        return this._read(schema, data3);
      }
      _read(schema, value) {
        const isObject3 = value !== null && typeof value === "object";
        const ns = NormalizedSchema.of(schema);
        if (isObject3) {
          if (ns.isStructSchema()) {
            const record = value;
            const union = ns.isUnionSchema();
            const out = {};
            let nameMap = void 0;
            const { jsonName } = this.settings;
            if (jsonName) {
              nameMap = {};
            }
            let unionSerde;
            if (union) {
              unionSerde = new UnionSerde7(record, out);
            }
            for (const [memberName, memberSchema] of ns.structIterator()) {
              let fromKey = memberName;
              if (jsonName) {
                fromKey = memberSchema.getMergedTraits().jsonName ?? fromKey;
                nameMap[fromKey] = memberName;
              }
              if (union) {
                unionSerde.mark(fromKey);
              }
              if (record[fromKey] != null) {
                out[memberName] = this._read(memberSchema, record[fromKey]);
              }
            }
            if (union) {
              unionSerde.writeUnknown();
            } else if (typeof record.__type === "string") {
              for (const k32 in record) {
                const v = record[k32];
                const t = jsonName ? nameMap[k32] ?? k32 : k32;
                if (!(t in out)) {
                  out[t] = v;
                }
              }
            }
            return out;
          }
          if (Array.isArray(value) && ns.isListSchema()) {
            const listMember = ns.getValueSchema();
            const out = [];
            for (const item of value) {
              out.push(this._read(listMember, item));
            }
            return out;
          }
          if (ns.isMapSchema()) {
            const mapMember = ns.getValueSchema();
            const out = {};
            for (const _k in value) {
              out[_k] = this._read(mapMember, value[_k]);
            }
            return out;
          }
        }
        if (ns.isBlobSchema() && typeof value === "string") {
          return (0, import_util_base6440.fromBase64)(value);
        }
        const mediaType = ns.getMergedTraits().mediaType;
        if (ns.isStringSchema() && typeof value === "string" && mediaType) {
          const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
          if (isJson) {
            return LazyJsonString.from(value);
          }
          return value;
        }
        if (ns.isTimestampSchema() && value != null) {
          const format32 = determineTimestampFormat(ns, this.settings);
          switch (format32) {
            case 5:
              return parseRfc3339DateTimeWithOffset(value);
            case 6:
              return parseRfc7231DateTime(value);
            case 7:
              return parseEpochTimestamp(value);
            default:
              console.warn("Missing timestamp format, parsing value with Date constructor:", value);
              return new Date(value);
          }
        }
        if (ns.isBigIntegerSchema() && (typeof value === "number" || typeof value === "string")) {
          return BigInt(value);
        }
        if (ns.isBigDecimalSchema() && value != void 0) {
          if (value instanceof NumericValue) {
            return value;
          }
          const untyped = value;
          if (untyped.type === "bigDecimal" && "string" in untyped) {
            return new NumericValue(untyped.string, untyped.type);
          }
          return new NumericValue(String(value), "bigDecimal");
        }
        if (ns.isNumericSchema() && typeof value === "string") {
          switch (value) {
            case "Infinity":
              return Infinity;
            case "-Infinity":
              return -Infinity;
            case "NaN":
              return NaN;
          }
          return value;
        }
        if (ns.isDocumentSchema()) {
          if (isObject3) {
            const out = Array.isArray(value) ? [] : {};
            for (const k32 in value) {
              const v = value[k32];
              if (v instanceof NumericValue) {
                out[k32] = v;
              } else {
                out[k32] = this._read(ns, v);
              }
            }
            return out;
          } else {
            return structuredClone(value);
          }
        }
        return value;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReplacer.js
var NUMERIC_CONTROL_CHAR7, JsonReplacer7;
var init_jsonReplacer7 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReplacer.js"() {
    init_serde();
    NUMERIC_CONTROL_CHAR7 = String.fromCharCode(925);
    JsonReplacer7 = class {
      static {
        __name(this, "JsonReplacer");
      }
      values = /* @__PURE__ */ new Map();
      counter = 0;
      stage = 0;
      createReplacer() {
        if (this.stage === 1) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer already created.");
        }
        if (this.stage === 2) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer exhausted.");
        }
        this.stage = 1;
        return (key, value) => {
          if (value instanceof NumericValue) {
            const v = `${NUMERIC_CONTROL_CHAR7 + "nv" + this.counter++}_` + value.string;
            this.values.set(`"${v}"`, value.string);
            return v;
          }
          if (typeof value === "bigint") {
            const s = value.toString();
            const v = `${NUMERIC_CONTROL_CHAR7 + "b" + this.counter++}_` + s;
            this.values.set(`"${v}"`, s);
            return v;
          }
          return value;
        };
      }
      replaceInJson(json) {
        if (this.stage === 0) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer not created yet.");
        }
        if (this.stage === 2) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer exhausted.");
        }
        this.stage = 2;
        if (this.counter === 0) {
          return json;
        }
        for (const [key, value] of this.values) {
          json = json.replace(key, value);
        }
        return json;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeSerializer.js
var import_util_base6441, JsonShapeSerializer7;
var init_JsonShapeSerializer7 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeSerializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_util_base6441 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext7();
    init_jsonReplacer7();
    JsonShapeSerializer7 = class extends SerdeContextConfig7 {
      static {
        __name(this, "JsonShapeSerializer");
      }
      settings;
      buffer;
      useReplacer = false;
      rootSchema;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value) {
        this.rootSchema = NormalizedSchema.of(schema);
        this.buffer = this._write(this.rootSchema, value);
      }
      flush() {
        const { rootSchema, useReplacer } = this;
        this.rootSchema = void 0;
        this.useReplacer = false;
        if (rootSchema?.isStructSchema() || rootSchema?.isDocumentSchema()) {
          if (!useReplacer) {
            return JSON.stringify(this.buffer);
          }
          const replacer = new JsonReplacer7();
          return replacer.replaceInJson(JSON.stringify(this.buffer, replacer.createReplacer(), 0));
        }
        return this.buffer;
      }
      writeDiscriminatedDocument(schema, value) {
        this.write(schema, value);
        if (typeof this.buffer === "object") {
          this.buffer.__type = NormalizedSchema.of(schema).getName(true);
        }
      }
      _write(schema, value, container) {
        const isObject3 = value !== null && typeof value === "object";
        const ns = NormalizedSchema.of(schema);
        if (isObject3) {
          if (ns.isStructSchema()) {
            const record = value;
            const out = {};
            const { jsonName } = this.settings;
            let nameMap = void 0;
            if (jsonName) {
              nameMap = {};
            }
            let outCount = 0;
            for (const [memberName, memberSchema] of ns.structIterator()) {
              const serializableValue = this._write(memberSchema, record[memberName], ns);
              if (serializableValue !== void 0) {
                let targetKey = memberName;
                if (jsonName) {
                  targetKey = memberSchema.getMergedTraits().jsonName ?? memberName;
                  nameMap[memberName] = targetKey;
                }
                out[targetKey] = serializableValue;
                outCount++;
              }
            }
            if (ns.isUnionSchema() && outCount === 0) {
              const { $unknown } = record;
              if (Array.isArray($unknown)) {
                const [k32, v] = $unknown;
                out[k32] = this._write(15, v);
              }
            } else if (typeof record.__type === "string") {
              for (const k32 in record) {
                const v = record[k32];
                const targetKey = jsonName ? nameMap[k32] ?? k32 : k32;
                if (!(targetKey in out)) {
                  out[targetKey] = this._write(15, v);
                }
              }
            }
            return out;
          }
          if (Array.isArray(value) && ns.isListSchema()) {
            const listMember = ns.getValueSchema();
            const out = [];
            const sparse = !!ns.getMergedTraits().sparse;
            for (const item of value) {
              if (sparse || item != null) {
                out.push(this._write(listMember, item));
              }
            }
            return out;
          }
          if (ns.isMapSchema()) {
            const mapMember = ns.getValueSchema();
            const out = {};
            const sparse = !!ns.getMergedTraits().sparse;
            for (const _k in value) {
              const _v = value[_k];
              if (sparse || _v != null) {
                out[_k] = this._write(mapMember, _v);
              }
            }
            return out;
          }
          if (value instanceof Uint8Array && (ns.isBlobSchema() || ns.isDocumentSchema())) {
            if (ns === this.rootSchema) {
              return value;
            }
            return (this.serdeContext?.base64Encoder ?? import_util_base6441.toBase64)(value);
          }
          if (value instanceof Date && (ns.isTimestampSchema() || ns.isDocumentSchema())) {
            const format32 = determineTimestampFormat(ns, this.settings);
            switch (format32) {
              case 5:
                return value.toISOString().replace(".000Z", "Z");
              case 6:
                return dateToUtcString(value);
              case 7:
                return value.getTime() / 1e3;
              default:
                console.warn("Missing timestamp format, using epoch seconds", value);
                return value.getTime() / 1e3;
            }
          }
          if (value instanceof NumericValue) {
            this.useReplacer = true;
          }
        }
        if (value === null && container?.isStructSchema()) {
          return void 0;
        }
        if (ns.isStringSchema()) {
          if (typeof value === "undefined" && ns.isIdempotencyToken()) {
            return (0, import_uuid.v4)();
          }
          const mediaType = ns.getMergedTraits().mediaType;
          if (value != null && mediaType) {
            const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
            if (isJson) {
              return LazyJsonString.from(value);
            }
          }
          return value;
        }
        if (typeof value === "number" && ns.isNumericSchema()) {
          if (Math.abs(value) === Infinity || isNaN(value)) {
            return String(value);
          }
          return value;
        }
        if (typeof value === "string" && ns.isBlobSchema()) {
          if (ns === this.rootSchema) {
            return value;
          }
          return (this.serdeContext?.base64Encoder ?? import_util_base6441.toBase64)(value);
        }
        if (typeof value === "bigint") {
          this.useReplacer = true;
        }
        if (ns.isDocumentSchema()) {
          if (isObject3) {
            const out = Array.isArray(value) ? [] : {};
            for (const k32 in value) {
              const v = value[k32];
              if (v instanceof NumericValue) {
                this.useReplacer = true;
                out[k32] = v;
              } else {
                out[k32] = this._write(ns, v);
              }
            }
            return out;
          } else {
            return structuredClone(value);
          }
        }
        return value;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonCodec.js
var JsonCodec7;
var init_JsonCodec7 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonCodec.js"() {
    init_ConfigurableSerdeContext7();
    init_JsonShapeDeserializer7();
    init_JsonShapeSerializer7();
    JsonCodec7 = class extends SerdeContextConfig7 {
      static {
        __name(this, "JsonCodec");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      createSerializer() {
        const serializer = new JsonShapeSerializer7(this.settings);
        serializer.setSerdeContext(this.serdeContext);
        return serializer;
      }
      createDeserializer() {
        const deserializer = new JsonShapeDeserializer7(this.settings);
        deserializer.setSerdeContext(this.serdeContext);
        return deserializer;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJsonRpcProtocol.js
var AwsJsonRpcProtocol5;
var init_AwsJsonRpcProtocol7 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJsonRpcProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib7();
    init_JsonCodec7();
    init_parseJsonBody7();
    AwsJsonRpcProtocol5 = class extends RpcProtocol {
      static {
        __name(this, "AwsJsonRpcProtocol");
      }
      serializer;
      deserializer;
      serviceTarget;
      codec;
      mixin;
      awsQueryCompatible;
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, serviceTarget, awsQueryCompatible, jsonCodec }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32
        });
        this.serviceTarget = serviceTarget;
        this.codec = jsonCodec ?? new JsonCodec7({
          timestampFormat: {
            useTrait: true,
            default: 7
          },
          jsonName: false
        });
        this.serializer = this.codec.createSerializer();
        this.deserializer = this.codec.createDeserializer();
        this.awsQueryCompatible = !!awsQueryCompatible;
        this.mixin = new ProtocolLib7(this.awsQueryCompatible);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        if (!request4.path.endsWith("/")) {
          request4.path += "/";
        }
        request4.headers["content-type"] = `application/x-amz-json-${this.getJsonRpcVersion()}`;
        request4.headers["x-amz-target"] = `${this.serviceTarget}.${operationSchema.name}`;
        if (this.awsQueryCompatible) {
          request4.headers["x-amzn-query-mode"] = "true";
        }
        if (deref(operationSchema.input) === "unit" || !request4.body) {
          request4.body = "{}";
        }
        return request4;
      }
      getPayloadCodec() {
        return this.codec;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        if (this.awsQueryCompatible) {
          this.mixin.setQueryCompatError(dataObject, response);
        }
        const errorIdentifier = loadRestJsonErrorCode7(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata, this.awsQueryCompatible ? this.mixin.findQueryCompatibleError : void 0);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          if (dataObject[name] != null) {
            output[name] = errorDeserializer.readObject(member7, dataObject[name]);
          }
        }
        if (this.awsQueryCompatible) {
          this.mixin.queryCompatOutput(dataObject, output);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_0Protocol.js
var AwsJson1_0Protocol5;
var init_AwsJson1_0Protocol7 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_0Protocol.js"() {
    init_AwsJsonRpcProtocol7();
    AwsJson1_0Protocol5 = class extends AwsJsonRpcProtocol5 {
      static {
        __name(this, "AwsJson1_0Protocol");
      }
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, serviceTarget, awsQueryCompatible, jsonCodec }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32,
          serviceTarget,
          awsQueryCompatible,
          jsonCodec
        });
      }
      getShapeId() {
        return "aws.protocols#awsJson1_0";
      }
      getJsonRpcVersion() {
        return "1.0";
      }
      getDefaultContentType() {
        return "application/x-amz-json-1.0";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_1Protocol.js
var AwsJson1_1Protocol5;
var init_AwsJson1_1Protocol7 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_1Protocol.js"() {
    init_AwsJsonRpcProtocol7();
    AwsJson1_1Protocol5 = class extends AwsJsonRpcProtocol5 {
      static {
        __name(this, "AwsJson1_1Protocol");
      }
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, serviceTarget, awsQueryCompatible, jsonCodec }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32,
          serviceTarget,
          awsQueryCompatible,
          jsonCodec
        });
      }
      getShapeId() {
        return "aws.protocols#awsJson1_1";
      }
      getJsonRpcVersion() {
        return "1.1";
      }
      getDefaultContentType() {
        return "application/x-amz-json-1.1";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsRestJsonProtocol.js
var AwsRestJsonProtocol7;
var init_AwsRestJsonProtocol7 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsRestJsonProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib7();
    init_JsonCodec7();
    init_parseJsonBody7();
    AwsRestJsonProtocol7 = class extends HttpBindingProtocol {
      static {
        __name(this, "AwsRestJsonProtocol");
      }
      serializer;
      deserializer;
      codec;
      mixin = new ProtocolLib7();
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32 }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32
        });
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 7
          },
          httpBindings: true,
          jsonName: true
        };
        this.codec = new JsonCodec7(settings);
        this.serializer = new HttpInterceptingShapeSerializer(this.codec.createSerializer(), settings);
        this.deserializer = new HttpInterceptingShapeDeserializer(this.codec.createDeserializer(), settings);
      }
      getShapeId() {
        return "aws.protocols#restJson1";
      }
      getPayloadCodec() {
        return this.codec;
      }
      setSerdeContext(serdeContext) {
        this.codec.setSerdeContext(serdeContext);
        super.setSerdeContext(serdeContext);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        const inputSchema = NormalizedSchema.of(operationSchema.input);
        if (!request4.headers["content-type"]) {
          const contentType = this.mixin.resolveRestContentType(this.getDefaultContentType(), inputSchema);
          if (contentType) {
            request4.headers["content-type"] = contentType;
          }
        }
        if (request4.body == null && request4.headers["content-type"] === this.getDefaultContentType()) {
          request4.body = "{}";
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        const output = await super.deserializeResponse(operationSchema, context, response);
        const outputSchema = NormalizedSchema.of(operationSchema.output);
        for (const [name, member7] of outputSchema.structIterator()) {
          if (member7.getMemberTraits().httpPayload && !(name in output)) {
            output[name] = null;
          }
        }
        return output;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = loadRestJsonErrorCode7(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        await this.deserializeHttpMessage(errorSchema, context, response, dataObject);
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().jsonName ?? name;
          output[name] = errorDeserializer.readObject(member7, dataObject[target]);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      getDefaultContentType() {
        return "application/json";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/awsExpectUnion.js
var import_smithy_client147, awsExpectUnion5;
var init_awsExpectUnion7 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/awsExpectUnion.js"() {
    import_smithy_client147 = __toESM(require_dist_cjs34());
    awsExpectUnion5 = /* @__PURE__ */ __name((value) => {
      if (value == null) {
        return void 0;
      }
      if (typeof value === "object" && "__type" in value) {
        delete value.__type;
      }
      return (0, import_smithy_client147.expectUnion)(value);
    }, "awsExpectUnion");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeDeserializer.js
var import_xml_builder14, import_smithy_client148, import_util_utf833, XmlShapeDeserializer6;
var init_XmlShapeDeserializer7 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeDeserializer.js"() {
    import_xml_builder14 = __toESM(require_dist_cjs47());
    init_protocols();
    init_schema4();
    import_smithy_client148 = __toESM(require_dist_cjs34());
    import_util_utf833 = __toESM(require_dist_cjs9());
    init_ConfigurableSerdeContext7();
    init_UnionSerde7();
    XmlShapeDeserializer6 = class extends SerdeContextConfig7 {
      static {
        __name(this, "XmlShapeDeserializer");
      }
      settings;
      stringDeserializer;
      constructor(settings) {
        super();
        this.settings = settings;
        this.stringDeserializer = new FromStringShapeDeserializer(settings);
      }
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
        this.stringDeserializer.setSerdeContext(serdeContext);
      }
      read(schema, bytes, key) {
        const ns = NormalizedSchema.of(schema);
        const memberSchemas = ns.getMemberSchemas();
        const isEventPayload = ns.isStructSchema() && ns.isMemberSchema() && !!Object.values(memberSchemas).find((memberNs) => {
          return !!memberNs.getMemberTraits().eventPayload;
        });
        if (isEventPayload) {
          const output = {};
          const memberName = Object.keys(memberSchemas)[0];
          const eventMemberSchema = memberSchemas[memberName];
          if (eventMemberSchema.isBlobSchema()) {
            output[memberName] = bytes;
          } else {
            output[memberName] = this.read(memberSchemas[memberName], bytes);
          }
          return output;
        }
        const xmlString = (this.serdeContext?.utf8Encoder ?? import_util_utf833.toUtf8)(bytes);
        const parsedObject = this.parseXml(xmlString);
        return this.readSchema(schema, key ? parsedObject[key] : parsedObject);
      }
      readSchema(_schema, value) {
        const ns = NormalizedSchema.of(_schema);
        if (ns.isUnitSchema()) {
          return;
        }
        const traits = ns.getMergedTraits();
        if (ns.isListSchema() && !Array.isArray(value)) {
          return this.readSchema(ns, [value]);
        }
        if (value == null) {
          return value;
        }
        if (typeof value === "object") {
          const flat = !!traits.xmlFlattened;
          if (ns.isListSchema()) {
            const listValue = ns.getValueSchema();
            const buffer2 = [];
            const sourceKey = listValue.getMergedTraits().xmlName ?? "member";
            const source = flat ? value : (value[0] ?? value)[sourceKey];
            if (source == null) {
              return buffer2;
            }
            const sourceArray = Array.isArray(source) ? source : [source];
            for (const v of sourceArray) {
              buffer2.push(this.readSchema(listValue, v));
            }
            return buffer2;
          }
          const buffer = {};
          if (ns.isMapSchema()) {
            const keyNs = ns.getKeySchema();
            const memberNs = ns.getValueSchema();
            let entries;
            if (flat) {
              entries = Array.isArray(value) ? value : [value];
            } else {
              entries = Array.isArray(value.entry) ? value.entry : [value.entry];
            }
            const keyProperty = keyNs.getMergedTraits().xmlName ?? "key";
            const valueProperty = memberNs.getMergedTraits().xmlName ?? "value";
            for (const entry of entries) {
              const key = entry[keyProperty];
              const value2 = entry[valueProperty];
              buffer[key] = this.readSchema(memberNs, value2);
            }
            return buffer;
          }
          if (ns.isStructSchema()) {
            const union = ns.isUnionSchema();
            let unionSerde;
            if (union) {
              unionSerde = new UnionSerde7(value, buffer);
            }
            for (const [memberName, memberSchema] of ns.structIterator()) {
              const memberTraits = memberSchema.getMergedTraits();
              const xmlObjectKey = !memberTraits.httpPayload ? memberSchema.getMemberTraits().xmlName ?? memberName : memberTraits.xmlName ?? memberSchema.getName();
              if (union) {
                unionSerde.mark(xmlObjectKey);
              }
              if (value[xmlObjectKey] != null) {
                buffer[memberName] = this.readSchema(memberSchema, value[xmlObjectKey]);
              }
            }
            if (union) {
              unionSerde.writeUnknown();
            }
            return buffer;
          }
          if (ns.isDocumentSchema()) {
            return value;
          }
          throw new Error(`@aws-sdk/core/protocols - xml deserializer unhandled schema type for ${ns.getName(true)}`);
        }
        if (ns.isListSchema()) {
          return [];
        }
        if (ns.isMapSchema() || ns.isStructSchema()) {
          return {};
        }
        return this.stringDeserializer.read(ns, value);
      }
      parseXml(xml) {
        if (xml.length) {
          let parsedObj;
          try {
            parsedObj = (0, import_xml_builder14.parseXML)(xml);
          } catch (e32) {
            if (e32 && typeof e32 === "object") {
              Object.defineProperty(e32, "$responseBodyText", {
                value: xml
              });
            }
            throw e32;
          }
          const textNodeName = "#text";
          const key = Object.keys(parsedObj)[0];
          const parsedObjToReturn = parsedObj[key];
          if (parsedObjToReturn[textNodeName]) {
            parsedObjToReturn[key] = parsedObjToReturn[textNodeName];
            delete parsedObjToReturn[textNodeName];
          }
          return (0, import_smithy_client148.getValueFromTextNode)(parsedObjToReturn);
        }
        return {};
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QueryShapeSerializer.js
var import_smithy_client149, import_util_base6442, QueryShapeSerializer6;
var init_QueryShapeSerializer7 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QueryShapeSerializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_smithy_client149 = __toESM(require_dist_cjs34());
    import_util_base6442 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext7();
    QueryShapeSerializer6 = class extends SerdeContextConfig7 {
      static {
        __name(this, "QueryShapeSerializer");
      }
      settings;
      buffer;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value, prefix = "") {
        if (this.buffer === void 0) {
          this.buffer = "";
        }
        const ns = NormalizedSchema.of(schema);
        if (prefix && !prefix.endsWith(".")) {
          prefix += ".";
        }
        if (ns.isBlobSchema()) {
          if (typeof value === "string" || value instanceof Uint8Array) {
            this.writeKey(prefix);
            this.writeValue((this.serdeContext?.base64Encoder ?? import_util_base6442.toBase64)(value));
          }
        } else if (ns.isBooleanSchema() || ns.isNumericSchema() || ns.isStringSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(String(value));
          } else if (ns.isIdempotencyToken()) {
            this.writeKey(prefix);
            this.writeValue((0, import_uuid.v4)());
          }
        } else if (ns.isBigIntegerSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(String(value));
          }
        } else if (ns.isBigDecimalSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(value instanceof NumericValue ? value.string : String(value));
          }
        } else if (ns.isTimestampSchema()) {
          if (value instanceof Date) {
            this.writeKey(prefix);
            const format32 = determineTimestampFormat(ns, this.settings);
            switch (format32) {
              case 5:
                this.writeValue(value.toISOString().replace(".000Z", "Z"));
                break;
              case 6:
                this.writeValue((0, import_smithy_client149.dateToUtcString)(value));
                break;
              case 7:
                this.writeValue(String(value.getTime() / 1e3));
                break;
            }
          }
        } else if (ns.isDocumentSchema()) {
          if (Array.isArray(value)) {
            this.write(64 | 15, value, prefix);
          } else if (value instanceof Date) {
            this.write(4, value, prefix);
          } else if (value instanceof Uint8Array) {
            this.write(21, value, prefix);
          } else if (value && typeof value === "object") {
            this.write(128 | 15, value, prefix);
          } else {
            this.writeKey(prefix);
            this.writeValue(String(value));
          }
        } else if (ns.isListSchema()) {
          if (Array.isArray(value)) {
            if (value.length === 0) {
              if (this.settings.serializeEmptyLists) {
                this.writeKey(prefix);
                this.writeValue("");
              }
            } else {
              const member7 = ns.getValueSchema();
              const flat = this.settings.flattenLists || ns.getMergedTraits().xmlFlattened;
              let i32 = 1;
              for (const item of value) {
                if (item == null) {
                  continue;
                }
                const traits = member7.getMergedTraits();
                const suffix = this.getKey("member", traits.xmlName, traits.ec2QueryName);
                const key = flat ? `${prefix}${i32}` : `${prefix}${suffix}.${i32}`;
                this.write(member7, item, key);
                ++i32;
              }
            }
          }
        } else if (ns.isMapSchema()) {
          if (value && typeof value === "object") {
            const keySchema = ns.getKeySchema();
            const memberSchema = ns.getValueSchema();
            const flat = ns.getMergedTraits().xmlFlattened;
            let i32 = 1;
            for (const k32 in value) {
              const v = value[k32];
              if (v == null) {
                continue;
              }
              const keyTraits = keySchema.getMergedTraits();
              const keySuffix = this.getKey("key", keyTraits.xmlName, keyTraits.ec2QueryName);
              const key = flat ? `${prefix}${i32}.${keySuffix}` : `${prefix}entry.${i32}.${keySuffix}`;
              const valTraits = memberSchema.getMergedTraits();
              const valueSuffix = this.getKey("value", valTraits.xmlName, valTraits.ec2QueryName);
              const valueKey = flat ? `${prefix}${i32}.${valueSuffix}` : `${prefix}entry.${i32}.${valueSuffix}`;
              this.write(keySchema, k32, key);
              this.write(memberSchema, v, valueKey);
              ++i32;
            }
          }
        } else if (ns.isStructSchema()) {
          if (value && typeof value === "object") {
            let didWriteMember = false;
            for (const [memberName, member7] of ns.structIterator()) {
              if (value[memberName] == null && !member7.isIdempotencyToken()) {
                continue;
              }
              const traits = member7.getMergedTraits();
              const suffix = this.getKey(memberName, traits.xmlName, traits.ec2QueryName, "struct");
              const key = `${prefix}${suffix}`;
              this.write(member7, value[memberName], key);
              didWriteMember = true;
            }
            if (!didWriteMember && ns.isUnionSchema()) {
              const { $unknown } = value;
              if (Array.isArray($unknown)) {
                const [k32, v] = $unknown;
                const key = `${prefix}${k32}`;
                this.write(15, v, key);
              }
            }
          }
        } else if (ns.isUnitSchema()) {
        } else {
          throw new Error(`@aws-sdk/core/protocols - QuerySerializer unrecognized schema type ${ns.getName(true)}`);
        }
      }
      flush() {
        if (this.buffer === void 0) {
          throw new Error("@aws-sdk/core/protocols - QuerySerializer cannot flush with nothing written to buffer.");
        }
        const str = this.buffer;
        delete this.buffer;
        return str;
      }
      getKey(memberName, xmlName, ec2QueryName, keySource) {
        const { ec2, capitalizeKeys } = this.settings;
        if (ec2 && ec2QueryName) {
          return ec2QueryName;
        }
        const key = xmlName ?? memberName;
        if (capitalizeKeys && keySource === "struct") {
          return key[0].toUpperCase() + key.slice(1);
        }
        return key;
      }
      writeKey(key) {
        if (key.endsWith(".")) {
          key = key.slice(0, key.length - 1);
        }
        this.buffer += `&${extendedEncodeURIComponent(key)}=`;
      }
      writeValue(value) {
        this.buffer += extendedEncodeURIComponent(value);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsQueryProtocol.js
var AwsQueryProtocol6;
var init_AwsQueryProtocol7 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsQueryProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib7();
    init_XmlShapeDeserializer7();
    init_QueryShapeSerializer7();
    AwsQueryProtocol6 = class extends RpcProtocol {
      static {
        __name(this, "AwsQueryProtocol");
      }
      options;
      serializer;
      deserializer;
      mixin = new ProtocolLib7();
      constructor(options) {
        super({
          defaultNamespace: options.defaultNamespace,
          errorTypeRegistries: options.errorTypeRegistries
        });
        this.options = options;
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 5
          },
          httpBindings: false,
          xmlNamespace: options.xmlNamespace,
          serviceNamespace: options.defaultNamespace,
          serializeEmptyLists: true
        };
        this.serializer = new QueryShapeSerializer6(settings);
        this.deserializer = new XmlShapeDeserializer6(settings);
      }
      getShapeId() {
        return "aws.protocols#awsQuery";
      }
      setSerdeContext(serdeContext) {
        this.serializer.setSerdeContext(serdeContext);
        this.deserializer.setSerdeContext(serdeContext);
      }
      getPayloadCodec() {
        throw new Error("AWSQuery protocol has no payload codec.");
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        if (!request4.path.endsWith("/")) {
          request4.path += "/";
        }
        request4.headers["content-type"] = "application/x-www-form-urlencoded";
        if (deref(operationSchema.input) === "unit" || !request4.body) {
          request4.body = "";
        }
        const action = operationSchema.name.split("#")[1] ?? operationSchema.name;
        request4.body = `Action=${action}&Version=${this.options.version}` + request4.body;
        if (request4.body.endsWith("&")) {
          request4.body = request4.body.slice(-1);
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        const deserializer = this.deserializer;
        const ns = NormalizedSchema.of(operationSchema.output);
        const dataObject = {};
        if (response.statusCode >= 300) {
          const bytes2 = await collectBody(response.body, context);
          if (bytes2.byteLength > 0) {
            Object.assign(dataObject, await deserializer.read(15, bytes2));
          }
          await this.handleError(operationSchema, context, response, dataObject, this.deserializeMetadata(response));
        }
        for (const header in response.headers) {
          const value = response.headers[header];
          delete response.headers[header];
          response.headers[header.toLowerCase()] = value;
        }
        const shortName = operationSchema.name.split("#")[1] ?? operationSchema.name;
        const awsQueryResultKey = ns.isStructSchema() && this.useNestedResult() ? shortName + "Result" : void 0;
        const bytes = await collectBody(response.body, context);
        if (bytes.byteLength > 0) {
          Object.assign(dataObject, await deserializer.read(ns, bytes, awsQueryResultKey));
        }
        dataObject.$metadata = this.deserializeMetadata(response);
        return dataObject;
      }
      useNestedResult() {
        return true;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = this.loadQueryErrorCode(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const errorData = this.loadQueryError(dataObject) ?? {};
        const message2 = this.loadQueryErrorMessage(dataObject);
        errorData.message = message2;
        errorData.Error = {
          Type: errorData.Type,
          Code: errorData.Code,
          Message: message2
        };
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, errorData, metadata, this.mixin.findQueryCompatibleError);
        const ns = NormalizedSchema.of(errorSchema);
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        const output = {
          Type: errorData.Error.Type,
          Code: errorData.Error.Code,
          Error: errorData.Error
        };
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().xmlName ?? name;
          const value = errorData[target] ?? dataObject[target];
          output[name] = this.deserializer.readSchema(member7, value);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      loadQueryErrorCode(output, data3) {
        const code = (data3.Errors?.[0]?.Error ?? data3.Errors?.Error ?? data3.Error)?.Code;
        if (code !== void 0) {
          return code;
        }
        if (output.statusCode == 404) {
          return "NotFound";
        }
      }
      loadQueryError(data3) {
        return data3.Errors?.[0]?.Error ?? data3.Errors?.Error ?? data3.Error;
      }
      loadQueryErrorMessage(data3) {
        const errorData = this.loadQueryError(data3);
        return errorData?.message ?? errorData?.Message ?? data3.message ?? data3.Message ?? "Unknown";
      }
      getDefaultContentType() {
        return "application/x-www-form-urlencoded";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsEc2QueryProtocol.js
var AwsEc2QueryProtocol5;
var init_AwsEc2QueryProtocol7 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsEc2QueryProtocol.js"() {
    init_AwsQueryProtocol7();
    AwsEc2QueryProtocol5 = class extends AwsQueryProtocol6 {
      static {
        __name(this, "AwsEc2QueryProtocol");
      }
      options;
      constructor(options) {
        super(options);
        this.options = options;
        const ec2Settings = {
          capitalizeKeys: true,
          flattenLists: true,
          serializeEmptyLists: false,
          ec2: true
        };
        Object.assign(this.serializer.settings, ec2Settings);
      }
      getShapeId() {
        return "aws.protocols#ec2Query";
      }
      useNestedResult() {
        return false;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QuerySerializerSettings.js
var init_QuerySerializerSettings7 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QuerySerializerSettings.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/parseXmlBody.js
var import_xml_builder15, import_smithy_client150, parseXmlBody5, parseXmlErrorBody5, loadRestXmlErrorCode5;
var init_parseXmlBody7 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/parseXmlBody.js"() {
    import_xml_builder15 = __toESM(require_dist_cjs47());
    import_smithy_client150 = __toESM(require_dist_cjs34());
    init_common8();
    parseXmlBody5 = /* @__PURE__ */ __name((streamBody, context) => collectBodyString7(streamBody, context).then((encoded) => {
      if (encoded.length) {
        let parsedObj;
        try {
          parsedObj = (0, import_xml_builder15.parseXML)(encoded);
        } catch (e32) {
          if (e32 && typeof e32 === "object") {
            Object.defineProperty(e32, "$responseBodyText", {
              value: encoded
            });
          }
          throw e32;
        }
        const textNodeName = "#text";
        const key = Object.keys(parsedObj)[0];
        const parsedObjToReturn = parsedObj[key];
        if (parsedObjToReturn[textNodeName]) {
          parsedObjToReturn[key] = parsedObjToReturn[textNodeName];
          delete parsedObjToReturn[textNodeName];
        }
        return (0, import_smithy_client150.getValueFromTextNode)(parsedObjToReturn);
      }
      return {};
    }), "parseXmlBody");
    parseXmlErrorBody5 = /* @__PURE__ */ __name(async (errorBody, context) => {
      const value = await parseXmlBody5(errorBody, context);
      if (value.Error) {
        value.Error.message = value.Error.message ?? value.Error.Message;
      }
      return value;
    }, "parseXmlErrorBody");
    loadRestXmlErrorCode5 = /* @__PURE__ */ __name((output, data3) => {
      if (data3?.Error?.Code !== void 0) {
        return data3.Error.Code;
      }
      if (data3?.Code !== void 0) {
        return data3.Code;
      }
      if (output.statusCode == 404) {
        return "NotFound";
      }
    }, "loadRestXmlErrorCode");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeSerializer.js
var import_xml_builder16, import_smithy_client151, import_util_base6443, XmlShapeSerializer5;
var init_XmlShapeSerializer7 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeSerializer.js"() {
    import_xml_builder16 = __toESM(require_dist_cjs47());
    init_protocols();
    init_schema4();
    init_serde();
    import_smithy_client151 = __toESM(require_dist_cjs34());
    import_util_base6443 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext7();
    XmlShapeSerializer5 = class extends SerdeContextConfig7 {
      static {
        __name(this, "XmlShapeSerializer");
      }
      settings;
      stringBuffer;
      byteBuffer;
      buffer;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value) {
        const ns = NormalizedSchema.of(schema);
        if (ns.isStringSchema() && typeof value === "string") {
          this.stringBuffer = value;
        } else if (ns.isBlobSchema()) {
          this.byteBuffer = "byteLength" in value ? value : (this.serdeContext?.base64Decoder ?? import_util_base6443.fromBase64)(value);
        } else {
          this.buffer = this.writeStruct(ns, value, void 0);
          const traits = ns.getMergedTraits();
          if (traits.httpPayload && !traits.xmlName) {
            this.buffer.withName(ns.getName());
          }
        }
      }
      flush() {
        if (this.byteBuffer !== void 0) {
          const bytes = this.byteBuffer;
          delete this.byteBuffer;
          return bytes;
        }
        if (this.stringBuffer !== void 0) {
          const str = this.stringBuffer;
          delete this.stringBuffer;
          return str;
        }
        const buffer = this.buffer;
        if (this.settings.xmlNamespace) {
          if (!buffer?.attributes?.["xmlns"]) {
            buffer.addAttribute("xmlns", this.settings.xmlNamespace);
          }
        }
        delete this.buffer;
        return buffer.toString();
      }
      writeStruct(ns, value, parentXmlns) {
        const traits = ns.getMergedTraits();
        const name = ns.isMemberSchema() && !traits.httpPayload ? ns.getMemberTraits().xmlName ?? ns.getMemberName() : traits.xmlName ?? ns.getName();
        if (!name || !ns.isStructSchema()) {
          throw new Error(`@aws-sdk/core/protocols - xml serializer, cannot write struct with empty name or non-struct, schema=${ns.getName(true)}.`);
        }
        const structXmlNode = import_xml_builder16.XmlNode.of(name);
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(ns, parentXmlns);
        for (const [memberName, memberSchema] of ns.structIterator()) {
          const val = value[memberName];
          if (val != null || memberSchema.isIdempotencyToken()) {
            if (memberSchema.getMergedTraits().xmlAttribute) {
              structXmlNode.addAttribute(memberSchema.getMergedTraits().xmlName ?? memberName, this.writeSimple(memberSchema, val));
              continue;
            }
            if (memberSchema.isListSchema()) {
              this.writeList(memberSchema, val, structXmlNode, xmlns);
            } else if (memberSchema.isMapSchema()) {
              this.writeMap(memberSchema, val, structXmlNode, xmlns);
            } else if (memberSchema.isStructSchema()) {
              structXmlNode.addChildNode(this.writeStruct(memberSchema, val, xmlns));
            } else {
              const memberNode = import_xml_builder16.XmlNode.of(memberSchema.getMergedTraits().xmlName ?? memberSchema.getMemberName());
              this.writeSimpleInto(memberSchema, val, memberNode, xmlns);
              structXmlNode.addChildNode(memberNode);
            }
          }
        }
        const { $unknown } = value;
        if ($unknown && ns.isUnionSchema() && Array.isArray($unknown) && Object.keys(value).length === 1) {
          const [k32, v] = $unknown;
          const node = import_xml_builder16.XmlNode.of(k32);
          if (typeof v !== "string") {
            if (value instanceof import_xml_builder16.XmlNode || value instanceof import_xml_builder16.XmlText) {
              structXmlNode.addChildNode(value);
            } else {
              throw new Error(`@aws-sdk - $unknown union member in XML requires value of type string, @aws-sdk/xml-builder::XmlNode or XmlText.`);
            }
          }
          this.writeSimpleInto(0, v, node, xmlns);
          structXmlNode.addChildNode(node);
        }
        if (xmlns) {
          structXmlNode.addAttribute(xmlnsAttr, xmlns);
        }
        return structXmlNode;
      }
      writeList(listMember, array, container, parentXmlns) {
        if (!listMember.isMemberSchema()) {
          throw new Error(`@aws-sdk/core/protocols - xml serializer, cannot write non-member list: ${listMember.getName(true)}`);
        }
        const listTraits = listMember.getMergedTraits();
        const listValueSchema = listMember.getValueSchema();
        const listValueTraits = listValueSchema.getMergedTraits();
        const sparse = !!listValueTraits.sparse;
        const flat = !!listTraits.xmlFlattened;
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(listMember, parentXmlns);
        const writeItem = /* @__PURE__ */ __name((container2, value) => {
          if (listValueSchema.isListSchema()) {
            this.writeList(listValueSchema, Array.isArray(value) ? value : [value], container2, xmlns);
          } else if (listValueSchema.isMapSchema()) {
            this.writeMap(listValueSchema, value, container2, xmlns);
          } else if (listValueSchema.isStructSchema()) {
            const struct3 = this.writeStruct(listValueSchema, value, xmlns);
            container2.addChildNode(struct3.withName(flat ? listTraits.xmlName ?? listMember.getMemberName() : listValueTraits.xmlName ?? "member"));
          } else {
            const listItemNode = import_xml_builder16.XmlNode.of(flat ? listTraits.xmlName ?? listMember.getMemberName() : listValueTraits.xmlName ?? "member");
            this.writeSimpleInto(listValueSchema, value, listItemNode, xmlns);
            container2.addChildNode(listItemNode);
          }
        }, "writeItem");
        if (flat) {
          for (const value of array) {
            if (sparse || value != null) {
              writeItem(container, value);
            }
          }
        } else {
          const listNode = import_xml_builder16.XmlNode.of(listTraits.xmlName ?? listMember.getMemberName());
          if (xmlns) {
            listNode.addAttribute(xmlnsAttr, xmlns);
          }
          for (const value of array) {
            if (sparse || value != null) {
              writeItem(listNode, value);
            }
          }
          container.addChildNode(listNode);
        }
      }
      writeMap(mapMember, map5, container, parentXmlns, containerIsMap = false) {
        if (!mapMember.isMemberSchema()) {
          throw new Error(`@aws-sdk/core/protocols - xml serializer, cannot write non-member map: ${mapMember.getName(true)}`);
        }
        const mapTraits = mapMember.getMergedTraits();
        const mapKeySchema = mapMember.getKeySchema();
        const mapKeyTraits = mapKeySchema.getMergedTraits();
        const keyTag = mapKeyTraits.xmlName ?? "key";
        const mapValueSchema = mapMember.getValueSchema();
        const mapValueTraits = mapValueSchema.getMergedTraits();
        const valueTag = mapValueTraits.xmlName ?? "value";
        const sparse = !!mapValueTraits.sparse;
        const flat = !!mapTraits.xmlFlattened;
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(mapMember, parentXmlns);
        const addKeyValue = /* @__PURE__ */ __name((entry, key, val) => {
          const keyNode = import_xml_builder16.XmlNode.of(keyTag, key);
          const [keyXmlnsAttr, keyXmlns] = this.getXmlnsAttribute(mapKeySchema, xmlns);
          if (keyXmlns) {
            keyNode.addAttribute(keyXmlnsAttr, keyXmlns);
          }
          entry.addChildNode(keyNode);
          let valueNode = import_xml_builder16.XmlNode.of(valueTag);
          if (mapValueSchema.isListSchema()) {
            this.writeList(mapValueSchema, val, valueNode, xmlns);
          } else if (mapValueSchema.isMapSchema()) {
            this.writeMap(mapValueSchema, val, valueNode, xmlns, true);
          } else if (mapValueSchema.isStructSchema()) {
            valueNode = this.writeStruct(mapValueSchema, val, xmlns);
          } else {
            this.writeSimpleInto(mapValueSchema, val, valueNode, xmlns);
          }
          entry.addChildNode(valueNode);
        }, "addKeyValue");
        if (flat) {
          for (const key in map5) {
            const val = map5[key];
            if (sparse || val != null) {
              const entry = import_xml_builder16.XmlNode.of(mapTraits.xmlName ?? mapMember.getMemberName());
              addKeyValue(entry, key, val);
              container.addChildNode(entry);
            }
          }
        } else {
          let mapNode;
          if (!containerIsMap) {
            mapNode = import_xml_builder16.XmlNode.of(mapTraits.xmlName ?? mapMember.getMemberName());
            if (xmlns) {
              mapNode.addAttribute(xmlnsAttr, xmlns);
            }
            container.addChildNode(mapNode);
          }
          for (const key in map5) {
            const val = map5[key];
            if (sparse || val != null) {
              const entry = import_xml_builder16.XmlNode.of("entry");
              addKeyValue(entry, key, val);
              (containerIsMap ? container : mapNode).addChildNode(entry);
            }
          }
        }
      }
      writeSimple(_schema, value) {
        if (null === value) {
          throw new Error("@aws-sdk/core/protocols - (XML serializer) cannot write null value.");
        }
        const ns = NormalizedSchema.of(_schema);
        let nodeContents = null;
        if (value && typeof value === "object") {
          if (ns.isBlobSchema()) {
            nodeContents = (this.serdeContext?.base64Encoder ?? import_util_base6443.toBase64)(value);
          } else if (ns.isTimestampSchema() && value instanceof Date) {
            const format32 = determineTimestampFormat(ns, this.settings);
            switch (format32) {
              case 5:
                nodeContents = value.toISOString().replace(".000Z", "Z");
                break;
              case 6:
                nodeContents = (0, import_smithy_client151.dateToUtcString)(value);
                break;
              case 7:
                nodeContents = String(value.getTime() / 1e3);
                break;
              default:
                console.warn("Missing timestamp format, using http date", value);
                nodeContents = (0, import_smithy_client151.dateToUtcString)(value);
                break;
            }
          } else if (ns.isBigDecimalSchema() && value) {
            if (value instanceof NumericValue) {
              return value.string;
            }
            return String(value);
          } else if (ns.isMapSchema() || ns.isListSchema()) {
            throw new Error("@aws-sdk/core/protocols - xml serializer, cannot call _write() on List/Map schema, call writeList or writeMap() instead.");
          } else {
            throw new Error(`@aws-sdk/core/protocols - xml serializer, unhandled schema type for object value and schema: ${ns.getName(true)}`);
          }
        }
        if (ns.isBooleanSchema() || ns.isNumericSchema() || ns.isBigIntegerSchema() || ns.isBigDecimalSchema()) {
          nodeContents = String(value);
        }
        if (ns.isStringSchema()) {
          if (value === void 0 && ns.isIdempotencyToken()) {
            nodeContents = (0, import_uuid.v4)();
          } else {
            nodeContents = String(value);
          }
        }
        if (nodeContents === null) {
          throw new Error(`Unhandled schema-value pair ${ns.getName(true)}=${value}`);
        }
        return nodeContents;
      }
      writeSimpleInto(_schema, value, into, parentXmlns) {
        const nodeContents = this.writeSimple(_schema, value);
        const ns = NormalizedSchema.of(_schema);
        const content = new import_xml_builder16.XmlText(nodeContents);
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(ns, parentXmlns);
        if (xmlns) {
          into.addAttribute(xmlnsAttr, xmlns);
        }
        into.addChildNode(content);
      }
      getXmlnsAttribute(ns, parentXmlns) {
        const traits = ns.getMergedTraits();
        const [prefix, xmlns] = traits.xmlNamespace ?? [];
        if (xmlns && xmlns !== parentXmlns) {
          return [prefix ? `xmlns:${prefix}` : "xmlns", xmlns];
        }
        return [void 0, void 0];
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlCodec.js
var XmlCodec5;
var init_XmlCodec7 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlCodec.js"() {
    init_ConfigurableSerdeContext7();
    init_XmlShapeDeserializer7();
    init_XmlShapeSerializer7();
    XmlCodec5 = class extends SerdeContextConfig7 {
      static {
        __name(this, "XmlCodec");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      createSerializer() {
        const serializer = new XmlShapeSerializer5(this.settings);
        serializer.setSerdeContext(this.serdeContext);
        return serializer;
      }
      createDeserializer() {
        const deserializer = new XmlShapeDeserializer6(this.settings);
        deserializer.setSerdeContext(this.serdeContext);
        return deserializer;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/AwsRestXmlProtocol.js
var AwsRestXmlProtocol5;
var init_AwsRestXmlProtocol7 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/AwsRestXmlProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib7();
    init_parseXmlBody7();
    init_XmlCodec7();
    AwsRestXmlProtocol5 = class extends HttpBindingProtocol {
      static {
        __name(this, "AwsRestXmlProtocol");
      }
      codec;
      serializer;
      deserializer;
      mixin = new ProtocolLib7();
      constructor(options) {
        super(options);
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 5
          },
          httpBindings: true,
          xmlNamespace: options.xmlNamespace,
          serviceNamespace: options.defaultNamespace
        };
        this.codec = new XmlCodec5(settings);
        this.serializer = new HttpInterceptingShapeSerializer(this.codec.createSerializer(), settings);
        this.deserializer = new HttpInterceptingShapeDeserializer(this.codec.createDeserializer(), settings);
      }
      getPayloadCodec() {
        return this.codec;
      }
      getShapeId() {
        return "aws.protocols#restXml";
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        const inputSchema = NormalizedSchema.of(operationSchema.input);
        if (!request4.headers["content-type"]) {
          const contentType = this.mixin.resolveRestContentType(this.getDefaultContentType(), inputSchema);
          if (contentType) {
            request4.headers["content-type"] = contentType;
          }
        }
        if (typeof request4.body === "string" && request4.headers["content-type"] === this.getDefaultContentType() && !request4.body.startsWith("<?xml ") && !this.hasUnstructuredPayloadBinding(inputSchema)) {
          request4.body = '<?xml version="1.0" encoding="UTF-8"?>' + request4.body;
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        return super.deserializeResponse(operationSchema, context, response);
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = loadRestXmlErrorCode5(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        if (dataObject.Error && typeof dataObject.Error === "object") {
          for (const key of Object.keys(dataObject.Error)) {
            dataObject[key] = dataObject.Error[key];
            if (key.toLowerCase() === "message") {
              dataObject.message = dataObject.Error[key];
            }
          }
        }
        if (dataObject.RequestId && !metadata.requestId) {
          metadata.requestId = dataObject.RequestId;
        }
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.Error?.message ?? dataObject.Error?.Message ?? dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        await this.deserializeHttpMessage(errorSchema, context, response, dataObject);
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().xmlName ?? name;
          const value = dataObject.Error?.[target] ?? dataObject[target];
          output[name] = errorDeserializer.readSchema(member7, value);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      getDefaultContentType() {
        return "application/xml";
      }
      hasUnstructuredPayloadBinding(ns) {
        for (const [, member7] of ns.structIterator()) {
          if (member7.getMergedTraits().httpPayload) {
            return !(member7.isStructSchema() || member7.isMapSchema() || member7.isListSchema());
          }
        }
        return false;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/index.js
var protocols_exports7 = {};
__export(protocols_exports7, {
  AwsEc2QueryProtocol: () => AwsEc2QueryProtocol5,
  AwsJson1_0Protocol: () => AwsJson1_0Protocol5,
  AwsJson1_1Protocol: () => AwsJson1_1Protocol5,
  AwsJsonRpcProtocol: () => AwsJsonRpcProtocol5,
  AwsQueryProtocol: () => AwsQueryProtocol6,
  AwsRestJsonProtocol: () => AwsRestJsonProtocol7,
  AwsRestXmlProtocol: () => AwsRestXmlProtocol5,
  AwsSmithyRpcV2CborProtocol: () => AwsSmithyRpcV2CborProtocol5,
  JsonCodec: () => JsonCodec7,
  JsonShapeDeserializer: () => JsonShapeDeserializer7,
  JsonShapeSerializer: () => JsonShapeSerializer7,
  QueryShapeSerializer: () => QueryShapeSerializer6,
  XmlCodec: () => XmlCodec5,
  XmlShapeDeserializer: () => XmlShapeDeserializer6,
  XmlShapeSerializer: () => XmlShapeSerializer5,
  _toBool: () => _toBool5,
  _toNum: () => _toNum5,
  _toStr: () => _toStr5,
  awsExpectUnion: () => awsExpectUnion5,
  loadRestJsonErrorCode: () => loadRestJsonErrorCode7,
  loadRestXmlErrorCode: () => loadRestXmlErrorCode5,
  parseJsonBody: () => parseJsonBody7,
  parseJsonErrorBody: () => parseJsonErrorBody5,
  parseXmlBody: () => parseXmlBody5,
  parseXmlErrorBody: () => parseXmlErrorBody5
});
var init_protocols10 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/core/dist-es/submodules/protocols/index.js"() {
    init_AwsSmithyRpcV2CborProtocol7();
    init_coercing_serializers7();
    init_AwsJson1_0Protocol7();
    init_AwsJson1_1Protocol7();
    init_AwsJsonRpcProtocol7();
    init_AwsRestJsonProtocol7();
    init_JsonCodec7();
    init_JsonShapeDeserializer7();
    init_JsonShapeSerializer7();
    init_awsExpectUnion7();
    init_parseJsonBody7();
    init_AwsEc2QueryProtocol7();
    init_AwsQueryProtocol7();
    init_QuerySerializerSettings7();
    init_QueryShapeSerializer7();
    init_AwsRestXmlProtocol7();
    init_XmlCodec7();
    init_XmlShapeDeserializer7();
    init_XmlShapeSerializer7();
    init_parseXmlBody7();
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/bdd.js
var import_util_endpoints46, k16, a16, b16, c16, d16, e16, f16, g16, h16, i16, j16, _data16, root16, r16, nodes16, bdd16;
var init_bdd16 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/bdd.js"() {
    import_util_endpoints46 = __toESM(require_dist_cjs20());
    k16 = "ref";
    a16 = -1;
    b16 = true;
    c16 = "isSet";
    d16 = "PartitionResult";
    e16 = "booleanEquals";
    f16 = "getAttr";
    g16 = { [k16]: "Endpoint" };
    h16 = { [k16]: d16 };
    i16 = {};
    j16 = [{ [k16]: "Region" }];
    _data16 = {
      conditions: [
        [c16, [g16]],
        [c16, j16],
        ["aws.partition", j16, d16],
        [e16, [{ [k16]: "UseFIPS" }, b16]],
        [e16, [{ [k16]: "UseDualStack" }, b16]],
        [e16, [{ fn: f16, argv: [h16, "supportsDualStack"] }, b16]],
        [e16, [{ fn: f16, argv: [h16, "supportsFIPS"] }, b16]],
        ["stringEquals", [{ fn: f16, argv: [h16, "name"] }, "aws-us-gov"]]
      ],
      results: [
        [a16],
        [a16, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a16, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [g16, i16],
        ["https://portal.sso-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", i16],
        [a16, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://portal.sso.{Region}.amazonaws.com", i16],
        ["https://portal.sso-fips.{Region}.{PartitionResult#dnsSuffix}", i16],
        [a16, "FIPS is enabled but this partition does not support FIPS"],
        ["https://portal.sso.{Region}.{PartitionResult#dualStackDnsSuffix}", i16],
        [a16, "DualStack is enabled but this partition does not support DualStack"],
        ["https://portal.sso.{Region}.{PartitionResult#dnsSuffix}", i16],
        [a16, "Invalid Configuration: Missing Region"]
      ]
    };
    root16 = 2;
    r16 = 1e8;
    nodes16 = new Int32Array([
      -1,
      1,
      -1,
      0,
      13,
      3,
      1,
      4,
      r16 + 12,
      2,
      5,
      r16 + 12,
      3,
      8,
      6,
      4,
      7,
      r16 + 11,
      5,
      r16 + 9,
      r16 + 10,
      4,
      11,
      9,
      6,
      10,
      r16 + 8,
      7,
      r16 + 6,
      r16 + 7,
      5,
      12,
      r16 + 5,
      6,
      r16 + 4,
      r16 + 5,
      3,
      r16 + 1,
      14,
      4,
      r16 + 2,
      r16 + 3
    ]);
    bdd16 = import_util_endpoints46.BinaryDecisionDiagram.from(nodes16, root16, _data16.conditions, _data16.results);
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/endpointResolver.js
var import_util_endpoints47, import_util_endpoints48, cache16, defaultEndpointResolver16;
var init_endpointResolver16 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/endpointResolver.js"() {
    import_util_endpoints47 = __toESM(require_dist_cjs21());
    import_util_endpoints48 = __toESM(require_dist_cjs20());
    init_bdd16();
    cache16 = new import_util_endpoints48.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    defaultEndpointResolver16 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache16.get(endpointParams, () => (0, import_util_endpoints48.decideEndpoint)(bdd16, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    import_util_endpoints48.customEndpointFunctions.aws = import_util_endpoints47.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/SSOServiceException.js
var import_smithy_client152, SSOServiceException5;
var init_SSOServiceException5 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/SSOServiceException.js"() {
    import_smithy_client152 = __toESM(require_dist_cjs34());
    SSOServiceException5 = class _SSOServiceException extends import_smithy_client152.ServiceException {
      static {
        __name(this, "SSOServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _SSOServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/errors.js
var InvalidRequestException7, ResourceNotFoundException6, TooManyRequestsException6, UnauthorizedException5;
var init_errors16 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/errors.js"() {
    init_SSOServiceException5();
    InvalidRequestException7 = class _InvalidRequestException extends SSOServiceException5 {
      static {
        __name(this, "InvalidRequestException");
      }
      name = "InvalidRequestException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidRequestException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidRequestException.prototype);
      }
    };
    ResourceNotFoundException6 = class _ResourceNotFoundException extends SSOServiceException5 {
      static {
        __name(this, "ResourceNotFoundException");
      }
      name = "ResourceNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ResourceNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceNotFoundException.prototype);
      }
    };
    TooManyRequestsException6 = class _TooManyRequestsException extends SSOServiceException5 {
      static {
        __name(this, "TooManyRequestsException");
      }
      name = "TooManyRequestsException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TooManyRequestsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyRequestsException.prototype);
      }
    };
    UnauthorizedException5 = class _UnauthorizedException extends SSOServiceException5 {
      static {
        __name(this, "UnauthorizedException");
      }
      name = "UnauthorizedException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "UnauthorizedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnauthorizedException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/schemas/schemas_0.js
var _ATT5, _GRC5, _GRCR5, _GRCRe5, _IRE7, _RC5, _RNFE6, _SAKT5, _STT5, _TMRE10, _UE5, _aI5, _aKI9, _aT11, _ai5, _c16, _e16, _ex5, _h11, _hE16, _hH5, _hQ5, _m14, _rC5, _rN5, _rn5, _s16, _sAK9, _sT9, _xasbt5, n016, _s_registry16, SSOServiceException$5, n0_registry16, InvalidRequestException$7, ResourceNotFoundException$6, TooManyRequestsException$6, UnauthorizedException$5, errorTypeRegistries16, AccessTokenType5, SecretAccessKeyType5, SessionTokenType5, GetRoleCredentialsRequest$5, GetRoleCredentialsResponse$5, RoleCredentials$5, GetRoleCredentials$5;
var init_schemas_016 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/schemas/schemas_0.js"() {
    init_schema4();
    init_errors16();
    init_SSOServiceException5();
    _ATT5 = "AccessTokenType";
    _GRC5 = "GetRoleCredentials";
    _GRCR5 = "GetRoleCredentialsRequest";
    _GRCRe5 = "GetRoleCredentialsResponse";
    _IRE7 = "InvalidRequestException";
    _RC5 = "RoleCredentials";
    _RNFE6 = "ResourceNotFoundException";
    _SAKT5 = "SecretAccessKeyType";
    _STT5 = "SessionTokenType";
    _TMRE10 = "TooManyRequestsException";
    _UE5 = "UnauthorizedException";
    _aI5 = "accountId";
    _aKI9 = "accessKeyId";
    _aT11 = "accessToken";
    _ai5 = "account_id";
    _c16 = "client";
    _e16 = "error";
    _ex5 = "expiration";
    _h11 = "http";
    _hE16 = "httpError";
    _hH5 = "httpHeader";
    _hQ5 = "httpQuery";
    _m14 = "message";
    _rC5 = "roleCredentials";
    _rN5 = "roleName";
    _rn5 = "role_name";
    _s16 = "smithy.ts.sdk.synthetic.com.amazonaws.sso";
    _sAK9 = "secretAccessKey";
    _sT9 = "sessionToken";
    _xasbt5 = "x-amz-sso_bearer_token";
    n016 = "com.amazonaws.sso";
    _s_registry16 = TypeRegistry.for(_s16);
    SSOServiceException$5 = [-3, _s16, "SSOServiceException", 0, [], []];
    _s_registry16.registerError(SSOServiceException$5, SSOServiceException5);
    n0_registry16 = TypeRegistry.for(n016);
    InvalidRequestException$7 = [-3, n016, _IRE7, { [_e16]: _c16, [_hE16]: 400 }, [_m14], [0]];
    n0_registry16.registerError(InvalidRequestException$7, InvalidRequestException7);
    ResourceNotFoundException$6 = [-3, n016, _RNFE6, { [_e16]: _c16, [_hE16]: 404 }, [_m14], [0]];
    n0_registry16.registerError(ResourceNotFoundException$6, ResourceNotFoundException6);
    TooManyRequestsException$6 = [-3, n016, _TMRE10, { [_e16]: _c16, [_hE16]: 429 }, [_m14], [0]];
    n0_registry16.registerError(TooManyRequestsException$6, TooManyRequestsException6);
    UnauthorizedException$5 = [-3, n016, _UE5, { [_e16]: _c16, [_hE16]: 401 }, [_m14], [0]];
    n0_registry16.registerError(UnauthorizedException$5, UnauthorizedException5);
    errorTypeRegistries16 = [_s_registry16, n0_registry16];
    AccessTokenType5 = [0, n016, _ATT5, 8, 0];
    SecretAccessKeyType5 = [0, n016, _SAKT5, 8, 0];
    SessionTokenType5 = [0, n016, _STT5, 8, 0];
    GetRoleCredentialsRequest$5 = [
      3,
      n016,
      _GRCR5,
      0,
      [_rN5, _aI5, _aT11],
      [
        [0, { [_hQ5]: _rn5 }],
        [0, { [_hQ5]: _ai5 }],
        [() => AccessTokenType5, { [_hH5]: _xasbt5 }]
      ],
      3
    ];
    GetRoleCredentialsResponse$5 = [
      3,
      n016,
      _GRCRe5,
      0,
      [_rC5],
      [[() => RoleCredentials$5, 0]]
    ];
    RoleCredentials$5 = [
      3,
      n016,
      _RC5,
      0,
      [_aKI9, _sAK9, _sT9, _ex5],
      [0, [() => SecretAccessKeyType5, 0], [() => SessionTokenType5, 0], 1]
    ];
    GetRoleCredentials$5 = [
      9,
      n016,
      _GRC5,
      { [_h11]: ["GET", "/federation/credentials", 200] },
      () => GetRoleCredentialsRequest$5,
      () => GetRoleCredentialsResponse$5
    ];
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.shared.js
var import_smithy_client153, import_url_parser17, import_util_base6444, import_util_utf834, getRuntimeConfig31;
var init_runtimeConfig_shared16 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.shared.js"() {
    init_httpAuthSchemes7();
    init_protocols10();
    init_dist_es();
    import_smithy_client153 = __toESM(require_dist_cjs34());
    import_url_parser17 = __toESM(require_dist_cjs18());
    import_util_base6444 = __toESM(require_dist_cjs10());
    import_util_utf834 = __toESM(require_dist_cjs9());
    init_httpAuthSchemeProvider16();
    init_endpointResolver16();
    init_schemas_016();
    getRuntimeConfig31 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2019-06-10",
        base64Decoder: config2?.base64Decoder ?? import_util_base6444.fromBase64,
        base64Encoder: config2?.base64Encoder ?? import_util_base6444.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver16,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSSOHttpAuthSchemeProvider5,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer6()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        logger: config2?.logger ?? new import_smithy_client153.NoOpLogger(),
        protocol: config2?.protocol ?? AwsRestJsonProtocol7,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.sso",
          errorTypeRegistries: errorTypeRegistries16,
          version: "2019-06-10",
          serviceTarget: "SWBPortalService"
        },
        serviceId: config2?.serviceId ?? "SSO",
        urlParser: config2?.urlParser ?? import_url_parser17.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? import_util_utf834.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? import_util_utf834.toUtf8
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.js
var import_util_user_agent_node16, import_config_resolver32, import_hash_node16, import_middleware_retry31, import_node_config_provider17, import_node_http_handler16, import_smithy_client154, import_util_body_length_node16, import_util_defaults_mode_node16, import_util_retry24, getRuntimeConfig32;
var init_runtimeConfig16 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.js"() {
    init_package6();
    init_client10();
    init_httpAuthSchemes7();
    import_util_user_agent_node16 = __toESM(require_dist_cjs132());
    import_config_resolver32 = __toESM(require_dist_cjs25());
    import_hash_node16 = __toESM(require_dist_cjs44());
    import_middleware_retry31 = __toESM(require_dist_cjs128());
    import_node_config_provider17 = __toESM(require_dist_cjs29());
    import_node_http_handler16 = __toESM(require_dist_cjs13());
    import_smithy_client154 = __toESM(require_dist_cjs34());
    import_util_body_length_node16 = __toESM(require_dist_cjs45());
    import_util_defaults_mode_node16 = __toESM(require_dist_cjs46());
    import_util_retry24 = __toESM(require_dist_cjs22());
    init_runtimeConfig_shared16();
    getRuntimeConfig32 = /* @__PURE__ */ __name((config2) => {
      (0, import_smithy_client154.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, import_util_defaults_mode_node16.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(import_smithy_client154.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig31(config2);
      emitWarningIfUnsupportedVersion23(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, import_node_config_provider17.loadConfig)(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS6, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? import_util_body_length_node16.calculateBodyLength,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, import_util_user_agent_node16.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_default6.version }),
        maxAttempts: config2?.maxAttempts ?? (0, import_node_config_provider17.loadConfig)(import_middleware_retry31.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, import_node_config_provider17.loadConfig)(import_config_resolver32.NODE_REGION_CONFIG_OPTIONS, { ...import_config_resolver32.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: import_node_http_handler16.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, import_node_config_provider17.loadConfig)({
          ...import_middleware_retry31.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || import_util_retry24.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? import_hash_node16.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? import_node_http_handler16.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, import_node_config_provider17.loadConfig)(import_config_resolver32.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, import_node_config_provider17.loadConfig)(import_config_resolver32.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, import_node_config_provider17.loadConfig)(import_util_user_agent_node16.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration16, resolveHttpAuthRuntimeConfig16;
var init_httpAuthExtensionConfiguration16 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration16 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig16 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeExtensions.js
var import_region_config_resolver20, import_protocol_http42, import_smithy_client155, resolveRuntimeExtensions16;
var init_runtimeExtensions16 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeExtensions.js"() {
    import_region_config_resolver20 = __toESM(require_dist_cjs48());
    import_protocol_http42 = __toESM(require_dist_cjs2());
    import_smithy_client155 = __toESM(require_dist_cjs34());
    init_httpAuthExtensionConfiguration16();
    resolveRuntimeExtensions16 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign((0, import_region_config_resolver20.getAwsRegionExtensionConfiguration)(runtimeConfig), (0, import_smithy_client155.getDefaultExtensionConfiguration)(runtimeConfig), (0, import_protocol_http42.getHttpHandlerExtensionConfiguration)(runtimeConfig), getHttpAuthExtensionConfiguration16(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, (0, import_region_config_resolver20.resolveAwsRegionExtensionConfiguration)(extensionConfiguration), (0, import_smithy_client155.resolveDefaultRuntimeConfig)(extensionConfiguration), (0, import_protocol_http42.resolveHttpHandlerRuntimeConfig)(extensionConfiguration), resolveHttpAuthRuntimeConfig16(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSOClient.js
var import_middleware_host_header16, import_middleware_logger16, import_middleware_recursion_detection16, import_middleware_user_agent16, import_config_resolver33, import_middleware_content_length16, import_middleware_endpoint40, import_middleware_retry32, import_smithy_client156, SSOClient5;
var init_SSOClient5 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSOClient.js"() {
    import_middleware_host_header16 = __toESM(require_dist_cjs3());
    import_middleware_logger16 = __toESM(require_dist_cjs4());
    import_middleware_recursion_detection16 = __toESM(require_dist_cjs5());
    import_middleware_user_agent16 = __toESM(require_dist_cjs127());
    import_config_resolver33 = __toESM(require_dist_cjs25());
    init_dist_es();
    init_schema4();
    import_middleware_content_length16 = __toESM(require_dist_cjs26());
    import_middleware_endpoint40 = __toESM(require_dist_cjs31());
    import_middleware_retry32 = __toESM(require_dist_cjs128());
    import_smithy_client156 = __toESM(require_dist_cjs34());
    init_httpAuthSchemeProvider16();
    init_EndpointParameters16();
    init_runtimeConfig16();
    init_runtimeExtensions16();
    SSOClient5 = class extends import_smithy_client156.Client {
      static {
        __name(this, "SSOClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig32(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters16(_config_0);
        const _config_2 = (0, import_middleware_user_agent16.resolveUserAgentConfig)(_config_1);
        const _config_3 = (0, import_middleware_retry32.resolveRetryConfig)(_config_2);
        const _config_4 = (0, import_config_resolver33.resolveRegionConfig)(_config_3);
        const _config_5 = (0, import_middleware_host_header16.resolveHostHeaderConfig)(_config_4);
        const _config_6 = (0, import_middleware_endpoint40.resolveEndpointConfig)(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig16(_config_6);
        const _config_8 = resolveRuntimeExtensions16(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin(this.config));
        this.middlewareStack.use((0, import_middleware_user_agent16.getUserAgentPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_retry32.getRetryPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_content_length16.getContentLengthPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_host_header16.getHostHeaderPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_logger16.getLoggerPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_recursion_detection16.getRecursionDetectionPlugin)(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: defaultSSOHttpAuthSchemeParametersProvider5,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/GetRoleCredentialsCommand.js
var import_middleware_endpoint41, import_smithy_client157, GetRoleCredentialsCommand5;
var init_GetRoleCredentialsCommand5 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/GetRoleCredentialsCommand.js"() {
    import_middleware_endpoint41 = __toESM(require_dist_cjs31());
    import_smithy_client157 = __toESM(require_dist_cjs34());
    init_EndpointParameters16();
    init_schemas_016();
    GetRoleCredentialsCommand5 = class extends import_smithy_client157.Command.classBuilder().ep(commonParams16).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint41.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("SWBPortalService", "GetRoleCredentials", {}).n("SSOClient", "GetRoleCredentialsCommand").sc(GetRoleCredentials$5).build() {
      static {
        __name(this, "GetRoleCredentialsCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSO.js
var import_smithy_client158, commands16, SSO5;
var init_SSO5 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSO.js"() {
    import_smithy_client158 = __toESM(require_dist_cjs34());
    init_GetRoleCredentialsCommand5();
    init_SSOClient5();
    commands16 = {
      GetRoleCredentialsCommand: GetRoleCredentialsCommand5
    };
    SSO5 = class extends SSOClient5 {
      static {
        __name(this, "SSO");
      }
    };
    (0, import_smithy_client158.createAggregatedClient)(commands16, SSO5);
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/index.js
var init_commands17 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/index.js"() {
    init_GetRoleCredentialsCommand5();
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/models_0.js
var init_models_016 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/index.js
var sso_exports5 = {};
__export(sso_exports5, {
  $Command: () => import_smithy_client157.Command,
  GetRoleCredentials$: () => GetRoleCredentials$5,
  GetRoleCredentialsCommand: () => GetRoleCredentialsCommand5,
  GetRoleCredentialsRequest$: () => GetRoleCredentialsRequest$5,
  GetRoleCredentialsResponse$: () => GetRoleCredentialsResponse$5,
  InvalidRequestException: () => InvalidRequestException7,
  InvalidRequestException$: () => InvalidRequestException$7,
  ResourceNotFoundException: () => ResourceNotFoundException6,
  ResourceNotFoundException$: () => ResourceNotFoundException$6,
  RoleCredentials$: () => RoleCredentials$5,
  SSO: () => SSO5,
  SSOClient: () => SSOClient5,
  SSOServiceException: () => SSOServiceException5,
  SSOServiceException$: () => SSOServiceException$5,
  TooManyRequestsException: () => TooManyRequestsException6,
  TooManyRequestsException$: () => TooManyRequestsException$6,
  UnauthorizedException: () => UnauthorizedException5,
  UnauthorizedException$: () => UnauthorizedException$5,
  __Client: () => import_smithy_client156.Client,
  errorTypeRegistries: () => errorTypeRegistries16
});
var init_sso5 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/index.js"() {
    init_SSOClient5();
    init_SSO5();
    init_commands17();
    init_schemas_016();
    init_errors16();
    init_models_016();
    init_SSOServiceException5();
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/loadSso-BKDNrsal.js
var require_loadSso_BKDNrsal5 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/loadSso-BKDNrsal.js"(exports2) {
    "use strict";
    var sso = (init_sso5(), __toCommonJS(sso_exports5));
    exports2.GetRoleCredentialsCommand = sso.GetRoleCredentialsCommand;
    exports2.SSOClient = sso.SSOClient;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/index.js
var require_dist_cjs133 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/index.js"(exports2) {
    "use strict";
    var propertyProvider = require_dist_cjs27();
    var sharedIniFileLoader = require_dist_cjs28();
    var client = (init_client10(), __toCommonJS(client_exports8));
    var tokenProviders = require_dist_cjs49();
    var isSsoProfile = /* @__PURE__ */ __name((arg) => arg && (typeof arg.sso_start_url === "string" || typeof arg.sso_account_id === "string" || typeof arg.sso_session === "string" || typeof arg.sso_region === "string" || typeof arg.sso_role_name === "string"), "isSsoProfile");
    var SHOULD_FAIL_CREDENTIAL_CHAIN = false;
    var resolveSSOCredentials = /* @__PURE__ */ __name(async ({ ssoStartUrl, ssoSession, ssoAccountId, ssoRegion, ssoRoleName, ssoClient, clientConfig, parentClientConfig, callerClientConfig, profile, filepath, configFilepath, ignoreCache, logger: logger5 }) => {
      let token;
      const refreshMessage = `To refresh this SSO session run aws sso login with the corresponding profile.`;
      if (ssoSession) {
        try {
          const _token = await tokenProviders.fromSso({
            profile,
            filepath,
            configFilepath,
            ignoreCache
          })();
          token = {
            accessToken: _token.token,
            expiresAt: new Date(_token.expiration).toISOString()
          };
        } catch (e32) {
          throw new propertyProvider.CredentialsProviderError(e32.message, {
            tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
            logger: logger5
          });
        }
      } else {
        try {
          token = await sharedIniFileLoader.getSSOTokenFromFile(ssoStartUrl);
        } catch (e32) {
          throw new propertyProvider.CredentialsProviderError(`The SSO session associated with this profile is invalid. ${refreshMessage}`, {
            tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
            logger: logger5
          });
        }
      }
      if (new Date(token.expiresAt).getTime() - Date.now() <= 0) {
        throw new propertyProvider.CredentialsProviderError(`The SSO session associated with this profile has expired. ${refreshMessage}`, {
          tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
          logger: logger5
        });
      }
      const { accessToken } = token;
      const { SSOClient: SSOClient10, GetRoleCredentialsCommand: GetRoleCredentialsCommand10 } = await Promise.resolve().then(function() {
        return require_loadSso_BKDNrsal5();
      });
      const sso = ssoClient || new SSOClient10(Object.assign({}, clientConfig ?? {}, {
        logger: clientConfig?.logger ?? callerClientConfig?.logger ?? parentClientConfig?.logger,
        region: clientConfig?.region ?? ssoRegion,
        userAgentAppId: clientConfig?.userAgentAppId ?? callerClientConfig?.userAgentAppId ?? parentClientConfig?.userAgentAppId
      }));
      let ssoResp;
      try {
        ssoResp = await sso.send(new GetRoleCredentialsCommand10({
          accountId: ssoAccountId,
          roleName: ssoRoleName,
          accessToken
        }));
      } catch (e32) {
        throw new propertyProvider.CredentialsProviderError(e32, {
          tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
          logger: logger5
        });
      }
      const { roleCredentials: { accessKeyId, secretAccessKey, sessionToken, expiration, credentialScope, accountId } = {} } = ssoResp;
      if (!accessKeyId || !secretAccessKey || !sessionToken || !expiration) {
        throw new propertyProvider.CredentialsProviderError("SSO returns an invalid temporary credential.", {
          tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
          logger: logger5
        });
      }
      const credentials = {
        accessKeyId,
        secretAccessKey,
        sessionToken,
        expiration: new Date(expiration),
        ...credentialScope && { credentialScope },
        ...accountId && { accountId }
      };
      if (ssoSession) {
        client.setCredentialFeature(credentials, "CREDENTIALS_SSO", "s");
      } else {
        client.setCredentialFeature(credentials, "CREDENTIALS_SSO_LEGACY", "u");
      }
      return credentials;
    }, "resolveSSOCredentials");
    var validateSsoProfile = /* @__PURE__ */ __name((profile, logger5) => {
      const { sso_start_url, sso_account_id, sso_region, sso_role_name } = profile;
      if (!sso_start_url || !sso_account_id || !sso_region || !sso_role_name) {
        throw new propertyProvider.CredentialsProviderError(`Profile is configured with invalid SSO credentials. Required parameters "sso_account_id", "sso_region", "sso_role_name", "sso_start_url". Got ${Object.keys(profile).join(", ")}
Reference: https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-sso.html`, { tryNextLink: false, logger: logger5 });
      }
      return profile;
    }, "validateSsoProfile");
    var fromSSO = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/credential-provider-sso - fromSSO");
      const { ssoStartUrl, ssoAccountId, ssoRegion, ssoRoleName, ssoSession } = init;
      const { ssoClient } = init;
      const profileName = sharedIniFileLoader.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      });
      if (!ssoStartUrl && !ssoAccountId && !ssoRegion && !ssoRoleName && !ssoSession) {
        const profiles = await sharedIniFileLoader.parseKnownFiles(init);
        const profile = profiles[profileName];
        if (!profile) {
          throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} was not found.`, { logger: init.logger });
        }
        if (!isSsoProfile(profile)) {
          throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} is not configured with SSO credentials.`, {
            logger: init.logger
          });
        }
        if (profile?.sso_session) {
          const ssoSessions = await sharedIniFileLoader.loadSsoSessionData(init);
          const session = ssoSessions[profile.sso_session];
          const conflictMsg = ` configurations in profile ${profileName} and sso-session ${profile.sso_session}`;
          if (ssoRegion && ssoRegion !== session.sso_region) {
            throw new propertyProvider.CredentialsProviderError(`Conflicting SSO region` + conflictMsg, {
              tryNextLink: false,
              logger: init.logger
            });
          }
          if (ssoStartUrl && ssoStartUrl !== session.sso_start_url) {
            throw new propertyProvider.CredentialsProviderError(`Conflicting SSO start_url` + conflictMsg, {
              tryNextLink: false,
              logger: init.logger
            });
          }
          profile.sso_region = session.sso_region;
          profile.sso_start_url = session.sso_start_url;
        }
        const { sso_start_url, sso_account_id, sso_region, sso_role_name, sso_session } = validateSsoProfile(profile, init.logger);
        return resolveSSOCredentials({
          ssoStartUrl: sso_start_url,
          ssoSession: sso_session,
          ssoAccountId: sso_account_id,
          ssoRegion: sso_region,
          ssoRoleName: sso_role_name,
          ssoClient,
          clientConfig: init.clientConfig,
          parentClientConfig: init.parentClientConfig,
          callerClientConfig: init.callerClientConfig,
          profile: profileName,
          filepath: init.filepath,
          configFilepath: init.configFilepath,
          ignoreCache: init.ignoreCache,
          logger: init.logger
        });
      } else if (!ssoStartUrl || !ssoAccountId || !ssoRegion || !ssoRoleName) {
        throw new propertyProvider.CredentialsProviderError('Incomplete configuration. The fromSSO() argument hash must include "ssoStartUrl", "ssoAccountId", "ssoRegion", "ssoRoleName"', { tryNextLink: false, logger: init.logger });
      } else {
        return resolveSSOCredentials({
          ssoStartUrl,
          ssoSession,
          ssoAccountId,
          ssoRegion,
          ssoRoleName,
          ssoClient,
          clientConfig: init.clientConfig,
          parentClientConfig: init.parentClientConfig,
          callerClientConfig: init.callerClientConfig,
          profile: profileName,
          filepath: init.filepath,
          configFilepath: init.configFilepath,
          ignoreCache: init.ignoreCache,
          logger: init.logger
        });
      }
    }, "fromSSO");
    exports2.fromSSO = fromSSO;
    exports2.isSsoProfile = isSsoProfile;
    exports2.validateSsoProfile = validateSsoProfile;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption17(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "signin",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption17(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var import_util_middleware22, defaultSigninHttpAuthSchemeParametersProvider5, defaultSigninHttpAuthSchemeProvider5, resolveHttpAuthSchemeConfig17;
var init_httpAuthSchemeProvider17 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes7();
    import_util_middleware22 = __toESM(require_dist_cjs6());
    defaultSigninHttpAuthSchemeParametersProvider5 = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, import_util_middleware22.getSmithyContext)(context).operation,
        region: await (0, import_util_middleware22.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultSigninHttpAuthSchemeParametersProvider");
    __name(createAwsAuthSigv4HttpAuthOption17, "createAwsAuthSigv4HttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption17, "createSmithyApiNoAuthHttpAuthOption");
    defaultSigninHttpAuthSchemeProvider5 = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "CreateOAuth2Token": {
          options.push(createSmithyApiNoAuthHttpAuthOption17(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption17(authParameters));
        }
      }
      return options;
    }, "defaultSigninHttpAuthSchemeProvider");
    resolveHttpAuthSchemeConfig17 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveAwsSdkSigV4Config6(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, import_util_middleware22.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/EndpointParameters.js
var resolveClientEndpointParameters17, commonParams17;
var init_EndpointParameters17 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters17 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "signin"
      });
    }, "resolveClientEndpointParameters");
    commonParams17 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/bdd.js
var import_util_endpoints49, m10, a17, b17, c17, d17, e17, f17, g17, h17, i17, j17, k17, l10, _data17, root17, r17, nodes17, bdd17;
var init_bdd17 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/bdd.js"() {
    import_util_endpoints49 = __toESM(require_dist_cjs20());
    m10 = "ref";
    a17 = -1;
    b17 = true;
    c17 = "isSet";
    d17 = "PartitionResult";
    e17 = "booleanEquals";
    f17 = "getAttr";
    g17 = "stringEquals";
    h17 = { [m10]: "Endpoint" };
    i17 = { [m10]: d17 };
    j17 = { fn: f17, argv: [i17, "name"] };
    k17 = {};
    l10 = [{ [m10]: "Region" }];
    _data17 = {
      conditions: [
        [c17, [h17]],
        [c17, l10],
        ["aws.partition", l10, d17],
        [e17, [{ [m10]: "UseFIPS" }, b17]],
        [e17, [{ [m10]: "UseDualStack" }, b17]],
        [e17, [{ fn: f17, argv: [i17, "supportsDualStack"] }, b17]],
        [e17, [{ fn: f17, argv: [i17, "supportsFIPS"] }, b17]],
        [g17, [j17, "aws"]],
        [g17, [j17, "aws-cn"]],
        [g17, [j17, "aws-us-gov"]]
      ],
      results: [
        [a17],
        [a17, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a17, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [h17, k17],
        ["https://{Region}.signin.aws.amazon.com", k17],
        ["https://{Region}.signin.amazonaws.cn", k17],
        ["https://{Region}.signin.amazonaws-us-gov.com", k17],
        ["https://signin-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", k17],
        [a17, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://signin-fips.{Region}.{PartitionResult#dnsSuffix}", k17],
        [a17, "FIPS is enabled but this partition does not support FIPS"],
        ["https://signin.{Region}.{PartitionResult#dualStackDnsSuffix}", k17],
        [a17, "DualStack is enabled but this partition does not support DualStack"],
        ["https://signin.{Region}.{PartitionResult#dnsSuffix}", k17],
        [a17, "Invalid Configuration: Missing Region"]
      ]
    };
    root17 = 2;
    r17 = 1e8;
    nodes17 = new Int32Array([
      -1,
      1,
      -1,
      0,
      15,
      3,
      1,
      4,
      r17 + 14,
      2,
      5,
      r17 + 14,
      3,
      11,
      6,
      4,
      10,
      7,
      7,
      r17 + 4,
      8,
      8,
      r17 + 5,
      9,
      9,
      r17 + 6,
      r17 + 13,
      5,
      r17 + 11,
      r17 + 12,
      4,
      13,
      12,
      6,
      r17 + 9,
      r17 + 10,
      5,
      14,
      r17 + 8,
      6,
      r17 + 7,
      r17 + 8,
      3,
      r17 + 1,
      16,
      4,
      r17 + 2,
      r17 + 3
    ]);
    bdd17 = import_util_endpoints49.BinaryDecisionDiagram.from(nodes17, root17, _data17.conditions, _data17.results);
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/endpointResolver.js
var import_util_endpoints50, import_util_endpoints51, cache17, defaultEndpointResolver17;
var init_endpointResolver17 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/endpointResolver.js"() {
    import_util_endpoints50 = __toESM(require_dist_cjs21());
    import_util_endpoints51 = __toESM(require_dist_cjs20());
    init_bdd17();
    cache17 = new import_util_endpoints51.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    defaultEndpointResolver17 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache17.get(endpointParams, () => (0, import_util_endpoints51.decideEndpoint)(bdd17, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    import_util_endpoints51.customEndpointFunctions.aws = import_util_endpoints50.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/SigninServiceException.js
var import_smithy_client159, SigninServiceException5;
var init_SigninServiceException5 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/SigninServiceException.js"() {
    import_smithy_client159 = __toESM(require_dist_cjs34());
    SigninServiceException5 = class _SigninServiceException extends import_smithy_client159.ServiceException {
      static {
        __name(this, "SigninServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _SigninServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/errors.js
var AccessDeniedException7, InternalServerException7, TooManyRequestsError5, ValidationException5;
var init_errors17 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/errors.js"() {
    init_SigninServiceException5();
    AccessDeniedException7 = class _AccessDeniedException extends SigninServiceException5 {
      static {
        __name(this, "AccessDeniedException");
      }
      name = "AccessDeniedException";
      $fault = "client";
      error;
      constructor(opts) {
        super({
          name: "AccessDeniedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AccessDeniedException.prototype);
        this.error = opts.error;
      }
    };
    InternalServerException7 = class _InternalServerException extends SigninServiceException5 {
      static {
        __name(this, "InternalServerException");
      }
      name = "InternalServerException";
      $fault = "server";
      error;
      constructor(opts) {
        super({
          name: "InternalServerException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _InternalServerException.prototype);
        this.error = opts.error;
      }
    };
    TooManyRequestsError5 = class _TooManyRequestsError extends SigninServiceException5 {
      static {
        __name(this, "TooManyRequestsError");
      }
      name = "TooManyRequestsError";
      $fault = "client";
      error;
      constructor(opts) {
        super({
          name: "TooManyRequestsError",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyRequestsError.prototype);
        this.error = opts.error;
      }
    };
    ValidationException5 = class _ValidationException extends SigninServiceException5 {
      static {
        __name(this, "ValidationException");
      }
      name = "ValidationException";
      $fault = "client";
      error;
      constructor(opts) {
        super({
          name: "ValidationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ValidationException.prototype);
        this.error = opts.error;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/schemas/schemas_0.js
var _ADE7, _AT7, _COAT5, _COATR5, _COATRB5, _COATRBr5, _COATRr5, _ISE7, _RT7, _TMRE11, _VE5, _aKI10, _aT12, _c17, _cI7, _cV7, _co7, _e17, _eI7, _gT7, _h12, _hE17, _iT7, _jN5, _m15, _rT7, _rU7, _s17, _sAK10, _sT10, _se8, _tI5, _tO5, _tT7, n017, _s_registry17, SigninServiceException$5, n0_registry17, AccessDeniedException$7, InternalServerException$7, TooManyRequestsError$5, ValidationException$5, errorTypeRegistries17, RefreshToken7, AccessToken$5, CreateOAuth2TokenRequest$5, CreateOAuth2TokenRequestBody$5, CreateOAuth2TokenResponse$5, CreateOAuth2TokenResponseBody$5, CreateOAuth2Token$5;
var init_schemas_017 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/schemas/schemas_0.js"() {
    init_schema4();
    init_errors17();
    init_SigninServiceException5();
    _ADE7 = "AccessDeniedException";
    _AT7 = "AccessToken";
    _COAT5 = "CreateOAuth2Token";
    _COATR5 = "CreateOAuth2TokenRequest";
    _COATRB5 = "CreateOAuth2TokenRequestBody";
    _COATRBr5 = "CreateOAuth2TokenResponseBody";
    _COATRr5 = "CreateOAuth2TokenResponse";
    _ISE7 = "InternalServerException";
    _RT7 = "RefreshToken";
    _TMRE11 = "TooManyRequestsError";
    _VE5 = "ValidationException";
    _aKI10 = "accessKeyId";
    _aT12 = "accessToken";
    _c17 = "client";
    _cI7 = "clientId";
    _cV7 = "codeVerifier";
    _co7 = "code";
    _e17 = "error";
    _eI7 = "expiresIn";
    _gT7 = "grantType";
    _h12 = "http";
    _hE17 = "httpError";
    _iT7 = "idToken";
    _jN5 = "jsonName";
    _m15 = "message";
    _rT7 = "refreshToken";
    _rU7 = "redirectUri";
    _s17 = "smithy.ts.sdk.synthetic.com.amazonaws.signin";
    _sAK10 = "secretAccessKey";
    _sT10 = "sessionToken";
    _se8 = "server";
    _tI5 = "tokenInput";
    _tO5 = "tokenOutput";
    _tT7 = "tokenType";
    n017 = "com.amazonaws.signin";
    _s_registry17 = TypeRegistry.for(_s17);
    SigninServiceException$5 = [-3, _s17, "SigninServiceException", 0, [], []];
    _s_registry17.registerError(SigninServiceException$5, SigninServiceException5);
    n0_registry17 = TypeRegistry.for(n017);
    AccessDeniedException$7 = [-3, n017, _ADE7, { [_e17]: _c17 }, [_e17, _m15], [0, 0], 2];
    n0_registry17.registerError(AccessDeniedException$7, AccessDeniedException7);
    InternalServerException$7 = [-3, n017, _ISE7, { [_e17]: _se8, [_hE17]: 500 }, [_e17, _m15], [0, 0], 2];
    n0_registry17.registerError(InternalServerException$7, InternalServerException7);
    TooManyRequestsError$5 = [-3, n017, _TMRE11, { [_e17]: _c17, [_hE17]: 429 }, [_e17, _m15], [0, 0], 2];
    n0_registry17.registerError(TooManyRequestsError$5, TooManyRequestsError5);
    ValidationException$5 = [-3, n017, _VE5, { [_e17]: _c17, [_hE17]: 400 }, [_e17, _m15], [0, 0], 2];
    n0_registry17.registerError(ValidationException$5, ValidationException5);
    errorTypeRegistries17 = [_s_registry17, n0_registry17];
    RefreshToken7 = [0, n017, _RT7, 8, 0];
    AccessToken$5 = [
      3,
      n017,
      _AT7,
      8,
      [_aKI10, _sAK10, _sT10],
      [
        [0, { [_jN5]: _aKI10 }],
        [0, { [_jN5]: _sAK10 }],
        [0, { [_jN5]: _sT10 }]
      ],
      3
    ];
    CreateOAuth2TokenRequest$5 = [
      3,
      n017,
      _COATR5,
      0,
      [_tI5],
      [[() => CreateOAuth2TokenRequestBody$5, 16]],
      1
    ];
    CreateOAuth2TokenRequestBody$5 = [
      3,
      n017,
      _COATRB5,
      0,
      [_cI7, _gT7, _co7, _rU7, _cV7, _rT7],
      [
        [0, { [_jN5]: _cI7 }],
        [0, { [_jN5]: _gT7 }],
        0,
        [0, { [_jN5]: _rU7 }],
        [0, { [_jN5]: _cV7 }],
        [() => RefreshToken7, { [_jN5]: _rT7 }]
      ],
      2
    ];
    CreateOAuth2TokenResponse$5 = [
      3,
      n017,
      _COATRr5,
      0,
      [_tO5],
      [[() => CreateOAuth2TokenResponseBody$5, 16]],
      1
    ];
    CreateOAuth2TokenResponseBody$5 = [
      3,
      n017,
      _COATRBr5,
      0,
      [_aT12, _tT7, _eI7, _rT7, _iT7],
      [
        [() => AccessToken$5, { [_jN5]: _aT12 }],
        [0, { [_jN5]: _tT7 }],
        [1, { [_jN5]: _eI7 }],
        [() => RefreshToken7, { [_jN5]: _rT7 }],
        [0, { [_jN5]: _iT7 }]
      ],
      4
    ];
    CreateOAuth2Token$5 = [
      9,
      n017,
      _COAT5,
      { [_h12]: ["POST", "/v1/token", 200] },
      () => CreateOAuth2TokenRequest$5,
      () => CreateOAuth2TokenResponse$5
    ];
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.shared.js
var import_smithy_client160, import_url_parser18, import_util_base6445, import_util_utf835, getRuntimeConfig33;
var init_runtimeConfig_shared17 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.shared.js"() {
    init_httpAuthSchemes7();
    init_protocols10();
    init_dist_es();
    import_smithy_client160 = __toESM(require_dist_cjs34());
    import_url_parser18 = __toESM(require_dist_cjs18());
    import_util_base6445 = __toESM(require_dist_cjs10());
    import_util_utf835 = __toESM(require_dist_cjs9());
    init_httpAuthSchemeProvider17();
    init_endpointResolver17();
    init_schemas_017();
    getRuntimeConfig33 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2023-01-01",
        base64Decoder: config2?.base64Decoder ?? import_util_base6445.fromBase64,
        base64Encoder: config2?.base64Encoder ?? import_util_base6445.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver17,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSigninHttpAuthSchemeProvider5,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer6()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        logger: config2?.logger ?? new import_smithy_client160.NoOpLogger(),
        protocol: config2?.protocol ?? AwsRestJsonProtocol7,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.signin",
          errorTypeRegistries: errorTypeRegistries17,
          version: "2023-01-01",
          serviceTarget: "Signin"
        },
        serviceId: config2?.serviceId ?? "Signin",
        urlParser: config2?.urlParser ?? import_url_parser18.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? import_util_utf835.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? import_util_utf835.toUtf8
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.js
var import_util_user_agent_node17, import_config_resolver34, import_hash_node17, import_middleware_retry33, import_node_config_provider18, import_node_http_handler17, import_smithy_client161, import_util_body_length_node17, import_util_defaults_mode_node17, import_util_retry25, getRuntimeConfig34;
var init_runtimeConfig17 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.js"() {
    init_package6();
    init_client10();
    init_httpAuthSchemes7();
    import_util_user_agent_node17 = __toESM(require_dist_cjs132());
    import_config_resolver34 = __toESM(require_dist_cjs25());
    import_hash_node17 = __toESM(require_dist_cjs44());
    import_middleware_retry33 = __toESM(require_dist_cjs128());
    import_node_config_provider18 = __toESM(require_dist_cjs29());
    import_node_http_handler17 = __toESM(require_dist_cjs13());
    import_smithy_client161 = __toESM(require_dist_cjs34());
    import_util_body_length_node17 = __toESM(require_dist_cjs45());
    import_util_defaults_mode_node17 = __toESM(require_dist_cjs46());
    import_util_retry25 = __toESM(require_dist_cjs22());
    init_runtimeConfig_shared17();
    getRuntimeConfig34 = /* @__PURE__ */ __name((config2) => {
      (0, import_smithy_client161.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, import_util_defaults_mode_node17.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(import_smithy_client161.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig33(config2);
      emitWarningIfUnsupportedVersion23(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, import_node_config_provider18.loadConfig)(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS6, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? import_util_body_length_node17.calculateBodyLength,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, import_util_user_agent_node17.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_default6.version }),
        maxAttempts: config2?.maxAttempts ?? (0, import_node_config_provider18.loadConfig)(import_middleware_retry33.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, import_node_config_provider18.loadConfig)(import_config_resolver34.NODE_REGION_CONFIG_OPTIONS, { ...import_config_resolver34.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: import_node_http_handler17.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, import_node_config_provider18.loadConfig)({
          ...import_middleware_retry33.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || import_util_retry25.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? import_hash_node17.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? import_node_http_handler17.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, import_node_config_provider18.loadConfig)(import_config_resolver34.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, import_node_config_provider18.loadConfig)(import_config_resolver34.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, import_node_config_provider18.loadConfig)(import_util_user_agent_node17.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration17, resolveHttpAuthRuntimeConfig17;
var init_httpAuthExtensionConfiguration17 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration17 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig17 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeExtensions.js
var import_region_config_resolver21, import_protocol_http43, import_smithy_client162, resolveRuntimeExtensions17;
var init_runtimeExtensions17 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeExtensions.js"() {
    import_region_config_resolver21 = __toESM(require_dist_cjs48());
    import_protocol_http43 = __toESM(require_dist_cjs2());
    import_smithy_client162 = __toESM(require_dist_cjs34());
    init_httpAuthExtensionConfiguration17();
    resolveRuntimeExtensions17 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign((0, import_region_config_resolver21.getAwsRegionExtensionConfiguration)(runtimeConfig), (0, import_smithy_client162.getDefaultExtensionConfiguration)(runtimeConfig), (0, import_protocol_http43.getHttpHandlerExtensionConfiguration)(runtimeConfig), getHttpAuthExtensionConfiguration17(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, (0, import_region_config_resolver21.resolveAwsRegionExtensionConfiguration)(extensionConfiguration), (0, import_smithy_client162.resolveDefaultRuntimeConfig)(extensionConfiguration), (0, import_protocol_http43.resolveHttpHandlerRuntimeConfig)(extensionConfiguration), resolveHttpAuthRuntimeConfig17(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/SigninClient.js
var import_middleware_host_header17, import_middleware_logger17, import_middleware_recursion_detection17, import_middleware_user_agent17, import_config_resolver35, import_middleware_content_length17, import_middleware_endpoint42, import_middleware_retry34, import_smithy_client163, SigninClient5;
var init_SigninClient5 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/SigninClient.js"() {
    import_middleware_host_header17 = __toESM(require_dist_cjs3());
    import_middleware_logger17 = __toESM(require_dist_cjs4());
    import_middleware_recursion_detection17 = __toESM(require_dist_cjs5());
    import_middleware_user_agent17 = __toESM(require_dist_cjs127());
    import_config_resolver35 = __toESM(require_dist_cjs25());
    init_dist_es();
    init_schema4();
    import_middleware_content_length17 = __toESM(require_dist_cjs26());
    import_middleware_endpoint42 = __toESM(require_dist_cjs31());
    import_middleware_retry34 = __toESM(require_dist_cjs128());
    import_smithy_client163 = __toESM(require_dist_cjs34());
    init_httpAuthSchemeProvider17();
    init_EndpointParameters17();
    init_runtimeConfig17();
    init_runtimeExtensions17();
    SigninClient5 = class extends import_smithy_client163.Client {
      static {
        __name(this, "SigninClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig34(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters17(_config_0);
        const _config_2 = (0, import_middleware_user_agent17.resolveUserAgentConfig)(_config_1);
        const _config_3 = (0, import_middleware_retry34.resolveRetryConfig)(_config_2);
        const _config_4 = (0, import_config_resolver35.resolveRegionConfig)(_config_3);
        const _config_5 = (0, import_middleware_host_header17.resolveHostHeaderConfig)(_config_4);
        const _config_6 = (0, import_middleware_endpoint42.resolveEndpointConfig)(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig17(_config_6);
        const _config_8 = resolveRuntimeExtensions17(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin(this.config));
        this.middlewareStack.use((0, import_middleware_user_agent17.getUserAgentPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_retry34.getRetryPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_content_length17.getContentLengthPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_host_header17.getHostHeaderPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_logger17.getLoggerPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_recursion_detection17.getRecursionDetectionPlugin)(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: defaultSigninHttpAuthSchemeParametersProvider5,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/CreateOAuth2TokenCommand.js
var import_middleware_endpoint43, import_smithy_client164, CreateOAuth2TokenCommand5;
var init_CreateOAuth2TokenCommand5 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/CreateOAuth2TokenCommand.js"() {
    import_middleware_endpoint43 = __toESM(require_dist_cjs31());
    import_smithy_client164 = __toESM(require_dist_cjs34());
    init_EndpointParameters17();
    init_schemas_017();
    CreateOAuth2TokenCommand5 = class extends import_smithy_client164.Command.classBuilder().ep(commonParams17).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint43.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("Signin", "CreateOAuth2Token", {}).n("SigninClient", "CreateOAuth2TokenCommand").sc(CreateOAuth2Token$5).build() {
      static {
        __name(this, "CreateOAuth2TokenCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/Signin.js
var import_smithy_client165, commands17, Signin5;
var init_Signin5 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/Signin.js"() {
    import_smithy_client165 = __toESM(require_dist_cjs34());
    init_CreateOAuth2TokenCommand5();
    init_SigninClient5();
    commands17 = {
      CreateOAuth2TokenCommand: CreateOAuth2TokenCommand5
    };
    Signin5 = class extends SigninClient5 {
      static {
        __name(this, "Signin");
      }
    };
    (0, import_smithy_client165.createAggregatedClient)(commands17, Signin5);
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/index.js
var init_commands18 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/index.js"() {
    init_CreateOAuth2TokenCommand5();
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/enums.js
var OAuth2ErrorCode5;
var init_enums7 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/enums.js"() {
    OAuth2ErrorCode5 = {
      AUTHCODE_EXPIRED: "AUTHCODE_EXPIRED",
      INSUFFICIENT_PERMISSIONS: "INSUFFICIENT_PERMISSIONS",
      INVALID_REQUEST: "INVALID_REQUEST",
      SERVER_ERROR: "server_error",
      TOKEN_EXPIRED: "TOKEN_EXPIRED",
      USER_CREDENTIALS_CHANGED: "USER_CREDENTIALS_CHANGED"
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/models_0.js
var init_models_017 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/index.js
var signin_exports5 = {};
__export(signin_exports5, {
  $Command: () => import_smithy_client164.Command,
  AccessDeniedException: () => AccessDeniedException7,
  AccessDeniedException$: () => AccessDeniedException$7,
  AccessToken$: () => AccessToken$5,
  CreateOAuth2Token$: () => CreateOAuth2Token$5,
  CreateOAuth2TokenCommand: () => CreateOAuth2TokenCommand5,
  CreateOAuth2TokenRequest$: () => CreateOAuth2TokenRequest$5,
  CreateOAuth2TokenRequestBody$: () => CreateOAuth2TokenRequestBody$5,
  CreateOAuth2TokenResponse$: () => CreateOAuth2TokenResponse$5,
  CreateOAuth2TokenResponseBody$: () => CreateOAuth2TokenResponseBody$5,
  InternalServerException: () => InternalServerException7,
  InternalServerException$: () => InternalServerException$7,
  OAuth2ErrorCode: () => OAuth2ErrorCode5,
  Signin: () => Signin5,
  SigninClient: () => SigninClient5,
  SigninServiceException: () => SigninServiceException5,
  SigninServiceException$: () => SigninServiceException$5,
  TooManyRequestsError: () => TooManyRequestsError5,
  TooManyRequestsError$: () => TooManyRequestsError$5,
  ValidationException: () => ValidationException5,
  ValidationException$: () => ValidationException$5,
  __Client: () => import_smithy_client163.Client,
  errorTypeRegistries: () => errorTypeRegistries17
});
var init_signin5 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/index.js"() {
    init_SigninClient5();
    init_Signin5();
    init_commands18();
    init_schemas_017();
    init_enums7();
    init_errors17();
    init_models_017();
    init_SigninServiceException5();
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-login/dist-cjs/index.js
var require_dist_cjs134 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-login/dist-cjs/index.js"(exports2) {
    "use strict";
    var client = (init_client10(), __toCommonJS(client_exports8));
    var propertyProvider = require_dist_cjs27();
    var sharedIniFileLoader = require_dist_cjs28();
    var protocolHttp = require_dist_cjs2();
    var node_crypto = require("node:crypto");
    var node_fs = require("node:fs");
    var node_os = require("node:os");
    var node_path = require("node:path");
    var LoginCredentialsFetcher = class _LoginCredentialsFetcher {
      static {
        __name(this, "LoginCredentialsFetcher");
      }
      profileData;
      init;
      callerClientConfig;
      static REFRESH_THRESHOLD = 5 * 60 * 1e3;
      constructor(profileData, init, callerClientConfig) {
        this.profileData = profileData;
        this.init = init;
        this.callerClientConfig = callerClientConfig;
      }
      async loadCredentials() {
        const token = await this.loadToken();
        if (!token) {
          throw new propertyProvider.CredentialsProviderError(`Failed to load a token for session ${this.loginSession}, please re-authenticate using aws login`, { tryNextLink: false, logger: this.logger });
        }
        const accessToken = token.accessToken;
        const now = Date.now();
        const expiryTime = new Date(accessToken.expiresAt).getTime();
        const timeUntilExpiry = expiryTime - now;
        if (timeUntilExpiry <= _LoginCredentialsFetcher.REFRESH_THRESHOLD) {
          return this.refresh(token);
        }
        return {
          accessKeyId: accessToken.accessKeyId,
          secretAccessKey: accessToken.secretAccessKey,
          sessionToken: accessToken.sessionToken,
          accountId: accessToken.accountId,
          expiration: new Date(accessToken.expiresAt)
        };
      }
      get logger() {
        return this.init?.logger;
      }
      get loginSession() {
        return this.profileData.login_session;
      }
      async refresh(token) {
        const { SigninClient: SigninClient10, CreateOAuth2TokenCommand: CreateOAuth2TokenCommand10 } = await Promise.resolve().then(() => (init_signin5(), signin_exports5));
        const { logger: logger5, userAgentAppId } = this.callerClientConfig ?? {};
        const isH210 = /* @__PURE__ */ __name((requestHandler2) => {
          return requestHandler2?.metadata?.handlerProtocol === "h2";
        }, "isH2");
        const requestHandler = isH210(this.callerClientConfig?.requestHandler) ? void 0 : this.callerClientConfig?.requestHandler;
        const region = this.profileData.region ?? await this.callerClientConfig?.region?.() ?? process.env.AWS_REGION;
        const client2 = new SigninClient10({
          credentials: {
            accessKeyId: "",
            secretAccessKey: ""
          },
          region,
          requestHandler,
          logger: logger5,
          userAgentAppId,
          ...this.init?.clientConfig
        });
        this.createDPoPInterceptor(client2.middlewareStack);
        const commandInput = {
          tokenInput: {
            clientId: token.clientId,
            refreshToken: token.refreshToken,
            grantType: "refresh_token"
          }
        };
        try {
          const response = await client2.send(new CreateOAuth2TokenCommand10(commandInput));
          const { accessKeyId, secretAccessKey, sessionToken } = response.tokenOutput?.accessToken ?? {};
          const { refreshToken, expiresIn } = response.tokenOutput ?? {};
          if (!accessKeyId || !secretAccessKey || !sessionToken || !refreshToken) {
            throw new propertyProvider.CredentialsProviderError("Token refresh response missing required fields", {
              logger: this.logger,
              tryNextLink: false
            });
          }
          const expiresInMs = (expiresIn ?? 900) * 1e3;
          const expiration = new Date(Date.now() + expiresInMs);
          const updatedToken = {
            ...token,
            accessToken: {
              ...token.accessToken,
              accessKeyId,
              secretAccessKey,
              sessionToken,
              expiresAt: expiration.toISOString()
            },
            refreshToken
          };
          await this.saveToken(updatedToken);
          const newAccessToken = updatedToken.accessToken;
          return {
            accessKeyId: newAccessToken.accessKeyId,
            secretAccessKey: newAccessToken.secretAccessKey,
            sessionToken: newAccessToken.sessionToken,
            accountId: newAccessToken.accountId,
            expiration
          };
        } catch (error4) {
          if (error4.name === "AccessDeniedException") {
            const errorType = error4.error;
            let message2;
            switch (errorType) {
              case "TOKEN_EXPIRED":
                message2 = "Your session has expired. Please reauthenticate.";
                break;
              case "USER_CREDENTIALS_CHANGED":
                message2 = "Unable to refresh credentials because of a change in your password. Please reauthenticate with your new password.";
                break;
              case "INSUFFICIENT_PERMISSIONS":
                message2 = "Unable to refresh credentials due to insufficient permissions. You may be missing permission for the 'CreateOAuth2Token' action.";
                break;
              default:
                message2 = `Failed to refresh token: ${String(error4)}. Please re-authenticate using \`aws login\``;
            }
            throw new propertyProvider.CredentialsProviderError(message2, { logger: this.logger, tryNextLink: false });
          }
          throw new propertyProvider.CredentialsProviderError(`Failed to refresh token: ${String(error4)}. Please re-authenticate using aws login`, { logger: this.logger });
        }
      }
      async loadToken() {
        const tokenFilePath = this.getTokenFilePath();
        try {
          let tokenData;
          try {
            tokenData = await sharedIniFileLoader.readFile(tokenFilePath, { ignoreCache: this.init?.ignoreCache });
          } catch {
            tokenData = await node_fs.promises.readFile(tokenFilePath, "utf8");
          }
          const token = JSON.parse(tokenData);
          const missingFields = ["accessToken", "clientId", "refreshToken", "dpopKey"].filter((k32) => !token[k32]);
          if (!token.accessToken?.accountId) {
            missingFields.push("accountId");
          }
          if (missingFields.length > 0) {
            throw new propertyProvider.CredentialsProviderError(`Token validation failed, missing fields: ${missingFields.join(", ")}`, {
              logger: this.logger,
              tryNextLink: false
            });
          }
          return token;
        } catch (error4) {
          throw new propertyProvider.CredentialsProviderError(`Failed to load token from ${tokenFilePath}: ${String(error4)}`, {
            logger: this.logger,
            tryNextLink: false
          });
        }
      }
      async saveToken(token) {
        const tokenFilePath = this.getTokenFilePath();
        const directory = node_path.dirname(tokenFilePath);
        try {
          await node_fs.promises.mkdir(directory, { recursive: true });
        } catch (error4) {
        }
        await node_fs.promises.writeFile(tokenFilePath, JSON.stringify(token, null, 2), "utf8");
      }
      getTokenFilePath() {
        const directory = process.env.AWS_LOGIN_CACHE_DIRECTORY ?? node_path.join(node_os.homedir(), ".aws", "login", "cache");
        const loginSessionBytes = Buffer.from(this.loginSession, "utf8");
        const loginSessionSha256 = node_crypto.createHash("sha256").update(loginSessionBytes).digest("hex");
        return node_path.join(directory, `${loginSessionSha256}.json`);
      }
      derToRawSignature(derSignature) {
        let offset = 2;
        if (derSignature[offset] !== 2) {
          throw new Error("Invalid DER signature");
        }
        offset++;
        const rLength = derSignature[offset++];
        let r32 = derSignature.subarray(offset, offset + rLength);
        offset += rLength;
        if (derSignature[offset] !== 2) {
          throw new Error("Invalid DER signature");
        }
        offset++;
        const sLength = derSignature[offset++];
        let s = derSignature.subarray(offset, offset + sLength);
        r32 = r32[0] === 0 ? r32.subarray(1) : r32;
        s = s[0] === 0 ? s.subarray(1) : s;
        const rPadded = Buffer.concat([Buffer.alloc(32 - r32.length), r32]);
        const sPadded = Buffer.concat([Buffer.alloc(32 - s.length), s]);
        return Buffer.concat([rPadded, sPadded]);
      }
      createDPoPInterceptor(middlewareStack) {
        middlewareStack.add((next) => async (args) => {
          if (protocolHttp.HttpRequest.isInstance(args.request)) {
            const request4 = args.request;
            const actualEndpoint = `${request4.protocol}//${request4.hostname}${request4.port ? `:${request4.port}` : ""}${request4.path}`;
            const dpop = await this.generateDpop(request4.method, actualEndpoint);
            request4.headers = {
              ...request4.headers,
              DPoP: dpop
            };
          }
          return next(args);
        }, {
          step: "finalizeRequest",
          name: "dpopInterceptor",
          override: true
        });
      }
      async generateDpop(method = "POST", endpoint) {
        const token = await this.loadToken();
        try {
          const privateKey = node_crypto.createPrivateKey({
            key: token.dpopKey,
            format: "pem",
            type: "sec1"
          });
          const publicKey = node_crypto.createPublicKey(privateKey);
          const publicDer = publicKey.export({ format: "der", type: "spki" });
          let pointStart = -1;
          for (let i32 = 0; i32 < publicDer.length; i32++) {
            if (publicDer[i32] === 4) {
              pointStart = i32;
              break;
            }
          }
          const x = publicDer.slice(pointStart + 1, pointStart + 33);
          const y = publicDer.slice(pointStart + 33, pointStart + 65);
          const header = {
            alg: "ES256",
            typ: "dpop+jwt",
            jwk: {
              kty: "EC",
              crv: "P-256",
              x: x.toString("base64url"),
              y: y.toString("base64url")
            }
          };
          const payload3 = {
            jti: crypto.randomUUID(),
            htm: method,
            htu: endpoint,
            iat: Math.floor(Date.now() / 1e3)
          };
          const headerB64 = Buffer.from(JSON.stringify(header)).toString("base64url");
          const payloadB64 = Buffer.from(JSON.stringify(payload3)).toString("base64url");
          const message2 = `${headerB64}.${payloadB64}`;
          const asn1Signature = node_crypto.sign("sha256", Buffer.from(message2), privateKey);
          const rawSignature = this.derToRawSignature(asn1Signature);
          const signatureB64 = rawSignature.toString("base64url");
          return `${message2}.${signatureB64}`;
        } catch (error4) {
          throw new propertyProvider.CredentialsProviderError(`Failed to generate Dpop proof: ${error4 instanceof Error ? error4.message : String(error4)}`, { logger: this.logger, tryNextLink: false });
        }
      }
    };
    var fromLoginCredentials = /* @__PURE__ */ __name((init) => async ({ callerClientConfig } = {}) => {
      init?.logger?.debug?.("@aws-sdk/credential-providers - fromLoginCredentials");
      const profiles = await sharedIniFileLoader.parseKnownFiles(init || {});
      const profileName = sharedIniFileLoader.getProfileName({
        profile: init?.profile ?? callerClientConfig?.profile
      });
      const profile = profiles[profileName];
      if (!profile?.login_session) {
        throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} does not contain login_session.`, {
          tryNextLink: true,
          logger: init?.logger
        });
      }
      const fetcher = new LoginCredentialsFetcher(profile, init, callerClientConfig);
      const credentials = await fetcher.loadCredentials();
      return client.setCredentialFeature(credentials, "CREDENTIALS_LOGIN", "AD");
    }, "fromLoginCredentials");
    exports2.fromLoginCredentials = fromLoginCredentials;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/bdd.js
var import_util_endpoints52, q5, a18, b18, c18, d18, e18, f18, g18, h18, i18, j18, k18, l11, m11, n5, o5, p5, _data18, root18, r18, nodes18, bdd18;
var init_bdd18 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/bdd.js"() {
    import_util_endpoints52 = __toESM(require_dist_cjs20());
    q5 = "ref";
    a18 = -1;
    b18 = true;
    c18 = "isSet";
    d18 = "PartitionResult";
    e18 = "booleanEquals";
    f18 = "stringEquals";
    g18 = "getAttr";
    h18 = "us-east-1";
    i18 = "sigv4";
    j18 = "sts";
    k18 = "https://sts.{Region}.{PartitionResult#dnsSuffix}";
    l11 = { [q5]: "Endpoint" };
    m11 = { [q5]: "Region" };
    n5 = { [q5]: d18 };
    o5 = {};
    p5 = [m11];
    _data18 = {
      conditions: [
        [c18, [l11]],
        [c18, p5],
        ["aws.partition", p5, d18],
        [e18, [{ [q5]: "UseFIPS" }, b18]],
        [e18, [{ [q5]: "UseDualStack" }, b18]],
        [f18, [m11, "aws-global"]],
        [e18, [{ [q5]: "UseGlobalEndpoint" }, b18]],
        [f18, [m11, "eu-central-1"]],
        [e18, [{ fn: g18, argv: [n5, "supportsDualStack"] }, b18]],
        [e18, [{ fn: g18, argv: [n5, "supportsFIPS"] }, b18]],
        [f18, [m11, "ap-south-1"]],
        [f18, [m11, "eu-north-1"]],
        [f18, [m11, "eu-west-1"]],
        [f18, [m11, "eu-west-2"]],
        [f18, [m11, "eu-west-3"]],
        [f18, [m11, "sa-east-1"]],
        [f18, [m11, h18]],
        [f18, [m11, "us-east-2"]],
        [f18, [m11, "us-west-2"]],
        [f18, [m11, "us-west-1"]],
        [f18, [m11, "ca-central-1"]],
        [f18, [m11, "ap-southeast-1"]],
        [f18, [m11, "ap-northeast-1"]],
        [f18, [m11, "ap-southeast-2"]],
        [f18, [{ fn: g18, argv: [n5, "name"] }, "aws-us-gov"]]
      ],
      results: [
        [a18],
        ["https://sts.amazonaws.com", { authSchemes: [{ name: i18, signingName: j18, signingRegion: h18 }] }],
        [k18, { authSchemes: [{ name: i18, signingName: j18, signingRegion: "{Region}" }] }],
        [a18, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a18, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [l11, o5],
        ["https://sts-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", o5],
        [a18, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://sts.{Region}.amazonaws.com", o5],
        ["https://sts-fips.{Region}.{PartitionResult#dnsSuffix}", o5],
        [a18, "FIPS is enabled but this partition does not support FIPS"],
        ["https://sts.{Region}.{PartitionResult#dualStackDnsSuffix}", o5],
        [a18, "DualStack is enabled but this partition does not support DualStack"],
        [k18, o5],
        [a18, "Invalid Configuration: Missing Region"]
      ]
    };
    root18 = 2;
    r18 = 1e8;
    nodes18 = new Int32Array([
      -1,
      1,
      -1,
      0,
      30,
      3,
      1,
      4,
      r18 + 14,
      2,
      5,
      r18 + 14,
      3,
      25,
      6,
      4,
      24,
      7,
      5,
      r18 + 1,
      8,
      6,
      9,
      r18 + 13,
      7,
      r18 + 1,
      10,
      10,
      r18 + 1,
      11,
      11,
      r18 + 1,
      12,
      12,
      r18 + 1,
      13,
      13,
      r18 + 1,
      14,
      14,
      r18 + 1,
      15,
      15,
      r18 + 1,
      16,
      16,
      r18 + 1,
      17,
      17,
      r18 + 1,
      18,
      18,
      r18 + 1,
      19,
      19,
      r18 + 1,
      20,
      20,
      r18 + 1,
      21,
      21,
      r18 + 1,
      22,
      22,
      r18 + 1,
      23,
      23,
      r18 + 1,
      r18 + 2,
      8,
      r18 + 11,
      r18 + 12,
      4,
      28,
      26,
      9,
      27,
      r18 + 10,
      24,
      r18 + 8,
      r18 + 9,
      8,
      29,
      r18 + 7,
      9,
      r18 + 6,
      r18 + 7,
      3,
      r18 + 3,
      31,
      4,
      r18 + 4,
      r18 + 5
    ]);
    bdd18 = import_util_endpoints52.BinaryDecisionDiagram.from(nodes18, root18, _data18.conditions, _data18.results);
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/endpointResolver.js
var import_util_endpoints53, import_util_endpoints54, cache18, defaultEndpointResolver18;
var init_endpointResolver18 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/endpointResolver.js"() {
    import_util_endpoints53 = __toESM(require_dist_cjs21());
    import_util_endpoints54 = __toESM(require_dist_cjs20());
    init_bdd18();
    cache18 = new import_util_endpoints54.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS", "UseGlobalEndpoint"]
    });
    defaultEndpointResolver18 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache18.get(endpointParams, () => (0, import_util_endpoints54.decideEndpoint)(bdd18, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    import_util_endpoints54.customEndpointFunctions.aws = import_util_endpoints53.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption18(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "sts",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createAwsAuthSigv4aHttpAuthOption5(authParameters) {
  return {
    schemeId: "aws.auth#sigv4a",
    signingProperties: {
      name: "sts",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption18(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var import_signature_v4_multi_region9, import_middleware_endpoint44, import_util_middleware23, createEndpointRuleSetHttpAuthSchemeParametersProvider5, _defaultSTSHttpAuthSchemeParametersProvider5, defaultSTSHttpAuthSchemeParametersProvider5, createEndpointRuleSetHttpAuthSchemeProvider5, _defaultSTSHttpAuthSchemeProvider5, defaultSTSHttpAuthSchemeProvider5, resolveStsAuthConfig5, resolveHttpAuthSchemeConfig18;
var init_httpAuthSchemeProvider18 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes7();
    import_signature_v4_multi_region9 = __toESM(require_dist_cjs55());
    import_middleware_endpoint44 = __toESM(require_dist_cjs31());
    import_util_middleware23 = __toESM(require_dist_cjs6());
    init_endpointResolver18();
    init_STSClient5();
    createEndpointRuleSetHttpAuthSchemeParametersProvider5 = /* @__PURE__ */ __name((defaultHttpAuthSchemeParametersProvider) => async (config2, context, input) => {
      if (!input) {
        throw new Error("Could not find `input` for `defaultEndpointRuleSetHttpAuthSchemeParametersProvider`");
      }
      const defaultParameters = await defaultHttpAuthSchemeParametersProvider(config2, context, input);
      const instructionsFn = (0, import_util_middleware23.getSmithyContext)(context)?.commandInstance?.constructor?.getEndpointParameterInstructions;
      if (!instructionsFn) {
        throw new Error(`getEndpointParameterInstructions() is not defined on '${context.commandName}'`);
      }
      const endpointParameters = await (0, import_middleware_endpoint44.resolveParams)(input, { getEndpointParameterInstructions: instructionsFn }, config2);
      return Object.assign(defaultParameters, endpointParameters);
    }, "createEndpointRuleSetHttpAuthSchemeParametersProvider");
    _defaultSTSHttpAuthSchemeParametersProvider5 = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, import_util_middleware23.getSmithyContext)(context).operation,
        region: await (0, import_util_middleware23.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "_defaultSTSHttpAuthSchemeParametersProvider");
    defaultSTSHttpAuthSchemeParametersProvider5 = createEndpointRuleSetHttpAuthSchemeParametersProvider5(_defaultSTSHttpAuthSchemeParametersProvider5);
    __name(createAwsAuthSigv4HttpAuthOption18, "createAwsAuthSigv4HttpAuthOption");
    __name(createAwsAuthSigv4aHttpAuthOption5, "createAwsAuthSigv4aHttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption18, "createSmithyApiNoAuthHttpAuthOption");
    createEndpointRuleSetHttpAuthSchemeProvider5 = /* @__PURE__ */ __name((defaultEndpointResolver32, defaultHttpAuthSchemeResolver, createHttpAuthOptionFunctions) => {
      const endpointRuleSetHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
        const endpoint = defaultEndpointResolver32(authParameters);
        const authSchemes = endpoint.properties?.authSchemes;
        if (!authSchemes) {
          return defaultHttpAuthSchemeResolver(authParameters);
        }
        const options = [];
        for (const scheme of authSchemes) {
          const { name: resolvedName, properties = {}, ...rest } = scheme;
          const name = resolvedName.toLowerCase();
          if (resolvedName !== name) {
            console.warn(`HttpAuthScheme has been normalized with lowercasing: '${resolvedName}' to '${name}'`);
          }
          let schemeId;
          if (name === "sigv4a") {
            schemeId = "aws.auth#sigv4a";
            const sigv4Present = authSchemes.find((s) => {
              const name2 = s.name.toLowerCase();
              return name2 !== "sigv4a" && name2.startsWith("sigv4");
            });
            if (import_signature_v4_multi_region9.SignatureV4MultiRegion.sigv4aDependency() === "none" && sigv4Present) {
              continue;
            }
          } else if (name.startsWith("sigv4")) {
            schemeId = "aws.auth#sigv4";
          } else {
            throw new Error(`Unknown HttpAuthScheme found in '@smithy.rules#endpointRuleSet': '${name}'`);
          }
          const createOption = createHttpAuthOptionFunctions[schemeId];
          if (!createOption) {
            throw new Error(`Could not find HttpAuthOption create function for '${schemeId}'`);
          }
          const option = createOption(authParameters);
          option.schemeId = schemeId;
          option.signingProperties = { ...option.signingProperties || {}, ...rest, ...properties };
          options.push(option);
        }
        return options;
      }, "endpointRuleSetHttpAuthSchemeProvider");
      return endpointRuleSetHttpAuthSchemeProvider;
    }, "createEndpointRuleSetHttpAuthSchemeProvider");
    _defaultSTSHttpAuthSchemeProvider5 = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "AssumeRoleWithWebIdentity": {
          options.push(createSmithyApiNoAuthHttpAuthOption18(authParameters));
          options.push(createAwsAuthSigv4aHttpAuthOption5(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption18(authParameters));
          options.push(createAwsAuthSigv4aHttpAuthOption5(authParameters));
        }
      }
      return options;
    }, "_defaultSTSHttpAuthSchemeProvider");
    defaultSTSHttpAuthSchemeProvider5 = createEndpointRuleSetHttpAuthSchemeProvider5(defaultEndpointResolver18, _defaultSTSHttpAuthSchemeProvider5, {
      "aws.auth#sigv4": createAwsAuthSigv4HttpAuthOption18,
      "aws.auth#sigv4a": createAwsAuthSigv4aHttpAuthOption5,
      "smithy.api#noAuth": createSmithyApiNoAuthHttpAuthOption18
    });
    resolveStsAuthConfig5 = /* @__PURE__ */ __name((input) => Object.assign(input, {
      stsClientCtor: STSClient6
    }), "resolveStsAuthConfig");
    resolveHttpAuthSchemeConfig18 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveStsAuthConfig5(config2);
      const config_1 = resolveAwsSdkSigV4Config6(config_0);
      const config_2 = resolveAwsSdkSigV4AConfig6(config_1);
      return Object.assign(config_2, {
        authSchemePreference: (0, import_util_middleware23.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/EndpointParameters.js
var resolveClientEndpointParameters18, commonParams18;
var init_EndpointParameters18 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters18 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        useGlobalEndpoint: options.useGlobalEndpoint ?? false,
        defaultSigningName: "sts"
      });
    }, "resolveClientEndpointParameters");
    commonParams18 = {
      UseGlobalEndpoint: { type: "builtInParams", name: "useGlobalEndpoint" },
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/STSServiceException.js
var import_smithy_client166, STSServiceException5;
var init_STSServiceException5 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/STSServiceException.js"() {
    import_smithy_client166 = __toESM(require_dist_cjs34());
    STSServiceException5 = class _STSServiceException extends import_smithy_client166.ServiceException {
      static {
        __name(this, "STSServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _STSServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/errors.js
var ExpiredTokenException7, MalformedPolicyDocumentException5, PackedPolicyTooLargeException5, RegionDisabledException5, IDPRejectedClaimException5, InvalidIdentityTokenException5, IDPCommunicationErrorException5;
var init_errors18 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/errors.js"() {
    init_STSServiceException5();
    ExpiredTokenException7 = class _ExpiredTokenException extends STSServiceException5 {
      static {
        __name(this, "ExpiredTokenException");
      }
      name = "ExpiredTokenException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ExpiredTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ExpiredTokenException.prototype);
      }
    };
    MalformedPolicyDocumentException5 = class _MalformedPolicyDocumentException extends STSServiceException5 {
      static {
        __name(this, "MalformedPolicyDocumentException");
      }
      name = "MalformedPolicyDocumentException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "MalformedPolicyDocumentException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _MalformedPolicyDocumentException.prototype);
      }
    };
    PackedPolicyTooLargeException5 = class _PackedPolicyTooLargeException extends STSServiceException5 {
      static {
        __name(this, "PackedPolicyTooLargeException");
      }
      name = "PackedPolicyTooLargeException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "PackedPolicyTooLargeException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _PackedPolicyTooLargeException.prototype);
      }
    };
    RegionDisabledException5 = class _RegionDisabledException extends STSServiceException5 {
      static {
        __name(this, "RegionDisabledException");
      }
      name = "RegionDisabledException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "RegionDisabledException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _RegionDisabledException.prototype);
      }
    };
    IDPRejectedClaimException5 = class _IDPRejectedClaimException extends STSServiceException5 {
      static {
        __name(this, "IDPRejectedClaimException");
      }
      name = "IDPRejectedClaimException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "IDPRejectedClaimException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _IDPRejectedClaimException.prototype);
      }
    };
    InvalidIdentityTokenException5 = class _InvalidIdentityTokenException extends STSServiceException5 {
      static {
        __name(this, "InvalidIdentityTokenException");
      }
      name = "InvalidIdentityTokenException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidIdentityTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidIdentityTokenException.prototype);
      }
    };
    IDPCommunicationErrorException5 = class _IDPCommunicationErrorException extends STSServiceException5 {
      static {
        __name(this, "IDPCommunicationErrorException");
      }
      name = "IDPCommunicationErrorException";
      $fault = "client";
      $retryable = {};
      constructor(opts) {
        super({
          name: "IDPCommunicationErrorException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _IDPCommunicationErrorException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/schemas/schemas_0.js
var _A5, _AKI6, _AR5, _ARI5, _ARR5, _ARRs5, _ARU5, _ARWWI5, _ARWWIR5, _ARWWIRs5, _Au5, _C6, _CA5, _DS5, _E6, _EI5, _ETE7, _IDPCEE5, _IDPRCE5, _IITE5, _K5, _MPDE5, _P5, _PA5, _PAr5, _PC5, _PCLT5, _PCr5, _PDT5, _PI5, _PPS5, _PPTLE5, _Pr5, _RA5, _RDE5, _RSN5, _SAK5, _SFWIT5, _SI5, _SN5, _ST6, _T5, _TC5, _TTK5, _Ta5, _V5, _WIT5, _a5, _aKST5, _aQE5, _c18, _cTT5, _e18, _hE18, _m16, _pDLT5, _s18, _tLT5, n018, _s_registry18, STSServiceException$5, n0_registry18, ExpiredTokenException$7, IDPCommunicationErrorException$5, IDPRejectedClaimException$5, InvalidIdentityTokenException$5, MalformedPolicyDocumentException$5, PackedPolicyTooLargeException$5, RegionDisabledException$5, errorTypeRegistries18, accessKeySecretType5, clientTokenType5, AssumedRoleUser$5, AssumeRoleRequest$5, AssumeRoleResponse$5, AssumeRoleWithWebIdentityRequest$5, AssumeRoleWithWebIdentityResponse$5, Credentials$6, PolicyDescriptorType$5, ProvidedContext$5, Tag$5, policyDescriptorListType5, ProvidedContextsListType5, tagKeyListType5, tagListType5, AssumeRole$5, AssumeRoleWithWebIdentity$5;
var init_schemas_018 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/schemas/schemas_0.js"() {
    init_schema4();
    init_errors18();
    init_STSServiceException5();
    _A5 = "Arn";
    _AKI6 = "AccessKeyId";
    _AR5 = "AssumeRole";
    _ARI5 = "AssumedRoleId";
    _ARR5 = "AssumeRoleRequest";
    _ARRs5 = "AssumeRoleResponse";
    _ARU5 = "AssumedRoleUser";
    _ARWWI5 = "AssumeRoleWithWebIdentity";
    _ARWWIR5 = "AssumeRoleWithWebIdentityRequest";
    _ARWWIRs5 = "AssumeRoleWithWebIdentityResponse";
    _Au5 = "Audience";
    _C6 = "Credentials";
    _CA5 = "ContextAssertion";
    _DS5 = "DurationSeconds";
    _E6 = "Expiration";
    _EI5 = "ExternalId";
    _ETE7 = "ExpiredTokenException";
    _IDPCEE5 = "IDPCommunicationErrorException";
    _IDPRCE5 = "IDPRejectedClaimException";
    _IITE5 = "InvalidIdentityTokenException";
    _K5 = "Key";
    _MPDE5 = "MalformedPolicyDocumentException";
    _P5 = "Policy";
    _PA5 = "PolicyArns";
    _PAr5 = "ProviderArn";
    _PC5 = "ProvidedContexts";
    _PCLT5 = "ProvidedContextsListType";
    _PCr5 = "ProvidedContext";
    _PDT5 = "PolicyDescriptorType";
    _PI5 = "ProviderId";
    _PPS5 = "PackedPolicySize";
    _PPTLE5 = "PackedPolicyTooLargeException";
    _Pr5 = "Provider";
    _RA5 = "RoleArn";
    _RDE5 = "RegionDisabledException";
    _RSN5 = "RoleSessionName";
    _SAK5 = "SecretAccessKey";
    _SFWIT5 = "SubjectFromWebIdentityToken";
    _SI5 = "SourceIdentity";
    _SN5 = "SerialNumber";
    _ST6 = "SessionToken";
    _T5 = "Tags";
    _TC5 = "TokenCode";
    _TTK5 = "TransitiveTagKeys";
    _Ta5 = "Tag";
    _V5 = "Value";
    _WIT5 = "WebIdentityToken";
    _a5 = "arn";
    _aKST5 = "accessKeySecretType";
    _aQE5 = "awsQueryError";
    _c18 = "client";
    _cTT5 = "clientTokenType";
    _e18 = "error";
    _hE18 = "httpError";
    _m16 = "message";
    _pDLT5 = "policyDescriptorListType";
    _s18 = "smithy.ts.sdk.synthetic.com.amazonaws.sts";
    _tLT5 = "tagListType";
    n018 = "com.amazonaws.sts";
    _s_registry18 = TypeRegistry.for(_s18);
    STSServiceException$5 = [-3, _s18, "STSServiceException", 0, [], []];
    _s_registry18.registerError(STSServiceException$5, STSServiceException5);
    n0_registry18 = TypeRegistry.for(n018);
    ExpiredTokenException$7 = [
      -3,
      n018,
      _ETE7,
      { [_aQE5]: [`ExpiredTokenException`, 400], [_e18]: _c18, [_hE18]: 400 },
      [_m16],
      [0]
    ];
    n0_registry18.registerError(ExpiredTokenException$7, ExpiredTokenException7);
    IDPCommunicationErrorException$5 = [
      -3,
      n018,
      _IDPCEE5,
      { [_aQE5]: [`IDPCommunicationError`, 400], [_e18]: _c18, [_hE18]: 400 },
      [_m16],
      [0]
    ];
    n0_registry18.registerError(IDPCommunicationErrorException$5, IDPCommunicationErrorException5);
    IDPRejectedClaimException$5 = [
      -3,
      n018,
      _IDPRCE5,
      { [_aQE5]: [`IDPRejectedClaim`, 403], [_e18]: _c18, [_hE18]: 403 },
      [_m16],
      [0]
    ];
    n0_registry18.registerError(IDPRejectedClaimException$5, IDPRejectedClaimException5);
    InvalidIdentityTokenException$5 = [
      -3,
      n018,
      _IITE5,
      { [_aQE5]: [`InvalidIdentityToken`, 400], [_e18]: _c18, [_hE18]: 400 },
      [_m16],
      [0]
    ];
    n0_registry18.registerError(InvalidIdentityTokenException$5, InvalidIdentityTokenException5);
    MalformedPolicyDocumentException$5 = [
      -3,
      n018,
      _MPDE5,
      { [_aQE5]: [`MalformedPolicyDocument`, 400], [_e18]: _c18, [_hE18]: 400 },
      [_m16],
      [0]
    ];
    n0_registry18.registerError(MalformedPolicyDocumentException$5, MalformedPolicyDocumentException5);
    PackedPolicyTooLargeException$5 = [
      -3,
      n018,
      _PPTLE5,
      { [_aQE5]: [`PackedPolicyTooLarge`, 400], [_e18]: _c18, [_hE18]: 400 },
      [_m16],
      [0]
    ];
    n0_registry18.registerError(PackedPolicyTooLargeException$5, PackedPolicyTooLargeException5);
    RegionDisabledException$5 = [
      -3,
      n018,
      _RDE5,
      { [_aQE5]: [`RegionDisabledException`, 403], [_e18]: _c18, [_hE18]: 403 },
      [_m16],
      [0]
    ];
    n0_registry18.registerError(RegionDisabledException$5, RegionDisabledException5);
    errorTypeRegistries18 = [_s_registry18, n0_registry18];
    accessKeySecretType5 = [0, n018, _aKST5, 8, 0];
    clientTokenType5 = [0, n018, _cTT5, 8, 0];
    AssumedRoleUser$5 = [3, n018, _ARU5, 0, [_ARI5, _A5], [0, 0], 2];
    AssumeRoleRequest$5 = [
      3,
      n018,
      _ARR5,
      0,
      [_RA5, _RSN5, _PA5, _P5, _DS5, _T5, _TTK5, _EI5, _SN5, _TC5, _SI5, _PC5],
      [0, 0, () => policyDescriptorListType5, 0, 1, () => tagListType5, 64 | 0, 0, 0, 0, 0, () => ProvidedContextsListType5],
      2
    ];
    AssumeRoleResponse$5 = [
      3,
      n018,
      _ARRs5,
      0,
      [_C6, _ARU5, _PPS5, _SI5],
      [[() => Credentials$6, 0], () => AssumedRoleUser$5, 1, 0]
    ];
    AssumeRoleWithWebIdentityRequest$5 = [
      3,
      n018,
      _ARWWIR5,
      0,
      [_RA5, _RSN5, _WIT5, _PI5, _PA5, _P5, _DS5],
      [0, 0, [() => clientTokenType5, 0], 0, () => policyDescriptorListType5, 0, 1],
      3
    ];
    AssumeRoleWithWebIdentityResponse$5 = [
      3,
      n018,
      _ARWWIRs5,
      0,
      [_C6, _SFWIT5, _ARU5, _PPS5, _Pr5, _Au5, _SI5],
      [[() => Credentials$6, 0], 0, () => AssumedRoleUser$5, 1, 0, 0, 0]
    ];
    Credentials$6 = [
      3,
      n018,
      _C6,
      0,
      [_AKI6, _SAK5, _ST6, _E6],
      [0, [() => accessKeySecretType5, 0], 0, 4],
      4
    ];
    PolicyDescriptorType$5 = [3, n018, _PDT5, 0, [_a5], [0]];
    ProvidedContext$5 = [3, n018, _PCr5, 0, [_PAr5, _CA5], [0, 0]];
    Tag$5 = [3, n018, _Ta5, 0, [_K5, _V5], [0, 0], 2];
    policyDescriptorListType5 = [1, n018, _pDLT5, 0, () => PolicyDescriptorType$5];
    ProvidedContextsListType5 = [1, n018, _PCLT5, 0, () => ProvidedContext$5];
    tagKeyListType5 = 64 | 0;
    tagListType5 = [1, n018, _tLT5, 0, () => Tag$5];
    AssumeRole$5 = [9, n018, _AR5, 0, () => AssumeRoleRequest$5, () => AssumeRoleResponse$5];
    AssumeRoleWithWebIdentity$5 = [
      9,
      n018,
      _ARWWI5,
      0,
      () => AssumeRoleWithWebIdentityRequest$5,
      () => AssumeRoleWithWebIdentityResponse$5
    ];
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.shared.js
var import_signature_v4_multi_region10, import_smithy_client167, import_url_parser19, import_util_base6446, import_util_utf836, getRuntimeConfig35;
var init_runtimeConfig_shared18 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.shared.js"() {
    init_httpAuthSchemes7();
    init_protocols10();
    import_signature_v4_multi_region10 = __toESM(require_dist_cjs55());
    init_dist_es();
    import_smithy_client167 = __toESM(require_dist_cjs34());
    import_url_parser19 = __toESM(require_dist_cjs18());
    import_util_base6446 = __toESM(require_dist_cjs10());
    import_util_utf836 = __toESM(require_dist_cjs9());
    init_httpAuthSchemeProvider18();
    init_endpointResolver18();
    init_schemas_018();
    getRuntimeConfig35 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2011-06-15",
        base64Decoder: config2?.base64Decoder ?? import_util_base6446.fromBase64,
        base64Encoder: config2?.base64Encoder ?? import_util_base6446.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver18,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSTSHttpAuthSchemeProvider5,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer6()
          },
          {
            schemeId: "aws.auth#sigv4a",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4a"), "identityProvider"),
            signer: new AwsSdkSigV4ASigner6()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        logger: config2?.logger ?? new import_smithy_client167.NoOpLogger(),
        protocol: config2?.protocol ?? AwsQueryProtocol6,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.sts",
          errorTypeRegistries: errorTypeRegistries18,
          xmlNamespace: "https://sts.amazonaws.com/doc/2011-06-15/",
          version: "2011-06-15",
          serviceTarget: "AWSSecurityTokenServiceV20110615"
        },
        serviceId: config2?.serviceId ?? "STS",
        signerConstructor: config2?.signerConstructor ?? import_signature_v4_multi_region10.SignatureV4MultiRegion,
        urlParser: config2?.urlParser ?? import_url_parser19.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? import_util_utf836.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? import_util_utf836.toUtf8
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.js
var import_util_user_agent_node18, import_config_resolver36, import_hash_node18, import_middleware_retry35, import_node_config_provider19, import_node_http_handler18, import_smithy_client168, import_util_body_length_node18, import_util_defaults_mode_node18, import_util_retry26, getRuntimeConfig36;
var init_runtimeConfig18 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.js"() {
    init_package6();
    init_client10();
    init_httpAuthSchemes7();
    import_util_user_agent_node18 = __toESM(require_dist_cjs132());
    import_config_resolver36 = __toESM(require_dist_cjs25());
    init_dist_es();
    import_hash_node18 = __toESM(require_dist_cjs44());
    import_middleware_retry35 = __toESM(require_dist_cjs128());
    import_node_config_provider19 = __toESM(require_dist_cjs29());
    import_node_http_handler18 = __toESM(require_dist_cjs13());
    import_smithy_client168 = __toESM(require_dist_cjs34());
    import_util_body_length_node18 = __toESM(require_dist_cjs45());
    import_util_defaults_mode_node18 = __toESM(require_dist_cjs46());
    import_util_retry26 = __toESM(require_dist_cjs22());
    init_runtimeConfig_shared18();
    getRuntimeConfig36 = /* @__PURE__ */ __name((config2) => {
      (0, import_smithy_client168.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, import_util_defaults_mode_node18.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(import_smithy_client168.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig35(config2);
      emitWarningIfUnsupportedVersion23(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, import_node_config_provider19.loadConfig)(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS6, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? import_util_body_length_node18.calculateBodyLength,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, import_util_user_agent_node18.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_default6.version }),
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4") || (async (idProps) => await config2.credentialDefaultProvider(idProps?.__config || {})()), "identityProvider"),
            signer: new AwsSdkSigV4Signer6()
          },
          {
            schemeId: "aws.auth#sigv4a",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4a"), "identityProvider"),
            signer: new AwsSdkSigV4ASigner6()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        maxAttempts: config2?.maxAttempts ?? (0, import_node_config_provider19.loadConfig)(import_middleware_retry35.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, import_node_config_provider19.loadConfig)(import_config_resolver36.NODE_REGION_CONFIG_OPTIONS, { ...import_config_resolver36.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: import_node_http_handler18.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, import_node_config_provider19.loadConfig)({
          ...import_middleware_retry35.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || import_util_retry26.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? import_hash_node18.Hash.bind(null, "sha256"),
        sigv4aSigningRegionSet: config2?.sigv4aSigningRegionSet ?? (0, import_node_config_provider19.loadConfig)(NODE_SIGV4A_CONFIG_OPTIONS6, loaderConfig),
        streamCollector: config2?.streamCollector ?? import_node_http_handler18.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, import_node_config_provider19.loadConfig)(import_config_resolver36.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, import_node_config_provider19.loadConfig)(import_config_resolver36.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, import_node_config_provider19.loadConfig)(import_util_user_agent_node18.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration18, resolveHttpAuthRuntimeConfig18;
var init_httpAuthExtensionConfiguration18 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration18 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig18 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeExtensions.js
var import_region_config_resolver22, import_protocol_http44, import_smithy_client169, resolveRuntimeExtensions18;
var init_runtimeExtensions18 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeExtensions.js"() {
    import_region_config_resolver22 = __toESM(require_dist_cjs48());
    import_protocol_http44 = __toESM(require_dist_cjs2());
    import_smithy_client169 = __toESM(require_dist_cjs34());
    init_httpAuthExtensionConfiguration18();
    resolveRuntimeExtensions18 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign((0, import_region_config_resolver22.getAwsRegionExtensionConfiguration)(runtimeConfig), (0, import_smithy_client169.getDefaultExtensionConfiguration)(runtimeConfig), (0, import_protocol_http44.getHttpHandlerExtensionConfiguration)(runtimeConfig), getHttpAuthExtensionConfiguration18(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, (0, import_region_config_resolver22.resolveAwsRegionExtensionConfiguration)(extensionConfiguration), (0, import_smithy_client169.resolveDefaultRuntimeConfig)(extensionConfiguration), (0, import_protocol_http44.resolveHttpHandlerRuntimeConfig)(extensionConfiguration), resolveHttpAuthRuntimeConfig18(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STSClient.js
var import_middleware_host_header18, import_middleware_logger18, import_middleware_recursion_detection18, import_middleware_user_agent18, import_config_resolver37, import_middleware_content_length18, import_middleware_endpoint45, import_middleware_retry36, import_smithy_client170, STSClient6;
var init_STSClient5 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STSClient.js"() {
    import_middleware_host_header18 = __toESM(require_dist_cjs3());
    import_middleware_logger18 = __toESM(require_dist_cjs4());
    import_middleware_recursion_detection18 = __toESM(require_dist_cjs5());
    import_middleware_user_agent18 = __toESM(require_dist_cjs127());
    import_config_resolver37 = __toESM(require_dist_cjs25());
    init_dist_es();
    init_schema4();
    import_middleware_content_length18 = __toESM(require_dist_cjs26());
    import_middleware_endpoint45 = __toESM(require_dist_cjs31());
    import_middleware_retry36 = __toESM(require_dist_cjs128());
    import_smithy_client170 = __toESM(require_dist_cjs34());
    init_httpAuthSchemeProvider18();
    init_EndpointParameters18();
    init_runtimeConfig18();
    init_runtimeExtensions18();
    STSClient6 = class extends import_smithy_client170.Client {
      static {
        __name(this, "STSClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig36(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters18(_config_0);
        const _config_2 = (0, import_middleware_user_agent18.resolveUserAgentConfig)(_config_1);
        const _config_3 = (0, import_middleware_retry36.resolveRetryConfig)(_config_2);
        const _config_4 = (0, import_config_resolver37.resolveRegionConfig)(_config_3);
        const _config_5 = (0, import_middleware_host_header18.resolveHostHeaderConfig)(_config_4);
        const _config_6 = (0, import_middleware_endpoint45.resolveEndpointConfig)(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig18(_config_6);
        const _config_8 = resolveRuntimeExtensions18(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin(this.config));
        this.middlewareStack.use((0, import_middleware_user_agent18.getUserAgentPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_retry36.getRetryPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_content_length18.getContentLengthPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_host_header18.getHostHeaderPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_logger18.getLoggerPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_recursion_detection18.getRecursionDetectionPlugin)(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: defaultSTSHttpAuthSchemeParametersProvider5,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials,
            "aws.auth#sigv4a": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleCommand.js
var import_middleware_endpoint46, import_smithy_client171, AssumeRoleCommand5;
var init_AssumeRoleCommand5 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleCommand.js"() {
    import_middleware_endpoint46 = __toESM(require_dist_cjs31());
    import_smithy_client171 = __toESM(require_dist_cjs34());
    init_EndpointParameters18();
    init_schemas_018();
    AssumeRoleCommand5 = class extends import_smithy_client171.Command.classBuilder().ep(commonParams18).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint46.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "AssumeRole", {}).n("STSClient", "AssumeRoleCommand").sc(AssumeRole$5).build() {
      static {
        __name(this, "AssumeRoleCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleWithWebIdentityCommand.js
var import_middleware_endpoint47, import_smithy_client172, AssumeRoleWithWebIdentityCommand5;
var init_AssumeRoleWithWebIdentityCommand5 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleWithWebIdentityCommand.js"() {
    import_middleware_endpoint47 = __toESM(require_dist_cjs31());
    import_smithy_client172 = __toESM(require_dist_cjs34());
    init_EndpointParameters18();
    init_schemas_018();
    AssumeRoleWithWebIdentityCommand5 = class extends import_smithy_client172.Command.classBuilder().ep(commonParams18).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint47.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "AssumeRoleWithWebIdentity", {}).n("STSClient", "AssumeRoleWithWebIdentityCommand").sc(AssumeRoleWithWebIdentity$5).build() {
      static {
        __name(this, "AssumeRoleWithWebIdentityCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STS.js
var import_smithy_client173, commands18, STS5;
var init_STS5 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STS.js"() {
    import_smithy_client173 = __toESM(require_dist_cjs34());
    init_AssumeRoleCommand5();
    init_AssumeRoleWithWebIdentityCommand5();
    init_STSClient5();
    commands18 = {
      AssumeRoleCommand: AssumeRoleCommand5,
      AssumeRoleWithWebIdentityCommand: AssumeRoleWithWebIdentityCommand5
    };
    STS5 = class extends STSClient6 {
      static {
        __name(this, "STS");
      }
    };
    (0, import_smithy_client173.createAggregatedClient)(commands18, STS5);
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/index.js
var init_commands19 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/index.js"() {
    init_AssumeRoleCommand5();
    init_AssumeRoleWithWebIdentityCommand5();
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/models_0.js
var init_models_018 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultStsRoleAssumers.js
var import_region_config_resolver23, getAccountIdFromAssumedRoleUser5, resolveRegion5, getDefaultRoleAssumer9, getDefaultRoleAssumerWithWebIdentity9, isH25;
var init_defaultStsRoleAssumers5 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultStsRoleAssumers.js"() {
    init_client10();
    import_region_config_resolver23 = __toESM(require_dist_cjs48());
    init_AssumeRoleCommand5();
    init_AssumeRoleWithWebIdentityCommand5();
    getAccountIdFromAssumedRoleUser5 = /* @__PURE__ */ __name((assumedRoleUser) => {
      if (typeof assumedRoleUser?.Arn === "string") {
        const arnComponents = assumedRoleUser.Arn.split(":");
        if (arnComponents.length > 4 && arnComponents[4] !== "") {
          return arnComponents[4];
        }
      }
      return void 0;
    }, "getAccountIdFromAssumedRoleUser");
    resolveRegion5 = /* @__PURE__ */ __name(async (_region, _parentRegion, credentialProviderLogger, loaderConfig = {}) => {
      const region = typeof _region === "function" ? await _region() : _region;
      const parentRegion = typeof _parentRegion === "function" ? await _parentRegion() : _parentRegion;
      let stsDefaultRegion = "";
      const resolvedRegion = region ?? parentRegion ?? (stsDefaultRegion = await (0, import_region_config_resolver23.stsRegionDefaultResolver)(loaderConfig)());
      credentialProviderLogger?.debug?.("@aws-sdk/client-sts::resolveRegion", "accepting first of:", `${region} (credential provider clientConfig)`, `${parentRegion} (contextual client)`, `${stsDefaultRegion} (STS default: AWS_REGION, profile region, or us-east-1)`);
      return resolvedRegion;
    }, "resolveRegion");
    getDefaultRoleAssumer9 = /* @__PURE__ */ __name((stsOptions, STSClient12) => {
      let stsClient;
      let closureSourceCreds;
      return async (sourceCreds, params) => {
        closureSourceCreds = sourceCreds;
        if (!stsClient) {
          const { logger: logger5 = stsOptions?.parentClientConfig?.logger, profile = stsOptions?.parentClientConfig?.profile, region, requestHandler = stsOptions?.parentClientConfig?.requestHandler, credentialProviderLogger, userAgentAppId = stsOptions?.parentClientConfig?.userAgentAppId } = stsOptions;
          const resolvedRegion = await resolveRegion5(region, stsOptions?.parentClientConfig?.region, credentialProviderLogger, {
            logger: logger5,
            profile
          });
          const isCompatibleRequestHandler = !isH25(requestHandler);
          stsClient = new STSClient12({
            ...stsOptions,
            userAgentAppId,
            profile,
            credentialDefaultProvider: /* @__PURE__ */ __name(() => async () => closureSourceCreds, "credentialDefaultProvider"),
            region: resolvedRegion,
            requestHandler: isCompatibleRequestHandler ? requestHandler : void 0,
            logger: logger5
          });
        }
        const { Credentials, AssumedRoleUser } = await stsClient.send(new AssumeRoleCommand5(params));
        if (!Credentials || !Credentials.AccessKeyId || !Credentials.SecretAccessKey) {
          throw new Error(`Invalid response from STS.assumeRole call with role ${params.RoleArn}`);
        }
        const accountId = getAccountIdFromAssumedRoleUser5(AssumedRoleUser);
        const credentials = {
          accessKeyId: Credentials.AccessKeyId,
          secretAccessKey: Credentials.SecretAccessKey,
          sessionToken: Credentials.SessionToken,
          expiration: Credentials.Expiration,
          ...Credentials.CredentialScope && { credentialScope: Credentials.CredentialScope },
          ...accountId && { accountId }
        };
        setCredentialFeature8(credentials, "CREDENTIALS_STS_ASSUME_ROLE", "i");
        return credentials;
      };
    }, "getDefaultRoleAssumer");
    getDefaultRoleAssumerWithWebIdentity9 = /* @__PURE__ */ __name((stsOptions, STSClient12) => {
      let stsClient;
      return async (params) => {
        if (!stsClient) {
          const { logger: logger5 = stsOptions?.parentClientConfig?.logger, profile = stsOptions?.parentClientConfig?.profile, region, requestHandler = stsOptions?.parentClientConfig?.requestHandler, credentialProviderLogger, userAgentAppId = stsOptions?.parentClientConfig?.userAgentAppId } = stsOptions;
          const resolvedRegion = await resolveRegion5(region, stsOptions?.parentClientConfig?.region, credentialProviderLogger, {
            logger: logger5,
            profile
          });
          const isCompatibleRequestHandler = !isH25(requestHandler);
          stsClient = new STSClient12({
            ...stsOptions,
            userAgentAppId,
            profile,
            region: resolvedRegion,
            requestHandler: isCompatibleRequestHandler ? requestHandler : void 0,
            logger: logger5
          });
        }
        const { Credentials, AssumedRoleUser } = await stsClient.send(new AssumeRoleWithWebIdentityCommand5(params));
        if (!Credentials || !Credentials.AccessKeyId || !Credentials.SecretAccessKey) {
          throw new Error(`Invalid response from STS.assumeRoleWithWebIdentity call with role ${params.RoleArn}`);
        }
        const accountId = getAccountIdFromAssumedRoleUser5(AssumedRoleUser);
        const credentials = {
          accessKeyId: Credentials.AccessKeyId,
          secretAccessKey: Credentials.SecretAccessKey,
          sessionToken: Credentials.SessionToken,
          expiration: Credentials.Expiration,
          ...Credentials.CredentialScope && { credentialScope: Credentials.CredentialScope },
          ...accountId && { accountId }
        };
        if (accountId) {
          setCredentialFeature8(credentials, "RESOLVED_ACCOUNT_ID", "T");
        }
        setCredentialFeature8(credentials, "CREDENTIALS_STS_ASSUME_ROLE_WEB_ID", "k");
        return credentials;
      };
    }, "getDefaultRoleAssumerWithWebIdentity");
    isH25 = /* @__PURE__ */ __name((requestHandler) => {
      return requestHandler?.metadata?.handlerProtocol === "h2";
    }, "isH2");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultRoleAssumers.js
var getCustomizableStsClientCtor5, getDefaultRoleAssumer10, getDefaultRoleAssumerWithWebIdentity10, decorateDefaultCredentialProvider5;
var init_defaultRoleAssumers5 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultRoleAssumers.js"() {
    init_defaultStsRoleAssumers5();
    init_STSClient5();
    getCustomizableStsClientCtor5 = /* @__PURE__ */ __name((baseCtor, customizations) => {
      if (!customizations)
        return baseCtor;
      else
        return class CustomizableSTSClient extends baseCtor {
          static {
            __name(this, "CustomizableSTSClient");
          }
          constructor(config2) {
            super(config2);
            for (const customization of customizations) {
              this.middlewareStack.use(customization);
            }
          }
        };
    }, "getCustomizableStsClientCtor");
    getDefaultRoleAssumer10 = /* @__PURE__ */ __name((stsOptions = {}, stsPlugins) => getDefaultRoleAssumer9(stsOptions, getCustomizableStsClientCtor5(STSClient6, stsPlugins)), "getDefaultRoleAssumer");
    getDefaultRoleAssumerWithWebIdentity10 = /* @__PURE__ */ __name((stsOptions = {}, stsPlugins) => getDefaultRoleAssumerWithWebIdentity9(stsOptions, getCustomizableStsClientCtor5(STSClient6, stsPlugins)), "getDefaultRoleAssumerWithWebIdentity");
    decorateDefaultCredentialProvider5 = /* @__PURE__ */ __name((provider) => (input) => provider({
      roleAssumer: getDefaultRoleAssumer10(input),
      roleAssumerWithWebIdentity: getDefaultRoleAssumerWithWebIdentity10(input),
      ...input
    }), "decorateDefaultCredentialProvider");
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/index.js
var sts_exports5 = {};
__export(sts_exports5, {
  AssumeRole$: () => AssumeRole$5,
  AssumeRoleCommand: () => AssumeRoleCommand5,
  AssumeRoleRequest$: () => AssumeRoleRequest$5,
  AssumeRoleResponse$: () => AssumeRoleResponse$5,
  AssumeRoleWithWebIdentity$: () => AssumeRoleWithWebIdentity$5,
  AssumeRoleWithWebIdentityCommand: () => AssumeRoleWithWebIdentityCommand5,
  AssumeRoleWithWebIdentityRequest$: () => AssumeRoleWithWebIdentityRequest$5,
  AssumeRoleWithWebIdentityResponse$: () => AssumeRoleWithWebIdentityResponse$5,
  AssumedRoleUser$: () => AssumedRoleUser$5,
  Credentials$: () => Credentials$6,
  ExpiredTokenException: () => ExpiredTokenException7,
  ExpiredTokenException$: () => ExpiredTokenException$7,
  IDPCommunicationErrorException: () => IDPCommunicationErrorException5,
  IDPCommunicationErrorException$: () => IDPCommunicationErrorException$5,
  IDPRejectedClaimException: () => IDPRejectedClaimException5,
  IDPRejectedClaimException$: () => IDPRejectedClaimException$5,
  InvalidIdentityTokenException: () => InvalidIdentityTokenException5,
  InvalidIdentityTokenException$: () => InvalidIdentityTokenException$5,
  MalformedPolicyDocumentException: () => MalformedPolicyDocumentException5,
  MalformedPolicyDocumentException$: () => MalformedPolicyDocumentException$5,
  PackedPolicyTooLargeException: () => PackedPolicyTooLargeException5,
  PackedPolicyTooLargeException$: () => PackedPolicyTooLargeException$5,
  PolicyDescriptorType$: () => PolicyDescriptorType$5,
  ProvidedContext$: () => ProvidedContext$5,
  RegionDisabledException: () => RegionDisabledException5,
  RegionDisabledException$: () => RegionDisabledException$5,
  STS: () => STS5,
  STSClient: () => STSClient6,
  STSServiceException: () => STSServiceException5,
  STSServiceException$: () => STSServiceException$5,
  Tag$: () => Tag$5,
  __Client: () => import_smithy_client170.Client,
  decorateDefaultCredentialProvider: () => decorateDefaultCredentialProvider5,
  errorTypeRegistries: () => errorTypeRegistries18,
  getDefaultRoleAssumer: () => getDefaultRoleAssumer10,
  getDefaultRoleAssumerWithWebIdentity: () => getDefaultRoleAssumerWithWebIdentity10
});
var init_sts5 = __esm({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/index.js"() {
    init_STSClient5();
    init_STS5();
    init_commands19();
    init_schemas_018();
    init_errors18();
    init_models_018();
    init_defaultRoleAssumers5();
    init_STSServiceException5();
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-process/dist-cjs/index.js
var require_dist_cjs135 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-process/dist-cjs/index.js"(exports2) {
    "use strict";
    var sharedIniFileLoader = require_dist_cjs28();
    var propertyProvider = require_dist_cjs27();
    var node_child_process = require("node:child_process");
    var node_util = require("node:util");
    var client = (init_client10(), __toCommonJS(client_exports8));
    var getValidatedProcessCredentials = /* @__PURE__ */ __name((profileName, data3, profiles) => {
      if (data3.Version !== 1) {
        throw Error(`Profile ${profileName} credential_process did not return Version 1.`);
      }
      if (data3.AccessKeyId === void 0 || data3.SecretAccessKey === void 0) {
        throw Error(`Profile ${profileName} credential_process returned invalid credentials.`);
      }
      if (data3.Expiration) {
        const currentTime = /* @__PURE__ */ new Date();
        const expireTime = new Date(data3.Expiration);
        if (expireTime < currentTime) {
          throw Error(`Profile ${profileName} credential_process returned expired credentials.`);
        }
      }
      let accountId = data3.AccountId;
      if (!accountId && profiles?.[profileName]?.aws_account_id) {
        accountId = profiles[profileName].aws_account_id;
      }
      const credentials = {
        accessKeyId: data3.AccessKeyId,
        secretAccessKey: data3.SecretAccessKey,
        ...data3.SessionToken && { sessionToken: data3.SessionToken },
        ...data3.Expiration && { expiration: new Date(data3.Expiration) },
        ...data3.CredentialScope && { credentialScope: data3.CredentialScope },
        ...accountId && { accountId }
      };
      client.setCredentialFeature(credentials, "CREDENTIALS_PROCESS", "w");
      return credentials;
    }, "getValidatedProcessCredentials");
    var resolveProcessCredentials = /* @__PURE__ */ __name(async (profileName, profiles, logger5) => {
      const profile = profiles[profileName];
      if (profiles[profileName]) {
        const credentialProcess = profile["credential_process"];
        if (credentialProcess !== void 0) {
          const execPromise = node_util.promisify(sharedIniFileLoader.externalDataInterceptor?.getTokenRecord?.().exec ?? node_child_process.exec);
          try {
            const { stdout } = await execPromise(credentialProcess);
            let data3;
            try {
              data3 = JSON.parse(stdout.trim());
            } catch {
              throw Error(`Profile ${profileName} credential_process returned invalid JSON.`);
            }
            return getValidatedProcessCredentials(profileName, data3, profiles);
          } catch (error4) {
            throw new propertyProvider.CredentialsProviderError(error4.message, { logger: logger5 });
          }
        } else {
          throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} did not contain credential_process.`, { logger: logger5 });
        }
      } else {
        throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} could not be found in shared credentials file.`, {
          logger: logger5
        });
      }
    }, "resolveProcessCredentials");
    var fromProcess = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/credential-provider-process - fromProcess");
      const profiles = await sharedIniFileLoader.parseKnownFiles(init);
      return resolveProcessCredentials(sharedIniFileLoader.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      }), profiles, init.logger);
    }, "fromProcess");
    exports2.fromProcess = fromProcess;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromWebToken.js
var require_fromWebToken6 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromWebToken.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __setModuleDefault2 = exports2 && exports2.__setModuleDefault || (Object.create ? (function(o10, v) {
      Object.defineProperty(o10, "default", { enumerable: true, value: v });
    }) : function(o10, v) {
      o10["default"] = v;
    });
    var __importStar2 = exports2 && exports2.__importStar || /* @__PURE__ */ (function() {
      var ownKeys2 = /* @__PURE__ */ __name(function(o10) {
        ownKeys2 = Object.getOwnPropertyNames || function(o11) {
          var ar = [];
          for (var k32 in o11) if (Object.prototype.hasOwnProperty.call(o11, k32)) ar[ar.length] = k32;
          return ar;
        };
        return ownKeys2(o10);
      }, "ownKeys");
      return function(mod) {
        if (mod && mod.__esModule) return mod;
        var result2 = {};
        if (mod != null) {
          for (var k32 = ownKeys2(mod), i32 = 0; i32 < k32.length; i32++) if (k32[i32] !== "default") __createBinding3(result2, mod, k32[i32]);
        }
        __setModuleDefault2(result2, mod);
        return result2;
      };
    })();
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromWebToken = void 0;
    var fromWebToken = /* @__PURE__ */ __name((init) => async (awsIdentityProperties) => {
      init.logger?.debug("@aws-sdk/credential-provider-web-identity - fromWebToken");
      const { roleArn, roleSessionName, webIdentityToken, providerId, policyArns, policy, durationSeconds } = init;
      let { roleAssumerWithWebIdentity } = init;
      if (!roleAssumerWithWebIdentity) {
        const { getDefaultRoleAssumerWithWebIdentity: getDefaultRoleAssumerWithWebIdentity19 } = await Promise.resolve().then(() => __importStar2((init_sts5(), __toCommonJS(sts_exports5))));
        roleAssumerWithWebIdentity = getDefaultRoleAssumerWithWebIdentity19({
          ...init.clientConfig,
          credentialProviderLogger: init.logger,
          parentClientConfig: {
            ...awsIdentityProperties?.callerClientConfig,
            ...init.parentClientConfig
          }
        }, init.clientPlugins);
      }
      return roleAssumerWithWebIdentity({
        RoleArn: roleArn,
        RoleSessionName: roleSessionName ?? `aws-sdk-js-session-${Date.now()}`,
        WebIdentityToken: webIdentityToken,
        ProviderId: providerId,
        PolicyArns: policyArns,
        Policy: policy,
        DurationSeconds: durationSeconds
      });
    }, "fromWebToken");
    exports2.fromWebToken = fromWebToken;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromTokenFile.js
var require_fromTokenFile6 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromTokenFile.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromTokenFile = void 0;
    var client_1 = (init_client10(), __toCommonJS(client_exports8));
    var property_provider_1 = require_dist_cjs27();
    var shared_ini_file_loader_1 = require_dist_cjs28();
    var node_fs_1 = require("node:fs");
    var fromWebToken_1 = require_fromWebToken6();
    var ENV_TOKEN_FILE = "AWS_WEB_IDENTITY_TOKEN_FILE";
    var ENV_ROLE_ARN = "AWS_ROLE_ARN";
    var ENV_ROLE_SESSION_NAME = "AWS_ROLE_SESSION_NAME";
    var fromTokenFile = /* @__PURE__ */ __name((init = {}) => async (awsIdentityProperties) => {
      init.logger?.debug("@aws-sdk/credential-provider-web-identity - fromTokenFile");
      const webIdentityTokenFile = init?.webIdentityTokenFile ?? process.env[ENV_TOKEN_FILE];
      const roleArn = init?.roleArn ?? process.env[ENV_ROLE_ARN];
      const roleSessionName = init?.roleSessionName ?? process.env[ENV_ROLE_SESSION_NAME];
      if (!webIdentityTokenFile || !roleArn) {
        throw new property_provider_1.CredentialsProviderError("Web identity configuration not specified", {
          logger: init.logger
        });
      }
      const credentials = await (0, fromWebToken_1.fromWebToken)({
        ...init,
        webIdentityToken: shared_ini_file_loader_1.externalDataInterceptor?.getTokenRecord?.()[webIdentityTokenFile] ?? (0, node_fs_1.readFileSync)(webIdentityTokenFile, { encoding: "ascii" }),
        roleArn,
        roleSessionName
      })(awsIdentityProperties);
      if (webIdentityTokenFile === process.env[ENV_TOKEN_FILE]) {
        (0, client_1.setCredentialFeature)(credentials, "CREDENTIALS_ENV_VARS_STS_WEB_ID_TOKEN", "h");
      }
      return credentials;
    }, "fromTokenFile");
    exports2.fromTokenFile = fromTokenFile;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/index.js
var require_dist_cjs136 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/index.js"(exports2) {
    "use strict";
    var fromTokenFile = require_fromTokenFile6();
    var fromWebToken = require_fromWebToken6();
    Object.prototype.hasOwnProperty.call(fromTokenFile, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: fromTokenFile["__proto__"]
    });
    Object.keys(fromTokenFile).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = fromTokenFile[k32];
    });
    Object.prototype.hasOwnProperty.call(fromWebToken, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: fromWebToken["__proto__"]
    });
    Object.keys(fromWebToken).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = fromWebToken[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-ini/dist-cjs/index.js
var require_dist_cjs137 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-ini/dist-cjs/index.js"(exports2) {
    "use strict";
    var sharedIniFileLoader = require_dist_cjs28();
    var propertyProvider = require_dist_cjs27();
    var client = (init_client10(), __toCommonJS(client_exports8));
    var credentialProviderLogin = require_dist_cjs134();
    var resolveCredentialSource = /* @__PURE__ */ __name((credentialSource, profileName, logger5) => {
      const sourceProvidersMap = {
        EcsContainer: /* @__PURE__ */ __name(async (options) => {
          const { fromHttp } = await Promise.resolve().then(() => __toESM(require_dist_cjs131()));
          const { fromContainerMetadata } = await Promise.resolve().then(() => __toESM(require_dist_cjs38()));
          logger5?.debug("@aws-sdk/credential-provider-ini - credential_source is EcsContainer");
          return async () => propertyProvider.chain(fromHttp(options ?? {}), fromContainerMetadata(options))().then(setNamedProvider);
        }, "EcsContainer"),
        Ec2InstanceMetadata: /* @__PURE__ */ __name(async (options) => {
          logger5?.debug("@aws-sdk/credential-provider-ini - credential_source is Ec2InstanceMetadata");
          const { fromInstanceMetadata } = await Promise.resolve().then(() => __toESM(require_dist_cjs38()));
          return async () => fromInstanceMetadata(options)().then(setNamedProvider);
        }, "Ec2InstanceMetadata"),
        Environment: /* @__PURE__ */ __name(async (options) => {
          logger5?.debug("@aws-sdk/credential-provider-ini - credential_source is Environment");
          const { fromEnv: fromEnv6 } = await Promise.resolve().then(() => __toESM(require_dist_cjs129()));
          return async () => fromEnv6(options)().then(setNamedProvider);
        }, "Environment")
      };
      if (credentialSource in sourceProvidersMap) {
        return sourceProvidersMap[credentialSource];
      } else {
        throw new propertyProvider.CredentialsProviderError(`Unsupported credential source in profile ${profileName}. Got ${credentialSource}, expected EcsContainer or Ec2InstanceMetadata or Environment.`, { logger: logger5 });
      }
    }, "resolveCredentialSource");
    var setNamedProvider = /* @__PURE__ */ __name((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_NAMED_PROVIDER", "p"), "setNamedProvider");
    var isAssumeRoleProfile = /* @__PURE__ */ __name((arg, { profile = "default", logger: logger5 } = {}) => {
      return Boolean(arg) && typeof arg === "object" && typeof arg.role_arn === "string" && ["undefined", "string"].indexOf(typeof arg.role_session_name) > -1 && ["undefined", "string"].indexOf(typeof arg.external_id) > -1 && ["undefined", "string"].indexOf(typeof arg.mfa_serial) > -1 && (isAssumeRoleWithSourceProfile(arg, { profile, logger: logger5 }) || isCredentialSourceProfile(arg, { profile, logger: logger5 }));
    }, "isAssumeRoleProfile");
    var isAssumeRoleWithSourceProfile = /* @__PURE__ */ __name((arg, { profile, logger: logger5 }) => {
      const withSourceProfile = typeof arg.source_profile === "string" && typeof arg.credential_source === "undefined";
      if (withSourceProfile) {
        logger5?.debug?.(`    ${profile} isAssumeRoleWithSourceProfile source_profile=${arg.source_profile}`);
      }
      return withSourceProfile;
    }, "isAssumeRoleWithSourceProfile");
    var isCredentialSourceProfile = /* @__PURE__ */ __name((arg, { profile, logger: logger5 }) => {
      const withProviderProfile = typeof arg.credential_source === "string" && typeof arg.source_profile === "undefined";
      if (withProviderProfile) {
        logger5?.debug?.(`    ${profile} isCredentialSourceProfile credential_source=${arg.credential_source}`);
      }
      return withProviderProfile;
    }, "isCredentialSourceProfile");
    var resolveAssumeRoleCredentials = /* @__PURE__ */ __name(async (profileName, profiles, options, callerClientConfig, visitedProfiles = {}, resolveProfileData2) => {
      options.logger?.debug("@aws-sdk/credential-provider-ini - resolveAssumeRoleCredentials (STS)");
      const profileData = profiles[profileName];
      const { source_profile, region } = profileData;
      if (!options.roleAssumer) {
        const { getDefaultRoleAssumer: getDefaultRoleAssumer19 } = await Promise.resolve().then(() => (init_sts5(), sts_exports5));
        options.roleAssumer = getDefaultRoleAssumer19({
          ...options.clientConfig,
          credentialProviderLogger: options.logger,
          parentClientConfig: {
            ...callerClientConfig,
            ...options?.parentClientConfig,
            region: region ?? options?.parentClientConfig?.region ?? callerClientConfig?.region
          }
        }, options.clientPlugins);
      }
      if (source_profile && source_profile in visitedProfiles) {
        throw new propertyProvider.CredentialsProviderError(`Detected a cycle attempting to resolve credentials for profile ${sharedIniFileLoader.getProfileName(options)}. Profiles visited: ` + Object.keys(visitedProfiles).join(", "), { logger: options.logger });
      }
      options.logger?.debug(`@aws-sdk/credential-provider-ini - finding credential resolver using ${source_profile ? `source_profile=[${source_profile}]` : `profile=[${profileName}]`}`);
      const sourceCredsProvider = source_profile ? resolveProfileData2(source_profile, profiles, options, callerClientConfig, {
        ...visitedProfiles,
        [source_profile]: true
      }, isCredentialSourceWithoutRoleArn(profiles[source_profile] ?? {})) : (await resolveCredentialSource(profileData.credential_source, profileName, options.logger)(options))();
      if (isCredentialSourceWithoutRoleArn(profileData)) {
        return sourceCredsProvider.then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SOURCE_PROFILE", "o"));
      } else {
        const params = {
          RoleArn: profileData.role_arn,
          RoleSessionName: profileData.role_session_name || `aws-sdk-js-${Date.now()}`,
          ExternalId: profileData.external_id,
          DurationSeconds: parseInt(profileData.duration_seconds || "3600", 10)
        };
        const { mfa_serial } = profileData;
        if (mfa_serial) {
          if (!options.mfaCodeProvider) {
            throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} requires multi-factor authentication, but no MFA code callback was provided.`, { logger: options.logger, tryNextLink: false });
          }
          params.SerialNumber = mfa_serial;
          params.TokenCode = await options.mfaCodeProvider(mfa_serial);
        }
        const sourceCreds = await sourceCredsProvider;
        return options.roleAssumer(sourceCreds, params).then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SOURCE_PROFILE", "o"));
      }
    }, "resolveAssumeRoleCredentials");
    var isCredentialSourceWithoutRoleArn = /* @__PURE__ */ __name((section) => {
      return !section.role_arn && !!section.credential_source;
    }, "isCredentialSourceWithoutRoleArn");
    var isLoginProfile = /* @__PURE__ */ __name((data3) => {
      return Boolean(data3 && data3.login_session);
    }, "isLoginProfile");
    var resolveLoginCredentials = /* @__PURE__ */ __name(async (profileName, options, callerClientConfig) => {
      const credentials = await credentialProviderLogin.fromLoginCredentials({
        ...options,
        profile: profileName
      })({ callerClientConfig });
      return client.setCredentialFeature(credentials, "CREDENTIALS_PROFILE_LOGIN", "AC");
    }, "resolveLoginCredentials");
    var isProcessProfile = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.credential_process === "string", "isProcessProfile");
    var resolveProcessCredentials = /* @__PURE__ */ __name(async (options, profile) => Promise.resolve().then(() => __toESM(require_dist_cjs135())).then(({ fromProcess }) => fromProcess({
      ...options,
      profile
    })().then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_PROCESS", "v"))), "resolveProcessCredentials");
    var resolveSsoCredentials = /* @__PURE__ */ __name(async (profile, profileData, options = {}, callerClientConfig) => {
      const { fromSSO } = await Promise.resolve().then(() => __toESM(require_dist_cjs133()));
      return fromSSO({
        profile,
        logger: options.logger,
        parentClientConfig: options.parentClientConfig,
        clientConfig: options.clientConfig
      })({
        callerClientConfig
      }).then((creds) => {
        if (profileData.sso_session) {
          return client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SSO", "r");
        } else {
          return client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SSO_LEGACY", "t");
        }
      });
    }, "resolveSsoCredentials");
    var isSsoProfile = /* @__PURE__ */ __name((arg) => arg && (typeof arg.sso_start_url === "string" || typeof arg.sso_account_id === "string" || typeof arg.sso_session === "string" || typeof arg.sso_region === "string" || typeof arg.sso_role_name === "string"), "isSsoProfile");
    var isStaticCredsProfile = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.aws_access_key_id === "string" && typeof arg.aws_secret_access_key === "string" && ["undefined", "string"].indexOf(typeof arg.aws_session_token) > -1 && ["undefined", "string"].indexOf(typeof arg.aws_account_id) > -1, "isStaticCredsProfile");
    var resolveStaticCredentials = /* @__PURE__ */ __name(async (profile, options) => {
      options?.logger?.debug("@aws-sdk/credential-provider-ini - resolveStaticCredentials");
      const credentials = {
        accessKeyId: profile.aws_access_key_id,
        secretAccessKey: profile.aws_secret_access_key,
        sessionToken: profile.aws_session_token,
        ...profile.aws_credential_scope && { credentialScope: profile.aws_credential_scope },
        ...profile.aws_account_id && { accountId: profile.aws_account_id }
      };
      return client.setCredentialFeature(credentials, "CREDENTIALS_PROFILE", "n");
    }, "resolveStaticCredentials");
    var isWebIdentityProfile = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.web_identity_token_file === "string" && typeof arg.role_arn === "string" && ["undefined", "string"].indexOf(typeof arg.role_session_name) > -1, "isWebIdentityProfile");
    var resolveWebIdentityCredentials = /* @__PURE__ */ __name(async (profile, options, callerClientConfig) => Promise.resolve().then(() => __toESM(require_dist_cjs136())).then(({ fromTokenFile }) => fromTokenFile({
      webIdentityTokenFile: profile.web_identity_token_file,
      roleArn: profile.role_arn,
      roleSessionName: profile.role_session_name,
      roleAssumerWithWebIdentity: options.roleAssumerWithWebIdentity,
      logger: options.logger,
      parentClientConfig: options.parentClientConfig
    })({
      callerClientConfig
    }).then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_STS_WEB_ID_TOKEN", "q"))), "resolveWebIdentityCredentials");
    var resolveProfileData = /* @__PURE__ */ __name(async (profileName, profiles, options, callerClientConfig, visitedProfiles = {}, isAssumeRoleRecursiveCall = false) => {
      const data3 = profiles[profileName];
      if (Object.keys(visitedProfiles).length > 0 && isStaticCredsProfile(data3)) {
        return resolveStaticCredentials(data3, options);
      }
      if (isAssumeRoleRecursiveCall || isAssumeRoleProfile(data3, { profile: profileName, logger: options.logger })) {
        return resolveAssumeRoleCredentials(profileName, profiles, options, callerClientConfig, visitedProfiles, resolveProfileData);
      }
      if (isStaticCredsProfile(data3)) {
        return resolveStaticCredentials(data3, options);
      }
      if (isWebIdentityProfile(data3)) {
        return resolveWebIdentityCredentials(data3, options, callerClientConfig);
      }
      if (isProcessProfile(data3)) {
        return resolveProcessCredentials(options, profileName);
      }
      if (isSsoProfile(data3)) {
        return await resolveSsoCredentials(profileName, data3, options, callerClientConfig);
      }
      if (isLoginProfile(data3)) {
        return resolveLoginCredentials(profileName, options, callerClientConfig);
      }
      throw new propertyProvider.CredentialsProviderError(`Could not resolve credentials using profile: [${profileName}] in configuration/credentials file(s).`, { logger: options.logger });
    }, "resolveProfileData");
    var fromIni2 = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/credential-provider-ini - fromIni");
      const profiles = await sharedIniFileLoader.parseKnownFiles(init);
      return resolveProfileData(sharedIniFileLoader.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      }), profiles, init, callerClientConfig);
    }, "fromIni");
    exports2.fromIni = fromIni2;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-node/dist-cjs/index.js
var require_dist_cjs138 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@aws-sdk/credential-provider-node/dist-cjs/index.js"(exports2) {
    "use strict";
    var credentialProviderEnv = require_dist_cjs129();
    var propertyProvider = require_dist_cjs27();
    var sharedIniFileLoader = require_dist_cjs28();
    var ENV_IMDS_DISABLED3 = "AWS_EC2_METADATA_DISABLED";
    var remoteProvider = /* @__PURE__ */ __name(async (init) => {
      const { ENV_CMDS_FULL_URI, ENV_CMDS_RELATIVE_URI, fromContainerMetadata, fromInstanceMetadata } = await Promise.resolve().then(() => __toESM(require_dist_cjs38()));
      if (process.env[ENV_CMDS_RELATIVE_URI] || process.env[ENV_CMDS_FULL_URI]) {
        init.logger?.debug("@aws-sdk/credential-provider-node - remoteProvider::fromHttp/fromContainerMetadata");
        const { fromHttp } = await Promise.resolve().then(() => __toESM(require_dist_cjs131()));
        return propertyProvider.chain(fromHttp(init), fromContainerMetadata(init));
      }
      if (process.env[ENV_IMDS_DISABLED3] && process.env[ENV_IMDS_DISABLED3] !== "false") {
        return async () => {
          throw new propertyProvider.CredentialsProviderError("EC2 Instance Metadata Service access disabled", { logger: init.logger });
        };
      }
      init.logger?.debug("@aws-sdk/credential-provider-node - remoteProvider::fromInstanceMetadata");
      return fromInstanceMetadata(init);
    }, "remoteProvider");
    function memoizeChain(providers, treatAsExpired) {
      const chain5 = internalCreateChain(providers);
      let activeLock;
      let passiveLock;
      let credentials;
      const provider = /* @__PURE__ */ __name(async (options) => {
        if (options?.forceRefresh) {
          return await chain5(options);
        }
        if (credentials?.expiration) {
          if (credentials?.expiration?.getTime() < Date.now()) {
            credentials = void 0;
          }
        }
        if (activeLock) {
          await activeLock;
        } else if (!credentials || treatAsExpired?.(credentials)) {
          if (credentials) {
            if (!passiveLock) {
              passiveLock = chain5(options).then((c32) => {
                credentials = c32;
              }).finally(() => {
                passiveLock = void 0;
              });
            }
          } else {
            activeLock = chain5(options).then((c32) => {
              credentials = c32;
            }).finally(() => {
              activeLock = void 0;
            });
            return provider(options);
          }
        }
        return credentials;
      }, "provider");
      return provider;
    }
    __name(memoizeChain, "memoizeChain");
    var internalCreateChain = /* @__PURE__ */ __name((providers) => async (awsIdentityProperties) => {
      let lastProviderError;
      for (const provider of providers) {
        try {
          return await provider(awsIdentityProperties);
        } catch (err) {
          lastProviderError = err;
          if (err?.tryNextLink) {
            continue;
          }
          throw err;
        }
      }
      throw lastProviderError;
    }, "internalCreateChain");
    var multipleCredentialSourceWarningEmitted = false;
    var defaultProvider = /* @__PURE__ */ __name((init = {}) => memoizeChain([
      async () => {
        const profile = init.profile ?? process.env[sharedIniFileLoader.ENV_PROFILE];
        if (profile) {
          const envStaticCredentialsAreSet = process.env[credentialProviderEnv.ENV_KEY] && process.env[credentialProviderEnv.ENV_SECRET];
          if (envStaticCredentialsAreSet) {
            if (!multipleCredentialSourceWarningEmitted) {
              const warnFn = init.logger?.warn && init.logger?.constructor?.name !== "NoOpLogger" ? init.logger.warn.bind(init.logger) : console.warn;
              warnFn(`@aws-sdk/credential-provider-node - defaultProvider::fromEnv WARNING:
    Multiple credential sources detected: 
    Both AWS_PROFILE and the pair AWS_ACCESS_KEY_ID/AWS_SECRET_ACCESS_KEY static credentials are set.
    This SDK will proceed with the AWS_PROFILE value.
    
    However, a future version may change this behavior to prefer the ENV static credentials.
    Please ensure that your environment only sets either the AWS_PROFILE or the
    AWS_ACCESS_KEY_ID/AWS_SECRET_ACCESS_KEY pair.
`);
              multipleCredentialSourceWarningEmitted = true;
            }
          }
          throw new propertyProvider.CredentialsProviderError("AWS_PROFILE is set, skipping fromEnv provider.", {
            logger: init.logger,
            tryNextLink: true
          });
        }
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromEnv");
        return credentialProviderEnv.fromEnv(init)();
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromSSO");
        const { ssoStartUrl, ssoAccountId, ssoRegion, ssoRoleName, ssoSession } = init;
        if (!ssoStartUrl && !ssoAccountId && !ssoRegion && !ssoRoleName && !ssoSession) {
          throw new propertyProvider.CredentialsProviderError("Skipping SSO provider in default chain (inputs do not include SSO fields).", { logger: init.logger });
        }
        const { fromSSO } = await Promise.resolve().then(() => __toESM(require_dist_cjs133()));
        return fromSSO(init)(awsIdentityProperties);
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromIni");
        const { fromIni: fromIni2 } = await Promise.resolve().then(() => __toESM(require_dist_cjs137()));
        return fromIni2(init)(awsIdentityProperties);
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromProcess");
        const { fromProcess } = await Promise.resolve().then(() => __toESM(require_dist_cjs135()));
        return fromProcess(init)(awsIdentityProperties);
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromTokenFile");
        const { fromTokenFile } = await Promise.resolve().then(() => __toESM(require_dist_cjs136()));
        return fromTokenFile(init)(awsIdentityProperties);
      },
      async () => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::remoteProvider");
        return (await remoteProvider(init))();
      },
      async () => {
        throw new propertyProvider.CredentialsProviderError("Could not load credentials from any providers", {
          tryNextLink: false,
          logger: init.logger
        });
      }
    ], credentialsTreatedAsExpired), "defaultProvider");
    var credentialsWillNeedRefresh = /* @__PURE__ */ __name((credentials) => credentials?.expiration !== void 0, "credentialsWillNeedRefresh");
    var credentialsTreatedAsExpired = /* @__PURE__ */ __name((credentials) => credentials?.expiration !== void 0 && credentials.expiration.getTime() - Date.now() < 3e5, "credentialsTreatedAsExpired");
    exports2.credentialsTreatedAsExpired = credentialsTreatedAsExpired;
    exports2.credentialsWillNeedRefresh = credentialsWillNeedRefresh;
    exports2.defaultProvider = defaultProvider;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/dist-cjs/endpoint/bdd.js
var require_bdd5 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/dist-cjs/endpoint/bdd.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.bdd = void 0;
    var util_endpoints_1 = require_dist_cjs20();
    var k32 = "ref";
    var a32 = -1;
    var b32 = true;
    var c32 = "isSet";
    var d32 = "PartitionResult";
    var e32 = "booleanEquals";
    var f32 = "getAttr";
    var g32 = { [k32]: "Endpoint" };
    var h32 = { [k32]: d32 };
    var i32 = {};
    var j32 = [{ [k32]: "Region" }];
    var _data32 = {
      conditions: [
        [c32, [g32]],
        [c32, j32],
        ["aws.partition", j32, d32],
        [e32, [{ [k32]: "UseFIPS" }, b32]],
        [e32, [{ [k32]: "UseDualStack" }, b32]],
        [e32, [{ fn: f32, argv: [h32, "supportsDualStack"] }, b32]],
        [e32, [{ fn: f32, argv: [h32, "supportsFIPS"] }, b32]],
        ["stringEquals", [{ fn: f32, argv: [h32, "name"] }, "aws-us-gov"]]
      ],
      results: [
        [a32],
        [a32, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a32, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [g32, i32],
        ["https://cloudformation-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", i32],
        [a32, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://cloudformation.{Region}.amazonaws.com", i32],
        ["https://cloudformation-fips.{Region}.{PartitionResult#dnsSuffix}", i32],
        [a32, "FIPS is enabled but this partition does not support FIPS"],
        ["https://cloudformation.{Region}.{PartitionResult#dualStackDnsSuffix}", i32],
        [a32, "DualStack is enabled but this partition does not support DualStack"],
        ["https://cloudformation.{Region}.{PartitionResult#dnsSuffix}", i32],
        [a32, "Invalid Configuration: Missing Region"]
      ]
    };
    var root32 = 2;
    var r32 = 1e8;
    var nodes32 = new Int32Array([
      -1,
      1,
      -1,
      0,
      13,
      3,
      1,
      4,
      r32 + 12,
      2,
      5,
      r32 + 12,
      3,
      8,
      6,
      4,
      7,
      r32 + 11,
      5,
      r32 + 9,
      r32 + 10,
      4,
      11,
      9,
      6,
      10,
      r32 + 8,
      7,
      r32 + 6,
      r32 + 7,
      5,
      12,
      r32 + 5,
      6,
      r32 + 4,
      r32 + 5,
      3,
      r32 + 1,
      14,
      4,
      r32 + 2,
      r32 + 3
    ]);
    exports2.bdd = util_endpoints_1.BinaryDecisionDiagram.from(nodes32, root32, _data32.conditions, _data32.results);
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/dist-cjs/endpoint/endpointResolver.js
var require_endpointResolver5 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/dist-cjs/endpoint/endpointResolver.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.defaultEndpointResolver = void 0;
    var util_endpoints_1 = require_dist_cjs21();
    var util_endpoints_2 = require_dist_cjs20();
    var bdd_1 = require_bdd5();
    var cache32 = new util_endpoints_2.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    var defaultEndpointResolver32 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache32.get(endpointParams, () => (0, util_endpoints_2.decideEndpoint)(bdd_1.bdd, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    exports2.defaultEndpointResolver = defaultEndpointResolver32;
    util_endpoints_2.customEndpointFunctions.aws = util_endpoints_1.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/dist-cjs/models/CloudFormationServiceException.js
var require_CloudFormationServiceException = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/dist-cjs/models/CloudFormationServiceException.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.CloudFormationServiceException = exports2.__ServiceException = void 0;
    var smithy_client_1 = require_dist_cjs34();
    Object.defineProperty(exports2, "__ServiceException", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return smithy_client_1.ServiceException;
    }, "get") });
    var CloudFormationServiceException = class _CloudFormationServiceException extends smithy_client_1.ServiceException {
      static {
        __name(this, "CloudFormationServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _CloudFormationServiceException.prototype);
      }
    };
    exports2.CloudFormationServiceException = CloudFormationServiceException;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/dist-cjs/models/errors.js
var require_errors5 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/dist-cjs/models/errors.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ResourceScanLimitExceededException = exports2.OperationStatusCheckFailedException = exports2.InvalidStateTransitionException = exports2.ResourceScanInProgressException = exports2.StackNotFoundException = exports2.HookResultNotFoundException = exports2.StackRefactorNotFoundException = exports2.StackInstanceNotFoundException = exports2.ResourceScanNotFoundException = exports2.StackSetNotEmptyException = exports2.GeneratedTemplateNotFoundException = exports2.InvalidChangeSetStatusException = exports2.NameAlreadyExistsException = exports2.CreatedButModifiedException = exports2.StaleRequestException = exports2.StackSetNotFoundException = exports2.OperationInProgressException = exports2.OperationIdAlreadyExistsException = exports2.ConcurrentResourcesLimitExceededException = exports2.LimitExceededException = exports2.InsufficientCapabilitiesException = exports2.ChangeSetNotFoundException = exports2.TokenAlreadyExistsException = exports2.TypeConfigurationNotFoundException = exports2.AlreadyExistsException = exports2.TypeNotFoundException = exports2.CFNRegistryException = exports2.OperationNotFoundException = exports2.InvalidOperationException = void 0;
    var CloudFormationServiceException_1 = require_CloudFormationServiceException();
    var InvalidOperationException = class _InvalidOperationException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "InvalidOperationException");
      }
      name = "InvalidOperationException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidOperationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidOperationException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidOperationException = InvalidOperationException;
    var OperationNotFoundException = class _OperationNotFoundException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "OperationNotFoundException");
      }
      name = "OperationNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "OperationNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _OperationNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.OperationNotFoundException = OperationNotFoundException;
    var CFNRegistryException = class _CFNRegistryException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "CFNRegistryException");
      }
      name = "CFNRegistryException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "CFNRegistryException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CFNRegistryException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.CFNRegistryException = CFNRegistryException;
    var TypeNotFoundException = class _TypeNotFoundException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "TypeNotFoundException");
      }
      name = "TypeNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "TypeNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TypeNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.TypeNotFoundException = TypeNotFoundException;
    var AlreadyExistsException = class _AlreadyExistsException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "AlreadyExistsException");
      }
      name = "AlreadyExistsException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "AlreadyExistsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AlreadyExistsException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.AlreadyExistsException = AlreadyExistsException;
    var TypeConfigurationNotFoundException = class _TypeConfigurationNotFoundException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "TypeConfigurationNotFoundException");
      }
      name = "TypeConfigurationNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "TypeConfigurationNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TypeConfigurationNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.TypeConfigurationNotFoundException = TypeConfigurationNotFoundException;
    var TokenAlreadyExistsException = class _TokenAlreadyExistsException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "TokenAlreadyExistsException");
      }
      name = "TokenAlreadyExistsException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "TokenAlreadyExistsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TokenAlreadyExistsException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.TokenAlreadyExistsException = TokenAlreadyExistsException;
    var ChangeSetNotFoundException = class _ChangeSetNotFoundException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "ChangeSetNotFoundException");
      }
      name = "ChangeSetNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "ChangeSetNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ChangeSetNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ChangeSetNotFoundException = ChangeSetNotFoundException;
    var InsufficientCapabilitiesException = class _InsufficientCapabilitiesException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "InsufficientCapabilitiesException");
      }
      name = "InsufficientCapabilitiesException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InsufficientCapabilitiesException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InsufficientCapabilitiesException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InsufficientCapabilitiesException = InsufficientCapabilitiesException;
    var LimitExceededException2 = class _LimitExceededException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "LimitExceededException");
      }
      name = "LimitExceededException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "LimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _LimitExceededException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.LimitExceededException = LimitExceededException2;
    var ConcurrentResourcesLimitExceededException = class _ConcurrentResourcesLimitExceededException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "ConcurrentResourcesLimitExceededException");
      }
      name = "ConcurrentResourcesLimitExceededException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "ConcurrentResourcesLimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ConcurrentResourcesLimitExceededException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ConcurrentResourcesLimitExceededException = ConcurrentResourcesLimitExceededException;
    var OperationIdAlreadyExistsException = class _OperationIdAlreadyExistsException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "OperationIdAlreadyExistsException");
      }
      name = "OperationIdAlreadyExistsException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "OperationIdAlreadyExistsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _OperationIdAlreadyExistsException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.OperationIdAlreadyExistsException = OperationIdAlreadyExistsException;
    var OperationInProgressException = class _OperationInProgressException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "OperationInProgressException");
      }
      name = "OperationInProgressException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "OperationInProgressException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _OperationInProgressException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.OperationInProgressException = OperationInProgressException;
    var StackSetNotFoundException = class _StackSetNotFoundException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "StackSetNotFoundException");
      }
      name = "StackSetNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "StackSetNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _StackSetNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.StackSetNotFoundException = StackSetNotFoundException;
    var StaleRequestException = class _StaleRequestException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "StaleRequestException");
      }
      name = "StaleRequestException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "StaleRequestException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _StaleRequestException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.StaleRequestException = StaleRequestException;
    var CreatedButModifiedException = class _CreatedButModifiedException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "CreatedButModifiedException");
      }
      name = "CreatedButModifiedException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "CreatedButModifiedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CreatedButModifiedException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.CreatedButModifiedException = CreatedButModifiedException;
    var NameAlreadyExistsException = class _NameAlreadyExistsException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "NameAlreadyExistsException");
      }
      name = "NameAlreadyExistsException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "NameAlreadyExistsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _NameAlreadyExistsException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.NameAlreadyExistsException = NameAlreadyExistsException;
    var InvalidChangeSetStatusException = class _InvalidChangeSetStatusException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "InvalidChangeSetStatusException");
      }
      name = "InvalidChangeSetStatusException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidChangeSetStatusException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidChangeSetStatusException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidChangeSetStatusException = InvalidChangeSetStatusException;
    var GeneratedTemplateNotFoundException = class _GeneratedTemplateNotFoundException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "GeneratedTemplateNotFoundException");
      }
      name = "GeneratedTemplateNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "GeneratedTemplateNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _GeneratedTemplateNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.GeneratedTemplateNotFoundException = GeneratedTemplateNotFoundException;
    var StackSetNotEmptyException = class _StackSetNotEmptyException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "StackSetNotEmptyException");
      }
      name = "StackSetNotEmptyException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "StackSetNotEmptyException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _StackSetNotEmptyException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.StackSetNotEmptyException = StackSetNotEmptyException;
    var ResourceScanNotFoundException = class _ResourceScanNotFoundException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "ResourceScanNotFoundException");
      }
      name = "ResourceScanNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "ResourceScanNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceScanNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ResourceScanNotFoundException = ResourceScanNotFoundException;
    var StackInstanceNotFoundException = class _StackInstanceNotFoundException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "StackInstanceNotFoundException");
      }
      name = "StackInstanceNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "StackInstanceNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _StackInstanceNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.StackInstanceNotFoundException = StackInstanceNotFoundException;
    var StackRefactorNotFoundException = class _StackRefactorNotFoundException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "StackRefactorNotFoundException");
      }
      name = "StackRefactorNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "StackRefactorNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _StackRefactorNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.StackRefactorNotFoundException = StackRefactorNotFoundException;
    var HookResultNotFoundException = class _HookResultNotFoundException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "HookResultNotFoundException");
      }
      name = "HookResultNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "HookResultNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _HookResultNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.HookResultNotFoundException = HookResultNotFoundException;
    var StackNotFoundException = class _StackNotFoundException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "StackNotFoundException");
      }
      name = "StackNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "StackNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _StackNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.StackNotFoundException = StackNotFoundException;
    var ResourceScanInProgressException = class _ResourceScanInProgressException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "ResourceScanInProgressException");
      }
      name = "ResourceScanInProgressException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "ResourceScanInProgressException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceScanInProgressException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ResourceScanInProgressException = ResourceScanInProgressException;
    var InvalidStateTransitionException = class _InvalidStateTransitionException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "InvalidStateTransitionException");
      }
      name = "InvalidStateTransitionException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidStateTransitionException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidStateTransitionException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidStateTransitionException = InvalidStateTransitionException;
    var OperationStatusCheckFailedException = class _OperationStatusCheckFailedException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "OperationStatusCheckFailedException");
      }
      name = "OperationStatusCheckFailedException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "OperationStatusCheckFailedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _OperationStatusCheckFailedException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.OperationStatusCheckFailedException = OperationStatusCheckFailedException;
    var ResourceScanLimitExceededException = class _ResourceScanLimitExceededException extends CloudFormationServiceException_1.CloudFormationServiceException {
      static {
        __name(this, "ResourceScanLimitExceededException");
      }
      name = "ResourceScanLimitExceededException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "ResourceScanLimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceScanLimitExceededException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ResourceScanLimitExceededException = ResourceScanLimitExceededException;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/dist-cjs/schemas/schemas_0.js
var require_schemas_05 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/dist-cjs/schemas/schemas_0.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ContinueUpdateRollbackOutput$ = exports2.ContinueUpdateRollbackInput$ = exports2.ChangeSetSummary$ = exports2.ChangeSetHookTargetDetails$ = exports2.ChangeSetHookResourceTargetDetails$ = exports2.ChangeSetHook$ = exports2.Change$ = exports2.CancelUpdateStackInput$ = exports2.BatchDescribeTypeConfigurationsOutput$ = exports2.BatchDescribeTypeConfigurationsInput$ = exports2.BatchDescribeTypeConfigurationsError$ = exports2.AutoDeployment$ = exports2.Annotation$ = exports2.ActivateTypeOutput$ = exports2.ActivateTypeInput$ = exports2.ActivateOrganizationsAccessOutput$ = exports2.ActivateOrganizationsAccessInput$ = exports2.AccountLimit$ = exports2.AccountGateResult$ = exports2.errorTypeRegistries = exports2.TypeNotFoundException$ = exports2.TypeConfigurationNotFoundException$ = exports2.TokenAlreadyExistsException$ = exports2.StaleRequestException$ = exports2.StackSetNotFoundException$ = exports2.StackSetNotEmptyException$ = exports2.StackRefactorNotFoundException$ = exports2.StackNotFoundException$ = exports2.StackInstanceNotFoundException$ = exports2.ResourceScanNotFoundException$ = exports2.ResourceScanLimitExceededException$ = exports2.ResourceScanInProgressException$ = exports2.OperationStatusCheckFailedException$ = exports2.OperationNotFoundException$ = exports2.OperationInProgressException$ = exports2.OperationIdAlreadyExistsException$ = exports2.NameAlreadyExistsException$ = exports2.LimitExceededException$ = exports2.InvalidStateTransitionException$ = exports2.InvalidOperationException$ = exports2.InvalidChangeSetStatusException$ = exports2.InsufficientCapabilitiesException$ = exports2.HookResultNotFoundException$ = exports2.GeneratedTemplateNotFoundException$ = exports2.CreatedButModifiedException$ = exports2.ConcurrentResourcesLimitExceededException$ = exports2.ChangeSetNotFoundException$ = exports2.CFNRegistryException$ = exports2.AlreadyExistsException$ = exports2.CloudFormationServiceException$ = void 0;
    exports2.DescribeStackRefactorInput$ = exports2.DescribeStackInstanceOutput$ = exports2.DescribeStackInstanceInput$ = exports2.DescribeStackEventsOutput$ = exports2.DescribeStackEventsInput$ = exports2.DescribeStackDriftDetectionStatusOutput$ = exports2.DescribeStackDriftDetectionStatusInput$ = exports2.DescribeResourceScanOutput$ = exports2.DescribeResourceScanInput$ = exports2.DescribePublisherOutput$ = exports2.DescribePublisherInput$ = exports2.DescribeOrganizationsAccessOutput$ = exports2.DescribeOrganizationsAccessInput$ = exports2.DescribeGeneratedTemplateOutput$ = exports2.DescribeGeneratedTemplateInput$ = exports2.DescribeEventsOutput$ = exports2.DescribeEventsInput$ = exports2.DescribeChangeSetOutput$ = exports2.DescribeChangeSetInput$ = exports2.DescribeChangeSetHooksOutput$ = exports2.DescribeChangeSetHooksInput$ = exports2.DescribeAccountLimitsOutput$ = exports2.DescribeAccountLimitsInput$ = exports2.DeregisterTypeOutput$ = exports2.DeregisterTypeInput$ = exports2.DeploymentTargets$ = exports2.DeleteStackSetOutput$ = exports2.DeleteStackSetInput$ = exports2.DeleteStackInstancesOutput$ = exports2.DeleteStackInstancesInput$ = exports2.DeleteStackInput$ = exports2.DeleteGeneratedTemplateInput$ = exports2.DeleteChangeSetOutput$ = exports2.DeleteChangeSetInput$ = exports2.DeactivateTypeOutput$ = exports2.DeactivateTypeInput$ = exports2.DeactivateOrganizationsAccessOutput$ = exports2.DeactivateOrganizationsAccessInput$ = exports2.CreateStackSetOutput$ = exports2.CreateStackSetInput$ = exports2.CreateStackRefactorOutput$ = exports2.CreateStackRefactorInput$ = exports2.CreateStackOutput$ = exports2.CreateStackInstancesOutput$ = exports2.CreateStackInstancesInput$ = exports2.CreateStackInput$ = exports2.CreateGeneratedTemplateOutput$ = exports2.CreateGeneratedTemplateInput$ = exports2.CreateChangeSetOutput$ = exports2.CreateChangeSetInput$ = void 0;
    exports2.ListGeneratedTemplatesOutput$ = exports2.ListGeneratedTemplatesInput$ = exports2.ListExportsOutput$ = exports2.ListExportsInput$ = exports2.ListChangeSetsOutput$ = exports2.ListChangeSetsInput$ = exports2.ImportStacksToStackSetOutput$ = exports2.ImportStacksToStackSetInput$ = exports2.HookTarget$ = exports2.HookResultSummary$ = exports2.GetTemplateSummaryOutput$ = exports2.GetTemplateSummaryInput$ = exports2.GetTemplateOutput$ = exports2.GetTemplateInput$ = exports2.GetStackPolicyOutput$ = exports2.GetStackPolicyInput$ = exports2.GetHookResultOutput$ = exports2.GetHookResultInput$ = exports2.GetGeneratedTemplateOutput$ = exports2.GetGeneratedTemplateInput$ = exports2.Export$ = exports2.ExecuteStackRefactorInput$ = exports2.ExecuteChangeSetOutput$ = exports2.ExecuteChangeSetInput$ = exports2.EventFilter$ = exports2.EstimateTemplateCostOutput$ = exports2.EstimateTemplateCostInput$ = exports2.DetectStackSetDriftOutput$ = exports2.DetectStackSetDriftInput$ = exports2.DetectStackResourceDriftOutput$ = exports2.DetectStackResourceDriftInput$ = exports2.DetectStackDriftOutput$ = exports2.DetectStackDriftInput$ = exports2.DescribeTypeRegistrationOutput$ = exports2.DescribeTypeRegistrationInput$ = exports2.DescribeTypeOutput$ = exports2.DescribeTypeInput$ = exports2.DescribeStacksOutput$ = exports2.DescribeStacksInput$ = exports2.DescribeStackSetOutput$ = exports2.DescribeStackSetOperationOutput$ = exports2.DescribeStackSetOperationInput$ = exports2.DescribeStackSetInput$ = exports2.DescribeStackResourcesOutput$ = exports2.DescribeStackResourcesInput$ = exports2.DescribeStackResourceOutput$ = exports2.DescribeStackResourceInput$ = exports2.DescribeStackResourceDriftsOutput$ = exports2.DescribeStackResourceDriftsInput$ = exports2.DescribeStackRefactorOutput$ = void 0;
    exports2.PublishTypeInput$ = exports2.PropertyDifference$ = exports2.PhysicalResourceIdContextKeyValuePair$ = exports2.ParameterDeclaration$ = exports2.ParameterConstraints$ = exports2.Parameter$ = exports2.Output$ = exports2.OperationResultFilter$ = exports2.OperationEvent$ = exports2.OperationEntry$ = exports2.ModuleInfo$ = exports2.ManagedExecution$ = exports2.LoggingConfig$ = exports2.LiveResourceDrift$ = exports2.ListTypeVersionsOutput$ = exports2.ListTypeVersionsInput$ = exports2.ListTypesOutput$ = exports2.ListTypesInput$ = exports2.ListTypeRegistrationsOutput$ = exports2.ListTypeRegistrationsInput$ = exports2.ListStacksOutput$ = exports2.ListStacksInput$ = exports2.ListStackSetsOutput$ = exports2.ListStackSetsInput$ = exports2.ListStackSetOperationsOutput$ = exports2.ListStackSetOperationsInput$ = exports2.ListStackSetOperationResultsOutput$ = exports2.ListStackSetOperationResultsInput$ = exports2.ListStackSetAutoDeploymentTargetsOutput$ = exports2.ListStackSetAutoDeploymentTargetsInput$ = exports2.ListStackResourcesOutput$ = exports2.ListStackResourcesInput$ = exports2.ListStackRefactorsOutput$ = exports2.ListStackRefactorsInput$ = exports2.ListStackRefactorActionsOutput$ = exports2.ListStackRefactorActionsInput$ = exports2.ListStackInstancesOutput$ = exports2.ListStackInstancesInput$ = exports2.ListStackInstanceResourceDriftsOutput$ = exports2.ListStackInstanceResourceDriftsInput$ = exports2.ListResourceScansOutput$ = exports2.ListResourceScansInput$ = exports2.ListResourceScanResourcesOutput$ = exports2.ListResourceScanResourcesInput$ = exports2.ListResourceScanRelatedResourcesOutput$ = exports2.ListResourceScanRelatedResourcesInput$ = exports2.ListImportsOutput$ = exports2.ListImportsInput$ = exports2.ListHookResultsOutput$ = exports2.ListHookResultsInput$ = void 0;
    exports2.StackResourceSummary$ = exports2.StackResourceDriftInformationSummary$ = exports2.StackResourceDriftInformation$ = exports2.StackResourceDrift$ = exports2.StackResourceDetail$ = exports2.StackResource$ = exports2.StackRefactorSummary$ = exports2.StackRefactorAction$ = exports2.StackInstanceSummary$ = exports2.StackInstanceResourceDriftsSummary$ = exports2.StackInstanceFilter$ = exports2.StackInstanceComprehensiveStatus$ = exports2.StackInstance$ = exports2.StackEvent$ = exports2.StackDriftInformationSummary$ = exports2.StackDriftInformation$ = exports2.StackDefinition$ = exports2.Stack$ = exports2.SignalResourceInput$ = exports2.SetTypeDefaultVersionOutput$ = exports2.SetTypeDefaultVersionInput$ = exports2.SetTypeConfigurationOutput$ = exports2.SetTypeConfigurationInput$ = exports2.SetStackPolicyInput$ = exports2.ScannedResourceIdentifier$ = exports2.ScannedResource$ = exports2.ScanFilter$ = exports2.RollbackTrigger$ = exports2.RollbackStackOutput$ = exports2.RollbackStackInput$ = exports2.RollbackConfiguration$ = exports2.ResourceToImport$ = exports2.ResourceTargetDefinition$ = exports2.ResourceScanSummary$ = exports2.ResourceMapping$ = exports2.ResourceLocation$ = exports2.ResourceIdentifierSummary$ = exports2.ResourceDriftIgnoredAttribute$ = exports2.ResourceDetail$ = exports2.ResourceDefinition$ = exports2.ResourceChangeDetail$ = exports2.ResourceChange$ = exports2.RequiredActivatedType$ = exports2.RegisterTypeOutput$ = exports2.RegisterTypeInput$ = exports2.RegisterPublisherOutput$ = exports2.RegisterPublisherInput$ = exports2.RecordHandlerProgressOutput$ = exports2.RecordHandlerProgressInput$ = exports2.PublishTypeOutput$ = void 0;
    exports2.CreateStack$ = exports2.CreateGeneratedTemplate$ = exports2.CreateChangeSet$ = exports2.ContinueUpdateRollback$ = exports2.CancelUpdateStack$ = exports2.BatchDescribeTypeConfigurations$ = exports2.ActivateType$ = exports2.ActivateOrganizationsAccess$ = exports2.Warnings$ = exports2.WarningProperty$ = exports2.WarningDetail$ = exports2.ValidateTemplateOutput$ = exports2.ValidateTemplateInput$ = exports2.UpdateTerminationProtectionOutput$ = exports2.UpdateTerminationProtectionInput$ = exports2.UpdateStackSetOutput$ = exports2.UpdateStackSetInput$ = exports2.UpdateStackOutput$ = exports2.UpdateStackInstancesOutput$ = exports2.UpdateStackInstancesInput$ = exports2.UpdateStackInput$ = exports2.UpdateGeneratedTemplateOutput$ = exports2.UpdateGeneratedTemplateInput$ = exports2.TypeVersionSummary$ = exports2.TypeSummary$ = exports2.TypeFilters$ = exports2.TypeConfigurationIdentifier$ = exports2.TypeConfigurationDetails$ = exports2.TestTypeOutput$ = exports2.TestTypeInput$ = exports2.TemplateSummaryConfig$ = exports2.TemplateSummary$ = exports2.TemplateProgress$ = exports2.TemplateParameter$ = exports2.TemplateConfiguration$ = exports2.Tag$ = exports2.StopStackSetOperationOutput$ = exports2.StopStackSetOperationInput$ = exports2.StartResourceScanOutput$ = exports2.StartResourceScanInput$ = exports2.StackSummary$ = exports2.StackSetSummary$ = exports2.StackSetOperationSummary$ = exports2.StackSetOperationStatusDetails$ = exports2.StackSetOperationResultSummary$ = exports2.StackSetOperationPreferences$ = exports2.StackSetOperation$ = exports2.StackSetDriftDetectionDetails$ = exports2.StackSetAutoDeploymentTargetSummary$ = exports2.StackSet$ = void 0;
    exports2.ListResourceScanResources$ = exports2.ListResourceScanRelatedResources$ = exports2.ListImports$ = exports2.ListHookResults$ = exports2.ListGeneratedTemplates$ = exports2.ListExports$ = exports2.ListChangeSets$ = exports2.ImportStacksToStackSet$ = exports2.GetTemplateSummary$ = exports2.GetTemplate$ = exports2.GetStackPolicy$ = exports2.GetHookResult$ = exports2.GetGeneratedTemplate$ = exports2.ExecuteStackRefactor$ = exports2.ExecuteChangeSet$ = exports2.EstimateTemplateCost$ = exports2.DetectStackSetDrift$ = exports2.DetectStackResourceDrift$ = exports2.DetectStackDrift$ = exports2.DescribeTypeRegistration$ = exports2.DescribeType$ = exports2.DescribeStackSetOperation$ = exports2.DescribeStackSet$ = exports2.DescribeStacks$ = exports2.DescribeStackResources$ = exports2.DescribeStackResourceDrifts$ = exports2.DescribeStackResource$ = exports2.DescribeStackRefactor$ = exports2.DescribeStackInstance$ = exports2.DescribeStackEvents$ = exports2.DescribeStackDriftDetectionStatus$ = exports2.DescribeResourceScan$ = exports2.DescribePublisher$ = exports2.DescribeOrganizationsAccess$ = exports2.DescribeGeneratedTemplate$ = exports2.DescribeEvents$ = exports2.DescribeChangeSetHooks$ = exports2.DescribeChangeSet$ = exports2.DescribeAccountLimits$ = exports2.DeregisterType$ = exports2.DeleteStackSet$ = exports2.DeleteStackInstances$ = exports2.DeleteStack$ = exports2.DeleteGeneratedTemplate$ = exports2.DeleteChangeSet$ = exports2.DeactivateType$ = exports2.DeactivateOrganizationsAccess$ = exports2.CreateStackSet$ = exports2.CreateStackRefactor$ = exports2.CreateStackInstances$ = void 0;
    exports2.ValidateTemplate$ = exports2.UpdateTerminationProtection$ = exports2.UpdateStackSet$ = exports2.UpdateStackInstances$ = exports2.UpdateStack$ = exports2.UpdateGeneratedTemplate$ = exports2.TestType$ = exports2.StopStackSetOperation$ = exports2.StartResourceScan$ = exports2.SignalResource$ = exports2.SetTypeDefaultVersion$ = exports2.SetTypeConfiguration$ = exports2.SetStackPolicy$ = exports2.RollbackStack$ = exports2.RegisterType$ = exports2.RegisterPublisher$ = exports2.RecordHandlerProgress$ = exports2.PublishType$ = exports2.ListTypeVersions$ = exports2.ListTypes$ = exports2.ListTypeRegistrations$ = exports2.ListStackSets$ = exports2.ListStackSetOperations$ = exports2.ListStackSetOperationResults$ = exports2.ListStackSetAutoDeploymentTargets$ = exports2.ListStacks$ = exports2.ListStackResources$ = exports2.ListStackRefactors$ = exports2.ListStackRefactorActions$ = exports2.ListStackInstances$ = exports2.ListStackInstanceResourceDrifts$ = exports2.ListResourceScans$ = void 0;
    var _A10 = "Arn";
    var _AC = "AfterContext";
    var _ACT = "AttributeChangeType";
    var _AD = "AutoDeployment";
    var _AEE = "AlreadyExistsException";
    var _AFT = "AccountFilterType";
    var _AGR = "AccountGateResult";
    var _AL = "AccountLimit";
    var _ALL = "AccountLimitList";
    var _ALc = "AccountLimits";
    var _ALn = "AnnotationList";
    var _AN = "AnnotationName";
    var _AOA = "ActivateOrganizationsAccess";
    var _AOAI = "ActivateOrganizationsAccessInput";
    var _AOAO = "ActivateOrganizationsAccessOutput";
    var _AP = "ActualProperties";
    var _AR10 = "AddResources";
    var _ARARN = "AdministrationRoleARN";
    var _AT13 = "ActivateType";
    var _ATAC = "AcceptTermsAndConditions";
    var _ATI = "ActivateTypeInput";
    var _ATO = "ActivateTypeOutput";
    var _AU = "AutoUpdate";
    var _AUc = "AccountsUrl";
    var _AV = "ActualValue";
    var _AVF = "AfterValueFrom";
    var _AVf = "AfterValue";
    var _AVl = "AllowedValues";
    var _Ac = "Accounts";
    var _Acc = "Account";
    var _Act = "Action";
    var _Acti = "Active";
    var _Al = "Alias";
    var _An = "Annotation";
    var _Ann = "Annotations";
    var _At = "Attribute";
    var _BC = "BeforeContext";
    var _BDTC = "BatchDescribeTypeConfigurations";
    var _BDTCE = "BatchDescribeTypeConfigurationsError";
    var _BDTCEa = "BatchDescribeTypeConfigurationsErrors";
    var _BDTCI = "BatchDescribeTypeConfigurationsInput";
    var _BDTCO = "BatchDescribeTypeConfigurationsOutput";
    var _BT = "BearerToken";
    var _BV = "BeforeValue";
    var _BVF = "BeforeValueFrom";
    var _C11 = "Change";
    var _CA10 = "CallAs";
    var _CAo = "ConnectionArn";
    var _CAon = "ConfigurationAlias";
    var _CAonf = "ConfigurationArn";
    var _CBME = "CreatedButModifiedException";
    var _CCS = "CreateChangeSet";
    var _CCSI = "CreateChangeSetInput";
    var _CCSO = "CreateChangeSetOutput";
    var _CE = "CausingEntity";
    var _CFNRE = "CFNRegistryException";
    var _CGT = "CreateGeneratedTemplate";
    var _CGTI = "CreateGeneratedTemplateInput";
    var _CGTO = "CreateGeneratedTemplateOutput";
    var _CM = "ConcurrencyMode";
    var _COS = "CurrentOperationStatus";
    var _CR = "CapabilitiesReason";
    var _CRLEE = "ConcurrentResourcesLimitExceededException";
    var _CRT = "ClientRequestToken";
    var _CS4 = "ConfigurationSchema";
    var _CSH = "ChangeSetHook";
    var _CSHRTD = "ChangeSetHookResourceTargetDetails";
    var _CSHTD = "ChangeSetHookTargetDetails";
    var _CSHh = "ChangeSetHooks";
    var _CSI = "ChangeSetId";
    var _CSII = "CreateStackInstancesInput";
    var _CSIO = "CreateStackInstancesOutput";
    var _CSIr = "CreateStackInput";
    var _CSIre = "CreateStackInstances";
    var _CSN = "ChangeSetName";
    var _CSNFE = "ChangeSetNotFoundException";
    var _CSO = "CreateStackOutput";
    var _CSR = "CreateStackRefactor";
    var _CSRI = "CreateStackRefactorInput";
    var _CSRO = "CreateStackRefactorOutput";
    var _CSS = "ChangeSetSummary";
    var _CSSI = "CreateStackSetInput";
    var _CSSO = "CreateStackSetOutput";
    var _CSSh = "ChangeSetSummaries";
    var _CSSr = "CreateStackSet";
    var _CST = "ChangeSetType";
    var _CSh = "ChangeSource";
    var _CSr = "CreateStack";
    var _CT4 = "CreationTime";
    var _CTl = "ClientToken";
    var _CTr = "CreationTimestamp";
    var _CUR = "ContinueUpdateRollback";
    var _CURI = "ContinueUpdateRollbackInput";
    var _CURO = "ContinueUpdateRollbackOutput";
    var _CUS = "CancelUpdateStack";
    var _CUSI = "CancelUpdateStackInput";
    var _Ca = "Capabilities";
    var _Cat = "Category";
    var _Ch = "Changes";
    var _Co = "Configuration";
    var _D = "Description";
    var _DAL = "DescribeAccountLimits";
    var _DALI = "DescribeAccountLimitsInput";
    var _DALO = "DescribeAccountLimitsOutput";
    var _DCS = "DeleteChangeSet";
    var _DCSH = "DescribeChangeSetHooks";
    var _DCSHI = "DescribeChangeSetHooksInput";
    var _DCSHO = "DescribeChangeSetHooksOutput";
    var _DCSI = "DeleteChangeSetInput";
    var _DCSIe = "DescribeChangeSetInput";
    var _DCSO = "DeleteChangeSetOutput";
    var _DCSOe = "DescribeChangeSetOutput";
    var _DCSe = "DescribeChangeSet";
    var _DDS = "DriftDetectionStatus";
    var _DDT = "DriftDetectionTimestamp";
    var _DE = "DescribeEvents";
    var _DEI = "DescribeEventsInput";
    var _DEO = "DescribeEventsOutput";
    var _DGT = "DeleteGeneratedTemplate";
    var _DGTI = "DeleteGeneratedTemplateInput";
    var _DGTIe = "DescribeGeneratedTemplateInput";
    var _DGTO = "DescribeGeneratedTemplateOutput";
    var _DGTe = "DescribeGeneratedTemplate";
    var _DI = "DriftInformation";
    var _DM = "DeploymentMode";
    var _DMe = "DeletionMode";
    var _DO = "DependsOn";
    var _DOA = "DeactivateOrganizationsAccess";
    var _DOAI = "DeactivateOrganizationsAccessInput";
    var _DOAIe = "DescribeOrganizationsAccessInput";
    var _DOAO = "DeactivateOrganizationsAccessOutput";
    var _DOAOe = "DescribeOrganizationsAccessOutput";
    var _DOAe = "DescribeOrganizationsAccess";
    var _DP = "DeletionPolicy";
    var _DPI = "DescribePublisherInput";
    var _DPO = "DescribePublisherOutput";
    var _DPe = "DescribePublisher";
    var _DR = "DisableRollback";
    var _DRS = "DescribeResourceScan";
    var _DRSI = "DescribeResourceScanInput";
    var _DRSO = "DescribeResourceScanOutput";
    var _DRe = "DetectionReason";
    var _DS10 = "DetectionStatus";
    var _DSD = "DetectStackDrift";
    var _DSDDS = "DescribeStackDriftDetectionStatus";
    var _DSDDSI = "DescribeStackDriftDetectionStatusInput";
    var _DSDDSO = "DescribeStackDriftDetectionStatusOutput";
    var _DSDI = "DetectStackDriftInput";
    var _DSDO = "DetectStackDriftOutput";
    var _DSE = "DescribeStackEvents";
    var _DSEI = "DescribeStackEventsInput";
    var _DSEO = "DescribeStackEventsOutput";
    var _DSI = "DeleteStackInput";
    var _DSIC = "DriftedStackInstancesCount";
    var _DSII = "DeleteStackInstancesInput";
    var _DSIIe = "DescribeStackInstanceInput";
    var _DSIO = "DeleteStackInstancesOutput";
    var _DSIOe = "DescribeStackInstanceOutput";
    var _DSIe = "DescribeStacksInput";
    var _DSIel = "DeleteStackInstances";
    var _DSIes = "DescribeStackInstance";
    var _DSO = "DescribeStacksOutput";
    var _DSR = "DetectionStatusReason";
    var _DSRC = "DriftedStackResourceCount";
    var _DSRD = "DescribeStackResourceDrifts";
    var _DSRDI = "DescribeStackResourceDriftsInput";
    var _DSRDIe = "DetectStackResourceDriftInput";
    var _DSRDO = "DescribeStackResourceDriftsOutput";
    var _DSRDOe = "DetectStackResourceDriftOutput";
    var _DSRDe = "DetectStackResourceDrift";
    var _DSRI = "DescribeStackRefactorInput";
    var _DSRIe = "DescribeStackResourceInput";
    var _DSRIes = "DescribeStackResourcesInput";
    var _DSRO = "DescribeStackRefactorOutput";
    var _DSROe = "DescribeStackResourceOutput";
    var _DSROes = "DescribeStackResourcesOutput";
    var _DSRe = "DescribeStackRefactor";
    var _DSRes = "DescribeStackResource";
    var _DSResc = "DescribeStackResources";
    var _DSRr = "DriftStatusReason";
    var _DSS = "DeleteStackSet";
    var _DSSD = "DetectStackSetDrift";
    var _DSSDI = "DetectStackSetDriftInput";
    var _DSSDO = "DetectStackSetDriftOutput";
    var _DSSI = "DeleteStackSetInput";
    var _DSSIe = "DescribeStackSetInput";
    var _DSSO = "DeleteStackSetOutput";
    var _DSSOI = "DescribeStackSetOperationInput";
    var _DSSOO = "DescribeStackSetOperationOutput";
    var _DSSOe = "DescribeStackSetOutput";
    var _DSSOes = "DescribeStackSetOperation";
    var _DSSe = "DescribeStackSet";
    var _DSe = "DeprecatedStatus";
    var _DSel = "DeleteStack";
    var _DSes = "DescribeStacks";
    var _DSet = "DetailedStatus";
    var _DSr = "DriftStatus";
    var _DT = "DeploymentTargets";
    var _DTI = "DeactivateTypeInput";
    var _DTIe = "DeregisterTypeInput";
    var _DTIes = "DescribeTypeInput";
    var _DTO = "DeactivateTypeOutput";
    var _DTOe = "DeregisterTypeOutput";
    var _DTOes = "DescribeTypeOutput";
    var _DTR = "DescribeTypeRegistration";
    var _DTRI = "DescribeTypeRegistrationInput";
    var _DTRO = "DescribeTypeRegistrationOutput";
    var _DTe = "DeclaredTransforms";
    var _DTea = "DeactivateType";
    var _DTel = "DeletionTime";
    var _DTer = "DeregisterType";
    var _DTes = "DescribeType";
    var _DTi = "DifferenceType";
    var _DU = "DocumentationUrl";
    var _DV = "DefaultValue";
    var _DVI = "DefaultVersionId";
    var _De = "Details";
    var _Des = "Destination";
    var _Det = "Detection";
    var _Dr = "Drift";
    var _E11 = "Enabled";
    var _EC = "ErrorCode";
    var _ECS = "ExecuteChangeSet";
    var _ECSI = "ExecuteChangeSetInput";
    var _ECSO = "ExecuteChangeSetOutput";
    var _EF = "EventFilter";
    var _EI10 = "EventId";
    var _EM = "ErrorMessage";
    var _EN = "ExportName";
    var _EP = "ExpectedProperties";
    var _ERA = "ExecutionRoleArn";
    var _ERN = "ExecutionRoleName";
    var _ES = "ExecutionStatus";
    var _ESC = "EnableStackCreation";
    var _ESF = "ExecutionStatusFilter";
    var _ESI = "ExportingStackId";
    var _ESR = "ExecutionStatusReason";
    var _ESRI = "ExecuteStackRefactorInput";
    var _ESRx = "ExecuteStackRefactor";
    var _ET = "EndTime";
    var _ETC = "EstimateTemplateCost";
    var _ETCI = "EstimateTemplateCostInput";
    var _ETCO = "EstimateTemplateCostOutput";
    var _ETP = "EnableTerminationProtection";
    var _ETn = "EndTimestamp";
    var _ETv = "EventType";
    var _EV = "ExpectedValue";
    var _En = "Entity";
    var _Er = "Errors";
    var _Ev = "Evaluation";
    var _Ex = "Export";
    var _Exp = "Exports";
    var _F = "Filters";
    var _FE = "FailedEvents";
    var _FM = "FailureMode";
    var _FSIC = "FailedStackInstancesCount";
    var _FTC = "FailureToleranceCount";
    var _FTP = "FailureTolerancePercentage";
    var _Fo = "Format";
    var _GGT = "GetGeneratedTemplate";
    var _GGTI = "GetGeneratedTemplateInput";
    var _GGTO = "GetGeneratedTemplateOutput";
    var _GHR = "GetHookResult";
    var _GHRI = "GetHookResultInput";
    var _GHRO = "GetHookResultOutput";
    var _GSP = "GetStackPolicy";
    var _GSPI = "GetStackPolicyInput";
    var _GSPO = "GetStackPolicyOutput";
    var _GT = "GetTemplate";
    var _GTI = "GeneratedTemplateId";
    var _GTIe = "GetTemplateInput";
    var _GTN = "GeneratedTemplateName";
    var _GTNFE = "GeneratedTemplateNotFoundException";
    var _GTO = "GetTemplateOutput";
    var _GTS = "GetTemplateSummary";
    var _GTSI = "GetTemplateSummaryInput";
    var _GTSO = "GetTemplateSummaryOutput";
    var _H = "Hooks";
    var _HET = "HookExecutionTarget";
    var _HFM = "HookFailureMode";
    var _HIC = "HookInvocationCount";
    var _HII = "HookInvocationId";
    var _HIP = "HookInvocationPoint";
    var _HR = "HookResults";
    var _HRI = "HookResultId";
    var _HRNFE = "HookResultNotFoundException";
    var _HRS = "HookResultSummary";
    var _HRSo = "HookResultSummaries";
    var _HS = "HookStatus";
    var _HSR = "HookStatusReason";
    var _HT = "HookTarget";
    var _HTo = "HookType";
    var _I = "Id";
    var _IA = "IsActivated";
    var _IAn = "InvokedAt";
    var _ICE4 = "InsufficientCapabilitiesException";
    var _ICSSE = "InvalidChangeSetStatusException";
    var _IDC = "IsDefaultConfiguration";
    var _IDV = "IsDefaultVersion";
    var _IER = "ImportExistingResources";
    var _INS = "IncludeNestedStacks";
    var _IOE = "InvalidOperationException";
    var _IP = "InvocationPoint";
    var _IPSIC = "InProgressStackInstancesCount";
    var _IPV = "IncludePropertyValues";
    var _IPd = "IdentityProvider";
    var _ISSIC = "InSyncStackInstancesCount";
    var _ISTE = "InvalidStateTransitionException";
    var _ISTSS = "ImportStacksToStackSet";
    var _ISTSSI = "ImportStacksToStackSetInput";
    var _ISTSSO = "ImportStacksToStackSetOutput";
    var _Im = "Imports";
    var _K10 = "Key";
    var _LC = "LoggingConfig";
    var _LCS = "ListChangeSets";
    var _LCSI = "ListChangeSetsInput";
    var _LCSO = "ListChangeSetsOutput";
    var _LCT = "LastCheckTimestamp";
    var _LDB = "LogDeliveryBucket";
    var _LDCT = "LastDriftCheckTimestamp";
    var _LE = "ListExports";
    var _LEE2 = "LimitExceededException";
    var _LEI = "ListExportsInput";
    var _LEO = "ListExportsOutput";
    var _LGN = "LogGroupName";
    var _LGT = "ListGeneratedTemplates";
    var _LGTI = "ListGeneratedTemplatesInput";
    var _LGTO = "ListGeneratedTemplatesOutput";
    var _LHR = "ListHookResults";
    var _LHRI = "ListHookResultsInput";
    var _LHRO = "ListHookResultsOutput";
    var _LI = "ListImports";
    var _LIH = "LogicalIdHierarchy";
    var _LII = "ListImportsInput";
    var _LIO = "ListImportsOutput";
    var _LO = "LastOperations";
    var _LOI = "LastOperationId";
    var _LPV = "LatestPublicVersion";
    var _LRA = "LogRoleArn";
    var _LRD = "LiveResourceDrift";
    var _LRI = "LogicalResourceId";
    var _LRIo = "LogicalResourceIds";
    var _LRS = "ListResourceScans";
    var _LRSI = "ListResourceScansInput";
    var _LRSO = "ListResourceScansOutput";
    var _LRSR = "ListResourceScanResources";
    var _LRSRI = "ListResourceScanResourcesInput";
    var _LRSRO = "ListResourceScanResourcesOutput";
    var _LRSRR = "ListResourceScanRelatedResources";
    var _LRSRRI = "ListResourceScanRelatedResourcesInput";
    var _LRSRRO = "ListResourceScanRelatedResourcesOutput";
    var _LS = "ListStacks";
    var _LSI = "ListStacksInput";
    var _LSII = "ListStackInstancesInput";
    var _LSIO = "ListStackInstancesOutput";
    var _LSIRD = "ListStackInstanceResourceDrifts";
    var _LSIRDI = "ListStackInstanceResourceDriftsInput";
    var _LSIRDO = "ListStackInstanceResourceDriftsOutput";
    var _LSIi = "ListStackInstances";
    var _LSO = "ListStacksOutput";
    var _LSR = "ListStackRefactors";
    var _LSRA = "ListStackRefactorActions";
    var _LSRAI = "ListStackRefactorActionsInput";
    var _LSRAO = "ListStackRefactorActionsOutput";
    var _LSRI = "ListStackRefactorsInput";
    var _LSRIi = "ListStackResourcesInput";
    var _LSRO = "ListStackRefactorsOutput";
    var _LSROi = "ListStackResourcesOutput";
    var _LSRi = "ListStackResources";
    var _LSS = "ListStackSets";
    var _LSSADT = "ListStackSetAutoDeploymentTargets";
    var _LSSADTI = "ListStackSetAutoDeploymentTargetsInput";
    var _LSSADTO = "ListStackSetAutoDeploymentTargetsOutput";
    var _LSSI = "ListStackSetsInput";
    var _LSSO = "ListStackSetsOutput";
    var _LSSOI = "ListStackSetOperationsInput";
    var _LSSOO = "ListStackSetOperationsOutput";
    var _LSSOR = "ListStackSetOperationResults";
    var _LSSORI = "ListStackSetOperationResultsInput";
    var _LSSORO = "ListStackSetOperationResultsOutput";
    var _LSSOi = "ListStackSetOperations";
    var _LT = "ListTypes";
    var _LTI = "ListTypesInput";
    var _LTO = "ListTypesOutput";
    var _LTR = "ListTypeRegistrations";
    var _LTRI = "ListTypeRegistrationsInput";
    var _LTRO = "ListTypeRegistrationsOutput";
    var _LTV = "ListTypeVersions";
    var _LTVI = "ListTypeVersionsInput";
    var _LTVO = "ListTypeVersionsOutput";
    var _LU = "LastUpdated";
    var _LUT = "LastUpdatedTime";
    var _LUTa = "LastUpdatedTimestamp";
    var _M = "Message";
    var _MBS = "ManagedByStack";
    var _MCC = "MaxConcurrentCount";
    var _MCP = "MaxConcurrentPercentage";
    var _ME = "ManagedExecution";
    var _MI = "ModuleInfo";
    var _MR = "MaxResults";
    var _MTIM = "MonitoringTimeInMinutes";
    var _MV = "MajorVersion";
    var _Me = "Metadata";
    var _N = "Name";
    var _NAEE = "NameAlreadyExistsException";
    var _NARN = "NotificationARNs";
    var _NE = "NoEcho";
    var _NGTN = "NewGeneratedTemplateName";
    var _NOR = "NumberOfResources";
    var _NT = "NextToken";
    var _O = "Output";
    var _OE = "OperationEvents";
    var _OEp = "OperationEntry";
    var _OEpe = "OperationEvent";
    var _OF = "OnFailure";
    var _OI = "OperationId";
    var _OIAEE = "OperationIdAlreadyExistsException";
    var _OIPE = "OperationInProgressException";
    var _OK = "OutputKey";
    var _ONFE = "OperationNotFoundException";
    var _OP = "OperationPreferences";
    var _ORF = "OperationResultFilter";
    var _ORFp = "OperationResultFilters";
    var _OS = "OperationStatus";
    var _OSCFE = "OperationStatusCheckFailedException";
    var _OSF = "OnStackFailure";
    var _OT = "OperationType";
    var _OTA = "OriginalTypeArn";
    var _OTN = "OriginalTypeName";
    var _OUI = "OrganizationalUnitIds";
    var _OUIr = "OrganizationalUnitId";
    var _OV = "OutputValue";
    var _Ou = "Outputs";
    var _P10 = "Parameters";
    var _PA10 = "PolicyAction";
    var _PC10 = "PercentageCompleted";
    var _PCSI = "ParentChangeSetId";
    var _PCa = "ParameterConstraints";
    var _PD = "ParameterDeclaration";
    var _PDC = "PreviousDeploymentContext";
    var _PDa = "ParameterDeclarations";
    var _PDr = "PropertyDifference";
    var _PDro = "PropertyDifferences";
    var _PI10 = "PublisherId";
    var _PIa = "ParentId";
    var _PIu = "PublisherIdentity";
    var _PK = "ParameterKey";
    var _PM = "PermissionModel";
    var _PN = "PublisherName";
    var _PO = "ParameterOverrides";
    var _PP = "PublisherProfile";
    var _PPr = "PropertyPath";
    var _PRI = "PhysicalResourceId";
    var _PRIC = "PhysicalResourceIdContext";
    var _PRICKVP = "PhysicalResourceIdContextKeyValuePair";
    var _PS = "PublisherStatus";
    var _PSr = "ProgressStatus";
    var _PT = "ProvisioningType";
    var _PTA = "PublicTypeArn";
    var _PTI = "PublishTypeInput";
    var _PTO = "PublishTypeOutput";
    var _PTa = "ParameterType";
    var _PTu = "PublishType";
    var _PV = "PreviousValue";
    var _PVN = "PublicVersionNumber";
    var _PVa = "ParameterValue";
    var _Pa = "Parameter";
    var _Pat = "Path";
    var _Pr10 = "Progress";
    var _Pro = "Properties";
    var _R = "Resources";
    var _RA10 = "ResourceAction";
    var _RAR = "RefreshAllResources";
    var _RARN = "RoleARN";
    var _RAT = "RequiredActivatedTypes";
    var _RATe = "RequiredActivatedType";
    var _RC10 = "ResourceChange";
    var _RCD = "ResourceChangeDetail";
    var _RCDe = "ResourceChangeDetails";
    var _RCSI = "RootChangeSetId";
    var _RCT = "RegionConcurrencyType";
    var _RCo = "RollbackConfiguration";
    var _RD = "ResourceDefinition";
    var _RDIA = "ResourceDriftIgnoredAttributes";
    var _RDIAe = "ResourceDriftIgnoredAttribute";
    var _RDS = "ResourceDriftStatus";
    var _RDe = "ResourceDetail";
    var _RDes = "ResourceDefinitions";
    var _RDeso = "ResourceDetails";
    var _REOC = "RetainExceptOnCreate";
    var _RF = "ResourcesFailed";
    var _RHP = "RecordHandlerProgress";
    var _RHPI = "RecordHandlerProgressInput";
    var _RHPO = "RecordHandlerProgressOutput";
    var _RI = "ResourceIdentifier";
    var _RIS = "ResourceIdentifierSummaries";
    var _RISe = "ResourceIdentifierSummary";
    var _RIe = "ResourceIdentifiers";
    var _RIo = "RootId";
    var _RL = "RemediationLink";
    var _RLe = "ResourceLocation";
    var _RM = "RemediationMessage";
    var _RMe = "ResourceMappings";
    var _RMes = "ResourceModel";
    var _RMeso = "ResourceMapping";
    var _RO = "RegionOrder";
    var _RP = "ResourceProperties";
    var _RPI = "RegisterPublisherInput";
    var _RPO = "RegisterPublisherOutput";
    var _RPe = "ResourcesProcessing";
    var _RPeg = "RegisterPublisher";
    var _RPes = "ResourcesPending";
    var _RR = "RetainResources";
    var _RRe = "ResourcesRead";
    var _RRel = "RelatedResources";
    var _RRem = "RemoveResources";
    var _RReq = "RequiresRecreation";
    var _RS = "RetainStacks";
    var _RSF = "RegistrationStatusFilter";
    var _RSI = "ResourceScanId";
    var _RSIPE = "ResourceScanInProgressException";
    var _RSIo = "RollbackStackInput";
    var _RSLEE = "ResourceScanLimitExceededException";
    var _RSNFE = "ResourceScanNotFoundException";
    var _RSO = "RollbackStackOutput";
    var _RSOAR = "RetainStacksOnAccountRemoval";
    var _RSR = "ResourceStatusReason";
    var _RSS = "ResourceScanSummaries";
    var _RSSe = "ResourceScanSummary";
    var _RSe = "ResourcesScanned";
    var _RSes = "ResourceStatus";
    var _RSeso = "ResourcesSucceeded";
    var _RSo = "RollbackStack";
    var _RT13 = "ResourceType";
    var _RTD = "ResourceTargetDetails";
    var _RTDe = "ResourceTargetDefinition";
    var _RTI = "ResourcesToImport";
    var _RTIe = "RegisterTypeInput";
    var _RTIes = "ResourceToImport";
    var _RTL = "RegistrationTokenList";
    var _RTO = "RegisterTypeOutput";
    var _RTP = "ResourceTypePrefix";
    var _RTS = "ResourcesToSkip";
    var _RTe = "ResourceTypes";
    var _RTeg = "RegistrationToken";
    var _RTegi = "RegisterType";
    var _RTo = "RollbackTriggers";
    var _RTol = "RollbackTrigger";
    var _RV = "ResolvedValue";
    var _Re = "Regions";
    var _Rea = "Reason";
    var _Reg = "Region";
    var _Rep = "Replacement";
    var _Req = "Required";
    var _S = "Status";
    var _SA = "StagesAvailable";
    var _SD = "StackDefinitions";
    var _SDDI = "StackDriftDetectionId";
    var _SDI = "StackDriftInformation";
    var _SDIS = "StackDriftInformationSummary";
    var _SDS = "StackDriftStatus";
    var _SDt = "StackDefinition";
    var _SDta = "StatusDetails";
    var _SE = "StackEvents";
    var _SEt = "StackEvent";
    var _SF = "ScanFilters";
    var _SFc = "ScanFilter";
    var _SHP = "SchemaHandlerPackage";
    var _SI10 = "StackId";
    var _SIA = "StackInstanceAccount";
    var _SICS = "StackInstanceComprehensiveStatus";
    var _SIF = "StackInstanceFilter";
    var _SIFt = "StackInstanceFilters";
    var _SINFE = "StackInstanceNotFoundException";
    var _SIR = "StackInstanceRegion";
    var _SIRDS = "StackInstanceResourceDriftStatuses";
    var _SIRDSt = "StackInstanceResourceDriftsSummary";
    var _SIRDSta = "StackInstanceResourceDriftsSummaries";
    var _SIS = "StackInstanceStatus";
    var _SISt = "StackInstanceSummary";
    var _SISta = "StackInstanceSummaries";
    var _SIU = "StackIdsUrl";
    var _SIt = "StackInstance";
    var _SIta = "StackIds";
    var _SL = "SeverityLevel";
    var _SM = "StatusMessage";
    var _SMV = "SupportedMajorVersions";
    var _SN10 = "StackName";
    var _SNFE = "StackNotFoundException";
    var _SPB = "StackPolicyBody";
    var _SPDUB = "StackPolicyDuringUpdateBody";
    var _SPDUURL = "StackPolicyDuringUpdateURL";
    var _SPURL = "StackPolicyURL";
    var _SR = "StatusReason";
    var _SRA = "StackRefactorActions";
    var _SRAt = "StackRefactorAction";
    var _SRD = "StackResourceDrifts";
    var _SRDI = "StackResourceDriftInformation";
    var _SRDIS = "StackResourceDriftInformationSummary";
    var _SRDS = "StackResourceDriftStatus";
    var _SRDSF = "StackResourceDriftStatusFilters";
    var _SRDt = "StackResourceDetail";
    var _SRDta = "StackResourceDrift";
    var _SRE = "StaleRequestException";
    var _SRI = "StackRefactorId";
    var _SRIc = "ScannedResourceIdentifier";
    var _SRIca = "ScannedResourceIdentifiers";
    var _SRIi = "SignalResourceInput";
    var _SRNFE = "StackRefactorNotFoundException";
    var _SRS = "StackRefactorSummaries";
    var _SRSI = "StartResourceScanInput";
    var _SRSO = "StartResourceScanOutput";
    var _SRSt = "StackResourceSummaries";
    var _SRSta = "StackRefactorSummary";
    var _SRStac = "StackResourceSummary";
    var _SRStar = "StartResourceScan";
    var _SRTR = "StackRefactorTagResources";
    var _SRc = "ScannedResource";
    var _SRca = "ScannedResources";
    var _SRi = "SignalResource";
    var _SRt = "StackResources";
    var _SRta = "StackResource";
    var _SS = "StackSet";
    var _SSADTS = "StackSetAutoDeploymentTargetSummary";
    var _SSADTSt = "StackSetAutoDeploymentTargetSummaries";
    var _SSARN = "StackSetARN";
    var _SSDDD = "StackSetDriftDetectionDetails";
    var _SSF = "StackStatusFilter";
    var _SSI = "StackSetId";
    var _SSN = "StackSetName";
    var _SSNEE = "StackSetNotEmptyException";
    var _SSNFE = "StackSetNotFoundException";
    var _SSO = "StackSetOperation";
    var _SSOP = "StackSetOperationPreferences";
    var _SSORS = "StackSetOperationResultSummary";
    var _SSORSt = "StackSetOperationResultSummaries";
    var _SSOS = "StackSetOperationSummary";
    var _SSOSD = "StackSetOperationStatusDetails";
    var _SSOSt = "StackSetOperationSummaries";
    var _SSP = "SetStackPolicy";
    var _SSPI = "SetStackPolicyInput";
    var _SSR = "StackStatusReason";
    var _SSS = "StackSetSummary";
    var _SSSO = "StopStackSetOperation";
    var _SSSOI = "StopStackSetOperationInput";
    var _SSSOO = "StopStackSetOperationOutput";
    var _SSSt = "StackSetSummaries";
    var _SSt = "StackSummaries";
    var _SSta = "StackStatus";
    var _SStac = "StackSummary";
    var _ST11 = "StartTime";
    var _STC = "SetTypeConfiguration";
    var _STCI = "SetTypeConfigurationInput";
    var _STCO = "SetTypeConfigurationOutput";
    var _STDV = "SetTypeDefaultVersion";
    var _STDVI = "SetTypeDefaultVersionInput";
    var _STDVO = "SetTypeDefaultVersionOutput";
    var _STF = "ScanTypeFilter";
    var _STc = "ScanType";
    var _SU = "SourceUrl";
    var _Sc = "Schema";
    var _Sco = "Scope";
    var _So = "Source";
    var _St = "Stacks";
    var _Sta = "Stack";
    var _Su = "Summaries";
    var _T10 = "Type";
    var _TA = "TypeArn";
    var _TAEE = "TokenAlreadyExistsException";
    var _TB = "TemplateBody";
    var _TC10 = "TypeConfigurations";
    var _TCA = "TypeConfigurationAlias";
    var _TCAy = "TypeConfigurationArn";
    var _TCD = "TypeConfigurationDetails";
    var _TCDL = "TypeConfigurationDetailsList";
    var _TCI = "TypeConfigurationIdentifier";
    var _TCIy = "TypeConfigurationIdentifiers";
    var _TCNFE = "TypeConfigurationNotFoundException";
    var _TCVI = "TypeConfigurationVersionId";
    var _TCe = "TemplateConfiguration";
    var _TCi = "TimeCreated";
    var _TD = "TargetDetails";
    var _TDe = "TemplateDescription";
    var _TF = "TypeFilters";
    var _TH = "TypeHierarchy";
    var _TI = "TargetId";
    var _TIM = "TimeoutInMinutes";
    var _TK = "TagKey";
    var _TN = "TypeName";
    var _TNA = "TypeNameAlias";
    var _TNFE = "TypeNotFoundException";
    var _TNP = "TypeNamePrefix";
    var _TP = "TemplateParameter";
    var _TPe = "TemplateProgress";
    var _TPem = "TemplateParameters";
    var _TR = "TagResources";
    var _TS = "TemplateStage";
    var _TSC = "TemplateSummaryConfig";
    var _TSIC = "TotalStackInstancesCount";
    var _TSe = "TemplateSummary";
    var _TSem = "TemplateSummaries";
    var _TSy = "TypeSummaries";
    var _TSyp = "TypeSummary";
    var _TT = "TargetType";
    var _TTI = "TestTypeInput";
    var _TTN = "TargetTypeName";
    var _TTO = "TestTypeOutput";
    var _TTS = "TypeTestsStatus";
    var _TTSD = "TypeTestsStatusDescription";
    var _TTe = "TestType";
    var _TURL = "TemplateURL";
    var _TURTAW = "TreatUnrecognizedResourceTypesAsWarnings";
    var _TV = "TagValue";
    var _TVA = "TypeVersionArn";
    var _TVI = "TypeVersionId";
    var _TVS = "TypeVersionSummaries";
    var _TVSy = "TypeVersionSummary";
    var _TW = "TotalWarnings";
    var _Ta10 = "Tags";
    var _Tag = "Tag";
    var _Tar = "Target";
    var _Ti = "Timestamp";
    var _Ty = "Types";
    var _U = "Url";
    var _UGT = "UpdateGeneratedTemplate";
    var _UGTI = "UpdateGeneratedTemplateInput";
    var _UGTO = "UpdateGeneratedTemplateOutput";
    var _UI = "UniqueId";
    var _UPT = "UsePreviousTemplate";
    var _UPV = "UsePreviousValue";
    var _UR = "UntagResources";
    var _URP = "UpdateReplacePolicy";
    var _URT = "UnrecognizedResourceTypes";
    var _US = "UpdateStack";
    var _USI = "UpdateStackInput";
    var _USII = "UpdateStackInstancesInput";
    var _USIO = "UpdateStackInstancesOutput";
    var _USIp = "UpdateStackInstances";
    var _USO = "UpdateStackOutput";
    var _USS = "UpdateStackSet";
    var _USSI = "UpdateStackSetInput";
    var _USSO = "UpdateStackSetOutput";
    var _UTC = "UnprocessedTypeConfigurations";
    var _UTP = "UpdateTerminationProtection";
    var _UTPI = "UpdateTerminationProtectionInput";
    var _UTPO = "UpdateTerminationProtectionOutput";
    var _V10 = "Value";
    var _VB = "VersionBump";
    var _VFM = "ValidationFailureMode";
    var _VI = "VersionId";
    var _VN = "ValidationName";
    var _VP = "ValidationPath";
    var _VS = "ValidationStatus";
    var _VSR = "ValidationStatusReason";
    var _VT = "ValidateTemplate";
    var _VTI = "ValidateTemplateInput";
    var _VTO = "ValidateTemplateOutput";
    var _Va = "Values";
    var _Ve = "Version";
    var _Vi = "Visibility";
    var _W = "Warnings";
    var _WD = "WarningDetail";
    var _WDa = "WarningDetails";
    var _WP = "WarningProperty";
    var _WPa = "WarningProperties";
    var _aQE10 = "awsQueryError";
    var _c32 = "client";
    var _e32 = "error";
    var _hE32 = "httpError";
    var _s32 = "smithy.ts.sdk.synthetic.com.amazonaws.cloudformation";
    var n032 = "com.amazonaws.cloudformation";
    var schema_1 = (init_schema4(), __toCommonJS(schema_exports));
    var CloudFormationServiceException_1 = require_CloudFormationServiceException();
    var errors_1 = require_errors5();
    var _s_registry32 = schema_1.TypeRegistry.for(_s32);
    exports2.CloudFormationServiceException$ = [-3, _s32, "CloudFormationServiceException", 0, [], []];
    _s_registry32.registerError(exports2.CloudFormationServiceException$, CloudFormationServiceException_1.CloudFormationServiceException);
    var n0_registry32 = schema_1.TypeRegistry.for(n032);
    exports2.AlreadyExistsException$ = [
      -3,
      n032,
      _AEE,
      { [_aQE10]: [`AlreadyExistsException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.AlreadyExistsException$, errors_1.AlreadyExistsException);
    exports2.CFNRegistryException$ = [
      -3,
      n032,
      _CFNRE,
      { [_aQE10]: [`CFNRegistryException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.CFNRegistryException$, errors_1.CFNRegistryException);
    exports2.ChangeSetNotFoundException$ = [
      -3,
      n032,
      _CSNFE,
      { [_aQE10]: [`ChangeSetNotFound`, 404], [_e32]: _c32, [_hE32]: 404 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ChangeSetNotFoundException$, errors_1.ChangeSetNotFoundException);
    exports2.ConcurrentResourcesLimitExceededException$ = [
      -3,
      n032,
      _CRLEE,
      { [_aQE10]: [`ConcurrentResourcesLimitExceeded`, 429], [_e32]: _c32, [_hE32]: 429 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ConcurrentResourcesLimitExceededException$, errors_1.ConcurrentResourcesLimitExceededException);
    exports2.CreatedButModifiedException$ = [
      -3,
      n032,
      _CBME,
      { [_aQE10]: [`CreatedButModifiedException`, 409], [_e32]: _c32, [_hE32]: 409 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.CreatedButModifiedException$, errors_1.CreatedButModifiedException);
    exports2.GeneratedTemplateNotFoundException$ = [
      -3,
      n032,
      _GTNFE,
      { [_aQE10]: [`GeneratedTemplateNotFound`, 404], [_e32]: _c32, [_hE32]: 404 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.GeneratedTemplateNotFoundException$, errors_1.GeneratedTemplateNotFoundException);
    exports2.HookResultNotFoundException$ = [
      -3,
      n032,
      _HRNFE,
      { [_aQE10]: [`HookResultNotFound`, 404], [_e32]: _c32, [_hE32]: 404 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.HookResultNotFoundException$, errors_1.HookResultNotFoundException);
    exports2.InsufficientCapabilitiesException$ = [
      -3,
      n032,
      _ICE4,
      { [_aQE10]: [`InsufficientCapabilitiesException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InsufficientCapabilitiesException$, errors_1.InsufficientCapabilitiesException);
    exports2.InvalidChangeSetStatusException$ = [
      -3,
      n032,
      _ICSSE,
      { [_aQE10]: [`InvalidChangeSetStatus`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidChangeSetStatusException$, errors_1.InvalidChangeSetStatusException);
    exports2.InvalidOperationException$ = [
      -3,
      n032,
      _IOE,
      { [_aQE10]: [`InvalidOperationException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidOperationException$, errors_1.InvalidOperationException);
    exports2.InvalidStateTransitionException$ = [
      -3,
      n032,
      _ISTE,
      { [_aQE10]: [`InvalidStateTransition`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidStateTransitionException$, errors_1.InvalidStateTransitionException);
    exports2.LimitExceededException$ = [
      -3,
      n032,
      _LEE2,
      { [_aQE10]: [`LimitExceededException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.LimitExceededException$, errors_1.LimitExceededException);
    exports2.NameAlreadyExistsException$ = [
      -3,
      n032,
      _NAEE,
      { [_aQE10]: [`NameAlreadyExistsException`, 409], [_e32]: _c32, [_hE32]: 409 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.NameAlreadyExistsException$, errors_1.NameAlreadyExistsException);
    exports2.OperationIdAlreadyExistsException$ = [
      -3,
      n032,
      _OIAEE,
      { [_aQE10]: [`OperationIdAlreadyExistsException`, 409], [_e32]: _c32, [_hE32]: 409 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.OperationIdAlreadyExistsException$, errors_1.OperationIdAlreadyExistsException);
    exports2.OperationInProgressException$ = [
      -3,
      n032,
      _OIPE,
      { [_aQE10]: [`OperationInProgressException`, 409], [_e32]: _c32, [_hE32]: 409 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.OperationInProgressException$, errors_1.OperationInProgressException);
    exports2.OperationNotFoundException$ = [
      -3,
      n032,
      _ONFE,
      { [_aQE10]: [`OperationNotFoundException`, 404], [_e32]: _c32, [_hE32]: 404 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.OperationNotFoundException$, errors_1.OperationNotFoundException);
    exports2.OperationStatusCheckFailedException$ = [
      -3,
      n032,
      _OSCFE,
      { [_aQE10]: [`ConditionalCheckFailed`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.OperationStatusCheckFailedException$, errors_1.OperationStatusCheckFailedException);
    exports2.ResourceScanInProgressException$ = [
      -3,
      n032,
      _RSIPE,
      { [_aQE10]: [`ResourceScanInProgress`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ResourceScanInProgressException$, errors_1.ResourceScanInProgressException);
    exports2.ResourceScanLimitExceededException$ = [
      -3,
      n032,
      _RSLEE,
      { [_aQE10]: [`ResourceScanLimitExceeded`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ResourceScanLimitExceededException$, errors_1.ResourceScanLimitExceededException);
    exports2.ResourceScanNotFoundException$ = [
      -3,
      n032,
      _RSNFE,
      { [_aQE10]: [`ResourceScanNotFound`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ResourceScanNotFoundException$, errors_1.ResourceScanNotFoundException);
    exports2.StackInstanceNotFoundException$ = [
      -3,
      n032,
      _SINFE,
      { [_aQE10]: [`StackInstanceNotFoundException`, 404], [_e32]: _c32, [_hE32]: 404 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.StackInstanceNotFoundException$, errors_1.StackInstanceNotFoundException);
    exports2.StackNotFoundException$ = [
      -3,
      n032,
      _SNFE,
      { [_aQE10]: [`StackNotFoundException`, 404], [_e32]: _c32, [_hE32]: 404 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.StackNotFoundException$, errors_1.StackNotFoundException);
    exports2.StackRefactorNotFoundException$ = [
      -3,
      n032,
      _SRNFE,
      { [_aQE10]: [`StackRefactorNotFoundException`, 404], [_e32]: _c32, [_hE32]: 404 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.StackRefactorNotFoundException$, errors_1.StackRefactorNotFoundException);
    exports2.StackSetNotEmptyException$ = [
      -3,
      n032,
      _SSNEE,
      { [_aQE10]: [`StackSetNotEmptyException`, 409], [_e32]: _c32, [_hE32]: 409 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.StackSetNotEmptyException$, errors_1.StackSetNotEmptyException);
    exports2.StackSetNotFoundException$ = [
      -3,
      n032,
      _SSNFE,
      { [_aQE10]: [`StackSetNotFoundException`, 404], [_e32]: _c32, [_hE32]: 404 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.StackSetNotFoundException$, errors_1.StackSetNotFoundException);
    exports2.StaleRequestException$ = [
      -3,
      n032,
      _SRE,
      { [_aQE10]: [`StaleRequestException`, 409], [_e32]: _c32, [_hE32]: 409 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.StaleRequestException$, errors_1.StaleRequestException);
    exports2.TokenAlreadyExistsException$ = [
      -3,
      n032,
      _TAEE,
      { [_aQE10]: [`TokenAlreadyExistsException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.TokenAlreadyExistsException$, errors_1.TokenAlreadyExistsException);
    exports2.TypeConfigurationNotFoundException$ = [
      -3,
      n032,
      _TCNFE,
      { [_aQE10]: [`TypeConfigurationNotFoundException`, 404], [_e32]: _c32, [_hE32]: 404 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.TypeConfigurationNotFoundException$, errors_1.TypeConfigurationNotFoundException);
    exports2.TypeNotFoundException$ = [
      -3,
      n032,
      _TNFE,
      { [_aQE10]: [`TypeNotFoundException`, 404], [_e32]: _c32, [_hE32]: 404 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.TypeNotFoundException$, errors_1.TypeNotFoundException);
    exports2.errorTypeRegistries = [
      _s_registry32,
      n0_registry32
    ];
    exports2.AccountGateResult$ = [
      3,
      n032,
      _AGR,
      0,
      [_S, _SR],
      [0, 0]
    ];
    exports2.AccountLimit$ = [
      3,
      n032,
      _AL,
      0,
      [_N, _V10],
      [0, 1]
    ];
    exports2.ActivateOrganizationsAccessInput$ = [
      3,
      n032,
      _AOAI,
      0,
      [],
      []
    ];
    exports2.ActivateOrganizationsAccessOutput$ = [
      3,
      n032,
      _AOAO,
      0,
      [],
      []
    ];
    exports2.ActivateTypeInput$ = [
      3,
      n032,
      _ATI,
      0,
      [_T10, _PTA, _PI10, _TN, _TNA, _AU, _LC, _ERA, _VB, _MV],
      [0, 0, 0, 0, 0, 2, () => exports2.LoggingConfig$, 0, 0, 1]
    ];
    exports2.ActivateTypeOutput$ = [
      3,
      n032,
      _ATO,
      0,
      [_A10],
      [0]
    ];
    exports2.Annotation$ = [
      3,
      n032,
      _An,
      0,
      [_AN, _S, _SM, _RM, _RL, _SL],
      [0, 0, 0, 0, 0, 0]
    ];
    exports2.AutoDeployment$ = [
      3,
      n032,
      _AD,
      0,
      [_E11, _RSOAR, _DO],
      [2, 2, 64 | 0]
    ];
    exports2.BatchDescribeTypeConfigurationsError$ = [
      3,
      n032,
      _BDTCE,
      0,
      [_EC, _EM, _TCI],
      [0, 0, () => exports2.TypeConfigurationIdentifier$]
    ];
    exports2.BatchDescribeTypeConfigurationsInput$ = [
      3,
      n032,
      _BDTCI,
      0,
      [_TCIy],
      [() => TypeConfigurationIdentifiers],
      1
    ];
    exports2.BatchDescribeTypeConfigurationsOutput$ = [
      3,
      n032,
      _BDTCO,
      0,
      [_Er, _UTC, _TC10],
      [() => BatchDescribeTypeConfigurationsErrors, () => UnprocessedTypeConfigurations, () => TypeConfigurationDetailsList]
    ];
    exports2.CancelUpdateStackInput$ = [
      3,
      n032,
      _CUSI,
      0,
      [_SN10, _CRT],
      [0, 0],
      1
    ];
    exports2.Change$ = [
      3,
      n032,
      _C11,
      0,
      [_T10, _HIC, _RC10],
      [0, 1, () => exports2.ResourceChange$]
    ];
    exports2.ChangeSetHook$ = [
      3,
      n032,
      _CSH,
      0,
      [_IP, _FM, _TN, _TVI, _TCVI, _TD],
      [0, 0, 0, 0, 0, () => exports2.ChangeSetHookTargetDetails$]
    ];
    exports2.ChangeSetHookResourceTargetDetails$ = [
      3,
      n032,
      _CSHRTD,
      0,
      [_LRI, _RT13, _RA10],
      [0, 0, 0]
    ];
    exports2.ChangeSetHookTargetDetails$ = [
      3,
      n032,
      _CSHTD,
      0,
      [_TT, _RTD],
      [0, () => exports2.ChangeSetHookResourceTargetDetails$]
    ];
    exports2.ChangeSetSummary$ = [
      3,
      n032,
      _CSS,
      0,
      [_SI10, _SN10, _CSI, _CSN, _ES, _S, _SR, _CT4, _D, _INS, _PCSI, _RCSI, _IER],
      [0, 0, 0, 0, 0, 0, 0, 4, 0, 2, 0, 0, 2]
    ];
    exports2.ContinueUpdateRollbackInput$ = [
      3,
      n032,
      _CURI,
      0,
      [_SN10, _RARN, _RTS, _CRT],
      [0, 0, 64 | 0, 0],
      1
    ];
    exports2.ContinueUpdateRollbackOutput$ = [
      3,
      n032,
      _CURO,
      0,
      [],
      []
    ];
    exports2.CreateChangeSetInput$ = [
      3,
      n032,
      _CCSI,
      0,
      [_SN10, _CSN, _TB, _TURL, _UPT, _P10, _Ca, _RTe, _RARN, _RCo, _NARN, _Ta10, _CTl, _D, _CST, _RTI, _INS, _OSF, _IER, _DM],
      [0, 0, 0, 0, 2, () => _Parameters, 64 | 0, 64 | 0, 0, () => exports2.RollbackConfiguration$, 64 | 0, () => Tags, 0, 0, 0, () => ResourcesToImport, 2, 0, 2, 0],
      2
    ];
    exports2.CreateChangeSetOutput$ = [
      3,
      n032,
      _CCSO,
      0,
      [_I, _SI10],
      [0, 0]
    ];
    exports2.CreateGeneratedTemplateInput$ = [
      3,
      n032,
      _CGTI,
      0,
      [_GTN, _R, _SN10, _TCe],
      [0, () => ResourceDefinitions, 0, () => exports2.TemplateConfiguration$],
      1
    ];
    exports2.CreateGeneratedTemplateOutput$ = [
      3,
      n032,
      _CGTO,
      0,
      [_GTI],
      [0]
    ];
    exports2.CreateStackInput$ = [
      3,
      n032,
      _CSIr,
      0,
      [_SN10, _TB, _TURL, _P10, _DR, _RCo, _TIM, _NARN, _Ca, _RTe, _RARN, _OF, _SPB, _SPURL, _Ta10, _CRT, _ETP, _REOC],
      [0, 0, 0, () => _Parameters, 2, () => exports2.RollbackConfiguration$, 1, 64 | 0, 64 | 0, 64 | 0, 0, 0, 0, 0, () => Tags, 0, 2, 2],
      1
    ];
    exports2.CreateStackInstancesInput$ = [
      3,
      n032,
      _CSII,
      0,
      [_SSN, _Re, _Ac, _DT, _PO, _OP, _OI, _CA10],
      [0, 64 | 0, 64 | 0, () => exports2.DeploymentTargets$, () => _Parameters, () => exports2.StackSetOperationPreferences$, [0, 4], 0],
      2
    ];
    exports2.CreateStackInstancesOutput$ = [
      3,
      n032,
      _CSIO,
      0,
      [_OI],
      [0]
    ];
    exports2.CreateStackOutput$ = [
      3,
      n032,
      _CSO,
      0,
      [_SI10, _OI],
      [0, 0]
    ];
    exports2.CreateStackRefactorInput$ = [
      3,
      n032,
      _CSRI,
      0,
      [_SD, _D, _ESC, _RMe],
      [() => StackDefinitions, 0, 2, () => ResourceMappings],
      1
    ];
    exports2.CreateStackRefactorOutput$ = [
      3,
      n032,
      _CSRO,
      0,
      [_SRI],
      [0],
      1
    ];
    exports2.CreateStackSetInput$ = [
      3,
      n032,
      _CSSI,
      0,
      [_SSN, _D, _TB, _TURL, _SI10, _P10, _Ca, _Ta10, _ARARN, _ERN, _PM, _AD, _CA10, _CRT, _ME],
      [0, 0, 0, 0, 0, () => _Parameters, 64 | 0, () => Tags, 0, 0, 0, () => exports2.AutoDeployment$, 0, [0, 4], () => exports2.ManagedExecution$],
      1
    ];
    exports2.CreateStackSetOutput$ = [
      3,
      n032,
      _CSSO,
      0,
      [_SSI],
      [0]
    ];
    exports2.DeactivateOrganizationsAccessInput$ = [
      3,
      n032,
      _DOAI,
      0,
      [],
      []
    ];
    exports2.DeactivateOrganizationsAccessOutput$ = [
      3,
      n032,
      _DOAO,
      0,
      [],
      []
    ];
    exports2.DeactivateTypeInput$ = [
      3,
      n032,
      _DTI,
      0,
      [_TN, _T10, _A10],
      [0, 0, 0]
    ];
    exports2.DeactivateTypeOutput$ = [
      3,
      n032,
      _DTO,
      0,
      [],
      []
    ];
    exports2.DeleteChangeSetInput$ = [
      3,
      n032,
      _DCSI,
      0,
      [_CSN, _SN10],
      [0, 0],
      1
    ];
    exports2.DeleteChangeSetOutput$ = [
      3,
      n032,
      _DCSO,
      0,
      [],
      []
    ];
    exports2.DeleteGeneratedTemplateInput$ = [
      3,
      n032,
      _DGTI,
      0,
      [_GTN],
      [0],
      1
    ];
    exports2.DeleteStackInput$ = [
      3,
      n032,
      _DSI,
      0,
      [_SN10, _RR, _RARN, _CRT, _DMe],
      [0, 64 | 0, 0, 0, 0],
      1
    ];
    exports2.DeleteStackInstancesInput$ = [
      3,
      n032,
      _DSII,
      0,
      [_SSN, _Re, _RS, _Ac, _DT, _OP, _OI, _CA10],
      [0, 64 | 0, 2, 64 | 0, () => exports2.DeploymentTargets$, () => exports2.StackSetOperationPreferences$, [0, 4], 0],
      3
    ];
    exports2.DeleteStackInstancesOutput$ = [
      3,
      n032,
      _DSIO,
      0,
      [_OI],
      [0]
    ];
    exports2.DeleteStackSetInput$ = [
      3,
      n032,
      _DSSI,
      0,
      [_SSN, _CA10],
      [0, 0],
      1
    ];
    exports2.DeleteStackSetOutput$ = [
      3,
      n032,
      _DSSO,
      0,
      [],
      []
    ];
    exports2.DeploymentTargets$ = [
      3,
      n032,
      _DT,
      0,
      [_Ac, _AUc, _OUI, _AFT],
      [64 | 0, 0, 64 | 0, 0]
    ];
    exports2.DeregisterTypeInput$ = [
      3,
      n032,
      _DTIe,
      0,
      [_A10, _T10, _TN, _VI],
      [0, 0, 0, 0]
    ];
    exports2.DeregisterTypeOutput$ = [
      3,
      n032,
      _DTOe,
      0,
      [],
      []
    ];
    exports2.DescribeAccountLimitsInput$ = [
      3,
      n032,
      _DALI,
      0,
      [_NT],
      [0]
    ];
    exports2.DescribeAccountLimitsOutput$ = [
      3,
      n032,
      _DALO,
      0,
      [_ALc, _NT],
      [() => AccountLimitList, 0]
    ];
    exports2.DescribeChangeSetHooksInput$ = [
      3,
      n032,
      _DCSHI,
      0,
      [_CSN, _SN10, _NT, _LRI],
      [0, 0, 0, 0],
      1
    ];
    exports2.DescribeChangeSetHooksOutput$ = [
      3,
      n032,
      _DCSHO,
      0,
      [_CSI, _CSN, _H, _S, _NT, _SI10, _SN10],
      [0, 0, () => ChangeSetHooks, 0, 0, 0, 0]
    ];
    exports2.DescribeChangeSetInput$ = [
      3,
      n032,
      _DCSIe,
      0,
      [_CSN, _SN10, _NT, _IPV],
      [0, 0, 0, 2],
      1
    ];
    exports2.DescribeChangeSetOutput$ = [
      3,
      n032,
      _DCSOe,
      0,
      [_CSN, _CSI, _SI10, _SN10, _D, _P10, _CT4, _ES, _S, _SR, _SDS, _NARN, _RCo, _Ca, _Ta10, _Ch, _NT, _INS, _PCSI, _RCSI, _OSF, _IER, _DM],
      [0, 0, 0, 0, 0, () => _Parameters, 4, 0, 0, 0, 0, 64 | 0, () => exports2.RollbackConfiguration$, 64 | 0, () => Tags, () => Changes, 0, 2, 0, 0, 0, 2, 0]
    ];
    exports2.DescribeEventsInput$ = [
      3,
      n032,
      _DEI,
      0,
      [_SN10, _CSN, _OI, _F, _NT],
      [0, 0, 0, () => exports2.EventFilter$, 0]
    ];
    exports2.DescribeEventsOutput$ = [
      3,
      n032,
      _DEO,
      0,
      [_OE, _NT],
      [() => OperationEvents, 0]
    ];
    exports2.DescribeGeneratedTemplateInput$ = [
      3,
      n032,
      _DGTIe,
      0,
      [_GTN],
      [0],
      1
    ];
    exports2.DescribeGeneratedTemplateOutput$ = [
      3,
      n032,
      _DGTO,
      0,
      [_GTI, _GTN, _R, _S, _SR, _CT4, _LUT, _Pr10, _SI10, _TCe, _TW],
      [0, 0, () => ResourceDetails, 0, 0, 4, 4, () => exports2.TemplateProgress$, 0, () => exports2.TemplateConfiguration$, 1]
    ];
    exports2.DescribeOrganizationsAccessInput$ = [
      3,
      n032,
      _DOAIe,
      0,
      [_CA10],
      [0]
    ];
    exports2.DescribeOrganizationsAccessOutput$ = [
      3,
      n032,
      _DOAOe,
      0,
      [_S],
      [0]
    ];
    exports2.DescribePublisherInput$ = [
      3,
      n032,
      _DPI,
      0,
      [_PI10],
      [0]
    ];
    exports2.DescribePublisherOutput$ = [
      3,
      n032,
      _DPO,
      0,
      [_PI10, _PS, _IPd, _PP],
      [0, 0, 0, 0]
    ];
    exports2.DescribeResourceScanInput$ = [
      3,
      n032,
      _DRSI,
      0,
      [_RSI],
      [0],
      1
    ];
    exports2.DescribeResourceScanOutput$ = [
      3,
      n032,
      _DRSO,
      0,
      [_RSI, _S, _SR, _ST11, _ET, _PC10, _RTe, _RSe, _RRe, _SF],
      [0, 0, 0, 4, 4, 1, 64 | 0, 1, 1, () => ScanFilters]
    ];
    exports2.DescribeStackDriftDetectionStatusInput$ = [
      3,
      n032,
      _DSDDSI,
      0,
      [_SDDI],
      [0],
      1
    ];
    exports2.DescribeStackDriftDetectionStatusOutput$ = [
      3,
      n032,
      _DSDDSO,
      0,
      [_SI10, _SDDI, _DS10, _Ti, _SDS, _DSR, _DSRC],
      [0, 0, 0, 4, 0, 0, 1],
      4
    ];
    exports2.DescribeStackEventsInput$ = [
      3,
      n032,
      _DSEI,
      0,
      [_SN10, _NT],
      [0, 0],
      1
    ];
    exports2.DescribeStackEventsOutput$ = [
      3,
      n032,
      _DSEO,
      0,
      [_SE, _NT],
      [() => StackEvents, 0]
    ];
    exports2.DescribeStackInstanceInput$ = [
      3,
      n032,
      _DSIIe,
      0,
      [_SSN, _SIA, _SIR, _CA10],
      [0, 0, 0, 0],
      3
    ];
    exports2.DescribeStackInstanceOutput$ = [
      3,
      n032,
      _DSIOe,
      0,
      [_SIt],
      [() => exports2.StackInstance$]
    ];
    exports2.DescribeStackRefactorInput$ = [
      3,
      n032,
      _DSRI,
      0,
      [_SRI],
      [0],
      1
    ];
    exports2.DescribeStackRefactorOutput$ = [
      3,
      n032,
      _DSRO,
      0,
      [_D, _SRI, _SIta, _ES, _ESR, _S, _SR],
      [0, 0, 64 | 0, 0, 0, 0, 0]
    ];
    exports2.DescribeStackResourceDriftsInput$ = [
      3,
      n032,
      _DSRDI,
      0,
      [_SN10, _SRDSF, _NT, _MR],
      [0, 64 | 0, 0, 1],
      1
    ];
    exports2.DescribeStackResourceDriftsOutput$ = [
      3,
      n032,
      _DSRDO,
      0,
      [_SRD, _NT],
      [() => StackResourceDrifts, 0],
      1
    ];
    exports2.DescribeStackResourceInput$ = [
      3,
      n032,
      _DSRIe,
      0,
      [_SN10, _LRI],
      [0, 0],
      2
    ];
    exports2.DescribeStackResourceOutput$ = [
      3,
      n032,
      _DSROe,
      0,
      [_SRDt],
      [() => exports2.StackResourceDetail$]
    ];
    exports2.DescribeStackResourcesInput$ = [
      3,
      n032,
      _DSRIes,
      0,
      [_SN10, _LRI, _PRI],
      [0, 0, 0]
    ];
    exports2.DescribeStackResourcesOutput$ = [
      3,
      n032,
      _DSROes,
      0,
      [_SRt],
      [() => StackResources]
    ];
    exports2.DescribeStackSetInput$ = [
      3,
      n032,
      _DSSIe,
      0,
      [_SSN, _CA10],
      [0, 0],
      1
    ];
    exports2.DescribeStackSetOperationInput$ = [
      3,
      n032,
      _DSSOI,
      0,
      [_SSN, _OI, _CA10],
      [0, 0, 0],
      2
    ];
    exports2.DescribeStackSetOperationOutput$ = [
      3,
      n032,
      _DSSOO,
      0,
      [_SSO],
      [() => exports2.StackSetOperation$]
    ];
    exports2.DescribeStackSetOutput$ = [
      3,
      n032,
      _DSSOe,
      0,
      [_SS],
      [() => exports2.StackSet$]
    ];
    exports2.DescribeStacksInput$ = [
      3,
      n032,
      _DSIe,
      0,
      [_SN10, _NT],
      [0, 0]
    ];
    exports2.DescribeStacksOutput$ = [
      3,
      n032,
      _DSO,
      0,
      [_St, _NT],
      [() => Stacks, 0]
    ];
    exports2.DescribeTypeInput$ = [
      3,
      n032,
      _DTIes,
      0,
      [_T10, _TN, _A10, _VI, _PI10, _PVN],
      [0, 0, 0, 0, 0, 0]
    ];
    exports2.DescribeTypeOutput$ = [
      3,
      n032,
      _DTOes,
      0,
      [_A10, _T10, _TN, _DVI, _IDV, _TTS, _TTSD, _D, _Sc, _PT, _DSe, _LC, _RAT, _ERA, _Vi, _SU, _DU, _LU, _TCi, _CS4, _PI10, _OTN, _OTA, _PVN, _LPV, _IA, _AU],
      [0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, () => exports2.LoggingConfig$, () => RequiredActivatedTypes, 0, 0, 0, 0, 4, 4, 0, 0, 0, 0, 0, 0, 2, 2]
    ];
    exports2.DescribeTypeRegistrationInput$ = [
      3,
      n032,
      _DTRI,
      0,
      [_RTeg],
      [0],
      1
    ];
    exports2.DescribeTypeRegistrationOutput$ = [
      3,
      n032,
      _DTRO,
      0,
      [_PSr, _D, _TA, _TVA],
      [0, 0, 0, 0]
    ];
    exports2.DetectStackDriftInput$ = [
      3,
      n032,
      _DSDI,
      0,
      [_SN10, _LRIo],
      [0, 64 | 0],
      1
    ];
    exports2.DetectStackDriftOutput$ = [
      3,
      n032,
      _DSDO,
      0,
      [_SDDI],
      [0],
      1
    ];
    exports2.DetectStackResourceDriftInput$ = [
      3,
      n032,
      _DSRDIe,
      0,
      [_SN10, _LRI],
      [0, 0],
      2
    ];
    exports2.DetectStackResourceDriftOutput$ = [
      3,
      n032,
      _DSRDOe,
      0,
      [_SRDta],
      [() => exports2.StackResourceDrift$],
      1
    ];
    exports2.DetectStackSetDriftInput$ = [
      3,
      n032,
      _DSSDI,
      0,
      [_SSN, _OP, _OI, _CA10],
      [0, () => exports2.StackSetOperationPreferences$, [0, 4], 0],
      1
    ];
    exports2.DetectStackSetDriftOutput$ = [
      3,
      n032,
      _DSSDO,
      0,
      [_OI],
      [0]
    ];
    exports2.EstimateTemplateCostInput$ = [
      3,
      n032,
      _ETCI,
      0,
      [_TB, _TURL, _P10],
      [0, 0, () => _Parameters]
    ];
    exports2.EstimateTemplateCostOutput$ = [
      3,
      n032,
      _ETCO,
      0,
      [_U],
      [0]
    ];
    exports2.EventFilter$ = [
      3,
      n032,
      _EF,
      0,
      [_FE],
      [2]
    ];
    exports2.ExecuteChangeSetInput$ = [
      3,
      n032,
      _ECSI,
      0,
      [_CSN, _SN10, _CRT, _DR, _REOC],
      [0, 0, 0, 2, 2],
      1
    ];
    exports2.ExecuteChangeSetOutput$ = [
      3,
      n032,
      _ECSO,
      0,
      [],
      []
    ];
    exports2.ExecuteStackRefactorInput$ = [
      3,
      n032,
      _ESRI,
      0,
      [_SRI],
      [0],
      1
    ];
    exports2.Export$ = [
      3,
      n032,
      _Ex,
      0,
      [_ESI, _N, _V10],
      [0, 0, 0]
    ];
    exports2.GetGeneratedTemplateInput$ = [
      3,
      n032,
      _GGTI,
      0,
      [_GTN, _Fo],
      [0, 0],
      1
    ];
    exports2.GetGeneratedTemplateOutput$ = [
      3,
      n032,
      _GGTO,
      0,
      [_S, _TB],
      [0, 0]
    ];
    exports2.GetHookResultInput$ = [
      3,
      n032,
      _GHRI,
      0,
      [_HRI],
      [0]
    ];
    exports2.GetHookResultOutput$ = [
      3,
      n032,
      _GHRO,
      0,
      [_HRI, _IP, _FM, _TN, _OTN, _TVI, _TCVI, _TA, _S, _HSR, _IAn, _Tar, _Ann],
      [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, () => exports2.HookTarget$, () => AnnotationList]
    ];
    exports2.GetStackPolicyInput$ = [
      3,
      n032,
      _GSPI,
      0,
      [_SN10],
      [0],
      1
    ];
    exports2.GetStackPolicyOutput$ = [
      3,
      n032,
      _GSPO,
      0,
      [_SPB],
      [0]
    ];
    exports2.GetTemplateInput$ = [
      3,
      n032,
      _GTIe,
      0,
      [_SN10, _CSN, _TS],
      [0, 0, 0]
    ];
    exports2.GetTemplateOutput$ = [
      3,
      n032,
      _GTO,
      0,
      [_TB, _SA],
      [0, 64 | 0]
    ];
    exports2.GetTemplateSummaryInput$ = [
      3,
      n032,
      _GTSI,
      0,
      [_TB, _TURL, _SN10, _SSN, _CA10, _TSC],
      [0, 0, 0, 0, 0, () => exports2.TemplateSummaryConfig$]
    ];
    exports2.GetTemplateSummaryOutput$ = [
      3,
      n032,
      _GTSO,
      0,
      [_P10, _D, _Ca, _CR, _RTe, _Ve, _Me, _DTe, _RIS, _W],
      [() => ParameterDeclarations, 0, 64 | 0, 0, 64 | 0, 0, 0, 64 | 0, () => ResourceIdentifierSummaries, () => exports2.Warnings$]
    ];
    exports2.HookResultSummary$ = [
      3,
      n032,
      _HRS,
      0,
      [_HRI, _IP, _FM, _TN, _TVI, _TCVI, _S, _HSR, _IAn, _TT, _TI, _TA, _HET],
      [0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0]
    ];
    exports2.HookTarget$ = [
      3,
      n032,
      _HT,
      0,
      [_TT, _TTN, _TI, _Act],
      [0, 0, 0, 0],
      4
    ];
    exports2.ImportStacksToStackSetInput$ = [
      3,
      n032,
      _ISTSSI,
      0,
      [_SSN, _SIta, _SIU, _OUI, _OP, _OI, _CA10],
      [0, 64 | 0, 0, 64 | 0, () => exports2.StackSetOperationPreferences$, [0, 4], 0],
      1
    ];
    exports2.ImportStacksToStackSetOutput$ = [
      3,
      n032,
      _ISTSSO,
      0,
      [_OI],
      [0]
    ];
    exports2.ListChangeSetsInput$ = [
      3,
      n032,
      _LCSI,
      0,
      [_SN10, _NT],
      [0, 0],
      1
    ];
    exports2.ListChangeSetsOutput$ = [
      3,
      n032,
      _LCSO,
      0,
      [_Su, _NT],
      [() => ChangeSetSummaries, 0]
    ];
    exports2.ListExportsInput$ = [
      3,
      n032,
      _LEI,
      0,
      [_NT],
      [0]
    ];
    exports2.ListExportsOutput$ = [
      3,
      n032,
      _LEO,
      0,
      [_Exp, _NT],
      [() => Exports, 0]
    ];
    exports2.ListGeneratedTemplatesInput$ = [
      3,
      n032,
      _LGTI,
      0,
      [_NT, _MR],
      [0, 1]
    ];
    exports2.ListGeneratedTemplatesOutput$ = [
      3,
      n032,
      _LGTO,
      0,
      [_Su, _NT],
      [() => TemplateSummaries, 0]
    ];
    exports2.ListHookResultsInput$ = [
      3,
      n032,
      _LHRI,
      0,
      [_TT, _TI, _TA, _S, _NT],
      [0, 0, 0, 0, 0]
    ];
    exports2.ListHookResultsOutput$ = [
      3,
      n032,
      _LHRO,
      0,
      [_TT, _TI, _HR, _NT],
      [0, 0, () => HookResultSummaries, 0]
    ];
    exports2.ListImportsInput$ = [
      3,
      n032,
      _LII,
      0,
      [_EN, _NT],
      [0, 0],
      1
    ];
    exports2.ListImportsOutput$ = [
      3,
      n032,
      _LIO,
      0,
      [_Im, _NT],
      [64 | 0, 0]
    ];
    exports2.ListResourceScanRelatedResourcesInput$ = [
      3,
      n032,
      _LRSRRI,
      0,
      [_RSI, _R, _NT, _MR],
      [0, () => ScannedResourceIdentifiers, 0, 1],
      2
    ];
    exports2.ListResourceScanRelatedResourcesOutput$ = [
      3,
      n032,
      _LRSRRO,
      0,
      [_RRel, _NT],
      [() => RelatedResources, 0]
    ];
    exports2.ListResourceScanResourcesInput$ = [
      3,
      n032,
      _LRSRI,
      0,
      [_RSI, _RI, _RTP, _TK, _TV, _NT, _MR],
      [0, 0, 0, 0, 0, 0, 1],
      1
    ];
    exports2.ListResourceScanResourcesOutput$ = [
      3,
      n032,
      _LRSRO,
      0,
      [_R, _NT],
      [() => ScannedResources, 0]
    ];
    exports2.ListResourceScansInput$ = [
      3,
      n032,
      _LRSI,
      0,
      [_NT, _MR, _STF],
      [0, 1, 0]
    ];
    exports2.ListResourceScansOutput$ = [
      3,
      n032,
      _LRSO,
      0,
      [_RSS, _NT],
      [() => ResourceScanSummaries, 0]
    ];
    exports2.ListStackInstanceResourceDriftsInput$ = [
      3,
      n032,
      _LSIRDI,
      0,
      [_SSN, _SIA, _SIR, _OI, _NT, _MR, _SIRDS, _CA10],
      [0, 0, 0, 0, 0, 1, 64 | 0, 0],
      4
    ];
    exports2.ListStackInstanceResourceDriftsOutput$ = [
      3,
      n032,
      _LSIRDO,
      0,
      [_Su, _NT],
      [() => StackInstanceResourceDriftsSummaries, 0]
    ];
    exports2.ListStackInstancesInput$ = [
      3,
      n032,
      _LSII,
      0,
      [_SSN, _NT, _MR, _F, _SIA, _SIR, _CA10],
      [0, 0, 1, () => StackInstanceFilters, 0, 0, 0],
      1
    ];
    exports2.ListStackInstancesOutput$ = [
      3,
      n032,
      _LSIO,
      0,
      [_Su, _NT],
      [() => StackInstanceSummaries, 0]
    ];
    exports2.ListStackRefactorActionsInput$ = [
      3,
      n032,
      _LSRAI,
      0,
      [_SRI, _NT, _MR],
      [0, 0, 1],
      1
    ];
    exports2.ListStackRefactorActionsOutput$ = [
      3,
      n032,
      _LSRAO,
      0,
      [_SRA, _NT],
      [() => StackRefactorActions, 0],
      1
    ];
    exports2.ListStackRefactorsInput$ = [
      3,
      n032,
      _LSRI,
      0,
      [_ESF, _NT, _MR],
      [64 | 0, 0, 1]
    ];
    exports2.ListStackRefactorsOutput$ = [
      3,
      n032,
      _LSRO,
      0,
      [_SRS, _NT],
      [() => StackRefactorSummaries, 0],
      1
    ];
    exports2.ListStackResourcesInput$ = [
      3,
      n032,
      _LSRIi,
      0,
      [_SN10, _NT],
      [0, 0],
      1
    ];
    exports2.ListStackResourcesOutput$ = [
      3,
      n032,
      _LSROi,
      0,
      [_SRSt, _NT],
      [() => StackResourceSummaries, 0]
    ];
    exports2.ListStackSetAutoDeploymentTargetsInput$ = [
      3,
      n032,
      _LSSADTI,
      0,
      [_SSN, _NT, _MR, _CA10],
      [0, 0, 1, 0],
      1
    ];
    exports2.ListStackSetAutoDeploymentTargetsOutput$ = [
      3,
      n032,
      _LSSADTO,
      0,
      [_Su, _NT],
      [() => StackSetAutoDeploymentTargetSummaries, 0]
    ];
    exports2.ListStackSetOperationResultsInput$ = [
      3,
      n032,
      _LSSORI,
      0,
      [_SSN, _OI, _NT, _MR, _CA10, _F],
      [0, 0, 0, 1, 0, () => OperationResultFilters],
      2
    ];
    exports2.ListStackSetOperationResultsOutput$ = [
      3,
      n032,
      _LSSORO,
      0,
      [_Su, _NT],
      [() => StackSetOperationResultSummaries, 0]
    ];
    exports2.ListStackSetOperationsInput$ = [
      3,
      n032,
      _LSSOI,
      0,
      [_SSN, _NT, _MR, _CA10],
      [0, 0, 1, 0],
      1
    ];
    exports2.ListStackSetOperationsOutput$ = [
      3,
      n032,
      _LSSOO,
      0,
      [_Su, _NT],
      [() => StackSetOperationSummaries, 0]
    ];
    exports2.ListStackSetsInput$ = [
      3,
      n032,
      _LSSI,
      0,
      [_NT, _MR, _S, _CA10],
      [0, 1, 0, 0]
    ];
    exports2.ListStackSetsOutput$ = [
      3,
      n032,
      _LSSO,
      0,
      [_Su, _NT],
      [() => StackSetSummaries, 0]
    ];
    exports2.ListStacksInput$ = [
      3,
      n032,
      _LSI,
      0,
      [_NT, _SSF],
      [0, 64 | 0]
    ];
    exports2.ListStacksOutput$ = [
      3,
      n032,
      _LSO,
      0,
      [_SSt, _NT],
      [() => StackSummaries, 0]
    ];
    exports2.ListTypeRegistrationsInput$ = [
      3,
      n032,
      _LTRI,
      0,
      [_T10, _TN, _TA, _RSF, _MR, _NT],
      [0, 0, 0, 0, 1, 0]
    ];
    exports2.ListTypeRegistrationsOutput$ = [
      3,
      n032,
      _LTRO,
      0,
      [_RTL, _NT],
      [64 | 0, 0]
    ];
    exports2.ListTypesInput$ = [
      3,
      n032,
      _LTI,
      0,
      [_Vi, _PT, _DSe, _T10, _F, _MR, _NT],
      [0, 0, 0, 0, () => exports2.TypeFilters$, 1, 0]
    ];
    exports2.ListTypesOutput$ = [
      3,
      n032,
      _LTO,
      0,
      [_TSy, _NT],
      [() => TypeSummaries, 0]
    ];
    exports2.ListTypeVersionsInput$ = [
      3,
      n032,
      _LTVI,
      0,
      [_T10, _TN, _A10, _MR, _NT, _DSe, _PI10],
      [0, 0, 0, 1, 0, 0, 0]
    ];
    exports2.ListTypeVersionsOutput$ = [
      3,
      n032,
      _LTVO,
      0,
      [_TVS, _NT],
      [() => TypeVersionSummaries, 0]
    ];
    exports2.LiveResourceDrift$ = [
      3,
      n032,
      _LRD,
      0,
      [_PV, _AV, _DDT],
      [0, 0, 4]
    ];
    exports2.LoggingConfig$ = [
      3,
      n032,
      _LC,
      0,
      [_LRA, _LGN],
      [0, 0],
      2
    ];
    exports2.ManagedExecution$ = [
      3,
      n032,
      _ME,
      0,
      [_Acti],
      [2]
    ];
    exports2.ModuleInfo$ = [
      3,
      n032,
      _MI,
      0,
      [_TH, _LIH],
      [0, 0]
    ];
    exports2.OperationEntry$ = [
      3,
      n032,
      _OEp,
      0,
      [_OT, _OI],
      [0, 0]
    ];
    exports2.OperationEvent$ = [
      3,
      n032,
      _OEpe,
      0,
      [_EI10, _SI10, _OI, _OT, _OS, _ETv, _LRI, _PRI, _RT13, _Ti, _ST11, _ET, _RSes, _RSR, _RP, _CRT, _HTo, _HS, _HSR, _HIP, _HFM, _DSet, _VFM, _VN, _VS, _VSR, _VP],
      [0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 4, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]
    ];
    exports2.OperationResultFilter$ = [
      3,
      n032,
      _ORF,
      0,
      [_N, _Va],
      [0, 0]
    ];
    exports2.Output$ = [
      3,
      n032,
      _O,
      0,
      [_OK, _OV, _D, _EN],
      [0, 0, 0, 0]
    ];
    exports2.Parameter$ = [
      3,
      n032,
      _Pa,
      0,
      [_PK, _PVa, _UPV, _RV],
      [0, 0, 2, 0]
    ];
    exports2.ParameterConstraints$ = [
      3,
      n032,
      _PCa,
      0,
      [_AVl],
      [64 | 0]
    ];
    exports2.ParameterDeclaration$ = [
      3,
      n032,
      _PD,
      0,
      [_PK, _DV, _PTa, _NE, _D, _PCa],
      [0, 0, 0, 2, 0, () => exports2.ParameterConstraints$]
    ];
    exports2.PhysicalResourceIdContextKeyValuePair$ = [
      3,
      n032,
      _PRICKVP,
      0,
      [_K10, _V10],
      [0, 0],
      2
    ];
    exports2.PropertyDifference$ = [
      3,
      n032,
      _PDr,
      0,
      [_PPr, _EV, _AV, _DTi],
      [0, 0, 0, 0],
      4
    ];
    exports2.PublishTypeInput$ = [
      3,
      n032,
      _PTI,
      0,
      [_T10, _A10, _TN, _PVN],
      [0, 0, 0, 0]
    ];
    exports2.PublishTypeOutput$ = [
      3,
      n032,
      _PTO,
      0,
      [_PTA],
      [0]
    ];
    exports2.RecordHandlerProgressInput$ = [
      3,
      n032,
      _RHPI,
      0,
      [_BT, _OS, _COS, _SM, _EC, _RMes, _CRT],
      [0, 0, 0, 0, 0, 0, 0],
      2
    ];
    exports2.RecordHandlerProgressOutput$ = [
      3,
      n032,
      _RHPO,
      0,
      [],
      []
    ];
    exports2.RegisterPublisherInput$ = [
      3,
      n032,
      _RPI,
      0,
      [_ATAC, _CAo],
      [2, 0]
    ];
    exports2.RegisterPublisherOutput$ = [
      3,
      n032,
      _RPO,
      0,
      [_PI10],
      [0]
    ];
    exports2.RegisterTypeInput$ = [
      3,
      n032,
      _RTIe,
      0,
      [_TN, _SHP, _T10, _LC, _ERA, _CRT],
      [0, 0, 0, () => exports2.LoggingConfig$, 0, 0],
      2
    ];
    exports2.RegisterTypeOutput$ = [
      3,
      n032,
      _RTO,
      0,
      [_RTeg],
      [0]
    ];
    exports2.RequiredActivatedType$ = [
      3,
      n032,
      _RATe,
      0,
      [_TNA, _OTN, _PI10, _SMV],
      [0, 0, 0, 64 | 1]
    ];
    exports2.ResourceChange$ = [
      3,
      n032,
      _RC10,
      0,
      [_PA10, _Act, _LRI, _PRI, _RT13, _Rep, _Sco, _RDS, _RDIA, _De, _CSI, _MI, _BC, _AC, _PDC],
      [0, 0, 0, 0, 0, 0, 64 | 0, 0, () => ResourceDriftIgnoredAttributes, () => ResourceChangeDetails, 0, () => exports2.ModuleInfo$, 0, 0, 0]
    ];
    exports2.ResourceChangeDetail$ = [
      3,
      n032,
      _RCD,
      0,
      [_Tar, _Ev, _CSh, _CE],
      [() => exports2.ResourceTargetDefinition$, 0, 0, 0]
    ];
    exports2.ResourceDefinition$ = [
      3,
      n032,
      _RD,
      0,
      [_RT13, _RI, _LRI],
      [0, 128 | 0, 0],
      2
    ];
    exports2.ResourceDetail$ = [
      3,
      n032,
      _RDe,
      0,
      [_RT13, _LRI, _RI, _RSes, _RSR, _W],
      [0, 0, 128 | 0, 0, 0, () => WarningDetails]
    ];
    exports2.ResourceDriftIgnoredAttribute$ = [
      3,
      n032,
      _RDIAe,
      0,
      [_Pat, _Rea],
      [0, 0]
    ];
    exports2.ResourceIdentifierSummary$ = [
      3,
      n032,
      _RISe,
      0,
      [_RT13, _LRIo, _RIe],
      [0, 64 | 0, 64 | 0]
    ];
    exports2.ResourceLocation$ = [
      3,
      n032,
      _RLe,
      0,
      [_SN10, _LRI],
      [0, 0],
      2
    ];
    exports2.ResourceMapping$ = [
      3,
      n032,
      _RMeso,
      0,
      [_So, _Des],
      [() => exports2.ResourceLocation$, () => exports2.ResourceLocation$],
      2
    ];
    exports2.ResourceScanSummary$ = [
      3,
      n032,
      _RSSe,
      0,
      [_RSI, _S, _SR, _ST11, _ET, _PC10, _STc],
      [0, 0, 0, 4, 4, 1, 0]
    ];
    exports2.ResourceTargetDefinition$ = [
      3,
      n032,
      _RTDe,
      0,
      [_At, _N, _RReq, _Pat, _BV, _AVf, _BVF, _AVF, _Dr, _ACT],
      [0, 0, 0, 0, 0, 0, 0, 0, () => exports2.LiveResourceDrift$, 0]
    ];
    exports2.ResourceToImport$ = [
      3,
      n032,
      _RTIes,
      0,
      [_RT13, _LRI, _RI],
      [0, 0, 128 | 0],
      3
    ];
    exports2.RollbackConfiguration$ = [
      3,
      n032,
      _RCo,
      0,
      [_RTo, _MTIM],
      [() => RollbackTriggers, 1]
    ];
    exports2.RollbackStackInput$ = [
      3,
      n032,
      _RSIo,
      0,
      [_SN10, _RARN, _CRT, _REOC],
      [0, 0, 0, 2],
      1
    ];
    exports2.RollbackStackOutput$ = [
      3,
      n032,
      _RSO,
      0,
      [_SI10, _OI],
      [0, 0]
    ];
    exports2.RollbackTrigger$ = [
      3,
      n032,
      _RTol,
      0,
      [_A10, _T10],
      [0, 0],
      2
    ];
    exports2.ScanFilter$ = [
      3,
      n032,
      _SFc,
      0,
      [_Ty],
      [64 | 0]
    ];
    exports2.ScannedResource$ = [
      3,
      n032,
      _SRc,
      0,
      [_RT13, _RI, _MBS],
      [0, 128 | 0, 2]
    ];
    exports2.ScannedResourceIdentifier$ = [
      3,
      n032,
      _SRIc,
      0,
      [_RT13, _RI],
      [0, 128 | 0],
      2
    ];
    exports2.SetStackPolicyInput$ = [
      3,
      n032,
      _SSPI,
      0,
      [_SN10, _SPB, _SPURL],
      [0, 0, 0],
      1
    ];
    exports2.SetTypeConfigurationInput$ = [
      3,
      n032,
      _STCI,
      0,
      [_Co, _TA, _CAon, _TN, _T10],
      [0, 0, 0, 0, 0],
      1
    ];
    exports2.SetTypeConfigurationOutput$ = [
      3,
      n032,
      _STCO,
      0,
      [_CAonf],
      [0]
    ];
    exports2.SetTypeDefaultVersionInput$ = [
      3,
      n032,
      _STDVI,
      0,
      [_A10, _T10, _TN, _VI],
      [0, 0, 0, 0]
    ];
    exports2.SetTypeDefaultVersionOutput$ = [
      3,
      n032,
      _STDVO,
      0,
      [],
      []
    ];
    exports2.SignalResourceInput$ = [
      3,
      n032,
      _SRIi,
      0,
      [_SN10, _LRI, _UI, _S],
      [0, 0, 0, 0],
      4
    ];
    exports2.Stack$ = [
      3,
      n032,
      _Sta,
      0,
      [_SN10, _CT4, _SSta, _SI10, _CSI, _D, _P10, _DTel, _LUT, _RCo, _SSR, _DR, _NARN, _TIM, _Ca, _Ou, _RARN, _Ta10, _ETP, _PIa, _RIo, _DI, _REOC, _DMe, _DSet, _LO],
      [0, 4, 0, 0, 0, 0, () => _Parameters, 4, 4, () => exports2.RollbackConfiguration$, 0, 2, 64 | 0, 1, 64 | 0, () => Outputs, 0, () => Tags, 2, 0, 0, () => exports2.StackDriftInformation$, 2, 0, 0, () => LastOperations],
      3
    ];
    exports2.StackDefinition$ = [
      3,
      n032,
      _SDt,
      0,
      [_SN10, _TB, _TURL],
      [0, 0, 0]
    ];
    exports2.StackDriftInformation$ = [
      3,
      n032,
      _SDI,
      0,
      [_SDS, _LCT],
      [0, 4],
      1
    ];
    exports2.StackDriftInformationSummary$ = [
      3,
      n032,
      _SDIS,
      0,
      [_SDS, _LCT],
      [0, 4],
      1
    ];
    exports2.StackEvent$ = [
      3,
      n032,
      _SEt,
      0,
      [_SI10, _EI10, _SN10, _Ti, _OI, _LRI, _PRI, _RT13, _RSes, _RSR, _RP, _CRT, _HTo, _HS, _HSR, _HIP, _HII, _HFM, _DSet],
      [0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
      4
    ];
    exports2.StackInstance$ = [
      3,
      n032,
      _SIt,
      0,
      [_SSI, _Reg, _Acc, _SI10, _PO, _S, _SIS, _SR, _OUIr, _DSr, _LDCT, _LOI],
      [0, 0, 0, 0, () => _Parameters, 0, () => exports2.StackInstanceComprehensiveStatus$, 0, 0, 0, 4, 0]
    ];
    exports2.StackInstanceComprehensiveStatus$ = [
      3,
      n032,
      _SICS,
      0,
      [_DSet],
      [0]
    ];
    exports2.StackInstanceFilter$ = [
      3,
      n032,
      _SIF,
      0,
      [_N, _Va],
      [0, 0]
    ];
    exports2.StackInstanceResourceDriftsSummary$ = [
      3,
      n032,
      _SIRDSt,
      0,
      [_SI10, _LRI, _RT13, _SRDS, _Ti, _PRI, _PRIC, _PDro],
      [0, 0, 0, 0, 4, 0, () => PhysicalResourceIdContext, () => PropertyDifferences],
      5
    ];
    exports2.StackInstanceSummary$ = [
      3,
      n032,
      _SISt,
      0,
      [_SSI, _Reg, _Acc, _SI10, _S, _SR, _SIS, _OUIr, _DSr, _LDCT, _LOI],
      [0, 0, 0, 0, 0, 0, () => exports2.StackInstanceComprehensiveStatus$, 0, 0, 4, 0]
    ];
    exports2.StackRefactorAction$ = [
      3,
      n032,
      _SRAt,
      0,
      [_Act, _En, _PRI, _RI, _D, _Det, _DRe, _TR, _UR, _RMeso],
      [0, 0, 0, 0, 0, 0, 0, () => StackRefactorTagResources, 64 | 0, () => exports2.ResourceMapping$]
    ];
    exports2.StackRefactorSummary$ = [
      3,
      n032,
      _SRSta,
      0,
      [_SRI, _D, _ES, _ESR, _S, _SR],
      [0, 0, 0, 0, 0, 0]
    ];
    exports2.StackResource$ = [
      3,
      n032,
      _SRta,
      0,
      [_LRI, _RT13, _Ti, _RSes, _SN10, _SI10, _PRI, _RSR, _D, _DI, _MI],
      [0, 0, 4, 0, 0, 0, 0, 0, 0, () => exports2.StackResourceDriftInformation$, () => exports2.ModuleInfo$],
      4
    ];
    exports2.StackResourceDetail$ = [
      3,
      n032,
      _SRDt,
      0,
      [_LRI, _RT13, _LUTa, _RSes, _SN10, _SI10, _PRI, _RSR, _D, _Me, _DI, _MI],
      [0, 0, 4, 0, 0, 0, 0, 0, 0, 0, () => exports2.StackResourceDriftInformation$, () => exports2.ModuleInfo$],
      4
    ];
    exports2.StackResourceDrift$ = [
      3,
      n032,
      _SRDta,
      0,
      [_SI10, _LRI, _RT13, _SRDS, _Ti, _PRI, _PRIC, _EP, _AP, _PDro, _MI, _DSRr],
      [0, 0, 0, 0, 4, 0, () => PhysicalResourceIdContext, 0, 0, () => PropertyDifferences, () => exports2.ModuleInfo$, 0],
      5
    ];
    exports2.StackResourceDriftInformation$ = [
      3,
      n032,
      _SRDI,
      0,
      [_SRDS, _LCT],
      [0, 4],
      1
    ];
    exports2.StackResourceDriftInformationSummary$ = [
      3,
      n032,
      _SRDIS,
      0,
      [_SRDS, _LCT],
      [0, 4],
      1
    ];
    exports2.StackResourceSummary$ = [
      3,
      n032,
      _SRStac,
      0,
      [_LRI, _RT13, _LUTa, _RSes, _PRI, _RSR, _DI, _MI],
      [0, 0, 4, 0, 0, 0, () => exports2.StackResourceDriftInformationSummary$, () => exports2.ModuleInfo$],
      4
    ];
    exports2.StackSet$ = [
      3,
      n032,
      _SS,
      0,
      [_SSN, _SSI, _D, _S, _TB, _P10, _Ca, _Ta10, _SSARN, _ARARN, _ERN, _SSDDD, _AD, _PM, _OUI, _ME, _Re],
      [0, 0, 0, 0, 0, () => _Parameters, 64 | 0, () => Tags, 0, 0, 0, () => exports2.StackSetDriftDetectionDetails$, () => exports2.AutoDeployment$, 0, 64 | 0, () => exports2.ManagedExecution$, 64 | 0]
    ];
    exports2.StackSetAutoDeploymentTargetSummary$ = [
      3,
      n032,
      _SSADTS,
      0,
      [_OUIr, _Re],
      [0, 64 | 0]
    ];
    exports2.StackSetDriftDetectionDetails$ = [
      3,
      n032,
      _SSDDD,
      0,
      [_DSr, _DDS, _LDCT, _TSIC, _DSIC, _ISSIC, _IPSIC, _FSIC],
      [0, 0, 4, 1, 1, 1, 1, 1]
    ];
    exports2.StackSetOperation$ = [
      3,
      n032,
      _SSO,
      0,
      [_OI, _SSI, _Act, _S, _OP, _RS, _ARARN, _ERN, _CTr, _ETn, _DT, _SSDDD, _SR, _SDta],
      [0, 0, 0, 0, () => exports2.StackSetOperationPreferences$, 2, 0, 0, 4, 4, () => exports2.DeploymentTargets$, () => exports2.StackSetDriftDetectionDetails$, 0, () => exports2.StackSetOperationStatusDetails$]
    ];
    exports2.StackSetOperationPreferences$ = [
      3,
      n032,
      _SSOP,
      0,
      [_RCT, _RO, _FTC, _FTP, _MCC, _MCP, _CM],
      [0, 64 | 0, 1, 1, 1, 1, 0]
    ];
    exports2.StackSetOperationResultSummary$ = [
      3,
      n032,
      _SSORS,
      0,
      [_Acc, _Reg, _S, _SR, _AGR, _OUIr],
      [0, 0, 0, 0, () => exports2.AccountGateResult$, 0]
    ];
    exports2.StackSetOperationStatusDetails$ = [
      3,
      n032,
      _SSOSD,
      0,
      [_FSIC],
      [1]
    ];
    exports2.StackSetOperationSummary$ = [
      3,
      n032,
      _SSOS,
      0,
      [_OI, _Act, _S, _CTr, _ETn, _SR, _SDta, _OP],
      [0, 0, 0, 4, 4, 0, () => exports2.StackSetOperationStatusDetails$, () => exports2.StackSetOperationPreferences$]
    ];
    exports2.StackSetSummary$ = [
      3,
      n032,
      _SSS,
      0,
      [_SSN, _SSI, _D, _S, _AD, _PM, _DSr, _LDCT, _ME],
      [0, 0, 0, 0, () => exports2.AutoDeployment$, 0, 0, 4, () => exports2.ManagedExecution$]
    ];
    exports2.StackSummary$ = [
      3,
      n032,
      _SStac,
      0,
      [_SN10, _CT4, _SSta, _SI10, _TDe, _LUT, _DTel, _SSR, _PIa, _RIo, _DI, _LO],
      [0, 4, 0, 0, 0, 4, 4, 0, 0, 0, () => exports2.StackDriftInformationSummary$, () => LastOperations],
      3
    ];
    exports2.StartResourceScanInput$ = [
      3,
      n032,
      _SRSI,
      0,
      [_CRT, _SF],
      [0, () => ScanFilters]
    ];
    exports2.StartResourceScanOutput$ = [
      3,
      n032,
      _SRSO,
      0,
      [_RSI],
      [0]
    ];
    exports2.StopStackSetOperationInput$ = [
      3,
      n032,
      _SSSOI,
      0,
      [_SSN, _OI, _CA10],
      [0, 0, 0],
      2
    ];
    exports2.StopStackSetOperationOutput$ = [
      3,
      n032,
      _SSSOO,
      0,
      [],
      []
    ];
    exports2.Tag$ = [
      3,
      n032,
      _Tag,
      0,
      [_K10, _V10],
      [0, 0],
      2
    ];
    exports2.TemplateConfiguration$ = [
      3,
      n032,
      _TCe,
      0,
      [_DP, _URP],
      [0, 0]
    ];
    exports2.TemplateParameter$ = [
      3,
      n032,
      _TP,
      0,
      [_PK, _DV, _NE, _D],
      [0, 0, 2, 0]
    ];
    exports2.TemplateProgress$ = [
      3,
      n032,
      _TPe,
      0,
      [_RSeso, _RF, _RPe, _RPes],
      [1, 1, 1, 1]
    ];
    exports2.TemplateSummary$ = [
      3,
      n032,
      _TSe,
      0,
      [_GTI, _GTN, _S, _SR, _CT4, _LUT, _NOR],
      [0, 0, 0, 0, 4, 4, 1]
    ];
    exports2.TemplateSummaryConfig$ = [
      3,
      n032,
      _TSC,
      0,
      [_TURTAW],
      [2]
    ];
    exports2.TestTypeInput$ = [
      3,
      n032,
      _TTI,
      0,
      [_A10, _T10, _TN, _VI, _LDB],
      [0, 0, 0, 0, 0]
    ];
    exports2.TestTypeOutput$ = [
      3,
      n032,
      _TTO,
      0,
      [_TVA],
      [0]
    ];
    exports2.TypeConfigurationDetails$ = [
      3,
      n032,
      _TCD,
      0,
      [_A10, _Al, _Co, _LU, _TA, _TN, _IDC],
      [0, 0, 0, 4, 0, 0, 2]
    ];
    exports2.TypeConfigurationIdentifier$ = [
      3,
      n032,
      _TCI,
      0,
      [_TA, _TCA, _TCAy, _T10, _TN],
      [0, 0, 0, 0, 0]
    ];
    exports2.TypeFilters$ = [
      3,
      n032,
      _TF,
      0,
      [_Cat, _PI10, _TNP],
      [0, 0, 0]
    ];
    exports2.TypeSummary$ = [
      3,
      n032,
      _TSyp,
      0,
      [_T10, _TN, _DVI, _TA, _LU, _D, _PI10, _OTN, _PVN, _LPV, _PIu, _PN, _IA],
      [0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 2]
    ];
    exports2.TypeVersionSummary$ = [
      3,
      n032,
      _TVSy,
      0,
      [_T10, _TN, _VI, _IDV, _A10, _TCi, _D, _PVN],
      [0, 0, 0, 2, 0, 4, 0, 0]
    ];
    exports2.UpdateGeneratedTemplateInput$ = [
      3,
      n032,
      _UGTI,
      0,
      [_GTN, _NGTN, _AR10, _RRem, _RAR, _TCe],
      [0, 0, () => ResourceDefinitions, 64 | 0, 2, () => exports2.TemplateConfiguration$],
      1
    ];
    exports2.UpdateGeneratedTemplateOutput$ = [
      3,
      n032,
      _UGTO,
      0,
      [_GTI],
      [0]
    ];
    exports2.UpdateStackInput$ = [
      3,
      n032,
      _USI,
      0,
      [_SN10, _TB, _TURL, _UPT, _SPDUB, _SPDUURL, _P10, _Ca, _RTe, _RARN, _RCo, _SPB, _SPURL, _NARN, _Ta10, _DR, _CRT, _REOC],
      [0, 0, 0, 2, 0, 0, () => _Parameters, 64 | 0, 64 | 0, 0, () => exports2.RollbackConfiguration$, 0, 0, 64 | 0, () => Tags, 2, 0, 2],
      1
    ];
    exports2.UpdateStackInstancesInput$ = [
      3,
      n032,
      _USII,
      0,
      [_SSN, _Re, _Ac, _DT, _PO, _OP, _OI, _CA10],
      [0, 64 | 0, 64 | 0, () => exports2.DeploymentTargets$, () => _Parameters, () => exports2.StackSetOperationPreferences$, [0, 4], 0],
      2
    ];
    exports2.UpdateStackInstancesOutput$ = [
      3,
      n032,
      _USIO,
      0,
      [_OI],
      [0]
    ];
    exports2.UpdateStackOutput$ = [
      3,
      n032,
      _USO,
      0,
      [_SI10, _OI],
      [0, 0]
    ];
    exports2.UpdateStackSetInput$ = [
      3,
      n032,
      _USSI,
      0,
      [_SSN, _D, _TB, _TURL, _UPT, _P10, _Ca, _Ta10, _OP, _ARARN, _ERN, _DT, _PM, _AD, _OI, _Ac, _Re, _CA10, _ME],
      [0, 0, 0, 0, 2, () => _Parameters, 64 | 0, () => Tags, () => exports2.StackSetOperationPreferences$, 0, 0, () => exports2.DeploymentTargets$, 0, () => exports2.AutoDeployment$, [0, 4], 64 | 0, 64 | 0, 0, () => exports2.ManagedExecution$],
      1
    ];
    exports2.UpdateStackSetOutput$ = [
      3,
      n032,
      _USSO,
      0,
      [_OI],
      [0]
    ];
    exports2.UpdateTerminationProtectionInput$ = [
      3,
      n032,
      _UTPI,
      0,
      [_ETP, _SN10],
      [2, 0],
      2
    ];
    exports2.UpdateTerminationProtectionOutput$ = [
      3,
      n032,
      _UTPO,
      0,
      [_SI10],
      [0]
    ];
    exports2.ValidateTemplateInput$ = [
      3,
      n032,
      _VTI,
      0,
      [_TB, _TURL],
      [0, 0]
    ];
    exports2.ValidateTemplateOutput$ = [
      3,
      n032,
      _VTO,
      0,
      [_P10, _D, _Ca, _CR, _DTe],
      [() => TemplateParameters2, 0, 64 | 0, 0, 64 | 0]
    ];
    exports2.WarningDetail$ = [
      3,
      n032,
      _WD,
      0,
      [_T10, _Pro],
      [0, () => WarningProperties]
    ];
    exports2.WarningProperty$ = [
      3,
      n032,
      _WP,
      0,
      [_PPr, _Req, _D],
      [0, 2, 0]
    ];
    exports2.Warnings$ = [
      3,
      n032,
      _W,
      0,
      [_URT],
      [64 | 0]
    ];
    var __Unit = "unit";
    var AccountLimitList = [
      1,
      n032,
      _ALL,
      0,
      () => exports2.AccountLimit$
    ];
    var AccountList = 64 | 0;
    var AllowedValues = 64 | 0;
    var AnnotationList = [
      1,
      n032,
      _ALn,
      0,
      () => exports2.Annotation$
    ];
    var BatchDescribeTypeConfigurationsErrors = [
      1,
      n032,
      _BDTCEa,
      0,
      () => exports2.BatchDescribeTypeConfigurationsError$
    ];
    var Capabilities = 64 | 0;
    var Changes = [
      1,
      n032,
      _Ch,
      0,
      () => exports2.Change$
    ];
    var ChangeSetHooks = [
      1,
      n032,
      _CSHh,
      0,
      () => exports2.ChangeSetHook$
    ];
    var ChangeSetSummaries = [
      1,
      n032,
      _CSSh,
      0,
      () => exports2.ChangeSetSummary$
    ];
    var Exports = [
      1,
      n032,
      _Exp,
      0,
      () => exports2.Export$
    ];
    var HookResultSummaries = [
      1,
      n032,
      _HRSo,
      0,
      () => exports2.HookResultSummary$
    ];
    var Imports = 64 | 0;
    var JazzLogicalResourceIds = 64 | 0;
    var LastOperations = [
      1,
      n032,
      _LO,
      0,
      () => exports2.OperationEntry$
    ];
    var LogicalResourceIds = 64 | 0;
    var NotificationARNs = 64 | 0;
    var OperationEvents = [
      1,
      n032,
      _OE,
      0,
      () => exports2.OperationEvent$
    ];
    var OperationResultFilters = [
      1,
      n032,
      _ORFp,
      0,
      () => exports2.OperationResultFilter$
    ];
    var OrganizationalUnitIdList = 64 | 0;
    var Outputs = [
      1,
      n032,
      _Ou,
      0,
      () => exports2.Output$
    ];
    var ParameterDeclarations = [
      1,
      n032,
      _PDa,
      0,
      () => exports2.ParameterDeclaration$
    ];
    var _Parameters = [
      1,
      n032,
      _P10,
      0,
      () => exports2.Parameter$
    ];
    var PhysicalResourceIdContext = [
      1,
      n032,
      _PRIC,
      0,
      () => exports2.PhysicalResourceIdContextKeyValuePair$
    ];
    var PropertyDifferences = [
      1,
      n032,
      _PDro,
      0,
      () => exports2.PropertyDifference$
    ];
    var RegionList = 64 | 0;
    var RegistrationTokenList = 64 | 0;
    var RelatedResources = [
      1,
      n032,
      _RRel,
      0,
      () => exports2.ScannedResource$
    ];
    var RequiredActivatedTypes = [
      1,
      n032,
      _RAT,
      0,
      () => exports2.RequiredActivatedType$
    ];
    var ResourceChangeDetails = [
      1,
      n032,
      _RCDe,
      0,
      () => exports2.ResourceChangeDetail$
    ];
    var ResourceDefinitions = [
      1,
      n032,
      _RDes,
      0,
      () => exports2.ResourceDefinition$
    ];
    var ResourceDetails = [
      1,
      n032,
      _RDeso,
      0,
      () => exports2.ResourceDetail$
    ];
    var ResourceDriftIgnoredAttributes = [
      1,
      n032,
      _RDIA,
      0,
      () => exports2.ResourceDriftIgnoredAttribute$
    ];
    var ResourceIdentifiers = 64 | 0;
    var ResourceIdentifierSummaries = [
      1,
      n032,
      _RIS,
      0,
      () => exports2.ResourceIdentifierSummary$
    ];
    var ResourceMappings = [
      1,
      n032,
      _RMe,
      0,
      () => exports2.ResourceMapping$
    ];
    var ResourceScanSummaries = [
      1,
      n032,
      _RSS,
      0,
      () => exports2.ResourceScanSummary$
    ];
    var ResourcesToImport = [
      1,
      n032,
      _RTI,
      0,
      () => exports2.ResourceToImport$
    ];
    var ResourcesToSkip = 64 | 0;
    var ResourceTypeFilters = 64 | 0;
    var ResourceTypes = 64 | 0;
    var RetainResources = 64 | 0;
    var RollbackTriggers = [
      1,
      n032,
      _RTo,
      0,
      () => exports2.RollbackTrigger$
    ];
    var ScanFilters = [
      1,
      n032,
      _SF,
      0,
      () => exports2.ScanFilter$
    ];
    var ScannedResourceIdentifiers = [
      1,
      n032,
      _SRIca,
      0,
      () => exports2.ScannedResourceIdentifier$
    ];
    var ScannedResources = [
      1,
      n032,
      _SRca,
      0,
      () => exports2.ScannedResource$
    ];
    var Scope = 64 | 0;
    var StackDefinitions = [
      1,
      n032,
      _SD,
      0,
      () => exports2.StackDefinition$
    ];
    var StackEvents = [
      1,
      n032,
      _SE,
      0,
      () => exports2.StackEvent$
    ];
    var StackIdList = 64 | 0;
    var StackIds = 64 | 0;
    var StackInstanceFilters = [
      1,
      n032,
      _SIFt,
      0,
      () => exports2.StackInstanceFilter$
    ];
    var StackInstanceResourceDriftsSummaries = [
      1,
      n032,
      _SIRDSta,
      0,
      () => exports2.StackInstanceResourceDriftsSummary$
    ];
    var StackInstanceSummaries = [
      1,
      n032,
      _SISta,
      0,
      () => exports2.StackInstanceSummary$
    ];
    var StackRefactorActions = [
      1,
      n032,
      _SRA,
      0,
      () => exports2.StackRefactorAction$
    ];
    var StackRefactorExecutionStatusFilter = 64 | 0;
    var StackRefactorSummaries = [
      1,
      n032,
      _SRS,
      0,
      () => exports2.StackRefactorSummary$
    ];
    var StackRefactorTagResources = [
      1,
      n032,
      _SRTR,
      0,
      () => exports2.Tag$
    ];
    var StackRefactorUntagResources = 64 | 0;
    var StackResourceDrifts = [
      1,
      n032,
      _SRD,
      0,
      () => exports2.StackResourceDrift$
    ];
    var StackResourceDriftStatusFilters = 64 | 0;
    var StackResources = [
      1,
      n032,
      _SRt,
      0,
      () => exports2.StackResource$
    ];
    var StackResourceSummaries = [
      1,
      n032,
      _SRSt,
      0,
      () => exports2.StackResourceSummary$
    ];
    var Stacks = [
      1,
      n032,
      _St,
      0,
      () => exports2.Stack$
    ];
    var StackSetARNList = 64 | 0;
    var StackSetAutoDeploymentTargetSummaries = [
      1,
      n032,
      _SSADTSt,
      0,
      () => exports2.StackSetAutoDeploymentTargetSummary$
    ];
    var StackSetOperationResultSummaries = [
      1,
      n032,
      _SSORSt,
      0,
      () => exports2.StackSetOperationResultSummary$
    ];
    var StackSetOperationSummaries = [
      1,
      n032,
      _SSOSt,
      0,
      () => exports2.StackSetOperationSummary$
    ];
    var StackSetSummaries = [
      1,
      n032,
      _SSSt,
      0,
      () => exports2.StackSetSummary$
    ];
    var StackStatusFilter = 64 | 0;
    var StackSummaries = [
      1,
      n032,
      _SSt,
      0,
      () => exports2.StackSummary$
    ];
    var StageList = 64 | 0;
    var SupportedMajorVersions = 64 | 1;
    var Tags = [
      1,
      n032,
      _Ta10,
      0,
      () => exports2.Tag$
    ];
    var TemplateParameters2 = [
      1,
      n032,
      _TPem,
      0,
      () => exports2.TemplateParameter$
    ];
    var TemplateSummaries = [
      1,
      n032,
      _TSem,
      0,
      () => exports2.TemplateSummary$
    ];
    var TransformsList = 64 | 0;
    var TypeConfigurationDetailsList = [
      1,
      n032,
      _TCDL,
      0,
      () => exports2.TypeConfigurationDetails$
    ];
    var TypeConfigurationIdentifiers = [
      1,
      n032,
      _TCIy,
      0,
      () => exports2.TypeConfigurationIdentifier$
    ];
    var TypeSummaries = [
      1,
      n032,
      _TSy,
      0,
      () => exports2.TypeSummary$
    ];
    var TypeVersionSummaries = [
      1,
      n032,
      _TVS,
      0,
      () => exports2.TypeVersionSummary$
    ];
    var UnprocessedTypeConfigurations = [
      1,
      n032,
      _UTC,
      0,
      () => exports2.TypeConfigurationIdentifier$
    ];
    var WarningDetails = [
      1,
      n032,
      _WDa,
      0,
      () => exports2.WarningDetail$
    ];
    var WarningProperties = [
      1,
      n032,
      _WPa,
      0,
      () => exports2.WarningProperty$
    ];
    var JazzResourceIdentifierProperties = 128 | 0;
    var ResourceIdentifierProperties = 128 | 0;
    exports2.ActivateOrganizationsAccess$ = [
      9,
      n032,
      _AOA,
      0,
      () => exports2.ActivateOrganizationsAccessInput$,
      () => exports2.ActivateOrganizationsAccessOutput$
    ];
    exports2.ActivateType$ = [
      9,
      n032,
      _AT13,
      2,
      () => exports2.ActivateTypeInput$,
      () => exports2.ActivateTypeOutput$
    ];
    exports2.BatchDescribeTypeConfigurations$ = [
      9,
      n032,
      _BDTC,
      0,
      () => exports2.BatchDescribeTypeConfigurationsInput$,
      () => exports2.BatchDescribeTypeConfigurationsOutput$
    ];
    exports2.CancelUpdateStack$ = [
      9,
      n032,
      _CUS,
      0,
      () => exports2.CancelUpdateStackInput$,
      () => __Unit
    ];
    exports2.ContinueUpdateRollback$ = [
      9,
      n032,
      _CUR,
      0,
      () => exports2.ContinueUpdateRollbackInput$,
      () => exports2.ContinueUpdateRollbackOutput$
    ];
    exports2.CreateChangeSet$ = [
      9,
      n032,
      _CCS,
      0,
      () => exports2.CreateChangeSetInput$,
      () => exports2.CreateChangeSetOutput$
    ];
    exports2.CreateGeneratedTemplate$ = [
      9,
      n032,
      _CGT,
      0,
      () => exports2.CreateGeneratedTemplateInput$,
      () => exports2.CreateGeneratedTemplateOutput$
    ];
    exports2.CreateStack$ = [
      9,
      n032,
      _CSr,
      0,
      () => exports2.CreateStackInput$,
      () => exports2.CreateStackOutput$
    ];
    exports2.CreateStackInstances$ = [
      9,
      n032,
      _CSIre,
      0,
      () => exports2.CreateStackInstancesInput$,
      () => exports2.CreateStackInstancesOutput$
    ];
    exports2.CreateStackRefactor$ = [
      9,
      n032,
      _CSR,
      0,
      () => exports2.CreateStackRefactorInput$,
      () => exports2.CreateStackRefactorOutput$
    ];
    exports2.CreateStackSet$ = [
      9,
      n032,
      _CSSr,
      0,
      () => exports2.CreateStackSetInput$,
      () => exports2.CreateStackSetOutput$
    ];
    exports2.DeactivateOrganizationsAccess$ = [
      9,
      n032,
      _DOA,
      0,
      () => exports2.DeactivateOrganizationsAccessInput$,
      () => exports2.DeactivateOrganizationsAccessOutput$
    ];
    exports2.DeactivateType$ = [
      9,
      n032,
      _DTea,
      2,
      () => exports2.DeactivateTypeInput$,
      () => exports2.DeactivateTypeOutput$
    ];
    exports2.DeleteChangeSet$ = [
      9,
      n032,
      _DCS,
      0,
      () => exports2.DeleteChangeSetInput$,
      () => exports2.DeleteChangeSetOutput$
    ];
    exports2.DeleteGeneratedTemplate$ = [
      9,
      n032,
      _DGT,
      0,
      () => exports2.DeleteGeneratedTemplateInput$,
      () => __Unit
    ];
    exports2.DeleteStack$ = [
      9,
      n032,
      _DSel,
      0,
      () => exports2.DeleteStackInput$,
      () => __Unit
    ];
    exports2.DeleteStackInstances$ = [
      9,
      n032,
      _DSIel,
      0,
      () => exports2.DeleteStackInstancesInput$,
      () => exports2.DeleteStackInstancesOutput$
    ];
    exports2.DeleteStackSet$ = [
      9,
      n032,
      _DSS,
      0,
      () => exports2.DeleteStackSetInput$,
      () => exports2.DeleteStackSetOutput$
    ];
    exports2.DeregisterType$ = [
      9,
      n032,
      _DTer,
      2,
      () => exports2.DeregisterTypeInput$,
      () => exports2.DeregisterTypeOutput$
    ];
    exports2.DescribeAccountLimits$ = [
      9,
      n032,
      _DAL,
      0,
      () => exports2.DescribeAccountLimitsInput$,
      () => exports2.DescribeAccountLimitsOutput$
    ];
    exports2.DescribeChangeSet$ = [
      9,
      n032,
      _DCSe,
      0,
      () => exports2.DescribeChangeSetInput$,
      () => exports2.DescribeChangeSetOutput$
    ];
    exports2.DescribeChangeSetHooks$ = [
      9,
      n032,
      _DCSH,
      0,
      () => exports2.DescribeChangeSetHooksInput$,
      () => exports2.DescribeChangeSetHooksOutput$
    ];
    exports2.DescribeEvents$ = [
      9,
      n032,
      _DE,
      0,
      () => exports2.DescribeEventsInput$,
      () => exports2.DescribeEventsOutput$
    ];
    exports2.DescribeGeneratedTemplate$ = [
      9,
      n032,
      _DGTe,
      0,
      () => exports2.DescribeGeneratedTemplateInput$,
      () => exports2.DescribeGeneratedTemplateOutput$
    ];
    exports2.DescribeOrganizationsAccess$ = [
      9,
      n032,
      _DOAe,
      0,
      () => exports2.DescribeOrganizationsAccessInput$,
      () => exports2.DescribeOrganizationsAccessOutput$
    ];
    exports2.DescribePublisher$ = [
      9,
      n032,
      _DPe,
      2,
      () => exports2.DescribePublisherInput$,
      () => exports2.DescribePublisherOutput$
    ];
    exports2.DescribeResourceScan$ = [
      9,
      n032,
      _DRS,
      0,
      () => exports2.DescribeResourceScanInput$,
      () => exports2.DescribeResourceScanOutput$
    ];
    exports2.DescribeStackDriftDetectionStatus$ = [
      9,
      n032,
      _DSDDS,
      0,
      () => exports2.DescribeStackDriftDetectionStatusInput$,
      () => exports2.DescribeStackDriftDetectionStatusOutput$
    ];
    exports2.DescribeStackEvents$ = [
      9,
      n032,
      _DSE,
      0,
      () => exports2.DescribeStackEventsInput$,
      () => exports2.DescribeStackEventsOutput$
    ];
    exports2.DescribeStackInstance$ = [
      9,
      n032,
      _DSIes,
      0,
      () => exports2.DescribeStackInstanceInput$,
      () => exports2.DescribeStackInstanceOutput$
    ];
    exports2.DescribeStackRefactor$ = [
      9,
      n032,
      _DSRe,
      0,
      () => exports2.DescribeStackRefactorInput$,
      () => exports2.DescribeStackRefactorOutput$
    ];
    exports2.DescribeStackResource$ = [
      9,
      n032,
      _DSRes,
      0,
      () => exports2.DescribeStackResourceInput$,
      () => exports2.DescribeStackResourceOutput$
    ];
    exports2.DescribeStackResourceDrifts$ = [
      9,
      n032,
      _DSRD,
      0,
      () => exports2.DescribeStackResourceDriftsInput$,
      () => exports2.DescribeStackResourceDriftsOutput$
    ];
    exports2.DescribeStackResources$ = [
      9,
      n032,
      _DSResc,
      0,
      () => exports2.DescribeStackResourcesInput$,
      () => exports2.DescribeStackResourcesOutput$
    ];
    exports2.DescribeStacks$ = [
      9,
      n032,
      _DSes,
      0,
      () => exports2.DescribeStacksInput$,
      () => exports2.DescribeStacksOutput$
    ];
    exports2.DescribeStackSet$ = [
      9,
      n032,
      _DSSe,
      0,
      () => exports2.DescribeStackSetInput$,
      () => exports2.DescribeStackSetOutput$
    ];
    exports2.DescribeStackSetOperation$ = [
      9,
      n032,
      _DSSOes,
      0,
      () => exports2.DescribeStackSetOperationInput$,
      () => exports2.DescribeStackSetOperationOutput$
    ];
    exports2.DescribeType$ = [
      9,
      n032,
      _DTes,
      2,
      () => exports2.DescribeTypeInput$,
      () => exports2.DescribeTypeOutput$
    ];
    exports2.DescribeTypeRegistration$ = [
      9,
      n032,
      _DTR,
      2,
      () => exports2.DescribeTypeRegistrationInput$,
      () => exports2.DescribeTypeRegistrationOutput$
    ];
    exports2.DetectStackDrift$ = [
      9,
      n032,
      _DSD,
      0,
      () => exports2.DetectStackDriftInput$,
      () => exports2.DetectStackDriftOutput$
    ];
    exports2.DetectStackResourceDrift$ = [
      9,
      n032,
      _DSRDe,
      0,
      () => exports2.DetectStackResourceDriftInput$,
      () => exports2.DetectStackResourceDriftOutput$
    ];
    exports2.DetectStackSetDrift$ = [
      9,
      n032,
      _DSSD,
      0,
      () => exports2.DetectStackSetDriftInput$,
      () => exports2.DetectStackSetDriftOutput$
    ];
    exports2.EstimateTemplateCost$ = [
      9,
      n032,
      _ETC,
      0,
      () => exports2.EstimateTemplateCostInput$,
      () => exports2.EstimateTemplateCostOutput$
    ];
    exports2.ExecuteChangeSet$ = [
      9,
      n032,
      _ECS,
      0,
      () => exports2.ExecuteChangeSetInput$,
      () => exports2.ExecuteChangeSetOutput$
    ];
    exports2.ExecuteStackRefactor$ = [
      9,
      n032,
      _ESRx,
      0,
      () => exports2.ExecuteStackRefactorInput$,
      () => __Unit
    ];
    exports2.GetGeneratedTemplate$ = [
      9,
      n032,
      _GGT,
      0,
      () => exports2.GetGeneratedTemplateInput$,
      () => exports2.GetGeneratedTemplateOutput$
    ];
    exports2.GetHookResult$ = [
      9,
      n032,
      _GHR,
      0,
      () => exports2.GetHookResultInput$,
      () => exports2.GetHookResultOutput$
    ];
    exports2.GetStackPolicy$ = [
      9,
      n032,
      _GSP,
      0,
      () => exports2.GetStackPolicyInput$,
      () => exports2.GetStackPolicyOutput$
    ];
    exports2.GetTemplate$ = [
      9,
      n032,
      _GT,
      0,
      () => exports2.GetTemplateInput$,
      () => exports2.GetTemplateOutput$
    ];
    exports2.GetTemplateSummary$ = [
      9,
      n032,
      _GTS,
      0,
      () => exports2.GetTemplateSummaryInput$,
      () => exports2.GetTemplateSummaryOutput$
    ];
    exports2.ImportStacksToStackSet$ = [
      9,
      n032,
      _ISTSS,
      0,
      () => exports2.ImportStacksToStackSetInput$,
      () => exports2.ImportStacksToStackSetOutput$
    ];
    exports2.ListChangeSets$ = [
      9,
      n032,
      _LCS,
      0,
      () => exports2.ListChangeSetsInput$,
      () => exports2.ListChangeSetsOutput$
    ];
    exports2.ListExports$ = [
      9,
      n032,
      _LE,
      0,
      () => exports2.ListExportsInput$,
      () => exports2.ListExportsOutput$
    ];
    exports2.ListGeneratedTemplates$ = [
      9,
      n032,
      _LGT,
      0,
      () => exports2.ListGeneratedTemplatesInput$,
      () => exports2.ListGeneratedTemplatesOutput$
    ];
    exports2.ListHookResults$ = [
      9,
      n032,
      _LHR,
      0,
      () => exports2.ListHookResultsInput$,
      () => exports2.ListHookResultsOutput$
    ];
    exports2.ListImports$ = [
      9,
      n032,
      _LI,
      0,
      () => exports2.ListImportsInput$,
      () => exports2.ListImportsOutput$
    ];
    exports2.ListResourceScanRelatedResources$ = [
      9,
      n032,
      _LRSRR,
      0,
      () => exports2.ListResourceScanRelatedResourcesInput$,
      () => exports2.ListResourceScanRelatedResourcesOutput$
    ];
    exports2.ListResourceScanResources$ = [
      9,
      n032,
      _LRSR,
      0,
      () => exports2.ListResourceScanResourcesInput$,
      () => exports2.ListResourceScanResourcesOutput$
    ];
    exports2.ListResourceScans$ = [
      9,
      n032,
      _LRS,
      0,
      () => exports2.ListResourceScansInput$,
      () => exports2.ListResourceScansOutput$
    ];
    exports2.ListStackInstanceResourceDrifts$ = [
      9,
      n032,
      _LSIRD,
      0,
      () => exports2.ListStackInstanceResourceDriftsInput$,
      () => exports2.ListStackInstanceResourceDriftsOutput$
    ];
    exports2.ListStackInstances$ = [
      9,
      n032,
      _LSIi,
      0,
      () => exports2.ListStackInstancesInput$,
      () => exports2.ListStackInstancesOutput$
    ];
    exports2.ListStackRefactorActions$ = [
      9,
      n032,
      _LSRA,
      0,
      () => exports2.ListStackRefactorActionsInput$,
      () => exports2.ListStackRefactorActionsOutput$
    ];
    exports2.ListStackRefactors$ = [
      9,
      n032,
      _LSR,
      0,
      () => exports2.ListStackRefactorsInput$,
      () => exports2.ListStackRefactorsOutput$
    ];
    exports2.ListStackResources$ = [
      9,
      n032,
      _LSRi,
      0,
      () => exports2.ListStackResourcesInput$,
      () => exports2.ListStackResourcesOutput$
    ];
    exports2.ListStacks$ = [
      9,
      n032,
      _LS,
      0,
      () => exports2.ListStacksInput$,
      () => exports2.ListStacksOutput$
    ];
    exports2.ListStackSetAutoDeploymentTargets$ = [
      9,
      n032,
      _LSSADT,
      0,
      () => exports2.ListStackSetAutoDeploymentTargetsInput$,
      () => exports2.ListStackSetAutoDeploymentTargetsOutput$
    ];
    exports2.ListStackSetOperationResults$ = [
      9,
      n032,
      _LSSOR,
      0,
      () => exports2.ListStackSetOperationResultsInput$,
      () => exports2.ListStackSetOperationResultsOutput$
    ];
    exports2.ListStackSetOperations$ = [
      9,
      n032,
      _LSSOi,
      0,
      () => exports2.ListStackSetOperationsInput$,
      () => exports2.ListStackSetOperationsOutput$
    ];
    exports2.ListStackSets$ = [
      9,
      n032,
      _LSS,
      0,
      () => exports2.ListStackSetsInput$,
      () => exports2.ListStackSetsOutput$
    ];
    exports2.ListTypeRegistrations$ = [
      9,
      n032,
      _LTR,
      2,
      () => exports2.ListTypeRegistrationsInput$,
      () => exports2.ListTypeRegistrationsOutput$
    ];
    exports2.ListTypes$ = [
      9,
      n032,
      _LT,
      2,
      () => exports2.ListTypesInput$,
      () => exports2.ListTypesOutput$
    ];
    exports2.ListTypeVersions$ = [
      9,
      n032,
      _LTV,
      2,
      () => exports2.ListTypeVersionsInput$,
      () => exports2.ListTypeVersionsOutput$
    ];
    exports2.PublishType$ = [
      9,
      n032,
      _PTu,
      2,
      () => exports2.PublishTypeInput$,
      () => exports2.PublishTypeOutput$
    ];
    exports2.RecordHandlerProgress$ = [
      9,
      n032,
      _RHP,
      2,
      () => exports2.RecordHandlerProgressInput$,
      () => exports2.RecordHandlerProgressOutput$
    ];
    exports2.RegisterPublisher$ = [
      9,
      n032,
      _RPeg,
      2,
      () => exports2.RegisterPublisherInput$,
      () => exports2.RegisterPublisherOutput$
    ];
    exports2.RegisterType$ = [
      9,
      n032,
      _RTegi,
      2,
      () => exports2.RegisterTypeInput$,
      () => exports2.RegisterTypeOutput$
    ];
    exports2.RollbackStack$ = [
      9,
      n032,
      _RSo,
      0,
      () => exports2.RollbackStackInput$,
      () => exports2.RollbackStackOutput$
    ];
    exports2.SetStackPolicy$ = [
      9,
      n032,
      _SSP,
      0,
      () => exports2.SetStackPolicyInput$,
      () => __Unit
    ];
    exports2.SetTypeConfiguration$ = [
      9,
      n032,
      _STC,
      0,
      () => exports2.SetTypeConfigurationInput$,
      () => exports2.SetTypeConfigurationOutput$
    ];
    exports2.SetTypeDefaultVersion$ = [
      9,
      n032,
      _STDV,
      2,
      () => exports2.SetTypeDefaultVersionInput$,
      () => exports2.SetTypeDefaultVersionOutput$
    ];
    exports2.SignalResource$ = [
      9,
      n032,
      _SRi,
      0,
      () => exports2.SignalResourceInput$,
      () => __Unit
    ];
    exports2.StartResourceScan$ = [
      9,
      n032,
      _SRStar,
      0,
      () => exports2.StartResourceScanInput$,
      () => exports2.StartResourceScanOutput$
    ];
    exports2.StopStackSetOperation$ = [
      9,
      n032,
      _SSSO,
      0,
      () => exports2.StopStackSetOperationInput$,
      () => exports2.StopStackSetOperationOutput$
    ];
    exports2.TestType$ = [
      9,
      n032,
      _TTe,
      2,
      () => exports2.TestTypeInput$,
      () => exports2.TestTypeOutput$
    ];
    exports2.UpdateGeneratedTemplate$ = [
      9,
      n032,
      _UGT,
      0,
      () => exports2.UpdateGeneratedTemplateInput$,
      () => exports2.UpdateGeneratedTemplateOutput$
    ];
    exports2.UpdateStack$ = [
      9,
      n032,
      _US,
      0,
      () => exports2.UpdateStackInput$,
      () => exports2.UpdateStackOutput$
    ];
    exports2.UpdateStackInstances$ = [
      9,
      n032,
      _USIp,
      0,
      () => exports2.UpdateStackInstancesInput$,
      () => exports2.UpdateStackInstancesOutput$
    ];
    exports2.UpdateStackSet$ = [
      9,
      n032,
      _USS,
      0,
      () => exports2.UpdateStackSetInput$,
      () => exports2.UpdateStackSetOutput$
    ];
    exports2.UpdateTerminationProtection$ = [
      9,
      n032,
      _UTP,
      0,
      () => exports2.UpdateTerminationProtectionInput$,
      () => exports2.UpdateTerminationProtectionOutput$
    ];
    exports2.ValidateTemplate$ = [
      9,
      n032,
      _VT,
      0,
      () => exports2.ValidateTemplateInput$,
      () => exports2.ValidateTemplateOutput$
    ];
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/dist-cjs/runtimeConfig.shared.js
var require_runtimeConfig_shared6 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/dist-cjs/runtimeConfig.shared.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes7(), __toCommonJS(httpAuthSchemes_exports6));
    var protocols_1 = (init_protocols10(), __toCommonJS(protocols_exports7));
    var smithy_client_1 = require_dist_cjs34();
    var url_parser_1 = require_dist_cjs18();
    var util_base64_1 = require_dist_cjs10();
    var util_utf8_1 = require_dist_cjs9();
    var httpAuthSchemeProvider_1 = require_httpAuthSchemeProvider5();
    var endpointResolver_1 = require_endpointResolver5();
    var schemas_0_1 = require_schemas_05();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2010-05-15",
        base64Decoder: config2?.base64Decoder ?? util_base64_1.fromBase64,
        base64Encoder: config2?.base64Encoder ?? util_base64_1.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? endpointResolver_1.defaultEndpointResolver,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? httpAuthSchemeProvider_1.defaultCloudFormationHttpAuthSchemeProvider,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new httpAuthSchemes_1.AwsSdkSigV4Signer()
          }
        ],
        logger: config2?.logger ?? new smithy_client_1.NoOpLogger(),
        protocol: config2?.protocol ?? protocols_1.AwsQueryProtocol,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.cloudformation",
          errorTypeRegistries: schemas_0_1.errorTypeRegistries,
          xmlNamespace: "http://cloudformation.amazonaws.com/doc/2010-05-15/",
          version: "2010-05-15",
          serviceTarget: "CloudFormation"
        },
        serviceId: config2?.serviceId ?? "CloudFormation",
        urlParser: config2?.urlParser ?? url_parser_1.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? util_utf8_1.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? util_utf8_1.toUtf8
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/dist-cjs/runtimeConfig.js
var require_runtimeConfig6 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/dist-cjs/runtimeConfig.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var package_json_1 = tslib_1.__importDefault(require_package5());
    var client_1 = (init_client10(), __toCommonJS(client_exports8));
    var httpAuthSchemes_1 = (init_httpAuthSchemes7(), __toCommonJS(httpAuthSchemes_exports6));
    var credential_provider_node_1 = require_dist_cjs138();
    var util_user_agent_node_1 = require_dist_cjs132();
    var config_resolver_1 = require_dist_cjs25();
    var hash_node_1 = require_dist_cjs44();
    var middleware_retry_1 = require_dist_cjs128();
    var node_config_provider_1 = require_dist_cjs29();
    var node_http_handler_1 = require_dist_cjs13();
    var smithy_client_1 = require_dist_cjs34();
    var util_body_length_node_1 = require_dist_cjs45();
    var util_defaults_mode_node_1 = require_dist_cjs46();
    var util_retry_1 = require_dist_cjs22();
    var runtimeConfig_shared_1 = require_runtimeConfig_shared6();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      (0, smithy_client_1.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, util_defaults_mode_node_1.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(smithy_client_1.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = (0, runtimeConfig_shared_1.getRuntimeConfig)(config2);
      (0, client_1.emitWarningIfUnsupportedVersion)(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, node_config_provider_1.loadConfig)(httpAuthSchemes_1.NODE_AUTH_SCHEME_PREFERENCE_OPTIONS, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? util_body_length_node_1.calculateBodyLength,
        credentialDefaultProvider: config2?.credentialDefaultProvider ?? credential_provider_node_1.defaultProvider,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, util_user_agent_node_1.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_json_1.default.version }),
        maxAttempts: config2?.maxAttempts ?? (0, node_config_provider_1.loadConfig)(middleware_retry_1.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_REGION_CONFIG_OPTIONS, { ...config_resolver_1.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: node_http_handler_1.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, node_config_provider_1.loadConfig)({
          ...middleware_retry_1.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || util_retry_1.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? hash_node_1.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? node_http_handler_1.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, node_config_provider_1.loadConfig)(util_user_agent_node_1.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-waiter/dist-cjs/index.js
var require_dist_cjs139 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/node_modules/@smithy/util-waiter/dist-cjs/index.js"(exports2) {
    "use strict";
    var getCircularReplacer3 = /* @__PURE__ */ __name(() => {
      const seen = /* @__PURE__ */ new WeakSet();
      return (key, value) => {
        if (typeof value === "object" && value !== null) {
          if (seen.has(value)) {
            return "[Circular]";
          }
          seen.add(value);
        }
        return value;
      };
    }, "getCircularReplacer");
    var sleep4 = /* @__PURE__ */ __name((seconds) => {
      return new Promise((resolve13) => setTimeout(resolve13, seconds * 1e3));
    }, "sleep");
    var waiterServiceDefaults3 = {
      minDelay: 2,
      maxDelay: 120
    };
    exports2.WaiterState = void 0;
    (function(WaiterState3) {
      WaiterState3["ABORTED"] = "ABORTED";
      WaiterState3["FAILURE"] = "FAILURE";
      WaiterState3["SUCCESS"] = "SUCCESS";
      WaiterState3["RETRY"] = "RETRY";
      WaiterState3["TIMEOUT"] = "TIMEOUT";
    })(exports2.WaiterState || (exports2.WaiterState = {}));
    var checkExceptions3 = /* @__PURE__ */ __name((result2) => {
      if (result2.state === exports2.WaiterState.ABORTED) {
        const abortError = new Error(`${JSON.stringify({
          ...result2,
          reason: "Request was aborted"
        }, getCircularReplacer3())}`);
        abortError.name = "AbortError";
        throw abortError;
      } else if (result2.state === exports2.WaiterState.TIMEOUT) {
        const timeoutError = new Error(`${JSON.stringify({
          ...result2,
          reason: "Waiter has timed out"
        }, getCircularReplacer3())}`);
        timeoutError.name = "TimeoutError";
        throw timeoutError;
      } else if (result2.state !== exports2.WaiterState.SUCCESS) {
        throw new Error(`${JSON.stringify(result2, getCircularReplacer3())}`);
      }
      return result2;
    }, "checkExceptions");
    var runPolling3 = /* @__PURE__ */ __name(async ({ minDelay, maxDelay, maxWaitTime, abortController, client, abortSignal }, input, acceptorChecks) => {
      const observedResponses = {};
      const [minDelayMs, maxDelayMs] = [minDelay * 1e3, maxDelay * 1e3];
      let currentAttempt = 0;
      const waitUntil = Date.now() + maxWaitTime * 1e3;
      const warn403Time = Date.now() + 6e4;
      let didWarn403 = false;
      while (true) {
        if (currentAttempt > 0) {
          const delayMs = exponentialBackoffWithJitter3(minDelayMs, maxDelayMs, currentAttempt, waitUntil);
          if (abortController?.signal?.aborted || abortSignal?.aborted) {
            const message2 = "AbortController signal aborted.";
            observedResponses[message2] |= 0;
            observedResponses[message2] += 1;
            return { state: exports2.WaiterState.ABORTED, observedResponses };
          }
          if (Date.now() + delayMs > waitUntil) {
            return { state: exports2.WaiterState.TIMEOUT, observedResponses };
          }
          await sleep4(delayMs / 1e3);
        }
        const { state: state13, reason } = await acceptorChecks(client, input);
        if (reason) {
          const message2 = createMessageFromResponse3(reason);
          observedResponses[message2] |= 0;
          observedResponses[message2] += 1;
        }
        if (state13 !== exports2.WaiterState.RETRY) {
          return { state: state13, reason, final: reason, observedResponses };
        }
        currentAttempt += 1;
        if (!didWarn403 && Date.now() >= warn403Time) {
          checkWarn4033(observedResponses, client);
          didWarn403 = true;
        }
      }
    }, "runPolling");
    var checkWarn4033 = /* @__PURE__ */ __name((observedResponses = {}, client) => {
      const orderedErrors = Object.keys(observedResponses);
      let count403 = 0;
      for (const response of orderedErrors) {
        const n10 = observedResponses[response] | 0;
        if (response.startsWith("403:")) {
          count403 += n10;
        }
      }
      const clientLogger = client?.config?.logger;
      const warningLogger = typeof clientLogger?.warn === "function" && !clientLogger.constructor?.name?.includes?.("NoOpLogger") ? clientLogger : console;
      if (count403 >= 3 || orderedErrors[orderedErrors.length - 1].startsWith("403:")) {
        warningLogger.warn(`@smithy/util-waiter WARN - 403 status code encountered during waiter polling.`);
      }
    }, "checkWarn403");
    var createMessageFromResponse3 = /* @__PURE__ */ __name((reason) => {
      const status = reason?.$response?.statusCode ?? reason?.$metadata?.httpStatusCode;
      if (reason?.$responseBodyText) {
        return `${status ? status + ": " : ""}Deserialization error for body: ${reason.$responseBodyText}`;
      }
      if (status) {
        if (reason?.$response || reason?.message) {
          return `${status ?? "Unknown"}: ${reason?.message}`;
        }
        return `${status}: OK`;
      }
      return String(reason?.message ?? JSON.stringify(reason, getCircularReplacer3()) ?? "Unknown");
    }, "createMessageFromResponse");
    var exponentialBackoffWithJitter3 = /* @__PURE__ */ __name((minDelayMs, maxDelayMs, attempt, waitUntil) => {
      const attemptCountCeiling = Math.log(maxDelayMs / minDelayMs) / Math.log(2) + 1;
      if (attempt > attemptCountCeiling) {
        return maxDelayMs;
      }
      const delay = minDelayMs * 2 ** (attempt - 1);
      const capped = Math.min(delay, maxDelayMs);
      const waitFor2 = randomInRange3(minDelayMs, capped);
      if (Date.now() + waitFor2 > waitUntil) {
        const timeRemaining = waitUntil - Date.now();
        return Math.max(0, timeRemaining - 500);
      }
      return waitFor2;
    }, "exponentialBackoffWithJitter");
    var randomInRange3 = /* @__PURE__ */ __name((min, max) => min + Math.random() * (max - min), "randomInRange");
    var validateWaiterOptions3 = /* @__PURE__ */ __name((options) => {
      if (options.maxWaitTime <= 0) {
        throw new Error(`WaiterConfiguration.maxWaitTime must be greater than 0`);
      } else if (options.minDelay <= 0) {
        throw new Error(`WaiterConfiguration.minDelay must be greater than 0`);
      } else if (options.maxDelay <= 0) {
        throw new Error(`WaiterConfiguration.maxDelay must be greater than 0`);
      } else if (options.maxWaitTime <= options.minDelay) {
        throw new Error(`WaiterConfiguration.maxWaitTime [${options.maxWaitTime}] must be greater than WaiterConfiguration.minDelay [${options.minDelay}] for this waiter`);
      } else if (options.maxDelay < options.minDelay) {
        throw new Error(`WaiterConfiguration.maxDelay [${options.maxDelay}] must be greater than WaiterConfiguration.minDelay [${options.minDelay}] for this waiter`);
      }
    }, "validateWaiterOptions");
    var abortTimeout3 = /* @__PURE__ */ __name((abortSignal) => {
      let onAbort;
      const promise = new Promise((resolve13) => {
        onAbort = /* @__PURE__ */ __name(() => resolve13({ state: exports2.WaiterState.ABORTED }), "onAbort");
        if (typeof abortSignal.addEventListener === "function") {
          abortSignal.addEventListener("abort", onAbort);
        } else {
          abortSignal.onabort = onAbort;
        }
      });
      return {
        clearListener() {
          if (typeof abortSignal.removeEventListener === "function") {
            abortSignal.removeEventListener("abort", onAbort);
          }
        },
        aborted: promise
      };
    }, "abortTimeout");
    var createWaiter3 = /* @__PURE__ */ __name(async (options, input, acceptorChecks) => {
      const params = {
        ...waiterServiceDefaults3,
        ...options
      };
      validateWaiterOptions3(params);
      const exitConditions = [runPolling3(params, input, acceptorChecks)];
      const finalize = [];
      if (options.abortSignal) {
        const { aborted, clearListener } = abortTimeout3(options.abortSignal);
        finalize.push(clearListener);
        exitConditions.push(aborted);
      }
      if (options.abortController?.signal) {
        const { aborted, clearListener } = abortTimeout3(options.abortController.signal);
        finalize.push(clearListener);
        exitConditions.push(aborted);
      }
      return Promise.race(exitConditions).then((result2) => {
        for (const fn of finalize) {
          fn();
        }
        return result2;
      });
    }, "createWaiter");
    exports2.checkExceptions = checkExceptions3;
    exports2.createWaiter = createWaiter3;
    exports2.waiterServiceDefaults = waiterServiceDefaults3;
  }
});

// ../../node_modules/@aws-sdk/client-cloudformation/dist-cjs/index.js
var require_dist_cjs140 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudformation/dist-cjs/index.js"(exports2) {
    "use strict";
    var middlewareHostHeader = require_dist_cjs3();
    var middlewareLogger = require_dist_cjs4();
    var middlewareRecursionDetection = require_dist_cjs5();
    var middlewareUserAgent = require_dist_cjs127();
    var configResolver = require_dist_cjs25();
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var schema = (init_schema4(), __toCommonJS(schema_exports));
    var middlewareContentLength = require_dist_cjs26();
    var middlewareEndpoint = require_dist_cjs31();
    var middlewareRetry = require_dist_cjs128();
    var smithyClient = require_dist_cjs34();
    var httpAuthSchemeProvider = require_httpAuthSchemeProvider5();
    var runtimeConfig = require_runtimeConfig6();
    var regionConfigResolver = require_dist_cjs48();
    var protocolHttp = require_dist_cjs2();
    var schemas_0 = require_schemas_05();
    var utilWaiter = require_dist_cjs139();
    var errors = require_errors5();
    var CloudFormationServiceException = require_CloudFormationServiceException();
    var resolveClientEndpointParameters32 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "cloudformation"
      });
    }, "resolveClientEndpointParameters");
    var commonParams32 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
    var getHttpAuthExtensionConfiguration32 = /* @__PURE__ */ __name((runtimeConfig2) => {
      const _httpAuthSchemes = runtimeConfig2.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig2.httpAuthSchemeProvider;
      let _credentials = runtimeConfig2.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider2) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider2;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    var resolveHttpAuthRuntimeConfig32 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
    var resolveRuntimeExtensions32 = /* @__PURE__ */ __name((runtimeConfig2, extensions) => {
      const extensionConfiguration = Object.assign(regionConfigResolver.getAwsRegionExtensionConfiguration(runtimeConfig2), smithyClient.getDefaultExtensionConfiguration(runtimeConfig2), protocolHttp.getHttpHandlerExtensionConfiguration(runtimeConfig2), getHttpAuthExtensionConfiguration32(runtimeConfig2));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig2, regionConfigResolver.resolveAwsRegionExtensionConfiguration(extensionConfiguration), smithyClient.resolveDefaultRuntimeConfig(extensionConfiguration), protocolHttp.resolveHttpHandlerRuntimeConfig(extensionConfiguration), resolveHttpAuthRuntimeConfig32(extensionConfiguration));
    }, "resolveRuntimeExtensions");
    var CloudFormationClient2 = class extends smithyClient.Client {
      static {
        __name(this, "CloudFormationClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = runtimeConfig.getRuntimeConfig(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters32(_config_0);
        const _config_2 = middlewareUserAgent.resolveUserAgentConfig(_config_1);
        const _config_3 = middlewareRetry.resolveRetryConfig(_config_2);
        const _config_4 = configResolver.resolveRegionConfig(_config_3);
        const _config_5 = middlewareHostHeader.resolveHostHeaderConfig(_config_4);
        const _config_6 = middlewareEndpoint.resolveEndpointConfig(_config_5);
        const _config_7 = httpAuthSchemeProvider.resolveHttpAuthSchemeConfig(_config_6);
        const _config_8 = resolveRuntimeExtensions32(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(schema.getSchemaSerdePlugin(this.config));
        this.middlewareStack.use(middlewareUserAgent.getUserAgentPlugin(this.config));
        this.middlewareStack.use(middlewareRetry.getRetryPlugin(this.config));
        this.middlewareStack.use(middlewareContentLength.getContentLengthPlugin(this.config));
        this.middlewareStack.use(middlewareHostHeader.getHostHeaderPlugin(this.config));
        this.middlewareStack.use(middlewareLogger.getLoggerPlugin(this.config));
        this.middlewareStack.use(middlewareRecursionDetection.getRecursionDetectionPlugin(this.config));
        this.middlewareStack.use(core.getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: httpAuthSchemeProvider.defaultCloudFormationHttpAuthSchemeParametersProvider,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new core.DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(core.getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
    var ActivateOrganizationsAccessCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "ActivateOrganizationsAccess", {}).n("CloudFormationClient", "ActivateOrganizationsAccessCommand").sc(schemas_0.ActivateOrganizationsAccess$).build() {
      static {
        __name(this, "ActivateOrganizationsAccessCommand");
      }
    };
    var ActivateTypeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "ActivateType", {}).n("CloudFormationClient", "ActivateTypeCommand").sc(schemas_0.ActivateType$).build() {
      static {
        __name(this, "ActivateTypeCommand");
      }
    };
    var BatchDescribeTypeConfigurationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "BatchDescribeTypeConfigurations", {}).n("CloudFormationClient", "BatchDescribeTypeConfigurationsCommand").sc(schemas_0.BatchDescribeTypeConfigurations$).build() {
      static {
        __name(this, "BatchDescribeTypeConfigurationsCommand");
      }
    };
    var CancelUpdateStackCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "CancelUpdateStack", {}).n("CloudFormationClient", "CancelUpdateStackCommand").sc(schemas_0.CancelUpdateStack$).build() {
      static {
        __name(this, "CancelUpdateStackCommand");
      }
    };
    var ContinueUpdateRollbackCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "ContinueUpdateRollback", {}).n("CloudFormationClient", "ContinueUpdateRollbackCommand").sc(schemas_0.ContinueUpdateRollback$).build() {
      static {
        __name(this, "ContinueUpdateRollbackCommand");
      }
    };
    var CreateChangeSetCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "CreateChangeSet", {}).n("CloudFormationClient", "CreateChangeSetCommand").sc(schemas_0.CreateChangeSet$).build() {
      static {
        __name(this, "CreateChangeSetCommand");
      }
    };
    var CreateGeneratedTemplateCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "CreateGeneratedTemplate", {}).n("CloudFormationClient", "CreateGeneratedTemplateCommand").sc(schemas_0.CreateGeneratedTemplate$).build() {
      static {
        __name(this, "CreateGeneratedTemplateCommand");
      }
    };
    var CreateStackCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "CreateStack", {}).n("CloudFormationClient", "CreateStackCommand").sc(schemas_0.CreateStack$).build() {
      static {
        __name(this, "CreateStackCommand");
      }
    };
    var CreateStackInstancesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "CreateStackInstances", {}).n("CloudFormationClient", "CreateStackInstancesCommand").sc(schemas_0.CreateStackInstances$).build() {
      static {
        __name(this, "CreateStackInstancesCommand");
      }
    };
    var CreateStackRefactorCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "CreateStackRefactor", {}).n("CloudFormationClient", "CreateStackRefactorCommand").sc(schemas_0.CreateStackRefactor$).build() {
      static {
        __name(this, "CreateStackRefactorCommand");
      }
    };
    var CreateStackSetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "CreateStackSet", {}).n("CloudFormationClient", "CreateStackSetCommand").sc(schemas_0.CreateStackSet$).build() {
      static {
        __name(this, "CreateStackSetCommand");
      }
    };
    var DeactivateOrganizationsAccessCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DeactivateOrganizationsAccess", {}).n("CloudFormationClient", "DeactivateOrganizationsAccessCommand").sc(schemas_0.DeactivateOrganizationsAccess$).build() {
      static {
        __name(this, "DeactivateOrganizationsAccessCommand");
      }
    };
    var DeactivateTypeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DeactivateType", {}).n("CloudFormationClient", "DeactivateTypeCommand").sc(schemas_0.DeactivateType$).build() {
      static {
        __name(this, "DeactivateTypeCommand");
      }
    };
    var DeleteChangeSetCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DeleteChangeSet", {}).n("CloudFormationClient", "DeleteChangeSetCommand").sc(schemas_0.DeleteChangeSet$).build() {
      static {
        __name(this, "DeleteChangeSetCommand");
      }
    };
    var DeleteGeneratedTemplateCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DeleteGeneratedTemplate", {}).n("CloudFormationClient", "DeleteGeneratedTemplateCommand").sc(schemas_0.DeleteGeneratedTemplate$).build() {
      static {
        __name(this, "DeleteGeneratedTemplateCommand");
      }
    };
    var DeleteStackCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DeleteStack", {}).n("CloudFormationClient", "DeleteStackCommand").sc(schemas_0.DeleteStack$).build() {
      static {
        __name(this, "DeleteStackCommand");
      }
    };
    var DeleteStackInstancesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DeleteStackInstances", {}).n("CloudFormationClient", "DeleteStackInstancesCommand").sc(schemas_0.DeleteStackInstances$).build() {
      static {
        __name(this, "DeleteStackInstancesCommand");
      }
    };
    var DeleteStackSetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DeleteStackSet", {}).n("CloudFormationClient", "DeleteStackSetCommand").sc(schemas_0.DeleteStackSet$).build() {
      static {
        __name(this, "DeleteStackSetCommand");
      }
    };
    var DeregisterTypeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DeregisterType", {}).n("CloudFormationClient", "DeregisterTypeCommand").sc(schemas_0.DeregisterType$).build() {
      static {
        __name(this, "DeregisterTypeCommand");
      }
    };
    var DescribeAccountLimitsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DescribeAccountLimits", {}).n("CloudFormationClient", "DescribeAccountLimitsCommand").sc(schemas_0.DescribeAccountLimits$).build() {
      static {
        __name(this, "DescribeAccountLimitsCommand");
      }
    };
    var DescribeChangeSetCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DescribeChangeSet", {}).n("CloudFormationClient", "DescribeChangeSetCommand").sc(schemas_0.DescribeChangeSet$).build() {
      static {
        __name(this, "DescribeChangeSetCommand");
      }
    };
    var DescribeChangeSetHooksCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DescribeChangeSetHooks", {}).n("CloudFormationClient", "DescribeChangeSetHooksCommand").sc(schemas_0.DescribeChangeSetHooks$).build() {
      static {
        __name(this, "DescribeChangeSetHooksCommand");
      }
    };
    var DescribeEventsCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DescribeEvents", {}).n("CloudFormationClient", "DescribeEventsCommand").sc(schemas_0.DescribeEvents$).build() {
      static {
        __name(this, "DescribeEventsCommand");
      }
    };
    var DescribeGeneratedTemplateCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DescribeGeneratedTemplate", {}).n("CloudFormationClient", "DescribeGeneratedTemplateCommand").sc(schemas_0.DescribeGeneratedTemplate$).build() {
      static {
        __name(this, "DescribeGeneratedTemplateCommand");
      }
    };
    var DescribeOrganizationsAccessCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DescribeOrganizationsAccess", {}).n("CloudFormationClient", "DescribeOrganizationsAccessCommand").sc(schemas_0.DescribeOrganizationsAccess$).build() {
      static {
        __name(this, "DescribeOrganizationsAccessCommand");
      }
    };
    var DescribePublisherCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DescribePublisher", {}).n("CloudFormationClient", "DescribePublisherCommand").sc(schemas_0.DescribePublisher$).build() {
      static {
        __name(this, "DescribePublisherCommand");
      }
    };
    var DescribeResourceScanCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DescribeResourceScan", {}).n("CloudFormationClient", "DescribeResourceScanCommand").sc(schemas_0.DescribeResourceScan$).build() {
      static {
        __name(this, "DescribeResourceScanCommand");
      }
    };
    var DescribeStackDriftDetectionStatusCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DescribeStackDriftDetectionStatus", {}).n("CloudFormationClient", "DescribeStackDriftDetectionStatusCommand").sc(schemas_0.DescribeStackDriftDetectionStatus$).build() {
      static {
        __name(this, "DescribeStackDriftDetectionStatusCommand");
      }
    };
    var DescribeStackEventsCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DescribeStackEvents", {}).n("CloudFormationClient", "DescribeStackEventsCommand").sc(schemas_0.DescribeStackEvents$).build() {
      static {
        __name(this, "DescribeStackEventsCommand");
      }
    };
    var DescribeStackInstanceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DescribeStackInstance", {}).n("CloudFormationClient", "DescribeStackInstanceCommand").sc(schemas_0.DescribeStackInstance$).build() {
      static {
        __name(this, "DescribeStackInstanceCommand");
      }
    };
    var DescribeStackRefactorCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DescribeStackRefactor", {}).n("CloudFormationClient", "DescribeStackRefactorCommand").sc(schemas_0.DescribeStackRefactor$).build() {
      static {
        __name(this, "DescribeStackRefactorCommand");
      }
    };
    var DescribeStackResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DescribeStackResource", {}).n("CloudFormationClient", "DescribeStackResourceCommand").sc(schemas_0.DescribeStackResource$).build() {
      static {
        __name(this, "DescribeStackResourceCommand");
      }
    };
    var DescribeStackResourceDriftsCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DescribeStackResourceDrifts", {}).n("CloudFormationClient", "DescribeStackResourceDriftsCommand").sc(schemas_0.DescribeStackResourceDrifts$).build() {
      static {
        __name(this, "DescribeStackResourceDriftsCommand");
      }
    };
    var DescribeStackResourcesCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DescribeStackResources", {}).n("CloudFormationClient", "DescribeStackResourcesCommand").sc(schemas_0.DescribeStackResources$).build() {
      static {
        __name(this, "DescribeStackResourcesCommand");
      }
    };
    var DescribeStacksCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DescribeStacks", {}).n("CloudFormationClient", "DescribeStacksCommand").sc(schemas_0.DescribeStacks$).build() {
      static {
        __name(this, "DescribeStacksCommand");
      }
    };
    var DescribeStackSetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DescribeStackSet", {}).n("CloudFormationClient", "DescribeStackSetCommand").sc(schemas_0.DescribeStackSet$).build() {
      static {
        __name(this, "DescribeStackSetCommand");
      }
    };
    var DescribeStackSetOperationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DescribeStackSetOperation", {}).n("CloudFormationClient", "DescribeStackSetOperationCommand").sc(schemas_0.DescribeStackSetOperation$).build() {
      static {
        __name(this, "DescribeStackSetOperationCommand");
      }
    };
    var DescribeTypeCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DescribeType", {}).n("CloudFormationClient", "DescribeTypeCommand").sc(schemas_0.DescribeType$).build() {
      static {
        __name(this, "DescribeTypeCommand");
      }
    };
    var DescribeTypeRegistrationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DescribeTypeRegistration", {}).n("CloudFormationClient", "DescribeTypeRegistrationCommand").sc(schemas_0.DescribeTypeRegistration$).build() {
      static {
        __name(this, "DescribeTypeRegistrationCommand");
      }
    };
    var DetectStackDriftCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DetectStackDrift", {}).n("CloudFormationClient", "DetectStackDriftCommand").sc(schemas_0.DetectStackDrift$).build() {
      static {
        __name(this, "DetectStackDriftCommand");
      }
    };
    var DetectStackResourceDriftCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DetectStackResourceDrift", {}).n("CloudFormationClient", "DetectStackResourceDriftCommand").sc(schemas_0.DetectStackResourceDrift$).build() {
      static {
        __name(this, "DetectStackResourceDriftCommand");
      }
    };
    var DetectStackSetDriftCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "DetectStackSetDrift", {}).n("CloudFormationClient", "DetectStackSetDriftCommand").sc(schemas_0.DetectStackSetDrift$).build() {
      static {
        __name(this, "DetectStackSetDriftCommand");
      }
    };
    var EstimateTemplateCostCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "EstimateTemplateCost", {}).n("CloudFormationClient", "EstimateTemplateCostCommand").sc(schemas_0.EstimateTemplateCost$).build() {
      static {
        __name(this, "EstimateTemplateCostCommand");
      }
    };
    var ExecuteChangeSetCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "ExecuteChangeSet", {}).n("CloudFormationClient", "ExecuteChangeSetCommand").sc(schemas_0.ExecuteChangeSet$).build() {
      static {
        __name(this, "ExecuteChangeSetCommand");
      }
    };
    var ExecuteStackRefactorCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "ExecuteStackRefactor", {}).n("CloudFormationClient", "ExecuteStackRefactorCommand").sc(schemas_0.ExecuteStackRefactor$).build() {
      static {
        __name(this, "ExecuteStackRefactorCommand");
      }
    };
    var GetGeneratedTemplateCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "GetGeneratedTemplate", {}).n("CloudFormationClient", "GetGeneratedTemplateCommand").sc(schemas_0.GetGeneratedTemplate$).build() {
      static {
        __name(this, "GetGeneratedTemplateCommand");
      }
    };
    var GetHookResultCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "GetHookResult", {}).n("CloudFormationClient", "GetHookResultCommand").sc(schemas_0.GetHookResult$).build() {
      static {
        __name(this, "GetHookResultCommand");
      }
    };
    var GetStackPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "GetStackPolicy", {}).n("CloudFormationClient", "GetStackPolicyCommand").sc(schemas_0.GetStackPolicy$).build() {
      static {
        __name(this, "GetStackPolicyCommand");
      }
    };
    var GetTemplateCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "GetTemplate", {}).n("CloudFormationClient", "GetTemplateCommand").sc(schemas_0.GetTemplate$).build() {
      static {
        __name(this, "GetTemplateCommand");
      }
    };
    var GetTemplateSummaryCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "GetTemplateSummary", {}).n("CloudFormationClient", "GetTemplateSummaryCommand").sc(schemas_0.GetTemplateSummary$).build() {
      static {
        __name(this, "GetTemplateSummaryCommand");
      }
    };
    var ImportStacksToStackSetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "ImportStacksToStackSet", {}).n("CloudFormationClient", "ImportStacksToStackSetCommand").sc(schemas_0.ImportStacksToStackSet$).build() {
      static {
        __name(this, "ImportStacksToStackSetCommand");
      }
    };
    var ListChangeSetsCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "ListChangeSets", {}).n("CloudFormationClient", "ListChangeSetsCommand").sc(schemas_0.ListChangeSets$).build() {
      static {
        __name(this, "ListChangeSetsCommand");
      }
    };
    var ListExportsCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "ListExports", {}).n("CloudFormationClient", "ListExportsCommand").sc(schemas_0.ListExports$).build() {
      static {
        __name(this, "ListExportsCommand");
      }
    };
    var ListGeneratedTemplatesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "ListGeneratedTemplates", {}).n("CloudFormationClient", "ListGeneratedTemplatesCommand").sc(schemas_0.ListGeneratedTemplates$).build() {
      static {
        __name(this, "ListGeneratedTemplatesCommand");
      }
    };
    var ListHookResultsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "ListHookResults", {}).n("CloudFormationClient", "ListHookResultsCommand").sc(schemas_0.ListHookResults$).build() {
      static {
        __name(this, "ListHookResultsCommand");
      }
    };
    var ListImportsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "ListImports", {}).n("CloudFormationClient", "ListImportsCommand").sc(schemas_0.ListImports$).build() {
      static {
        __name(this, "ListImportsCommand");
      }
    };
    var ListResourceScanRelatedResourcesCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "ListResourceScanRelatedResources", {}).n("CloudFormationClient", "ListResourceScanRelatedResourcesCommand").sc(schemas_0.ListResourceScanRelatedResources$).build() {
      static {
        __name(this, "ListResourceScanRelatedResourcesCommand");
      }
    };
    var ListResourceScanResourcesCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "ListResourceScanResources", {}).n("CloudFormationClient", "ListResourceScanResourcesCommand").sc(schemas_0.ListResourceScanResources$).build() {
      static {
        __name(this, "ListResourceScanResourcesCommand");
      }
    };
    var ListResourceScansCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "ListResourceScans", {}).n("CloudFormationClient", "ListResourceScansCommand").sc(schemas_0.ListResourceScans$).build() {
      static {
        __name(this, "ListResourceScansCommand");
      }
    };
    var ListStackInstanceResourceDriftsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "ListStackInstanceResourceDrifts", {}).n("CloudFormationClient", "ListStackInstanceResourceDriftsCommand").sc(schemas_0.ListStackInstanceResourceDrifts$).build() {
      static {
        __name(this, "ListStackInstanceResourceDriftsCommand");
      }
    };
    var ListStackInstancesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "ListStackInstances", {}).n("CloudFormationClient", "ListStackInstancesCommand").sc(schemas_0.ListStackInstances$).build() {
      static {
        __name(this, "ListStackInstancesCommand");
      }
    };
    var ListStackRefactorActionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "ListStackRefactorActions", {}).n("CloudFormationClient", "ListStackRefactorActionsCommand").sc(schemas_0.ListStackRefactorActions$).build() {
      static {
        __name(this, "ListStackRefactorActionsCommand");
      }
    };
    var ListStackRefactorsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "ListStackRefactors", {}).n("CloudFormationClient", "ListStackRefactorsCommand").sc(schemas_0.ListStackRefactors$).build() {
      static {
        __name(this, "ListStackRefactorsCommand");
      }
    };
    var ListStackResourcesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "ListStackResources", {}).n("CloudFormationClient", "ListStackResourcesCommand").sc(schemas_0.ListStackResources$).build() {
      static {
        __name(this, "ListStackResourcesCommand");
      }
    };
    var ListStacksCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "ListStacks", {}).n("CloudFormationClient", "ListStacksCommand").sc(schemas_0.ListStacks$).build() {
      static {
        __name(this, "ListStacksCommand");
      }
    };
    var ListStackSetAutoDeploymentTargetsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "ListStackSetAutoDeploymentTargets", {}).n("CloudFormationClient", "ListStackSetAutoDeploymentTargetsCommand").sc(schemas_0.ListStackSetAutoDeploymentTargets$).build() {
      static {
        __name(this, "ListStackSetAutoDeploymentTargetsCommand");
      }
    };
    var ListStackSetOperationResultsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "ListStackSetOperationResults", {}).n("CloudFormationClient", "ListStackSetOperationResultsCommand").sc(schemas_0.ListStackSetOperationResults$).build() {
      static {
        __name(this, "ListStackSetOperationResultsCommand");
      }
    };
    var ListStackSetOperationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "ListStackSetOperations", {}).n("CloudFormationClient", "ListStackSetOperationsCommand").sc(schemas_0.ListStackSetOperations$).build() {
      static {
        __name(this, "ListStackSetOperationsCommand");
      }
    };
    var ListStackSetsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "ListStackSets", {}).n("CloudFormationClient", "ListStackSetsCommand").sc(schemas_0.ListStackSets$).build() {
      static {
        __name(this, "ListStackSetsCommand");
      }
    };
    var ListTypeRegistrationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "ListTypeRegistrations", {}).n("CloudFormationClient", "ListTypeRegistrationsCommand").sc(schemas_0.ListTypeRegistrations$).build() {
      static {
        __name(this, "ListTypeRegistrationsCommand");
      }
    };
    var ListTypesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "ListTypes", {}).n("CloudFormationClient", "ListTypesCommand").sc(schemas_0.ListTypes$).build() {
      static {
        __name(this, "ListTypesCommand");
      }
    };
    var ListTypeVersionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "ListTypeVersions", {}).n("CloudFormationClient", "ListTypeVersionsCommand").sc(schemas_0.ListTypeVersions$).build() {
      static {
        __name(this, "ListTypeVersionsCommand");
      }
    };
    var PublishTypeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "PublishType", {}).n("CloudFormationClient", "PublishTypeCommand").sc(schemas_0.PublishType$).build() {
      static {
        __name(this, "PublishTypeCommand");
      }
    };
    var RecordHandlerProgressCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "RecordHandlerProgress", {}).n("CloudFormationClient", "RecordHandlerProgressCommand").sc(schemas_0.RecordHandlerProgress$).build() {
      static {
        __name(this, "RecordHandlerProgressCommand");
      }
    };
    var RegisterPublisherCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "RegisterPublisher", {}).n("CloudFormationClient", "RegisterPublisherCommand").sc(schemas_0.RegisterPublisher$).build() {
      static {
        __name(this, "RegisterPublisherCommand");
      }
    };
    var RegisterTypeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "RegisterType", {}).n("CloudFormationClient", "RegisterTypeCommand").sc(schemas_0.RegisterType$).build() {
      static {
        __name(this, "RegisterTypeCommand");
      }
    };
    var RollbackStackCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "RollbackStack", {}).n("CloudFormationClient", "RollbackStackCommand").sc(schemas_0.RollbackStack$).build() {
      static {
        __name(this, "RollbackStackCommand");
      }
    };
    var SetStackPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "SetStackPolicy", {}).n("CloudFormationClient", "SetStackPolicyCommand").sc(schemas_0.SetStackPolicy$).build() {
      static {
        __name(this, "SetStackPolicyCommand");
      }
    };
    var SetTypeConfigurationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "SetTypeConfiguration", {}).n("CloudFormationClient", "SetTypeConfigurationCommand").sc(schemas_0.SetTypeConfiguration$).build() {
      static {
        __name(this, "SetTypeConfigurationCommand");
      }
    };
    var SetTypeDefaultVersionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "SetTypeDefaultVersion", {}).n("CloudFormationClient", "SetTypeDefaultVersionCommand").sc(schemas_0.SetTypeDefaultVersion$).build() {
      static {
        __name(this, "SetTypeDefaultVersionCommand");
      }
    };
    var SignalResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "SignalResource", {}).n("CloudFormationClient", "SignalResourceCommand").sc(schemas_0.SignalResource$).build() {
      static {
        __name(this, "SignalResourceCommand");
      }
    };
    var StartResourceScanCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "StartResourceScan", {}).n("CloudFormationClient", "StartResourceScanCommand").sc(schemas_0.StartResourceScan$).build() {
      static {
        __name(this, "StartResourceScanCommand");
      }
    };
    var StopStackSetOperationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "StopStackSetOperation", {}).n("CloudFormationClient", "StopStackSetOperationCommand").sc(schemas_0.StopStackSetOperation$).build() {
      static {
        __name(this, "StopStackSetOperationCommand");
      }
    };
    var TestTypeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "TestType", {}).n("CloudFormationClient", "TestTypeCommand").sc(schemas_0.TestType$).build() {
      static {
        __name(this, "TestTypeCommand");
      }
    };
    var UpdateGeneratedTemplateCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "UpdateGeneratedTemplate", {}).n("CloudFormationClient", "UpdateGeneratedTemplateCommand").sc(schemas_0.UpdateGeneratedTemplate$).build() {
      static {
        __name(this, "UpdateGeneratedTemplateCommand");
      }
    };
    var UpdateStackCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "UpdateStack", {}).n("CloudFormationClient", "UpdateStackCommand").sc(schemas_0.UpdateStack$).build() {
      static {
        __name(this, "UpdateStackCommand");
      }
    };
    var UpdateStackInstancesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "UpdateStackInstances", {}).n("CloudFormationClient", "UpdateStackInstancesCommand").sc(schemas_0.UpdateStackInstances$).build() {
      static {
        __name(this, "UpdateStackInstancesCommand");
      }
    };
    var UpdateStackSetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "UpdateStackSet", {}).n("CloudFormationClient", "UpdateStackSetCommand").sc(schemas_0.UpdateStackSet$).build() {
      static {
        __name(this, "UpdateStackSetCommand");
      }
    };
    var UpdateTerminationProtectionCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "UpdateTerminationProtection", {}).n("CloudFormationClient", "UpdateTerminationProtectionCommand").sc(schemas_0.UpdateTerminationProtection$).build() {
      static {
        __name(this, "UpdateTerminationProtectionCommand");
      }
    };
    var ValidateTemplateCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudFormation", "ValidateTemplate", {}).n("CloudFormationClient", "ValidateTemplateCommand").sc(schemas_0.ValidateTemplate$).build() {
      static {
        __name(this, "ValidateTemplateCommand");
      }
    };
    var paginateDescribeAccountLimits = core.createPaginator(CloudFormationClient2, DescribeAccountLimitsCommand, "NextToken", "NextToken", "");
    var paginateDescribeChangeSet = core.createPaginator(CloudFormationClient2, DescribeChangeSetCommand2, "NextToken", "NextToken", "");
    var paginateDescribeEvents2 = core.createPaginator(CloudFormationClient2, DescribeEventsCommand2, "NextToken", "NextToken", "");
    var paginateDescribeStackEvents = core.createPaginator(CloudFormationClient2, DescribeStackEventsCommand2, "NextToken", "NextToken", "");
    var paginateDescribeStackResourceDrifts = core.createPaginator(CloudFormationClient2, DescribeStackResourceDriftsCommand2, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeStacks = core.createPaginator(CloudFormationClient2, DescribeStacksCommand2, "NextToken", "NextToken", "");
    var paginateListChangeSets = core.createPaginator(CloudFormationClient2, ListChangeSetsCommand2, "NextToken", "NextToken", "");
    var paginateListExports = core.createPaginator(CloudFormationClient2, ListExportsCommand2, "NextToken", "NextToken", "");
    var paginateListGeneratedTemplates = core.createPaginator(CloudFormationClient2, ListGeneratedTemplatesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListImports = core.createPaginator(CloudFormationClient2, ListImportsCommand, "NextToken", "NextToken", "");
    var paginateListResourceScanRelatedResources = core.createPaginator(CloudFormationClient2, ListResourceScanRelatedResourcesCommand2, "NextToken", "NextToken", "MaxResults");
    var paginateListResourceScanResources = core.createPaginator(CloudFormationClient2, ListResourceScanResourcesCommand2, "NextToken", "NextToken", "MaxResults");
    var paginateListResourceScans = core.createPaginator(CloudFormationClient2, ListResourceScansCommand2, "NextToken", "NextToken", "MaxResults");
    var paginateListStackInstances = core.createPaginator(CloudFormationClient2, ListStackInstancesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListStackRefactorActions = core.createPaginator(CloudFormationClient2, ListStackRefactorActionsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListStackRefactors = core.createPaginator(CloudFormationClient2, ListStackRefactorsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListStackResources2 = core.createPaginator(CloudFormationClient2, ListStackResourcesCommand, "NextToken", "NextToken", "");
    var paginateListStackSetOperationResults = core.createPaginator(CloudFormationClient2, ListStackSetOperationResultsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListStackSetOperations = core.createPaginator(CloudFormationClient2, ListStackSetOperationsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListStackSets = core.createPaginator(CloudFormationClient2, ListStackSetsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListStacks2 = core.createPaginator(CloudFormationClient2, ListStacksCommand2, "NextToken", "NextToken", "");
    var paginateListTypeRegistrations = core.createPaginator(CloudFormationClient2, ListTypeRegistrationsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListTypes = core.createPaginator(CloudFormationClient2, ListTypesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListTypeVersions = core.createPaginator(CloudFormationClient2, ListTypeVersionsCommand, "NextToken", "NextToken", "MaxResults");
    var checkState$9 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeChangeSetCommand2(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.Status;
          }, "returnComparator");
          if (returnComparator() === "CREATE_COMPLETE") {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.Status;
          }, "returnComparator");
          if (returnComparator() === "FAILED") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name === "ValidationError") {
          return { state: utilWaiter.WaiterState.FAILURE, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$9");
    var waitForChangeSetCreateComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 30, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$9);
    }, "waitForChangeSetCreateComplete");
    var waitUntilChangeSetCreateComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 30, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$9);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilChangeSetCreateComplete");
    var checkState$8 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeStacksCommand2(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "CREATE_COMPLETE";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "UPDATE_COMPLETE";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "UPDATE_IN_PROGRESS";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "UPDATE_COMPLETE_CLEANUP_IN_PROGRESS";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "UPDATE_FAILED";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "UPDATE_ROLLBACK_IN_PROGRESS";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "UPDATE_ROLLBACK_FAILED";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "UPDATE_ROLLBACK_COMPLETE_CLEANUP_IN_PROGRESS";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "UPDATE_ROLLBACK_COMPLETE";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "CREATE_FAILED") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "DELETE_COMPLETE") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "DELETE_FAILED") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "ROLLBACK_FAILED") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "ROLLBACK_COMPLETE") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name === "ValidationError") {
          return { state: utilWaiter.WaiterState.FAILURE, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$8");
    var waitForStackCreateComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 30, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$8);
    }, "waitForStackCreateComplete");
    var waitUntilStackCreateComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 30, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$8);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilStackCreateComplete");
    var checkState$7 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeStacksCommand2(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "DELETE_COMPLETE";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "DELETE_FAILED") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "CREATE_FAILED") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "ROLLBACK_FAILED") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "UPDATE_ROLLBACK_IN_PROGRESS") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "UPDATE_ROLLBACK_FAILED") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "UPDATE_ROLLBACK_COMPLETE") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "UPDATE_COMPLETE") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name === "ValidationError") {
          return { state: utilWaiter.WaiterState.SUCCESS, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$7");
    var waitForStackDeleteComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 30, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$7);
    }, "waitForStackDeleteComplete");
    var waitUntilStackDeleteComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 30, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$7);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilStackDeleteComplete");
    var checkState$6 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeStacksCommand2(input));
        reason = result2;
        return { state: utilWaiter.WaiterState.SUCCESS, reason };
      } catch (exception) {
        reason = exception;
        if (exception.name === "ValidationError") {
          return { state: utilWaiter.WaiterState.RETRY, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$6");
    var waitForStackExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$6);
    }, "waitForStackExists");
    var waitUntilStackExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$6);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilStackExists");
    var checkState$5 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeStacksCommand2(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "IMPORT_COMPLETE";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "ROLLBACK_COMPLETE") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "ROLLBACK_FAILED") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "IMPORT_ROLLBACK_IN_PROGRESS") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "IMPORT_ROLLBACK_FAILED") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "IMPORT_ROLLBACK_COMPLETE") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name === "ValidationError") {
          return { state: utilWaiter.WaiterState.FAILURE, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$5");
    var waitForStackImportComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 30, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$5);
    }, "waitForStackImportComplete");
    var waitUntilStackImportComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 30, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$5);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilStackImportComplete");
    var checkState$4 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeStackRefactorCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.Status;
          }, "returnComparator");
          if (returnComparator() === "CREATE_COMPLETE") {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.Status;
          }, "returnComparator");
          if (returnComparator() === "CREATE_FAILED") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name === "ValidationError") {
          return { state: utilWaiter.WaiterState.FAILURE, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$4");
    var waitForStackRefactorCreateComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$4);
    }, "waitForStackRefactorCreateComplete");
    var waitUntilStackRefactorCreateComplete2 = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$4);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilStackRefactorCreateComplete");
    var checkState$3 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeStackRefactorCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.ExecutionStatus;
          }, "returnComparator");
          if (returnComparator() === "EXECUTE_COMPLETE") {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.ExecutionStatus;
          }, "returnComparator");
          if (returnComparator() === "EXECUTE_FAILED") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.ExecutionStatus;
          }, "returnComparator");
          if (returnComparator() === "ROLLBACK_COMPLETE") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name === "ValidationError") {
          return { state: utilWaiter.WaiterState.FAILURE, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$3");
    var waitForStackRefactorExecuteComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$3);
    }, "waitForStackRefactorExecuteComplete");
    var waitUntilStackRefactorExecuteComplete2 = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$3);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilStackRefactorExecuteComplete");
    var checkState$2 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeStacksCommand2(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "UPDATE_ROLLBACK_COMPLETE";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "UPDATE_FAILED") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "UPDATE_ROLLBACK_FAILED") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "DELETE_FAILED") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name === "ValidationError") {
          return { state: utilWaiter.WaiterState.FAILURE, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$2");
    var waitForStackRollbackComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 30, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$2);
    }, "waitForStackRollbackComplete");
    var waitUntilStackRollbackComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 30, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$2);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilStackRollbackComplete");
    var checkState$1 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeStacksCommand2(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "UPDATE_COMPLETE";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "UPDATE_FAILED") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "UPDATE_ROLLBACK_FAILED") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Stacks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StackStatus;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "UPDATE_ROLLBACK_COMPLETE") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name === "ValidationError") {
          return { state: utilWaiter.WaiterState.FAILURE, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$1");
    var waitForStackUpdateComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 30, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$1);
    }, "waitForStackUpdateComplete");
    var waitUntilStackUpdateComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 30, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$1);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilStackUpdateComplete");
    var checkState = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeTypeRegistrationCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.ProgressStatus;
          }, "returnComparator");
          if (returnComparator() === "COMPLETE") {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.ProgressStatus;
          }, "returnComparator");
          if (returnComparator() === "FAILED") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState");
    var waitForTypeRegistrationComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 30, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState);
    }, "waitForTypeRegistrationComplete");
    var waitUntilTypeRegistrationComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 30, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilTypeRegistrationComplete");
    var commands32 = {
      ActivateOrganizationsAccessCommand,
      ActivateTypeCommand,
      BatchDescribeTypeConfigurationsCommand,
      CancelUpdateStackCommand,
      ContinueUpdateRollbackCommand: ContinueUpdateRollbackCommand2,
      CreateChangeSetCommand: CreateChangeSetCommand2,
      CreateGeneratedTemplateCommand: CreateGeneratedTemplateCommand2,
      CreateStackCommand: CreateStackCommand2,
      CreateStackInstancesCommand,
      CreateStackRefactorCommand: CreateStackRefactorCommand2,
      CreateStackSetCommand,
      DeactivateOrganizationsAccessCommand,
      DeactivateTypeCommand,
      DeleteChangeSetCommand: DeleteChangeSetCommand2,
      DeleteGeneratedTemplateCommand: DeleteGeneratedTemplateCommand2,
      DeleteStackCommand: DeleteStackCommand2,
      DeleteStackInstancesCommand,
      DeleteStackSetCommand,
      DeregisterTypeCommand,
      DescribeAccountLimitsCommand,
      DescribeChangeSetCommand: DescribeChangeSetCommand2,
      DescribeChangeSetHooksCommand,
      DescribeEventsCommand: DescribeEventsCommand2,
      DescribeGeneratedTemplateCommand: DescribeGeneratedTemplateCommand2,
      DescribeOrganizationsAccessCommand,
      DescribePublisherCommand,
      DescribeResourceScanCommand: DescribeResourceScanCommand2,
      DescribeStackDriftDetectionStatusCommand: DescribeStackDriftDetectionStatusCommand2,
      DescribeStackEventsCommand: DescribeStackEventsCommand2,
      DescribeStackInstanceCommand,
      DescribeStackRefactorCommand,
      DescribeStackResourceCommand,
      DescribeStackResourceDriftsCommand: DescribeStackResourceDriftsCommand2,
      DescribeStackResourcesCommand: DescribeStackResourcesCommand2,
      DescribeStacksCommand: DescribeStacksCommand2,
      DescribeStackSetCommand,
      DescribeStackSetOperationCommand,
      DescribeTypeCommand: DescribeTypeCommand2,
      DescribeTypeRegistrationCommand,
      DetectStackDriftCommand: DetectStackDriftCommand2,
      DetectStackResourceDriftCommand: DetectStackResourceDriftCommand2,
      DetectStackSetDriftCommand,
      EstimateTemplateCostCommand,
      ExecuteChangeSetCommand: ExecuteChangeSetCommand2,
      ExecuteStackRefactorCommand: ExecuteStackRefactorCommand2,
      GetGeneratedTemplateCommand: GetGeneratedTemplateCommand2,
      GetHookResultCommand: GetHookResultCommand2,
      GetStackPolicyCommand,
      GetTemplateCommand: GetTemplateCommand2,
      GetTemplateSummaryCommand: GetTemplateSummaryCommand2,
      ImportStacksToStackSetCommand,
      ListChangeSetsCommand: ListChangeSetsCommand2,
      ListExportsCommand: ListExportsCommand2,
      ListGeneratedTemplatesCommand,
      ListHookResultsCommand,
      ListImportsCommand,
      ListResourceScanRelatedResourcesCommand: ListResourceScanRelatedResourcesCommand2,
      ListResourceScanResourcesCommand: ListResourceScanResourcesCommand2,
      ListResourceScansCommand: ListResourceScansCommand2,
      ListStackInstanceResourceDriftsCommand,
      ListStackInstancesCommand,
      ListStackRefactorActionsCommand,
      ListStackRefactorsCommand,
      ListStackResourcesCommand,
      ListStacksCommand: ListStacksCommand2,
      ListStackSetAutoDeploymentTargetsCommand,
      ListStackSetOperationResultsCommand,
      ListStackSetOperationsCommand,
      ListStackSetsCommand,
      ListTypeRegistrationsCommand,
      ListTypesCommand,
      ListTypeVersionsCommand,
      PublishTypeCommand,
      RecordHandlerProgressCommand,
      RegisterPublisherCommand,
      RegisterTypeCommand,
      RollbackStackCommand: RollbackStackCommand2,
      SetStackPolicyCommand,
      SetTypeConfigurationCommand,
      SetTypeDefaultVersionCommand,
      SignalResourceCommand,
      StartResourceScanCommand: StartResourceScanCommand2,
      StopStackSetOperationCommand,
      TestTypeCommand,
      UpdateGeneratedTemplateCommand,
      UpdateStackCommand: UpdateStackCommand2,
      UpdateStackInstancesCommand,
      UpdateStackSetCommand,
      UpdateTerminationProtectionCommand: UpdateTerminationProtectionCommand2,
      ValidateTemplateCommand
    };
    var paginators = {
      paginateDescribeAccountLimits,
      paginateDescribeChangeSet,
      paginateDescribeEvents: paginateDescribeEvents2,
      paginateDescribeStackEvents,
      paginateDescribeStackResourceDrifts,
      paginateDescribeStacks,
      paginateListChangeSets,
      paginateListExports,
      paginateListGeneratedTemplates,
      paginateListImports,
      paginateListResourceScanRelatedResources,
      paginateListResourceScanResources,
      paginateListResourceScans,
      paginateListStackInstances,
      paginateListStackRefactorActions,
      paginateListStackRefactors,
      paginateListStackResources: paginateListStackResources2,
      paginateListStacks: paginateListStacks2,
      paginateListStackSetOperationResults,
      paginateListStackSetOperations,
      paginateListStackSets,
      paginateListTypeRegistrations,
      paginateListTypes,
      paginateListTypeVersions
    };
    var waiters = {
      waitUntilChangeSetCreateComplete,
      waitUntilStackRefactorCreateComplete: waitUntilStackRefactorCreateComplete2,
      waitUntilStackRefactorExecuteComplete: waitUntilStackRefactorExecuteComplete2,
      waitUntilStackCreateComplete,
      waitUntilStackDeleteComplete,
      waitUntilStackExists,
      waitUntilStackImportComplete,
      waitUntilStackRollbackComplete,
      waitUntilStackUpdateComplete,
      waitUntilTypeRegistrationComplete
    };
    var CloudFormation = class extends CloudFormationClient2 {
      static {
        __name(this, "CloudFormation");
      }
    };
    smithyClient.createAggregatedClient(commands32, CloudFormation, { paginators, waiters });
    var AccountFilterType = {
      DIFFERENCE: "DIFFERENCE",
      INTERSECTION: "INTERSECTION",
      NONE: "NONE",
      UNION: "UNION"
    };
    var AccountGateStatus = {
      FAILED: "FAILED",
      SKIPPED: "SKIPPED",
      SUCCEEDED: "SUCCEEDED"
    };
    var ThirdPartyType = {
      HOOK: "HOOK",
      MODULE: "MODULE",
      RESOURCE: "RESOURCE"
    };
    var VersionBump = {
      MAJOR: "MAJOR",
      MINOR: "MINOR"
    };
    var AfterValueFrom = {
      TEMPLATE: "TEMPLATE"
    };
    var AnnotationSeverityLevel = {
      CRITICAL: "CRITICAL",
      HIGH: "HIGH",
      INFORMATIONAL: "INFORMATIONAL",
      LOW: "LOW",
      MEDIUM: "MEDIUM"
    };
    var AnnotationStatus = {
      FAILED: "FAILED",
      PASSED: "PASSED",
      SKIPPED: "SKIPPED"
    };
    var AttributeChangeType = {
      Add: "Add",
      Modify: "Modify",
      Remove: "Remove",
      SyncWithActual: "SyncWithActual"
    };
    var BeaconStackOperationStatus = {
      FAILED: "FAILED",
      IN_PROGRESS: "IN_PROGRESS",
      SUCCEEDED: "SUCCEEDED"
    };
    var BeforeValueFrom = {
      ACTUAL_STATE: "ACTUAL_STATE",
      PREVIOUS_DEPLOYMENT_STATE: "PREVIOUS_DEPLOYMENT_STATE"
    };
    var CallAs = {
      DELEGATED_ADMIN: "DELEGATED_ADMIN",
      SELF: "SELF"
    };
    var Capability = {
      CAPABILITY_AUTO_EXPAND: "CAPABILITY_AUTO_EXPAND",
      CAPABILITY_IAM: "CAPABILITY_IAM",
      CAPABILITY_NAMED_IAM: "CAPABILITY_NAMED_IAM"
    };
    var Category = {
      ACTIVATED: "ACTIVATED",
      AWS_TYPES: "AWS_TYPES",
      REGISTERED: "REGISTERED",
      THIRD_PARTY: "THIRD_PARTY"
    };
    var ChangeAction = {
      Add: "Add",
      Dynamic: "Dynamic",
      Import: "Import",
      Modify: "Modify",
      Remove: "Remove",
      SyncWithActual: "SyncWithActual"
    };
    var ChangeSource = {
      Automatic: "Automatic",
      DirectModification: "DirectModification",
      NoModification: "NoModification",
      ParameterReference: "ParameterReference",
      ResourceAttribute: "ResourceAttribute",
      ResourceReference: "ResourceReference"
    };
    var EvaluationType = {
      Dynamic: "Dynamic",
      Static: "Static"
    };
    var ResourceAttribute = {
      CreationPolicy: "CreationPolicy",
      DeletionPolicy: "DeletionPolicy",
      Metadata: "Metadata",
      Properties: "Properties",
      Tags: "Tags",
      UpdatePolicy: "UpdatePolicy",
      UpdateReplacePolicy: "UpdateReplacePolicy"
    };
    var RequiresRecreation = {
      Always: "Always",
      Conditionally: "Conditionally",
      Never: "Never"
    };
    var PolicyAction = {
      Delete: "Delete",
      ReplaceAndDelete: "ReplaceAndDelete",
      ReplaceAndRetain: "ReplaceAndRetain",
      ReplaceAndSnapshot: "ReplaceAndSnapshot",
      Retain: "Retain",
      Snapshot: "Snapshot"
    };
    var Replacement = {
      Conditional: "Conditional",
      False: "False",
      True: "True"
    };
    var DriftIgnoredReason = {
      MANAGED_BY_AWS: "MANAGED_BY_AWS",
      WRITE_ONLY_PROPERTY: "WRITE_ONLY_PROPERTY"
    };
    var StackResourceDriftStatus2 = {
      DELETED: "DELETED",
      IN_SYNC: "IN_SYNC",
      MODIFIED: "MODIFIED",
      NOT_CHECKED: "NOT_CHECKED",
      UNKNOWN: "UNKNOWN",
      UNSUPPORTED: "UNSUPPORTED"
    };
    var ChangeType2 = {
      Resource: "Resource"
    };
    var HookFailureMode = {
      FAIL: "FAIL",
      WARN: "WARN"
    };
    var HookInvocationPoint = {
      PRE_PROVISION: "PRE_PROVISION"
    };
    var HookTargetType = {
      RESOURCE: "RESOURCE"
    };
    var ChangeSetHooksStatus = {
      PLANNED: "PLANNED",
      PLANNING: "PLANNING",
      UNAVAILABLE: "UNAVAILABLE"
    };
    var ChangeSetStatus3 = {
      CREATE_COMPLETE: "CREATE_COMPLETE",
      CREATE_IN_PROGRESS: "CREATE_IN_PROGRESS",
      CREATE_PENDING: "CREATE_PENDING",
      DELETE_COMPLETE: "DELETE_COMPLETE",
      DELETE_FAILED: "DELETE_FAILED",
      DELETE_IN_PROGRESS: "DELETE_IN_PROGRESS",
      DELETE_PENDING: "DELETE_PENDING",
      FAILED: "FAILED"
    };
    var ExecutionStatus = {
      AVAILABLE: "AVAILABLE",
      EXECUTE_COMPLETE: "EXECUTE_COMPLETE",
      EXECUTE_FAILED: "EXECUTE_FAILED",
      EXECUTE_IN_PROGRESS: "EXECUTE_IN_PROGRESS",
      OBSOLETE: "OBSOLETE",
      UNAVAILABLE: "UNAVAILABLE"
    };
    var ChangeSetType = {
      CREATE: "CREATE",
      IMPORT: "IMPORT",
      UPDATE: "UPDATE"
    };
    var DeploymentMode = {
      REVERT_DRIFT: "REVERT_DRIFT"
    };
    var OnStackFailure = {
      DELETE: "DELETE",
      DO_NOTHING: "DO_NOTHING",
      ROLLBACK: "ROLLBACK"
    };
    var GeneratedTemplateDeletionPolicy = {
      DELETE: "DELETE",
      RETAIN: "RETAIN"
    };
    var GeneratedTemplateUpdateReplacePolicy = {
      DELETE: "DELETE",
      RETAIN: "RETAIN"
    };
    var OnFailure = {
      DELETE: "DELETE",
      DO_NOTHING: "DO_NOTHING",
      ROLLBACK: "ROLLBACK"
    };
    var ConcurrencyMode = {
      SOFT_FAILURE_TOLERANCE: "SOFT_FAILURE_TOLERANCE",
      STRICT_FAILURE_TOLERANCE: "STRICT_FAILURE_TOLERANCE"
    };
    var RegionConcurrencyType = {
      PARALLEL: "PARALLEL",
      SEQUENTIAL: "SEQUENTIAL"
    };
    var PermissionModels = {
      SELF_MANAGED: "SELF_MANAGED",
      SERVICE_MANAGED: "SERVICE_MANAGED"
    };
    var DeletionMode = {
      FORCE_DELETE_STACK: "FORCE_DELETE_STACK",
      STANDARD: "STANDARD"
    };
    var RegistryType = {
      HOOK: "HOOK",
      MODULE: "MODULE",
      RESOURCE: "RESOURCE"
    };
    var StackDriftStatus = {
      DRIFTED: "DRIFTED",
      IN_SYNC: "IN_SYNC",
      NOT_CHECKED: "NOT_CHECKED",
      UNKNOWN: "UNKNOWN"
    };
    var DetailedStatus = {
      CONFIGURATION_COMPLETE: "CONFIGURATION_COMPLETE",
      VALIDATION_FAILED: "VALIDATION_FAILED"
    };
    var EventType2 = {
      HOOK_INVOCATION_ERROR: "HOOK_INVOCATION_ERROR",
      PROGRESS_EVENT: "PROGRESS_EVENT",
      PROVISIONING_ERROR: "PROVISIONING_ERROR",
      STACK_EVENT: "STACK_EVENT",
      VALIDATION_ERROR: "VALIDATION_ERROR"
    };
    var HookStatus = {
      HOOK_COMPLETE_FAILED: "HOOK_COMPLETE_FAILED",
      HOOK_COMPLETE_SUCCEEDED: "HOOK_COMPLETE_SUCCEEDED",
      HOOK_FAILED: "HOOK_FAILED",
      HOOK_IN_PROGRESS: "HOOK_IN_PROGRESS"
    };
    var OperationType = {
      CONTINUE_ROLLBACK: "CONTINUE_ROLLBACK",
      CREATE_CHANGESET: "CREATE_CHANGESET",
      CREATE_STACK: "CREATE_STACK",
      DELETE_STACK: "DELETE_STACK",
      ROLLBACK: "ROLLBACK",
      UPDATE_STACK: "UPDATE_STACK"
    };
    var ResourceStatus2 = {
      CREATE_COMPLETE: "CREATE_COMPLETE",
      CREATE_FAILED: "CREATE_FAILED",
      CREATE_IN_PROGRESS: "CREATE_IN_PROGRESS",
      DELETE_COMPLETE: "DELETE_COMPLETE",
      DELETE_FAILED: "DELETE_FAILED",
      DELETE_IN_PROGRESS: "DELETE_IN_PROGRESS",
      DELETE_SKIPPED: "DELETE_SKIPPED",
      EXPORT_COMPLETE: "EXPORT_COMPLETE",
      EXPORT_FAILED: "EXPORT_FAILED",
      EXPORT_IN_PROGRESS: "EXPORT_IN_PROGRESS",
      EXPORT_ROLLBACK_COMPLETE: "EXPORT_ROLLBACK_COMPLETE",
      EXPORT_ROLLBACK_FAILED: "EXPORT_ROLLBACK_FAILED",
      EXPORT_ROLLBACK_IN_PROGRESS: "EXPORT_ROLLBACK_IN_PROGRESS",
      IMPORT_COMPLETE: "IMPORT_COMPLETE",
      IMPORT_FAILED: "IMPORT_FAILED",
      IMPORT_IN_PROGRESS: "IMPORT_IN_PROGRESS",
      IMPORT_ROLLBACK_COMPLETE: "IMPORT_ROLLBACK_COMPLETE",
      IMPORT_ROLLBACK_FAILED: "IMPORT_ROLLBACK_FAILED",
      IMPORT_ROLLBACK_IN_PROGRESS: "IMPORT_ROLLBACK_IN_PROGRESS",
      ROLLBACK_COMPLETE: "ROLLBACK_COMPLETE",
      ROLLBACK_FAILED: "ROLLBACK_FAILED",
      ROLLBACK_IN_PROGRESS: "ROLLBACK_IN_PROGRESS",
      UPDATE_COMPLETE: "UPDATE_COMPLETE",
      UPDATE_FAILED: "UPDATE_FAILED",
      UPDATE_IN_PROGRESS: "UPDATE_IN_PROGRESS",
      UPDATE_ROLLBACK_COMPLETE: "UPDATE_ROLLBACK_COMPLETE",
      UPDATE_ROLLBACK_FAILED: "UPDATE_ROLLBACK_FAILED",
      UPDATE_ROLLBACK_IN_PROGRESS: "UPDATE_ROLLBACK_IN_PROGRESS"
    };
    var ValidationStatus = {
      FAILED: "FAILED",
      SKIPPED: "SKIPPED"
    };
    var GeneratedTemplateResourceStatus = {
      COMPLETE: "COMPLETE",
      FAILED: "FAILED",
      IN_PROGRESS: "IN_PROGRESS",
      PENDING: "PENDING"
    };
    var WarningType = {
      EXCLUDED_PROPERTIES: "EXCLUDED_PROPERTIES",
      EXCLUDED_RESOURCES: "EXCLUDED_RESOURCES",
      MUTUALLY_EXCLUSIVE_PROPERTIES: "MUTUALLY_EXCLUSIVE_PROPERTIES",
      MUTUALLY_EXCLUSIVE_TYPES: "MUTUALLY_EXCLUSIVE_TYPES",
      UNSUPPORTED_PROPERTIES: "UNSUPPORTED_PROPERTIES"
    };
    var GeneratedTemplateStatus = {
      COMPLETE: "COMPLETE",
      CREATE_IN_PROGRESS: "CREATE_IN_PROGRESS",
      CREATE_PENDING: "CREATE_PENDING",
      DELETE_IN_PROGRESS: "DELETE_IN_PROGRESS",
      DELETE_PENDING: "DELETE_PENDING",
      FAILED: "FAILED",
      UPDATE_IN_PROGRESS: "UPDATE_IN_PROGRESS",
      UPDATE_PENDING: "UPDATE_PENDING"
    };
    var OrganizationStatus = {
      DISABLED: "DISABLED",
      DISABLED_PERMANENTLY: "DISABLED_PERMANENTLY",
      ENABLED: "ENABLED"
    };
    var IdentityProvider = {
      AWS_Marketplace: "AWS_Marketplace",
      Bitbucket: "Bitbucket",
      GitHub: "GitHub"
    };
    var PublisherStatus = {
      UNVERIFIED: "UNVERIFIED",
      VERIFIED: "VERIFIED"
    };
    var ResourceScanStatus = {
      COMPLETE: "COMPLETE",
      EXPIRED: "EXPIRED",
      FAILED: "FAILED",
      IN_PROGRESS: "IN_PROGRESS"
    };
    var StackDriftDetectionStatus = {
      DETECTION_COMPLETE: "DETECTION_COMPLETE",
      DETECTION_FAILED: "DETECTION_FAILED",
      DETECTION_IN_PROGRESS: "DETECTION_IN_PROGRESS"
    };
    var StackInstanceDetailedStatus = {
      CANCELLED: "CANCELLED",
      FAILED: "FAILED",
      FAILED_IMPORT: "FAILED_IMPORT",
      INOPERABLE: "INOPERABLE",
      PENDING: "PENDING",
      RUNNING: "RUNNING",
      SKIPPED_SUSPENDED_ACCOUNT: "SKIPPED_SUSPENDED_ACCOUNT",
      SUCCEEDED: "SUCCEEDED"
    };
    var StackInstanceStatus = {
      CURRENT: "CURRENT",
      INOPERABLE: "INOPERABLE",
      OUTDATED: "OUTDATED"
    };
    var StackRefactorExecutionStatus = {
      AVAILABLE: "AVAILABLE",
      EXECUTE_COMPLETE: "EXECUTE_COMPLETE",
      EXECUTE_FAILED: "EXECUTE_FAILED",
      EXECUTE_IN_PROGRESS: "EXECUTE_IN_PROGRESS",
      OBSOLETE: "OBSOLETE",
      ROLLBACK_COMPLETE: "ROLLBACK_COMPLETE",
      ROLLBACK_FAILED: "ROLLBACK_FAILED",
      ROLLBACK_IN_PROGRESS: "ROLLBACK_IN_PROGRESS",
      UNAVAILABLE: "UNAVAILABLE"
    };
    var StackRefactorStatus = {
      CREATE_COMPLETE: "CREATE_COMPLETE",
      CREATE_FAILED: "CREATE_FAILED",
      CREATE_IN_PROGRESS: "CREATE_IN_PROGRESS",
      DELETE_COMPLETE: "DELETE_COMPLETE",
      DELETE_FAILED: "DELETE_FAILED",
      DELETE_IN_PROGRESS: "DELETE_IN_PROGRESS"
    };
    var DifferenceType = {
      ADD: "ADD",
      NOT_EQUAL: "NOT_EQUAL",
      REMOVE: "REMOVE"
    };
    var StackStatus2 = {
      CREATE_COMPLETE: "CREATE_COMPLETE",
      CREATE_FAILED: "CREATE_FAILED",
      CREATE_IN_PROGRESS: "CREATE_IN_PROGRESS",
      DELETE_COMPLETE: "DELETE_COMPLETE",
      DELETE_FAILED: "DELETE_FAILED",
      DELETE_IN_PROGRESS: "DELETE_IN_PROGRESS",
      IMPORT_COMPLETE: "IMPORT_COMPLETE",
      IMPORT_IN_PROGRESS: "IMPORT_IN_PROGRESS",
      IMPORT_ROLLBACK_COMPLETE: "IMPORT_ROLLBACK_COMPLETE",
      IMPORT_ROLLBACK_FAILED: "IMPORT_ROLLBACK_FAILED",
      IMPORT_ROLLBACK_IN_PROGRESS: "IMPORT_ROLLBACK_IN_PROGRESS",
      REVIEW_IN_PROGRESS: "REVIEW_IN_PROGRESS",
      ROLLBACK_COMPLETE: "ROLLBACK_COMPLETE",
      ROLLBACK_FAILED: "ROLLBACK_FAILED",
      ROLLBACK_IN_PROGRESS: "ROLLBACK_IN_PROGRESS",
      UPDATE_COMPLETE: "UPDATE_COMPLETE",
      UPDATE_COMPLETE_CLEANUP_IN_PROGRESS: "UPDATE_COMPLETE_CLEANUP_IN_PROGRESS",
      UPDATE_FAILED: "UPDATE_FAILED",
      UPDATE_IN_PROGRESS: "UPDATE_IN_PROGRESS",
      UPDATE_ROLLBACK_COMPLETE: "UPDATE_ROLLBACK_COMPLETE",
      UPDATE_ROLLBACK_COMPLETE_CLEANUP_IN_PROGRESS: "UPDATE_ROLLBACK_COMPLETE_CLEANUP_IN_PROGRESS",
      UPDATE_ROLLBACK_FAILED: "UPDATE_ROLLBACK_FAILED",
      UPDATE_ROLLBACK_IN_PROGRESS: "UPDATE_ROLLBACK_IN_PROGRESS"
    };
    var StackSetDriftDetectionStatus = {
      COMPLETED: "COMPLETED",
      FAILED: "FAILED",
      IN_PROGRESS: "IN_PROGRESS",
      PARTIAL_SUCCESS: "PARTIAL_SUCCESS",
      STOPPED: "STOPPED"
    };
    var StackSetDriftStatus = {
      DRIFTED: "DRIFTED",
      IN_SYNC: "IN_SYNC",
      NOT_CHECKED: "NOT_CHECKED"
    };
    var StackSetStatus = {
      ACTIVE: "ACTIVE",
      DELETED: "DELETED"
    };
    var StackSetOperationAction = {
      CREATE: "CREATE",
      DELETE: "DELETE",
      DETECT_DRIFT: "DETECT_DRIFT",
      UPDATE: "UPDATE"
    };
    var StackSetOperationStatus = {
      FAILED: "FAILED",
      QUEUED: "QUEUED",
      RUNNING: "RUNNING",
      STOPPED: "STOPPED",
      STOPPING: "STOPPING",
      SUCCEEDED: "SUCCEEDED"
    };
    var DeprecatedStatus = {
      DEPRECATED: "DEPRECATED",
      LIVE: "LIVE"
    };
    var ProvisioningType = {
      FULLY_MUTABLE: "FULLY_MUTABLE",
      IMMUTABLE: "IMMUTABLE",
      NON_PROVISIONABLE: "NON_PROVISIONABLE"
    };
    var TypeTestsStatus = {
      FAILED: "FAILED",
      IN_PROGRESS: "IN_PROGRESS",
      NOT_TESTED: "NOT_TESTED",
      PASSED: "PASSED"
    };
    var Visibility = {
      PRIVATE: "PRIVATE",
      PUBLIC: "PUBLIC"
    };
    var RegistrationStatus = {
      COMPLETE: "COMPLETE",
      FAILED: "FAILED",
      IN_PROGRESS: "IN_PROGRESS"
    };
    var TemplateFormat = {
      JSON: "JSON",
      YAML: "YAML"
    };
    var HookTargetAction = {
      CREATE: "CREATE",
      DELETE: "DELETE",
      IMPORT: "IMPORT",
      UPDATE: "UPDATE"
    };
    var TemplateStage = {
      Original: "Original",
      Processed: "Processed"
    };
    var ListHookResultsTargetType = {
      CHANGE_SET: "CHANGE_SET",
      CLOUD_CONTROL: "CLOUD_CONTROL",
      RESOURCE: "RESOURCE",
      STACK: "STACK"
    };
    var ScanType = {
      FULL: "FULL",
      PARTIAL: "PARTIAL"
    };
    var StackInstanceFilterName = {
      DETAILED_STATUS: "DETAILED_STATUS",
      DRIFT_STATUS: "DRIFT_STATUS",
      LAST_OPERATION_ID: "LAST_OPERATION_ID"
    };
    var StackRefactorActionType = {
      CREATE: "CREATE",
      MOVE: "MOVE"
    };
    var StackRefactorDetection = {
      AUTO: "AUTO",
      MANUAL: "MANUAL"
    };
    var StackRefactorActionEntity = {
      RESOURCE: "RESOURCE",
      STACK: "STACK"
    };
    var OperationResultFilterName = {
      OPERATION_RESULT_STATUS: "OPERATION_RESULT_STATUS"
    };
    var StackSetOperationResultStatus = {
      CANCELLED: "CANCELLED",
      FAILED: "FAILED",
      PENDING: "PENDING",
      RUNNING: "RUNNING",
      SUCCEEDED: "SUCCEEDED"
    };
    var OperationStatus = {
      FAILED: "FAILED",
      IN_PROGRESS: "IN_PROGRESS",
      PENDING: "PENDING",
      SUCCESS: "SUCCESS"
    };
    var HandlerErrorCode = {
      AccessDenied: "AccessDenied",
      AlreadyExists: "AlreadyExists",
      GeneralServiceException: "GeneralServiceException",
      HandlerInternalFailure: "HandlerInternalFailure",
      InternalFailure: "InternalFailure",
      InvalidCredentials: "InvalidCredentials",
      InvalidRequest: "InvalidRequest",
      InvalidTypeConfiguration: "InvalidTypeConfiguration",
      NetworkFailure: "NetworkFailure",
      NonCompliant: "NonCompliant",
      NotFound: "NotFound",
      NotUpdatable: "NotUpdatable",
      ResourceConflict: "ResourceConflict",
      ServiceInternalError: "ServiceInternalError",
      ServiceLimitExceeded: "ServiceLimitExceeded",
      ServiceTimeout: "NotStabilized",
      Throttling: "Throttling",
      Unknown: "Unknown",
      UnsupportedTarget: "UnsupportedTarget"
    };
    var ResourceSignalStatus = {
      FAILURE: "FAILURE",
      SUCCESS: "SUCCESS"
    };
    exports2.$Command = smithyClient.Command;
    exports2.__Client = smithyClient.Client;
    exports2.CloudFormationServiceException = CloudFormationServiceException.CloudFormationServiceException;
    exports2.AccountFilterType = AccountFilterType;
    exports2.AccountGateStatus = AccountGateStatus;
    exports2.ActivateOrganizationsAccessCommand = ActivateOrganizationsAccessCommand;
    exports2.ActivateTypeCommand = ActivateTypeCommand;
    exports2.AfterValueFrom = AfterValueFrom;
    exports2.AnnotationSeverityLevel = AnnotationSeverityLevel;
    exports2.AnnotationStatus = AnnotationStatus;
    exports2.AttributeChangeType = AttributeChangeType;
    exports2.BatchDescribeTypeConfigurationsCommand = BatchDescribeTypeConfigurationsCommand;
    exports2.BeaconStackOperationStatus = BeaconStackOperationStatus;
    exports2.BeforeValueFrom = BeforeValueFrom;
    exports2.CallAs = CallAs;
    exports2.CancelUpdateStackCommand = CancelUpdateStackCommand;
    exports2.Capability = Capability;
    exports2.Category = Category;
    exports2.ChangeAction = ChangeAction;
    exports2.ChangeSetHooksStatus = ChangeSetHooksStatus;
    exports2.ChangeSetStatus = ChangeSetStatus3;
    exports2.ChangeSetType = ChangeSetType;
    exports2.ChangeSource = ChangeSource;
    exports2.ChangeType = ChangeType2;
    exports2.CloudFormation = CloudFormation;
    exports2.CloudFormationClient = CloudFormationClient2;
    exports2.ConcurrencyMode = ConcurrencyMode;
    exports2.ContinueUpdateRollbackCommand = ContinueUpdateRollbackCommand2;
    exports2.CreateChangeSetCommand = CreateChangeSetCommand2;
    exports2.CreateGeneratedTemplateCommand = CreateGeneratedTemplateCommand2;
    exports2.CreateStackCommand = CreateStackCommand2;
    exports2.CreateStackInstancesCommand = CreateStackInstancesCommand;
    exports2.CreateStackRefactorCommand = CreateStackRefactorCommand2;
    exports2.CreateStackSetCommand = CreateStackSetCommand;
    exports2.DeactivateOrganizationsAccessCommand = DeactivateOrganizationsAccessCommand;
    exports2.DeactivateTypeCommand = DeactivateTypeCommand;
    exports2.DeleteChangeSetCommand = DeleteChangeSetCommand2;
    exports2.DeleteGeneratedTemplateCommand = DeleteGeneratedTemplateCommand2;
    exports2.DeleteStackCommand = DeleteStackCommand2;
    exports2.DeleteStackInstancesCommand = DeleteStackInstancesCommand;
    exports2.DeleteStackSetCommand = DeleteStackSetCommand;
    exports2.DeletionMode = DeletionMode;
    exports2.DeploymentMode = DeploymentMode;
    exports2.DeprecatedStatus = DeprecatedStatus;
    exports2.DeregisterTypeCommand = DeregisterTypeCommand;
    exports2.DescribeAccountLimitsCommand = DescribeAccountLimitsCommand;
    exports2.DescribeChangeSetCommand = DescribeChangeSetCommand2;
    exports2.DescribeChangeSetHooksCommand = DescribeChangeSetHooksCommand;
    exports2.DescribeEventsCommand = DescribeEventsCommand2;
    exports2.DescribeGeneratedTemplateCommand = DescribeGeneratedTemplateCommand2;
    exports2.DescribeOrganizationsAccessCommand = DescribeOrganizationsAccessCommand;
    exports2.DescribePublisherCommand = DescribePublisherCommand;
    exports2.DescribeResourceScanCommand = DescribeResourceScanCommand2;
    exports2.DescribeStackDriftDetectionStatusCommand = DescribeStackDriftDetectionStatusCommand2;
    exports2.DescribeStackEventsCommand = DescribeStackEventsCommand2;
    exports2.DescribeStackInstanceCommand = DescribeStackInstanceCommand;
    exports2.DescribeStackRefactorCommand = DescribeStackRefactorCommand;
    exports2.DescribeStackResourceCommand = DescribeStackResourceCommand;
    exports2.DescribeStackResourceDriftsCommand = DescribeStackResourceDriftsCommand2;
    exports2.DescribeStackResourcesCommand = DescribeStackResourcesCommand2;
    exports2.DescribeStackSetCommand = DescribeStackSetCommand;
    exports2.DescribeStackSetOperationCommand = DescribeStackSetOperationCommand;
    exports2.DescribeStacksCommand = DescribeStacksCommand2;
    exports2.DescribeTypeCommand = DescribeTypeCommand2;
    exports2.DescribeTypeRegistrationCommand = DescribeTypeRegistrationCommand;
    exports2.DetailedStatus = DetailedStatus;
    exports2.DetectStackDriftCommand = DetectStackDriftCommand2;
    exports2.DetectStackResourceDriftCommand = DetectStackResourceDriftCommand2;
    exports2.DetectStackSetDriftCommand = DetectStackSetDriftCommand;
    exports2.DifferenceType = DifferenceType;
    exports2.DriftIgnoredReason = DriftIgnoredReason;
    exports2.EstimateTemplateCostCommand = EstimateTemplateCostCommand;
    exports2.EvaluationType = EvaluationType;
    exports2.EventType = EventType2;
    exports2.ExecuteChangeSetCommand = ExecuteChangeSetCommand2;
    exports2.ExecuteStackRefactorCommand = ExecuteStackRefactorCommand2;
    exports2.ExecutionStatus = ExecutionStatus;
    exports2.GeneratedTemplateDeletionPolicy = GeneratedTemplateDeletionPolicy;
    exports2.GeneratedTemplateResourceStatus = GeneratedTemplateResourceStatus;
    exports2.GeneratedTemplateStatus = GeneratedTemplateStatus;
    exports2.GeneratedTemplateUpdateReplacePolicy = GeneratedTemplateUpdateReplacePolicy;
    exports2.GetGeneratedTemplateCommand = GetGeneratedTemplateCommand2;
    exports2.GetHookResultCommand = GetHookResultCommand2;
    exports2.GetStackPolicyCommand = GetStackPolicyCommand;
    exports2.GetTemplateCommand = GetTemplateCommand2;
    exports2.GetTemplateSummaryCommand = GetTemplateSummaryCommand2;
    exports2.HandlerErrorCode = HandlerErrorCode;
    exports2.HookFailureMode = HookFailureMode;
    exports2.HookInvocationPoint = HookInvocationPoint;
    exports2.HookStatus = HookStatus;
    exports2.HookTargetAction = HookTargetAction;
    exports2.HookTargetType = HookTargetType;
    exports2.IdentityProvider = IdentityProvider;
    exports2.ImportStacksToStackSetCommand = ImportStacksToStackSetCommand;
    exports2.ListChangeSetsCommand = ListChangeSetsCommand2;
    exports2.ListExportsCommand = ListExportsCommand2;
    exports2.ListGeneratedTemplatesCommand = ListGeneratedTemplatesCommand;
    exports2.ListHookResultsCommand = ListHookResultsCommand;
    exports2.ListHookResultsTargetType = ListHookResultsTargetType;
    exports2.ListImportsCommand = ListImportsCommand;
    exports2.ListResourceScanRelatedResourcesCommand = ListResourceScanRelatedResourcesCommand2;
    exports2.ListResourceScanResourcesCommand = ListResourceScanResourcesCommand2;
    exports2.ListResourceScansCommand = ListResourceScansCommand2;
    exports2.ListStackInstanceResourceDriftsCommand = ListStackInstanceResourceDriftsCommand;
    exports2.ListStackInstancesCommand = ListStackInstancesCommand;
    exports2.ListStackRefactorActionsCommand = ListStackRefactorActionsCommand;
    exports2.ListStackRefactorsCommand = ListStackRefactorsCommand;
    exports2.ListStackResourcesCommand = ListStackResourcesCommand;
    exports2.ListStackSetAutoDeploymentTargetsCommand = ListStackSetAutoDeploymentTargetsCommand;
    exports2.ListStackSetOperationResultsCommand = ListStackSetOperationResultsCommand;
    exports2.ListStackSetOperationsCommand = ListStackSetOperationsCommand;
    exports2.ListStackSetsCommand = ListStackSetsCommand;
    exports2.ListStacksCommand = ListStacksCommand2;
    exports2.ListTypeRegistrationsCommand = ListTypeRegistrationsCommand;
    exports2.ListTypeVersionsCommand = ListTypeVersionsCommand;
    exports2.ListTypesCommand = ListTypesCommand;
    exports2.OnFailure = OnFailure;
    exports2.OnStackFailure = OnStackFailure;
    exports2.OperationResultFilterName = OperationResultFilterName;
    exports2.OperationStatus = OperationStatus;
    exports2.OperationType = OperationType;
    exports2.OrganizationStatus = OrganizationStatus;
    exports2.PermissionModels = PermissionModels;
    exports2.PolicyAction = PolicyAction;
    exports2.ProvisioningType = ProvisioningType;
    exports2.PublishTypeCommand = PublishTypeCommand;
    exports2.PublisherStatus = PublisherStatus;
    exports2.RecordHandlerProgressCommand = RecordHandlerProgressCommand;
    exports2.RegionConcurrencyType = RegionConcurrencyType;
    exports2.RegisterPublisherCommand = RegisterPublisherCommand;
    exports2.RegisterTypeCommand = RegisterTypeCommand;
    exports2.RegistrationStatus = RegistrationStatus;
    exports2.RegistryType = RegistryType;
    exports2.Replacement = Replacement;
    exports2.RequiresRecreation = RequiresRecreation;
    exports2.ResourceAttribute = ResourceAttribute;
    exports2.ResourceScanStatus = ResourceScanStatus;
    exports2.ResourceSignalStatus = ResourceSignalStatus;
    exports2.ResourceStatus = ResourceStatus2;
    exports2.RollbackStackCommand = RollbackStackCommand2;
    exports2.ScanType = ScanType;
    exports2.SetStackPolicyCommand = SetStackPolicyCommand;
    exports2.SetTypeConfigurationCommand = SetTypeConfigurationCommand;
    exports2.SetTypeDefaultVersionCommand = SetTypeDefaultVersionCommand;
    exports2.SignalResourceCommand = SignalResourceCommand;
    exports2.StackDriftDetectionStatus = StackDriftDetectionStatus;
    exports2.StackDriftStatus = StackDriftStatus;
    exports2.StackInstanceDetailedStatus = StackInstanceDetailedStatus;
    exports2.StackInstanceFilterName = StackInstanceFilterName;
    exports2.StackInstanceStatus = StackInstanceStatus;
    exports2.StackRefactorActionEntity = StackRefactorActionEntity;
    exports2.StackRefactorActionType = StackRefactorActionType;
    exports2.StackRefactorDetection = StackRefactorDetection;
    exports2.StackRefactorExecutionStatus = StackRefactorExecutionStatus;
    exports2.StackRefactorStatus = StackRefactorStatus;
    exports2.StackResourceDriftStatus = StackResourceDriftStatus2;
    exports2.StackSetDriftDetectionStatus = StackSetDriftDetectionStatus;
    exports2.StackSetDriftStatus = StackSetDriftStatus;
    exports2.StackSetOperationAction = StackSetOperationAction;
    exports2.StackSetOperationResultStatus = StackSetOperationResultStatus;
    exports2.StackSetOperationStatus = StackSetOperationStatus;
    exports2.StackSetStatus = StackSetStatus;
    exports2.StackStatus = StackStatus2;
    exports2.StartResourceScanCommand = StartResourceScanCommand2;
    exports2.StopStackSetOperationCommand = StopStackSetOperationCommand;
    exports2.TemplateFormat = TemplateFormat;
    exports2.TemplateStage = TemplateStage;
    exports2.TestTypeCommand = TestTypeCommand;
    exports2.ThirdPartyType = ThirdPartyType;
    exports2.TypeTestsStatus = TypeTestsStatus;
    exports2.UpdateGeneratedTemplateCommand = UpdateGeneratedTemplateCommand;
    exports2.UpdateStackCommand = UpdateStackCommand2;
    exports2.UpdateStackInstancesCommand = UpdateStackInstancesCommand;
    exports2.UpdateStackSetCommand = UpdateStackSetCommand;
    exports2.UpdateTerminationProtectionCommand = UpdateTerminationProtectionCommand2;
    exports2.ValidateTemplateCommand = ValidateTemplateCommand;
    exports2.ValidationStatus = ValidationStatus;
    exports2.VersionBump = VersionBump;
    exports2.Visibility = Visibility;
    exports2.WarningType = WarningType;
    exports2.paginateDescribeAccountLimits = paginateDescribeAccountLimits;
    exports2.paginateDescribeChangeSet = paginateDescribeChangeSet;
    exports2.paginateDescribeEvents = paginateDescribeEvents2;
    exports2.paginateDescribeStackEvents = paginateDescribeStackEvents;
    exports2.paginateDescribeStackResourceDrifts = paginateDescribeStackResourceDrifts;
    exports2.paginateDescribeStacks = paginateDescribeStacks;
    exports2.paginateListChangeSets = paginateListChangeSets;
    exports2.paginateListExports = paginateListExports;
    exports2.paginateListGeneratedTemplates = paginateListGeneratedTemplates;
    exports2.paginateListImports = paginateListImports;
    exports2.paginateListResourceScanRelatedResources = paginateListResourceScanRelatedResources;
    exports2.paginateListResourceScanResources = paginateListResourceScanResources;
    exports2.paginateListResourceScans = paginateListResourceScans;
    exports2.paginateListStackInstances = paginateListStackInstances;
    exports2.paginateListStackRefactorActions = paginateListStackRefactorActions;
    exports2.paginateListStackRefactors = paginateListStackRefactors;
    exports2.paginateListStackResources = paginateListStackResources2;
    exports2.paginateListStackSetOperationResults = paginateListStackSetOperationResults;
    exports2.paginateListStackSetOperations = paginateListStackSetOperations;
    exports2.paginateListStackSets = paginateListStackSets;
    exports2.paginateListStacks = paginateListStacks2;
    exports2.paginateListTypeRegistrations = paginateListTypeRegistrations;
    exports2.paginateListTypeVersions = paginateListTypeVersions;
    exports2.paginateListTypes = paginateListTypes;
    exports2.waitForChangeSetCreateComplete = waitForChangeSetCreateComplete;
    exports2.waitForStackCreateComplete = waitForStackCreateComplete;
    exports2.waitForStackDeleteComplete = waitForStackDeleteComplete;
    exports2.waitForStackExists = waitForStackExists;
    exports2.waitForStackImportComplete = waitForStackImportComplete;
    exports2.waitForStackRefactorCreateComplete = waitForStackRefactorCreateComplete;
    exports2.waitForStackRefactorExecuteComplete = waitForStackRefactorExecuteComplete;
    exports2.waitForStackRollbackComplete = waitForStackRollbackComplete;
    exports2.waitForStackUpdateComplete = waitForStackUpdateComplete;
    exports2.waitForTypeRegistrationComplete = waitForTypeRegistrationComplete;
    exports2.waitUntilChangeSetCreateComplete = waitUntilChangeSetCreateComplete;
    exports2.waitUntilStackCreateComplete = waitUntilStackCreateComplete;
    exports2.waitUntilStackDeleteComplete = waitUntilStackDeleteComplete;
    exports2.waitUntilStackExists = waitUntilStackExists;
    exports2.waitUntilStackImportComplete = waitUntilStackImportComplete;
    exports2.waitUntilStackRefactorCreateComplete = waitUntilStackRefactorCreateComplete2;
    exports2.waitUntilStackRefactorExecuteComplete = waitUntilStackRefactorExecuteComplete2;
    exports2.waitUntilStackRollbackComplete = waitUntilStackRollbackComplete;
    exports2.waitUntilStackUpdateComplete = waitUntilStackUpdateComplete;
    exports2.waitUntilTypeRegistrationComplete = waitUntilTypeRegistrationComplete;
    Object.prototype.hasOwnProperty.call(schemas_0, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: schemas_0["__proto__"]
    });
    Object.keys(schemas_0).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = schemas_0[k32];
    });
    Object.prototype.hasOwnProperty.call(errors, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: errors["__proto__"]
    });
    Object.keys(errors).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = errors[k32];
    });
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/resource-metadata/resource-metadata.ts
function resourceMetadata(stack, logicalId) {
  const metadata = stack.metadata;
  if (!metadata) {
    return void 0;
  }
  for (const path47 of Object.keys(metadata)) {
    const entry = metadata[path47].filter((e32) => e32.type === import_cloud_assembly_schema3.ArtifactMetadataEntryType.LOGICAL_ID).find((e32) => e32.data === logicalId);
    if (entry) {
      return {
        entry,
        constructPath: simplifyConstructPath(path47, stack.stackName)
      };
    }
  }
  return void 0;
}
function simplifyConstructPath(path47, stackName) {
  path47 = path47.replace(/\/Resource$/, "");
  path47 = path47.replace(/^\//, "");
  if (stackName) {
    if (path47.startsWith(stackName + "/")) {
      path47 = path47.slice(stackName.length + 1);
    }
  }
  return path47;
}
var import_cloud_assembly_schema3;
var init_resource_metadata = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/resource-metadata/resource-metadata.ts"() {
    "use strict";
    import_cloud_assembly_schema3 = __toESM(require_lib2());
    __name(resourceMetadata, "resourceMetadata");
    __name(simplifyConstructPath, "simplifyConstructPath");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/resource-metadata/index.ts
var init_resource_metadata2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/resource-metadata/index.ts"() {
    "use strict";
    init_resource_metadata();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/cloudformation/evaluate-cloudformation-template.ts
function iamArnFmt(parts) {
  return `arn:${parts.partition}:${parts.service}::${parts.account}:${parts.resourceType}/${parts.resourceName}`;
}
function s3ArnFmt(parts) {
  return `arn:${parts.partition}:${parts.service}:::${parts.resourceName}`;
}
function stdColonResourceArnFmt(parts) {
  return `arn:${parts.partition}:${parts.service}:${parts.region}:${parts.account}:${parts.resourceType}:${parts.resourceName}`;
}
function stdSlashResourceArnFmt(parts) {
  return `arn:${parts.partition}:${parts.service}:${parts.region}:${parts.account}:${parts.resourceType}/${parts.resourceName}`;
}
function appsyncGraphQlApiApiIdFmt(parts) {
  return parts.resourceName.split("/")[1];
}
function appsyncGraphQlFunctionIDFmt(parts) {
  return parts.resourceName.split("/")[3];
}
function appsyncGraphQlDataSourceNameFmt(parts) {
  return parts.resourceName.split("/")[3];
}
async function asyncGlobalReplace(str, regex, cb) {
  if (!regex.global) {
    throw new ToolkitError("RegexMissingGlobalFlag", "Regex must be created with /g flag");
  }
  const ret = new Array();
  let start = 0;
  while (true) {
    const match = regex.exec(str);
    if (!match) {
      break;
    }
    ret.push(str.substring(start, match.index));
    ret.push(await cb(match[1]));
    start = regex.lastIndex;
  }
  ret.push(str.slice(start));
  return ret.join("");
}
var LazyListStackResources, LookupExportError, LazyLookupExport, CfnEvaluationException, EvaluateCloudFormationTemplate, RESOURCE_TYPE_PRIMARY_IDENTIFIERS, RESOURCE_TYPE_SPECIAL_NAMES, RESOURCE_TYPE_ATTRIBUTES_FORMATS;
var init_evaluate_cloudformation_template = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/cloudformation/evaluate-cloudformation-template.ts"() {
    "use strict";
    init_toolkit_error();
    init_resource_metadata2();
    LazyListStackResources = class {
      constructor(sdk, stackName) {
        this.sdk = sdk;
        this.stackName = stackName;
      }
      sdk;
      stackName;
      static {
        __name(this, "LazyListStackResources");
      }
      stackResources;
      async listStackResources() {
        if (this.stackResources === void 0) {
          this.stackResources = this.sdk.cloudFormation().listStackResources({
            StackName: this.stackName
          });
        }
        return this.stackResources;
      }
    };
    LookupExportError = class extends Error {
      static {
        __name(this, "LookupExportError");
      }
    };
    LazyLookupExport = class {
      constructor(sdk) {
        this.sdk = sdk;
      }
      sdk;
      static {
        __name(this, "LazyLookupExport");
      }
      cachedExports = {};
      async lookupExport(name) {
        if (this.cachedExports[name]) {
          return this.cachedExports[name];
        }
        for await (const cfnExport of this.listExports()) {
          if (!cfnExport.Name) {
            continue;
          }
          this.cachedExports[cfnExport.Name] = cfnExport;
          if (cfnExport.Name === name) {
            return cfnExport;
          }
        }
        return void 0;
      }
      // TODO: Paginate
      async *listExports() {
        let nextToken = void 0;
        while (true) {
          const response = await this.sdk.cloudFormation().listExports({ NextToken: nextToken });
          for (const cfnExport of response.Exports ?? []) {
            yield cfnExport;
          }
          if (!response.NextToken) {
            return;
          }
          nextToken = response.NextToken;
        }
      }
    };
    CfnEvaluationException = class extends Error {
      static {
        __name(this, "CfnEvaluationException");
      }
    };
    EvaluateCloudFormationTemplate = class _EvaluateCloudFormationTemplate {
      static {
        __name(this, "EvaluateCloudFormationTemplate");
      }
      stackArtifact;
      stackName;
      template;
      context;
      account;
      region;
      partition;
      sdk;
      nestedStacks;
      stackResources;
      lookupExport;
      cachedUrlSuffix;
      _cloudControl;
      constructor(props) {
        this.stackArtifact = props.stackArtifact;
        this.stackName = props.stackName ?? props.stackArtifact.stackName;
        this.template = props.template ?? props.stackArtifact.template;
        this.context = {
          "AWS::AccountId": props.account,
          "AWS::Region": props.region,
          "AWS::Partition": props.partition,
          ...props.parameters
        };
        this.account = props.account;
        this.region = props.region;
        this.partition = props.partition;
        this.sdk = props.sdk;
        this.nestedStacks = props.nestedStacks ?? {};
        this.stackResources = new LazyListStackResources(this.sdk, this.stackName);
        this.lookupExport = new LazyLookupExport(this.sdk);
      }
      get cloudControl() {
        if (!this._cloudControl) {
          this._cloudControl = this.sdk.cloudControl();
        }
        return this._cloudControl;
      }
      // clones current EvaluateCloudFormationTemplate object, but updates the stack name
      async createNestedEvaluateCloudFormationTemplate(stackName, nestedTemplate, nestedStackParameters) {
        const evaluatedParams = await this.evaluateCfnExpression(nestedStackParameters);
        return new _EvaluateCloudFormationTemplate({
          stackArtifact: this.stackArtifact,
          stackName,
          template: nestedTemplate,
          parameters: evaluatedParams,
          account: this.account,
          region: this.region,
          partition: this.partition,
          sdk: this.sdk,
          nestedStacks: this.nestedStacks
        });
      }
      async establishResourcePhysicalName(logicalId, physicalNameInCfnTemplate) {
        if (physicalNameInCfnTemplate != null) {
          try {
            return await this.evaluateCfnExpression(physicalNameInCfnTemplate);
          } catch (e32) {
            if (!(e32 instanceof CfnEvaluationException)) {
              throw e32;
            }
          }
        }
        return this.findPhysicalNameFor(logicalId);
      }
      async findPhysicalNameFor(logicalId) {
        const stackResources = await this.stackResources.listStackResources();
        return stackResources.find((sr) => sr.LogicalResourceId === logicalId)?.PhysicalResourceId;
      }
      async findLogicalIdForPhysicalName(physicalName) {
        const stackResources = await this.stackResources.listStackResources();
        return stackResources.find((sr) => sr.PhysicalResourceId === physicalName)?.LogicalResourceId;
      }
      findReferencesTo(logicalId) {
        const ret = new Array();
        for (const [resourceLogicalId, resourceDef] of Object.entries(this.template?.Resources ?? {})) {
          if (logicalId !== resourceLogicalId && this.references(logicalId, resourceDef)) {
            ret.push({
              ...resourceDef,
              LogicalId: resourceLogicalId
            });
          }
        }
        return ret;
      }
      async evaluateCfnExpression(cfnExpression) {
        const self2 = this;
        class CfnIntrinsics {
          static {
            __name(this, "CfnIntrinsics");
          }
          evaluateIntrinsic(intrinsic) {
            const intrinsicFunc = this[intrinsic.name];
            if (!intrinsicFunc) {
              throw new CfnEvaluationException(`CloudFormation function ${intrinsic.name} is not supported`);
            }
            const argsAsArray = Array.isArray(intrinsic.args) ? intrinsic.args : [intrinsic.args];
            return intrinsicFunc.apply(this, argsAsArray);
          }
          async "Fn::Join"(separator, args) {
            const evaluatedArgs = await self2.evaluateCfnExpression(args);
            return evaluatedArgs.join(separator);
          }
          async "Fn::Split"(separator, args) {
            const evaluatedArgs = await self2.evaluateCfnExpression(args);
            return evaluatedArgs.split(separator);
          }
          async "Fn::Select"(index, args) {
            const evaluatedArgs = await self2.evaluateCfnExpression(args);
            return evaluatedArgs[index];
          }
          async Ref(logicalId) {
            const refTarget = await self2.findRefTarget(logicalId);
            if (refTarget) {
              return refTarget;
            } else {
              throw new CfnEvaluationException(`Parameter or resource '${logicalId}' could not be found for evaluation`);
            }
          }
          async "Fn::GetAtt"(logicalId, attributeName) {
            const attrValue = await self2.findGetAttTarget(logicalId, attributeName);
            if (attrValue) {
              return attrValue;
            } else {
              throw new CfnEvaluationException(
                `Attribute '${attributeName}' of resource '${logicalId}' could not be found for evaluation`
              );
            }
          }
          async "Fn::Sub"(template, explicitPlaceholders) {
            const placeholders = explicitPlaceholders ? await self2.evaluateCfnExpression(explicitPlaceholders) : {};
            return asyncGlobalReplace(template, /\${([^}]*)}/g, (key) => {
              if (key in placeholders) {
                return placeholders[key];
              } else {
                const splitKey = key.split(".");
                return splitKey.length === 1 ? this.Ref(key) : this["Fn::GetAtt"](splitKey[0], splitKey.slice(1).join("."));
              }
            });
          }
          async "Fn::ImportValue"(name) {
            const exported = await self2.lookupExport.lookupExport(name);
            if (!exported) {
              throw new CfnEvaluationException(`Export '${name}' could not be found for evaluation`);
            }
            if (!exported.Value) {
              throw new CfnEvaluationException(`Export '${name}' exists without a value`);
            }
            return exported.Value;
          }
        }
        if (cfnExpression == null) {
          return cfnExpression;
        }
        if (Array.isArray(cfnExpression)) {
          return Promise.all(cfnExpression.map((expr) => this.evaluateCfnExpression(expr)));
        }
        if (typeof cfnExpression === "object") {
          const intrinsic = this.parseIntrinsic(cfnExpression);
          if (intrinsic) {
            return new CfnIntrinsics().evaluateIntrinsic(intrinsic);
          } else {
            const ret = {};
            for (const [key, val] of Object.entries(cfnExpression)) {
              ret[key] = await this.evaluateCfnExpression(val);
            }
            return ret;
          }
        }
        return cfnExpression;
      }
      /**
       * Best-effort attempt to construct the Cloud Control API primary identifier for a resource.
       *
       * Cloud Control compound identifiers are pipe-delimited, ordered by the `primaryIdentifier`
       * array in the resource type schema (e.g. `DatabaseName|TableName` for `AWS::Glue::Table`).
       *
       * CloudFormation's `PhysicalResourceId` (the `physicalId` parameter here) is the `Ref` return
       * value for the resource, which is resource-type-specific and may not correspond to the Cloud
       * Control Primary Identifier.
       *
       * For properties present in the template, we resolve them directly. For properties NOT in the
       * template (e.g. service-generated read-only values), we fall back to `physicalId`. This is
       * only correct when:
       *
       * - Exactly one property in the identifier is missing from the template, AND
       * - That property happens to be the one that `Ref` returns for this resource type.
       *
       * If multiple properties are missing, `physicalId` is reused for all of them.
       */
      async evaluateCloudControlIdentifier(logicalId, resourceType, physicalId) {
        if (resourceType in RESOURCE_TYPE_PRIMARY_IDENTIFIERS) {
          const primaryProps = RESOURCE_TYPE_PRIMARY_IDENTIFIERS[resourceType];
          const parts = [];
          for (const propName of primaryProps) {
            const templateVal = this.getResourceProperty(logicalId, propName);
            if (templateVal) {
              parts.push(await this.evaluateCfnExpression(templateVal));
            } else {
              parts.push(physicalId);
            }
          }
          return parts.join("|");
        }
        return physicalId;
      }
      getResourceProperty(logicalId, propertyName) {
        return this.template.Resources?.[logicalId]?.Properties?.[propertyName];
      }
      metadataFor(logicalId) {
        return resourceMetadata(this.stackArtifact, logicalId);
      }
      references(logicalId, templateElement) {
        if (typeof templateElement === "string") {
          return logicalId === templateElement;
        }
        if (templateElement == null) {
          return false;
        }
        if (Array.isArray(templateElement)) {
          return templateElement.some((el) => this.references(logicalId, el));
        }
        if (typeof templateElement === "object") {
          return Object.values(templateElement).some((el) => this.references(logicalId, el));
        }
        return false;
      }
      parseIntrinsic(x) {
        const keys = Object.keys(x);
        if (keys.length === 1 && (keys[0].startsWith("Fn::") || keys[0] === "Ref")) {
          return {
            name: keys[0],
            args: x[keys[0]]
          };
        }
        return void 0;
      }
      async findRefTarget(logicalId) {
        if (logicalId === "AWS::URLSuffix") {
          if (!this.cachedUrlSuffix) {
            this.cachedUrlSuffix = await this.sdk.getUrlSuffix(this.region);
          }
          return this.cachedUrlSuffix;
        }
        const parameterTarget = this.context[logicalId];
        if (parameterTarget) {
          return parameterTarget;
        }
        const defaultParameterValue = this.template.Parameters?.[logicalId]?.Default;
        if (defaultParameterValue) {
          return defaultParameterValue;
        }
        return this.findGetAttTarget(logicalId);
      }
      async findGetAttTarget(logicalId, attribute) {
        if (logicalId === "Outputs" && attribute) {
          return this.evaluateCfnExpression(this.template.Outputs[attribute]?.Value);
        }
        const stackResources = await this.stackResources.listStackResources();
        const foundResource = stackResources.find((sr) => sr.LogicalResourceId === logicalId);
        if (!foundResource) {
          return void 0;
        }
        if (foundResource.ResourceType == "AWS::CloudFormation::Stack" && attribute?.startsWith("Outputs.")) {
          const dependantStack = this.findNestedStack(logicalId, this.nestedStacks);
          if (!dependantStack || !dependantStack.physicalName) {
            return void 0;
          }
          const evaluateCfnTemplate = await this.createNestedEvaluateCloudFormationTemplate(
            dependantStack.physicalName,
            dependantStack.generatedTemplate,
            dependantStack.generatedTemplate.Parameters
          );
          return evaluateCfnTemplate.evaluateCfnExpression({
            "Fn::GetAtt": attribute.split(/\.(.*)/s)
          });
        }
        return this.formatResourceAttribute(foundResource, attribute);
      }
      findNestedStack(logicalId, nestedStacks) {
        for (const nestedStackLogicalId of Object.keys(nestedStacks)) {
          if (nestedStackLogicalId === logicalId) {
            return nestedStacks[nestedStackLogicalId];
          }
          const checkInNestedChildStacks = this.findNestedStack(
            logicalId,
            nestedStacks[nestedStackLogicalId].nestedStackTemplates
          );
          if (checkInNestedChildStacks) return checkInNestedChildStacks;
        }
        return void 0;
      }
      async formatResourceAttribute(resource, attribute) {
        const physicalId = resource.PhysicalResourceId;
        if (!attribute) {
          return physicalId;
        }
        const resourceTypeFormats = RESOURCE_TYPE_ATTRIBUTES_FORMATS[resource.ResourceType];
        if (resourceTypeFormats) {
          const attributeFormatFunc = resourceTypeFormats[attribute];
          if (attributeFormatFunc) {
            const service = this.getServiceOfResource(resource);
            const resourceTypeArnPart = this.getResourceTypeArnPartOfResource(resource);
            return attributeFormatFunc({
              partition: this.partition,
              service,
              region: this.region,
              account: this.account,
              resourceType: resourceTypeArnPart,
              resourceName: physicalId
            });
          }
        }
        try {
          const identifier = await this.evaluateCloudControlIdentifier(resource.LogicalResourceId, resource.ResourceType, physicalId);
          const response = await this.cloudControl.getResource({
            TypeName: resource.ResourceType,
            Identifier: identifier
          });
          const props = JSON.parse(response.ResourceDescription?.Properties ?? "{}");
          if (attribute in props) {
            return props[attribute];
          }
        } catch (error4) {
          throw new CfnEvaluationException(`Could not find '${attribute}' attribute of the '${resource.ResourceType}' resource becausean error occured while attempting to retrieve the information: '${error4.name}:${error4.message}'`);
        }
        throw new CfnEvaluationException(
          `We don't support the '${attribute}' attribute of the '${resource.ResourceType}' resource. This is a CDK limitation. Please report it at https://github.com/aws/aws-cdk/issues/new/choose`
        );
      }
      getServiceOfResource(resource) {
        return resource.ResourceType.split("::")[1].toLowerCase();
      }
      getResourceTypeArnPartOfResource(resource) {
        const resourceType = resource.ResourceType;
        const specialCaseResourceType = RESOURCE_TYPE_SPECIAL_NAMES[resourceType]?.resourceType;
        return specialCaseResourceType ? specialCaseResourceType : (
          // this is the default case
          resourceType.split("::")[2].toLowerCase()
        );
      }
    };
    RESOURCE_TYPE_PRIMARY_IDENTIFIERS = {
      "AWS::ApiGateway::Authorizer": ["RestApiId", "AuthorizerId"],
      "AWS::ApiGateway::Deployment": ["DeploymentId", "RestApiId"],
      "AWS::ApiGateway::Model": ["RestApiId", "Name"],
      "AWS::ApiGateway::RequestValidator": ["RestApiId", "RequestValidatorId"],
      "AWS::ApiGateway::DocumentationPart": ["DocumentationPartId", "RestApiId"],
      "AWS::ApiGateway::Resource": ["RestApiId", "ResourceId"],
      "AWS::ApiGateway::Stage": ["RestApiId", "StageName"],
      "AWS::ApiGatewayV2::ApiMapping": ["ApiMappingId", "DomainName"],
      "AWS::ApiGatewayV2::Authorizer": ["AuthorizerId", "ApiId"],
      "AWS::ApiGatewayV2::Deployment": ["ApiId", "DeploymentId"],
      "AWS::ApiGatewayV2::Integration": ["ApiId", "IntegrationId"],
      "AWS::ApiGatewayV2::IntegrationResponse": ["ApiId", "IntegrationId", "IntegrationResponseId"],
      "AWS::ApiGatewayV2::Model": ["ApiId", "ModelId"],
      "AWS::ApiGatewayV2::Route": ["ApiId", "RouteId"],
      "AWS::ApiGatewayV2::RouteResponse": ["ApiId", "RouteId", "RouteResponseId"],
      "AWS::ApiGatewayV2::Stage": ["Id"],
      "AWS::AppConfig::ConfigurationProfile": ["ApplicationId", "ConfigurationProfileId"],
      "AWS::AppConfig::Environment": ["ApplicationId", "EnvironmentId"],
      "AWS::AppConfig::HostedConfigurationVersion": ["ApplicationId", "ConfigurationProfileId", "VersionNumber"],
      "AWS::AppMesh::GatewayRoute": ["Id"],
      "AWS::AppMesh::Mesh": ["Id"],
      "AWS::AppMesh::Route": ["Id"],
      "AWS::AppMesh::VirtualGateway": ["Id"],
      "AWS::AppMesh::VirtualNode": ["Id"],
      "AWS::AppMesh::VirtualRouter": ["Id"],
      "AWS::AppMesh::VirtualService": ["Id"],
      "AWS::AppSync::ApiKey": ["ApiKeyId"],
      "AWS::AppSync::GraphQLApi": ["ApiId"],
      "AWS::Batch::JobDefinition": ["JobDefinitionName"],
      "AWS::CloudWatch::InsightRule": ["Id"],
      "AWS::CodeBuild::Project": ["Id"],
      "AWS::CodeBuild::ReportGroup": ["Id"],
      "AWS::CodeDeploy::DeploymentGroup": ["ApplicationName", "DeploymentGroupName"],
      "AWS::CodePipeline::Webhook": ["Id"],
      "AWS::Cognito::UserPoolClient": ["UserPoolId", "ClientId"],
      "AWS::Cognito::UserPoolDomain": ["UserPoolId", "Domain"],
      "AWS::Cognito::UserPoolGroup": ["UserPoolId", "GroupName"],
      "AWS::Cognito::UserPoolIdentityProvider": ["UserPoolId", "ProviderName"],
      "AWS::Cognito::UserPoolResourceServer": ["UserPoolId", "Identifier"],
      "AWS::Cognito::UserPoolUser": ["UserPoolId", "Username"],
      "AWS::DAX::Cluster": ["Id"],
      "AWS::DAX::ParameterGroup": ["Id"],
      "AWS::DAX::SubnetGroup": ["Id"],
      "AWS::DMS::EventSubscription": ["Id"],
      "AWS::EC2::EIP": ["PublicIp", "AllocationId"],
      "AWS::ECS::Service": ["ServiceArn", "Cluster"],
      "AWS::ElastiCache::CacheCluster": ["Id"],
      "AWS::ElasticLoadBalancing::LoadBalancer": ["Id"],
      "AWS::ElastiCache::User": ["UserId"],
      "AWS::Elasticsearch::Domain": ["Id"],
      "AWS::Events::Rule": ["Arn"],
      "AWS::EventSchemas::RegistryPolicy": ["Id"],
      "AWS::Glue::DevEndpoint": ["Id"],
      "AWS::Glue::Workflow": ["Id"],
      "AWS::IoT::Policy": ["Id"],
      "AWS::Logs::LogStream": ["LogGroupName", "LogStreamName"],
      "AWS::Logs::SubscriptionFilter": ["FilterName", "LogGroupName"],
      "AWS::MediaConvert::JobTemplate": ["Id"],
      "AWS::MediaConvert::Preset": ["Id"],
      "AWS::MediaConvert::Queue": ["Id"],
      "AWS::Route53::RecordSet": ["Id"],
      "AWS::SageMaker::Device": ["Device/DeviceName"],
      "AWS::SecretsManager::ResourcePolicy": ["Id"],
      "AWS::SecretsManager::SecretTargetAttachment": ["Id"],
      "AWS::SES::ReceiptRuleSet": ["Id"],
      "AWS::SSM::MaintenanceWindowTarget": ["WindowId", "WindowTargetId"],
      "AWS::SSM::MaintenanceWindowTask": ["WindowId", "WindowTaskId"]
    };
    RESOURCE_TYPE_SPECIAL_NAMES = {
      "AWS::Events::EventBus": {
        resourceType: "event-bus"
      }
    };
    RESOURCE_TYPE_ATTRIBUTES_FORMATS = {
      "AWS::IAM::Role": { Arn: iamArnFmt },
      "AWS::IAM::User": { Arn: iamArnFmt },
      "AWS::IAM::Group": { Arn: iamArnFmt },
      "AWS::S3::Bucket": { Arn: s3ArnFmt },
      "AWS::Lambda::Function": { Arn: stdColonResourceArnFmt },
      "AWS::Events::EventBus": {
        Arn: stdSlashResourceArnFmt,
        // the name attribute of the EventBus is the same as the Ref
        Name: /* @__PURE__ */ __name((parts) => parts.resourceName, "Name")
      },
      "AWS::DynamoDB::Table": { Arn: stdSlashResourceArnFmt },
      "AWS::AppSync::GraphQLApi": { ApiId: appsyncGraphQlApiApiIdFmt },
      "AWS::AppSync::FunctionConfiguration": {
        FunctionId: appsyncGraphQlFunctionIDFmt
      },
      "AWS::AppSync::DataSource": { Name: appsyncGraphQlDataSourceNameFmt },
      "AWS::KMS::Key": { Arn: stdSlashResourceArnFmt }
    };
    __name(iamArnFmt, "iamArnFmt");
    __name(s3ArnFmt, "s3ArnFmt");
    __name(stdColonResourceArnFmt, "stdColonResourceArnFmt");
    __name(stdSlashResourceArnFmt, "stdSlashResourceArnFmt");
    __name(appsyncGraphQlApiApiIdFmt, "appsyncGraphQlApiApiIdFmt");
    __name(appsyncGraphQlFunctionIDFmt, "appsyncGraphQlFunctionIDFmt");
    __name(appsyncGraphQlDataSourceNameFmt, "appsyncGraphQlDataSourceNameFmt");
    __name(asyncGlobalReplace, "asyncGlobalReplace");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/cloudformation/template-body-parameter.ts
async function makeBodyParameter(ioHelper, stack, resolvedEnvironment, assetManifest, resources, overrideTemplate) {
  if (stack.stackTemplateAssetObjectUrl && !overrideTemplate) {
    return {
      TemplateURL: await restUrlFromManifest(stack.stackTemplateAssetObjectUrl, resolvedEnvironment)
    };
  }
  const templateJson = toYAML(overrideTemplate ?? stack.template);
  if (templateJson.length <= LARGE_TEMPLATE_SIZE_KB * 1024) {
    return { TemplateBody: templateJson };
  }
  const toolkitInfo = await resources.lookupToolkit();
  if (!toolkitInfo.found) {
    await ioHelper.defaults.error(
      util3.format(
        `The template for stack "${stack.displayName}" is ${Math.round(templateJson.length / 1024)}KiB. Templates larger than ${LARGE_TEMPLATE_SIZE_KB}KiB must be uploaded to S3.
Run the following command in order to setup an S3 bucket in this environment, and then re-deploy:

`,
        chalk.blue(`	$ cdk bootstrap ${resolvedEnvironment.name}
`)
      )
    );
    throw new ToolkitError("TemplateTooLargeToDeploy", 'Template too large to deploy ("cdk bootstrap" is required)');
  }
  const templateHash = contentHash(templateJson);
  const key = `cdk/${stack.id}/${templateHash}.yml`;
  let templateFile = stack.templateFile;
  if (overrideTemplate) {
    templateFile = `${stack.templateFile}-${templateHash}.yaml`;
    const templateFilePath = path14.join(stack.assembly.directory, templateFile);
    await fs14.writeFile(templateFilePath, templateJson, { encoding: "utf-8" });
  }
  assetManifest.addFileAsset(
    templateHash,
    {
      path: templateFile
    },
    {
      bucketName: toolkitInfo.bucketName,
      objectKey: key
    }
  );
  const templateURL = `${toolkitInfo.bucketUrl}/${key}`;
  await ioHelper.defaults.debug(`Storing template in S3 at: ${templateURL}`);
  return { TemplateURL: templateURL };
}
async function restUrlFromManifest(url, environment) {
  const doNotUseMarker = "**DONOTUSE**";
  const region = environment.region;
  url = import_cloud_assembly_api3.EnvironmentPlaceholders.replace(url, {
    accountId: environment.account,
    region,
    partition: doNotUseMarker
  });
  if (url.indexOf(doNotUseMarker) > -1) {
    throw new ToolkitError("PartitionPlaceholderNotSupported", "Cannot use '${AWS::Partition}' in the 'stackTemplateAssetObjectUrl' field");
  }
  const s3Url = url.match(/s3:\/\/([^/]+)\/(.*)$/);
  if (!s3Url) {
    return url;
  }
  const bucketName = s3Url[1];
  const objectKey = s3Url[2];
  const originalOverrideS3Endpoint = process.env.AWS_ENDPOINT_URL_S3;
  setEnv("AWS_ENDPOINT_URL_S3", process.env.AWS_ENDPOINT_URL_S3_FOR_CLOUDFORMATION);
  try {
    const s3 = new import_client_s32.S3Client({ region });
    const endpoint = await (0, import_middleware_endpoint48.getEndpointFromInstructions)({}, import_client_s32.HeadObjectCommand, {
      ...s3.config
    });
    return `${endpoint.url.origin}/${bucketName}/${objectKey}`;
  } finally {
    setEnv("AWS_ENDPOINT_URL_S3", originalOverrideS3Endpoint);
  }
}
function setEnv(name, value) {
  if (value) {
    process.env[name] = value;
  } else {
    delete process.env[name];
  }
}
var fs14, path14, util3, import_cloud_assembly_api3, import_client_s32, import_middleware_endpoint48, chalk, LARGE_TEMPLATE_SIZE_KB;
var init_template_body_parameter = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/cloudformation/template-body-parameter.ts"() {
    "use strict";
    fs14 = __toESM(require("node:fs/promises"));
    path14 = __toESM(require("node:path"));
    util3 = __toESM(require("node:util"));
    import_cloud_assembly_api3 = __toESM(require_lib3());
    import_client_s32 = __toESM(require_dist_cjs90());
    import_middleware_endpoint48 = __toESM(require_dist_cjs31());
    chalk = __toESM(require_source());
    init_toolkit_error();
    init_util3();
    LARGE_TEMPLATE_SIZE_KB = 50;
    __name(makeBodyParameter, "makeBodyParameter");
    __name(restUrlFromManifest, "restUrlFromManifest");
    __name(setEnv, "setEnv");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/stack-events/resource-errors.ts
function errorFromEvent(ev) {
  return {
    logicalId: ev.event.LogicalResourceId ?? "",
    message: ev.event.ResourceStatusReason ?? "",
    parentStackLogicalIds: ev.parentStackLogicalIds,
    resourceType: ev.event.ResourceType ?? "",
    stackArn: ev.event.StackId ?? "",
    errorCode: extractErrorCode(ev.event),
    physicalId: ev.event.PhysicalResourceId
  };
}
function extractErrorCode(event) {
  const isOurCustomResource = OUR_CUSTOM_RESOURCE_TYPES.includes(event.ResourceType ?? "");
  const resourceTypeParts = (event.ResourceType ?? "").split("::");
  if (resourceTypeParts[0] !== "AWS" && !isOurCustomResource) {
    return DeploymentErrorCodes.PRIVATE_RESOURCE_ERROR;
  }
  const resourceType = isOurCustomResource ? resourceTypeParts.join("") : resourceTypeParts.slice(1).join("");
  const reason = event.ResourceStatusReason ?? "";
  const errorRe = /(?:HandlerErrorCode:|Error Code:) ([a-zA-Z0-9:-]+)/;
  const handlerCode = reason.match(errorRe);
  return `${resourceType}:${handlerCode ? handlerCode[1] : DeploymentErrorCodes.UNKNOWN_ERROR}`;
}
var ResourceErrors, OUR_CUSTOM_RESOURCE_TYPES;
var init_resource_errors = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/stack-events/resource-errors.ts"() {
    "use strict";
    init_toolkit_error();
    init_cloudformation();
    ResourceErrors = class {
      static {
        __name(this, "ResourceErrors");
      }
      /**
       * A list of all non-cancellation errors we have seen.
       *
       * By the nature of the order we see events in, will be ordered from oldest to newest.
       */
      _errors = [];
      isEmpty() {
        return this._errors.length === 0;
      }
      get all() {
        return this._errors;
      }
      /**
       * Update the error collection with the given stack activity
       *
       * May be from a nested stack as well.
       *
       * This class expects to see all events in chronological order.
       */
      update(...events) {
        for (const event of events) {
          if (isErrorEvent(event.event)) {
            if (!isCancellationEvent(event.event) && isRegularResourceEvent(event.event)) {
              this._errors.push(errorFromEvent(event));
            }
          }
        }
      }
      /**
       * Take our best guess at the error code of the root cause
       *
       * The first error that occurs is the root cause.
       */
      get rootCauseErrorCode() {
        return this.allErrorCodes[0];
      }
      /**
       * Return error messages of all encountered errors (that aren't cancellations)
       */
      get allErrorMessages() {
        return this._errors.map((e32) => e32.message);
      }
      /**
       * Return error codeds of all encountered errors (that aren't cancellations nor stack errors)
       *
       * We don't need to include nested stack errors because our poller will poll the nested stack,
       * and have returned the actual error as well.
       */
      get allErrorCodes() {
        return this._errors.map((e32) => e32.errorCode).filter((x) => typeof x === "string");
      }
    };
    __name(errorFromEvent, "errorFromEvent");
    __name(extractErrorCode, "extractErrorCode");
    OUR_CUSTOM_RESOURCE_TYPES = [
      "Custom::AWS",
      "Custom::AWSCDK-EKS-Cluster",
      "Custom::AWSCDK-EKS-FargateProfile",
      "Custom::AWSCDK-EKS-HelmChart",
      "Custom::AWSCDK-EKS-KubernetesObjectValue",
      "Custom::AWSCDK-EKS-KubernetesPatch",
      "Custom::AWSCDK-EKS-KubernetesResource",
      "Custom::AWSCDKCfnJson",
      "Custom::AWSCDKCfnJsonStringify",
      "Custom::AWSCDKOpenIdConnectProvider",
      "Custom::CDKBucketDeployment",
      "Custom::CloudwatchLogResourcePolicy",
      "Custom::CrossAccountZoneDelegation",
      "Custom::CrossRegionExportReader",
      "Custom::CrossRegionExportWriter",
      "Custom::CrossRegionStringParameterReader",
      "Custom::DeleteExistingRecordSet",
      "Custom::DescribeCognitoUserPoolClient",
      "Custom::DynamoDBReplica",
      "Custom::ECRAutoDeleteImages",
      "Custom::ElasticsearchAccessPolicy",
      "Custom::LogRetention",
      "Custom::OpenSearchAccessPolicy",
      "Custom::S3AutoDeleteObjects",
      "Custom::S3BucketNotifications",
      "Custom::SyntheticsAutoDeleteUnderlyingResources",
      "Custom::Trigger",
      "Custom::UserPoolCloudFrontDomainName",
      "Custom::VpcRestrictDefaultSG"
    ];
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/stack-events/stack-event-poller.ts
function isStackBeginOperationState(state13) {
  return [
    "CREATE_IN_PROGRESS",
    "UPDATE_IN_PROGRESS",
    "DELETE_IN_PROGRESS",
    "UPDATE_ROLLBACK_IN_PROGRESS",
    "ROLLBACK_IN_PROGRESS"
  ].includes(state13 ?? "");
}
function isStackTerminalState(state13) {
  return !(state13 ?? "").endsWith("_IN_PROGRESS");
}
var import_client_cloudformation, PollRange, StackEventPoller;
var init_stack_event_poller = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/stack-events/stack-event-poller.ts"() {
    "use strict";
    import_client_cloudformation = __toESM(require_dist_cjs140());
    init_resource_errors();
    init_util3();
    PollRange = class {
      static {
        __name(this, "PollRange");
      }
      /**
       * Only include events since than a given time
       */
      static sinceTimestamp(startTime) {
        return {
          shouldStop(event) {
            return event.event.Timestamp.valueOf() < startTime ? "stop-exclude" : "continue";
          }
        };
      }
      /**
       * Stop when we see the root stack entering this status
       *
       * Should be something like `CREATE_IN_PROGRESS`, `UPDATE_IN_PROGRESS`,
       * `DELETE_IN_PROGRESS, `ROLLBACK_IN_PROGRESS`.
       */
      static sinceStackStatus(statuses) {
        return {
          shouldStop(event) {
            return event.isRootStackEvent && statuses.includes(event.event.ResourceStatus ?? "") ? "stop-include" : "continue";
          }
        };
      }
      /**
       * Stop when we see events that belong to a different operation
       *
       * Records the first OperationId, and stops as soon as we see events that don't have it anymore.
       */
      static mostRecentOperation() {
        let operationId;
        return {
          shouldStop(event) {
            if (operationId === void 0) {
              operationId = event.event.OperationId;
              return "continue";
            }
            return event.event.OperationId === operationId ? "continue" : "stop-exclude";
          }
        };
      }
      /**
       * A poll range decider that always returns 'continue', consuming the entire CFN event stream.
       */
      static consumeAll() {
        return {
          shouldStop() {
            return "continue";
          }
        };
      }
    };
    StackEventPoller = class _StackEventPoller {
      constructor(cfn, props) {
        this.cfn = cfn;
        this.props = props;
      }
      cfn;
      props;
      static {
        __name(this, "StackEventPoller");
      }
      /**
       * All events we've seen so far
       */
      events = [];
      complete = false;
      /**
       * A record of the errors we've seen
       */
      errors = new ResourceErrors();
      /**
       * Resources that received DELETE_FAILED during a stack update.
       * CloudFormation skips these and completes the update anyway.
       */
      deleteFailures = [];
      eventIds = /* @__PURE__ */ new Set();
      nestedStackPollers = {};
      /**
       * From all accumulated events, return only the errors
       */
      get resourceErrors() {
        return this.errors.all;
      }
      /**
       * Poll for new stack events
       *
       * Will read all events that are available up until the oldest events
       * indicated by the constructor filters, or until it encounters events that it
       * has already read before.
       *
       * Recurses into nested stacks, and returns events old-to-new. Multiple
       * invocations to `poll` will return *newer* events (also in old-to-new order).
       */
      async poll() {
        const events = await this.doPoll();
        for (const [logicalId, poller] of Object.entries(this.nestedStackPollers)) {
          events.push(...await poller.poll());
          if (poller.complete) {
            delete this.nestedStackPollers[logicalId];
          }
        }
        events.sort((a32, b32) => a32.event.Timestamp.valueOf() - b32.event.Timestamp.valueOf());
        this.events.push(...events);
        this.errors.update(...events);
        this.updateDeleteFailures(events);
        return events;
      }
      updateDeleteFailures(events) {
        for (const { event } of events) {
          if (event.ResourceStatus === import_client_cloudformation.ResourceStatus.DELETE_FAILED && event.ResourceType !== "AWS::CloudFormation::Stack") {
            this.deleteFailures.push({
              logicalResourceId: event.LogicalResourceId ?? "",
              physicalResourceId: event.PhysicalResourceId,
              resourceType: event.ResourceType ?? "",
              reason: event.ResourceStatusReason ?? ""
            });
          }
        }
      }
      async doPoll() {
        const stopDecider = this.eventIds.size > 0 ? PollRange.consumeAll() : this.props.initialPollRange;
        const events = [];
        try {
          let nextToken;
          let finished = false;
          while (!finished) {
            const page = await this.cfn.describeStackEvents({ StackName: this.props.stackArn, NextToken: nextToken });
            for (const event of page?.StackEvents ?? []) {
              if (this.eventIds.has(event.EventId)) {
                return events;
              }
              const isParentStackEvent = isRootStackEvent(event);
              const resEvent = {
                event,
                parentStackLogicalIds: this.props.parentStackLogicalIds ?? [],
                isRootStackEvent: isParentStackEvent
              };
              const stopDecision = stopDecider.shouldStop(resEvent);
              if (stopDecision === "stop-exclude") {
                return events;
              }
              this.eventIds.add(event.EventId);
              events.push(resEvent);
              if (stopDecision === "stop-include") {
                return events;
              }
              if (!isParentStackEvent && event.ResourceType === "AWS::CloudFormation::Stack" && isStackBeginOperationState(event.ResourceStatus)) {
                this.trackNestedStack(event, [...this.props.parentStackLogicalIds ?? [], event.LogicalResourceId ?? ""]);
              }
              if (isParentStackEvent && isStackTerminalState(event.ResourceStatus)) {
                this.complete = true;
              }
            }
            nextToken = page?.NextToken;
            if (nextToken === void 0) {
              finished = true;
            }
          }
        } catch (e32) {
          if (!(e32.name === "ValidationError" && formatErrorMessage(e32) === `Stack [${this.props.stackArn}] does not exist`)) {
            throw e32;
          }
        }
        return events;
      }
      /**
       * On the CREATE_IN_PROGRESS, UPDATE_IN_PROGRESS, DELETE_IN_PROGRESS event of a nested stack, poll the nested stack updates
       */
      trackNestedStack(event, parentStackLogicalIds) {
        const logicalId = event.LogicalResourceId;
        const physicalResourceId = event.PhysicalResourceId;
        if (!logicalId || !physicalResourceId) {
          return;
        }
        if (!this.nestedStackPollers[logicalId]) {
          this.nestedStackPollers[logicalId] = new _StackEventPoller(this.cfn, {
            stackArn: physicalResourceId,
            parentStackLogicalIds,
            initialPollRange: PollRange.sinceTimestamp(event.Timestamp.valueOf())
          });
        }
      }
    };
    __name(isStackBeginOperationState, "isStackBeginOperationState");
    __name(isStackTerminalState, "isStackTerminalState");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/stack-events/stack-progress-monitor.ts
var util4, StackProgressMonitor;
var init_stack_progress_monitor = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/stack-events/stack-progress-monitor.ts"() {
    "use strict";
    util4 = __toESM(require("util"));
    init_util3();
    StackProgressMonitor = class {
      static {
        __name(this, "StackProgressMonitor");
      }
      /**
       * Previous completion state observed by logical ID
       *
       * We use this to detect that if we see a DELETE_COMPLETE after a
       * CREATE_COMPLETE, it's actually a rollback and we should DECREASE
       * resourcesDone instead of increase it
       */
      resourcesPrevCompleteState = {};
      /**
       * Count of resources that have reported a _COMPLETE status
       */
      resourcesDone = 0;
      /**
       * How many digits we need to represent the total count (for lining up the status reporting)
       */
      resourceDigits = 0;
      /**
       * Number of expected resources in the monitor.
       */
      resourcesTotal;
      constructor(resourcesTotal) {
        this.resourcesTotal = resourcesTotal ? resourcesTotal + 1 : void 0;
        this.resourceDigits = this.resourcesTotal ? Math.ceil(Math.log10(this.resourcesTotal)) : 0;
      }
      /**
       * Report the stack progress
       */
      get progress() {
        return {
          total: this.total,
          completed: this.completed,
          formatted: this.formatted
        };
      }
      /**
       * The total number of progress monitored resources.
       */
      get total() {
        return this.resourcesTotal;
      }
      /**
       * The number of completed resources.
       */
      get completed() {
        return this.resourcesDone;
      }
      /**
       * Report the current progress as a [34/42] string, or just [34] if the total is unknown
       */
      get formatted() {
        if (this.resourcesTotal == null) {
          return padLeft(3, util4.format("%s", this.resourcesDone));
        }
        return util4.format(
          "%s/%s",
          padLeft(this.resourceDigits, this.resourcesDone.toString()),
          padLeft(this.resourceDigits, this.resourcesTotal.toString())
        );
      }
      /**
       * Process as stack event and update the progress state.
       */
      process(resourceEvent) {
        if (resourceEvent.parentStackLogicalIds.length > 0) {
          return;
        }
        const event = resourceEvent.event;
        const status = event.ResourceStatus;
        if (!status || !event.LogicalResourceId) {
          return;
        }
        if (status.endsWith("_COMPLETE_CLEANUP_IN_PROGRESS")) {
          this.resourcesDone++;
        }
        if (status.endsWith("_COMPLETE")) {
          const prevState = this.resourcesPrevCompleteState[event.LogicalResourceId];
          if (!prevState) {
            this.resourcesDone++;
          } else {
            this.resourcesDone--;
            if (this.resourcesDone < 0) {
              this.resourcesDone = 0;
            }
          }
          this.resourcesPrevCompleteState[event.LogicalResourceId] = status;
        }
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/stack-events/stack-activity-monitor.ts
var import_node_crypto4, util5, StackActivityMonitor;
var init_stack_activity_monitor = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/stack-events/stack-activity-monitor.ts"() {
    "use strict";
    import_node_crypto4 = require("node:crypto");
    util5 = __toESM(require("node:util"));
    init_stack_event_poller();
    init_stack_progress_monitor();
    init_cloudformation();
    init_private();
    init_resource_metadata();
    StackActivityMonitor = class {
      static {
        __name(this, "StackActivityMonitor");
      }
      /**
       * The poller used to read stack events
       */
      poller;
      /**
       * Fetch new activity every 1 second
       * Printers can decide to update a view less frequently if desired
       */
      pollingInterval;
      monitorId;
      progressMonitor;
      /**
       * Current tick timer
       */
      tickTimer;
      /**
       * Set to the activity of reading the current events
       */
      readPromise;
      ioHelper;
      stackDisplayName;
      stack;
      cfn;
      envResources;
      isStackUpdate;
      constructor({
        cfn,
        ioHelper,
        stack,
        stackArn,
        resourcesTotal,
        changeSetCreationTime,
        pollingInterval = 2e3,
        envResources,
        isStackUpdate = false
      }) {
        this.ioHelper = ioHelper;
        this.stack = stack;
        this.stackDisplayName = stackNameFromArn(stackArn);
        this.cfn = cfn;
        this.envResources = envResources;
        this.isStackUpdate = isStackUpdate;
        this.progressMonitor = new StackProgressMonitor(resourcesTotal);
        this.pollingInterval = pollingInterval;
        this.poller = new StackEventPoller(cfn, {
          stackArn,
          initialPollRange: PollRange.sinceTimestamp(changeSetCreationTime?.getTime() ?? Date.now())
        });
      }
      /**
       * The resource errors that were discovered during monitoring of this stack
       */
      get errors() {
        return this.poller.errors;
      }
      /**
       * Resources that received DELETE_FAILED during the stack update.
       * CloudFormation skips these and completes the update anyway.
       */
      get deleteFailures() {
        return this.poller.deleteFailures;
      }
      async start() {
        this.monitorId = (0, import_node_crypto4.randomUUID)();
        await this.ioHelper.notify(IO.CDK_TOOLKIT_I5501.msg(`Deploying ${this.stackDisplayName}`, {
          deployment: this.monitorId,
          stack: this.stack,
          stackName: this.stackDisplayName,
          resourcesTotal: this.progressMonitor.total,
          isStackUpdate: this.isStackUpdate
        }));
        this.scheduleNextTick();
        return this;
      }
      async stop() {
        const oldMonitorId = this.monitorId;
        this.monitorId = void 0;
        if (this.tickTimer) {
          clearTimeout(this.tickTimer);
        }
        await this.finalPollToEnd(oldMonitorId);
        await this.ioHelper.notify(IO.CDK_TOOLKIT_I5503.msg(`Completed ${this.stackDisplayName}`, {
          deployment: oldMonitorId,
          stack: this.stack,
          stackName: this.stackDisplayName,
          resourcesTotal: this.progressMonitor.total
        }));
      }
      scheduleNextTick() {
        if (!this.monitorId) {
          return;
        }
        this.tickTimer = setTimeout(() => void this.tick(), this.pollingInterval);
      }
      async tick() {
        if (!this.monitorId) {
          return;
        }
        try {
          this.readPromise = this.readNewEvents(this.monitorId);
          await this.readPromise;
          this.readPromise = void 0;
          if (!this.monitorId) {
            return;
          }
        } catch (e32) {
          await this.ioHelper.notify(IO.CDK_TOOLKIT_E5500.msg(
            util5.format("Error occurred while monitoring stack: %s", e32),
            { error: e32 }
          ));
        }
        this.scheduleNextTick();
      }
      findMetadataFor(logicalId) {
        const metadata = this.stack.metadata;
        if (!logicalId || !metadata) {
          return void 0;
        }
        return resourceMetadata(this.stack, logicalId);
      }
      /**
       * Trims leading/trailing whitespace, collapses all internal whitespace
       * (including newlines) to a single space, and truncates to `maxChars`
       * characters, appending `[...truncated]` when the original was longer.
       */
      normalizeMessage(message2, maxChars = 400) {
        const normalized = message2.trim().replace(/\s+/g, " ");
        return normalized.length > maxChars ? normalized.substring(0, maxChars) + "[...truncated]" : normalized;
      }
      /**
       * Fetches Guard Hook annotation details via GetHookResult API and formats them
       * into a human-readable string. Returns undefined if the fetch fails or there
       * are no failed annotations.
       */
      async fetchGuardHookAnnotations(hookInvocationId) {
        try {
          const result2 = await this.cfn.getHookResult({ HookResultId: hookInvocationId });
          const annotations = result2.Annotations ?? [];
          const failedAnnotations = annotations.filter((a32) => a32.Status === "FAILED");
          if (failedAnnotations.length === 0) {
            return void 0;
          }
          const lines = ["NonCompliant Rules:", ""];
          for (const annotation of failedAnnotations) {
            if (annotation.AnnotationName) {
              lines.push(`[${annotation.AnnotationName}]`);
            }
            if (annotation.StatusMessage) {
              lines.push(`\u2022 ${this.normalizeMessage(annotation.StatusMessage)}`);
            }
            if (annotation.RemediationMessage) {
              lines.push(`Remediation: ${this.normalizeMessage(annotation.RemediationMessage)}`);
            }
            lines.push("");
          }
          return lines.join("\n").trimEnd();
        } catch (e32) {
          const errorMessage = e32 instanceof Error ? e32.message : String(e32);
          const isPermissionsError = e32.name === "AccessDeniedException" || typeof errorMessage === "string" && errorMessage.toLowerCase().includes("not authorized to perform: cloudformation:gethookresult");
          if (isPermissionsError && this.envResources) {
            let currentVersion = void 0;
            try {
              currentVersion = (await this.envResources.lookupToolkit()).version;
            } catch {
            }
            await this.ioHelper.defaults.warn(
              util5.format(
                `Failed to fetch result details for Hook invocation ${hookInvocationId}: ${errorMessage}. Make sure you have permissions to call the GetHookResult API, or re-bootstrap your environment by running 'cdk bootstrap' to update the Bootstrap CDK Toolkit stack.
            'Bootstrap toolkit stack version 31 or later is needed; current version: ${currentVersion ?? "unknown"}.`
              )
            );
          } else {
            await this.ioHelper.defaults.warn(
              util5.format("Failed to fetch Guard Hook details for invocation %s: %s", hookInvocationId, errorMessage)
            );
          }
          return void 0;
        }
      }
      /**
       * Reads all new events from the stack history
       *
       * The events are returned in chronological order by the underlying poller.
       */
      async readNewEvents(monitorId) {
        const pollEvents = await this.poller.poll();
        for (const resourceEvent of pollEvents) {
          this.progressMonitor.process(resourceEvent);
          if (resourceEvent.event.HookInvocationId) {
            const annotations = await this.fetchGuardHookAnnotations(resourceEvent.event.HookInvocationId);
            if (annotations) {
              resourceEvent.event.HookStatusReason = annotations;
            }
          }
          const activity = {
            deployment: monitorId,
            event: resourceEvent.event,
            metadata: this.findMetadataFor(resourceEvent.event.LogicalResourceId),
            progress: this.progressMonitor.progress
          };
          await this.ioHelper.notify(IO.CDK_TOOLKIT_I5502.msg(this.formatActivity(activity, true), activity));
        }
      }
      /**
       * Perform a final poll to the end and flush out all events to the printer
       *
       * Finish any poll currently in progress, then do a final one until we've
       * reached the last page.
       */
      async finalPollToEnd(monitorId) {
        if (this.readPromise) {
          await this.readPromise;
        }
        await this.readNewEvents(monitorId);
      }
      /**
       * Formats a stack activity into a basic string
       */
      formatActivity(activity, progress) {
        const event = activity.event;
        const metadata = activity.metadata;
        const resourceName = metadata ? metadata.constructPath : event.LogicalResourceId || "";
        const logicalId = resourceName !== event.LogicalResourceId ? `(${event.LogicalResourceId}) ` : "";
        return util5.format(
          "%s | %s%s | %s | %s | %s %s%s%s",
          event.StackName,
          progress !== false ? `${activity.progress.formatted} | ` : "",
          new Date(event.Timestamp).toLocaleTimeString(),
          event.ResourceStatus || "",
          event.ResourceType,
          resourceName,
          logicalId,
          event.ResourceStatusReason ? event.ResourceStatusReason : "",
          metadata?.entry.trace ? `
	${metadata.entry.trace.join("\n	\\_ ")}` : ""
        );
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/stack-events/stack-status.ts
var import_client_cloudformation2, StackStatus;
var init_stack_status = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/stack-events/stack-status.ts"() {
    "use strict";
    import_client_cloudformation2 = __toESM(require_dist_cjs140());
    StackStatus = class _StackStatus2 {
      constructor(name, reason) {
        this.name = name;
        this.reason = reason;
      }
      name;
      reason;
      static {
        __name(this, "StackStatus");
      }
      static fromStackDescription(description) {
        return new _StackStatus2(description.StackStatus, description.StackStatusReason);
      }
      get isCreationFailure() {
        return this.name === import_client_cloudformation2.StackStatus.ROLLBACK_COMPLETE || this.name === import_client_cloudformation2.StackStatus.ROLLBACK_FAILED;
      }
      get isDeleted() {
        return this.name.startsWith("DELETE_");
      }
      get isFailure() {
        return this.name.endsWith("FAILED");
      }
      get isInProgress() {
        return this.name.endsWith("_IN_PROGRESS") && !this.isReviewInProgress;
      }
      get isReviewInProgress() {
        return this.name === import_client_cloudformation2.StackStatus.REVIEW_IN_PROGRESS;
      }
      get isNotFound() {
        return this.name === "NOT_FOUND";
      }
      get isDeploySuccess() {
        return !this.isNotFound && (this.name === import_client_cloudformation2.StackStatus.CREATE_COMPLETE || this.name === import_client_cloudformation2.StackStatus.UPDATE_COMPLETE || this.name === import_client_cloudformation2.StackStatus.IMPORT_COMPLETE);
      }
      get isRollbackSuccess() {
        return this.name === import_client_cloudformation2.StackStatus.ROLLBACK_COMPLETE || this.name === import_client_cloudformation2.StackStatus.UPDATE_ROLLBACK_COMPLETE;
      }
      /**
       * Whether the stack is in a paused state due to `--no-rollback`.
       *
       * The possible actions here are retrying a new `--no-rollback` deployment, or initiating a rollback.
       */
      get rollbackChoice() {
        switch (this.name) {
          case import_client_cloudformation2.StackStatus.CREATE_FAILED:
          case import_client_cloudformation2.StackStatus.UPDATE_FAILED:
            return 0 /* START_ROLLBACK */;
          case import_client_cloudformation2.StackStatus.UPDATE_ROLLBACK_FAILED:
            return 1 /* CONTINUE_UPDATE_ROLLBACK */;
          case import_client_cloudformation2.StackStatus.ROLLBACK_FAILED:
            return 2 /* ROLLBACK_FAILED */;
          default:
            return 3 /* NONE */;
        }
      }
      get isRollbackable() {
        return [0 /* START_ROLLBACK */, 1 /* CONTINUE_UPDATE_ROLLBACK */].includes(this.rollbackChoice);
      }
      toString() {
        return this.name + (this.reason ? ` (${this.reason})` : "");
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/stack-events/index.ts
var init_stack_events = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/stack-events/index.ts"() {
    "use strict";
    init_stack_activity_monitor();
    init_stack_event_poller();
    init_stack_status();
    init_stack_progress_monitor();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/cloudformation/stack-helpers.ts
var CloudFormationStack;
var init_stack_helpers = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/cloudformation/stack-helpers.ts"() {
    "use strict";
    init_toolkit_error();
    init_util3();
    init_stack_events();
    CloudFormationStack = class _CloudFormationStack {
      constructor(cfn, stackName, stack, retrieveProcessedTemplate = false) {
        this.cfn = cfn;
        this.stackName = stackName;
        this.stack = stack;
        this.retrieveProcessedTemplate = retrieveProcessedTemplate;
      }
      cfn;
      stackName;
      stack;
      retrieveProcessedTemplate;
      static {
        __name(this, "CloudFormationStack");
      }
      static async lookup(cfn, stackName, retrieveProcessedTemplate = false) {
        try {
          const response = await cfn.describeStacks({ StackName: stackName });
          return new _CloudFormationStack(cfn, stackName, response.Stacks && response.Stacks[0], retrieveProcessedTemplate);
        } catch (e32) {
          if (e32.name === "ValidationError" && formatErrorMessage(e32) === `Stack with id ${stackName} does not exist`) {
            return new _CloudFormationStack(cfn, stackName, void 0);
          }
          throw e32;
        }
      }
      /**
       * Return a copy of the given stack that does not exist
       *
       * It's a little silly that it needs arguments to do that, but there we go.
       */
      static doesNotExist(cfn, stackName) {
        return new _CloudFormationStack(cfn, stackName);
      }
      /**
       * From static information (for testing)
       */
      static fromStaticInformation(cfn, stackName, stack) {
        return new _CloudFormationStack(cfn, stackName, stack);
      }
      _template;
      /**
       * Returns the Stack object returned from the CloudFormation service response that this decorating object wraps
       */
      get wrapped() {
        if (!this.stack) {
          throw new ToolkitError("NoStack", "CloudFormationStack object does not hold a stack");
        }
        return this.stack;
      }
      /**
       * Retrieve the stack's deployed template
       *
       * Cached, so will only be retrieved once. Will return an empty
       * structure if the stack does not exist.
       */
      async template() {
        if (!this.exists) {
          return {};
        }
        if (this._template === void 0) {
          const response = await this.cfn.getTemplate({
            StackName: this.stackName,
            TemplateStage: this.retrieveProcessedTemplate ? "Processed" : "Original"
          });
          this._template = response.TemplateBody && deserializeStructure(response.TemplateBody) || {};
        }
        return this._template;
      }
      /**
       * Whether the stack exists
       */
      get exists() {
        return this.stack !== void 0;
      }
      /**
       * The stack's ID (which is the same as its ARN)
       *
       * Throws if the stack doesn't exist.
       */
      get stackId() {
        this.assertExists();
        return this.stack.StackId;
      }
      /**
       * The stack's current outputs
       *
       * Empty object if the stack doesn't exist
       */
      get outputs() {
        if (!this.exists) {
          return {};
        }
        const result2 = {};
        (this.stack.Outputs || []).forEach((output) => {
          result2[output.OutputKey] = output.OutputValue;
        });
        return result2;
      }
      /**
       * The stack's status
       *
       * Special status NOT_FOUND if the stack does not exist.
       */
      get stackStatus() {
        if (!this.exists) {
          return new StackStatus("NOT_FOUND", "Stack not found during lookup");
        }
        return StackStatus.fromStackDescription(this.stack);
      }
      /**
       * The stack's current tags
       *
       * Empty list if the stack does not exist
       */
      get tags() {
        return this.stack?.Tags || [];
      }
      /**
       * SNS Topic ARNs that will receive stack events.
       *
       * Empty list if the stack does not exist
       */
      get notificationArns() {
        return this.stack?.NotificationARNs ?? [];
      }
      /**
       * Return the names of all current parameters to the stack
       *
       * Empty list if the stack does not exist.
       */
      get parameterNames() {
        return Object.keys(this.parameters);
      }
      /**
       * Return the names and values of all current parameters to the stack
       *
       * Empty object if the stack does not exist.
       */
      get parameters() {
        if (!this.exists) {
          return {};
        }
        const ret = {};
        for (const param of this.stack.Parameters ?? []) {
          ret[param.ParameterKey] = param.ResolvedValue ?? param.ParameterValue;
        }
        return ret;
      }
      /**
       * Return the termination protection of the stack
       */
      get terminationProtection() {
        return this.stack?.EnableTerminationProtection;
      }
      assertExists() {
        if (!this.exists) {
          throw new ToolkitError("StackNotFound", `No stack named '${this.stackName}'`);
        }
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/cloudformation/nested-stack-helpers.ts
async function loadCurrentTemplateWithNestedStacks(rootStackArtifact, sdk, retrieveProcessedTemplate = false) {
  const deployedRootTemplate = await loadCurrentTemplate(rootStackArtifact, sdk, retrieveProcessedTemplate);
  const nestedStacks = await loadNestedStacks(rootStackArtifact, sdk, {
    generatedTemplate: rootStackArtifact.template,
    deployedTemplate: deployedRootTemplate,
    deployedStackName: rootStackArtifact.stackName
  });
  return {
    deployedRootTemplate,
    nestedStacks
  };
}
async function loadCurrentTemplate(stackArtifact, sdk, retrieveProcessedTemplate = false) {
  return loadCurrentStackTemplate(stackArtifact.stackName, sdk, retrieveProcessedTemplate);
}
async function loadCurrentStackTemplate(stackName, sdk, retrieveProcessedTemplate = false) {
  const cfn = sdk.cloudFormation();
  const stack = await CloudFormationStack.lookup(cfn, stackName, retrieveProcessedTemplate);
  return stack.template();
}
async function loadNestedStacks(rootStackArtifact, sdk, parentTemplates) {
  const listStackResources = parentTemplates.deployedStackName ? new LazyListStackResources(sdk, parentTemplates.deployedStackName) : void 0;
  const nestedStacks = {};
  for (const [nestedStackLogicalId, generatedNestedStackResource] of Object.entries(
    parentTemplates.generatedTemplate.Resources ?? {}
  )) {
    if (!isCdkManagedNestedStack(generatedNestedStackResource)) {
      continue;
    }
    const assetPath = generatedNestedStackResource.Metadata["aws:asset:path"];
    const nestedStackTemplates = await getNestedStackTemplates(
      rootStackArtifact,
      assetPath,
      nestedStackLogicalId,
      listStackResources,
      sdk
    );
    nestedStacks[nestedStackLogicalId] = {
      deployedTemplate: nestedStackTemplates.deployedTemplate,
      generatedTemplate: nestedStackTemplates.generatedTemplate,
      physicalName: nestedStackTemplates.deployedStackName,
      nestedStackTemplates: await loadNestedStacks(rootStackArtifact, sdk, nestedStackTemplates)
    };
  }
  return nestedStacks;
}
async function getNestedStackTemplates(rootStackArtifact, nestedTemplateAssetPath, nestedStackLogicalId, listStackResources, sdk) {
  const nestedTemplatePath = path15.join(rootStackArtifact.assembly.directory, nestedTemplateAssetPath);
  const nestedStackArn = await getNestedStackArn(nestedStackLogicalId, listStackResources);
  const deployedStackName = nestedStackArn?.slice(nestedStackArn.indexOf("/") + 1, nestedStackArn.lastIndexOf("/"));
  return {
    generatedTemplate: JSON.parse(fs15.readFileSync(nestedTemplatePath, "utf-8")),
    deployedTemplate: deployedStackName ? await loadCurrentStackTemplate(deployedStackName, sdk) : {},
    deployedStackName
  };
}
async function getNestedStackArn(nestedStackLogicalId, listStackResources) {
  try {
    const stackResources = await listStackResources?.listStackResources();
    return stackResources?.find((sr) => sr.LogicalResourceId === nestedStackLogicalId)?.PhysicalResourceId;
  } catch (e32) {
    if (formatErrorMessage(e32).startsWith("Stack with id ") && formatErrorMessage(e32).endsWith(" does not exist")) {
      return;
    }
    throw e32;
  }
}
function isCdkManagedNestedStack(stackResource) {
  return stackResource.Type === "AWS::CloudFormation::Stack" && stackResource.Metadata && stackResource.Metadata["aws:asset:path"];
}
var path15, fs15;
var init_nested_stack_helpers = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/cloudformation/nested-stack-helpers.ts"() {
    "use strict";
    path15 = __toESM(require("path"));
    fs15 = __toESM(require_lib4());
    init_evaluate_cloudformation_template();
    init_stack_helpers();
    init_util3();
    __name(loadCurrentTemplateWithNestedStacks, "loadCurrentTemplateWithNestedStacks");
    __name(loadCurrentTemplate, "loadCurrentTemplate");
    __name(loadCurrentStackTemplate, "loadCurrentStackTemplate");
    __name(loadNestedStacks, "loadNestedStacks");
    __name(getNestedStackTemplates, "getNestedStackTemplates");
    __name(getNestedStackArn, "getNestedStackArn");
    __name(isCdkManagedNestedStack, "isCdkManagedNestedStack");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/cloudformation/logical-id-map.ts
function buildLogicalToPathMap(stack) {
  const toPath = {};
  const toLogicalId = {};
  const template = stack.template ?? {};
  for (const [logicalId, resource] of Object.entries(template.Resources ?? {})) {
    const path47 = resource?.Metadata?.["aws:cdk:path"];
    if (path47) {
      toPath[logicalId] = path47;
      toLogicalId[path47] = logicalId;
    }
  }
  const ownLogicalIds = /* @__PURE__ */ new Set();
  for (const section of ["Resources", "Parameters", "Conditions", "Outputs", "Rules", "Mappings"]) {
    for (const id of Object.keys(template[section] ?? {})) {
      ownLogicalIds.add(id);
    }
  }
  for (const md of stack.findMetadataByType(cxschema6.ArtifactMetadataEntryType.LOGICAL_ID)) {
    const logicalId = md.data;
    if (logicalId in toPath) {
      continue;
    }
    if (!ownLogicalIds.has(logicalId)) {
      continue;
    }
    toPath[logicalId] = md.path;
    toLogicalId[md.path] = logicalId;
  }
  return { toPath, toLogicalId };
}
var cxschema6;
var init_logical_id_map = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/cloudformation/logical-id-map.ts"() {
    "use strict";
    cxschema6 = __toESM(require_lib2());
    __name(buildLogicalToPathMap, "buildLogicalToPathMap");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/cloudformation/index.ts
var init_cloudformation2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/cloudformation/index.ts"() {
    "use strict";
    init_evaluate_cloudformation_template();
    init_template_body_parameter();
    init_nested_stack_helpers();
    init_stack_helpers();
    init_logical_id_map();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/diagnosing/format-utils.ts
function sideBySide(left, sep7, right) {
  const width = left.map((x) => x.length).reduce((acc, n10) => Math.max(acc, n10), 0);
  const ret = [];
  for (let i32 = 0; i32 < left.length || i32 < right.length; i32++) {
    const l20 = i32 < left.length ? left[i32] : " ".repeat(width);
    const r32 = i32 < right.length ? right[i32] : "";
    ret.push(`${l20}${sep7}${r32}`);
  }
  return ret;
}
function wrapText(n10, text) {
  const breakers = [" ", "\n"];
  const ret = [];
  let lineStart = 0;
  while (lineStart < text.length) {
    let lineEnd = lineStart + n10;
    while (lineEnd > lineStart && lineEnd < text.length && !breakers.includes(text[lineEnd])) {
      lineEnd -= 1;
    }
    if (lineEnd === lineStart) {
      lineEnd = lineStart + n10;
      while (lineEnd < text.length && !breakers.includes(text[lineEnd])) {
        lineEnd += 1;
      }
    }
    ret.push(text.slice(lineStart, lineEnd));
    lineStart = lineEnd + 1;
  }
  return ret;
}
var init_format_utils = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/diagnosing/format-utils.ts"() {
    "use strict";
    __name(sideBySide, "sideBySide");
    __name(wrapText, "wrapText");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/diagnosing/diagnosis-formatting.ts
function hostMessageFromDiagnosis(stack) {
  const diagnosis = stack.result;
  switch (diagnosis.type) {
    case "no-problem":
      return IO.CDK_TOOLKIT_I9500.msg(formatNoProblemStack(stack, diagnosis), stack);
    case "problem":
      return IO.CDK_TOOLKIT_E9500.msg(formatProblemStack(stack, diagnosis), stack);
    case "error-diagnosing":
      return IO.CDK_TOOLKIT_W9501.msg(formatDiagnosisErrorStack(stack, diagnosis), stack);
  }
}
function throwDeploymentErrorFromDiagnosis(diag) {
  switch (diag.type) {
    case "no-problem":
      throw new ToolkitError("DeploymentErrorNotError", "Diagnosis should represent an error, but does not");
    case "error-diagnosing":
      throw new DeploymentError(diag.message, "ErrorDiagnosisFailed");
  }
  const errorCode = diag.problems[0]?.errorCode;
  let defaultErrorCode;
  switch (diag.detectedBy.type) {
    case "change-set":
      defaultErrorCode = "ChangeSetCreationFailed";
      break;
    case "early-validation":
      defaultErrorCode = "EarlyValidationFailure";
      break;
    case "deployment":
      defaultErrorCode = "StackDeployFailed";
      break;
  }
  throw new DeploymentError(formatProblemDiagnosis(diag), errorCode ?? defaultErrorCode);
}
function formatProblemDiagnosis(diag) {
  switch (diag.detectedBy.type) {
    case "change-set":
      return formatChangeSetProblems(diag.problems, diag.detectedBy);
    case "early-validation":
      return formatEarlyValidationProblems(diag.problems, diag.detectedBy);
    case "deployment":
      return formatDeploymentProblems(diag.problems, diag.detectedBy);
  }
}
function formatChangeSetProblems(problems, detectedBy) {
  const caption = `Failed to create change set ${detectedBy.changeSetName}`;
  if (problems.length > 0) {
    return `${caption}:
${formatResourceErrors(problems)}`;
  } else {
    return `${caption}: ${detectedBy.statusReason}`;
  }
}
function formatEarlyValidationProblems(problems, detectedBy) {
  const caption = `Early validation failed for change set ${detectedBy.changeSetName}`;
  if (problems.length > 0) {
    return `${caption}:
${formatResourceErrors(problems)}`;
  } else {
    return caption;
  }
}
function formatDeploymentProblems(problems, detectedBy) {
  const caption = "Resource updates failed";
  if (problems.length > 0) {
    return `${caption}:
${formatResourceErrors(problems)}`;
  } else {
    return `${caption} (${detectedBy.stackStatus}): ${detectedBy.statusReason}`;
  }
}
function formatNoProblemStack(stack, _m29) {
  return `\u2705 Stack ${stack.stackName}: no issues found.`;
}
function formatProblemStack(stack, m20) {
  return `\u274C Stack ${stack.stackName}:
${formatProblemDiagnosis(m20)}`;
}
function formatDiagnosisErrorStack(stack, m20) {
  return `\u26A0\uFE0F Could not diagnose stack ${stack.stackName}: ${m20.message}`;
}
function formatResourceErrors(es) {
  sortByKey(es, (e32) => [locateResourceError(e32)]);
  const byLocation = /* @__PURE__ */ new Map();
  for (const e32 of es) {
    const key = locateResourceError(e32);
    (byLocation.get(key) ?? byLocation.set(key, []).get(key)).push(e32);
  }
  const blocks = [...byLocation.values()].map((group7) => formatResourceErrorBlock(group7));
  return blocks.join("\n\n");
}
function formatResourceErrorBlock(group7) {
  const first = group7[0];
  const lines = [];
  lines.push(`${locateResourceError(first)}  ${addendum(" ", first.resourceType, first.logicalId)}`.trim());
  for (const e32 of group7) {
    lines.push(...sideBySide(["  "], "", wrapText(120, e32.message)));
  }
  const sourceTrace = group7.find((e32) => e32.sourceTrace?.creationStackTrace)?.sourceTrace;
  if (sourceTrace?.creationStackTrace) {
    lines.push(...sideBySide(["Source Location:"], " ", sourceTrace.creationStackTrace));
  }
  for (const e32 of group7) {
    for (const ctx of e32.additionalContext ?? []) {
      lines.push("");
      for (const msg of ctx.messages) {
        lines.push(`${CONTEXT_INDENT}${msg}`);
      }
      if (ctx.link) {
        const leader = ctx.linkLabel ? `${ctx.linkLabel}: ` : "";
        lines.push(`${CONTEXT_INDENT}${leader}${ctx.link}`);
      }
    }
  }
  return lines.join("\n");
}
function locateResourceError(e32) {
  if (e32.sourceTrace?.constructPath) {
    return e32.sourceTrace?.constructPath;
  }
  const nestedStackParts = e32.parentStackLogicalIds.map((l20) => `Nested stack ${l20}`);
  if (e32.logicalId) {
    return [e32.topLevelStackHierarchicalId, ...nestedStackParts, e32.logicalId].join("/");
  }
  return [e32.topLevelStackHierarchicalId, nestedStackParts].join("/");
}
function addendum(sep7, ...xs) {
  xs = xs.filter((x) => x && typeof x === "string");
  if (xs.length > 0) {
    return `(${xs.join(sep7)})`;
  } else {
    return "";
  }
}
var CONTEXT_INDENT;
var init_diagnosis_formatting = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/diagnosing/diagnosis-formatting.ts"() {
    "use strict";
    init_format_utils();
    init_toolkit_error();
    init_util3();
    init_private();
    __name(hostMessageFromDiagnosis, "hostMessageFromDiagnosis");
    __name(throwDeploymentErrorFromDiagnosis, "throwDeploymentErrorFromDiagnosis");
    __name(formatProblemDiagnosis, "formatProblemDiagnosis");
    __name(formatChangeSetProblems, "formatChangeSetProblems");
    __name(formatEarlyValidationProblems, "formatEarlyValidationProblems");
    __name(formatDeploymentProblems, "formatDeploymentProblems");
    __name(formatNoProblemStack, "formatNoProblemStack");
    __name(formatProblemStack, "formatProblemStack");
    __name(formatDiagnosisErrorStack, "formatDiagnosisErrorStack");
    __name(formatResourceErrors, "formatResourceErrors");
    CONTEXT_INDENT = "   ";
    __name(formatResourceErrorBlock, "formatResourceErrorBlock");
    __name(locateResourceError, "locateResourceError");
    __name(addendum, "addendum");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/diagnosing/changeset-error-fetcher.ts
var ChangeSetResourceErrorFetcher;
var init_changeset_error_fetcher = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/diagnosing/changeset-error-fetcher.ts"() {
    "use strict";
    ChangeSetResourceErrorFetcher = class {
      constructor(sdk, envResources) {
        this.sdk = sdk;
        this.envResources = envResources;
      }
      sdk;
      envResources;
      static {
        __name(this, "ChangeSetResourceErrorFetcher");
      }
      /**
       * Fetch the details and return them as a string.
       *
       * If the details could not be fetched, log that as a warning using the IoHelper.
       *
       * (This method will only ever be used for early validation, so we are not generalizing
       * the error message in here).
       */
      async fetchDetailsString(changeSetName, stackName, ioHelper) {
        const summary = `Early validation failed for stack '${stackName}' (ChangeSet '${changeSetName}')`;
        const result2 = await this.fetchDetailsStructured(changeSetName, stackName);
        switch (result2.type) {
          case "could-not-check":
            await ioHelper.defaults.warn(result2.message);
            return summary;
          case "resource-errors":
            if (result2.errors.length === 0) {
              return summary;
            }
            return [
              `${summary}:`,
              ...result2.errors.map((e32) => `  - ${e32.message} (at ${e32.documentPath})`)
            ].join("\n");
        }
      }
      /**
       * Fetch the details and return them in structured form.
       */
      async fetchDetailsStructured(changeSetName, stackName) {
        let operationEvents = [];
        try {
          operationEvents = await this.getFailedEvents(stackName, changeSetName);
        } catch (error4) {
          let currentVersion = void 0;
          try {
            currentVersion = (await this.envResources?.lookupToolkit())?.version;
          } catch (e32) {
          }
          return {
            type: "could-not-check",
            message: `Could not retrieve additional details about change set creation errors (${error4}). Make sure you have permissions to call the DescribeEvents API, or re-bootstrap your environment by running 'cdk bootstrap' to update the Bootstrap CDK Toolkit stack. Bootstrap toolkit stack version 30 or later is needed; current version: ${currentVersion ?? "unknown"}.`
          };
        }
        return {
          type: "resource-errors",
          errors: operationEvents.map((ev) => ({
            eventType: ev.EventType ?? "",
            logicalId: ev.LogicalResourceId ?? "",
            message: ev.ValidationStatusReason ?? "",
            physicalId: ev.PhysicalResourceId ? ev.PhysicalResourceId : void 0,
            validationName: ev.ValidationName ?? "",
            documentPath: ev.ValidationPath ?? "",
            resourceType: ev.ResourceType
          }))
        };
      }
      async getFailedEvents(stackName, changeSetName) {
        return this.sdk.cloudFormation().paginatedDescribeEvents({
          StackName: stackName,
          ChangeSetName: changeSetName,
          Filters: {
            FailedEvents: true
          }
        });
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/diagnosing/resource-investigation.ts
async function investigateResource(err, sdk, debug2, options = {}) {
  switch (err.resourceType) {
    case "AWS::ECS::Service":
      return investigateEcsService(err, sdk, debug2, options);
    default:
      return [];
  }
}
async function investigateEcsService(err, sdk, debug2, options) {
  const physicalId = err.physicalId;
  if (!physicalId) {
    await debug2("ECS investigation: no physical ID available");
    return [];
  }
  const { cluster, serviceName } = parseEcsServiceIdentifier(physicalId);
  if (!serviceName) {
    await debug2(`ECS investigation: could not parse service identifier from "${physicalId}"`);
    return [];
  }
  const region = sdk.currentRegion;
  const ecs = sdk.ecs();
  const cwl = sdk.cloudWatchLogs();
  const service = await describeService(ecs, cluster, serviceName, debug2);
  if (!service) {
    if (options.rollbackEnabled) {
      return [{
        source: "ECS Service",
        messages: [
          "The service and its tasks were removed during rollback, so container-level failure detail is unavailable.",
          "Re-run the deployment with `--no-rollback` to retain the failed tasks and see why they stopped."
        ]
      }];
    }
    return [];
  }
  const results = [];
  const stoppedTaskResult = await getStoppedTaskReasons(ecs, cluster, serviceName, region, service, debug2);
  if (stoppedTaskResult.context) {
    results.push(stoppedTaskResult.context);
  }
  const taskDefinitionArn = service.taskDefinition;
  if (!taskDefinitionArn) {
    return results;
  }
  const taskDefInfo = await getTaskDefinitionInfo(ecs, taskDefinitionArn, debug2);
  if (!taskDefInfo) {
    return results;
  }
  const logConfigs = taskDefInfo.logConfigs;
  if (logConfigs.length === 0) {
    results.push({
      source: "CloudWatch Logs",
      messages: [
        "No CloudWatch Logs configuration found. Enable logging to see container output on failure.",
        "Example:",
        '  taskDefinition.addContainer("app", {',
        "    // ...",
        '    logging: ecs.LogDrivers.awsLogs({ streamPrefix: "my-service" }),',
        "  });"
      ]
    });
    return results;
  }
  const logResults = await Promise.all(logConfigs.map((cfg) => fetchRecentLogs(cwl, cfg, region, stoppedTaskResult.taskIds, debug2)));
  const logContexts = logResults.filter((c32) => c32 !== void 0);
  results.push(...logContexts);
  if (logContexts.length === 0) {
    results.push({
      source: "CloudWatch Logs",
      messages: ["No CloudWatch Logs found."]
    });
  }
  return results;
}
function parseEcsServiceIdentifier(physicalId) {
  const arnMatch = physicalId.match(/^arn:[^:]+:ecs:[^:]*:[^:]*:service\/([^/]+)\/([^/]+)$/);
  if (arnMatch) {
    return { cluster: arnMatch[1], serviceName: arnMatch[2] };
  }
  const parts = physicalId.split("/");
  if (parts.length === 2 && parts[0] && parts[1]) {
    return { cluster: parts[0], serviceName: parts[1] };
  }
  if (parts.length === 1 && parts[0]) {
    return { serviceName: parts[0] };
  }
  return {};
}
async function describeService(ecs, cluster, serviceName, debug2) {
  try {
    const resp = await ecs.describeServices({ cluster, services: [serviceName] });
    const service = resp.services?.[0];
    if (!service) {
      await debug2(`ECS investigation: service "${serviceName}" not found`);
    }
    return service;
  } catch (e32) {
    await debug2(`ECS investigation: failed to describe service: ${e32.message}`);
    return void 0;
  }
}
async function getStoppedTaskReasons(ecs, cluster, serviceName, region, service, debug2) {
  try {
    const taskIds = await listStoppedTaskIds(ecs, cluster, serviceName, debug2);
    const messages = [];
    if (taskIds.length > 0) {
      const tasksResp = await ecs.describeTasks({ cluster, tasks: [taskIds[0]] });
      const task = tasksResp.tasks?.[0];
      if (task) {
        if (task.stoppedReason) {
          messages.push(`Task stopped: ${task.stoppedReason}`);
        }
        for (const container of task.containers ?? []) {
          if (container.reason) {
            messages.push(`Container "${container.name}": ${container.reason}`);
          }
          if (container.exitCode != null && container.exitCode !== 0) {
            messages.push(`Container "${container.name}" exited with code ${container.exitCode}`);
          }
        }
      }
      if (messages.length > 0 && taskIds.length > 1) {
        messages.push(`(${taskIds.length - 1} other failed task(s) not shown)`);
      }
    }
    if (messages.length === 0) {
      const failureEvent = (service.events ?? []).find((e32) => e32.message?.includes("stopped") || e32.message?.includes("failed") || e32.message?.includes("unhealthy"));
      if (failureEvent?.message) {
        messages.push(failureEvent.message);
      }
    }
    if (messages.length === 0) {
      return { taskIds };
    }
    return {
      context: {
        source: "ECS Stopped Tasks",
        messages,
        link: ecsStoppedTasksConsoleUrl(region, cluster ?? "default", serviceName),
        linkLabel: "Tasks"
      },
      taskIds
    };
  } catch (e32) {
    await debug2(`ECS investigation: failed to get stopped task reasons: ${e32.message}`);
    return { taskIds: [] };
  }
}
async function listStoppedTaskIds(ecs, cluster, serviceName, debug2) {
  const toIds = /* @__PURE__ */ __name((arns2) => (arns2 ?? []).map((arn) => arn.split("/").pop()).filter((id) => !!id), "toIds");
  let arns;
  try {
    const byService = await ecs.listTasks({ cluster, serviceName, desiredStatus: "STOPPED" });
    arns = byService.taskArns;
    if (!arns || arns.length === 0) {
      const byCluster = await ecs.listTasks({ cluster, desiredStatus: "STOPPED" });
      arns = byCluster.taskArns;
    }
  } catch (e32) {
    await debug2(`ECS investigation: failed to list stopped tasks: ${e32.message}`);
    return [];
  }
  return toIds(arns).slice(0, MAX_STOPPED_TASKS);
}
async function getTaskDefinitionInfo(ecs, taskDefinitionArn, debug2) {
  try {
    const resp = await ecs.describeTaskDefinition({ taskDefinition: taskDefinitionArn });
    const containers = resp.taskDefinition?.containerDefinitions ?? [];
    const logConfigs = [];
    for (const container of containers) {
      const logConfig = container.logConfiguration;
      if (logConfig?.logDriver === "awslogs") {
        const logGroup = logConfig.options?.["awslogs-group"];
        if (logGroup) {
          logConfigs.push({
            logGroup,
            streamPrefix: logConfig.options?.["awslogs-stream-prefix"],
            containerName: container.name
          });
        }
      }
    }
    return { logConfigs };
  } catch (e32) {
    await debug2(`ECS investigation: failed to describe task definition: ${e32.message}`);
    return void 0;
  }
}
async function fetchRecentLogs(cwl, logConfig, region, taskIds, debug2) {
  try {
    const lastTaskId = taskIds[0];
    const targetStream = logConfig.streamPrefix && logConfig.containerName && lastTaskId ? `${logConfig.streamPrefix}/${logConfig.containerName}/${lastTaskId}` : void 0;
    const resp = await cwl.filterLogEvents({
      logGroupName: logConfig.logGroup,
      startTime: Date.now() - 30 * 60 * 1e3,
      limit: 1e3,
      ...targetStream ? { logStreamNames: [targetStream] } : logConfig.streamPrefix ? { logStreamNamePrefix: logConfig.streamPrefix } : {}
    });
    const events = resp.events ?? [];
    if (events.length === 0) {
      await debug2(`ECS investigation: no recent log events in ${logConfig.logGroup}${targetStream ? ` (targeted stream: ${targetStream})` : ""}`);
      return void 0;
    }
    const allMessages = events.map((e32) => e32.message?.trimEnd()).filter((m20) => m20 != null);
    const messages = allMessages.slice(-MAX_LOG_LINES);
    const omitted = allMessages.length - messages.length;
    if (omitted > 0) {
      messages.unshift(`... (${omitted} earlier lines omitted)`);
    }
    if (taskIds.length > 1) {
      messages.push(`(showing logs from last failed task; ${taskIds.length - 1} other failed task(s) available in console)`);
    }
    const source = logConfig.containerName ? `CloudWatch Logs: ${logConfig.logGroup} (container: ${logConfig.containerName})` : `CloudWatch Logs: ${logConfig.logGroup}`;
    return {
      source,
      messages,
      link: cloudWatchLogsConsoleUrl(region, logConfig.logGroup),
      linkLabel: "Logs"
    };
  } catch (e32) {
    await debug2(`ECS investigation: failed to fetch logs from ${logConfig.logGroup}: ${e32.message}`);
    return void 0;
  }
}
function cloudWatchLogsConsoleUrl(region, logGroup) {
  const encodedLogGroup = encodeURIComponent(encodeURIComponent(logGroup)).replace(/%/g, "$");
  return `https://${region}.console.aws.amazon.com/cloudwatch/home?region=${region}#logsV2:log-groups/log-group/${encodedLogGroup}`;
}
function ecsStoppedTasksConsoleUrl(region, cluster, serviceName) {
  return `https://${region}.console.aws.amazon.com/ecs/v2/clusters/${cluster}/services/${serviceName}/tasks?status=STOPPED&region=${region}`;
}
var MAX_LOG_LINES, MAX_STOPPED_TASKS;
var init_resource_investigation = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/diagnosing/resource-investigation.ts"() {
    "use strict";
    MAX_LOG_LINES = 50;
    __name(investigateResource, "investigateResource");
    __name(investigateEcsService, "investigateEcsService");
    __name(parseEcsServiceIdentifier, "parseEcsServiceIdentifier");
    __name(describeService, "describeService");
    __name(getStoppedTaskReasons, "getStoppedTaskReasons");
    MAX_STOPPED_TASKS = 3;
    __name(listStoppedTaskIds, "listStoppedTaskIds");
    __name(getTaskDefinitionInfo, "getTaskDefinitionInfo");
    __name(fetchRecentLogs, "fetchRecentLogs");
    __name(cloudWatchLogsConsoleUrl, "cloudWatchLogsConsoleUrl");
    __name(ecsStoppedTasksConsoleUrl, "ecsStoppedTasksConsoleUrl");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/diagnosing/stack-diagnoser.ts
function changeSetHasNoChanges(description) {
  const noChangeErrorPrefixes = [
    // Error message for a regular template
    "The submitted information didn't contain changes.",
    // Error message when a Transform is involved (see #10650)
    "No updates are to be performed."
  ];
  return description.Status === "FAILED" && noChangeErrorPrefixes.some((p10) => (description.StatusReason ?? "").startsWith(p10));
}
function resourceErrorFromEarlyValidationError(stackId, parentStackLogicalIds, ev) {
  return {
    logicalId: ev.logicalId,
    physicalId: ev.physicalId,
    resourceType: ev.resourceType,
    message: `${ev.message} (at ${ev.documentPath})`,
    errorCode: `${ev.validationName}_${ev.eventType}`,
    parentStackLogicalIds,
    stackArn: stackId
  };
}
var import_client_cloudformation3, CloudFormationStackDiagnoser;
var init_stack_diagnoser = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/diagnosing/stack-diagnoser.ts"() {
    "use strict";
    import_client_cloudformation3 = __toESM(require_dist_cjs140());
    init_changeset_error_fetcher();
    init_resource_investigation();
    init_stack_events();
    init_stack_status();
    CloudFormationStackDiagnoser = class _CloudFormationStackDiagnoser {
      constructor(props) {
        this.props = props;
        this.cfn = this.props.sdk.cloudFormation();
        this.parentStackLogicalIds = [];
      }
      props;
      static {
        __name(this, "CloudFormationStackDiagnoser");
      }
      cfn;
      parentStackLogicalIds;
      _additionalExplorationSdkPromise;
      rollbackEnabled = true;
      /**
       * Diagnose a stack's root cause given no pre-existing state
       */
      async diagnoseFromFresh(stackName) {
        try {
          const response = await this.cfn.describeStacks({ StackName: stackName });
          const stack = response.Stacks?.[0];
          if (!stack) {
            return {
              type: "error-diagnosing",
              message: `Stack with name ${stackName} not found`
            };
          }
          const status = StackStatus.fromStackDescription(stack);
          if (status.isInProgress) {
            return {
              type: "error-diagnosing",
              message: `Stack with name ${stackName} is currently being updated (${status.name}). Try again when it's finished.`
            };
          }
          if (status.isFailure || status.isRollbackSuccess) {
            return await this._diagnoseViaStackEvents(stack);
          }
          return await this._diagnoseChangeSetFailureFromStackName(stack);
        } catch (e32) {
          return { type: "error-diagnosing", message: e32.message };
        }
      }
      /**
       * Diagnose potential problems with the change set
       */
      async diagnoseChangeSet(changeSet) {
        try {
          return await this._diagnoseChangeSetFailure(changeSet);
        } catch (e32) {
          return { type: "error-diagnosing", message: e32.message };
        }
      }
      /**
       * Diagnose potential problems with the change set
       */
      async diagnoseFromErrorCollection(errors, stack, allowFallback = true, options = {}) {
        this.rollbackEnabled = options.rollbackEnabled ?? true;
        if (errors.isEmpty()) {
          if (allowFallback) {
            try {
              return await this._diagnoseViaStackEvents(stack);
            } catch (e32) {
              await this.props.ioHelper.defaults.debug(`Fallback diagnosis failed: ${e32.message}`);
            }
          }
          return { type: "no-problem" };
        }
        return {
          type: "problem",
          detectedBy: {
            type: "deployment",
            stackStatus: stack.StackStatus ?? "",
            statusReason: stack.StackStatusReason ?? ""
          },
          problems: await this.enhanceErrors(errors.all)
        };
      }
      /**
       * Diagnose a deployment failure via stack events
       *
       * This is the same logic that the deployment monitor uses.
       */
      async _diagnoseViaStackEvents(stack) {
        const poller = new StackEventPoller(this.cfn, {
          stackArn: stack.StackId,
          initialPollRange: PollRange.mostRecentOperation()
        });
        await poller.poll();
        return this.diagnoseFromErrorCollection(poller.errors, stack, false, { rollbackEnabled: this.rollbackEnabled });
      }
      async _diagnoseChangeSetFailureFromStackName(stack) {
        const cs = (await this.cfn.listChangeSets({
          StackName: stack.StackId
        })).Summaries ?? [];
        const pending = cs.filter((x) => x.Status === import_client_cloudformation3.ChangeSetStatus.CREATE_IN_PROGRESS || x.Status === import_client_cloudformation3.ChangeSetStatus.CREATE_PENDING);
        if (pending.length > 0) {
          return {
            type: "error-diagnosing",
            message: `Stack with name ${stack.StackName} has change sets currently being created (${pending[0].ChangeSetName}). Try again when it's finished.`
          };
        }
        const failed = cs.filter((x) => x.Status === import_client_cloudformation3.ChangeSetStatus.FAILED);
        if (failed.length === 0) {
          return { type: "no-problem" };
        }
        return this._diagnoseChangeSetFailure(failed[0]);
      }
      /**
       * Try to diagnose the reason that caused a changeset to fail to create
       *
       * There are a couple of different reasons this can happen, and we go through each of them in order.
       *
       * Usually this starts from trying to detect an error message pattern in the change set status reason,
       * and then potentially going to fetch additional information using additional API calls.
       */
      async _diagnoseChangeSetFailure(changeSet) {
        if (changeSet.Status !== import_client_cloudformation3.ChangeSetStatus.FAILED) {
          return { type: "no-problem" };
        }
        if (changeSetHasNoChanges(changeSet)) {
          return { type: "no-problem" };
        }
        const isEarlyValidationError = changeSet.StatusReason?.includes("AWS::EarlyValidation");
        if (isEarlyValidationError) {
          return this._reportChangeSetFailureFromEvents(changeSet, {
            type: "early-validation",
            changeSetName: changeSet.ChangeSetName ?? ""
          });
        }
        if (changeSet.StatusReason?.includes("Nested change set")) {
          return this._diagnoseNestedChangeSetFailure(changeSet);
        }
        const failedAutoErrors = this._tryDetectFailedAutoImport(changeSet);
        if (failedAutoErrors) {
          return {
            type: "problem",
            detectedBy: {
              type: "change-set",
              changeSetStatus: changeSet.Status ?? "",
              changeSetName: changeSet.ChangeSetName ?? "",
              statusReason: changeSet.StatusReason ?? ""
            },
            problems: await this.enhanceErrors(failedAutoErrors)
          };
        }
        return this._reportChangeSetFailureFromEvents(changeSet, {
          type: "change-set",
          changeSetStatus: changeSet.Status ?? "",
          changeSetName: changeSet.ChangeSetName ?? "",
          statusReason: changeSet.StatusReason ?? ""
        });
      }
      /**
       * Try to read the resource-specific reasons for a changeset failure from `DescribeEvents`.
       *
       * If we couldn't read the events or there are 0 errors returned by that API, return a generic
       * error.
       */
      async _reportChangeSetFailureFromEvents(changeSet, detectedBy) {
        const ev = await new ChangeSetResourceErrorFetcher(this.props.sdk, this.props.envResources).fetchDetailsStructured(changeSet.ChangeSetName, changeSet.StackName);
        if (ev.type === "resource-errors" && ev.errors.length > 0) {
          return {
            type: "problem",
            detectedBy,
            problems: await this.enhanceErrors(ev.errors.map((e32) => resourceErrorFromEarlyValidationError(changeSet.StackId ?? "", this.parentStackLogicalIds, e32)))
          };
        }
        if (ev.type === "could-not-check") {
          await this.props.ioHelper.defaults.warn(ev.message);
        }
        return this._nonSpecificChangeSetError(changeSet, detectedBy);
      }
      async enhanceErrors(errs) {
        return Promise.all(errs.map((e32) => this.enhanceError(e32)));
      }
      async enhanceError(err) {
        const sourceTracePromise = err.logicalId ? this.props.sourceTracer.traceResource(err.stackArn, err.parentStackLogicalIds, err.logicalId) : this.props.sourceTracer.traceStack(err.stackArn, err.parentStackLogicalIds);
        const [sourceTrace, additionalContext] = await Promise.all([
          sourceTracePromise,
          this.investigateResourceBestEffort(err)
        ]);
        return {
          ...err,
          sourceTrace,
          topLevelStackHierarchicalId: this.props.topLevelStackHierarchicalId,
          ...additionalContext.length > 0 ? { additionalContext } : {}
        };
      }
      async investigateResourceBestEffort(err) {
        const sdk = await this.additionalExplorationSdk();
        if (!sdk) {
          return [];
        }
        try {
          return await investigateResource(err, sdk, (msg) => this.props.ioHelper.defaults.debug(msg), {
            rollbackEnabled: this.rollbackEnabled
          });
        } catch (e32) {
          await this.props.ioHelper.defaults.debug(`Resource investigation failed: ${e32.message}`);
          return [];
        }
      }
      /**
       * Build a generic stack error from the given change set information
       *
       * We can't point to a specific resource.
       */
      async _nonSpecificChangeSetError(changeSet, detectedBy) {
        return {
          type: "problem",
          detectedBy,
          problems: [
            await this.enhanceError({
              // It's about a stack
              logicalId: void 0,
              message: changeSet.StatusReason ?? "",
              parentStackLogicalIds: this.parentStackLogicalIds,
              stackArn: changeSet.StackId ?? "",
              physicalId: changeSet.StackId,
              resourceType: "AWS::CloudFormation::Stack"
            })
          ]
        };
      }
      /**
       * Look for nested change sets that have failed, and diagnose those.
       */
      async _diagnoseNestedChangeSetFailure(changeSet) {
        const nested = await this._findFailedNestedStack(changeSet);
        if (!nested) {
          return this._nonSpecificChangeSetError(changeSet, {
            type: "change-set",
            changeSetName: changeSet.ChangeSetName ?? "",
            changeSetStatus: changeSet.Status ?? "",
            statusReason: changeSet.StatusReason ?? ""
          });
        }
        const nestedCs = await this.cfn.describeChangeSet({
          ChangeSetName: nested.changeSetArn,
          StackName: nested.stackArn
        });
        const nestedDiag = new _CloudFormationStackDiagnoser(this.props);
        nestedDiag.parentStackLogicalIds = [...this.parentStackLogicalIds, nested.logicalId];
        return nestedDiag._diagnoseChangeSetFailure(nestedCs);
      }
      async _findFailedNestedStack(changeSet) {
        let nextToken = void 0;
        do {
          const resp = await this.cfn.describeChangeSet({
            StackName: changeSet.StackId,
            ChangeSetName: changeSet.ChangeSetId,
            ...nextToken ? { NextToken: nextToken } : {}
          });
          for (const change of resp.Changes ?? []) {
            if (change.Type === import_client_cloudformation3.ChangeType.Resource && change.ResourceChange?.ResourceType === "AWS::CloudFormation::Stack" && change.ResourceChange?.ChangeSetId && changeSet.StatusReason?.includes(change.ResourceChange?.ChangeSetId)) {
              return {
                changeSetArn: change.ResourceChange.ChangeSetId,
                stackArn: change.ResourceChange.PhysicalResourceId ?? "",
                logicalId: change.ResourceChange.LogicalResourceId ?? ""
              };
            }
          }
          nextToken = resp.NextToken;
        } while (nextToken);
        return void 0;
      }
      /**
       * Try to parse failed auto-imports out from a change set status
       *
       * The pattern looks like this:
       *
       * ```
       * CloudFormation is attempting to import some resources because they already exist in your account. The resources must have the DeletionPolicy attribute set to 'Retain' or 'RetainExceptOnCreate' in the template for successful import. The affected resources are SomeBucketD5B70704 ({BucketName=zomaareenbucket})
       * ```
       *
       * Followed by
       *
       * ```
       * LogicalID ({Prop=Value,Prop=Value}), LogicalID ({Prop=Value}), ...
       * ```
       */
      _tryDetectFailedAutoImport(changeSet) {
        const message2 = changeSet.StatusReason;
        if (!message2?.includes("CloudFormation is attempting to import some resources because they already exist in your account")) {
          return void 0;
        }
        const marker = "The affected resources are ";
        const markerIndex = message2.indexOf(marker);
        if (markerIndex === -1) {
          return void 0;
        }
        const ret = [];
        let remaining = message2.slice(markerIndex + marker.length);
        while (remaining) {
          const endIx = remaining.indexOf("), ");
          const thisResource = endIx > -1 ? remaining.slice(0, endIx + 1) : remaining;
          remaining = remaining.slice(thisResource.length + 2);
          const openParen = thisResource.indexOf("(");
          const logicalId = openParen > -1 ? thisResource.slice(0, openParen).trim() : void 0;
          ret.push({
            message: `Automatic import of existing resource ${thisResource} needs a DeletionPolicy of 'Retain' or 'RetainExceptOnCreate'. Set the removal policy to 'RemovalPolicy.RETAIN' or 'RemovalPolicy.RETAIN_ON_UPDATE_OR_DELETE' (See https://docs.aws.amazon.com/cdk/v2/guide/resources.html#resources-removal)`,
            parentStackLogicalIds: this.parentStackLogicalIds,
            stackArn: changeSet.StackId ?? "",
            errorCode: "AutomaticImportNeedsRetain",
            logicalId
          });
        }
        return ret;
      }
      /**
       * Return the additional exploration SDK, if available.
       */
      additionalExplorationSdk() {
        if (!this._additionalExplorationSdkPromise) {
          this._additionalExplorationSdkPromise = (async () => {
            try {
              return await this.props.additionalExplorationSdkProvider?.();
            } catch (e32) {
              await this.props.ioHelper.defaults.debug(`Additional exploration SDK provider failed: ${e32.message}`);
              return void 0;
            }
          })();
        }
        return this._additionalExplorationSdkPromise;
      }
    };
    __name(changeSetHasNoChanges, "changeSetHasNoChanges");
    __name(resourceErrorFromEarlyValidationError, "resourceErrorFromEarlyValidationError");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/source-tracing/private/stack-source-tracing.ts
function findCreationStackTrace(stack, constructPath) {
  const candidates = [
    // logical ID traces
    ...resourceMetadata2(stack, constructPath, cxschema7.ArtifactMetadataEntryType.LOGICAL_ID).flatMap((m20) => {
      if (m20.trace) {
        return [m20.trace];
      }
      return [];
    }),
    // Creation stack
    ...resourceMetadata2(stack, constructPath, "aws:cdk:creationStack").flatMap((m20) => {
      if (m20.data) {
        return [m20.data];
      }
      return [];
    })
  ];
  return candidates[0];
}
function findMutationStackTraces(stack, constructPath, propertyName) {
  const assignments = resourceMetadata2(stack, constructPath, "aws:cdk:propertyAssignment");
  return assignments.flatMap((m20) => {
    const data3 = m20.data;
    if (data3?.propertyName === propertyName) {
      return [data3.stackTrace];
    }
    return [];
  });
}
function resourceMetadata2(stack, constructPath, metadataType) {
  if (!constructPath.startsWith("/")) {
    constructPath = "/" + constructPath;
  }
  return (stack.metadata[constructPath] ?? []).filter((m20) => m20.type === metadataType);
}
function getStackTemplate(stack, logicalIdPath) {
  let template = stack.template;
  const segments = [...logicalIdPath];
  while (segments.length > 0) {
    const next = segments.shift();
    const nextTemplateFile = template.Resources[next]?.Metadata?.[cxapi.ASSET_RESOURCE_METADATA_PATH_KEY];
    if (!nextTemplateFile) {
      return void 0;
    }
    const nextTemplatePath = path16.join(path16.dirname(stack.templateFullPath), nextTemplateFile);
    template = JSON.parse(fs16.readFileSync(nextTemplatePath, "utf-8"));
  }
  return template;
}
var fs16, path16, cxapi, cxschema7, StackArtifactSourceTracer;
var init_stack_source_tracing = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/source-tracing/private/stack-source-tracing.ts"() {
    "use strict";
    fs16 = __toESM(require("fs"));
    path16 = __toESM(require("path"));
    cxapi = __toESM(require_lib3());
    cxschema7 = __toESM(require_lib2());
    StackArtifactSourceTracer = class {
      constructor(stack) {
        this.stack = stack;
      }
      stack;
      static {
        __name(this, "StackArtifactSourceTracer");
      }
      async traceResource(_stackName, nestedStackLogicalIds, logicalId, propertyName) {
        const containingTemplate = getStackTemplate(this.stack, nestedStackLogicalIds);
        const constructPath = containingTemplate?.Resources?.[logicalId]?.Metadata?.[cxapi.PATH_METADATA_KEY];
        if (!constructPath) {
          return void 0;
        }
        return {
          constructPath,
          creationStackTrace: findCreationStackTrace(this.stack, constructPath),
          mutationStackTraces: propertyName ? findMutationStackTraces(this.stack, constructPath, propertyName) : void 0
        };
      }
      async traceStack(_stackName, nestedStackLogicalIds) {
        if (nestedStackLogicalIds.length > 0) {
          const lastLogicalId = nestedStackLogicalIds.pop();
          return this.traceResource(_stackName, nestedStackLogicalIds, lastLogicalId);
        }
        const constructPath = this.stack.hierarchicalId;
        return {
          constructPath,
          creationStackTrace: findCreationStackTrace(this.stack, constructPath)
        };
      }
    };
    __name(findCreationStackTrace, "findCreationStackTrace");
    __name(findMutationStackTraces, "findMutationStackTraces");
    __name(resourceMetadata2, "resourceMetadata");
    __name(getStackTemplate, "getStackTemplate");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/deployments/cfn-api.ts
var cfn_api_exports = {};
__export(cfn_api_exports, {
  ParameterValues: () => ParameterValues,
  TemplateParameters: () => TemplateParameters,
  createDiffChangeSet: () => createDiffChangeSet,
  createValidationChangeSet: () => createValidationChangeSet,
  stabilizeStack: () => stabilizeStack,
  uploadStackTemplateAssets: () => uploadStackTemplateAssets,
  waitForChangeSet: () => waitForChangeSet,
  waitForChangeSetGone: () => waitForChangeSetGone,
  waitForChangeSetReport: () => waitForChangeSetReport,
  waitForStackDelete: () => waitForStackDelete,
  waitForStackDeploy: () => waitForStackDeploy
});
async function describeChangeSet(cfn, stackNameOrArn, changeSetNameOrArn, { fetchAll }) {
  const response = await cfn.describeChangeSet({
    StackName: stackNameOrArn,
    ChangeSetName: changeSetNameOrArn
  });
  while (fetchAll && response.NextToken != null) {
    const nextPage = await cfn.describeChangeSet({
      StackName: response.StackId ?? stackNameOrArn,
      ChangeSetName: response.ChangeSetId ?? changeSetNameOrArn,
      NextToken: response.NextToken
    });
    if (nextPage.Changes != null) {
      response.Changes = response.Changes != null ? response.Changes.concat(nextPage.Changes) : nextPage.Changes;
    }
    response.NextToken = nextPage.NextToken;
  }
  return response;
}
async function waitFor(valueProvider, timeout = 5e3) {
  while (true) {
    const result2 = await valueProvider();
    if (result2 === null) {
      return void 0;
    } else if (result2 !== void 0) {
      return result2;
    }
    await new Promise((cb) => setTimeout(cb, timeout));
  }
}
async function waitForChangeSetReport(cfn, ioHelper, stackNameOrArn, changeSetNameOrArn, { fetchAll, diagnoser }) {
  const stackDisplayName = stackNameFromArn(stackNameOrArn);
  const changeSetDisplayName = changeSetNameFromArn(changeSetNameOrArn);
  await ioHelper.defaults.debug((0, import_node_util.format)("Waiting for changeset %s on stack %s to finish creating...", changeSetDisplayName, stackDisplayName));
  const ret = await waitFor(async () => {
    const description = await describeChangeSet(cfn, stackNameOrArn, changeSetNameOrArn, {
      fetchAll
    });
    if (description.Status === "CREATE_PENDING" || description.Status === "CREATE_IN_PROGRESS") {
      await ioHelper.defaults.debug((0, import_node_util.format)("Changeset %s on stack %s is still creating", changeSetDisplayName, stackDisplayName));
      return void 0;
    }
    const diagnosis = await diagnoser.diagnoseChangeSet(description);
    return { description, diagnosis };
  });
  if (!ret) {
    throw new DeploymentError("Change set took too long to be created; aborting", "ChangeSetTimeout");
  }
  return ret;
}
async function waitForChangeSet(cfn, ioHelper, stackNameOrArn, changeSetNameOrArn, { fetchAll, diagnoser }) {
  const { description, diagnosis } = await waitForChangeSetReport(cfn, ioHelper, stackNameOrArn, changeSetNameOrArn, { fetchAll, diagnoser });
  if (diagnosis.type !== "no-problem") {
    throwDeploymentErrorFromDiagnosis(diagnosis);
  }
  return description;
}
async function waitForChangeSetGone(cfn, ioHelper, stackNameOrArn, changeSetNameOrArn) {
  const stackDisplayName = stackNameFromArn(stackNameOrArn);
  const changeSetDisplayName = changeSetNameFromArn(changeSetNameOrArn);
  await ioHelper.defaults.debug((0, import_node_util.format)("Waiting for changeset %s on stack %s to finish deleting...", changeSetDisplayName, stackDisplayName));
  await waitFor(async () => {
    try {
      const description = await cfn.describeChangeSet({
        StackName: stackNameOrArn,
        ChangeSetName: changeSetNameOrArn
      });
      if (description.Status === import_client_cloudformation4.ChangeSetStatus.DELETE_COMPLETE || description.Status === import_client_cloudformation4.ChangeSetStatus.DELETE_FAILED) {
        return true;
      }
      return void 0;
    } catch (e32) {
      if (e32.name === "ChangeSetNotFoundException") {
        return true;
      }
      throw e32;
    }
  });
}
async function createDiffChangeSet(ioHelper, options) {
  try {
    return await uploadBodyParameterAndCreateChangeSet(ioHelper, {
      ...options,
      includeNestedStacks: true
    });
  } catch (e32) {
    if (options.failOnError) {
      throw ToolkitError.withCause("ChangeSetCreationFailed", "Could not create a change set, and '--method=change-set' was specified. Please check your permissions or use '--method=auto' to allow falling back to a template diff.", e32);
    }
    await ioHelper.defaults.debug(String(e32));
    await ioHelper.defaults.info(
      "Could not create a change set, will base the diff on template differences (run again with -v to see the reason)\n"
    );
    return void 0;
  }
}
function templatesFromAssetManifestArtifact(artifact) {
  const assets = [];
  const fileName = artifact.file;
  const assetManifest = import_cdk_assets_lib3.AssetManifest.fromFile(fileName);
  assetManifest.entries.forEach((entry) => {
    if (entry.type === "file") {
      const source = entry.source;
      if (source.path && source.path.endsWith(".template.json")) {
        assets.push(entry);
      }
    }
  });
  return [assetManifest, assets];
}
async function prepareChangeSetEnv(ioHelper, options) {
  const env3 = await options.deployments.envs.accessStackForMutableStackOperations(options.stack);
  await uploadStackTemplateAssets(options.stack, options.deployments);
  const bodyParameter = await makeBodyParameter(
    ioHelper,
    options.stack,
    env3.resolvedEnvironment,
    new AssetManifestBuilder(),
    env3.resources
  );
  const cfn = env3.sdk.cloudFormation();
  const stack = await CloudFormationStack.lookup(cfn, options.stack.stackName, false);
  const exists = stack.exists && stack.stackStatus.name !== "REVIEW_IN_PROGRESS" && stack.stackStatus.name !== "DELETE_IN_PROGRESS";
  const executionRoleArn = await env3.replacePlaceholders(options.stack.cloudFormationExecutionRoleArn);
  const diagnoser = new CloudFormationStackDiagnoser({
    sdk: env3.sdk,
    envResources: env3.resources,
    sourceTracer: new StackArtifactSourceTracer(options.stack),
    ioHelper,
    topLevelStackHierarchicalId: options.stack.hierarchicalId
  });
  return { cfn, bodyParameter, exists, stackExistedBefore: stack.exists, executionRoleArn, diagnoser };
}
async function uploadBodyParameterAndCreateChangeSet(ioHelper, options) {
  const { cfn, bodyParameter, exists, executionRoleArn, diagnoser } = await prepareChangeSetEnv(ioHelper, options);
  await ioHelper.defaults.info(
    "Hold on while we create a read-only change set to get a diff with accurate replacement information (use --method=template to use a less accurate but faster template-only diff)\n"
  );
  return createChangeSetAndCleanup(ioHelper, {
    cfn,
    changeSetName: "cdk-diff-change-set",
    stack: options.stack,
    exists,
    uuid: options.uuid,
    willExecute: options.willExecute,
    bodyParameter,
    parameters: options.parameters,
    resourcesToImport: options.resourcesToImport,
    importExistingResources: options.importExistingResources,
    includeNestedStacks: options.includeNestedStacks,
    role: executionRoleArn,
    diagnoser
  });
}
async function uploadStackTemplateAssets(stack, deployments) {
  for (const artifact of stack.dependencies) {
    if (!cxapi2.AssetManifestArtifact.isAssetManifestArtifact(artifact)) {
      continue;
    }
    const [assetManifest, file_entries] = templatesFromAssetManifestArtifact(artifact);
    for (const entry of file_entries) {
      await deployments.buildSingleAsset(artifact, assetManifest, entry, {
        stack
      });
      await deployments.publishSingleAsset(assetManifest, entry, {
        stack
      });
    }
  }
}
async function createChangeSetAndCleanup(ioHelper, options) {
  if (options.exists) {
    await cleanupOldChangeset(options.cfn, ioHelper, options.changeSetName, options.stack.stackName);
  }
  await ioHelper.defaults.debug(`Attempting to create ChangeSet with name ${options.changeSetName} for stack ${options.stack.stackName}`);
  const templateParams = TemplateParameters.fromTemplate(options.stack.template);
  const stackParams = templateParams.supplyAll(options.parameters);
  const changeSet = await options.cfn.createChangeSet({
    StackName: options.stack.stackName,
    ChangeSetName: options.changeSetName,
    ChangeSetType: options.resourcesToImport ? "IMPORT" : options.exists ? "UPDATE" : "CREATE",
    Description: `CDK Changeset for diff ${options.uuid}`,
    ClientToken: `diff${options.uuid}`,
    TemplateURL: options.bodyParameter.TemplateURL,
    TemplateBody: options.bodyParameter.TemplateBody,
    Parameters: stackParams.apiParameters,
    ResourcesToImport: options.resourcesToImport,
    ImportExistingResources: options.importExistingResources,
    IncludeNestedStacks: options.includeNestedStacks || void 0,
    RoleARN: options.role,
    Tags: toCfnTags(options.stack.tags),
    Capabilities: ["CAPABILITY_IAM", "CAPABILITY_NAMED_IAM", "CAPABILITY_AUTO_EXPAND"]
  });
  await ioHelper.defaults.debug((0, import_node_util.format)("Initiated creation of changeset: %s; waiting for it to finish creating...", changeSet.Id));
  const createdChangeSet = await waitForChangeSet(
    options.cfn,
    ioHelper,
    changeSet.StackId ?? options.stack.stackName,
    changeSet.Id ?? options.changeSetName,
    {
      fetchAll: options.willExecute,
      diagnoser: options.diagnoser
    }
  );
  await cleanupOldChangeset(
    options.cfn,
    ioHelper,
    changeSet.Id ?? options.changeSetName,
    changeSet.StackId ?? options.stack.stackName
  );
  if (!options.exists) {
    await ioHelper.defaults.debug((0, import_node_util.format)("Deleting empty stack created by diff changeset: %s", changeSet.StackId ?? options.stack.stackName));
    await options.cfn.deleteStack({
      StackName: changeSet.StackId ?? options.stack.stackName,
      ClientRequestToken: (0, import_node_crypto5.randomUUID)()
    });
  }
  return createdChangeSet;
}
async function createValidationChangeSet(ioHelper, options) {
  const { cfn, bodyParameter, exists, stackExistedBefore, executionRoleArn, diagnoser } = await prepareChangeSetEnv(ioHelper, options);
  const changeSetName = `cdk-validate-${options.uuid}`;
  const templateParams = TemplateParameters.fromTemplate(options.stack.template);
  const stackParams = templateParams.supplyAll(options.parameters);
  const changeSet = await cfn.createChangeSet({
    StackName: options.stack.stackName,
    ChangeSetName: changeSetName,
    ChangeSetType: exists ? "UPDATE" : "CREATE",
    Description: `CDK Changeset for validation ${options.uuid}`,
    ClientToken: `validate${options.uuid}`,
    TemplateURL: bodyParameter.TemplateURL,
    TemplateBody: bodyParameter.TemplateBody,
    Parameters: stackParams.apiParameters,
    IncludeNestedStacks: true,
    RoleARN: executionRoleArn,
    Tags: toCfnTags(options.stack.tags),
    Capabilities: ["CAPABILITY_IAM", "CAPABILITY_NAMED_IAM", "CAPABILITY_AUTO_EXPAND"]
  });
  try {
    const report = await waitForChangeSetReport(
      cfn,
      ioHelper,
      changeSet.StackId ?? options.stack.stackName,
      changeSet.Id ?? changeSetName,
      { fetchAll: false, diagnoser }
    );
    return report;
  } finally {
    await cleanupOldChangeset(cfn, ioHelper, changeSet.Id ?? changeSetName, changeSet.StackId ?? options.stack.stackName).catch((e32) => ioHelper.defaults.warn(`Failed to clean up validation change set: ${e32}`));
    if (!stackExistedBefore) {
      await cfn.deleteStack({
        StackName: changeSet.StackId ?? options.stack.stackName,
        ClientRequestToken: (0, import_node_crypto5.randomUUID)()
      }).catch((e32) => ioHelper.defaults.warn(`Failed to clean up REVIEW_IN_PROGRESS stack: ${e32}`));
    }
  }
}
function toCfnTags(tags) {
  return Object.entries(tags).map(([k32, v]) => ({
    Key: k32,
    Value: v
  }));
}
async function cleanupOldChangeset(cfn, ioHelper, changeSetNameOrArn, stackNameOrArn) {
  const changeSetDisplayName = changeSetNameFromArn(changeSetNameOrArn);
  await ioHelper.defaults.debug(`Removing existing change set with name ${changeSetDisplayName} if it exists`);
  await cfn.deleteChangeSet({
    StackName: stackNameOrArn,
    ChangeSetName: changeSetNameOrArn
  });
}
async function waitForStackDelete(cfn, ioHelper, stackNameOrArn) {
  const stackDisplayName = stackNameFromArn(stackNameOrArn);
  const stack = await stabilizeStack(cfn, ioHelper, stackNameOrArn);
  if (!stack) {
    return void 0;
  }
  const status = stack.stackStatus;
  if (status.isFailure) {
    throw new ToolkitError(
      "StackDeleteFailed",
      `The stack named ${stackDisplayName} is in a failed state. You may need to delete it from the AWS console : ${status}`
    );
  } else if (status.isDeleted) {
    return void 0;
  }
  return stack;
}
async function waitForStackDeploy(cfn, ioHelper, stackName) {
  const stack = await stabilizeStack(cfn, ioHelper, stackName);
  if (!stack) {
    return void 0;
  }
  const status = stack.stackStatus;
  if (status.isCreationFailure) {
    throw new DeploymentError(
      `The stack named ${stackName} failed creation, it may need to be manually deleted from the AWS console: ${status}`,
      "StackCreationFailed"
    );
  } else if (!status.isDeploySuccess) {
    throw new DeploymentError(`The stack named ${stackName} failed to deploy: ${status}`, "StackDeployFailed");
  }
  return stack;
}
async function stabilizeStack(cfn, ioHelper, stackNameOrArn) {
  const stackDisplayName = stackNameFromArn(stackNameOrArn);
  await ioHelper.defaults.debug((0, import_node_util.format)("Waiting for stack %s to finish creating or updating...", stackDisplayName));
  return waitFor(async () => {
    const stack = await CloudFormationStack.lookup(cfn, stackNameOrArn);
    if (!stack.exists) {
      await ioHelper.defaults.debug((0, import_node_util.format)("Stack %s does not exist", stackDisplayName));
      return null;
    }
    const status = stack.stackStatus;
    if (status.isInProgress) {
      await ioHelper.defaults.debug((0, import_node_util.format)("Stack %s has an ongoing operation in progress and is not stable (%s)", stackDisplayName, status));
      return void 0;
    } else if (status.isReviewInProgress) {
      await ioHelper.defaults.debug((0, import_node_util.format)("Stack %s is in REVIEW_IN_PROGRESS state. Considering this is a stable status (%s)", stackDisplayName, status));
    }
    return stack;
  });
}
var import_node_crypto5, import_node_util, import_cdk_assets_lib3, cxapi2, import_cloud_assembly_api4, import_client_cloudformation4, TemplateParameters, ParameterValues;
var init_cfn_api = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/deployments/cfn-api.ts"() {
    "use strict";
    import_node_crypto5 = require("node:crypto");
    import_node_util = require("node:util");
    import_cdk_assets_lib3 = __toESM(require_lib5());
    cxapi2 = __toESM(require_lib3());
    import_cloud_assembly_api4 = __toESM(require_lib3());
    import_client_cloudformation4 = __toESM(require_dist_cjs140());
    init_asset_manifest_builder();
    init_toolkit_error();
    init_cloudformation();
    init_cloudformation2();
    init_diagnosis_formatting();
    init_stack_diagnoser();
    init_stack_source_tracing();
    __name(describeChangeSet, "describeChangeSet");
    __name(waitFor, "waitFor");
    __name(waitForChangeSetReport, "waitForChangeSetReport");
    __name(waitForChangeSet, "waitForChangeSet");
    __name(waitForChangeSetGone, "waitForChangeSetGone");
    __name(createDiffChangeSet, "createDiffChangeSet");
    __name(templatesFromAssetManifestArtifact, "templatesFromAssetManifestArtifact");
    __name(prepareChangeSetEnv, "prepareChangeSetEnv");
    __name(uploadBodyParameterAndCreateChangeSet, "uploadBodyParameterAndCreateChangeSet");
    __name(uploadStackTemplateAssets, "uploadStackTemplateAssets");
    __name(createChangeSetAndCleanup, "createChangeSetAndCleanup");
    __name(createValidationChangeSet, "createValidationChangeSet");
    __name(toCfnTags, "toCfnTags");
    __name(cleanupOldChangeset, "cleanupOldChangeset");
    __name(waitForStackDelete, "waitForStackDelete");
    __name(waitForStackDeploy, "waitForStackDeploy");
    __name(stabilizeStack, "stabilizeStack");
    TemplateParameters = class _TemplateParameters {
      constructor(params) {
        this.params = params;
      }
      params;
      static {
        __name(this, "TemplateParameters");
      }
      static fromTemplate(template) {
        return new _TemplateParameters(template.Parameters || {});
      }
      /**
       * Calculate stack parameters to pass from the given desired parameter values
       *
       * Will throw if parameters without a Default value or a Previous value are not
       * supplied.
       */
      supplyAll(updates) {
        return new ParameterValues(this.params, updates);
      }
      /**
       * From the template, the given desired values and the current values, calculate the changes to the stack parameters
       *
       * Will take into account parameters already set on the template (will emit
       * 'UsePreviousValue: true' for those unless the value is changed), and will
       * throw if parameters without a Default value or a Previous value are not
       * supplied.
       */
      updateExisting(updates, previousValues) {
        return new ParameterValues(this.params, updates, previousValues);
      }
    };
    ParameterValues = class {
      constructor(formalParams, updates, previousValues = {}) {
        this.formalParams = formalParams;
        const missingRequired = new Array();
        for (const [key, formalParam] of Object.entries(this.formalParams)) {
          const updatedValue = updates[key];
          if (updatedValue !== void 0) {
            this.values[key] = updatedValue;
            this.apiParameters.push({
              ParameterKey: key,
              ParameterValue: updates[key]
            });
            continue;
          }
          if (key in previousValues) {
            this.values[key] = previousValues[key];
            this.apiParameters.push({ ParameterKey: key, UsePreviousValue: true });
            continue;
          }
          if (formalParam.Default !== void 0) {
            this.values[key] = formalParam.Default;
            continue;
          }
          missingRequired.push(key);
        }
        if (missingRequired.length > 0) {
          throw new ToolkitError("MissingParameters", `The following CloudFormation Parameters are missing a value: ${missingRequired.join(", ")}`);
        }
        const unknownParam = /* @__PURE__ */ __name(([key, _]) => this.formalParams[key] === void 0, "unknownParam");
        const hasValue = /* @__PURE__ */ __name(([_, value]) => !!value, "hasValue");
        for (const [key, value] of Object.entries(updates).filter(unknownParam).filter(hasValue)) {
          this.values[key] = value;
          this.apiParameters.push({ ParameterKey: key, ParameterValue: value });
        }
      }
      formalParams;
      static {
        __name(this, "ParameterValues");
      }
      values = {};
      apiParameters = [];
      /**
       * Whether this set of parameter updates will change the actual stack values
       */
      hasChanges(currentValues) {
        if (Object.values(this.formalParams).some(
          (p10) => p10.Type.startsWith("AWS::SSM::Parameter::") && !p10.Description?.includes(import_cloud_assembly_api4.SSMPARAM_NO_INVALIDATE)
        )) {
          return "ssm";
        }
        if (Object.entries(currentValues).some(([key, value]) => !(key in this.values) || value !== this.values[key])) {
          return true;
        }
        if (Object.keys(this.values).some((key) => !(key in currentValues))) {
          return true;
        }
        return false;
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/deployments/checks.ts
async function determineAllowCrossAccountAssetPublishing(sdk, ioHelper, customStackName) {
  try {
    const stackName = customStackName || "CDKToolkit";
    const stackInfo = await getBootstrapStackInfo(sdk, stackName);
    if (!stackInfo.hasStagingBucket) {
      return true;
    }
    if (stackInfo.bootstrapVersion >= 21) {
      return true;
    }
    return false;
  } catch (e32) {
    await ioHelper.defaults.debug(`Error determining cross account asset publishing: ${e32}`);
    await ioHelper.defaults.debug("Defaulting to allowing cross account asset publishing");
    return true;
  }
}
async function getBootstrapStackInfo(sdk, stackName) {
  try {
    const cfn = sdk.cloudFormation();
    const stackResponse = await cfn.describeStacks({ StackName: stackName });
    if (!stackResponse.Stacks || stackResponse.Stacks.length === 0) {
      throw new ToolkitError("ToolkitStackNotFound", `Toolkit stack ${stackName} not found`);
    }
    const stack = stackResponse.Stacks[0];
    const versionOutput = stack.Outputs?.find((output) => output.OutputKey === "BootstrapVersion");
    if (!versionOutput?.OutputValue) {
      throw new ToolkitError("BootstrapVersionNotFound", `Unable to find BootstrapVersion output in the toolkit stack ${stackName}`);
    }
    const bootstrapVersion = parseInt(versionOutput.OutputValue);
    if (isNaN(bootstrapVersion)) {
      throw new ToolkitError("InvalidBootstrapVersion", `Invalid BootstrapVersion value: ${versionOutput.OutputValue}`);
    }
    const bucketName = stack.Outputs?.find((output) => output.OutputKey === "BucketName")?.OutputValue;
    const hasStagingBucket = !!(bucketName && bucketName.match(/^[a-z0-9]/) && bucketName.match(/[a-z0-9]$/));
    return {
      hasStagingBucket,
      bootstrapVersion
    };
  } catch (e32) {
    throw new ToolkitError("ToolkitStackInfoError", `Error retrieving toolkit stack info: ${e32}`);
  }
}
var init_checks = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/deployments/checks.ts"() {
    "use strict";
    init_toolkit_error();
    __name(determineAllowCrossAccountAssetPublishing, "determineAllowCrossAccountAssetPublishing");
    __name(getBootstrapStackInfo, "getBootstrapStackInfo");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/deployments/assets.ts
async function addMetadataAssetsToManifest(ioHelper, stack, assetManifest, envResources, reuse) {
  reuse = reuse || [];
  const assets = stack.assets;
  if (assets.length === 0) {
    return {};
  }
  const toolkitInfo = await envResources.lookupToolkit();
  if (!toolkitInfo.found) {
    throw new ToolkitError("BootstrapStackRequired", `This stack uses assets, so the toolkit stack must be deployed to the environment (Run "${chalk2.blue("cdk bootstrap " + stack.environment.name)}")`);
  }
  const params = {};
  for (const asset of assets) {
    const reuseAsset = reuse.indexOf(asset.id) > -1;
    if (reuseAsset) {
      await ioHelper.defaults.debug(`Reusing asset ${asset.id}: ${JSON.stringify(asset)}`);
      continue;
    }
    await ioHelper.defaults.debug(`Preparing asset ${asset.id}: ${JSON.stringify(asset)}`);
    if (!stack.assembly) {
      throw new ToolkitError("AssemblyRequired", "Unexpected: stack assembly is required in order to find assets in assembly directory");
    }
    Object.assign(params, await prepareAsset(ioHelper, asset, assetManifest, envResources, toolkitInfo));
  }
  return params;
}
async function prepareAsset(ioHelper, asset, assetManifest, envResources, toolkitInfo) {
  switch (asset.packaging) {
    case "zip":
    case "file":
      return prepareFileAsset(
        ioHelper,
        asset,
        assetManifest,
        toolkitInfo,
        asset.packaging === "zip" ? cxschema8.FileAssetPackaging.ZIP_DIRECTORY : cxschema8.FileAssetPackaging.FILE
      );
    case "container-image":
      return prepareDockerImageAsset(asset, assetManifest, envResources);
    default:
      throw new ToolkitError("UnsupportedPackaging", `Unsupported packaging type: ${asset.packaging}. You might need to upgrade your aws-cdk toolkit to support this asset type.`);
  }
}
async function prepareFileAsset(ioHelper, asset, assetManifest, toolkitInfo, packaging) {
  const extension = packaging === cxschema8.FileAssetPackaging.ZIP_DIRECTORY ? ".zip" : path17.extname(asset.path);
  const baseName = `${asset.sourceHash}${extension}`;
  const s3Prefix = asset.id === asset.sourceHash ? "assets/" : `assets/${asset.id}/`;
  const key = `${s3Prefix}${baseName}`;
  const s3url = `s3://${toolkitInfo.bucketName}/${key}`;
  await ioHelper.defaults.debug(`Storing asset ${asset.path} at ${s3url}`);
  assetManifest.addFileAsset(asset.sourceHash, {
    path: asset.path,
    packaging
  }, {
    bucketName: toolkitInfo.bucketName,
    objectKey: key
  });
  return {
    [asset.s3BucketParameter]: toolkitInfo.bucketName,
    [asset.s3KeyParameter]: `${s3Prefix}${cxapi3.ASSET_PREFIX_SEPARATOR}${baseName}`,
    [asset.artifactHashParameter]: asset.sourceHash
  };
}
async function prepareDockerImageAsset(asset, assetManifest, envResources) {
  if (!asset.imageNameParameter && (!asset.repositoryName || !asset.imageTag)) {
    throw new ToolkitError("InvalidDockerAssetConfig", 'Invalid Docker image asset configuration: "repositoryName" and "imageTag" are required when "imageNameParameter" is left out');
  }
  const repositoryName = asset.repositoryName ?? "cdk/" + asset.id.replace(/[:/]/g, "-").toLowerCase();
  const { repositoryUri: repositoryUri2 } = await envResources.prepareEcrRepository(repositoryName);
  const imageTag = asset.imageTag ?? asset.sourceHash;
  assetManifest.addDockerImageAsset(asset.sourceHash, {
    directory: asset.path,
    dockerBuildArgs: asset.buildArgs,
    dockerBuildSecrets: asset.buildSecrets,
    dockerBuildSsh: asset.buildSsh,
    dockerBuildTarget: asset.target,
    dockerFile: asset.file,
    networkMode: asset.networkMode,
    platform: asset.platform,
    dockerOutputs: asset.outputs
  }, {
    repositoryName,
    imageTag
  });
  if (!asset.imageNameParameter) {
    return {};
  }
  return { [asset.imageNameParameter]: `${repositoryUri2}:${imageTag}` };
}
var path17, cxapi3, cxschema8, chalk2;
var init_assets3 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/deployments/assets.ts"() {
    "use strict";
    path17 = __toESM(require("path"));
    cxapi3 = __toESM(require_lib3());
    cxschema8 = __toESM(require_lib2());
    chalk2 = __toESM(require_source());
    init_toolkit_error();
    __name(addMetadataAssetsToManifest, "addMetadataAssetsToManifest");
    __name(prepareAsset, "prepareAsset");
    __name(prepareFileAsset, "prepareFileAsset");
    __name(prepareDockerImageAsset, "prepareDockerImageAsset");
  }
});

// ../@aws-cdk/toolkit-lib/lib/actions/deploy/private/deployment-method.ts
function isChangeSetDeployment(method) {
  return method?.method === "change-set";
}
function isExecutingChangeSetDeployment(method) {
  return isChangeSetDeployment(method) && (method.execute ?? true);
}
function isNonExecutingChangeSetDeployment(method) {
  return isChangeSetDeployment(method) && method.execute === false;
}
function isExecuteChangeSetDeployment(method) {
  return method?.method === "execute-change-set";
}
function toExecuteChangeSetDeployment(method) {
  return {
    method: "execute-change-set",
    changeSetName: method.changeSetName ?? DEFAULT_DEPLOY_CHANGE_SET_NAME
  };
}
var DEFAULT_DEPLOY_CHANGE_SET_NAME;
var init_deployment_method = __esm({
  "../@aws-cdk/toolkit-lib/lib/actions/deploy/private/deployment-method.ts"() {
    "use strict";
    DEFAULT_DEPLOY_CHANGE_SET_NAME = "cdk-deploy-change-set";
    __name(isChangeSetDeployment, "isChangeSetDeployment");
    __name(isExecutingChangeSetDeployment, "isExecutingChangeSetDeployment");
    __name(isNonExecutingChangeSetDeployment, "isNonExecutingChangeSetDeployment");
    __name(isExecuteChangeSetDeployment, "isExecuteChangeSetDeployment");
    __name(toExecuteChangeSetDeployment, "toExecuteChangeSetDeployment");
  }
});

// ../@aws-cdk/toolkit-lib/lib/payloads/hotswap.ts
var NonHotswappableReason;
var init_hotswap = __esm({
  "../@aws-cdk/toolkit-lib/lib/payloads/hotswap.ts"() {
    "use strict";
    NonHotswappableReason = /* @__PURE__ */ ((NonHotswappableReason2) => {
      NonHotswappableReason2["TAGS"] = "tags";
      NonHotswappableReason2["PROPERTIES"] = "properties";
      NonHotswappableReason2["OUTPUT"] = "output";
      NonHotswappableReason2["DEPENDENCY_UNSUPPORTED"] = "dependency-unsupported";
      NonHotswappableReason2["RESOURCE_UNSUPPORTED"] = "resource-unsupported";
      NonHotswappableReason2["RESOURCE_CREATION"] = "resource-creation";
      NonHotswappableReason2["RESOURCE_DELETION"] = "resource-deletion";
      NonHotswappableReason2["RESOURCE_TYPE_CHANGED"] = "resource-type-changed";
      NonHotswappableReason2["NESTED_STACK_CREATION"] = "nested-stack-creation";
      return NonHotswappableReason2;
    })(NonHotswappableReason || {});
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/hotswap/common.ts
function createHotswapPropertyOverrides(props) {
  return new HotswapPropertyOverrides(new EcsHotswapProperties(
    props.ecs?.minimumHealthyPercent,
    props.ecs?.maximumHealthyPercent,
    props.ecs?.stabilizationTimeoutSeconds
  ));
}
function classifyChanges(xs, hotswappablePropNames) {
  const hotswappableProps = {};
  const nonHotswappableProps = {};
  for (const [name, propDiff] of Object.entries(xs.propertyUpdates)) {
    if (hotswappablePropNames.includes(name)) {
      hotswappableProps[name] = propDiff;
    } else {
      nonHotswappableProps[name] = propDiff;
    }
  }
  return new ClassifiedChanges(xs, hotswappableProps, nonHotswappableProps);
}
function nonHotswappableChange(change, reason, description, nonHotswappableProps, hotswapOnlyVisible = true) {
  return {
    hotswappable: false,
    hotswapOnlyVisible,
    change: {
      reason,
      description,
      subject: {
        type: "Resource",
        logicalId: change.logicalId,
        resourceType: change.newValue.Type,
        rejectedProperties: Object.keys(nonHotswappableProps ?? change.propertyUpdates),
        metadata: change.metadata
      }
    }
  };
}
function nonHotswappableResource(change) {
  return {
    hotswappable: false,
    change: {
      reason: "resource-unsupported" /* RESOURCE_UNSUPPORTED */,
      description: "This resource type is not supported for hotswap deployments",
      subject: {
        type: "Resource",
        logicalId: change.logicalId,
        resourceType: change.newValue.Type,
        rejectedProperties: Object.keys(change.propertyUpdates),
        metadata: change.metadata
      }
    }
  };
}
var ICON, HotswapPropertyOverrides, EcsHotswapProperties, ClassifiedChanges;
var init_common9 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/hotswap/common.ts"() {
    "use strict";
    init_hotswap();
    init_toolkit_error();
    ICON = "\u2728";
    HotswapPropertyOverrides = class {
      static {
        __name(this, "HotswapPropertyOverrides");
      }
      // Each supported resource type will have its own properties. Currently this is ECS
      ecs;
      constructor(ecs) {
        this.ecs = ecs;
      }
    };
    EcsHotswapProperties = class {
      static {
        __name(this, "EcsHotswapProperties");
      }
      // The lower limit on the number of your service's tasks that must remain in the RUNNING state during a deployment, as a percentage of the desiredCount
      minimumHealthyPercent;
      // The upper limit on the number of your service's tasks that are allowed in the RUNNING or PENDING state during a deployment, as a percentage of the desiredCount
      maximumHealthyPercent;
      // The number of seconds to wait for a single service to reach stable state.
      stabilizationTimeoutSeconds;
      constructor(minimumHealthyPercent, maximumHealthyPercent, stabilizationTimeoutSeconds) {
        if (minimumHealthyPercent !== void 0 && minimumHealthyPercent < 0) {
          throw new ToolkitError("InvalidEcsMinHealthyPercent", "hotswap-ecs-minimum-healthy-percent can't be a negative number");
        }
        if (maximumHealthyPercent !== void 0 && maximumHealthyPercent < 0) {
          throw new ToolkitError("InvalidEcsMaxHealthyPercent", "hotswap-ecs-maximum-healthy-percent can't be a negative number");
        }
        if (stabilizationTimeoutSeconds !== void 0 && stabilizationTimeoutSeconds < 0) {
          throw new ToolkitError("InvalidEcsStabilizationTimeout", "hotswap-ecs-stabilization-timeout-seconds can't be a negative number");
        }
        if (minimumHealthyPercent == void 0) {
          this.minimumHealthyPercent = 0;
        } else {
          this.minimumHealthyPercent = minimumHealthyPercent;
        }
        this.maximumHealthyPercent = maximumHealthyPercent;
        this.stabilizationTimeoutSeconds = stabilizationTimeoutSeconds;
      }
      /**
       * Check if any hotswap properties are defined
       * @returns true if all properties are undefined, false otherwise
       */
      isEmpty() {
        return this.minimumHealthyPercent === 0 && this.maximumHealthyPercent === void 0;
      }
    };
    __name(createHotswapPropertyOverrides, "createHotswapPropertyOverrides");
    ClassifiedChanges = class {
      constructor(change, hotswappableProps, nonHotswappableProps) {
        this.change = change;
        this.hotswappableProps = hotswappableProps;
        this.nonHotswappableProps = nonHotswappableProps;
      }
      change;
      hotswappableProps;
      nonHotswappableProps;
      static {
        __name(this, "ClassifiedChanges");
      }
      reportNonHotswappablePropertyChanges(ret) {
        const nonHotswappablePropNames = Object.keys(this.nonHotswappableProps);
        if (nonHotswappablePropNames.length > 0) {
          const tagOnlyChange = nonHotswappablePropNames.length === 1 && nonHotswappablePropNames[0] === "Tags";
          const reason = tagOnlyChange ? "tags" /* TAGS */ : "properties" /* PROPERTIES */;
          const description = tagOnlyChange ? "Tags are not hotswappable" : `resource properties '${nonHotswappablePropNames}' are not hotswappable on this resource type`;
          ret.push(nonHotswappableChange(
            this.change,
            reason,
            description,
            this.nonHotswappableProps
          ));
        }
      }
      get namesOfHotswappableProps() {
        return Object.keys(this.hotswappableProps);
      }
    };
    __name(classifyChanges, "classifyChanges");
    __name(nonHotswappableChange, "nonHotswappableChange");
    __name(nonHotswappableResource, "nonHotswappableResource");
  }
});

// ../../node_modules/@cdklabs/tskb/lib/sorted-map.js
var require_sorted_map = __commonJS({
  "../../node_modules/@cdklabs/tskb/lib/sorted-map.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.sortedMap = void 0;
    var sortedMap;
    (function(sortedMap2) {
      function add(map5, cmp, key, value) {
        const i32 = lowerBound(map5, cmp, key);
        map5.splice(i32, 0, [key, value]);
      }
      __name(add, "add");
      sortedMap2.add = add;
      function find(map5, cmp, key) {
        const i32 = lowerBound(map5, cmp, key);
        if (i32 === map5.length) {
          return void 0;
        }
        const [foundKey, value] = map5[i32];
        return cmp(foundKey, key) === 0 ? value : void 0;
      }
      __name(find, "find");
      sortedMap2.find = find;
      function findAll(map5, cmp, key) {
        let i32 = lowerBound(map5, cmp, key);
        const ret = [];
        while (i32 < map5.length && cmp(map5[i32][0], key) === 0) {
          ret.push(map5[i32][1]);
          i32 += 1;
        }
        return ret;
      }
      __name(findAll, "findAll");
      sortedMap2.findAll = findAll;
      function lowerBound(map5, cmp, key) {
        let first = 0;
        let count = map5.length;
        while (count > 0) {
          let it = first;
          let step = Math.floor(count / 2);
          it += step;
          if (cmp(map5[it][0], key) < 0) {
            first = ++it;
            count -= step + 1;
          } else {
            count = step;
          }
        }
        return first;
      }
      __name(lowerBound, "lowerBound");
    })(sortedMap = exports2.sortedMap || (exports2.sortedMap = {}));
  }
});

// ../../node_modules/@cdklabs/tskb/lib/entity.js
var require_entity = __commonJS({
  "../../node_modules/@cdklabs/tskb/lib/entity.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.optionalCmp = exports2.numberCmp = exports2.stringCmp = exports2.ref = exports2.isEntityCollection = exports2.calculatedIndex = exports2.fieldIndex = exports2.entityCollection = void 0;
    var sorted_map_1 = require_sorted_map();
    function entityCollection() {
      const entities = /* @__PURE__ */ new Map();
      const _indexes = {};
      function add(x) {
        entities.set(x.$id, x);
        for (const index of Object.values(_indexes)) {
          index.add(x);
        }
      }
      __name(add, "add");
      return {
        type: "entities",
        entities,
        indexes: _indexes,
        add,
        dehydrate: /* @__PURE__ */ __name(() => ({
          type: "entities",
          entities: Array.from(validatePlainObjects(entities).values())
        }), "dehydrate"),
        hydrateFrom: /* @__PURE__ */ __name((x) => {
          entities.clear();
          for (const e32 of Object.values(x.entities)) {
            add(e32);
          }
        }, "hydrateFrom"),
        index(indexes) {
          if (Object.keys(_indexes).length > 0) {
            throw new Error("You may only call .index() once on a new collection");
          }
          Object.assign(_indexes, indexes);
          return this;
        }
      };
    }
    __name(entityCollection, "entityCollection");
    exports2.entityCollection = entityCollection;
    function fieldIndex(propName, comparator) {
      return calculatedIndex((x) => x[propName], comparator);
    }
    __name(fieldIndex, "fieldIndex");
    exports2.fieldIndex = fieldIndex;
    function calculatedIndex(fn, comparator) {
      const index = [];
      return {
        add: /* @__PURE__ */ __name((x) => sorted_map_1.sortedMap.add(index, comparator, fn(x), x.$id), "add"),
        lookups: {
          equals: /* @__PURE__ */ __name((value) => sorted_map_1.sortedMap.findAll(index, comparator, value), "equals")
        },
        index
      };
    }
    __name(calculatedIndex, "calculatedIndex");
    exports2.calculatedIndex = calculatedIndex;
    function isEntityCollection(x) {
      return typeof x === "object" && !!x && x.type === "entities";
    }
    __name(isEntityCollection, "isEntityCollection");
    exports2.isEntityCollection = isEntityCollection;
    function validatePlainObjects(xs) {
      for (const x of xs.values()) {
        if (x.constructor !== Object) {
          throw new Error(`Entities should be plain-text objects, got instance of ${x.constructor}`);
        }
      }
      return xs;
    }
    __name(validatePlainObjects, "validatePlainObjects");
    function ref(x) {
      return typeof x === "string" ? { $ref: x } : { $ref: x.$id };
    }
    __name(ref, "ref");
    exports2.ref = ref;
    function stringCmp(a32, b32) {
      return a32.localeCompare(b32);
    }
    __name(stringCmp, "stringCmp");
    exports2.stringCmp = stringCmp;
    function numberCmp(a32, b32) {
      return a32 - b32;
    }
    __name(numberCmp, "numberCmp");
    exports2.numberCmp = numberCmp;
    function optionalCmp(cmp, frontOrder = true) {
      return (a32, b32) => {
        if (a32 == void 0 && b32 != void 0) {
          return frontOrder ? -1 : 1;
        }
        if (a32 != void 0 && b32 == void 0) {
          return frontOrder ? 1 : -1;
        }
        if (a32 == void 0 && b32 == void 0) {
          return 0;
        }
        return cmp(a32, b32);
      };
    }
    __name(optionalCmp, "optionalCmp");
    exports2.optionalCmp = optionalCmp;
  }
});

// ../../node_modules/@cdklabs/tskb/lib/relationship.js
var require_relationship = __commonJS({
  "../../node_modules/@cdklabs/tskb/lib/relationship.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isRelationshipCollection = exports2.relationshipCollection = exports2.NO_RELATIONSHIPS = void 0;
    var NO_RELATIONSHIPS = /* @__PURE__ */ __name(() => ({}), "NO_RELATIONSHIPS");
    exports2.NO_RELATIONSHIPS = NO_RELATIONSHIPS;
    function relationshipCollection(fromField, toField) {
      const forward = /* @__PURE__ */ new Map();
      const backward = /* @__PURE__ */ new Map();
      function add(fromId, toId, attrs) {
        let f32 = forward.get(fromId);
        if (!f32) {
          f32 = [];
          forward.set(fromId, f32);
        }
        let b32 = backward.get(toId);
        if (!b32) {
          b32 = [];
          backward.set(toId, b32);
        }
        const forwardRel = { $id: toId, ...attrs };
        const forwardRelStr = JSON.stringify(forwardRel);
        const existingRelationship = f32.find((x) => JSON.stringify(x) === forwardRelStr);
        if (!existingRelationship) {
          f32.push(forwardRel);
          b32.push({ $id: fromId, ...attrs });
        }
      }
      __name(add, "add");
      return {
        type: "rel",
        fromColl: fromField,
        toColl: toField,
        forward,
        backward,
        add(from, to, attributes) {
          add(from.$id, to.$id, attributes);
        },
        dehydrate() {
          return {
            type: "rel",
            forward: Object.fromEntries(forward.entries())
          };
        },
        hydrateFrom(x) {
          forward.clear();
          backward.clear();
          for (const [fromId, targets] of Object.entries(x.forward)) {
            for (const target of targets) {
              add(fromId, target.$id, removeId(target));
            }
          }
        }
      };
    }
    __name(relationshipCollection, "relationshipCollection");
    exports2.relationshipCollection = relationshipCollection;
    function isRelationshipCollection(x) {
      return typeof x === "object" && !!x && x.type === "rel";
    }
    __name(isRelationshipCollection, "isRelationshipCollection");
    exports2.isRelationshipCollection = isRelationshipCollection;
    function removeId(x) {
      const ret = { ...x };
      delete ret.$id;
      return ret;
    }
    __name(removeId, "removeId");
  }
});

// ../../node_modules/@cdklabs/tskb/lib/database.js
var require_database = __commonJS({
  "../../node_modules/@cdklabs/tskb/lib/database.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.Database = void 0;
    var entity_1 = require_entity();
    var relationship_1 = require_relationship();
    var Database = class _Database {
      static {
        __name(this, "Database");
      }
      static entitiesOnly(entities) {
        return new _Database(entities, relationship_1.NO_RELATIONSHIPS);
      }
      constructor(entities, relationships) {
        this.idCtr = 0;
        this.schema = {
          ...entities,
          ...relationships({
            relationship: /* @__PURE__ */ __name((fromKey, toKey) => (0, relationship_1.relationshipCollection)((id) => this.get(fromKey, id), (id) => this.get(toKey, id)), "relationship")
          })
        };
      }
      id() {
        return `${this.idCtr++}`;
      }
      /**
       * Allocate an ID and store
       */
      allocate(key, entity) {
        return this.store(key, this.e(entity));
      }
      /**
       * Store with a preallocated ID
       */
      store(key, entity) {
        const coll = this.schema[key];
        coll.add(entity);
        return entity;
      }
      /**
       * Get an entity by key
       */
      get(key, id) {
        const coll = this.schema[key];
        const ret = coll.entities.get(typeof id === "string" ? id : id.$ref);
        if (!ret) {
          throw new Error(`No such ${String(key)}: ${id}`);
        }
        return ret;
      }
      /**
       * All entities of a given type
       */
      all(key) {
        const coll = this.schema[key];
        return Array.from(coll.entities.values());
      }
      /**
       * Lookup an entity by index
       */
      lookup(key, index, lookup, value) {
        const coll = this.schema[key];
        const ids = coll.indexes[index].lookups[lookup](value);
        return addOnlyMethod(ids.map((id) => coll.entities.get(id)), `${String(key)} with ${String(index)} ${String(lookup)} ${JSON.stringify(value)}`);
      }
      /**
       * Allocate an ID and store if the entity does not yet exist
       */
      findOrAllocate(key, index, lookup, entity) {
        const res = this.lookup(key, index, lookup, entity[index]);
        if (res.length) {
          return res.only();
        }
        return this.allocate(key, entity);
      }
      link(key, from, to, attributes) {
        const col = this.schema[key];
        col.add(from, to, attributes);
      }
      /**
       * Follow a link
       */
      follow(key, from) {
        const col = this.schema[key];
        const toLinks = col.forward.get(from.$id) ?? [];
        const ret = toLinks.map((i32) => ({ entity: col.toColl(i32.$id), ...removeId(i32) }));
        return addOnlyMethod(ret, `${String(key)} from ${from}`);
      }
      /**
       * Follow incoming links backwards
       */
      incoming(key, to) {
        const col = this.schema[key];
        const fromIds = col.backward.get(to.$id) ?? [];
        const ret = fromIds.map((i32) => ({ entity: col.fromColl(i32.$id), ...removeId(i32) }));
        return addOnlyMethod(ret, `${String(key)} to ${to}`);
      }
      e(entity) {
        return {
          $id: this.id(),
          ...entity
        };
      }
      /**
       * Turn the current database collection into something that can be stored.
       */
      save() {
        return {
          idCtr: this.idCtr,
          schema: dehydrate(this.schema)
        };
        function dehydrate(x) {
          if ((0, entity_1.isEntityCollection)(x)) {
            return x.dehydrate();
          }
          if ((0, relationship_1.isRelationshipCollection)(x)) {
            return x.dehydrate();
          }
          if (Array.isArray(x)) {
            return x.map(dehydrate);
          }
          if (!!x && typeof x === "object") {
            return Object.fromEntries(Object.entries(x).map(([k32, v]) => [k32, dehydrate(v)]));
          }
          return x;
        }
        __name(dehydrate, "dehydrate");
      }
      load(db) {
        this.idCtr = db.idCtr;
        hydrate(this.schema, db.schema);
        function hydrate(proto, x) {
          if ((0, entity_1.isEntityCollection)(proto)) {
            proto.hydrateFrom(x);
          }
          if ((0, relationship_1.isRelationshipCollection)(proto)) {
            proto.hydrateFrom(x);
          }
          if (Array.isArray(x)) {
            x.forEach(hydrate);
          }
          if (!!proto && typeof proto === "object" && !!x && typeof x === "object") {
            for (const [k32, v] of Object.entries(proto)) {
              const dehydratedData = x[k32];
              if (dehydratedData !== void 0) {
                hydrate(v, dehydratedData);
              }
            }
          }
        }
        __name(hydrate, "hydrate");
      }
    };
    exports2.Database = Database;
    function removeId(x) {
      const ret = { ...x };
      delete ret.$id;
      return ret;
    }
    __name(removeId, "removeId");
    function addOnlyMethod(xs, description) {
      return Object.defineProperties(xs, {
        only: {
          enumerable: false,
          value: /* @__PURE__ */ __name(() => {
            if (xs.length !== 1) {
              throw new Error(`Expected exactly 1 ${description}, found ${xs.length}`);
            }
            return xs[0];
          }, "value")
        }
      });
    }
    __name(addOnlyMethod, "addOnlyMethod");
  }
});

// ../../node_modules/@cdklabs/tskb/lib/invariant.js
var require_invariant = __commonJS({
  "../../node_modules/@cdklabs/tskb/lib/invariant.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.impliesU = exports2.implies = exports2.evolutionInvariant = void 0;
    function evolutionInvariant(description, pred) {
      Array.isArray(description);
      Array.isArray(pred);
    }
    __name(evolutionInvariant, "evolutionInvariant");
    exports2.evolutionInvariant = evolutionInvariant;
    function implies(x, y) {
      return !x || y;
    }
    __name(implies, "implies");
    exports2.implies = implies;
    function impliesU(x, y) {
      return !x || !!y;
    }
    __name(impliesU, "impliesU");
    exports2.impliesU = impliesU;
  }
});

// ../../node_modules/@cdklabs/tskb/lib/result.js
var require_result = __commonJS({
  "../../node_modules/@cdklabs/tskb/lib/result.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.liftUndefined = exports2.liftResult = exports2.locateFailure = exports2.chain = exports2.using = exports2.tryCatch = exports2.assertSuccess = exports2.errorFrom = exports2.errorMessage = exports2.unpackOr = exports2.unpack = exports2.isSuccess = exports2.isFailure = exports2.failure = void 0;
    var errorSym = /* @__PURE__ */ Symbol("error");
    function mkLocate(prefix) {
      const ret = /* @__PURE__ */ __name((error4) => failure(`${prefix}: ${error4}`), "ret");
      ret.in = (prefix2) => mkLocate(`${prefix}: ${prefix2}`);
      ret.locate = locateFailure(prefix);
      return ret;
    }
    __name(mkLocate, "mkLocate");
    function failure(error4) {
      return { [errorSym]: error4 };
    }
    __name(failure, "failure");
    exports2.failure = failure;
    failure.in = (prefix) => mkLocate(prefix);
    failure.locate = (x) => x;
    function isFailure(x) {
      return !!x && typeof x === "object" && x[errorSym];
    }
    __name(isFailure, "isFailure");
    exports2.isFailure = isFailure;
    function isSuccess(x) {
      return !isFailure(x);
    }
    __name(isSuccess, "isSuccess");
    exports2.isSuccess = isSuccess;
    function unpack(x) {
      if (isFailure(x)) {
        throw new Error(`unpack: ${x[errorSym]}`);
      }
      return x;
    }
    __name(unpack, "unpack");
    exports2.unpack = unpack;
    function unpackOr(x, def) {
      return isFailure(x) ? def : x;
    }
    __name(unpackOr, "unpackOr");
    exports2.unpackOr = unpackOr;
    function errorMessage(x) {
      return x[errorSym];
    }
    __name(errorMessage, "errorMessage");
    exports2.errorMessage = errorMessage;
    function errorFrom(x) {
      return new Error(errorMessage(x));
    }
    __name(errorFrom, "errorFrom");
    exports2.errorFrom = errorFrom;
    function assertSuccess(x) {
      if (isFailure(x)) {
        throw errorFrom(x);
      }
    }
    __name(assertSuccess, "assertSuccess");
    exports2.assertSuccess = assertSuccess;
    function tryCatch(failOrBlock, maybeBlock) {
      const block = maybeBlock ?? failOrBlock;
      const f32 = maybeBlock ? failOrBlock : failure;
      try {
        return block();
      } catch (e32) {
        return f32(`Error: ${e32.message}
${e32.stack}`);
      }
    }
    __name(tryCatch, "tryCatch");
    exports2.tryCatch = tryCatch;
    function using(value, block) {
      if (isFailure(value)) {
        return value;
      }
      return block(value);
    }
    __name(using, "using");
    exports2.using = using;
    function chain5(value, ...fns) {
      for (const fn of fns) {
        if (isFailure(value)) {
          return value;
        }
        value = fn(value);
      }
      return value;
    }
    __name(chain5, "chain");
    exports2.chain = chain5;
    function locateFailure(prefix) {
      return (x) => isFailure(x) ? failure(`${prefix}: ${x[errorSym]}`) : x;
    }
    __name(locateFailure, "locateFailure");
    exports2.locateFailure = locateFailure;
    function liftResult(xs) {
      const failures = Array.isArray(xs) ? xs.filter(isFailure) : Object.values(xs).filter(isFailure);
      if (failures.length > 0) {
        return failure(failures.map(errorMessage).join(", "));
      }
      return xs;
    }
    __name(liftResult, "liftResult");
    exports2.liftResult = liftResult;
    function liftUndefined(valueOrFunction) {
      if (typeof valueOrFunction === "function") {
        return (...args) => {
          const value = valueOrFunction(...args);
          return value !== void 0 ? value : failure("value is undefined");
        };
      }
      return valueOrFunction !== void 0 ? valueOrFunction : failure("value is undefined");
    }
    __name(liftUndefined, "liftUndefined");
    exports2.liftUndefined = liftUndefined;
  }
});

// ../../node_modules/@cdklabs/tskb/lib/index.js
var require_lib6 = __commonJS({
  "../../node_modules/@cdklabs/tskb/lib/index.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __exportStar3 = exports2 && exports2.__exportStar || function(m20, exports3) {
      for (var p10 in m20) if (p10 !== "default" && !Object.prototype.hasOwnProperty.call(exports3, p10)) __createBinding3(exports3, m20, p10);
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    __exportStar3(require_entity(), exports2);
    __exportStar3(require_relationship(), exports2);
    __exportStar3(require_database(), exports2);
    __exportStar3(require_invariant(), exports2);
    __exportStar3(require_result(), exports2);
  }
});

// ../../node_modules/@aws-cdk/service-spec-types/lib/types/database.js
var require_database2 = __commonJS({
  "../../node_modules/@aws-cdk/service-spec-types/lib/types/database.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.RichSpecDatabase = void 0;
    exports2.emptyDatabase = emptyDatabase;
    exports2.loadDatabase = loadDatabase;
    var fs_1 = require("fs");
    var zlib_1 = require("zlib");
    var tskb_1 = require_lib6();
    function emptyDatabase() {
      return new tskb_1.Database({
        resource: (0, tskb_1.entityCollection)().index({
          cloudFormationType: (0, tskb_1.fieldIndex)("cloudFormationType", tskb_1.stringCmp)
        }),
        region: (0, tskb_1.entityCollection)().index({
          name: (0, tskb_1.fieldIndex)("name", tskb_1.stringCmp)
        }),
        service: (0, tskb_1.entityCollection)().index({
          name: (0, tskb_1.fieldIndex)("name", tskb_1.stringCmp),
          cloudFormationNamespace: (0, tskb_1.fieldIndex)("cloudFormationNamespace", tskb_1.stringCmp)
        }),
        eventTypeDefinition: (0, tskb_1.entityCollection)(),
        typeDefinition: (0, tskb_1.entityCollection)(),
        augmentations: (0, tskb_1.entityCollection)(),
        metric: (0, tskb_1.entityCollection)().index({
          name: (0, tskb_1.fieldIndex)("name", tskb_1.stringCmp),
          namespace: (0, tskb_1.fieldIndex)("namespace", tskb_1.stringCmp),
          dedupKey: (0, tskb_1.fieldIndex)("dedupKey", tskb_1.stringCmp)
        }),
        dimensionSet: (0, tskb_1.entityCollection)().index({
          dedupKey: (0, tskb_1.fieldIndex)("dedupKey", tskb_1.stringCmp)
        }),
        event: (0, tskb_1.entityCollection)().index({
          name: (0, tskb_1.fieldIndex)("name", tskb_1.stringCmp)
        })
      }, (r32) => ({
        hasResource: r32.relationship("service", "resource"),
        regionHasResource: r32.relationship("region", "resource"),
        regionHasService: r32.relationship("region", "service"),
        usesType: r32.relationship("resource", "typeDefinition"),
        isAugmented: r32.relationship("resource", "augmentations"),
        usesDimensionSet: r32.relationship("metric", "dimensionSet"),
        resourceHasMetric: r32.relationship("resource", "metric"),
        serviceHasMetric: r32.relationship("service", "metric"),
        resourceHasDimensionSet: r32.relationship("resource", "dimensionSet"),
        serviceHasDimensionSet: r32.relationship("service", "dimensionSet"),
        resourceHasEvent: r32.relationship("resource", "event"),
        serviceHasEvent: r32.relationship("service", "event"),
        eventUsesType: r32.relationship("event", "eventTypeDefinition")
      }));
    }
    __name(emptyDatabase, "emptyDatabase");
    async function loadDatabase(pathToDb) {
      const db = emptyDatabase();
      const contents = await fs_1.promises.readFile(pathToDb);
      const json = pathToDb.endsWith(".gz") ? (0, zlib_1.gunzipSync)(contents).toString("utf-8") : contents.toString("utf-8");
      db.load(JSON.parse(json));
      return db;
    }
    __name(loadDatabase, "loadDatabase");
    var RichSpecDatabase = class {
      static {
        __name(this, "RichSpecDatabase");
      }
      constructor(db) {
        this.db = db;
      }
      /**
       * Find all resources of a given type
       */
      resourceByType(cfnType, operation3 = "resourceByType") {
        const res = this.db.lookup("resource", "cloudFormationType", "equals", cfnType);
        if (res.length === 0) {
          throw new Error(`${operation3}: no such resource: ${cfnType}`);
        }
        return res[0];
      }
      /**
       * All type definitions used by a certain resource
       */
      resourceTypeDefs(cfnType) {
        const resource = this.db.lookup("resource", "cloudFormationType", "equals", cfnType).only();
        return this.db.follow("usesType", resource).map((x) => x.entity);
      }
      /**
       * Find a type definition from a given property type
       */
      tryFindDef(type) {
        return type.type === "ref" ? this.db.get("typeDefinition", type.reference.$ref) : void 0;
      }
    };
    exports2.RichSpecDatabase = RichSpecDatabase;
  }
});

// ../../node_modules/@aws-cdk/service-spec-types/lib/util/sorting.js
var require_sorting = __commonJS({
  "../../node_modules/@aws-cdk/service-spec-types/lib/util/sorting.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.sortKeyComparator = sortKeyComparator;
    function sortKeyComparator(keyFn) {
      return (a32, b32) => {
        const ak = keyFn(a32);
        const bk = keyFn(b32);
        for (let i32 = 0; i32 < ak.length && i32 < bk.length; i32++) {
          const av = ak[i32];
          const bv = bk[i32];
          let diff = 0;
          if (typeof av === "number" && typeof bv === "number") {
            diff = av - bv;
          } else if (typeof av === "string" && typeof bv === "string") {
            diff = av.localeCompare(bv);
          }
          if (diff !== 0) {
            return diff;
          }
        }
        return bk.length - ak.length;
      };
    }
    __name(sortKeyComparator, "sortKeyComparator");
  }
});

// ../../node_modules/@aws-cdk/service-spec-types/lib/types/resource.js
var require_resource = __commonJS({
  "../../node_modules/@aws-cdk/service-spec-types/lib/types/resource.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.RichPropertyType = exports2.PropertyScrutinyType = exports2.ResourceScrutinyType = exports2.Deprecation = exports2.RichAttribute = exports2.RichProperty = exports2.RichTypedField = void 0;
    exports2.isCollectionType = isCollectionType;
    var sorting_1 = require_sorting();
    var RichTypedField = class {
      static {
        __name(this, "RichTypedField");
      }
      constructor(field) {
        this.field = field;
        if (field === void 0) {
          throw new Error("Field is undefined");
        }
      }
      types() {
        return [...this.field.previousTypes ?? [], this.field.type];
      }
      /**
       * Update the type of this property with a new type
       *
       * Only if it's not in the set of types already.
       *
       * Returns true if the type was updated.
       */
      updateType(type) {
        const richType = new RichPropertyType(type);
        if (this.types().some((t) => richType.equals(t))) {
          if ((type.type === "string" || type.type === "integer") && type.allowedValues) {
            if (this.field.type.type === type.type) {
              this.field.type.allowedValues = type.allowedValues;
            }
          }
          return false;
        }
        if (type.type === "string" && this.types().some((t) => t.type === "date-time")) {
          return false;
        }
        if (type.type === "string" && this.field.type.type === "json") {
          this.field.type = type;
          return true;
        }
        if (!this.field.previousTypes) {
          this.field.previousTypes = [];
        }
        this.field.previousTypes.push(this.field.type);
        this.field.type = type;
        return true;
      }
    };
    exports2.RichTypedField = RichTypedField;
    var RichProperty = class extends RichTypedField {
      static {
        __name(this, "RichProperty");
      }
      constructor(property) {
        super(property);
      }
    };
    exports2.RichProperty = RichProperty;
    var RichAttribute = class extends RichTypedField {
      static {
        __name(this, "RichAttribute");
      }
      constructor(attr) {
        super(attr);
      }
    };
    exports2.RichAttribute = RichAttribute;
    var Deprecation;
    (function(Deprecation2) {
      Deprecation2["NONE"] = "NONE";
      Deprecation2["WARN"] = "WARN";
      Deprecation2["IGNORE"] = "IGNORE";
    })(Deprecation || (exports2.Deprecation = Deprecation = {}));
    function isCollectionType(x) {
      return x.type === "array" || x.type === "map";
    }
    __name(isCollectionType, "isCollectionType");
    var ResourceScrutinyType3;
    (function(ResourceScrutinyType4) {
      ResourceScrutinyType4["None"] = "None";
      ResourceScrutinyType4["ResourcePolicyResource"] = "ResourcePolicyResource";
      ResourceScrutinyType4["IdentityPolicyResource"] = "IdentityPolicyResource";
      ResourceScrutinyType4["LambdaPermission"] = "LambdaPermission";
      ResourceScrutinyType4["IngressRuleResource"] = "IngressRuleResource";
      ResourceScrutinyType4["EgressRuleResource"] = "EgressRuleResource";
      ResourceScrutinyType4["SsoAssignmentResource"] = "SsoAssignmentResource";
      ResourceScrutinyType4["SsoInstanceACAConfigResource"] = "SsoInstanceACAConfigResource";
      ResourceScrutinyType4["SsoPermissionSet"] = "SsoPermissionSet";
    })(ResourceScrutinyType3 || (exports2.ResourceScrutinyType = ResourceScrutinyType3 = {}));
    var PropertyScrutinyType3;
    (function(PropertyScrutinyType4) {
      PropertyScrutinyType4["None"] = "None";
      PropertyScrutinyType4["InlineResourcePolicy"] = "InlineResourcePolicy";
      PropertyScrutinyType4["InlineIdentityPolicies"] = "InlineIdentityPolicies";
      PropertyScrutinyType4["ManagedPolicies"] = "ManagedPolicies";
      PropertyScrutinyType4["IngressRules"] = "IngressRules";
      PropertyScrutinyType4["EgressRules"] = "EgressRules";
    })(PropertyScrutinyType3 || (exports2.PropertyScrutinyType = PropertyScrutinyType3 = {}));
    var RichPropertyType = class _RichPropertyType {
      static {
        __name(this, "RichPropertyType");
      }
      constructor(type) {
        this.type = type;
      }
      equals(rhs) {
        switch (this.type.type) {
          case "integer":
          case "boolean":
          case "date-time":
          case "json":
          case "null":
          case "number":
          case "string":
          case "tag":
            return rhs.type === this.type.type;
          case "array":
          case "map":
            return rhs.type === this.type.type && new _RichPropertyType(this.type.element).equals(rhs.element);
          case "ref":
            return rhs.type === "ref" && this.type.reference.$ref === rhs.reference.$ref;
          case "union":
            const lhsKey = this.sortKey();
            const rhsKey = new _RichPropertyType(rhs).sortKey();
            return lhsKey.length === rhsKey.length && lhsKey.every((l20, i32) => l20 === rhsKey[i32]);
        }
      }
      /**
       * Whether the current type is JavaScript-equal to the RHS type
       *
       * Same as normal equality, but consider `integer` and `number` the same types.
       */
      javascriptEquals(rhs) {
        switch (this.type.type) {
          case "number":
          case "integer":
            return rhs.type === "integer" || rhs.type === "number";
          case "array":
          case "map":
            return rhs.type === this.type.type && new _RichPropertyType(this.type.element).javascriptEquals(rhs.element);
          case "union":
            if (rhs.type !== "union") {
              return false;
            }
            return this.type.types.every((t1) => rhs.types.some((t2) => new _RichPropertyType(t1).javascriptEquals(t2)));
          default:
            return this.equals(rhs);
        }
      }
      /**
       * Whether the current type is assignable to the RHS type.
       *
       * This is means every type member of the LHS must be present in the RHS type
       */
      assignableTo(rhs) {
        const extractMembers = /* @__PURE__ */ __name((type) => type.type == "union" ? type.types : [type], "extractMembers");
        const asRichType = /* @__PURE__ */ __name((type) => new _RichPropertyType(type), "asRichType");
        const rhsMembers = extractMembers(rhs);
        for (const lhsMember of extractMembers(this.type).map(asRichType)) {
          if (!rhsMembers.some((type) => lhsMember.equals(type))) {
            return false;
          }
        }
        return true;
      }
      /**
       * Return a version of this type, but with all type unions in a regularized order
       */
      normalize(db) {
        switch (this.type.type) {
          case "array":
          case "map":
            return new _RichPropertyType({
              type: this.type.type,
              element: new _RichPropertyType(this.type.element).normalize(db).type
            });
          case "union":
            const types2 = this.type.types.map((t) => new _RichPropertyType(t).normalize(db)).map((t) => [t, t.sortKey(db)]);
            types2.sort((0, sorting_1.sortKeyComparator)(([_, sortKey]) => sortKey));
            return new _RichPropertyType({
              type: "union",
              types: types2.map(([t, _]) => t.type)
            });
          default:
            return this;
        }
      }
      stringify(db, withId = true) {
        switch (this.type.type) {
          case "string":
            return this.type.allowedValues ? `string<${this.type.allowedValues.join("|")}>` : "string";
          case "integer":
            return this.type.allowedValues ? `integer<${this.type.allowedValues.join("|")}>` : "integer";
          case "boolean":
          case "date-time":
          case "json":
          case "null":
          case "number":
          case "tag":
            return this.type.type;
          case "array":
            return `Array<${new _RichPropertyType(this.type.element).stringify(db, withId)}>`;
          case "map":
            return `Map<string, ${new _RichPropertyType(this.type.element).stringify(db, withId)}>`;
          case "ref":
            const type = db.get("typeDefinition", this.type.reference);
            return withId ? `${type.name}(${this.type.reference.$ref})` : type.name;
          case "union":
            return this.type.types.map((t) => new _RichPropertyType(t).stringify(db, withId)).join(" | ");
        }
      }
      /**
       * Return a sortable key based on this type
       *
       * If a database is given, type definitions will be sorted based on type name,
       * otherwise on identifier
       */
      sortKey(db) {
        switch (this.type.type) {
          case "integer":
          case "boolean":
          case "date-time":
          case "json":
          case "null":
          case "number":
          case "string":
          case "tag":
            return ["0", this.type.type];
          case "array":
          case "map":
            return ["1", this.type.type, ...new _RichPropertyType(this.type.element).sortKey(db)];
          case "ref":
            return ["2", this.type.type, db?.get("typeDefinition", this.type.reference)?.name ?? this.type.reference.$ref];
          case "union":
            const typeKeys = this.type.types.map((t) => new _RichPropertyType(t).sortKey(db));
            typeKeys.sort((0, sorting_1.sortKeyComparator)((x) => x));
            return ["3", this.type.type, ...typeKeys.flatMap((x) => x)];
        }
      }
    };
    exports2.RichPropertyType = RichPropertyType;
  }
});

// ../../node_modules/@aws-cdk/service-spec-types/lib/types/augmentations.js
var require_augmentations = __commonJS({
  "../../node_modules/@aws-cdk/service-spec-types/lib/types/augmentations.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
  }
});

// ../../node_modules/@aws-cdk/service-spec-types/lib/types/event.js
var require_event = __commonJS({
  "../../node_modules/@aws-cdk/service-spec-types/lib/types/event.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
  }
});

// ../../node_modules/@aws-cdk/service-spec-types/lib/types/metrics.js
var require_metrics = __commonJS({
  "../../node_modules/@aws-cdk/service-spec-types/lib/types/metrics.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
  }
});

// ../../node_modules/@aws-cdk/service-spec-types/lib/types/diff.js
var require_diff3 = __commonJS({
  "../../node_modules/@aws-cdk/service-spec-types/lib/types/diff.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
  }
});

// ../../node_modules/@aws-cdk/service-spec-types/lib/types/common.js
var require_common3 = __commonJS({
  "../../node_modules/@aws-cdk/service-spec-types/lib/types/common.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
  }
});

// ../../node_modules/@aws-cdk/service-spec-types/lib/index.js
var require_lib7 = __commonJS({
  "../../node_modules/@aws-cdk/service-spec-types/lib/index.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __exportStar3 = exports2 && exports2.__exportStar || function(m20, exports3) {
      for (var p10 in m20) if (p10 !== "default" && !Object.prototype.hasOwnProperty.call(exports3, p10)) __createBinding3(exports3, m20, p10);
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    __exportStar3(require_database2(), exports2);
    __exportStar3(require_resource(), exports2);
    __exportStar3(require_augmentations(), exports2);
    __exportStar3(require_event(), exports2);
    __exportStar3(require_metrics(), exports2);
    __exportStar3(require_diff3(), exports2);
    __exportStar3(require_common3(), exports2);
  }
});

// ../../node_modules/@aws-cdk/aws-service-spec/lib/index.js
var require_lib8 = __commonJS({
  "../../node_modules/@aws-cdk/aws-service-spec/lib/index.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __setModuleDefault2 = exports2 && exports2.__setModuleDefault || (Object.create ? (function(o10, v) {
      Object.defineProperty(o10, "default", { enumerable: true, value: v });
    }) : function(o10, v) {
      o10["default"] = v;
    });
    var __importStar2 = exports2 && exports2.__importStar || /* @__PURE__ */ (function() {
      var ownKeys2 = /* @__PURE__ */ __name(function(o10) {
        ownKeys2 = Object.getOwnPropertyNames || function(o11) {
          var ar = [];
          for (var k32 in o11) if (Object.prototype.hasOwnProperty.call(o11, k32)) ar[ar.length] = k32;
          return ar;
        };
        return ownKeys2(o10);
      }, "ownKeys");
      return function(mod) {
        if (mod && mod.__esModule) return mod;
        var result2 = {};
        if (mod != null) {
          for (var k32 = ownKeys2(mod), i32 = 0; i32 < k32.length; i32++) if (k32[i32] !== "default") __createBinding3(result2, mod, k32[i32]);
        }
        __setModuleDefault2(result2, mod);
        return result2;
      };
    })();
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.loadAwsServiceSpec = loadAwsServiceSpec;
    exports2.loadAwsServiceSpecSync = loadAwsServiceSpecSync2;
    var node_fs_1 = require("node:fs");
    var path47 = __importStar2(require("node:path"));
    var node_zlib_1 = require("node:zlib");
    var service_spec_types_1 = require_lib7();
    var DB_COMPRESSED = "db.json.gz";
    var DB_PATH = path47.join(__dirname, "..", DB_COMPRESSED);
    async function loadAwsServiceSpec() {
      return loadBufferIntoDatabase(await node_fs_1.promises.readFile(DB_PATH));
    }
    __name(loadAwsServiceSpec, "loadAwsServiceSpec");
    function loadAwsServiceSpecSync2() {
      return loadBufferIntoDatabase((0, node_fs_1.readFileSync)(DB_PATH));
    }
    __name(loadAwsServiceSpecSync2, "loadAwsServiceSpecSync");
    function loadBufferIntoDatabase(spec) {
      const db = (0, service_spec_types_1.emptyDatabase)();
      db.load(JSON.parse((0, node_zlib_1.gunzipSync)(spec).toString("utf-8")));
      return db;
    }
    __name(loadBufferIntoDatabase, "loadBufferIntoDatabase");
  }
});

// ../@aws-cdk/cloudformation-diff/lib/diff/util.ts
var util_exports = {};
__export(util_exports, {
  deepEqual: () => deepEqual,
  diffKeyedEntities: () => diffKeyedEntities,
  loadResourceModel: () => loadResourceModel,
  mangleLikeCloudFormation: () => mangleLikeCloudFormation,
  unionOf: () => unionOf
});
function deepEqual(lvalue, rvalue) {
  if (lvalue === rvalue) {
    return true;
  }
  if ((typeof lvalue === "string" && typeof rvalue === "boolean" || typeof lvalue === "boolean" && typeof rvalue === "string") && lvalue.toString() === rvalue.toString()) {
    return true;
  }
  if ((typeof lvalue === "string" || typeof rvalue === "string") && safeParseFloat(lvalue) === safeParseFloat(rvalue)) {
    return true;
  }
  if (typeof lvalue !== typeof rvalue) {
    return false;
  }
  if (Array.isArray(lvalue) !== Array.isArray(rvalue)) {
    return false;
  }
  if (Array.isArray(lvalue)) {
    if (lvalue.length !== rvalue.length) {
      return false;
    }
    for (let i32 = 0; i32 < lvalue.length; i32++) {
      if (!deepEqual(lvalue[i32], rvalue[i32])) {
        return false;
      }
    }
    return true;
  }
  if (typeof lvalue === "object") {
    if (lvalue === null || rvalue === null) {
      return false;
    }
    const keys = Object.keys(lvalue);
    if (keys.length !== Object.keys(rvalue).length) {
      return false;
    }
    for (const key of keys) {
      if (!rvalue.hasOwnProperty(key)) {
        return false;
      }
      if (key === "DependsOn") {
        if (!dependsOnEqual(lvalue[key], rvalue[key])) {
          return false;
        }
        continue;
      }
      if (!deepEqual(lvalue[key], rvalue[key])) {
        return false;
      }
    }
    return true;
  }
  return false;
}
function dependsOnEqual(lvalue, rvalue) {
  if (Array.isArray(lvalue) !== Array.isArray(rvalue)) {
    const array = Array.isArray(lvalue) ? lvalue : rvalue;
    const nonArray = Array.isArray(lvalue) ? rvalue : lvalue;
    if (array.length === 1 && deepEqual(array[0], nonArray)) {
      return true;
    }
    return false;
  }
  if (Array.isArray(lvalue) && Array.isArray(rvalue)) {
    if (lvalue.length !== rvalue.length) {
      return false;
    }
    for (let i32 = 0; i32 < lvalue.length; i32++) {
      for (let j32 = 0; j32 < lvalue.length; j32++) {
        if (!deepEqual(lvalue[i32], rvalue[j32]) && j32 === lvalue.length - 1) {
          return false;
        }
        break;
      }
    }
    return true;
  }
  return false;
}
function diffKeyedEntities(oldValue, newValue, elementDiff) {
  const result2 = {};
  for (const logicalId of unionOf(Object.keys(oldValue || {}), Object.keys(newValue || {}))) {
    const oldElement = oldValue && oldValue[logicalId];
    const newElement = newValue && newValue[logicalId];
    if (oldElement === void 0 && newElement === void 0) {
      continue;
    }
    result2[logicalId] = elementDiff(oldElement, newElement, logicalId);
  }
  return result2;
}
function unionOf(lv, rv) {
  const result2 = new Set(lv);
  for (const v of rv) {
    result2.add(v);
  }
  return new Array(...result2);
}
function mangleLikeCloudFormation(payload3) {
  return payload3.replace(/[\u{80}-\u{10ffff}]/gu, "?");
}
function safeParseFloat(str) {
  return Number(str);
}
function database() {
  if (!DATABASE) {
    DATABASE = (0, import_aws_service_spec.loadAwsServiceSpecSync)();
  }
  return DATABASE;
}
function loadResourceModel(type) {
  return database().lookup("resource", "cloudFormationType", "equals", type)[0];
}
var import_aws_service_spec, DATABASE;
var init_util4 = __esm({
  "../@aws-cdk/cloudformation-diff/lib/diff/util.ts"() {
    "use strict";
    import_aws_service_spec = __toESM(require_lib8());
    __name(deepEqual, "deepEqual");
    __name(dependsOnEqual, "dependsOnEqual");
    __name(diffKeyedEntities, "diffKeyedEntities");
    __name(unionOf, "unionOf");
    __name(mangleLikeCloudFormation, "mangleLikeCloudFormation");
    __name(safeParseFloat, "safeParseFloat");
    __name(database, "database");
    __name(loadResourceModel, "loadResourceModel");
  }
});

// ../../node_modules/fast-deep-equal/index.js
var require_fast_deep_equal = __commonJS({
  "../../node_modules/fast-deep-equal/index.js"(exports2, module2) {
    "use strict";
    module2.exports = /* @__PURE__ */ __name(function equal(a32, b32) {
      if (a32 === b32) return true;
      if (a32 && b32 && typeof a32 == "object" && typeof b32 == "object") {
        if (a32.constructor !== b32.constructor) return false;
        var length, i32, keys;
        if (Array.isArray(a32)) {
          length = a32.length;
          if (length != b32.length) return false;
          for (i32 = length; i32-- !== 0; )
            if (!equal(a32[i32], b32[i32])) return false;
          return true;
        }
        if (a32.constructor === RegExp) return a32.source === b32.source && a32.flags === b32.flags;
        if (a32.valueOf !== Object.prototype.valueOf) return a32.valueOf() === b32.valueOf();
        if (a32.toString !== Object.prototype.toString) return a32.toString() === b32.toString();
        keys = Object.keys(a32);
        length = keys.length;
        if (length !== Object.keys(b32).length) return false;
        for (i32 = length; i32-- !== 0; )
          if (!Object.prototype.hasOwnProperty.call(b32, keys[i32])) return false;
        for (i32 = length; i32-- !== 0; ) {
          var key = keys[i32];
          if (!equal(a32[key], b32[key])) return false;
        }
        return true;
      }
      return a32 !== a32 && b32 !== b32;
    }, "equal");
  }
});

// ../@aws-cdk/cloudformation-diff/lib/iam/iam-identity-center.ts
var deepEqual2, SsoPermissionSet, SsoAssignment, SsoInstanceACAConfig;
var init_iam_identity_center = __esm({
  "../@aws-cdk/cloudformation-diff/lib/iam/iam-identity-center.ts"() {
    "use strict";
    deepEqual2 = require_fast_deep_equal();
    SsoPermissionSet = class {
      static {
        __name(this, "SsoPermissionSet");
      }
      constructor(props) {
        this.cfnLogicalId = props.cfnLogicalId;
        this.name = props.name;
        this.ssoInstanceArn = props.ssoInstanceArn;
        this.ssoPermissionsBoundary = props.ssoPermissionsBoundary;
        this.ssoCustomerManagedPolicyReferences = props.ssoCustomerManagedPolicyReferences;
      }
      equal(other) {
        return deepEqual2(this, other);
      }
    };
    SsoAssignment = class {
      static {
        __name(this, "SsoAssignment");
      }
      constructor(props) {
        this.cfnLogicalId = props.cfnLogicalId;
        this.ssoInstanceArn = props.ssoInstanceArn;
        this.permissionSetArn = props.permissionSetArn;
        this.principalId = props.principalId;
        this.principalType = props.principalType;
        this.targetId = props.targetId;
        this.targetType = props.targetType;
      }
      equal(other) {
        return deepEqual2(this, other);
      }
    };
    SsoInstanceACAConfig = class {
      static {
        __name(this, "SsoInstanceACAConfig");
      }
      constructor(props) {
        this.cfnLogicalId = props.cfnLogicalId;
        this.ssoInstanceArn = props.ssoInstanceArn;
        this.accessControlAttributes = props.accessControlAttributes;
      }
      equal(other) {
        return deepEqual2(this, other);
      }
    };
  }
});

// ../@aws-cdk/cloudformation-diff/lib/diff/maybe-parsed.ts
function mkParsed(value) {
  return { type: "parsed", value };
}
function mkUnparseable(value) {
  return {
    type: "unparseable",
    repr: typeof value === "string" ? value : JSON.stringify(value)
  };
}
var init_maybe_parsed = __esm({
  "../@aws-cdk/cloudformation-diff/lib/diff/maybe-parsed.ts"() {
    "use strict";
    __name(mkParsed, "mkParsed");
    __name(mkUnparseable, "mkUnparseable");
  }
});

// ../@aws-cdk/cloudformation-diff/lib/iam/managed-policy.ts
var ManagedPolicyAttachment;
var init_managed_policy = __esm({
  "../@aws-cdk/cloudformation-diff/lib/iam/managed-policy.ts"() {
    "use strict";
    init_maybe_parsed();
    ManagedPolicyAttachment = class _ManagedPolicyAttachment {
      constructor(identityArn, managedPolicyArn) {
        this.identityArn = identityArn;
        this.managedPolicyArn = managedPolicyArn;
      }
      static {
        __name(this, "ManagedPolicyAttachment");
      }
      static parseManagedPolicies(identityArn, arns) {
        return typeof arns === "string" ? [new _ManagedPolicyAttachment(identityArn, arns)] : arns.map((arn) => new _ManagedPolicyAttachment(identityArn, arn));
      }
      equal(other) {
        return this.identityArn === other.identityArn && this.managedPolicyArn === other.managedPolicyArn;
      }
      /**
       * Return a machine-readable version of the changes.
       * This is only used in tests.
       *
       * @internal
       */
      _toJson() {
        return mkParsed({
          identityArn: this.identityArn,
          managedPolicyArn: this.managedPolicyArn
        });
      }
    };
  }
});

// ../@aws-cdk/cloudformation-diff/lib/util.ts
function makeComparator(keyFn) {
  return (a32, b32) => {
    const keyA = keyFn(a32);
    const keyB = keyFn(b32);
    const len = Math.min(keyA.length, keyB.length);
    for (let i32 = 0; i32 < len; i32++) {
      const c32 = compare(keyA[i32], keyB[i32]);
      if (c32 !== 0) {
        return c32;
      }
    }
    return keyA.length - keyB.length;
  };
}
function compare(a32, b32) {
  if (a32 < b32) {
    return -1;
  }
  if (b32 < a32) {
    return 1;
  }
  return 0;
}
function dropIfEmpty(xs) {
  return xs.length > 0 ? xs : void 0;
}
function deepRemoveUndefined(x) {
  if (typeof x === void 0 || x === null) {
    return x;
  }
  if (Array.isArray(x)) {
    return x.map(deepRemoveUndefined);
  }
  if (typeof x === "object") {
    for (const [key, value] of Object.entries(x)) {
      x[key] = deepRemoveUndefined(value);
      if (x[key] === void 0) {
        delete x[key];
      }
    }
    return x;
  }
  return x;
}
function flatMap2(xs, f32) {
  const ret = new Array();
  for (const x of xs) {
    ret.push(...f32(x));
  }
  return ret;
}
var init_util5 = __esm({
  "../@aws-cdk/cloudformation-diff/lib/util.ts"() {
    "use strict";
    __name(makeComparator, "makeComparator");
    __name(compare, "compare");
    __name(dropIfEmpty, "dropIfEmpty");
    __name(deepRemoveUndefined, "deepRemoveUndefined");
    __name(flatMap2, "flatMap");
  }
});

// ../@aws-cdk/cloudformation-diff/lib/iam/statement.ts
function parseStatements(x) {
  if (x === void 0) {
    x = [];
  }
  if (!Array.isArray(x)) {
    x = [x];
  }
  return x.map((s) => new Statement(s));
}
function parseLambdaPermission(x) {
  const statement = {
    Effect: "Allow",
    Action: x.Action,
    Resource: x.FunctionName
  };
  if (x.Principal !== void 0) {
    if (x.Principal === "*") {
      statement.Principal = "*";
    } else if (/^\d{12}$/.test(x.Principal)) {
      statement.Principal = { AWS: `arn:aws:iam::${x.Principal}:root` };
    } else {
      statement.Principal = { Service: x.Principal };
    }
  }
  if (x.SourceArn !== void 0) {
    if (statement.Condition === void 0) {
      statement.Condition = {};
    }
    statement.Condition.ArnLike = { "AWS:SourceArn": x.SourceArn };
  }
  if (x.SourceAccount !== void 0) {
    if (statement.Condition === void 0) {
      statement.Condition = {};
    }
    statement.Condition.StringEquals = { "AWS:SourceAccount": x.SourceAccount };
  }
  if (x.EventSourceToken !== void 0) {
    if (statement.Condition === void 0) {
      statement.Condition = {};
    }
    statement.Condition.StringEquals = { "lambda:EventSourceToken": x.EventSourceToken };
  }
  return new Statement(statement);
}
function expectString2(x) {
  return typeof x === "string" ? x : void 0;
}
function expectEffect(x) {
  if (x === "Allow" /* Allow */ || x === "Deny" /* Deny */) {
    return x;
  }
  return "Unknown" /* Unknown */;
}
function forceListOfStrings(x) {
  if (typeof x === "string") {
    return [x];
  }
  if (typeof x === "undefined" || x === null) {
    return [];
  }
  if (Array.isArray(x)) {
    return x.map((e32) => forceListOfStrings(e32).join(","));
  }
  if (typeof x === "object" && x !== null) {
    const ret = [];
    for (const [key, value] of Object.entries(x)) {
      ret.push(...forceListOfStrings(value).map((s) => `${key}:${s}`));
    }
    return ret;
  }
  return [`${x}`];
}
function renderCondition(condition) {
  if (!condition || Object.keys(condition).length === 0) {
    return "";
  }
  const jsonRepresentation = JSON.stringify(condition, void 0, 2);
  const lines = jsonRepresentation.split("\n");
  return lines.slice(1, lines.length - 1).map((s) => s.slice(2)).join("\n");
}
var deepEqual3, Statement, Targets;
var init_statement = __esm({
  "../@aws-cdk/cloudformation-diff/lib/iam/statement.ts"() {
    "use strict";
    init_maybe_parsed();
    init_util5();
    deepEqual3 = require_fast_deep_equal();
    Statement = class {
      static {
        __name(this, "Statement");
      }
      constructor(statement) {
        if (typeof statement === "string") {
          this.sid = void 0;
          this.effect = "Unknown" /* Unknown */;
          this.resources = new Targets({}, "", "");
          this.actions = new Targets({}, "", "");
          this.principals = new Targets({}, "", "");
          this.condition = void 0;
          this.serializedIntrinsic = statement;
        } else {
          this.sid = expectString2(statement.Sid);
          this.effect = expectEffect(statement.Effect);
          this.resources = new Targets(statement, "Resource", "NotResource");
          this.actions = new Targets(statement, "Action", "NotAction");
          this.principals = new Targets(statement, "Principal", "NotPrincipal");
          this.condition = statement.Condition;
          this.serializedIntrinsic = void 0;
        }
      }
      /**
       * Whether this statement is equal to the other statement
       */
      equal(other) {
        return this.sid === other.sid && this.effect === other.effect && this.serializedIntrinsic === other.serializedIntrinsic && this.resources.equal(other.resources) && this.actions.equal(other.actions) && this.principals.equal(other.principals) && deepEqual3(this.condition, other.condition);
      }
      render() {
        return this.serializedIntrinsic ? {
          resource: this.serializedIntrinsic,
          effect: "",
          action: "",
          principal: this.principals.render(),
          // these will be replaced by the call to replaceEmpty() from IamChanges
          condition: ""
        } : {
          resource: this.resources.render(),
          effect: this.effect,
          action: this.actions.render(),
          principal: this.principals.render(),
          condition: renderCondition(this.condition)
        };
      }
      /**
       * Return a machine-readable version of the changes.
       * This is only used in tests.
       *
       * @internal
       */
      _toJson() {
        return this.serializedIntrinsic ? mkUnparseable(this.serializedIntrinsic) : mkParsed(deepRemoveUndefined({
          sid: this.sid,
          effect: this.effect,
          resources: this.resources._toJson(),
          principals: this.principals._toJson(),
          actions: this.actions._toJson(),
          condition: this.condition
        }));
      }
      /**
       * Whether this is a negative statement
       *
       * A statement is negative if any of its targets are negative, inverted
       * if the Effect is Deny.
       */
      get isNegativeStatement() {
        const notTarget = this.actions.not || this.principals.not || this.resources.not;
        return this.effect === "Allow" /* Allow */ ? notTarget : !notTarget;
      }
    };
    __name(parseStatements, "parseStatements");
    __name(parseLambdaPermission, "parseLambdaPermission");
    Targets = class {
      static {
        __name(this, "Targets");
      }
      constructor(statement, positiveKey, negativeKey) {
        if (negativeKey in statement) {
          this.values = forceListOfStrings(statement[negativeKey]);
          this.not = true;
        } else {
          this.values = forceListOfStrings(statement[positiveKey]);
          this.not = false;
        }
        this.values.sort();
      }
      get empty() {
        return this.values.length === 0;
      }
      /**
       * Whether this set of targets is equal to the other set of targets
       */
      equal(other) {
        return this.not === other.not && deepEqual3(this.values.sort(), other.values.sort());
      }
      /**
       * If the current value set is empty, put this in it
       */
      replaceEmpty(replacement) {
        if (this.empty) {
          this.values.push(replacement);
        }
      }
      /**
       * If the actions contains a '*', replace with this string.
       */
      replaceStar(replacement) {
        for (let i32 = 0; i32 < this.values.length; i32++) {
          if (this.values[i32] === "*") {
            this.values[i32] = replacement;
          }
        }
        this.values.sort();
      }
      /**
       * Render into a summary table cell
       */
      render() {
        return this.not ? this.values.map((s) => `NOT ${s}`).join("\n") : this.values.join("\n");
      }
      /**
       * Return a machine-readable version of the changes.
       * This is only used in tests.
       *
       * @internal
       */
      _toJson() {
        return { not: this.not, values: this.values };
      }
    };
    __name(expectString2, "expectString");
    __name(expectEffect, "expectEffect");
    __name(forceListOfStrings, "forceListOfStrings");
    __name(renderCondition, "renderCondition");
  }
});

// ../@aws-cdk/cloudformation-diff/lib/diffable.ts
function contains(element, xs) {
  return xs.some((x) => x.equal(element));
}
function difference(collection, elements) {
  return collection.filter((x) => !contains(x, elements));
}
var DiffableCollection;
var init_diffable = __esm({
  "../@aws-cdk/cloudformation-diff/lib/diffable.ts"() {
    "use strict";
    DiffableCollection = class {
      constructor() {
        this.additions = [];
        this.removals = [];
        this.oldElements = [];
        this.newElements = [];
      }
      static {
        __name(this, "DiffableCollection");
      }
      addOld(...elements) {
        this.oldElements.push(...elements);
      }
      addNew(...elements) {
        this.newElements.push(...elements);
      }
      calculateDiff() {
        this.additions.push(...difference(this.newElements, this.oldElements));
        this.removals.push(...difference(this.oldElements, this.newElements));
      }
      get hasChanges() {
        return this.additions.length + this.removals.length > 0;
      }
      get hasAdditions() {
        return this.additions.length > 0;
      }
      get hasRemovals() {
        return this.removals.length > 0;
      }
    };
    __name(contains, "contains");
    __name(difference, "difference");
  }
});

// ../@aws-cdk/cloudformation-diff/lib/render-intrinsics.ts
function renderIntrinsics(x) {
  if (Array.isArray(x)) {
    return x.filter((el) => !isNoValue(el)).map(renderIntrinsics);
  }
  if (isNoValue(x)) {
    return void 0;
  }
  const intrinsic = getIntrinsic(x);
  if (intrinsic) {
    if (intrinsic.fn === "Ref") {
      return "${" + intrinsic.args + "}";
    }
    if (intrinsic.fn === "Fn::GetAtt") {
      return "${" + intrinsic.args[0] + "." + intrinsic.args[1] + "}";
    }
    if (intrinsic.fn === "Fn::Join") {
      return unCloudFormationFnJoin(intrinsic.args[0], intrinsic.args[1]);
    }
    return stringifyIntrinsic(intrinsic.fn, intrinsic.args);
  }
  if (typeof x === "object" && x !== null) {
    const ret = {};
    for (const [key, value] of Object.entries(x)) {
      if (!isNoValue(value)) {
        ret[key] = renderIntrinsics(value);
      }
    }
    return ret;
  }
  return x;
}
function unCloudFormationFnJoin(separator, args) {
  if (Array.isArray(args)) {
    return args.filter((el) => !isNoValue(el)).map(renderIntrinsics).join(separator);
  }
  return stringifyIntrinsic("Fn::Join", [separator, args]);
}
function stringifyIntrinsic(fn, args) {
  return JSON.stringify({ [fn]: renderIntrinsics(args) });
}
function getIntrinsic(x) {
  if (x === void 0 || x === null || Array.isArray(x)) {
    return void 0;
  }
  if (typeof x !== "object") {
    return void 0;
  }
  const keys = Object.keys(x);
  return keys.length === 1 && (keys[0] === "Ref" || keys[0].startsWith("Fn::")) ? { fn: keys[0], args: x[keys[0]] } : void 0;
}
function isNoValue(x) {
  const int = getIntrinsic(x);
  return int && int.fn === "Ref" && int.args === "AWS::NoValue";
}
var init_render_intrinsics = __esm({
  "../@aws-cdk/cloudformation-diff/lib/render-intrinsics.ts"() {
    "use strict";
    __name(renderIntrinsics, "renderIntrinsics");
    __name(unCloudFormationFnJoin, "unCloudFormationFnJoin");
    __name(stringifyIntrinsic, "stringifyIntrinsic");
    __name(getIntrinsic, "getIntrinsic");
    __name(isNoValue, "isNoValue");
  }
});

// ../@aws-cdk/cloudformation-diff/lib/iam/iam-changes.ts
function defaultPrincipal(principal, statements) {
  statements.forEach((s) => s.principals.replaceEmpty(principal));
  statements.forEach((s) => s.principals.replaceStar(principal));
  return statements;
}
function defaultResource(resource, statements) {
  statements.forEach((s) => s.resources.replaceEmpty(resource));
  statements.forEach((s) => s.resources.replaceStar(resource));
  return statements;
}
var import_service_spec_types, chalk3, IamChanges;
var init_iam_changes = __esm({
  "../@aws-cdk/cloudformation-diff/lib/iam/iam-changes.ts"() {
    "use strict";
    import_service_spec_types = __toESM(require_lib7());
    chalk3 = __toESM(require_source());
    init_iam_identity_center();
    init_managed_policy();
    init_statement();
    init_diffable();
    init_render_intrinsics();
    init_util5();
    IamChanges = class {
      constructor(props) {
        // each entry in a DiffableCollection is used to generate a single row of the security changes table that is presented for cdk diff and cdk deploy.
        this.statements = new DiffableCollection();
        this.managedPolicies = new DiffableCollection();
        this.ssoPermissionSets = new DiffableCollection();
        this.ssoAssignments = new DiffableCollection();
        this.ssoInstanceACAConfigs = new DiffableCollection();
        for (const propertyChange of props.propertyChanges) {
          this.readPropertyChange(propertyChange);
        }
        for (const resourceChange of props.resourceChanges) {
          this.readResourceChange(resourceChange);
        }
        this.statements.calculateDiff();
        this.managedPolicies.calculateDiff();
        this.ssoPermissionSets.calculateDiff();
        this.ssoAssignments.calculateDiff();
        this.ssoInstanceACAConfigs.calculateDiff();
      }
      static {
        __name(this, "IamChanges");
      }
      static {
        this.IamPropertyScrutinies = [
          import_service_spec_types.PropertyScrutinyType.InlineIdentityPolicies,
          import_service_spec_types.PropertyScrutinyType.InlineResourcePolicy,
          import_service_spec_types.PropertyScrutinyType.ManagedPolicies
        ];
      }
      static {
        this.IamResourceScrutinies = [
          import_service_spec_types.ResourceScrutinyType.ResourcePolicyResource,
          import_service_spec_types.ResourceScrutinyType.IdentityPolicyResource,
          import_service_spec_types.ResourceScrutinyType.LambdaPermission,
          import_service_spec_types.ResourceScrutinyType.SsoAssignmentResource,
          import_service_spec_types.ResourceScrutinyType.SsoInstanceACAConfigResource,
          import_service_spec_types.ResourceScrutinyType.SsoPermissionSet
        ];
      }
      get hasChanges() {
        return this.statements.hasChanges || this.managedPolicies.hasChanges || this.ssoPermissionSets.hasChanges || this.ssoAssignments.hasChanges || this.ssoInstanceACAConfigs.hasChanges;
      }
      /**
       * Return whether the changes include broadened permissions
       *
       * Permissions are broadened if positive statements are added or
       * negative statements are removed, or if managed policies are added.
       */
      get permissionsBroadened() {
        return this.statements.additions.some((s) => !s.isNegativeStatement) || this.statements.removals.some((s) => s.isNegativeStatement) || this.managedPolicies.hasAdditions || this.ssoPermissionSets.hasAdditions || this.ssoAssignments.hasAdditions || this.ssoInstanceACAConfigs.hasAdditions;
      }
      /**
       * Return a summary table of changes
       */
      summarizeStatements() {
        const ret = [];
        const header = ["", "Resource", "Effect", "Action", "Principal", "Condition"];
        for (const statement of this.statements.additions) {
          const renderedStatement = statement.render();
          ret.push([
            "+",
            renderedStatement.resource,
            renderedStatement.effect,
            renderedStatement.action,
            renderedStatement.principal,
            renderedStatement.condition
          ].map((s) => chalk3.green(s)));
        }
        for (const statement of this.statements.removals) {
          const renderedStatement = statement.render();
          ret.push([
            "-",
            renderedStatement.resource,
            renderedStatement.effect,
            renderedStatement.action,
            renderedStatement.principal,
            renderedStatement.condition
          ].map((s) => chalk3.red(s)));
        }
        ret.sort(makeComparator((row) => [row[1]]));
        ret.splice(0, 0, header);
        return ret;
      }
      summarizeManagedPolicies() {
        const ret = [];
        const header = ["", "Resource", "Managed Policy ARN"];
        for (const att of this.managedPolicies.additions) {
          ret.push([
            "+",
            att.identityArn,
            att.managedPolicyArn
          ].map((s) => chalk3.green(s)));
        }
        for (const att of this.managedPolicies.removals) {
          ret.push([
            "-",
            att.identityArn,
            att.managedPolicyArn
          ].map((s) => chalk3.red(s)));
        }
        ret.sort(makeComparator((row) => [row[1]]));
        ret.splice(0, 0, header);
        return ret;
      }
      summarizeSsoAssignments() {
        const ret = [];
        const header = ["", "Resource", "InstanceArn", "PermissionSetArn", "PrincipalId", "PrincipalType", "TargetId", "TargetType"];
        for (const att of this.ssoAssignments.additions) {
          ret.push([
            "+",
            att.cfnLogicalId || "",
            att.ssoInstanceArn || "",
            att.permissionSetArn || "",
            att.principalId || "",
            att.principalType || "",
            att.targetId || "",
            att.targetType || ""
          ].map((s) => chalk3.green(s)));
        }
        for (const att of this.ssoAssignments.removals) {
          ret.push([
            "-",
            att.cfnLogicalId || "",
            att.ssoInstanceArn || "",
            att.permissionSetArn || "",
            att.principalId || "",
            att.principalType || "",
            att.targetId || "",
            att.targetType || ""
          ].map((s) => chalk3.red(s)));
        }
        ret.sort(makeComparator((row) => [row[1]]));
        ret.splice(0, 0, header);
        return ret;
      }
      summarizeSsoInstanceACAConfigs() {
        const ret = [];
        const header = ["", "Resource", "InstanceArn", "AccessControlAttributes"];
        function formatAccessControlAttribute(aca) {
          return `Key: ${aca?.Key}, Values: [${aca?.Value?.Source.join(", ")}]`;
        }
        __name(formatAccessControlAttribute, "formatAccessControlAttribute");
        for (const att of this.ssoInstanceACAConfigs.additions) {
          ret.push([
            "+",
            att.cfnLogicalId || "",
            att.ssoInstanceArn || "",
            att.accessControlAttributes?.map(formatAccessControlAttribute).join("\n") || ""
          ].map((s) => chalk3.green(s)));
        }
        for (const att of this.ssoInstanceACAConfigs.removals) {
          ret.push([
            "-",
            att.cfnLogicalId || "",
            att.ssoInstanceArn || "",
            att.accessControlAttributes?.map(formatAccessControlAttribute).join("\n") || ""
          ].map((s) => chalk3.red(s)));
        }
        ret.sort(makeComparator((row) => [row[1]]));
        ret.splice(0, 0, header);
        return ret;
      }
      summarizeSsoPermissionSets() {
        const ret = [];
        const header = ["", "Resource", "InstanceArn", "PermissionSet name", "PermissionsBoundary", "CustomerManagedPolicyReferences"];
        function formatManagedPolicyRef(s) {
          return `Name: ${s?.Name || ""}, Path: ${s?.Path || ""}`;
        }
        __name(formatManagedPolicyRef, "formatManagedPolicyRef");
        function formatSsoPermissionsBoundary(ssoPb) {
          if (ssoPb?.ManagedPolicyArn !== void 0) {
            return `ManagedPolicyArn: ${ssoPb?.ManagedPolicyArn || ""}`;
          } else if (ssoPb?.CustomerManagedPolicyReference !== void 0) {
            return `CustomerManagedPolicyReference: {
  ${formatManagedPolicyRef(ssoPb?.CustomerManagedPolicyReference)}
}`;
          } else {
            return "";
          }
        }
        __name(formatSsoPermissionsBoundary, "formatSsoPermissionsBoundary");
        for (const att of this.ssoPermissionSets.additions) {
          ret.push([
            "+",
            att.cfnLogicalId || "",
            att.ssoInstanceArn || "",
            att.name || "",
            formatSsoPermissionsBoundary(att.ssoPermissionsBoundary),
            att.ssoCustomerManagedPolicyReferences?.map(formatManagedPolicyRef).join("\n") || ""
          ].map((s) => chalk3.green(s)));
        }
        for (const att of this.ssoPermissionSets.removals) {
          ret.push([
            "-",
            att.cfnLogicalId || "",
            att.ssoInstanceArn || "",
            att.name || "",
            formatSsoPermissionsBoundary(att.ssoPermissionsBoundary),
            att.ssoCustomerManagedPolicyReferences?.map(formatManagedPolicyRef).join("\n") || ""
          ].map((s) => chalk3.red(s)));
        }
        ret.sort(makeComparator((row) => [row[1]]));
        ret.splice(0, 0, header);
        return ret;
      }
      /**
       * Return a machine-readable version of the changes.
       * This is only used in tests.
       *
       * @internal
       */
      _toJson() {
        return deepRemoveUndefined({
          statementAdditions: dropIfEmpty(this.statements.additions.map((s) => s._toJson())),
          statementRemovals: dropIfEmpty(this.statements.removals.map((s) => s._toJson())),
          managedPolicyAdditions: dropIfEmpty(this.managedPolicies.additions.map((s) => s._toJson())),
          managedPolicyRemovals: dropIfEmpty(this.managedPolicies.removals.map((s) => s._toJson()))
        });
      }
      readPropertyChange(propertyChange) {
        switch (propertyChange.scrutinyType) {
          case import_service_spec_types.PropertyScrutinyType.InlineIdentityPolicies:
            this.statements.addOld(...this.readIdentityPolicies(propertyChange.oldValue, propertyChange.resourceLogicalId));
            this.statements.addNew(...this.readIdentityPolicies(propertyChange.newValue, propertyChange.resourceLogicalId));
            break;
          case import_service_spec_types.PropertyScrutinyType.InlineResourcePolicy:
            if (propertyChange.resourceType === "AWS::SSO::PermissionSet") {
              this.statements.addOld(...this.readPermissionSetInlinePolicy(propertyChange.oldValue, propertyChange.resourceLogicalId));
              this.statements.addNew(...this.readPermissionSetInlinePolicy(propertyChange.newValue, propertyChange.resourceLogicalId));
            } else {
              this.statements.addOld(...this.readResourceStatements(propertyChange.oldValue, propertyChange.resourceLogicalId));
              this.statements.addNew(...this.readResourceStatements(propertyChange.newValue, propertyChange.resourceLogicalId));
            }
            break;
          case import_service_spec_types.PropertyScrutinyType.ManagedPolicies:
            this.managedPolicies.addOld(...this.readManagedPolicies(propertyChange.oldValue, propertyChange.resourceLogicalId));
            this.managedPolicies.addNew(...this.readManagedPolicies(propertyChange.newValue, propertyChange.resourceLogicalId));
            break;
        }
      }
      readResourceChange(resourceChange) {
        switch (resourceChange.scrutinyType) {
          case import_service_spec_types.ResourceScrutinyType.IdentityPolicyResource:
            this.statements.addOld(...this.readIdentityPolicyResource(resourceChange.oldProperties));
            this.statements.addNew(...this.readIdentityPolicyResource(resourceChange.newProperties));
            break;
          case import_service_spec_types.ResourceScrutinyType.ResourcePolicyResource:
            this.statements.addOld(...this.readResourcePolicyResource(resourceChange.oldProperties));
            this.statements.addNew(...this.readResourcePolicyResource(resourceChange.newProperties));
            break;
          case import_service_spec_types.ResourceScrutinyType.LambdaPermission:
            this.statements.addOld(...this.readLambdaStatements(resourceChange.oldProperties));
            this.statements.addNew(...this.readLambdaStatements(resourceChange.newProperties));
            break;
          case import_service_spec_types.ResourceScrutinyType.SsoPermissionSet:
            this.ssoPermissionSets.addOld(...this.readSsoPermissionSet(resourceChange.oldProperties, resourceChange.resourceLogicalId));
            this.ssoPermissionSets.addNew(...this.readSsoPermissionSet(resourceChange.newProperties, resourceChange.resourceLogicalId));
            break;
          case import_service_spec_types.ResourceScrutinyType.SsoAssignmentResource:
            this.ssoAssignments.addOld(...this.readSsoAssignments(resourceChange.oldProperties, resourceChange.resourceLogicalId));
            this.ssoAssignments.addNew(...this.readSsoAssignments(resourceChange.newProperties, resourceChange.resourceLogicalId));
            break;
          case import_service_spec_types.ResourceScrutinyType.SsoInstanceACAConfigResource:
            this.ssoInstanceACAConfigs.addOld(...this.readSsoInstanceACAConfigs(resourceChange.oldProperties, resourceChange.resourceLogicalId));
            this.ssoInstanceACAConfigs.addNew(...this.readSsoInstanceACAConfigs(resourceChange.newProperties, resourceChange.resourceLogicalId));
            break;
        }
      }
      /**
       * Parse a list of policies on an identity
       */
      readIdentityPolicies(policies, logicalId) {
        if (policies === void 0 || !Array.isArray(policies)) {
          return [];
        }
        const appliesToPrincipal = "AWS:${" + logicalId + "}";
        return flatMap2(policies, (policy) => {
          const unparsedStatement = policy.PolicyDocument?.Statement ? policy.PolicyDocument.Statement : policy;
          return defaultPrincipal(appliesToPrincipal, parseStatements(renderIntrinsics(unparsedStatement)));
        });
      }
      /**
       * Parse an IAM::Policy resource
       */
      readIdentityPolicyResource(properties) {
        if (properties === void 0) {
          return [];
        }
        properties = renderIntrinsics(properties);
        const principals = (properties.Groups || []).concat(properties.Users || []).concat(properties.Roles || []);
        return flatMap2(principals, (principal) => {
          const ref = "AWS:" + principal;
          return defaultPrincipal(ref, parseStatements(properties.PolicyDocument.Statement));
        });
      }
      readSsoInstanceACAConfigs(properties, logicalId) {
        if (properties === void 0) {
          return [];
        }
        properties = renderIntrinsics(properties);
        return [new SsoInstanceACAConfig({
          cfnLogicalId: "${" + logicalId + "}",
          ssoInstanceArn: properties.InstanceArn,
          accessControlAttributes: properties.AccessControlAttributes
        })];
      }
      readSsoAssignments(properties, logicalId) {
        if (properties === void 0) {
          return [];
        }
        properties = renderIntrinsics(properties);
        return [new SsoAssignment({
          cfnLogicalId: "${" + logicalId + "}",
          ssoInstanceArn: properties.InstanceArn,
          permissionSetArn: properties.PermissionSetArn,
          principalId: properties.PrincipalId,
          principalType: properties.PrincipalType,
          targetId: properties.TargetId,
          targetType: properties.TargetType
        })];
      }
      readSsoPermissionSet(properties, logicalId) {
        if (properties === void 0) {
          return [];
        }
        properties = renderIntrinsics(properties);
        return [new SsoPermissionSet({
          cfnLogicalId: "${" + logicalId + "}",
          name: properties.Name,
          ssoInstanceArn: properties.InstanceArn,
          ssoCustomerManagedPolicyReferences: properties.CustomerManagedPolicyReferences,
          ssoPermissionsBoundary: properties.PermissionsBoundary
        })];
      }
      readPermissionSetInlinePolicy(policy, logicalId) {
        if (policy === void 0) {
          return [];
        }
        const appliesToResource = "${" + logicalId + ".Arn}";
        const appliesToPrincipal = "AWS:${" + logicalId + "}";
        const statements = parseStatements(renderIntrinsics(policy.Statement));
        defaultResource(appliesToResource, statements);
        defaultPrincipal(appliesToPrincipal, statements);
        return statements;
      }
      readResourceStatements(policy, logicalId) {
        if (policy === void 0) {
          return [];
        }
        const appliesToResource = "${" + logicalId + ".Arn}";
        return defaultResource(appliesToResource, parseStatements(renderIntrinsics(policy.Statement)));
      }
      /**
       * Parse an AWS::*::{Bucket,Topic,Queue}policy
       */
      readResourcePolicyResource(properties) {
        if (properties === void 0) {
          return [];
        }
        properties = renderIntrinsics(properties);
        const policyKeys = Object.keys(properties).filter((key) => key.indexOf("Policy") > -1);
        const resourceKeys = Object.keys(properties).filter((key) => !policyKeys.includes(key) && !key.endsWith("Name"));
        let resources = resourceKeys.length === 1 ? properties[resourceKeys[0]] : ["???"];
        if (!Array.isArray(resources)) {
          resources = [resources];
        }
        return flatMap2(resources, (resource) => {
          return defaultResource(resource, parseStatements(properties[policyKeys[0]].Statement));
        });
      }
      readManagedPolicies(policyArns, logicalId) {
        if (!policyArns) {
          return [];
        }
        const rep = "${" + logicalId + "}";
        return ManagedPolicyAttachment.parseManagedPolicies(rep, renderIntrinsics(policyArns));
      }
      readLambdaStatements(properties) {
        if (!properties) {
          return [];
        }
        return [parseLambdaPermission(renderIntrinsics(properties))];
      }
    };
    __name(defaultPrincipal, "defaultPrincipal");
    __name(defaultResource, "defaultResource");
  }
});

// ../@aws-cdk/cloudformation-diff/lib/network/security-group-rule.ts
function peerEqual(a32, b32) {
  if (a32 === void 0 !== (b32 === void 0)) {
    return false;
  }
  if (a32 === void 0) {
    return true;
  }
  if (a32.kind !== b32.kind) {
    return false;
  }
  switch (a32.kind) {
    case "cidr-ip":
      return a32.ip === b32.ip;
    case "security-group":
      return a32.securityGroupId === b32.securityGroupId;
    case "prefix-list":
      return a32.prefixListId === b32.prefixListId;
  }
}
function findFirst(obj, keys, fn) {
  for (const key of keys) {
    try {
      if (key in obj) {
        return fn(obj[key]);
      }
    } catch (e32) {
      debugger;
    }
  }
  return void 0;
}
var SecurityGroupRule;
var init_security_group_rule = __esm({
  "../@aws-cdk/cloudformation-diff/lib/network/security-group-rule.ts"() {
    "use strict";
    SecurityGroupRule = class {
      static {
        __name(this, "SecurityGroupRule");
      }
      constructor(ruleObject, groupRef) {
        this.ipProtocol = ruleObject.IpProtocol?.toString() || "*unknown*";
        this.fromPort = ruleObject.FromPort;
        this.toPort = ruleObject.ToPort;
        this.groupId = ruleObject.GroupId || groupRef || "*unknown*";
        this.peer = findFirst(
          ruleObject,
          ["CidrIp", "CidrIpv6"],
          (ip) => ({ kind: "cidr-ip", ip })
        ) || findFirst(
          ruleObject,
          ["DestinationSecurityGroupId", "SourceSecurityGroupId"],
          (securityGroupId) => ({ kind: "security-group", securityGroupId })
        ) || findFirst(
          ruleObject,
          ["DestinationPrefixListId", "SourcePrefixListId"],
          (prefixListId) => ({ kind: "prefix-list", prefixListId })
        );
      }
      equal(other) {
        return this.ipProtocol === other.ipProtocol && this.fromPort === other.fromPort && this.toPort === other.toPort && peerEqual(this.peer, other.peer);
      }
      describeProtocol() {
        if (this.ipProtocol === "-1") {
          return "Everything";
        }
        const ipProtocol = this.ipProtocol.toUpperCase();
        if (this.fromPort === -1) {
          return `All ${ipProtocol}`;
        }
        if (this.fromPort === this.toPort) {
          return `${ipProtocol} ${this.fromPort}`;
        }
        return `${ipProtocol} ${this.fromPort}-${this.toPort}`;
      }
      describePeer() {
        if (this.peer) {
          switch (this.peer.kind) {
            case "cidr-ip":
              if (this.peer.ip === "0.0.0.0/0") {
                return "Everyone (IPv4)";
              }
              if (this.peer.ip === "::/0") {
                return "Everyone (IPv6)";
              }
              return `${this.peer.ip}`;
            case "prefix-list":
              return `${this.peer.prefixListId}`;
            case "security-group":
              return `${this.peer.securityGroupId}`;
          }
        }
        return "?";
      }
      toJson() {
        return {
          groupId: this.groupId,
          ipProtocol: this.ipProtocol,
          fromPort: this.fromPort,
          toPort: this.toPort,
          peer: this.peer
        };
      }
    };
    __name(peerEqual, "peerEqual");
    __name(findFirst, "findFirst");
  }
});

// ../@aws-cdk/cloudformation-diff/lib/network/security-group-changes.ts
var chalk4, SecurityGroupChanges;
var init_security_group_changes = __esm({
  "../@aws-cdk/cloudformation-diff/lib/network/security-group-changes.ts"() {
    "use strict";
    chalk4 = __toESM(require_source());
    init_security_group_rule();
    init_diffable();
    init_render_intrinsics();
    init_util5();
    SecurityGroupChanges = class {
      constructor(props) {
        this.ingress = new DiffableCollection();
        this.egress = new DiffableCollection();
        for (const ingressProp of props.ingressRulePropertyChanges) {
          this.ingress.addOld(...this.readInlineRules(ingressProp.oldValue, ingressProp.resourceLogicalId));
          this.ingress.addNew(...this.readInlineRules(ingressProp.newValue, ingressProp.resourceLogicalId));
        }
        for (const egressProp of props.egressRulePropertyChanges) {
          this.egress.addOld(...this.readInlineRules(egressProp.oldValue, egressProp.resourceLogicalId));
          this.egress.addNew(...this.readInlineRules(egressProp.newValue, egressProp.resourceLogicalId));
        }
        for (const ingressRes of props.ingressRuleResourceChanges) {
          this.ingress.addOld(...this.readRuleResource(ingressRes.oldProperties));
          this.ingress.addNew(...this.readRuleResource(ingressRes.newProperties));
        }
        for (const egressRes of props.egressRuleResourceChanges) {
          this.egress.addOld(...this.readRuleResource(egressRes.oldProperties));
          this.egress.addNew(...this.readRuleResource(egressRes.newProperties));
        }
        this.ingress.calculateDiff();
        this.egress.calculateDiff();
      }
      static {
        __name(this, "SecurityGroupChanges");
      }
      get hasChanges() {
        return this.ingress.hasChanges || this.egress.hasChanges;
      }
      /**
       * Return a summary table of changes
       */
      summarize() {
        const ret = [];
        const header = ["", "Group", "Dir", "Protocol", "Peer"];
        const inWord = "In";
        const outWord = "Out";
        const renderRule = /* @__PURE__ */ __name((plusMin, inOut) => (rule) => [
          plusMin,
          rule.groupId,
          inOut,
          rule.describeProtocol(),
          rule.describePeer()
        ].map((s) => plusMin === "+" ? chalk4.green(s) : chalk4.red(s)), "renderRule");
        ret.push(...this.ingress.additions.map(renderRule("+", inWord)));
        ret.push(...this.egress.additions.map(renderRule("+", outWord)));
        ret.push(...this.ingress.removals.map(renderRule("-", inWord)));
        ret.push(...this.egress.removals.map(renderRule("-", outWord)));
        ret.sort(makeComparator((row) => [row[1], row[2].indexOf(inWord) > -1 ? 0 : 1]));
        ret.splice(0, 0, header);
        return ret;
      }
      toJson() {
        return deepRemoveUndefined({
          ingressRuleAdditions: dropIfEmpty(this.ingress.additions.map((s) => s.toJson())),
          ingressRuleRemovals: dropIfEmpty(this.ingress.removals.map((s) => s.toJson())),
          egressRuleAdditions: dropIfEmpty(this.egress.additions.map((s) => s.toJson())),
          egressRuleRemovals: dropIfEmpty(this.egress.removals.map((s) => s.toJson()))
        });
      }
      get rulesAdded() {
        return this.ingress.hasAdditions || this.egress.hasAdditions;
      }
      readInlineRules(rules, logicalId) {
        if (!rules || !Array.isArray(rules)) {
          return [];
        }
        const ref = "${" + logicalId + ".GroupId}";
        return rules.flatMap((r32) => {
          const rendered = renderIntrinsics(r32);
          return typeof rendered === "object" ? [new SecurityGroupRule(rendered, ref)] : [];
        });
      }
      readRuleResource(resource) {
        if (!resource) {
          return [];
        }
        return [new SecurityGroupRule(renderIntrinsics(resource))];
      }
    };
  }
});

// ../@aws-cdk/cloudformation-diff/lib/diff/types.ts
function worstImpact(one, two) {
  if (!two) {
    return one;
  }
  const badness = {
    ["NO_CHANGE" /* NO_CHANGE */]: 0,
    ["WILL_IMPORT" /* WILL_IMPORT */]: 0,
    ["WILL_UPDATE" /* WILL_UPDATE */]: 1,
    ["WILL_CREATE" /* WILL_CREATE */]: 2,
    ["WILL_ORPHAN" /* WILL_ORPHAN */]: 3,
    ["MAY_REPLACE" /* MAY_REPLACE */]: 4,
    ["WILL_REPLACE" /* WILL_REPLACE */]: 5,
    ["WILL_DESTROY" /* WILL_DESTROY */]: 6
  };
  return badness[one] > badness[two] ? one : two;
}
function isPropertyDifference(diff) {
  return diff.changeImpact !== void 0;
}
function onlyChanges(xs) {
  const ret = {};
  for (const [key, diff] of Object.entries(xs)) {
    if (diff.isDifferent) {
      ret[key] = diff;
    }
  }
  return ret;
}
var import_assert, import_service_spec_types2, TemplateDiff, Difference, PropertyDifference, DifferenceCollection, ConditionDifference, MappingDifference, MetadataDifference, OutputDifference, ParameterDifference, ResourceImpact, ResourceDifference;
var init_types5 = __esm({
  "../@aws-cdk/cloudformation-diff/lib/diff/types.ts"() {
    "use strict";
    import_assert = require("assert");
    import_service_spec_types2 = __toESM(require_lib7());
    init_util4();
    init_iam_changes();
    init_security_group_changes();
    TemplateDiff = class {
      static {
        __name(this, "TemplateDiff");
      }
      constructor(args) {
        if (args.awsTemplateFormatVersion !== void 0) {
          this.awsTemplateFormatVersion = args.awsTemplateFormatVersion;
        }
        if (args.description !== void 0) {
          this.description = args.description;
        }
        if (args.transform !== void 0) {
          this.transform = args.transform;
        }
        this.conditions = args.conditions || new DifferenceCollection({});
        this.mappings = args.mappings || new DifferenceCollection({});
        this.metadata = args.metadata || new DifferenceCollection({});
        this.outputs = args.outputs || new DifferenceCollection({});
        this.parameters = args.parameters || new DifferenceCollection({});
        this.resources = args.resources || new DifferenceCollection({});
        this.unknown = args.unknown || new DifferenceCollection({});
        this.iamChanges = new IamChanges({
          propertyChanges: this.scrutinizablePropertyChanges(IamChanges.IamPropertyScrutinies),
          resourceChanges: this.scrutinizableResourceChanges(IamChanges.IamResourceScrutinies)
        });
        this.securityGroupChanges = new SecurityGroupChanges({
          egressRulePropertyChanges: this.scrutinizablePropertyChanges([import_service_spec_types2.PropertyScrutinyType.EgressRules]),
          ingressRulePropertyChanges: this.scrutinizablePropertyChanges([import_service_spec_types2.PropertyScrutinyType.IngressRules]),
          egressRuleResourceChanges: this.scrutinizableResourceChanges([import_service_spec_types2.ResourceScrutinyType.EgressRuleResource]),
          ingressRuleResourceChanges: this.scrutinizableResourceChanges([import_service_spec_types2.ResourceScrutinyType.IngressRuleResource])
        });
      }
      get differenceCount() {
        let count = 0;
        if (this.awsTemplateFormatVersion !== void 0) {
          count += 1;
        }
        if (this.description !== void 0) {
          count += 1;
        }
        if (this.transform !== void 0) {
          count += 1;
        }
        count += this.conditions.differenceCount;
        count += this.mappings.differenceCount;
        count += this.metadata.differenceCount;
        count += this.outputs.differenceCount;
        count += this.parameters.differenceCount;
        count += this.resources.differenceCount;
        count += this.unknown.differenceCount;
        return count;
      }
      get isEmpty() {
        return this.differenceCount === 0;
      }
      /**
       * Return true if any of the permissions objects involve a broadening of permissions
       */
      get permissionsBroadened() {
        return this.iamChanges.permissionsBroadened || this.securityGroupChanges.rulesAdded;
      }
      /**
       * Return true if any of the permissions objects have changed
       */
      get permissionsAnyChanges() {
        return this.iamChanges.hasChanges || this.securityGroupChanges.hasChanges;
      }
      /**
       * Return all property changes of a given scrutiny type
       *
       * We don't just look at property updates; we also look at resource additions and deletions (in which
       * case there is no further detail on property values), and resource type changes.
       */
      scrutinizablePropertyChanges(scrutinyTypes) {
        const ret = new Array();
        for (const [resourceLogicalId, resourceChange] of Object.entries(this.resources.changes)) {
          if (resourceChange.resourceTypeChanged) {
            continue;
          }
          if (!resourceChange.resourceType) {
            continue;
          }
          const newTypeProps = loadResourceModel(resourceChange.resourceType)?.properties || {};
          for (const [propertyName, prop] of Object.entries(newTypeProps)) {
            const propScrutinyType = prop.scrutinizable || import_service_spec_types2.PropertyScrutinyType.None;
            if (scrutinyTypes.includes(propScrutinyType)) {
              ret.push({
                resourceLogicalId,
                propertyName,
                resourceType: resourceChange.resourceType,
                scrutinyType: propScrutinyType,
                oldValue: resourceChange.oldProperties?.[propertyName],
                newValue: resourceChange.newProperties?.[propertyName]
              });
            }
          }
        }
        return ret;
      }
      /**
       * Return all resource changes of a given scrutiny type
       *
       * We don't just look at resource updates; we also look at resource additions and deletions (in which
       * case there is no further detail on property values), and resource type changes.
       */
      scrutinizableResourceChanges(scrutinyTypes) {
        const ret = new Array();
        for (const [resourceLogicalId, resourceChange] of Object.entries(this.resources.changes)) {
          if (!resourceChange) {
            continue;
          }
          const commonProps = {
            oldProperties: resourceChange.oldProperties,
            newProperties: resourceChange.newProperties,
            resourceLogicalId
          };
          if (resourceChange.resourceTypeChanged) {
            if (resourceChange.oldResourceType) {
              const oldResourceModel = loadResourceModel(resourceChange.oldResourceType);
              if (oldResourceModel && this.resourceIsScrutinizable(oldResourceModel, scrutinyTypes)) {
                ret.push({
                  ...commonProps,
                  newProperties: void 0,
                  resourceType: resourceChange.oldResourceType,
                  scrutinyType: oldResourceModel.scrutinizable
                });
              }
            }
            if (resourceChange.newResourceType) {
              const newResourceModel = loadResourceModel(resourceChange.newResourceType);
              if (newResourceModel && this.resourceIsScrutinizable(newResourceModel, scrutinyTypes)) {
                ret.push({
                  ...commonProps,
                  oldProperties: void 0,
                  resourceType: resourceChange.newResourceType,
                  scrutinyType: newResourceModel.scrutinizable
                });
              }
            }
          } else {
            if (!resourceChange.resourceType) {
              continue;
            }
            const resourceModel = loadResourceModel(resourceChange.resourceType);
            if (resourceModel && this.resourceIsScrutinizable(resourceModel, scrutinyTypes)) {
              ret.push({
                ...commonProps,
                resourceType: resourceChange.resourceType,
                scrutinyType: resourceModel.scrutinizable
              });
            }
          }
        }
        return ret;
      }
      resourceIsScrutinizable(res, scrutinyTypes) {
        return scrutinyTypes.includes(res.scrutinizable || import_service_spec_types2.ResourceScrutinyType.None);
      }
    };
    Difference = class {
      /**
       * @param oldValue - the old value, cannot be equal (to the sense of +deepEqual+) to +newValue+.
       * @param newValue - the new value, cannot be equal (to the sense of +deepEqual+) to +oldValue+.
       */
      constructor(oldValue, newValue) {
        this.oldValue = oldValue;
        this.newValue = newValue;
        if (oldValue === void 0 && newValue === void 0) {
          throw new import_assert.AssertionError({ message: "oldValue and newValue are both undefined!" });
        }
        this.isDifferent = !deepEqual(oldValue, newValue);
      }
      static {
        __name(this, "Difference");
      }
      /** @returns +true+ if the element is new to the template. */
      get isAddition() {
        return this.oldValue === void 0;
      }
      /** @returns +true+ if the element was removed from the template. */
      get isRemoval() {
        return this.newValue === void 0;
      }
      /** @returns +true+ if the element was already in the template and is updated. */
      get isUpdate() {
        return this.oldValue !== void 0 && this.newValue !== void 0;
      }
    };
    PropertyDifference = class extends Difference {
      static {
        __name(this, "PropertyDifference");
      }
      constructor(oldValue, newValue, args) {
        super(oldValue, newValue);
        this.changeImpact = args.changeImpact;
      }
    };
    DifferenceCollection = class _DifferenceCollection {
      constructor(diffs) {
        this.diffs = diffs;
      }
      static {
        __name(this, "DifferenceCollection");
      }
      get changes() {
        return onlyChanges(this.diffs);
      }
      get differenceCount() {
        return Object.values(this.changes).length;
      }
      get(logicalId) {
        const ret = this.diffs[logicalId];
        if (!ret) {
          throw new Error(`No object with logical ID '${logicalId}'`);
        }
        return ret;
      }
      remove(logicalId) {
        delete this.diffs[logicalId];
      }
      get logicalIds() {
        return Object.keys(this.changes);
      }
      /**
       * Returns a new TemplateDiff which only contains changes for which `predicate`
       * returns `true`.
       */
      filter(predicate) {
        const newChanges = {};
        for (const id of Object.keys(this.changes)) {
          const diff = this.changes[id];
          if (predicate(diff)) {
            newChanges[id] = diff;
          }
        }
        return new _DifferenceCollection(newChanges);
      }
      /**
       * Invokes `cb` for all changes in this collection.
       *
       * Changes will be sorted as follows:
       *  - Removed
       *  - Added
       *  - Updated
       *  - Others
       *
       */
      forEachDifference(cb) {
        const removed = new Array();
        const added = new Array();
        const updated = new Array();
        const others = new Array();
        for (const logicalId of this.logicalIds) {
          const change = this.changes[logicalId];
          if (change.isAddition) {
            added.push({ logicalId, change });
          } else if (change.isRemoval) {
            removed.push({ logicalId, change });
          } else if (change.isUpdate) {
            updated.push({ logicalId, change });
          } else if (change.isDifferent) {
            others.push({ logicalId, change });
          }
        }
        removed.forEach((v) => cb(v.logicalId, v.change));
        added.forEach((v) => cb(v.logicalId, v.change));
        updated.forEach((v) => cb(v.logicalId, v.change));
        others.forEach((v) => cb(v.logicalId, v.change));
      }
    };
    ConditionDifference = class extends Difference {
      static {
        __name(this, "ConditionDifference");
      }
      // TODO: define specific difference attributes
    };
    MappingDifference = class extends Difference {
      static {
        __name(this, "MappingDifference");
      }
      // TODO: define specific difference attributes
    };
    MetadataDifference = class extends Difference {
      static {
        __name(this, "MetadataDifference");
      }
      // TODO: define specific difference attributes
    };
    OutputDifference = class extends Difference {
      static {
        __name(this, "OutputDifference");
      }
      // TODO: define specific difference attributes
    };
    ParameterDifference = class extends Difference {
      static {
        __name(this, "ParameterDifference");
      }
      // TODO: define specific difference attributes
    };
    ResourceImpact = /* @__PURE__ */ ((ResourceImpact2) => {
      ResourceImpact2["WILL_UPDATE"] = "WILL_UPDATE";
      ResourceImpact2["WILL_CREATE"] = "WILL_CREATE";
      ResourceImpact2["WILL_REPLACE"] = "WILL_REPLACE";
      ResourceImpact2["MAY_REPLACE"] = "MAY_REPLACE";
      ResourceImpact2["WILL_DESTROY"] = "WILL_DESTROY";
      ResourceImpact2["WILL_ORPHAN"] = "WILL_ORPHAN";
      ResourceImpact2["WILL_IMPORT"] = "WILL_IMPORT";
      ResourceImpact2["NO_CHANGE"] = "NO_CHANGE";
      return ResourceImpact2;
    })(ResourceImpact || {});
    __name(worstImpact, "worstImpact");
    ResourceDifference = class {
      constructor(oldValue, newValue, args) {
        this.oldValue = oldValue;
        this.newValue = newValue;
        this.resourceTypes = args.resourceType;
        this.propertyDiffs = args.propertyDiffs;
        this.otherDiffs = args.otherDiffs;
        this.isAddition = oldValue === void 0;
        this.isRemoval = newValue === void 0;
        this.isImport = void 0;
      }
      static {
        __name(this, "ResourceDifference");
      }
      get oldProperties() {
        return this.oldValue && this.oldValue.Properties;
      }
      get newProperties() {
        return this.newValue && this.newValue.Properties;
      }
      /**
       * Whether this resource was modified at all
       */
      get isDifferent() {
        return this.differenceCount > 0 || this.oldResourceType !== this.newResourceType;
      }
      /**
       * Whether the resource was updated in-place
       */
      get isUpdate() {
        return this.isDifferent && !this.isAddition && !this.isRemoval;
      }
      get oldResourceType() {
        return this.resourceTypes.oldType;
      }
      get newResourceType() {
        return this.resourceTypes.newType;
      }
      /**
       * All actual property updates
       */
      get propertyUpdates() {
        return onlyChanges(this.propertyDiffs);
      }
      /**
       * All actual "other" updates
       */
      get otherChanges() {
        return onlyChanges(this.otherDiffs);
      }
      /**
       * Return whether the resource type was changed in this diff
       *
       * This is not a valid operation in CloudFormation but to be defensive we're going
       * to be aware of it anyway.
       */
      get resourceTypeChanged() {
        return this.resourceTypes.oldType !== void 0 && this.resourceTypes.newType !== void 0 && this.resourceTypes.oldType !== this.resourceTypes.newType;
      }
      /**
       * Return the resource type if it was unchanged
       *
       * If the resource type was changed, it's an error to call this.
       */
      get resourceType() {
        if (this.resourceTypeChanged) {
          throw new Error("Cannot get .resourceType, because the type was changed");
        }
        return this.resourceTypes.oldType || this.resourceTypes.newType;
      }
      /**
       * Replace a PropertyChange in this object
       *
       * This affects the property diff as it is summarized to users, but it DOES
       * NOT affect either the "oldValue" or "newValue" values; those still contain
       * the actual template values as provided by the user (they might still be
       * used for downstream processing).
       */
      setPropertyChange(propertyName, change) {
        this.propertyDiffs[propertyName] = change;
      }
      /**
       * Replace a OtherChange in this object
       *
       * This affects the property diff as it is summarized to users, but it DOES
       * NOT affect either the "oldValue" or "newValue" values; those still contain
       * the actual template values as provided by the user (they might still be
       * used for downstream processing).
       */
      setOtherChange(otherName, change) {
        this.otherDiffs[otherName] = change;
      }
      get changeImpact() {
        if (this.isImport) {
          return "WILL_IMPORT" /* WILL_IMPORT */;
        }
        if (this.resourceTypes.oldType !== this.resourceTypes.newType) {
          if (this.resourceTypes.oldType === void 0) {
            return "WILL_CREATE" /* WILL_CREATE */;
          }
          if (this.resourceTypes.newType === void 0) {
            return this.oldValue.DeletionPolicy === "Retain" ? "WILL_ORPHAN" /* WILL_ORPHAN */ : "WILL_DESTROY" /* WILL_DESTROY */;
          }
          return "WILL_REPLACE" /* WILL_REPLACE */;
        }
        const baseImpact = Object.keys(this.otherChanges).length > 0 ? "WILL_UPDATE" /* WILL_UPDATE */ : "NO_CHANGE" /* NO_CHANGE */;
        return Object.values(this.propertyDiffs).map((elt) => elt.changeImpact).reduce(worstImpact, baseImpact);
      }
      /**
       * Count of actual differences (not of elements)
       */
      get differenceCount() {
        return Object.values(this.propertyUpdates).length + Object.values(this.otherChanges).length;
      }
      /**
       * Invoke a callback for each actual difference
       */
      forEachDifference(cb) {
        for (const key of Object.keys(this.propertyUpdates).sort()) {
          cb("Property", key, this.propertyUpdates[key]);
        }
        for (const key of Object.keys(this.otherChanges).sort()) {
          cb("Other", key, this.otherDiffs[key]);
        }
      }
    };
    __name(isPropertyDifference, "isPropertyDifference");
    __name(onlyChanges, "onlyChanges");
  }
});

// ../@aws-cdk/cloudformation-diff/lib/diff/index.ts
function diffAttribute(oldValue, newValue) {
  return new Difference(_asString(oldValue), _asString(newValue));
}
function diffCondition(oldValue, newValue) {
  return new ConditionDifference(oldValue, newValue);
}
function diffMapping(oldValue, newValue) {
  return new MappingDifference(oldValue, newValue);
}
function diffMetadata(oldValue, newValue) {
  return new MetadataDifference(oldValue, newValue);
}
function diffOutput(oldValue, newValue) {
  return new OutputDifference(oldValue, newValue);
}
function diffParameter(oldValue, newValue) {
  return new ParameterDifference(oldValue, newValue);
}
function diffResource(oldValue, newValue, logicalId) {
  if (logicalId && logicalId.startsWith("Fn::ForEach::")) {
    const forEachType = "Fn::ForEach";
    return new ResourceDifference(oldValue, newValue, {
      resourceType: { oldType: oldValue ? forEachType : void 0, newType: newValue ? forEachType : void 0 },
      propertyDiffs: {},
      otherDiffs: !deepEqual(oldValue, newValue) ? { Value: new Difference(oldValue, newValue) } : {}
    });
  }
  const resourceType = {
    oldType: oldValue && oldValue.Type,
    newType: newValue && newValue.Type
  };
  let propertyDiffs = {};
  let otherDiffs = {};
  if (resourceType.oldType !== void 0 && resourceType.oldType === resourceType.newType) {
    const impl = loadResourceModel(resourceType.oldType);
    propertyDiffs = diffKeyedEntities(
      oldValue.Properties,
      newValue.Properties,
      (oldVal, newVal, key) => _diffProperty(oldVal, newVal, key, impl)
    );
    otherDiffs = diffKeyedEntities(oldValue, newValue, _diffOther);
    delete otherDiffs.Properties;
  }
  return new ResourceDifference(oldValue, newValue, {
    resourceType,
    propertyDiffs,
    otherDiffs
  });
  function _diffProperty(oldV, newV, key, resourceSpec) {
    let changeImpact = "NO_CHANGE" /* NO_CHANGE */;
    const spec = resourceSpec?.properties?.[key];
    if (spec && !deepEqual(oldV, newV)) {
      switch (spec.causesReplacement) {
        case "yes":
          changeImpact = "WILL_REPLACE" /* WILL_REPLACE */;
          break;
        case "maybe":
          changeImpact = "MAY_REPLACE" /* MAY_REPLACE */;
          break;
        default:
          changeImpact = "WILL_UPDATE" /* WILL_UPDATE */;
      }
    }
    return new PropertyDifference(oldV, newV, { changeImpact });
  }
  __name(_diffProperty, "_diffProperty");
  function _diffOther(oldV, newV) {
    return new Difference(oldV, newV);
  }
  __name(_diffOther, "_diffOther");
}
function diffUnknown(oldValue, newValue) {
  return new Difference(oldValue, newValue);
}
function _asString(value) {
  if (value == null) {
    return void 0;
  }
  if (typeof value === "string") {
    return value;
  }
  return JSON.stringify(value);
}
var init_diff = __esm({
  "../@aws-cdk/cloudformation-diff/lib/diff/index.ts"() {
    "use strict";
    init_types5();
    init_util4();
    __name(diffAttribute, "diffAttribute");
    __name(diffCondition, "diffCondition");
    __name(diffMapping, "diffMapping");
    __name(diffMetadata, "diffMetadata");
    __name(diffOutput, "diffOutput");
    __name(diffParameter, "diffParameter");
    __name(diffResource, "diffResource");
    __name(diffUnknown, "diffUnknown");
    __name(_asString, "_asString");
  }
});

// ../@aws-cdk/cloudformation-diff/lib/diff/template-and-changeset-diff-merger.ts
var TemplateAndChangeSetDiffMerger;
var init_template_and_changeset_diff_merger = __esm({
  "../@aws-cdk/cloudformation-diff/lib/diff/template-and-changeset-diff-merger.ts"() {
    "use strict";
    init_types5();
    TemplateAndChangeSetDiffMerger = class _TemplateAndChangeSetDiffMerger {
      static {
        __name(this, "TemplateAndChangeSetDiffMerger");
      }
      static determineChangeSetReplacementMode(propertyChange) {
        if (propertyChange.Target?.RequiresRecreation === void 0) {
          return "Conditionally";
        }
        if (propertyChange.Target.RequiresRecreation === "Always") {
          switch (propertyChange.Evaluation) {
            case "Static":
              return "Always";
            case "Dynamic":
              return "Conditionally";
          }
        }
        return propertyChange.Target.RequiresRecreation;
      }
      static {
        // If we somehow cannot find the resourceType, then we'll mark it as UNKNOWN, so that can be seen in the diff.
        this.UNKNOWN_RESOURCE_TYPE = "UNKNOWN_RESOURCE_TYPE";
      }
      constructor(props) {
        this.changeSet = props.changeSet;
        this.changeSetResources = props.changeSetResources ?? this.convertDescribeChangeSetOutputToChangeSetResources(this.changeSet);
      }
      /**
       * Read resources from the changeSet, extracting information into ChangeSetResources.
       */
      convertDescribeChangeSetOutputToChangeSetResources(changeSet) {
        const changeSetResources = {};
        for (const resourceChange of changeSet.Changes ?? []) {
          if (resourceChange.ResourceChange?.LogicalResourceId === void 0) {
            continue;
          }
          const propertyReplacementModes = {};
          for (const propertyChange of resourceChange.ResourceChange.Details ?? []) {
            if (propertyChange.Target?.Attribute === "Properties" && propertyChange.Target.Name) {
              propertyReplacementModes[propertyChange.Target.Name] = {
                replacementMode: _TemplateAndChangeSetDiffMerger.determineChangeSetReplacementMode(propertyChange)
              };
            }
          }
          changeSetResources[resourceChange.ResourceChange.LogicalResourceId] = {
            resourceWasReplaced: resourceChange.ResourceChange.Replacement === "True",
            resourceType: resourceChange.ResourceChange.ResourceType ?? _TemplateAndChangeSetDiffMerger.UNKNOWN_RESOURCE_TYPE,
            // DescribeChangeSet doesn't promise to have the ResourceType...
            propertyReplacementModes
          };
        }
        return changeSetResources;
      }
      /**
       * This is writing over the "ChangeImpact" that was computed from the template difference, and instead using the ChangeImpact that is included from the ChangeSet.
       * Using the ChangeSet ChangeImpact is more accurate. The ChangeImpact tells us what the consequence is of changing the field. If changing the field causes resource
       * replacement (e.g., changing the name of an IAM role requires deleting and replacing the role), then ChangeImpact is "Always".
       */
      overrideDiffResourceChangeImpactWithChangeSetChangeImpact(logicalId, change) {
        if (change.resourceTypeChanged === true || change.resourceType?.includes("AWS::Serverless")) {
          return;
        }
        change.forEachDifference((type, name, value) => {
          if (type === "Property") {
            if (!this.changeSetResources[logicalId]) {
              value.changeImpact = "NO_CHANGE" /* NO_CHANGE */;
              value.isDifferent = false;
              return;
            }
            const changingPropertyCausesResourceReplacement = (this.changeSetResources[logicalId].propertyReplacementModes ?? {})[name]?.replacementMode;
            switch (changingPropertyCausesResourceReplacement) {
              case "Always":
                value.changeImpact = "WILL_REPLACE" /* WILL_REPLACE */;
                break;
              case "Never":
                value.changeImpact = "WILL_UPDATE" /* WILL_UPDATE */;
                break;
              case "Conditionally":
                value.changeImpact = "MAY_REPLACE" /* MAY_REPLACE */;
                break;
              case void 0:
                value.changeImpact = "NO_CHANGE" /* NO_CHANGE */;
                value.isDifferent = false;
                break;
            }
          } else if (type === "Other") {
            switch (name) {
              case "Metadata":
                change.setOtherChange("Metadata", new Difference(value.newValue, value.newValue));
                break;
            }
          }
        });
      }
      addImportInformationFromChangeset(resourceDiffs) {
        const imports = this.findResourceImports();
        resourceDiffs.forEachDifference((logicalId, change) => {
          if (imports.includes(logicalId)) {
            change.isImport = true;
          }
        });
      }
      findResourceImports() {
        const importedResourceLogicalIds = [];
        for (const resourceChange of this.changeSet?.Changes ?? []) {
          if (resourceChange.ResourceChange?.Action === "Import") {
            importedResourceLogicalIds.push(resourceChange.ResourceChange.LogicalResourceId);
          }
        }
        return importedResourceLogicalIds;
      }
    };
  }
});

// ../@aws-cdk/cloudformation-diff/lib/diff-template.ts
var diff_template_exports = {};
__export(diff_template_exports, {
  ConditionDifference: () => ConditionDifference,
  Difference: () => Difference,
  DifferenceCollection: () => DifferenceCollection,
  MappingDifference: () => MappingDifference,
  MetadataDifference: () => MetadataDifference,
  OutputDifference: () => OutputDifference,
  ParameterDifference: () => ParameterDifference,
  PropertyDifference: () => PropertyDifference,
  ResourceDifference: () => ResourceDifference,
  ResourceImpact: () => ResourceImpact,
  TemplateDiff: () => TemplateDiff,
  diffTemplate: () => diffTemplate,
  fullDiff: () => fullDiff,
  isPropertyDifference: () => isPropertyDifference
});
function fullDiff(currentTemplate, newTemplate, changeSet, isImport) {
  normalize(currentTemplate);
  normalize(newTemplate);
  const theDiff = diffTemplate(currentTemplate, newTemplate);
  if (changeSet) {
    const changeSetDiff = new TemplateAndChangeSetDiffMerger({ changeSet });
    theDiff.resources.forEachDifference(
      (logicalId, change) => changeSetDiff.overrideDiffResourceChangeImpactWithChangeSetChangeImpact(logicalId, change)
    );
    changeSetDiff.addImportInformationFromChangeset(theDiff.resources);
  } else if (isImport) {
    makeAllResourceChangesImports(theDiff);
  }
  return theDiff;
}
function diffTemplate(currentTemplate, newTemplate) {
  const theDiff = calculateTemplateDiff(currentTemplate, newTemplate);
  const newTemplateCopy = deepCopy(newTemplate);
  let didPropagateReferenceChanges;
  let diffWithReplacements;
  do {
    diffWithReplacements = calculateTemplateDiff(currentTemplate, newTemplateCopy);
    didPropagateReferenceChanges = false;
    if (diffWithReplacements.resources) {
      diffWithReplacements.resources.forEachDifference((logicalId, change) => {
        if (change.changeImpact === "WILL_REPLACE" /* WILL_REPLACE */) {
          if (propagateReplacedReferences(newTemplateCopy, logicalId)) {
            didPropagateReferenceChanges = true;
          }
        }
      });
    }
  } while (didPropagateReferenceChanges);
  diffWithReplacements.resources.filter((r32) => isReplacement(r32.changeImpact)).forEachDifference((logicalId, downstreamReplacement) => {
    const resource = theDiff.resources.get(logicalId);
    if (resource.changeImpact !== downstreamReplacement.changeImpact) {
      propagatePropertyReplacement(downstreamReplacement, resource);
    }
  });
  return theDiff;
}
function isReplacement(impact) {
  return impact === "MAY_REPLACE" /* MAY_REPLACE */ || impact === "WILL_REPLACE" /* WILL_REPLACE */;
}
function propagatePropertyReplacement(source, dest) {
  for (const [propertyName, diff] of Object.entries(source.propertyUpdates)) {
    if (diff.changeImpact && isReplacement(diff.changeImpact)) {
      dest.setPropertyChange(propertyName, diff);
    }
  }
}
function calculateTemplateDiff(currentTemplate, newTemplate) {
  const differences = {};
  const unknown = {};
  for (const key of unionOf(Object.keys(currentTemplate), Object.keys(newTemplate)).sort()) {
    const oldValue = currentTemplate[key];
    const newValue = newTemplate[key];
    if (deepEqual(oldValue, newValue)) {
      continue;
    }
    const handler = DIFF_HANDLERS[key] || ((_diff, oldV, newV) => unknown[key] = diffUnknown(oldV, newV));
    handler(differences, oldValue, newValue);
  }
  if (Object.keys(unknown).length > 0) {
    differences.unknown = new DifferenceCollection(unknown);
  }
  return new TemplateDiff(differences);
}
function propagateReplacedReferences(template, logicalId) {
  let ret = false;
  function recurse(obj) {
    if (Array.isArray(obj)) {
      obj.forEach(recurse);
    }
    if (typeof obj === "object" && obj !== null) {
      if (!replaceReference(obj)) {
        Object.values(obj).forEach(recurse);
      }
    }
  }
  __name(recurse, "recurse");
  function replaceReference(obj) {
    const keys = Object.keys(obj);
    if (keys.length !== 1) {
      return false;
    }
    const key = keys[0];
    if (key === "Ref") {
      if (obj.Ref === logicalId) {
        obj.Ref = logicalId + " (replaced)";
        ret = true;
      }
      return true;
    }
    if (key.startsWith("Fn::")) {
      if (Array.isArray(obj[key]) && obj[key].length > 0 && obj[key][0] === logicalId) {
        obj[key][0] = logicalId + "(replaced)";
        ret = true;
      }
      return true;
    }
    return false;
  }
  __name(replaceReference, "replaceReference");
  recurse(template);
  return ret;
}
function deepCopy(x) {
  if (Array.isArray(x)) {
    return x.map(deepCopy);
  }
  if (typeof x === "object" && x !== null) {
    const ret = {};
    for (const key of Object.keys(x)) {
      ret[key] = deepCopy(x[key]);
    }
    return ret;
  }
  return x;
}
function makeAllResourceChangesImports(diff) {
  diff.resources.forEachDifference((_logicalId, change) => {
    change.isImport = true;
  });
}
function normalize(template) {
  if (typeof template === "object") {
    for (const key of Object.keys(template ?? {})) {
      if (key === "Fn::GetAtt" && typeof template[key] === "string") {
        template[key] = template[key].split(".");
        continue;
      } else if (key === "DependsOn") {
        if (typeof template[key] === "string") {
          template[key] = [template[key]];
        } else if (Array.isArray(template[key])) {
          template[key] = template[key].sort();
        }
        continue;
      }
      if (Array.isArray(template[key])) {
        for (const element of template[key]) {
          normalize(element);
        }
      } else {
        normalize(template[key]);
      }
    }
  }
}
var DIFF_HANDLERS;
var init_diff_template = __esm({
  "../@aws-cdk/cloudformation-diff/lib/diff-template.ts"() {
    "use strict";
    init_diff();
    init_template_and_changeset_diff_merger();
    init_types5();
    init_util4();
    init_types5();
    DIFF_HANDLERS = {
      AWSTemplateFormatVersion: /* @__PURE__ */ __name((diff, oldValue, newValue) => diff.awsTemplateFormatVersion = diffAttribute(oldValue, newValue), "AWSTemplateFormatVersion"),
      Description: /* @__PURE__ */ __name((diff, oldValue, newValue) => diff.description = diffAttribute(oldValue, newValue), "Description"),
      Metadata: /* @__PURE__ */ __name((diff, oldValue, newValue) => diff.metadata = new DifferenceCollection(diffKeyedEntities(oldValue, newValue, diffMetadata)), "Metadata"),
      Parameters: /* @__PURE__ */ __name((diff, oldValue, newValue) => diff.parameters = new DifferenceCollection(diffKeyedEntities(oldValue, newValue, diffParameter)), "Parameters"),
      Mappings: /* @__PURE__ */ __name((diff, oldValue, newValue) => diff.mappings = new DifferenceCollection(diffKeyedEntities(oldValue, newValue, diffMapping)), "Mappings"),
      Conditions: /* @__PURE__ */ __name((diff, oldValue, newValue) => diff.conditions = new DifferenceCollection(diffKeyedEntities(oldValue, newValue, diffCondition)), "Conditions"),
      Transform: /* @__PURE__ */ __name((diff, oldValue, newValue) => diff.transform = diffAttribute(oldValue, newValue), "Transform"),
      Resources: /* @__PURE__ */ __name((diff, oldValue, newValue) => diff.resources = new DifferenceCollection(diffKeyedEntities(oldValue, newValue, diffResource)), "Resources"),
      Outputs: /* @__PURE__ */ __name((diff, oldValue, newValue) => diff.outputs = new DifferenceCollection(diffKeyedEntities(oldValue, newValue, diffOutput)), "Outputs")
    };
    __name(fullDiff, "fullDiff");
    __name(diffTemplate, "diffTemplate");
    __name(isReplacement, "isReplacement");
    __name(propagatePropertyReplacement, "propagatePropertyReplacement");
    __name(calculateTemplateDiff, "calculateTemplateDiff");
    __name(propagateReplacedReferences, "propagateReplacedReferences");
    __name(deepCopy, "deepCopy");
    __name(makeAllResourceChangesImports, "makeAllResourceChangesImports");
    __name(normalize, "normalize");
  }
});

// ../@aws-cdk/cloudformation-diff/lib/format-foreach.ts
var format_foreach_exports = {};
__export(format_foreach_exports, {
  ForEachDiffFormatter: () => ForEachDiffFormatter,
  isForEachKey: () => isForEachKey
});
function isForEachKey(logicalId) {
  return logicalId.startsWith("Fn::ForEach::");
}
var chalk5, ADDITION, UPDATE, REMOVAL, ForEachDiffFormatter;
var init_format_foreach = __esm({
  "../@aws-cdk/cloudformation-diff/lib/format-foreach.ts"() {
    "use strict";
    chalk5 = __toESM(require_source());
    init_util4();
    ADDITION = chalk5.green("[+]");
    UPDATE = chalk5.yellow("[~]");
    REMOVAL = chalk5.red("[-]");
    ForEachDiffFormatter = class {
      static {
        __name(this, "ForEachDiffFormatter");
      }
      /**
       * Format a ForEach resource difference
       */
      formatForEach(key, oldValue, newValue) {
        const lines = [];
        const changeType = this.getChangeType(oldValue, newValue);
        const value = newValue ?? oldValue;
        if (!Array.isArray(value) || value.length < 2) {
          lines.push(`${this.changeSymbol(changeType)} ${chalk5.cyan(key)} (unrecognized ForEach structure)`);
          return lines;
        }
        const loopName = key.replace("Fn::ForEach::", "");
        const [collection, templateObj] = value;
        const entries = Object.entries(templateObj);
        if (entries.length === 0) {
          lines.push(`${this.changeSymbol(changeType)} ${chalk5.cyan(key)} (empty ForEach template)`);
          return lines;
        }
        const [[templateKey, templateValue]] = entries;
        const count = Array.isArray(collection) ? `${collection.length} resources` : "dynamic count";
        lines.push(
          `${this.changeSymbol(changeType)} ${chalk5.cyan(key)} (expands to ${count} at deploy time)`
        );
        lines.push(`    Loop variable: ${chalk5.blue(loopName)}`);
        lines.push(`    Collection: ${this.formatCollection(collection)}`);
        lines.push(`    \u2514\u2500\u2500 ${templateKey} ${chalk5.cyan(templateValue?.Type ?? "Unknown")}`);
        if (changeType === "update" && oldValue && newValue) {
          const oldProps = oldValue[1]?.[Object.keys(oldValue[1])[0]]?.Properties ?? {};
          const newProps = newValue[1]?.[Object.keys(newValue[1])[0]]?.Properties ?? {};
          const propDiff = this.diffProperties(oldProps, newProps);
          lines.push(...propDiff.map((l20) => `        ${l20}`));
        } else {
          for (const [propKey, propValue] of Object.entries(templateValue?.Properties ?? {})) {
            lines.push(`        ${propKey}: ${this.formatValue(propValue)}`);
          }
        }
        return lines;
      }
      changeSymbol(type) {
        switch (type) {
          case "add":
            return ADDITION;
          case "remove":
            return REMOVAL;
          case "update":
            return UPDATE;
        }
      }
      formatCollection(collection) {
        if (Array.isArray(collection)) {
          if (collection.length <= 5) return JSON.stringify(collection);
          return `[${collection.slice(0, 3).join(", ")}, ... +${collection.length - 3} more]`;
        }
        return JSON.stringify(collection);
      }
      getChangeType(oldVal, newVal) {
        if (!oldVal) return "add";
        if (!newVal) return "remove";
        return "update";
      }
      formatValue(value) {
        if (typeof value === "string") return value;
        return JSON.stringify(value);
      }
      diffProperties(oldProps, newProps) {
        const lines = [];
        const allKeys = /* @__PURE__ */ new Set([...Object.keys(oldProps), ...Object.keys(newProps)]);
        for (const key of allKeys) {
          const oldVal = oldProps[key];
          const newVal = newProps[key];
          if (oldVal === void 0) {
            lines.push(`${ADDITION} ${key}: ${this.formatValue(newVal)}`);
          } else if (newVal === void 0) {
            lines.push(`${REMOVAL} ${key}: ${this.formatValue(oldVal)}`);
          } else if (!deepEqual(oldVal, newVal)) {
            lines.push(`${UPDATE} ${key}: ${this.formatValue(oldVal)} \u2192 ${this.formatValue(newVal)}`);
          }
        }
        return lines;
      }
    };
    __name(isForEachKey, "isForEachKey");
  }
});

// ../../node_modules/ansi-regex/index.js
var require_ansi_regex = __commonJS({
  "../../node_modules/ansi-regex/index.js"(exports2, module2) {
    "use strict";
    module2.exports = ({ onlyFirst = false } = {}) => {
      const pattern = [
        "[\\u001B\\u009B][[\\]()#;?]*(?:(?:(?:(?:;[-a-zA-Z\\d\\/#&.:=?%@~_]+)*|[a-zA-Z\\d]+(?:;[-a-zA-Z\\d\\/#&.:=?%@~_]*)*)?\\u0007)",
        "(?:(?:\\d{1,4}(?:;\\d{0,4})*)?[\\dA-PR-TZcf-ntqry=><~]))"
      ].join("|");
      return new RegExp(pattern, onlyFirst ? void 0 : "g");
    };
  }
});

// ../../node_modules/strip-ansi/index.js
var require_strip_ansi = __commonJS({
  "../../node_modules/strip-ansi/index.js"(exports2, module2) {
    "use strict";
    var ansiRegex = require_ansi_regex();
    module2.exports = (string) => typeof string === "string" ? string.replace(ansiRegex(), "") : string;
  }
});

// ../../node_modules/is-fullwidth-code-point/index.js
var require_is_fullwidth_code_point = __commonJS({
  "../../node_modules/is-fullwidth-code-point/index.js"(exports2, module2) {
    "use strict";
    var isFullwidthCodePoint = /* @__PURE__ */ __name((codePoint) => {
      if (Number.isNaN(codePoint)) {
        return false;
      }
      if (codePoint >= 4352 && (codePoint <= 4447 || // Hangul Jamo
      codePoint === 9001 || // LEFT-POINTING ANGLE BRACKET
      codePoint === 9002 || // RIGHT-POINTING ANGLE BRACKET
      // CJK Radicals Supplement .. Enclosed CJK Letters and Months
      11904 <= codePoint && codePoint <= 12871 && codePoint !== 12351 || // Enclosed CJK Letters and Months .. CJK Unified Ideographs Extension A
      12880 <= codePoint && codePoint <= 19903 || // CJK Unified Ideographs .. Yi Radicals
      19968 <= codePoint && codePoint <= 42182 || // Hangul Jamo Extended-A
      43360 <= codePoint && codePoint <= 43388 || // Hangul Syllables
      44032 <= codePoint && codePoint <= 55203 || // CJK Compatibility Ideographs
      63744 <= codePoint && codePoint <= 64255 || // Vertical Forms
      65040 <= codePoint && codePoint <= 65049 || // CJK Compatibility Forms .. Small Form Variants
      65072 <= codePoint && codePoint <= 65131 || // Halfwidth and Fullwidth Forms
      65281 <= codePoint && codePoint <= 65376 || 65504 <= codePoint && codePoint <= 65510 || // Kana Supplement
      110592 <= codePoint && codePoint <= 110593 || // Enclosed Ideographic Supplement
      127488 <= codePoint && codePoint <= 127569 || // CJK Unified Ideographs Extension B .. Tertiary Ideographic Plane
      131072 <= codePoint && codePoint <= 262141)) {
        return true;
      }
      return false;
    }, "isFullwidthCodePoint");
    module2.exports = isFullwidthCodePoint;
    module2.exports.default = isFullwidthCodePoint;
  }
});

// ../../node_modules/emoji-regex/index.js
var require_emoji_regex = __commonJS({
  "../../node_modules/emoji-regex/index.js"(exports2, module2) {
    "use strict";
    module2.exports = function() {
      return /\uD83C\uDFF4\uDB40\uDC67\uDB40\uDC62(?:\uDB40\uDC65\uDB40\uDC6E\uDB40\uDC67|\uDB40\uDC73\uDB40\uDC63\uDB40\uDC74|\uDB40\uDC77\uDB40\uDC6C\uDB40\uDC73)\uDB40\uDC7F|\uD83D\uDC68(?:\uD83C\uDFFC\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68\uD83C\uDFFB|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFF\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFE])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFE\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFD])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFD\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB\uDFFC])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\u200D(?:\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D)?\uD83D\uDC68|(?:\uD83D[\uDC68\uDC69])\u200D(?:\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67]))|\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67])|(?:\uD83D[\uDC68\uDC69])\u200D(?:\uD83D[\uDC66\uDC67])|[\u2695\u2696\u2708]\uFE0F|\uD83D[\uDC66\uDC67]|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|(?:\uD83C\uDFFB\u200D[\u2695\u2696\u2708]|\uD83C\uDFFF\u200D[\u2695\u2696\u2708]|\uD83C\uDFFE\u200D[\u2695\u2696\u2708]|\uD83C\uDFFD\u200D[\u2695\u2696\u2708]|\uD83C\uDFFC\u200D[\u2695\u2696\u2708])\uFE0F|\uD83C\uDFFB\u200D(?:\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C[\uDFFB-\uDFFF])|(?:\uD83E\uDDD1\uD83C\uDFFB\u200D\uD83E\uDD1D\u200D\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFC\u200D\uD83E\uDD1D\u200D\uD83D\uDC69)\uD83C\uDFFB|\uD83E\uDDD1(?:\uD83C\uDFFF\u200D\uD83E\uDD1D\u200D\uD83E\uDDD1(?:\uD83C[\uDFFB-\uDFFF])|\u200D\uD83E\uDD1D\u200D\uD83E\uDDD1)|(?:\uD83E\uDDD1\uD83C\uDFFE\u200D\uD83E\uDD1D\u200D\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFF\u200D\uD83E\uDD1D\u200D(?:\uD83D[\uDC68\uDC69]))(?:\uD83C[\uDFFB-\uDFFE])|(?:\uD83E\uDDD1\uD83C\uDFFC\u200D\uD83E\uDD1D\u200D\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFD\u200D\uD83E\uDD1D\u200D\uD83D\uDC69)(?:\uD83C[\uDFFB\uDFFC])|\uD83D\uDC69(?:\uD83C\uDFFE\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB-\uDFFD\uDFFF])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFC\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB\uDFFD-\uDFFF])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFB\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFC-\uDFFF])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFD\u200D(?:\uD83E\uDD1D\u200D\uD83D\uDC68(?:\uD83C[\uDFFB\uDFFC\uDFFE\uDFFF])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\u200D(?:\u2764\uFE0F\u200D(?:\uD83D\uDC8B\u200D(?:\uD83D[\uDC68\uDC69])|\uD83D[\uDC68\uDC69])|\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD])|\uD83C\uDFFF\u200D(?:\uD83C[\uDF3E\uDF73\uDF93\uDFA4\uDFA8\uDFEB\uDFED]|\uD83D[\uDCBB\uDCBC\uDD27\uDD2C\uDE80\uDE92]|\uD83E[\uDDAF-\uDDB3\uDDBC\uDDBD]))|\uD83D\uDC69\u200D\uD83D\uDC69\u200D(?:\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67]))|(?:\uD83E\uDDD1\uD83C\uDFFD\u200D\uD83E\uDD1D\u200D\uD83E\uDDD1|\uD83D\uDC69\uD83C\uDFFE\u200D\uD83E\uDD1D\u200D\uD83D\uDC69)(?:\uD83C[\uDFFB-\uDFFD])|\uD83D\uDC69\u200D\uD83D\uDC66\u200D\uD83D\uDC66|\uD83D\uDC69\u200D\uD83D\uDC69\u200D(?:\uD83D[\uDC66\uDC67])|(?:\uD83D\uDC41\uFE0F\u200D\uD83D\uDDE8|\uD83D\uDC69(?:\uD83C\uDFFF\u200D[\u2695\u2696\u2708]|\uD83C\uDFFE\u200D[\u2695\u2696\u2708]|\uD83C\uDFFC\u200D[\u2695\u2696\u2708]|\uD83C\uDFFB\u200D[\u2695\u2696\u2708]|\uD83C\uDFFD\u200D[\u2695\u2696\u2708]|\u200D[\u2695\u2696\u2708])|(?:(?:\u26F9|\uD83C[\uDFCB\uDFCC]|\uD83D\uDD75)\uFE0F|\uD83D\uDC6F|\uD83E[\uDD3C\uDDDE\uDDDF])\u200D[\u2640\u2642]|(?:\u26F9|\uD83C[\uDFCB\uDFCC]|\uD83D\uDD75)(?:\uD83C[\uDFFB-\uDFFF])\u200D[\u2640\u2642]|(?:\uD83C[\uDFC3\uDFC4\uDFCA]|\uD83D[\uDC6E\uDC71\uDC73\uDC77\uDC81\uDC82\uDC86\uDC87\uDE45-\uDE47\uDE4B\uDE4D\uDE4E\uDEA3\uDEB4-\uDEB6]|\uD83E[\uDD26\uDD37-\uDD39\uDD3D\uDD3E\uDDB8\uDDB9\uDDCD-\uDDCF\uDDD6-\uDDDD])(?:(?:\uD83C[\uDFFB-\uDFFF])\u200D[\u2640\u2642]|\u200D[\u2640\u2642])|\uD83C\uDFF4\u200D\u2620)\uFE0F|\uD83D\uDC69\u200D\uD83D\uDC67\u200D(?:\uD83D[\uDC66\uDC67])|\uD83C\uDFF3\uFE0F\u200D\uD83C\uDF08|\uD83D\uDC15\u200D\uD83E\uDDBA|\uD83D\uDC69\u200D\uD83D\uDC66|\uD83D\uDC69\u200D\uD83D\uDC67|\uD83C\uDDFD\uD83C\uDDF0|\uD83C\uDDF4\uD83C\uDDF2|\uD83C\uDDF6\uD83C\uDDE6|[#\*0-9]\uFE0F\u20E3|\uD83C\uDDE7(?:\uD83C[\uDDE6\uDDE7\uDDE9-\uDDEF\uDDF1-\uDDF4\uDDF6-\uDDF9\uDDFB\uDDFC\uDDFE\uDDFF])|\uD83C\uDDF9(?:\uD83C[\uDDE6\uDDE8\uDDE9\uDDEB-\uDDED\uDDEF-\uDDF4\uDDF7\uDDF9\uDDFB\uDDFC\uDDFF])|\uD83C\uDDEA(?:\uD83C[\uDDE6\uDDE8\uDDEA\uDDEC\uDDED\uDDF7-\uDDFA])|\uD83E\uDDD1(?:\uD83C[\uDFFB-\uDFFF])|\uD83C\uDDF7(?:\uD83C[\uDDEA\uDDF4\uDDF8\uDDFA\uDDFC])|\uD83D\uDC69(?:\uD83C[\uDFFB-\uDFFF])|\uD83C\uDDF2(?:\uD83C[\uDDE6\uDDE8-\uDDED\uDDF0-\uDDFF])|\uD83C\uDDE6(?:\uD83C[\uDDE8-\uDDEC\uDDEE\uDDF1\uDDF2\uDDF4\uDDF6-\uDDFA\uDDFC\uDDFD\uDDFF])|\uD83C\uDDF0(?:\uD83C[\uDDEA\uDDEC-\uDDEE\uDDF2\uDDF3\uDDF5\uDDF7\uDDFC\uDDFE\uDDFF])|\uD83C\uDDED(?:\uD83C[\uDDF0\uDDF2\uDDF3\uDDF7\uDDF9\uDDFA])|\uD83C\uDDE9(?:\uD83C[\uDDEA\uDDEC\uDDEF\uDDF0\uDDF2\uDDF4\uDDFF])|\uD83C\uDDFE(?:\uD83C[\uDDEA\uDDF9])|\uD83C\uDDEC(?:\uD83C[\uDDE6\uDDE7\uDDE9-\uDDEE\uDDF1-\uDDF3\uDDF5-\uDDFA\uDDFC\uDDFE])|\uD83C\uDDF8(?:\uD83C[\uDDE6-\uDDEA\uDDEC-\uDDF4\uDDF7-\uDDF9\uDDFB\uDDFD-\uDDFF])|\uD83C\uDDEB(?:\uD83C[\uDDEE-\uDDF0\uDDF2\uDDF4\uDDF7])|\uD83C\uDDF5(?:\uD83C[\uDDE6\uDDEA-\uDDED\uDDF0-\uDDF3\uDDF7-\uDDF9\uDDFC\uDDFE])|\uD83C\uDDFB(?:\uD83C[\uDDE6\uDDE8\uDDEA\uDDEC\uDDEE\uDDF3\uDDFA])|\uD83C\uDDF3(?:\uD83C[\uDDE6\uDDE8\uDDEA-\uDDEC\uDDEE\uDDF1\uDDF4\uDDF5\uDDF7\uDDFA\uDDFF])|\uD83C\uDDE8(?:\uD83C[\uDDE6\uDDE8\uDDE9\uDDEB-\uDDEE\uDDF0-\uDDF5\uDDF7\uDDFA-\uDDFF])|\uD83C\uDDF1(?:\uD83C[\uDDE6-\uDDE8\uDDEE\uDDF0\uDDF7-\uDDFB\uDDFE])|\uD83C\uDDFF(?:\uD83C[\uDDE6\uDDF2\uDDFC])|\uD83C\uDDFC(?:\uD83C[\uDDEB\uDDF8])|\uD83C\uDDFA(?:\uD83C[\uDDE6\uDDEC\uDDF2\uDDF3\uDDF8\uDDFE\uDDFF])|\uD83C\uDDEE(?:\uD83C[\uDDE8-\uDDEA\uDDF1-\uDDF4\uDDF6-\uDDF9])|\uD83C\uDDEF(?:\uD83C[\uDDEA\uDDF2\uDDF4\uDDF5])|(?:\uD83C[\uDFC3\uDFC4\uDFCA]|\uD83D[\uDC6E\uDC71\uDC73\uDC77\uDC81\uDC82\uDC86\uDC87\uDE45-\uDE47\uDE4B\uDE4D\uDE4E\uDEA3\uDEB4-\uDEB6]|\uD83E[\uDD26\uDD37-\uDD39\uDD3D\uDD3E\uDDB8\uDDB9\uDDCD-\uDDCF\uDDD6-\uDDDD])(?:\uD83C[\uDFFB-\uDFFF])|(?:\u26F9|\uD83C[\uDFCB\uDFCC]|\uD83D\uDD75)(?:\uD83C[\uDFFB-\uDFFF])|(?:[\u261D\u270A-\u270D]|\uD83C[\uDF85\uDFC2\uDFC7]|\uD83D[\uDC42\uDC43\uDC46-\uDC50\uDC66\uDC67\uDC6B-\uDC6D\uDC70\uDC72\uDC74-\uDC76\uDC78\uDC7C\uDC83\uDC85\uDCAA\uDD74\uDD7A\uDD90\uDD95\uDD96\uDE4C\uDE4F\uDEC0\uDECC]|\uD83E[\uDD0F\uDD18-\uDD1C\uDD1E\uDD1F\uDD30-\uDD36\uDDB5\uDDB6\uDDBB\uDDD2-\uDDD5])(?:\uD83C[\uDFFB-\uDFFF])|(?:[\u231A\u231B\u23E9-\u23EC\u23F0\u23F3\u25FD\u25FE\u2614\u2615\u2648-\u2653\u267F\u2693\u26A1\u26AA\u26AB\u26BD\u26BE\u26C4\u26C5\u26CE\u26D4\u26EA\u26F2\u26F3\u26F5\u26FA\u26FD\u2705\u270A\u270B\u2728\u274C\u274E\u2753-\u2755\u2757\u2795-\u2797\u27B0\u27BF\u2B1B\u2B1C\u2B50\u2B55]|\uD83C[\uDC04\uDCCF\uDD8E\uDD91-\uDD9A\uDDE6-\uDDFF\uDE01\uDE1A\uDE2F\uDE32-\uDE36\uDE38-\uDE3A\uDE50\uDE51\uDF00-\uDF20\uDF2D-\uDF35\uDF37-\uDF7C\uDF7E-\uDF93\uDFA0-\uDFCA\uDFCF-\uDFD3\uDFE0-\uDFF0\uDFF4\uDFF8-\uDFFF]|\uD83D[\uDC00-\uDC3E\uDC40\uDC42-\uDCFC\uDCFF-\uDD3D\uDD4B-\uDD4E\uDD50-\uDD67\uDD7A\uDD95\uDD96\uDDA4\uDDFB-\uDE4F\uDE80-\uDEC5\uDECC\uDED0-\uDED2\uDED5\uDEEB\uDEEC\uDEF4-\uDEFA\uDFE0-\uDFEB]|\uD83E[\uDD0D-\uDD3A\uDD3C-\uDD45\uDD47-\uDD71\uDD73-\uDD76\uDD7A-\uDDA2\uDDA5-\uDDAA\uDDAE-\uDDCA\uDDCD-\uDDFF\uDE70-\uDE73\uDE78-\uDE7A\uDE80-\uDE82\uDE90-\uDE95])|(?:[#\*0-9\xA9\xAE\u203C\u2049\u2122\u2139\u2194-\u2199\u21A9\u21AA\u231A\u231B\u2328\u23CF\u23E9-\u23F3\u23F8-\u23FA\u24C2\u25AA\u25AB\u25B6\u25C0\u25FB-\u25FE\u2600-\u2604\u260E\u2611\u2614\u2615\u2618\u261D\u2620\u2622\u2623\u2626\u262A\u262E\u262F\u2638-\u263A\u2640\u2642\u2648-\u2653\u265F\u2660\u2663\u2665\u2666\u2668\u267B\u267E\u267F\u2692-\u2697\u2699\u269B\u269C\u26A0\u26A1\u26AA\u26AB\u26B0\u26B1\u26BD\u26BE\u26C4\u26C5\u26C8\u26CE\u26CF\u26D1\u26D3\u26D4\u26E9\u26EA\u26F0-\u26F5\u26F7-\u26FA\u26FD\u2702\u2705\u2708-\u270D\u270F\u2712\u2714\u2716\u271D\u2721\u2728\u2733\u2734\u2744\u2747\u274C\u274E\u2753-\u2755\u2757\u2763\u2764\u2795-\u2797\u27A1\u27B0\u27BF\u2934\u2935\u2B05-\u2B07\u2B1B\u2B1C\u2B50\u2B55\u3030\u303D\u3297\u3299]|\uD83C[\uDC04\uDCCF\uDD70\uDD71\uDD7E\uDD7F\uDD8E\uDD91-\uDD9A\uDDE6-\uDDFF\uDE01\uDE02\uDE1A\uDE2F\uDE32-\uDE3A\uDE50\uDE51\uDF00-\uDF21\uDF24-\uDF93\uDF96\uDF97\uDF99-\uDF9B\uDF9E-\uDFF0\uDFF3-\uDFF5\uDFF7-\uDFFF]|\uD83D[\uDC00-\uDCFD\uDCFF-\uDD3D\uDD49-\uDD4E\uDD50-\uDD67\uDD6F\uDD70\uDD73-\uDD7A\uDD87\uDD8A-\uDD8D\uDD90\uDD95\uDD96\uDDA4\uDDA5\uDDA8\uDDB1\uDDB2\uDDBC\uDDC2-\uDDC4\uDDD1-\uDDD3\uDDDC-\uDDDE\uDDE1\uDDE3\uDDE8\uDDEF\uDDF3\uDDFA-\uDE4F\uDE80-\uDEC5\uDECB-\uDED2\uDED5\uDEE0-\uDEE5\uDEE9\uDEEB\uDEEC\uDEF0\uDEF3-\uDEFA\uDFE0-\uDFEB]|\uD83E[\uDD0D-\uDD3A\uDD3C-\uDD45\uDD47-\uDD71\uDD73-\uDD76\uDD7A-\uDDA2\uDDA5-\uDDAA\uDDAE-\uDDCA\uDDCD-\uDDFF\uDE70-\uDE73\uDE78-\uDE7A\uDE80-\uDE82\uDE90-\uDE95])\uFE0F|(?:[\u261D\u26F9\u270A-\u270D]|\uD83C[\uDF85\uDFC2-\uDFC4\uDFC7\uDFCA-\uDFCC]|\uD83D[\uDC42\uDC43\uDC46-\uDC50\uDC66-\uDC78\uDC7C\uDC81-\uDC83\uDC85-\uDC87\uDC8F\uDC91\uDCAA\uDD74\uDD75\uDD7A\uDD90\uDD95\uDD96\uDE45-\uDE47\uDE4B-\uDE4F\uDEA3\uDEB4-\uDEB6\uDEC0\uDECC]|\uD83E[\uDD0F\uDD18-\uDD1F\uDD26\uDD30-\uDD39\uDD3C-\uDD3E\uDDB5\uDDB6\uDDB8\uDDB9\uDDBB\uDDCD-\uDDCF\uDDD1-\uDDDD])/g;
    };
  }
});

// ../../node_modules/string-width/index.js
var require_string_width = __commonJS({
  "../../node_modules/string-width/index.js"(exports2, module2) {
    "use strict";
    var stripAnsi2 = require_strip_ansi();
    var isFullwidthCodePoint = require_is_fullwidth_code_point();
    var emojiRegex = require_emoji_regex();
    var stringWidth2 = /* @__PURE__ */ __name((string) => {
      if (typeof string !== "string" || string.length === 0) {
        return 0;
      }
      string = stripAnsi2(string);
      if (string.length === 0) {
        return 0;
      }
      string = string.replace(emojiRegex(), "  ");
      let width = 0;
      for (let i32 = 0; i32 < string.length; i32++) {
        const code = string.codePointAt(i32);
        if (code <= 31 || code >= 127 && code <= 159) {
          continue;
        }
        if (code >= 768 && code <= 879) {
          continue;
        }
        if (code > 65535) {
          i32++;
        }
        width += isFullwidthCodePoint(code) ? 2 : 1;
      }
      return width;
    }, "stringWidth");
    module2.exports = stringWidth2;
    module2.exports.default = stringWidth2;
  }
});

// ../../node_modules/astral-regex/index.js
var require_astral_regex = __commonJS({
  "../../node_modules/astral-regex/index.js"(exports2, module2) {
    "use strict";
    var regex = "[\uD800-\uDBFF][\uDC00-\uDFFF]";
    var astralRegex = /* @__PURE__ */ __name((options) => options && options.exact ? new RegExp(`^${regex}$`) : new RegExp(regex, "g"), "astralRegex");
    module2.exports = astralRegex;
  }
});

// ../../node_modules/slice-ansi/index.js
var require_slice_ansi = __commonJS({
  "../../node_modules/slice-ansi/index.js"(exports2, module2) {
    "use strict";
    var isFullwidthCodePoint = require_is_fullwidth_code_point();
    var astralRegex = require_astral_regex();
    var ansiStyles = require_ansi_styles();
    var ESCAPES = [
      "\x1B",
      "\x9B"
    ];
    var wrapAnsi2 = /* @__PURE__ */ __name((code) => `${ESCAPES[0]}[${code}m`, "wrapAnsi");
    var checkAnsi = /* @__PURE__ */ __name((ansiCodes, isEscapes, endAnsiCode) => {
      let output = [];
      ansiCodes = [...ansiCodes];
      for (let ansiCode of ansiCodes) {
        const ansiCodeOrigin = ansiCode;
        if (ansiCode.includes(";")) {
          ansiCode = ansiCode.split(";")[0][0] + "0";
        }
        const item = ansiStyles.codes.get(Number.parseInt(ansiCode, 10));
        if (item) {
          const indexEscape = ansiCodes.indexOf(item.toString());
          if (indexEscape === -1) {
            output.push(wrapAnsi2(isEscapes ? item : ansiCodeOrigin));
          } else {
            ansiCodes.splice(indexEscape, 1);
          }
        } else if (isEscapes) {
          output.push(wrapAnsi2(0));
          break;
        } else {
          output.push(wrapAnsi2(ansiCodeOrigin));
        }
      }
      if (isEscapes) {
        output = output.filter((element, index) => output.indexOf(element) === index);
        if (endAnsiCode !== void 0) {
          const fistEscapeCode = wrapAnsi2(ansiStyles.codes.get(Number.parseInt(endAnsiCode, 10)));
          output = output.reduce((current, next) => next === fistEscapeCode ? [next, ...current] : [...current, next], []);
        }
      }
      return output.join("");
    }, "checkAnsi");
    module2.exports = (string, begin, end) => {
      const characters = [...string];
      const ansiCodes = [];
      let stringEnd = typeof end === "number" ? end : characters.length;
      let isInsideEscape = false;
      let ansiCode;
      let visible = 0;
      let output = "";
      for (const [index, character] of characters.entries()) {
        let leftEscape = false;
        if (ESCAPES.includes(character)) {
          const code = /\d[^m]*/.exec(string.slice(index, index + 18));
          ansiCode = code && code.length > 0 ? code[0] : void 0;
          if (visible < stringEnd) {
            isInsideEscape = true;
            if (ansiCode !== void 0) {
              ansiCodes.push(ansiCode);
            }
          }
        } else if (isInsideEscape && character === "m") {
          isInsideEscape = false;
          leftEscape = true;
        }
        if (!isInsideEscape && !leftEscape) {
          visible++;
        }
        if (!astralRegex({ exact: true }).test(character) && isFullwidthCodePoint(character.codePointAt())) {
          visible++;
          if (typeof end !== "number") {
            stringEnd++;
          }
        }
        if (visible > begin && visible <= stringEnd) {
          output += character;
        } else if (visible === begin && !isInsideEscape && ansiCode !== void 0) {
          output = checkAnsi(ansiCodes);
        } else if (visible >= stringEnd) {
          output += checkAnsi(ansiCodes, true, ansiCode);
          break;
        }
      }
      return output;
    };
  }
});

// ../../node_modules/table/dist/src/getBorderCharacters.js
var require_getBorderCharacters = __commonJS({
  "../../node_modules/table/dist/src/getBorderCharacters.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getBorderCharacters = void 0;
    var getBorderCharacters = /* @__PURE__ */ __name((name) => {
      if (name === "honeywell") {
        return {
          topBody: "\u2550",
          topJoin: "\u2564",
          topLeft: "\u2554",
          topRight: "\u2557",
          bottomBody: "\u2550",
          bottomJoin: "\u2567",
          bottomLeft: "\u255A",
          bottomRight: "\u255D",
          bodyLeft: "\u2551",
          bodyRight: "\u2551",
          bodyJoin: "\u2502",
          headerJoin: "\u252C",
          joinBody: "\u2500",
          joinLeft: "\u255F",
          joinRight: "\u2562",
          joinJoin: "\u253C",
          joinMiddleDown: "\u252C",
          joinMiddleUp: "\u2534",
          joinMiddleLeft: "\u2524",
          joinMiddleRight: "\u251C"
        };
      }
      if (name === "norc") {
        return {
          topBody: "\u2500",
          topJoin: "\u252C",
          topLeft: "\u250C",
          topRight: "\u2510",
          bottomBody: "\u2500",
          bottomJoin: "\u2534",
          bottomLeft: "\u2514",
          bottomRight: "\u2518",
          bodyLeft: "\u2502",
          bodyRight: "\u2502",
          bodyJoin: "\u2502",
          headerJoin: "\u252C",
          joinBody: "\u2500",
          joinLeft: "\u251C",
          joinRight: "\u2524",
          joinJoin: "\u253C",
          joinMiddleDown: "\u252C",
          joinMiddleUp: "\u2534",
          joinMiddleLeft: "\u2524",
          joinMiddleRight: "\u251C"
        };
      }
      if (name === "ramac") {
        return {
          topBody: "-",
          topJoin: "+",
          topLeft: "+",
          topRight: "+",
          bottomBody: "-",
          bottomJoin: "+",
          bottomLeft: "+",
          bottomRight: "+",
          bodyLeft: "|",
          bodyRight: "|",
          bodyJoin: "|",
          headerJoin: "+",
          joinBody: "-",
          joinLeft: "|",
          joinRight: "|",
          joinJoin: "|",
          joinMiddleDown: "+",
          joinMiddleUp: "+",
          joinMiddleLeft: "+",
          joinMiddleRight: "+"
        };
      }
      if (name === "void") {
        return {
          topBody: "",
          topJoin: "",
          topLeft: "",
          topRight: "",
          bottomBody: "",
          bottomJoin: "",
          bottomLeft: "",
          bottomRight: "",
          bodyLeft: "",
          bodyRight: "",
          bodyJoin: "",
          headerJoin: "",
          joinBody: "",
          joinLeft: "",
          joinRight: "",
          joinJoin: "",
          joinMiddleDown: "",
          joinMiddleUp: "",
          joinMiddleLeft: "",
          joinMiddleRight: ""
        };
      }
      throw new Error('Unknown border template "' + name + '".');
    }, "getBorderCharacters");
    exports2.getBorderCharacters = getBorderCharacters;
  }
});

// ../../node_modules/table/dist/src/utils.js
var require_utils8 = __commonJS({
  "../../node_modules/table/dist/src/utils.js"(exports2) {
    "use strict";
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isCellInRange = exports2.areCellEqual = exports2.calculateRangeCoordinate = exports2.flatten = exports2.extractTruncates = exports2.sumArray = exports2.sequence = exports2.distributeUnevenly = exports2.countSpaceSequence = exports2.groupBySizes = exports2.makeBorderConfig = exports2.splitAnsi = exports2.normalizeString = void 0;
    var slice_ansi_1 = __importDefault2(require_slice_ansi());
    var string_width_1 = __importDefault2(require_string_width());
    var strip_ansi_1 = __importDefault2(require_strip_ansi());
    var getBorderCharacters_1 = require_getBorderCharacters();
    var normalizeString = /* @__PURE__ */ __name((input) => {
      return input.replace(/\r\n/g, "\n");
    }, "normalizeString");
    exports2.normalizeString = normalizeString;
    var splitAnsi = /* @__PURE__ */ __name((input) => {
      const lengths = (0, strip_ansi_1.default)(input).split("\n").map(string_width_1.default);
      const result2 = [];
      let startIndex = 0;
      lengths.forEach((length) => {
        result2.push(length === 0 ? "" : (0, slice_ansi_1.default)(input, startIndex, startIndex + length));
        startIndex += length + 1;
      });
      return result2;
    }, "splitAnsi");
    exports2.splitAnsi = splitAnsi;
    var makeBorderConfig = /* @__PURE__ */ __name((border) => {
      return {
        ...(0, getBorderCharacters_1.getBorderCharacters)("honeywell"),
        ...border
      };
    }, "makeBorderConfig");
    exports2.makeBorderConfig = makeBorderConfig;
    var groupBySizes = /* @__PURE__ */ __name((array, sizes) => {
      let startIndex = 0;
      return sizes.map((size) => {
        const group7 = array.slice(startIndex, startIndex + size);
        startIndex += size;
        return group7;
      });
    }, "groupBySizes");
    exports2.groupBySizes = groupBySizes;
    var countSpaceSequence = /* @__PURE__ */ __name((input) => {
      var _a10, _b;
      return (_b = (_a10 = input.match(/\s+/g)) === null || _a10 === void 0 ? void 0 : _a10.length) !== null && _b !== void 0 ? _b : 0;
    }, "countSpaceSequence");
    exports2.countSpaceSequence = countSpaceSequence;
    var distributeUnevenly = /* @__PURE__ */ __name((sum4, length) => {
      const result2 = Array.from({ length }).fill(Math.floor(sum4 / length));
      return result2.map((element, index) => {
        return element + (index < sum4 % length ? 1 : 0);
      });
    }, "distributeUnevenly");
    exports2.distributeUnevenly = distributeUnevenly;
    var sequence = /* @__PURE__ */ __name((start, end) => {
      return Array.from({ length: end - start + 1 }, (_, index) => {
        return index + start;
      });
    }, "sequence");
    exports2.sequence = sequence;
    var sumArray = /* @__PURE__ */ __name((array) => {
      return array.reduce((accumulator, element) => {
        return accumulator + element;
      }, 0);
    }, "sumArray");
    exports2.sumArray = sumArray;
    var extractTruncates = /* @__PURE__ */ __name((config2) => {
      return config2.columns.map(({ truncate }) => {
        return truncate;
      });
    }, "extractTruncates");
    exports2.extractTruncates = extractTruncates;
    var flatten3 = /* @__PURE__ */ __name((array) => {
      return [].concat(...array);
    }, "flatten");
    exports2.flatten = flatten3;
    var calculateRangeCoordinate = /* @__PURE__ */ __name((spanningCellConfig) => {
      const { row, col, colSpan = 1, rowSpan = 1 } = spanningCellConfig;
      return {
        bottomRight: {
          col: col + colSpan - 1,
          row: row + rowSpan - 1
        },
        topLeft: {
          col,
          row
        }
      };
    }, "calculateRangeCoordinate");
    exports2.calculateRangeCoordinate = calculateRangeCoordinate;
    var areCellEqual = /* @__PURE__ */ __name((cell1, cell2) => {
      return cell1.row === cell2.row && cell1.col === cell2.col;
    }, "areCellEqual");
    exports2.areCellEqual = areCellEqual;
    var isCellInRange = /* @__PURE__ */ __name((cell, { topLeft, bottomRight }) => {
      return topLeft.row <= cell.row && cell.row <= bottomRight.row && topLeft.col <= cell.col && cell.col <= bottomRight.col;
    }, "isCellInRange");
    exports2.isCellInRange = isCellInRange;
  }
});

// ../../node_modules/table/dist/src/alignString.js
var require_alignString = __commonJS({
  "../../node_modules/table/dist/src/alignString.js"(exports2) {
    "use strict";
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.alignString = void 0;
    var string_width_1 = __importDefault2(require_string_width());
    var utils_1 = require_utils8();
    var alignLeft = /* @__PURE__ */ __name((subject, width) => {
      return subject + " ".repeat(width);
    }, "alignLeft");
    var alignRight = /* @__PURE__ */ __name((subject, width) => {
      return " ".repeat(width) + subject;
    }, "alignRight");
    var alignCenter = /* @__PURE__ */ __name((subject, width) => {
      return " ".repeat(Math.floor(width / 2)) + subject + " ".repeat(Math.ceil(width / 2));
    }, "alignCenter");
    var alignJustify = /* @__PURE__ */ __name((subject, width) => {
      const spaceSequenceCount = (0, utils_1.countSpaceSequence)(subject);
      if (spaceSequenceCount === 0) {
        return alignLeft(subject, width);
      }
      const addingSpaces = (0, utils_1.distributeUnevenly)(width, spaceSequenceCount);
      if (Math.max(...addingSpaces) > 3) {
        return alignLeft(subject, width);
      }
      let spaceSequenceIndex = 0;
      return subject.replace(/\s+/g, (groupSpace) => {
        return groupSpace + " ".repeat(addingSpaces[spaceSequenceIndex++]);
      });
    }, "alignJustify");
    var alignString = /* @__PURE__ */ __name((subject, containerWidth, alignment) => {
      const subjectWidth = (0, string_width_1.default)(subject);
      if (subjectWidth === containerWidth) {
        return subject;
      }
      if (subjectWidth > containerWidth) {
        throw new Error("Subject parameter value width cannot be greater than the container width.");
      }
      if (subjectWidth === 0) {
        return " ".repeat(containerWidth);
      }
      const availableWidth = containerWidth - subjectWidth;
      if (alignment === "left") {
        return alignLeft(subject, availableWidth);
      }
      if (alignment === "right") {
        return alignRight(subject, availableWidth);
      }
      if (alignment === "justify") {
        return alignJustify(subject, availableWidth);
      }
      return alignCenter(subject, availableWidth);
    }, "alignString");
    exports2.alignString = alignString;
  }
});

// ../../node_modules/table/dist/src/alignTableData.js
var require_alignTableData = __commonJS({
  "../../node_modules/table/dist/src/alignTableData.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.alignTableData = void 0;
    var alignString_1 = require_alignString();
    var alignTableData = /* @__PURE__ */ __name((rows, config2) => {
      return rows.map((row, rowIndex) => {
        return row.map((cell, cellIndex) => {
          var _a10;
          const { width, alignment } = config2.columns[cellIndex];
          const containingRange = (_a10 = config2.spanningCellManager) === null || _a10 === void 0 ? void 0 : _a10.getContainingRange({
            col: cellIndex,
            row: rowIndex
          }, { mapped: true });
          if (containingRange) {
            return cell;
          }
          return (0, alignString_1.alignString)(cell, width, alignment);
        });
      });
    }, "alignTableData");
    exports2.alignTableData = alignTableData;
  }
});

// ../../node_modules/table/dist/src/wrapString.js
var require_wrapString = __commonJS({
  "../../node_modules/table/dist/src/wrapString.js"(exports2) {
    "use strict";
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.wrapString = void 0;
    var slice_ansi_1 = __importDefault2(require_slice_ansi());
    var string_width_1 = __importDefault2(require_string_width());
    var wrapString = /* @__PURE__ */ __name((subject, size) => {
      let subjectSlice = subject;
      const chunks2 = [];
      do {
        chunks2.push((0, slice_ansi_1.default)(subjectSlice, 0, size));
        subjectSlice = (0, slice_ansi_1.default)(subjectSlice, size).trim();
      } while ((0, string_width_1.default)(subjectSlice));
      return chunks2;
    }, "wrapString");
    exports2.wrapString = wrapString;
  }
});

// ../../node_modules/table/dist/src/wrapWord.js
var require_wrapWord = __commonJS({
  "../../node_modules/table/dist/src/wrapWord.js"(exports2) {
    "use strict";
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.wrapWord = void 0;
    var slice_ansi_1 = __importDefault2(require_slice_ansi());
    var strip_ansi_1 = __importDefault2(require_strip_ansi());
    var calculateStringLengths = /* @__PURE__ */ __name((input, size) => {
      let subject = (0, strip_ansi_1.default)(input);
      const chunks2 = [];
      const re = new RegExp("(^.{1," + String(Math.max(size, 1)) + "}(\\s+|$))|(^.{1," + String(Math.max(size - 1, 1)) + "}(\\\\|/|_|\\.|,|;|-))");
      do {
        let chunk;
        const match = re.exec(subject);
        if (match) {
          chunk = match[0];
          subject = subject.slice(chunk.length);
          const trimmedLength = chunk.trim().length;
          const offset = chunk.length - trimmedLength;
          chunks2.push([trimmedLength, offset]);
        } else {
          chunk = subject.slice(0, size);
          subject = subject.slice(size);
          chunks2.push([chunk.length, 0]);
        }
      } while (subject.length);
      return chunks2;
    }, "calculateStringLengths");
    var wrapWord = /* @__PURE__ */ __name((input, size) => {
      const result2 = [];
      let startIndex = 0;
      calculateStringLengths(input, size).forEach(([length, offset]) => {
        result2.push((0, slice_ansi_1.default)(input, startIndex, startIndex + length));
        startIndex += length + offset;
      });
      return result2;
    }, "wrapWord");
    exports2.wrapWord = wrapWord;
  }
});

// ../../node_modules/table/dist/src/wrapCell.js
var require_wrapCell = __commonJS({
  "../../node_modules/table/dist/src/wrapCell.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.wrapCell = void 0;
    var utils_1 = require_utils8();
    var wrapString_1 = require_wrapString();
    var wrapWord_1 = require_wrapWord();
    var wrapCell = /* @__PURE__ */ __name((cellValue, cellWidth, useWrapWord) => {
      const cellLines = (0, utils_1.splitAnsi)(cellValue);
      for (let lineNr = 0; lineNr < cellLines.length; ) {
        let lineChunks;
        if (useWrapWord) {
          lineChunks = (0, wrapWord_1.wrapWord)(cellLines[lineNr], cellWidth);
        } else {
          lineChunks = (0, wrapString_1.wrapString)(cellLines[lineNr], cellWidth);
        }
        cellLines.splice(lineNr, 1, ...lineChunks);
        lineNr += lineChunks.length;
      }
      return cellLines;
    }, "wrapCell");
    exports2.wrapCell = wrapCell;
  }
});

// ../../node_modules/table/dist/src/calculateCellHeight.js
var require_calculateCellHeight = __commonJS({
  "../../node_modules/table/dist/src/calculateCellHeight.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.calculateCellHeight = void 0;
    var wrapCell_1 = require_wrapCell();
    var calculateCellHeight = /* @__PURE__ */ __name((value, columnWidth, useWrapWord = false) => {
      return (0, wrapCell_1.wrapCell)(value, columnWidth, useWrapWord).length;
    }, "calculateCellHeight");
    exports2.calculateCellHeight = calculateCellHeight;
  }
});

// ../../node_modules/table/dist/src/calculateRowHeights.js
var require_calculateRowHeights = __commonJS({
  "../../node_modules/table/dist/src/calculateRowHeights.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.calculateRowHeights = void 0;
    var calculateCellHeight_1 = require_calculateCellHeight();
    var utils_1 = require_utils8();
    var calculateRowHeights = /* @__PURE__ */ __name((rows, config2) => {
      const rowHeights = [];
      for (const [rowIndex, row] of rows.entries()) {
        let rowHeight = 1;
        row.forEach((cell, cellIndex) => {
          var _a10;
          const containingRange = (_a10 = config2.spanningCellManager) === null || _a10 === void 0 ? void 0 : _a10.getContainingRange({
            col: cellIndex,
            row: rowIndex
          });
          if (!containingRange) {
            const cellHeight = (0, calculateCellHeight_1.calculateCellHeight)(cell, config2.columns[cellIndex].width, config2.columns[cellIndex].wrapWord);
            rowHeight = Math.max(rowHeight, cellHeight);
            return;
          }
          const { topLeft, bottomRight, height } = containingRange;
          if (rowIndex === bottomRight.row) {
            const totalOccupiedSpanningCellHeight = (0, utils_1.sumArray)(rowHeights.slice(topLeft.row));
            const totalHorizontalBorderHeight = bottomRight.row - topLeft.row;
            const totalHiddenHorizontalBorderHeight = (0, utils_1.sequence)(topLeft.row + 1, bottomRight.row).filter((horizontalBorderIndex) => {
              var _a11;
              return !((_a11 = config2.drawHorizontalLine) === null || _a11 === void 0 ? void 0 : _a11.call(config2, horizontalBorderIndex, rows.length));
            }).length;
            const cellHeight = height - totalOccupiedSpanningCellHeight - totalHorizontalBorderHeight + totalHiddenHorizontalBorderHeight;
            rowHeight = Math.max(rowHeight, cellHeight);
          }
        });
        rowHeights.push(rowHeight);
      }
      return rowHeights;
    }, "calculateRowHeights");
    exports2.calculateRowHeights = calculateRowHeights;
  }
});

// ../../node_modules/table/dist/src/drawContent.js
var require_drawContent = __commonJS({
  "../../node_modules/table/dist/src/drawContent.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.drawContent = void 0;
    var drawContent = /* @__PURE__ */ __name((parameters) => {
      const { contents, separatorGetter, drawSeparator, spanningCellManager, rowIndex, elementType } = parameters;
      const contentSize = contents.length;
      const result2 = [];
      if (drawSeparator(0, contentSize)) {
        result2.push(separatorGetter(0, contentSize));
      }
      contents.forEach((content, contentIndex) => {
        if (!elementType || elementType === "border" || elementType === "row") {
          result2.push(content);
        }
        if (elementType === "cell" && rowIndex === void 0) {
          result2.push(content);
        }
        if (elementType === "cell" && rowIndex !== void 0) {
          const containingRange = spanningCellManager === null || spanningCellManager === void 0 ? void 0 : spanningCellManager.getContainingRange({
            col: contentIndex,
            row: rowIndex
          });
          if (!containingRange || contentIndex === containingRange.topLeft.col) {
            result2.push(content);
          }
        }
        if (contentIndex + 1 < contentSize && drawSeparator(contentIndex + 1, contentSize)) {
          const separator = separatorGetter(contentIndex + 1, contentSize);
          if (elementType === "cell" && rowIndex !== void 0) {
            const currentCell = {
              col: contentIndex + 1,
              row: rowIndex
            };
            const containingRange = spanningCellManager === null || spanningCellManager === void 0 ? void 0 : spanningCellManager.getContainingRange(currentCell);
            if (!containingRange || containingRange.topLeft.col === currentCell.col) {
              result2.push(separator);
            }
          } else {
            result2.push(separator);
          }
        }
      });
      if (drawSeparator(contentSize, contentSize)) {
        result2.push(separatorGetter(contentSize, contentSize));
      }
      return result2.join("");
    }, "drawContent");
    exports2.drawContent = drawContent;
  }
});

// ../../node_modules/table/dist/src/drawBorder.js
var require_drawBorder = __commonJS({
  "../../node_modules/table/dist/src/drawBorder.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createTableBorderGetter = exports2.drawBorderBottom = exports2.drawBorderJoin = exports2.drawBorderTop = exports2.drawBorder = exports2.createSeparatorGetter = exports2.drawBorderSegments = void 0;
    var drawContent_1 = require_drawContent();
    var drawBorderSegments = /* @__PURE__ */ __name((columnWidths, parameters) => {
      const { separator, horizontalBorderIndex, spanningCellManager } = parameters;
      return columnWidths.map((columnWidth, columnIndex) => {
        const normalSegment = separator.body.repeat(columnWidth);
        if (horizontalBorderIndex === void 0) {
          return normalSegment;
        }
        const range7 = spanningCellManager === null || spanningCellManager === void 0 ? void 0 : spanningCellManager.getContainingRange({
          col: columnIndex,
          row: horizontalBorderIndex
        });
        if (!range7) {
          return normalSegment;
        }
        const { topLeft } = range7;
        if (horizontalBorderIndex === topLeft.row) {
          return normalSegment;
        }
        if (columnIndex !== topLeft.col) {
          return "";
        }
        return range7.extractBorderContent(horizontalBorderIndex);
      });
    }, "drawBorderSegments");
    exports2.drawBorderSegments = drawBorderSegments;
    var createSeparatorGetter = /* @__PURE__ */ __name((dependencies) => {
      const { separator, spanningCellManager, horizontalBorderIndex, rowCount } = dependencies;
      return (verticalBorderIndex, columnCount) => {
        const inSameRange = spanningCellManager === null || spanningCellManager === void 0 ? void 0 : spanningCellManager.inSameRange;
        if (horizontalBorderIndex !== void 0 && inSameRange) {
          const topCell = {
            col: verticalBorderIndex,
            row: horizontalBorderIndex - 1
          };
          const leftCell = {
            col: verticalBorderIndex - 1,
            row: horizontalBorderIndex
          };
          const oppositeCell = {
            col: verticalBorderIndex - 1,
            row: horizontalBorderIndex - 1
          };
          const currentCell = {
            col: verticalBorderIndex,
            row: horizontalBorderIndex
          };
          const pairs = [
            [oppositeCell, topCell],
            [topCell, currentCell],
            [currentCell, leftCell],
            [leftCell, oppositeCell]
          ];
          if (verticalBorderIndex === 0) {
            if (inSameRange(currentCell, topCell) && separator.bodyJoinOuter) {
              return separator.bodyJoinOuter;
            }
            return separator.left;
          }
          if (verticalBorderIndex === columnCount) {
            if (inSameRange(oppositeCell, leftCell) && separator.bodyJoinOuter) {
              return separator.bodyJoinOuter;
            }
            return separator.right;
          }
          if (horizontalBorderIndex === 0) {
            if (inSameRange(currentCell, leftCell)) {
              return separator.body;
            }
            return separator.join;
          }
          if (horizontalBorderIndex === rowCount) {
            if (inSameRange(topCell, oppositeCell)) {
              return separator.body;
            }
            return separator.join;
          }
          const sameRangeCount = pairs.map((pair) => {
            return inSameRange(...pair);
          }).filter(Boolean).length;
          if (sameRangeCount === 0) {
            return separator.join;
          }
          if (sameRangeCount === 4) {
            return "";
          }
          if (sameRangeCount === 2) {
            if (inSameRange(...pairs[1]) && inSameRange(...pairs[3]) && separator.bodyJoinInner) {
              return separator.bodyJoinInner;
            }
            return separator.body;
          }
          if (sameRangeCount === 1) {
            if (!separator.joinRight || !separator.joinLeft || !separator.joinUp || !separator.joinDown) {
              throw new Error(`Can not get border separator for position [${horizontalBorderIndex}, ${verticalBorderIndex}]`);
            }
            if (inSameRange(...pairs[0])) {
              return separator.joinDown;
            }
            if (inSameRange(...pairs[1])) {
              return separator.joinLeft;
            }
            if (inSameRange(...pairs[2])) {
              return separator.joinUp;
            }
            return separator.joinRight;
          }
          throw new Error("Invalid case");
        }
        if (verticalBorderIndex === 0) {
          return separator.left;
        }
        if (verticalBorderIndex === columnCount) {
          return separator.right;
        }
        return separator.join;
      };
    }, "createSeparatorGetter");
    exports2.createSeparatorGetter = createSeparatorGetter;
    var drawBorder = /* @__PURE__ */ __name((columnWidths, parameters) => {
      const borderSegments = (0, exports2.drawBorderSegments)(columnWidths, parameters);
      const { drawVerticalLine, horizontalBorderIndex, spanningCellManager } = parameters;
      return (0, drawContent_1.drawContent)({
        contents: borderSegments,
        drawSeparator: drawVerticalLine,
        elementType: "border",
        rowIndex: horizontalBorderIndex,
        separatorGetter: (0, exports2.createSeparatorGetter)(parameters),
        spanningCellManager
      }) + "\n";
    }, "drawBorder");
    exports2.drawBorder = drawBorder;
    var drawBorderTop = /* @__PURE__ */ __name((columnWidths, parameters) => {
      const { border } = parameters;
      const result2 = (0, exports2.drawBorder)(columnWidths, {
        ...parameters,
        separator: {
          body: border.topBody,
          join: border.topJoin,
          left: border.topLeft,
          right: border.topRight
        }
      });
      if (result2 === "\n") {
        return "";
      }
      return result2;
    }, "drawBorderTop");
    exports2.drawBorderTop = drawBorderTop;
    var drawBorderJoin = /* @__PURE__ */ __name((columnWidths, parameters) => {
      const { border } = parameters;
      return (0, exports2.drawBorder)(columnWidths, {
        ...parameters,
        separator: {
          body: border.joinBody,
          bodyJoinInner: border.bodyJoin,
          bodyJoinOuter: border.bodyLeft,
          join: border.joinJoin,
          joinDown: border.joinMiddleDown,
          joinLeft: border.joinMiddleLeft,
          joinRight: border.joinMiddleRight,
          joinUp: border.joinMiddleUp,
          left: border.joinLeft,
          right: border.joinRight
        }
      });
    }, "drawBorderJoin");
    exports2.drawBorderJoin = drawBorderJoin;
    var drawBorderBottom = /* @__PURE__ */ __name((columnWidths, parameters) => {
      const { border } = parameters;
      return (0, exports2.drawBorder)(columnWidths, {
        ...parameters,
        separator: {
          body: border.bottomBody,
          join: border.bottomJoin,
          left: border.bottomLeft,
          right: border.bottomRight
        }
      });
    }, "drawBorderBottom");
    exports2.drawBorderBottom = drawBorderBottom;
    var createTableBorderGetter = /* @__PURE__ */ __name((columnWidths, parameters) => {
      return (index, size) => {
        const drawBorderParameters = {
          ...parameters,
          horizontalBorderIndex: index
        };
        if (index === 0) {
          return (0, exports2.drawBorderTop)(columnWidths, drawBorderParameters);
        } else if (index === size) {
          return (0, exports2.drawBorderBottom)(columnWidths, drawBorderParameters);
        }
        return (0, exports2.drawBorderJoin)(columnWidths, drawBorderParameters);
      };
    }, "createTableBorderGetter");
    exports2.createTableBorderGetter = createTableBorderGetter;
  }
});

// ../../node_modules/table/dist/src/drawRow.js
var require_drawRow = __commonJS({
  "../../node_modules/table/dist/src/drawRow.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.drawRow = void 0;
    var drawContent_1 = require_drawContent();
    var drawRow = /* @__PURE__ */ __name((row, config2) => {
      const { border, drawVerticalLine, rowIndex, spanningCellManager } = config2;
      return (0, drawContent_1.drawContent)({
        contents: row,
        drawSeparator: drawVerticalLine,
        elementType: "cell",
        rowIndex,
        separatorGetter: /* @__PURE__ */ __name((index, columnCount) => {
          if (index === 0) {
            return border.bodyLeft;
          }
          if (index === columnCount) {
            return border.bodyRight;
          }
          return border.bodyJoin;
        }, "separatorGetter"),
        spanningCellManager
      }) + "\n";
    }, "drawRow");
    exports2.drawRow = drawRow;
  }
});

// ../../node_modules/ajv/dist/runtime/equal.js
var require_equal = __commonJS({
  "../../node_modules/ajv/dist/runtime/equal.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var equal = require_fast_deep_equal();
    equal.code = 'require("ajv/dist/runtime/equal").default';
    exports2.default = equal;
  }
});

// ../../node_modules/table/dist/src/generated/validators.js
var require_validators = __commonJS({
  "../../node_modules/table/dist/src/generated/validators.js"(exports2) {
    "use strict";
    exports2["config.json"] = validate43;
    var schema13 = {
      "$id": "config.json",
      "$schema": "http://json-schema.org/draft-07/schema#",
      "type": "object",
      "properties": {
        "border": {
          "$ref": "shared.json#/definitions/borders"
        },
        "header": {
          "type": "object",
          "properties": {
            "content": {
              "type": "string"
            },
            "alignment": {
              "$ref": "shared.json#/definitions/alignment"
            },
            "wrapWord": {
              "type": "boolean"
            },
            "truncate": {
              "type": "integer"
            },
            "paddingLeft": {
              "type": "integer"
            },
            "paddingRight": {
              "type": "integer"
            }
          },
          "required": ["content"],
          "additionalProperties": false
        },
        "columns": {
          "$ref": "shared.json#/definitions/columns"
        },
        "columnDefault": {
          "$ref": "shared.json#/definitions/column"
        },
        "drawVerticalLine": {
          "typeof": "function"
        },
        "drawHorizontalLine": {
          "typeof": "function"
        },
        "singleLine": {
          "typeof": "boolean"
        },
        "spanningCells": {
          "type": "array",
          "items": {
            "type": "object",
            "properties": {
              "col": {
                "type": "integer",
                "minimum": 0
              },
              "row": {
                "type": "integer",
                "minimum": 0
              },
              "colSpan": {
                "type": "integer",
                "minimum": 1
              },
              "rowSpan": {
                "type": "integer",
                "minimum": 1
              },
              "alignment": {
                "$ref": "shared.json#/definitions/alignment"
              },
              "verticalAlignment": {
                "$ref": "shared.json#/definitions/verticalAlignment"
              },
              "wrapWord": {
                "type": "boolean"
              },
              "truncate": {
                "type": "integer"
              },
              "paddingLeft": {
                "type": "integer"
              },
              "paddingRight": {
                "type": "integer"
              }
            },
            "required": ["row", "col"],
            "additionalProperties": false
          }
        }
      },
      "additionalProperties": false
    };
    var schema15 = {
      "type": "object",
      "properties": {
        "topBody": {
          "$ref": "#/definitions/border"
        },
        "topJoin": {
          "$ref": "#/definitions/border"
        },
        "topLeft": {
          "$ref": "#/definitions/border"
        },
        "topRight": {
          "$ref": "#/definitions/border"
        },
        "bottomBody": {
          "$ref": "#/definitions/border"
        },
        "bottomJoin": {
          "$ref": "#/definitions/border"
        },
        "bottomLeft": {
          "$ref": "#/definitions/border"
        },
        "bottomRight": {
          "$ref": "#/definitions/border"
        },
        "bodyLeft": {
          "$ref": "#/definitions/border"
        },
        "bodyRight": {
          "$ref": "#/definitions/border"
        },
        "bodyJoin": {
          "$ref": "#/definitions/border"
        },
        "headerJoin": {
          "$ref": "#/definitions/border"
        },
        "joinBody": {
          "$ref": "#/definitions/border"
        },
        "joinLeft": {
          "$ref": "#/definitions/border"
        },
        "joinRight": {
          "$ref": "#/definitions/border"
        },
        "joinJoin": {
          "$ref": "#/definitions/border"
        },
        "joinMiddleUp": {
          "$ref": "#/definitions/border"
        },
        "joinMiddleDown": {
          "$ref": "#/definitions/border"
        },
        "joinMiddleLeft": {
          "$ref": "#/definitions/border"
        },
        "joinMiddleRight": {
          "$ref": "#/definitions/border"
        }
      },
      "additionalProperties": false
    };
    var func8 = Object.prototype.hasOwnProperty;
    function validate46(data3, { instancePath = "", parentData, parentDataProperty, rootData = data3 } = {}) {
      let vErrors = null;
      let errors = 0;
      if (typeof data3 !== "string") {
        const err0 = {
          instancePath,
          schemaPath: "#/type",
          keyword: "type",
          params: {
            type: "string"
          },
          message: "must be string"
        };
        if (vErrors === null) {
          vErrors = [err0];
        } else {
          vErrors.push(err0);
        }
        errors++;
      }
      validate46.errors = vErrors;
      return errors === 0;
    }
    __name(validate46, "validate46");
    function validate45(data3, { instancePath = "", parentData, parentDataProperty, rootData = data3 } = {}) {
      let vErrors = null;
      let errors = 0;
      if (data3 && typeof data3 == "object" && !Array.isArray(data3)) {
        for (const key0 in data3) {
          if (!func8.call(schema15.properties, key0)) {
            const err0 = {
              instancePath,
              schemaPath: "#/additionalProperties",
              keyword: "additionalProperties",
              params: {
                additionalProperty: key0
              },
              message: "must NOT have additional properties"
            };
            if (vErrors === null) {
              vErrors = [err0];
            } else {
              vErrors.push(err0);
            }
            errors++;
          }
        }
        if (data3.topBody !== void 0) {
          if (!validate46(data3.topBody, {
            instancePath: instancePath + "/topBody",
            parentData: data3,
            parentDataProperty: "topBody",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.topJoin !== void 0) {
          if (!validate46(data3.topJoin, {
            instancePath: instancePath + "/topJoin",
            parentData: data3,
            parentDataProperty: "topJoin",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.topLeft !== void 0) {
          if (!validate46(data3.topLeft, {
            instancePath: instancePath + "/topLeft",
            parentData: data3,
            parentDataProperty: "topLeft",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.topRight !== void 0) {
          if (!validate46(data3.topRight, {
            instancePath: instancePath + "/topRight",
            parentData: data3,
            parentDataProperty: "topRight",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.bottomBody !== void 0) {
          if (!validate46(data3.bottomBody, {
            instancePath: instancePath + "/bottomBody",
            parentData: data3,
            parentDataProperty: "bottomBody",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.bottomJoin !== void 0) {
          if (!validate46(data3.bottomJoin, {
            instancePath: instancePath + "/bottomJoin",
            parentData: data3,
            parentDataProperty: "bottomJoin",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.bottomLeft !== void 0) {
          if (!validate46(data3.bottomLeft, {
            instancePath: instancePath + "/bottomLeft",
            parentData: data3,
            parentDataProperty: "bottomLeft",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.bottomRight !== void 0) {
          if (!validate46(data3.bottomRight, {
            instancePath: instancePath + "/bottomRight",
            parentData: data3,
            parentDataProperty: "bottomRight",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.bodyLeft !== void 0) {
          if (!validate46(data3.bodyLeft, {
            instancePath: instancePath + "/bodyLeft",
            parentData: data3,
            parentDataProperty: "bodyLeft",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.bodyRight !== void 0) {
          if (!validate46(data3.bodyRight, {
            instancePath: instancePath + "/bodyRight",
            parentData: data3,
            parentDataProperty: "bodyRight",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.bodyJoin !== void 0) {
          if (!validate46(data3.bodyJoin, {
            instancePath: instancePath + "/bodyJoin",
            parentData: data3,
            parentDataProperty: "bodyJoin",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.headerJoin !== void 0) {
          if (!validate46(data3.headerJoin, {
            instancePath: instancePath + "/headerJoin",
            parentData: data3,
            parentDataProperty: "headerJoin",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.joinBody !== void 0) {
          if (!validate46(data3.joinBody, {
            instancePath: instancePath + "/joinBody",
            parentData: data3,
            parentDataProperty: "joinBody",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.joinLeft !== void 0) {
          if (!validate46(data3.joinLeft, {
            instancePath: instancePath + "/joinLeft",
            parentData: data3,
            parentDataProperty: "joinLeft",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.joinRight !== void 0) {
          if (!validate46(data3.joinRight, {
            instancePath: instancePath + "/joinRight",
            parentData: data3,
            parentDataProperty: "joinRight",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.joinJoin !== void 0) {
          if (!validate46(data3.joinJoin, {
            instancePath: instancePath + "/joinJoin",
            parentData: data3,
            parentDataProperty: "joinJoin",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.joinMiddleUp !== void 0) {
          if (!validate46(data3.joinMiddleUp, {
            instancePath: instancePath + "/joinMiddleUp",
            parentData: data3,
            parentDataProperty: "joinMiddleUp",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.joinMiddleDown !== void 0) {
          if (!validate46(data3.joinMiddleDown, {
            instancePath: instancePath + "/joinMiddleDown",
            parentData: data3,
            parentDataProperty: "joinMiddleDown",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.joinMiddleLeft !== void 0) {
          if (!validate46(data3.joinMiddleLeft, {
            instancePath: instancePath + "/joinMiddleLeft",
            parentData: data3,
            parentDataProperty: "joinMiddleLeft",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.joinMiddleRight !== void 0) {
          if (!validate46(data3.joinMiddleRight, {
            instancePath: instancePath + "/joinMiddleRight",
            parentData: data3,
            parentDataProperty: "joinMiddleRight",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
      } else {
        const err1 = {
          instancePath,
          schemaPath: "#/type",
          keyword: "type",
          params: {
            type: "object"
          },
          message: "must be object"
        };
        if (vErrors === null) {
          vErrors = [err1];
        } else {
          vErrors.push(err1);
        }
        errors++;
      }
      validate45.errors = vErrors;
      return errors === 0;
    }
    __name(validate45, "validate45");
    var schema17 = {
      "type": "string",
      "enum": ["left", "right", "center", "justify"]
    };
    var func0 = require_equal().default;
    function validate68(data3, { instancePath = "", parentData, parentDataProperty, rootData = data3 } = {}) {
      let vErrors = null;
      let errors = 0;
      if (typeof data3 !== "string") {
        const err0 = {
          instancePath,
          schemaPath: "#/type",
          keyword: "type",
          params: {
            type: "string"
          },
          message: "must be string"
        };
        if (vErrors === null) {
          vErrors = [err0];
        } else {
          vErrors.push(err0);
        }
        errors++;
      }
      if (!(data3 === "left" || data3 === "right" || data3 === "center" || data3 === "justify")) {
        const err1 = {
          instancePath,
          schemaPath: "#/enum",
          keyword: "enum",
          params: {
            allowedValues: schema17.enum
          },
          message: "must be equal to one of the allowed values"
        };
        if (vErrors === null) {
          vErrors = [err1];
        } else {
          vErrors.push(err1);
        }
        errors++;
      }
      validate68.errors = vErrors;
      return errors === 0;
    }
    __name(validate68, "validate68");
    var pattern0 = new RegExp("^[0-9]+$", "u");
    function validate72(data3, { instancePath = "", parentData, parentDataProperty, rootData = data3 } = {}) {
      let vErrors = null;
      let errors = 0;
      if (typeof data3 !== "string") {
        const err0 = {
          instancePath,
          schemaPath: "#/type",
          keyword: "type",
          params: {
            type: "string"
          },
          message: "must be string"
        };
        if (vErrors === null) {
          vErrors = [err0];
        } else {
          vErrors.push(err0);
        }
        errors++;
      }
      if (!(data3 === "left" || data3 === "right" || data3 === "center" || data3 === "justify")) {
        const err1 = {
          instancePath,
          schemaPath: "#/enum",
          keyword: "enum",
          params: {
            allowedValues: schema17.enum
          },
          message: "must be equal to one of the allowed values"
        };
        if (vErrors === null) {
          vErrors = [err1];
        } else {
          vErrors.push(err1);
        }
        errors++;
      }
      validate72.errors = vErrors;
      return errors === 0;
    }
    __name(validate72, "validate72");
    var schema21 = {
      "type": "string",
      "enum": ["top", "middle", "bottom"]
    };
    function validate74(data3, { instancePath = "", parentData, parentDataProperty, rootData = data3 } = {}) {
      let vErrors = null;
      let errors = 0;
      if (typeof data3 !== "string") {
        const err0 = {
          instancePath,
          schemaPath: "#/type",
          keyword: "type",
          params: {
            type: "string"
          },
          message: "must be string"
        };
        if (vErrors === null) {
          vErrors = [err0];
        } else {
          vErrors.push(err0);
        }
        errors++;
      }
      if (!(data3 === "top" || data3 === "middle" || data3 === "bottom")) {
        const err1 = {
          instancePath,
          schemaPath: "#/enum",
          keyword: "enum",
          params: {
            allowedValues: schema21.enum
          },
          message: "must be equal to one of the allowed values"
        };
        if (vErrors === null) {
          vErrors = [err1];
        } else {
          vErrors.push(err1);
        }
        errors++;
      }
      validate74.errors = vErrors;
      return errors === 0;
    }
    __name(validate74, "validate74");
    function validate71(data3, { instancePath = "", parentData, parentDataProperty, rootData = data3 } = {}) {
      let vErrors = null;
      let errors = 0;
      if (data3 && typeof data3 == "object" && !Array.isArray(data3)) {
        for (const key0 in data3) {
          if (!(key0 === "alignment" || key0 === "verticalAlignment" || key0 === "width" || key0 === "wrapWord" || key0 === "truncate" || key0 === "paddingLeft" || key0 === "paddingRight")) {
            const err0 = {
              instancePath,
              schemaPath: "#/additionalProperties",
              keyword: "additionalProperties",
              params: {
                additionalProperty: key0
              },
              message: "must NOT have additional properties"
            };
            if (vErrors === null) {
              vErrors = [err0];
            } else {
              vErrors.push(err0);
            }
            errors++;
          }
        }
        if (data3.alignment !== void 0) {
          if (!validate72(data3.alignment, {
            instancePath: instancePath + "/alignment",
            parentData: data3,
            parentDataProperty: "alignment",
            rootData
          })) {
            vErrors = vErrors === null ? validate72.errors : vErrors.concat(validate72.errors);
            errors = vErrors.length;
          }
        }
        if (data3.verticalAlignment !== void 0) {
          if (!validate74(data3.verticalAlignment, {
            instancePath: instancePath + "/verticalAlignment",
            parentData: data3,
            parentDataProperty: "verticalAlignment",
            rootData
          })) {
            vErrors = vErrors === null ? validate74.errors : vErrors.concat(validate74.errors);
            errors = vErrors.length;
          }
        }
        if (data3.width !== void 0) {
          let data22 = data3.width;
          if (!(typeof data22 == "number" && (!(data22 % 1) && !isNaN(data22)) && isFinite(data22))) {
            const err1 = {
              instancePath: instancePath + "/width",
              schemaPath: "#/properties/width/type",
              keyword: "type",
              params: {
                type: "integer"
              },
              message: "must be integer"
            };
            if (vErrors === null) {
              vErrors = [err1];
            } else {
              vErrors.push(err1);
            }
            errors++;
          }
          if (typeof data22 == "number" && isFinite(data22)) {
            if (data22 < 1 || isNaN(data22)) {
              const err2 = {
                instancePath: instancePath + "/width",
                schemaPath: "#/properties/width/minimum",
                keyword: "minimum",
                params: {
                  comparison: ">=",
                  limit: 1
                },
                message: "must be >= 1"
              };
              if (vErrors === null) {
                vErrors = [err2];
              } else {
                vErrors.push(err2);
              }
              errors++;
            }
          }
        }
        if (data3.wrapWord !== void 0) {
          if (typeof data3.wrapWord !== "boolean") {
            const err3 = {
              instancePath: instancePath + "/wrapWord",
              schemaPath: "#/properties/wrapWord/type",
              keyword: "type",
              params: {
                type: "boolean"
              },
              message: "must be boolean"
            };
            if (vErrors === null) {
              vErrors = [err3];
            } else {
              vErrors.push(err3);
            }
            errors++;
          }
        }
        if (data3.truncate !== void 0) {
          let data4 = data3.truncate;
          if (!(typeof data4 == "number" && (!(data4 % 1) && !isNaN(data4)) && isFinite(data4))) {
            const err4 = {
              instancePath: instancePath + "/truncate",
              schemaPath: "#/properties/truncate/type",
              keyword: "type",
              params: {
                type: "integer"
              },
              message: "must be integer"
            };
            if (vErrors === null) {
              vErrors = [err4];
            } else {
              vErrors.push(err4);
            }
            errors++;
          }
        }
        if (data3.paddingLeft !== void 0) {
          let data5 = data3.paddingLeft;
          if (!(typeof data5 == "number" && (!(data5 % 1) && !isNaN(data5)) && isFinite(data5))) {
            const err5 = {
              instancePath: instancePath + "/paddingLeft",
              schemaPath: "#/properties/paddingLeft/type",
              keyword: "type",
              params: {
                type: "integer"
              },
              message: "must be integer"
            };
            if (vErrors === null) {
              vErrors = [err5];
            } else {
              vErrors.push(err5);
            }
            errors++;
          }
        }
        if (data3.paddingRight !== void 0) {
          let data6 = data3.paddingRight;
          if (!(typeof data6 == "number" && (!(data6 % 1) && !isNaN(data6)) && isFinite(data6))) {
            const err6 = {
              instancePath: instancePath + "/paddingRight",
              schemaPath: "#/properties/paddingRight/type",
              keyword: "type",
              params: {
                type: "integer"
              },
              message: "must be integer"
            };
            if (vErrors === null) {
              vErrors = [err6];
            } else {
              vErrors.push(err6);
            }
            errors++;
          }
        }
      } else {
        const err7 = {
          instancePath,
          schemaPath: "#/type",
          keyword: "type",
          params: {
            type: "object"
          },
          message: "must be object"
        };
        if (vErrors === null) {
          vErrors = [err7];
        } else {
          vErrors.push(err7);
        }
        errors++;
      }
      validate71.errors = vErrors;
      return errors === 0;
    }
    __name(validate71, "validate71");
    function validate70(data3, { instancePath = "", parentData, parentDataProperty, rootData = data3 } = {}) {
      let vErrors = null;
      let errors = 0;
      const _errs0 = errors;
      let valid0 = false;
      let passing0 = null;
      const _errs1 = errors;
      if (data3 && typeof data3 == "object" && !Array.isArray(data3)) {
        for (const key0 in data3) {
          if (!pattern0.test(key0)) {
            const err0 = {
              instancePath,
              schemaPath: "#/oneOf/0/additionalProperties",
              keyword: "additionalProperties",
              params: {
                additionalProperty: key0
              },
              message: "must NOT have additional properties"
            };
            if (vErrors === null) {
              vErrors = [err0];
            } else {
              vErrors.push(err0);
            }
            errors++;
          }
        }
        for (const key1 in data3) {
          if (pattern0.test(key1)) {
            if (!validate71(data3[key1], {
              instancePath: instancePath + "/" + key1.replace(/~/g, "~0").replace(/\//g, "~1"),
              parentData: data3,
              parentDataProperty: key1,
              rootData
            })) {
              vErrors = vErrors === null ? validate71.errors : vErrors.concat(validate71.errors);
              errors = vErrors.length;
            }
          }
        }
      } else {
        const err1 = {
          instancePath,
          schemaPath: "#/oneOf/0/type",
          keyword: "type",
          params: {
            type: "object"
          },
          message: "must be object"
        };
        if (vErrors === null) {
          vErrors = [err1];
        } else {
          vErrors.push(err1);
        }
        errors++;
      }
      var _valid0 = _errs1 === errors;
      if (_valid0) {
        valid0 = true;
        passing0 = 0;
      }
      const _errs5 = errors;
      if (Array.isArray(data3)) {
        const len0 = data3.length;
        for (let i0 = 0; i0 < len0; i0++) {
          if (!validate71(data3[i0], {
            instancePath: instancePath + "/" + i0,
            parentData: data3,
            parentDataProperty: i0,
            rootData
          })) {
            vErrors = vErrors === null ? validate71.errors : vErrors.concat(validate71.errors);
            errors = vErrors.length;
          }
        }
      } else {
        const err2 = {
          instancePath,
          schemaPath: "#/oneOf/1/type",
          keyword: "type",
          params: {
            type: "array"
          },
          message: "must be array"
        };
        if (vErrors === null) {
          vErrors = [err2];
        } else {
          vErrors.push(err2);
        }
        errors++;
      }
      var _valid0 = _errs5 === errors;
      if (_valid0 && valid0) {
        valid0 = false;
        passing0 = [passing0, 1];
      } else {
        if (_valid0) {
          valid0 = true;
          passing0 = 1;
        }
      }
      if (!valid0) {
        const err3 = {
          instancePath,
          schemaPath: "#/oneOf",
          keyword: "oneOf",
          params: {
            passingSchemas: passing0
          },
          message: "must match exactly one schema in oneOf"
        };
        if (vErrors === null) {
          vErrors = [err3];
        } else {
          vErrors.push(err3);
        }
        errors++;
      } else {
        errors = _errs0;
        if (vErrors !== null) {
          if (_errs0) {
            vErrors.length = _errs0;
          } else {
            vErrors = null;
          }
        }
      }
      validate70.errors = vErrors;
      return errors === 0;
    }
    __name(validate70, "validate70");
    function validate79(data3, { instancePath = "", parentData, parentDataProperty, rootData = data3 } = {}) {
      let vErrors = null;
      let errors = 0;
      if (data3 && typeof data3 == "object" && !Array.isArray(data3)) {
        for (const key0 in data3) {
          if (!(key0 === "alignment" || key0 === "verticalAlignment" || key0 === "width" || key0 === "wrapWord" || key0 === "truncate" || key0 === "paddingLeft" || key0 === "paddingRight")) {
            const err0 = {
              instancePath,
              schemaPath: "#/additionalProperties",
              keyword: "additionalProperties",
              params: {
                additionalProperty: key0
              },
              message: "must NOT have additional properties"
            };
            if (vErrors === null) {
              vErrors = [err0];
            } else {
              vErrors.push(err0);
            }
            errors++;
          }
        }
        if (data3.alignment !== void 0) {
          if (!validate72(data3.alignment, {
            instancePath: instancePath + "/alignment",
            parentData: data3,
            parentDataProperty: "alignment",
            rootData
          })) {
            vErrors = vErrors === null ? validate72.errors : vErrors.concat(validate72.errors);
            errors = vErrors.length;
          }
        }
        if (data3.verticalAlignment !== void 0) {
          if (!validate74(data3.verticalAlignment, {
            instancePath: instancePath + "/verticalAlignment",
            parentData: data3,
            parentDataProperty: "verticalAlignment",
            rootData
          })) {
            vErrors = vErrors === null ? validate74.errors : vErrors.concat(validate74.errors);
            errors = vErrors.length;
          }
        }
        if (data3.width !== void 0) {
          let data22 = data3.width;
          if (!(typeof data22 == "number" && (!(data22 % 1) && !isNaN(data22)) && isFinite(data22))) {
            const err1 = {
              instancePath: instancePath + "/width",
              schemaPath: "#/properties/width/type",
              keyword: "type",
              params: {
                type: "integer"
              },
              message: "must be integer"
            };
            if (vErrors === null) {
              vErrors = [err1];
            } else {
              vErrors.push(err1);
            }
            errors++;
          }
          if (typeof data22 == "number" && isFinite(data22)) {
            if (data22 < 1 || isNaN(data22)) {
              const err2 = {
                instancePath: instancePath + "/width",
                schemaPath: "#/properties/width/minimum",
                keyword: "minimum",
                params: {
                  comparison: ">=",
                  limit: 1
                },
                message: "must be >= 1"
              };
              if (vErrors === null) {
                vErrors = [err2];
              } else {
                vErrors.push(err2);
              }
              errors++;
            }
          }
        }
        if (data3.wrapWord !== void 0) {
          if (typeof data3.wrapWord !== "boolean") {
            const err3 = {
              instancePath: instancePath + "/wrapWord",
              schemaPath: "#/properties/wrapWord/type",
              keyword: "type",
              params: {
                type: "boolean"
              },
              message: "must be boolean"
            };
            if (vErrors === null) {
              vErrors = [err3];
            } else {
              vErrors.push(err3);
            }
            errors++;
          }
        }
        if (data3.truncate !== void 0) {
          let data4 = data3.truncate;
          if (!(typeof data4 == "number" && (!(data4 % 1) && !isNaN(data4)) && isFinite(data4))) {
            const err4 = {
              instancePath: instancePath + "/truncate",
              schemaPath: "#/properties/truncate/type",
              keyword: "type",
              params: {
                type: "integer"
              },
              message: "must be integer"
            };
            if (vErrors === null) {
              vErrors = [err4];
            } else {
              vErrors.push(err4);
            }
            errors++;
          }
        }
        if (data3.paddingLeft !== void 0) {
          let data5 = data3.paddingLeft;
          if (!(typeof data5 == "number" && (!(data5 % 1) && !isNaN(data5)) && isFinite(data5))) {
            const err5 = {
              instancePath: instancePath + "/paddingLeft",
              schemaPath: "#/properties/paddingLeft/type",
              keyword: "type",
              params: {
                type: "integer"
              },
              message: "must be integer"
            };
            if (vErrors === null) {
              vErrors = [err5];
            } else {
              vErrors.push(err5);
            }
            errors++;
          }
        }
        if (data3.paddingRight !== void 0) {
          let data6 = data3.paddingRight;
          if (!(typeof data6 == "number" && (!(data6 % 1) && !isNaN(data6)) && isFinite(data6))) {
            const err6 = {
              instancePath: instancePath + "/paddingRight",
              schemaPath: "#/properties/paddingRight/type",
              keyword: "type",
              params: {
                type: "integer"
              },
              message: "must be integer"
            };
            if (vErrors === null) {
              vErrors = [err6];
            } else {
              vErrors.push(err6);
            }
            errors++;
          }
        }
      } else {
        const err7 = {
          instancePath,
          schemaPath: "#/type",
          keyword: "type",
          params: {
            type: "object"
          },
          message: "must be object"
        };
        if (vErrors === null) {
          vErrors = [err7];
        } else {
          vErrors.push(err7);
        }
        errors++;
      }
      validate79.errors = vErrors;
      return errors === 0;
    }
    __name(validate79, "validate79");
    function validate84(data3, { instancePath = "", parentData, parentDataProperty, rootData = data3 } = {}) {
      let vErrors = null;
      let errors = 0;
      if (typeof data3 !== "string") {
        const err0 = {
          instancePath,
          schemaPath: "#/type",
          keyword: "type",
          params: {
            type: "string"
          },
          message: "must be string"
        };
        if (vErrors === null) {
          vErrors = [err0];
        } else {
          vErrors.push(err0);
        }
        errors++;
      }
      if (!(data3 === "top" || data3 === "middle" || data3 === "bottom")) {
        const err1 = {
          instancePath,
          schemaPath: "#/enum",
          keyword: "enum",
          params: {
            allowedValues: schema21.enum
          },
          message: "must be equal to one of the allowed values"
        };
        if (vErrors === null) {
          vErrors = [err1];
        } else {
          vErrors.push(err1);
        }
        errors++;
      }
      validate84.errors = vErrors;
      return errors === 0;
    }
    __name(validate84, "validate84");
    function validate43(data3, { instancePath = "", parentData, parentDataProperty, rootData = data3 } = {}) {
      ;
      let vErrors = null;
      let errors = 0;
      if (data3 && typeof data3 == "object" && !Array.isArray(data3)) {
        for (const key0 in data3) {
          if (!(key0 === "border" || key0 === "header" || key0 === "columns" || key0 === "columnDefault" || key0 === "drawVerticalLine" || key0 === "drawHorizontalLine" || key0 === "singleLine" || key0 === "spanningCells")) {
            const err0 = {
              instancePath,
              schemaPath: "#/additionalProperties",
              keyword: "additionalProperties",
              params: {
                additionalProperty: key0
              },
              message: "must NOT have additional properties"
            };
            if (vErrors === null) {
              vErrors = [err0];
            } else {
              vErrors.push(err0);
            }
            errors++;
          }
        }
        if (data3.border !== void 0) {
          if (!validate45(data3.border, {
            instancePath: instancePath + "/border",
            parentData: data3,
            parentDataProperty: "border",
            rootData
          })) {
            vErrors = vErrors === null ? validate45.errors : vErrors.concat(validate45.errors);
            errors = vErrors.length;
          }
        }
        if (data3.header !== void 0) {
          let data1 = data3.header;
          if (data1 && typeof data1 == "object" && !Array.isArray(data1)) {
            if (data1.content === void 0) {
              const err1 = {
                instancePath: instancePath + "/header",
                schemaPath: "#/properties/header/required",
                keyword: "required",
                params: {
                  missingProperty: "content"
                },
                message: "must have required property 'content'"
              };
              if (vErrors === null) {
                vErrors = [err1];
              } else {
                vErrors.push(err1);
              }
              errors++;
            }
            for (const key1 in data1) {
              if (!(key1 === "content" || key1 === "alignment" || key1 === "wrapWord" || key1 === "truncate" || key1 === "paddingLeft" || key1 === "paddingRight")) {
                const err2 = {
                  instancePath: instancePath + "/header",
                  schemaPath: "#/properties/header/additionalProperties",
                  keyword: "additionalProperties",
                  params: {
                    additionalProperty: key1
                  },
                  message: "must NOT have additional properties"
                };
                if (vErrors === null) {
                  vErrors = [err2];
                } else {
                  vErrors.push(err2);
                }
                errors++;
              }
            }
            if (data1.content !== void 0) {
              if (typeof data1.content !== "string") {
                const err3 = {
                  instancePath: instancePath + "/header/content",
                  schemaPath: "#/properties/header/properties/content/type",
                  keyword: "type",
                  params: {
                    type: "string"
                  },
                  message: "must be string"
                };
                if (vErrors === null) {
                  vErrors = [err3];
                } else {
                  vErrors.push(err3);
                }
                errors++;
              }
            }
            if (data1.alignment !== void 0) {
              if (!validate68(data1.alignment, {
                instancePath: instancePath + "/header/alignment",
                parentData: data1,
                parentDataProperty: "alignment",
                rootData
              })) {
                vErrors = vErrors === null ? validate68.errors : vErrors.concat(validate68.errors);
                errors = vErrors.length;
              }
            }
            if (data1.wrapWord !== void 0) {
              if (typeof data1.wrapWord !== "boolean") {
                const err4 = {
                  instancePath: instancePath + "/header/wrapWord",
                  schemaPath: "#/properties/header/properties/wrapWord/type",
                  keyword: "type",
                  params: {
                    type: "boolean"
                  },
                  message: "must be boolean"
                };
                if (vErrors === null) {
                  vErrors = [err4];
                } else {
                  vErrors.push(err4);
                }
                errors++;
              }
            }
            if (data1.truncate !== void 0) {
              let data5 = data1.truncate;
              if (!(typeof data5 == "number" && (!(data5 % 1) && !isNaN(data5)) && isFinite(data5))) {
                const err5 = {
                  instancePath: instancePath + "/header/truncate",
                  schemaPath: "#/properties/header/properties/truncate/type",
                  keyword: "type",
                  params: {
                    type: "integer"
                  },
                  message: "must be integer"
                };
                if (vErrors === null) {
                  vErrors = [err5];
                } else {
                  vErrors.push(err5);
                }
                errors++;
              }
            }
            if (data1.paddingLeft !== void 0) {
              let data6 = data1.paddingLeft;
              if (!(typeof data6 == "number" && (!(data6 % 1) && !isNaN(data6)) && isFinite(data6))) {
                const err6 = {
                  instancePath: instancePath + "/header/paddingLeft",
                  schemaPath: "#/properties/header/properties/paddingLeft/type",
                  keyword: "type",
                  params: {
                    type: "integer"
                  },
                  message: "must be integer"
                };
                if (vErrors === null) {
                  vErrors = [err6];
                } else {
                  vErrors.push(err6);
                }
                errors++;
              }
            }
            if (data1.paddingRight !== void 0) {
              let data7 = data1.paddingRight;
              if (!(typeof data7 == "number" && (!(data7 % 1) && !isNaN(data7)) && isFinite(data7))) {
                const err7 = {
                  instancePath: instancePath + "/header/paddingRight",
                  schemaPath: "#/properties/header/properties/paddingRight/type",
                  keyword: "type",
                  params: {
                    type: "integer"
                  },
                  message: "must be integer"
                };
                if (vErrors === null) {
                  vErrors = [err7];
                } else {
                  vErrors.push(err7);
                }
                errors++;
              }
            }
          } else {
            const err8 = {
              instancePath: instancePath + "/header",
              schemaPath: "#/properties/header/type",
              keyword: "type",
              params: {
                type: "object"
              },
              message: "must be object"
            };
            if (vErrors === null) {
              vErrors = [err8];
            } else {
              vErrors.push(err8);
            }
            errors++;
          }
        }
        if (data3.columns !== void 0) {
          if (!validate70(data3.columns, {
            instancePath: instancePath + "/columns",
            parentData: data3,
            parentDataProperty: "columns",
            rootData
          })) {
            vErrors = vErrors === null ? validate70.errors : vErrors.concat(validate70.errors);
            errors = vErrors.length;
          }
        }
        if (data3.columnDefault !== void 0) {
          if (!validate79(data3.columnDefault, {
            instancePath: instancePath + "/columnDefault",
            parentData: data3,
            parentDataProperty: "columnDefault",
            rootData
          })) {
            vErrors = vErrors === null ? validate79.errors : vErrors.concat(validate79.errors);
            errors = vErrors.length;
          }
        }
        if (data3.drawVerticalLine !== void 0) {
          if (typeof data3.drawVerticalLine != "function") {
            const err9 = {
              instancePath: instancePath + "/drawVerticalLine",
              schemaPath: "#/properties/drawVerticalLine/typeof",
              keyword: "typeof",
              params: {},
              message: 'must pass "typeof" keyword validation'
            };
            if (vErrors === null) {
              vErrors = [err9];
            } else {
              vErrors.push(err9);
            }
            errors++;
          }
        }
        if (data3.drawHorizontalLine !== void 0) {
          if (typeof data3.drawHorizontalLine != "function") {
            const err10 = {
              instancePath: instancePath + "/drawHorizontalLine",
              schemaPath: "#/properties/drawHorizontalLine/typeof",
              keyword: "typeof",
              params: {},
              message: 'must pass "typeof" keyword validation'
            };
            if (vErrors === null) {
              vErrors = [err10];
            } else {
              vErrors.push(err10);
            }
            errors++;
          }
        }
        if (data3.singleLine !== void 0) {
          if (typeof data3.singleLine != "boolean") {
            const err11 = {
              instancePath: instancePath + "/singleLine",
              schemaPath: "#/properties/singleLine/typeof",
              keyword: "typeof",
              params: {},
              message: 'must pass "typeof" keyword validation'
            };
            if (vErrors === null) {
              vErrors = [err11];
            } else {
              vErrors.push(err11);
            }
            errors++;
          }
        }
        if (data3.spanningCells !== void 0) {
          let data13 = data3.spanningCells;
          if (Array.isArray(data13)) {
            const len0 = data13.length;
            for (let i0 = 0; i0 < len0; i0++) {
              let data14 = data13[i0];
              if (data14 && typeof data14 == "object" && !Array.isArray(data14)) {
                if (data14.row === void 0) {
                  const err12 = {
                    instancePath: instancePath + "/spanningCells/" + i0,
                    schemaPath: "#/properties/spanningCells/items/required",
                    keyword: "required",
                    params: {
                      missingProperty: "row"
                    },
                    message: "must have required property 'row'"
                  };
                  if (vErrors === null) {
                    vErrors = [err12];
                  } else {
                    vErrors.push(err12);
                  }
                  errors++;
                }
                if (data14.col === void 0) {
                  const err13 = {
                    instancePath: instancePath + "/spanningCells/" + i0,
                    schemaPath: "#/properties/spanningCells/items/required",
                    keyword: "required",
                    params: {
                      missingProperty: "col"
                    },
                    message: "must have required property 'col'"
                  };
                  if (vErrors === null) {
                    vErrors = [err13];
                  } else {
                    vErrors.push(err13);
                  }
                  errors++;
                }
                for (const key2 in data14) {
                  if (!func8.call(schema13.properties.spanningCells.items.properties, key2)) {
                    const err14 = {
                      instancePath: instancePath + "/spanningCells/" + i0,
                      schemaPath: "#/properties/spanningCells/items/additionalProperties",
                      keyword: "additionalProperties",
                      params: {
                        additionalProperty: key2
                      },
                      message: "must NOT have additional properties"
                    };
                    if (vErrors === null) {
                      vErrors = [err14];
                    } else {
                      vErrors.push(err14);
                    }
                    errors++;
                  }
                }
                if (data14.col !== void 0) {
                  let data15 = data14.col;
                  if (!(typeof data15 == "number" && (!(data15 % 1) && !isNaN(data15)) && isFinite(data15))) {
                    const err15 = {
                      instancePath: instancePath + "/spanningCells/" + i0 + "/col",
                      schemaPath: "#/properties/spanningCells/items/properties/col/type",
                      keyword: "type",
                      params: {
                        type: "integer"
                      },
                      message: "must be integer"
                    };
                    if (vErrors === null) {
                      vErrors = [err15];
                    } else {
                      vErrors.push(err15);
                    }
                    errors++;
                  }
                  if (typeof data15 == "number" && isFinite(data15)) {
                    if (data15 < 0 || isNaN(data15)) {
                      const err16 = {
                        instancePath: instancePath + "/spanningCells/" + i0 + "/col",
                        schemaPath: "#/properties/spanningCells/items/properties/col/minimum",
                        keyword: "minimum",
                        params: {
                          comparison: ">=",
                          limit: 0
                        },
                        message: "must be >= 0"
                      };
                      if (vErrors === null) {
                        vErrors = [err16];
                      } else {
                        vErrors.push(err16);
                      }
                      errors++;
                    }
                  }
                }
                if (data14.row !== void 0) {
                  let data16 = data14.row;
                  if (!(typeof data16 == "number" && (!(data16 % 1) && !isNaN(data16)) && isFinite(data16))) {
                    const err17 = {
                      instancePath: instancePath + "/spanningCells/" + i0 + "/row",
                      schemaPath: "#/properties/spanningCells/items/properties/row/type",
                      keyword: "type",
                      params: {
                        type: "integer"
                      },
                      message: "must be integer"
                    };
                    if (vErrors === null) {
                      vErrors = [err17];
                    } else {
                      vErrors.push(err17);
                    }
                    errors++;
                  }
                  if (typeof data16 == "number" && isFinite(data16)) {
                    if (data16 < 0 || isNaN(data16)) {
                      const err18 = {
                        instancePath: instancePath + "/spanningCells/" + i0 + "/row",
                        schemaPath: "#/properties/spanningCells/items/properties/row/minimum",
                        keyword: "minimum",
                        params: {
                          comparison: ">=",
                          limit: 0
                        },
                        message: "must be >= 0"
                      };
                      if (vErrors === null) {
                        vErrors = [err18];
                      } else {
                        vErrors.push(err18);
                      }
                      errors++;
                    }
                  }
                }
                if (data14.colSpan !== void 0) {
                  let data17 = data14.colSpan;
                  if (!(typeof data17 == "number" && (!(data17 % 1) && !isNaN(data17)) && isFinite(data17))) {
                    const err19 = {
                      instancePath: instancePath + "/spanningCells/" + i0 + "/colSpan",
                      schemaPath: "#/properties/spanningCells/items/properties/colSpan/type",
                      keyword: "type",
                      params: {
                        type: "integer"
                      },
                      message: "must be integer"
                    };
                    if (vErrors === null) {
                      vErrors = [err19];
                    } else {
                      vErrors.push(err19);
                    }
                    errors++;
                  }
                  if (typeof data17 == "number" && isFinite(data17)) {
                    if (data17 < 1 || isNaN(data17)) {
                      const err20 = {
                        instancePath: instancePath + "/spanningCells/" + i0 + "/colSpan",
                        schemaPath: "#/properties/spanningCells/items/properties/colSpan/minimum",
                        keyword: "minimum",
                        params: {
                          comparison: ">=",
                          limit: 1
                        },
                        message: "must be >= 1"
                      };
                      if (vErrors === null) {
                        vErrors = [err20];
                      } else {
                        vErrors.push(err20);
                      }
                      errors++;
                    }
                  }
                }
                if (data14.rowSpan !== void 0) {
                  let data18 = data14.rowSpan;
                  if (!(typeof data18 == "number" && (!(data18 % 1) && !isNaN(data18)) && isFinite(data18))) {
                    const err21 = {
                      instancePath: instancePath + "/spanningCells/" + i0 + "/rowSpan",
                      schemaPath: "#/properties/spanningCells/items/properties/rowSpan/type",
                      keyword: "type",
                      params: {
                        type: "integer"
                      },
                      message: "must be integer"
                    };
                    if (vErrors === null) {
                      vErrors = [err21];
                    } else {
                      vErrors.push(err21);
                    }
                    errors++;
                  }
                  if (typeof data18 == "number" && isFinite(data18)) {
                    if (data18 < 1 || isNaN(data18)) {
                      const err22 = {
                        instancePath: instancePath + "/spanningCells/" + i0 + "/rowSpan",
                        schemaPath: "#/properties/spanningCells/items/properties/rowSpan/minimum",
                        keyword: "minimum",
                        params: {
                          comparison: ">=",
                          limit: 1
                        },
                        message: "must be >= 1"
                      };
                      if (vErrors === null) {
                        vErrors = [err22];
                      } else {
                        vErrors.push(err22);
                      }
                      errors++;
                    }
                  }
                }
                if (data14.alignment !== void 0) {
                  if (!validate68(data14.alignment, {
                    instancePath: instancePath + "/spanningCells/" + i0 + "/alignment",
                    parentData: data14,
                    parentDataProperty: "alignment",
                    rootData
                  })) {
                    vErrors = vErrors === null ? validate68.errors : vErrors.concat(validate68.errors);
                    errors = vErrors.length;
                  }
                }
                if (data14.verticalAlignment !== void 0) {
                  if (!validate84(data14.verticalAlignment, {
                    instancePath: instancePath + "/spanningCells/" + i0 + "/verticalAlignment",
                    parentData: data14,
                    parentDataProperty: "verticalAlignment",
                    rootData
                  })) {
                    vErrors = vErrors === null ? validate84.errors : vErrors.concat(validate84.errors);
                    errors = vErrors.length;
                  }
                }
                if (data14.wrapWord !== void 0) {
                  if (typeof data14.wrapWord !== "boolean") {
                    const err23 = {
                      instancePath: instancePath + "/spanningCells/" + i0 + "/wrapWord",
                      schemaPath: "#/properties/spanningCells/items/properties/wrapWord/type",
                      keyword: "type",
                      params: {
                        type: "boolean"
                      },
                      message: "must be boolean"
                    };
                    if (vErrors === null) {
                      vErrors = [err23];
                    } else {
                      vErrors.push(err23);
                    }
                    errors++;
                  }
                }
                if (data14.truncate !== void 0) {
                  let data22 = data14.truncate;
                  if (!(typeof data22 == "number" && (!(data22 % 1) && !isNaN(data22)) && isFinite(data22))) {
                    const err24 = {
                      instancePath: instancePath + "/spanningCells/" + i0 + "/truncate",
                      schemaPath: "#/properties/spanningCells/items/properties/truncate/type",
                      keyword: "type",
                      params: {
                        type: "integer"
                      },
                      message: "must be integer"
                    };
                    if (vErrors === null) {
                      vErrors = [err24];
                    } else {
                      vErrors.push(err24);
                    }
                    errors++;
                  }
                }
                if (data14.paddingLeft !== void 0) {
                  let data23 = data14.paddingLeft;
                  if (!(typeof data23 == "number" && (!(data23 % 1) && !isNaN(data23)) && isFinite(data23))) {
                    const err25 = {
                      instancePath: instancePath + "/spanningCells/" + i0 + "/paddingLeft",
                      schemaPath: "#/properties/spanningCells/items/properties/paddingLeft/type",
                      keyword: "type",
                      params: {
                        type: "integer"
                      },
                      message: "must be integer"
                    };
                    if (vErrors === null) {
                      vErrors = [err25];
                    } else {
                      vErrors.push(err25);
                    }
                    errors++;
                  }
                }
                if (data14.paddingRight !== void 0) {
                  let data24 = data14.paddingRight;
                  if (!(typeof data24 == "number" && (!(data24 % 1) && !isNaN(data24)) && isFinite(data24))) {
                    const err26 = {
                      instancePath: instancePath + "/spanningCells/" + i0 + "/paddingRight",
                      schemaPath: "#/properties/spanningCells/items/properties/paddingRight/type",
                      keyword: "type",
                      params: {
                        type: "integer"
                      },
                      message: "must be integer"
                    };
                    if (vErrors === null) {
                      vErrors = [err26];
                    } else {
                      vErrors.push(err26);
                    }
                    errors++;
                  }
                }
              } else {
                const err27 = {
                  instancePath: instancePath + "/spanningCells/" + i0,
                  schemaPath: "#/properties/spanningCells/items/type",
                  keyword: "type",
                  params: {
                    type: "object"
                  },
                  message: "must be object"
                };
                if (vErrors === null) {
                  vErrors = [err27];
                } else {
                  vErrors.push(err27);
                }
                errors++;
              }
            }
          } else {
            const err28 = {
              instancePath: instancePath + "/spanningCells",
              schemaPath: "#/properties/spanningCells/type",
              keyword: "type",
              params: {
                type: "array"
              },
              message: "must be array"
            };
            if (vErrors === null) {
              vErrors = [err28];
            } else {
              vErrors.push(err28);
            }
            errors++;
          }
        }
      } else {
        const err29 = {
          instancePath,
          schemaPath: "#/type",
          keyword: "type",
          params: {
            type: "object"
          },
          message: "must be object"
        };
        if (vErrors === null) {
          vErrors = [err29];
        } else {
          vErrors.push(err29);
        }
        errors++;
      }
      validate43.errors = vErrors;
      return errors === 0;
    }
    __name(validate43, "validate43");
    exports2["streamConfig.json"] = validate86;
    function validate87(data3, { instancePath = "", parentData, parentDataProperty, rootData = data3 } = {}) {
      let vErrors = null;
      let errors = 0;
      if (data3 && typeof data3 == "object" && !Array.isArray(data3)) {
        for (const key0 in data3) {
          if (!func8.call(schema15.properties, key0)) {
            const err0 = {
              instancePath,
              schemaPath: "#/additionalProperties",
              keyword: "additionalProperties",
              params: {
                additionalProperty: key0
              },
              message: "must NOT have additional properties"
            };
            if (vErrors === null) {
              vErrors = [err0];
            } else {
              vErrors.push(err0);
            }
            errors++;
          }
        }
        if (data3.topBody !== void 0) {
          if (!validate46(data3.topBody, {
            instancePath: instancePath + "/topBody",
            parentData: data3,
            parentDataProperty: "topBody",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.topJoin !== void 0) {
          if (!validate46(data3.topJoin, {
            instancePath: instancePath + "/topJoin",
            parentData: data3,
            parentDataProperty: "topJoin",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.topLeft !== void 0) {
          if (!validate46(data3.topLeft, {
            instancePath: instancePath + "/topLeft",
            parentData: data3,
            parentDataProperty: "topLeft",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.topRight !== void 0) {
          if (!validate46(data3.topRight, {
            instancePath: instancePath + "/topRight",
            parentData: data3,
            parentDataProperty: "topRight",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.bottomBody !== void 0) {
          if (!validate46(data3.bottomBody, {
            instancePath: instancePath + "/bottomBody",
            parentData: data3,
            parentDataProperty: "bottomBody",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.bottomJoin !== void 0) {
          if (!validate46(data3.bottomJoin, {
            instancePath: instancePath + "/bottomJoin",
            parentData: data3,
            parentDataProperty: "bottomJoin",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.bottomLeft !== void 0) {
          if (!validate46(data3.bottomLeft, {
            instancePath: instancePath + "/bottomLeft",
            parentData: data3,
            parentDataProperty: "bottomLeft",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.bottomRight !== void 0) {
          if (!validate46(data3.bottomRight, {
            instancePath: instancePath + "/bottomRight",
            parentData: data3,
            parentDataProperty: "bottomRight",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.bodyLeft !== void 0) {
          if (!validate46(data3.bodyLeft, {
            instancePath: instancePath + "/bodyLeft",
            parentData: data3,
            parentDataProperty: "bodyLeft",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.bodyRight !== void 0) {
          if (!validate46(data3.bodyRight, {
            instancePath: instancePath + "/bodyRight",
            parentData: data3,
            parentDataProperty: "bodyRight",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.bodyJoin !== void 0) {
          if (!validate46(data3.bodyJoin, {
            instancePath: instancePath + "/bodyJoin",
            parentData: data3,
            parentDataProperty: "bodyJoin",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.headerJoin !== void 0) {
          if (!validate46(data3.headerJoin, {
            instancePath: instancePath + "/headerJoin",
            parentData: data3,
            parentDataProperty: "headerJoin",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.joinBody !== void 0) {
          if (!validate46(data3.joinBody, {
            instancePath: instancePath + "/joinBody",
            parentData: data3,
            parentDataProperty: "joinBody",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.joinLeft !== void 0) {
          if (!validate46(data3.joinLeft, {
            instancePath: instancePath + "/joinLeft",
            parentData: data3,
            parentDataProperty: "joinLeft",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.joinRight !== void 0) {
          if (!validate46(data3.joinRight, {
            instancePath: instancePath + "/joinRight",
            parentData: data3,
            parentDataProperty: "joinRight",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.joinJoin !== void 0) {
          if (!validate46(data3.joinJoin, {
            instancePath: instancePath + "/joinJoin",
            parentData: data3,
            parentDataProperty: "joinJoin",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.joinMiddleUp !== void 0) {
          if (!validate46(data3.joinMiddleUp, {
            instancePath: instancePath + "/joinMiddleUp",
            parentData: data3,
            parentDataProperty: "joinMiddleUp",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.joinMiddleDown !== void 0) {
          if (!validate46(data3.joinMiddleDown, {
            instancePath: instancePath + "/joinMiddleDown",
            parentData: data3,
            parentDataProperty: "joinMiddleDown",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.joinMiddleLeft !== void 0) {
          if (!validate46(data3.joinMiddleLeft, {
            instancePath: instancePath + "/joinMiddleLeft",
            parentData: data3,
            parentDataProperty: "joinMiddleLeft",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
        if (data3.joinMiddleRight !== void 0) {
          if (!validate46(data3.joinMiddleRight, {
            instancePath: instancePath + "/joinMiddleRight",
            parentData: data3,
            parentDataProperty: "joinMiddleRight",
            rootData
          })) {
            vErrors = vErrors === null ? validate46.errors : vErrors.concat(validate46.errors);
            errors = vErrors.length;
          }
        }
      } else {
        const err1 = {
          instancePath,
          schemaPath: "#/type",
          keyword: "type",
          params: {
            type: "object"
          },
          message: "must be object"
        };
        if (vErrors === null) {
          vErrors = [err1];
        } else {
          vErrors.push(err1);
        }
        errors++;
      }
      validate87.errors = vErrors;
      return errors === 0;
    }
    __name(validate87, "validate87");
    function validate109(data3, { instancePath = "", parentData, parentDataProperty, rootData = data3 } = {}) {
      let vErrors = null;
      let errors = 0;
      const _errs0 = errors;
      let valid0 = false;
      let passing0 = null;
      const _errs1 = errors;
      if (data3 && typeof data3 == "object" && !Array.isArray(data3)) {
        for (const key0 in data3) {
          if (!pattern0.test(key0)) {
            const err0 = {
              instancePath,
              schemaPath: "#/oneOf/0/additionalProperties",
              keyword: "additionalProperties",
              params: {
                additionalProperty: key0
              },
              message: "must NOT have additional properties"
            };
            if (vErrors === null) {
              vErrors = [err0];
            } else {
              vErrors.push(err0);
            }
            errors++;
          }
        }
        for (const key1 in data3) {
          if (pattern0.test(key1)) {
            if (!validate71(data3[key1], {
              instancePath: instancePath + "/" + key1.replace(/~/g, "~0").replace(/\//g, "~1"),
              parentData: data3,
              parentDataProperty: key1,
              rootData
            })) {
              vErrors = vErrors === null ? validate71.errors : vErrors.concat(validate71.errors);
              errors = vErrors.length;
            }
          }
        }
      } else {
        const err1 = {
          instancePath,
          schemaPath: "#/oneOf/0/type",
          keyword: "type",
          params: {
            type: "object"
          },
          message: "must be object"
        };
        if (vErrors === null) {
          vErrors = [err1];
        } else {
          vErrors.push(err1);
        }
        errors++;
      }
      var _valid0 = _errs1 === errors;
      if (_valid0) {
        valid0 = true;
        passing0 = 0;
      }
      const _errs5 = errors;
      if (Array.isArray(data3)) {
        const len0 = data3.length;
        for (let i0 = 0; i0 < len0; i0++) {
          if (!validate71(data3[i0], {
            instancePath: instancePath + "/" + i0,
            parentData: data3,
            parentDataProperty: i0,
            rootData
          })) {
            vErrors = vErrors === null ? validate71.errors : vErrors.concat(validate71.errors);
            errors = vErrors.length;
          }
        }
      } else {
        const err2 = {
          instancePath,
          schemaPath: "#/oneOf/1/type",
          keyword: "type",
          params: {
            type: "array"
          },
          message: "must be array"
        };
        if (vErrors === null) {
          vErrors = [err2];
        } else {
          vErrors.push(err2);
        }
        errors++;
      }
      var _valid0 = _errs5 === errors;
      if (_valid0 && valid0) {
        valid0 = false;
        passing0 = [passing0, 1];
      } else {
        if (_valid0) {
          valid0 = true;
          passing0 = 1;
        }
      }
      if (!valid0) {
        const err3 = {
          instancePath,
          schemaPath: "#/oneOf",
          keyword: "oneOf",
          params: {
            passingSchemas: passing0
          },
          message: "must match exactly one schema in oneOf"
        };
        if (vErrors === null) {
          vErrors = [err3];
        } else {
          vErrors.push(err3);
        }
        errors++;
      } else {
        errors = _errs0;
        if (vErrors !== null) {
          if (_errs0) {
            vErrors.length = _errs0;
          } else {
            vErrors = null;
          }
        }
      }
      validate109.errors = vErrors;
      return errors === 0;
    }
    __name(validate109, "validate109");
    function validate113(data3, { instancePath = "", parentData, parentDataProperty, rootData = data3 } = {}) {
      let vErrors = null;
      let errors = 0;
      if (data3 && typeof data3 == "object" && !Array.isArray(data3)) {
        for (const key0 in data3) {
          if (!(key0 === "alignment" || key0 === "verticalAlignment" || key0 === "width" || key0 === "wrapWord" || key0 === "truncate" || key0 === "paddingLeft" || key0 === "paddingRight")) {
            const err0 = {
              instancePath,
              schemaPath: "#/additionalProperties",
              keyword: "additionalProperties",
              params: {
                additionalProperty: key0
              },
              message: "must NOT have additional properties"
            };
            if (vErrors === null) {
              vErrors = [err0];
            } else {
              vErrors.push(err0);
            }
            errors++;
          }
        }
        if (data3.alignment !== void 0) {
          if (!validate72(data3.alignment, {
            instancePath: instancePath + "/alignment",
            parentData: data3,
            parentDataProperty: "alignment",
            rootData
          })) {
            vErrors = vErrors === null ? validate72.errors : vErrors.concat(validate72.errors);
            errors = vErrors.length;
          }
        }
        if (data3.verticalAlignment !== void 0) {
          if (!validate74(data3.verticalAlignment, {
            instancePath: instancePath + "/verticalAlignment",
            parentData: data3,
            parentDataProperty: "verticalAlignment",
            rootData
          })) {
            vErrors = vErrors === null ? validate74.errors : vErrors.concat(validate74.errors);
            errors = vErrors.length;
          }
        }
        if (data3.width !== void 0) {
          let data22 = data3.width;
          if (!(typeof data22 == "number" && (!(data22 % 1) && !isNaN(data22)) && isFinite(data22))) {
            const err1 = {
              instancePath: instancePath + "/width",
              schemaPath: "#/properties/width/type",
              keyword: "type",
              params: {
                type: "integer"
              },
              message: "must be integer"
            };
            if (vErrors === null) {
              vErrors = [err1];
            } else {
              vErrors.push(err1);
            }
            errors++;
          }
          if (typeof data22 == "number" && isFinite(data22)) {
            if (data22 < 1 || isNaN(data22)) {
              const err2 = {
                instancePath: instancePath + "/width",
                schemaPath: "#/properties/width/minimum",
                keyword: "minimum",
                params: {
                  comparison: ">=",
                  limit: 1
                },
                message: "must be >= 1"
              };
              if (vErrors === null) {
                vErrors = [err2];
              } else {
                vErrors.push(err2);
              }
              errors++;
            }
          }
        }
        if (data3.wrapWord !== void 0) {
          if (typeof data3.wrapWord !== "boolean") {
            const err3 = {
              instancePath: instancePath + "/wrapWord",
              schemaPath: "#/properties/wrapWord/type",
              keyword: "type",
              params: {
                type: "boolean"
              },
              message: "must be boolean"
            };
            if (vErrors === null) {
              vErrors = [err3];
            } else {
              vErrors.push(err3);
            }
            errors++;
          }
        }
        if (data3.truncate !== void 0) {
          let data4 = data3.truncate;
          if (!(typeof data4 == "number" && (!(data4 % 1) && !isNaN(data4)) && isFinite(data4))) {
            const err4 = {
              instancePath: instancePath + "/truncate",
              schemaPath: "#/properties/truncate/type",
              keyword: "type",
              params: {
                type: "integer"
              },
              message: "must be integer"
            };
            if (vErrors === null) {
              vErrors = [err4];
            } else {
              vErrors.push(err4);
            }
            errors++;
          }
        }
        if (data3.paddingLeft !== void 0) {
          let data5 = data3.paddingLeft;
          if (!(typeof data5 == "number" && (!(data5 % 1) && !isNaN(data5)) && isFinite(data5))) {
            const err5 = {
              instancePath: instancePath + "/paddingLeft",
              schemaPath: "#/properties/paddingLeft/type",
              keyword: "type",
              params: {
                type: "integer"
              },
              message: "must be integer"
            };
            if (vErrors === null) {
              vErrors = [err5];
            } else {
              vErrors.push(err5);
            }
            errors++;
          }
        }
        if (data3.paddingRight !== void 0) {
          let data6 = data3.paddingRight;
          if (!(typeof data6 == "number" && (!(data6 % 1) && !isNaN(data6)) && isFinite(data6))) {
            const err6 = {
              instancePath: instancePath + "/paddingRight",
              schemaPath: "#/properties/paddingRight/type",
              keyword: "type",
              params: {
                type: "integer"
              },
              message: "must be integer"
            };
            if (vErrors === null) {
              vErrors = [err6];
            } else {
              vErrors.push(err6);
            }
            errors++;
          }
        }
      } else {
        const err7 = {
          instancePath,
          schemaPath: "#/type",
          keyword: "type",
          params: {
            type: "object"
          },
          message: "must be object"
        };
        if (vErrors === null) {
          vErrors = [err7];
        } else {
          vErrors.push(err7);
        }
        errors++;
      }
      validate113.errors = vErrors;
      return errors === 0;
    }
    __name(validate113, "validate113");
    function validate86(data3, { instancePath = "", parentData, parentDataProperty, rootData = data3 } = {}) {
      ;
      let vErrors = null;
      let errors = 0;
      if (data3 && typeof data3 == "object" && !Array.isArray(data3)) {
        if (data3.columnDefault === void 0) {
          const err0 = {
            instancePath,
            schemaPath: "#/required",
            keyword: "required",
            params: {
              missingProperty: "columnDefault"
            },
            message: "must have required property 'columnDefault'"
          };
          if (vErrors === null) {
            vErrors = [err0];
          } else {
            vErrors.push(err0);
          }
          errors++;
        }
        if (data3.columnCount === void 0) {
          const err1 = {
            instancePath,
            schemaPath: "#/required",
            keyword: "required",
            params: {
              missingProperty: "columnCount"
            },
            message: "must have required property 'columnCount'"
          };
          if (vErrors === null) {
            vErrors = [err1];
          } else {
            vErrors.push(err1);
          }
          errors++;
        }
        for (const key0 in data3) {
          if (!(key0 === "border" || key0 === "columns" || key0 === "columnDefault" || key0 === "columnCount" || key0 === "drawVerticalLine")) {
            const err2 = {
              instancePath,
              schemaPath: "#/additionalProperties",
              keyword: "additionalProperties",
              params: {
                additionalProperty: key0
              },
              message: "must NOT have additional properties"
            };
            if (vErrors === null) {
              vErrors = [err2];
            } else {
              vErrors.push(err2);
            }
            errors++;
          }
        }
        if (data3.border !== void 0) {
          if (!validate87(data3.border, {
            instancePath: instancePath + "/border",
            parentData: data3,
            parentDataProperty: "border",
            rootData
          })) {
            vErrors = vErrors === null ? validate87.errors : vErrors.concat(validate87.errors);
            errors = vErrors.length;
          }
        }
        if (data3.columns !== void 0) {
          if (!validate109(data3.columns, {
            instancePath: instancePath + "/columns",
            parentData: data3,
            parentDataProperty: "columns",
            rootData
          })) {
            vErrors = vErrors === null ? validate109.errors : vErrors.concat(validate109.errors);
            errors = vErrors.length;
          }
        }
        if (data3.columnDefault !== void 0) {
          if (!validate113(data3.columnDefault, {
            instancePath: instancePath + "/columnDefault",
            parentData: data3,
            parentDataProperty: "columnDefault",
            rootData
          })) {
            vErrors = vErrors === null ? validate113.errors : vErrors.concat(validate113.errors);
            errors = vErrors.length;
          }
        }
        if (data3.columnCount !== void 0) {
          let data32 = data3.columnCount;
          if (!(typeof data32 == "number" && (!(data32 % 1) && !isNaN(data32)) && isFinite(data32))) {
            const err3 = {
              instancePath: instancePath + "/columnCount",
              schemaPath: "#/properties/columnCount/type",
              keyword: "type",
              params: {
                type: "integer"
              },
              message: "must be integer"
            };
            if (vErrors === null) {
              vErrors = [err3];
            } else {
              vErrors.push(err3);
            }
            errors++;
          }
          if (typeof data32 == "number" && isFinite(data32)) {
            if (data32 < 1 || isNaN(data32)) {
              const err4 = {
                instancePath: instancePath + "/columnCount",
                schemaPath: "#/properties/columnCount/minimum",
                keyword: "minimum",
                params: {
                  comparison: ">=",
                  limit: 1
                },
                message: "must be >= 1"
              };
              if (vErrors === null) {
                vErrors = [err4];
              } else {
                vErrors.push(err4);
              }
              errors++;
            }
          }
        }
        if (data3.drawVerticalLine !== void 0) {
          if (typeof data3.drawVerticalLine != "function") {
            const err5 = {
              instancePath: instancePath + "/drawVerticalLine",
              schemaPath: "#/properties/drawVerticalLine/typeof",
              keyword: "typeof",
              params: {},
              message: 'must pass "typeof" keyword validation'
            };
            if (vErrors === null) {
              vErrors = [err5];
            } else {
              vErrors.push(err5);
            }
            errors++;
          }
        }
      } else {
        const err6 = {
          instancePath,
          schemaPath: "#/type",
          keyword: "type",
          params: {
            type: "object"
          },
          message: "must be object"
        };
        if (vErrors === null) {
          vErrors = [err6];
        } else {
          vErrors.push(err6);
        }
        errors++;
      }
      validate86.errors = vErrors;
      return errors === 0;
    }
    __name(validate86, "validate86");
  }
});

// ../../node_modules/table/dist/src/validateConfig.js
var require_validateConfig = __commonJS({
  "../../node_modules/table/dist/src/validateConfig.js"(exports2) {
    "use strict";
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.validateConfig = void 0;
    var validators_1 = __importDefault2(require_validators());
    var validateConfig = /* @__PURE__ */ __name((schemaId, config2) => {
      const validate = validators_1.default[schemaId];
      if (!validate(config2) && validate.errors) {
        const errors = validate.errors.map((error4) => {
          return {
            message: error4.message,
            params: error4.params,
            schemaPath: error4.schemaPath
          };
        });
        console.log("config", config2);
        console.log("errors", errors);
        throw new Error("Invalid config.");
      }
    }, "validateConfig");
    exports2.validateConfig = validateConfig;
  }
});

// ../../node_modules/table/dist/src/makeStreamConfig.js
var require_makeStreamConfig = __commonJS({
  "../../node_modules/table/dist/src/makeStreamConfig.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.makeStreamConfig = void 0;
    var utils_1 = require_utils8();
    var validateConfig_1 = require_validateConfig();
    var makeColumnsConfig = /* @__PURE__ */ __name((columnCount, columns = {}, columnDefault) => {
      return Array.from({ length: columnCount }).map((_, index) => {
        return {
          alignment: "left",
          paddingLeft: 1,
          paddingRight: 1,
          truncate: Number.POSITIVE_INFINITY,
          verticalAlignment: "top",
          wrapWord: false,
          ...columnDefault,
          ...columns[index]
        };
      });
    }, "makeColumnsConfig");
    var makeStreamConfig = /* @__PURE__ */ __name((config2) => {
      (0, validateConfig_1.validateConfig)("streamConfig.json", config2);
      if (config2.columnDefault.width === void 0) {
        throw new Error("Must provide config.columnDefault.width when creating a stream.");
      }
      return {
        drawVerticalLine: /* @__PURE__ */ __name(() => {
          return true;
        }, "drawVerticalLine"),
        ...config2,
        border: (0, utils_1.makeBorderConfig)(config2.border),
        columns: makeColumnsConfig(config2.columnCount, config2.columns, config2.columnDefault)
      };
    }, "makeStreamConfig");
    exports2.makeStreamConfig = makeStreamConfig;
  }
});

// ../../node_modules/table/dist/src/mapDataUsingRowHeights.js
var require_mapDataUsingRowHeights = __commonJS({
  "../../node_modules/table/dist/src/mapDataUsingRowHeights.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.mapDataUsingRowHeights = exports2.padCellVertically = void 0;
    var utils_1 = require_utils8();
    var wrapCell_1 = require_wrapCell();
    var createEmptyStrings = /* @__PURE__ */ __name((length) => {
      return new Array(length).fill("");
    }, "createEmptyStrings");
    var padCellVertically = /* @__PURE__ */ __name((lines, rowHeight, verticalAlignment) => {
      const availableLines = rowHeight - lines.length;
      if (verticalAlignment === "top") {
        return [...lines, ...createEmptyStrings(availableLines)];
      }
      if (verticalAlignment === "bottom") {
        return [...createEmptyStrings(availableLines), ...lines];
      }
      return [
        ...createEmptyStrings(Math.floor(availableLines / 2)),
        ...lines,
        ...createEmptyStrings(Math.ceil(availableLines / 2))
      ];
    }, "padCellVertically");
    exports2.padCellVertically = padCellVertically;
    var mapDataUsingRowHeights = /* @__PURE__ */ __name((unmappedRows, rowHeights, config2) => {
      const nColumns = unmappedRows[0].length;
      const mappedRows = unmappedRows.map((unmappedRow, unmappedRowIndex) => {
        const outputRowHeight = rowHeights[unmappedRowIndex];
        const outputRow = Array.from({ length: outputRowHeight }, () => {
          return new Array(nColumns).fill("");
        });
        unmappedRow.forEach((cell, cellIndex) => {
          var _a10;
          const containingRange = (_a10 = config2.spanningCellManager) === null || _a10 === void 0 ? void 0 : _a10.getContainingRange({
            col: cellIndex,
            row: unmappedRowIndex
          });
          if (containingRange) {
            containingRange.extractCellContent(unmappedRowIndex).forEach((cellLine, cellLineIndex) => {
              outputRow[cellLineIndex][cellIndex] = cellLine;
            });
            return;
          }
          const cellLines = (0, wrapCell_1.wrapCell)(cell, config2.columns[cellIndex].width, config2.columns[cellIndex].wrapWord);
          const paddedCellLines = (0, exports2.padCellVertically)(cellLines, outputRowHeight, config2.columns[cellIndex].verticalAlignment);
          paddedCellLines.forEach((cellLine, cellLineIndex) => {
            outputRow[cellLineIndex][cellIndex] = cellLine;
          });
        });
        return outputRow;
      });
      return (0, utils_1.flatten)(mappedRows);
    }, "mapDataUsingRowHeights");
    exports2.mapDataUsingRowHeights = mapDataUsingRowHeights;
  }
});

// ../../node_modules/table/dist/src/padTableData.js
var require_padTableData = __commonJS({
  "../../node_modules/table/dist/src/padTableData.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.padTableData = exports2.padString = void 0;
    var padString = /* @__PURE__ */ __name((input, paddingLeft, paddingRight) => {
      return " ".repeat(paddingLeft) + input + " ".repeat(paddingRight);
    }, "padString");
    exports2.padString = padString;
    var padTableData = /* @__PURE__ */ __name((rows, config2) => {
      return rows.map((cells, rowIndex) => {
        return cells.map((cell, cellIndex) => {
          var _a10;
          const containingRange = (_a10 = config2.spanningCellManager) === null || _a10 === void 0 ? void 0 : _a10.getContainingRange({
            col: cellIndex,
            row: rowIndex
          }, { mapped: true });
          if (containingRange) {
            return cell;
          }
          const { paddingLeft, paddingRight } = config2.columns[cellIndex];
          return (0, exports2.padString)(cell, paddingLeft, paddingRight);
        });
      });
    }, "padTableData");
    exports2.padTableData = padTableData;
  }
});

// ../../node_modules/table/dist/src/stringifyTableData.js
var require_stringifyTableData = __commonJS({
  "../../node_modules/table/dist/src/stringifyTableData.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.stringifyTableData = void 0;
    var utils_1 = require_utils8();
    var stringifyTableData = /* @__PURE__ */ __name((rows) => {
      return rows.map((cells) => {
        return cells.map((cell) => {
          return (0, utils_1.normalizeString)(String(cell));
        });
      });
    }, "stringifyTableData");
    exports2.stringifyTableData = stringifyTableData;
  }
});

// ../../node_modules/lodash.truncate/index.js
var require_lodash = __commonJS({
  "../../node_modules/lodash.truncate/index.js"(exports2, module2) {
    var DEFAULT_TRUNC_LENGTH = 30;
    var DEFAULT_TRUNC_OMISSION = "...";
    var INFINITY = 1 / 0;
    var MAX_INTEGER = 17976931348623157e292;
    var NAN = 0 / 0;
    var regexpTag = "[object RegExp]";
    var symbolTag = "[object Symbol]";
    var reTrim = /^\s+|\s+$/g;
    var reFlags = /\w*$/;
    var reIsBadHex = /^[-+]0x[0-9a-f]+$/i;
    var reIsBinary = /^0b[01]+$/i;
    var reIsOctal = /^0o[0-7]+$/i;
    var rsAstralRange = "\\ud800-\\udfff";
    var rsComboMarksRange = "\\u0300-\\u036f\\ufe20-\\ufe23";
    var rsComboSymbolsRange = "\\u20d0-\\u20f0";
    var rsVarRange = "\\ufe0e\\ufe0f";
    var rsAstral = "[" + rsAstralRange + "]";
    var rsCombo = "[" + rsComboMarksRange + rsComboSymbolsRange + "]";
    var rsFitz = "\\ud83c[\\udffb-\\udfff]";
    var rsModifier = "(?:" + rsCombo + "|" + rsFitz + ")";
    var rsNonAstral = "[^" + rsAstralRange + "]";
    var rsRegional = "(?:\\ud83c[\\udde6-\\uddff]){2}";
    var rsSurrPair = "[\\ud800-\\udbff][\\udc00-\\udfff]";
    var rsZWJ = "\\u200d";
    var reOptMod = rsModifier + "?";
    var rsOptVar = "[" + rsVarRange + "]?";
    var rsOptJoin = "(?:" + rsZWJ + "(?:" + [rsNonAstral, rsRegional, rsSurrPair].join("|") + ")" + rsOptVar + reOptMod + ")*";
    var rsSeq = rsOptVar + reOptMod + rsOptJoin;
    var rsSymbol = "(?:" + [rsNonAstral + rsCombo + "?", rsCombo, rsRegional, rsSurrPair, rsAstral].join("|") + ")";
    var reUnicode = RegExp(rsFitz + "(?=" + rsFitz + ")|" + rsSymbol + rsSeq, "g");
    var reHasUnicode = RegExp("[" + rsZWJ + rsAstralRange + rsComboMarksRange + rsComboSymbolsRange + rsVarRange + "]");
    var freeParseInt = parseInt;
    var freeGlobal = typeof global == "object" && global && global.Object === Object && global;
    var freeSelf = typeof self == "object" && self && self.Object === Object && self;
    var root32 = freeGlobal || freeSelf || Function("return this")();
    var freeExports = typeof exports2 == "object" && exports2 && !exports2.nodeType && exports2;
    var freeModule = freeExports && typeof module2 == "object" && module2 && !module2.nodeType && module2;
    var moduleExports = freeModule && freeModule.exports === freeExports;
    var freeProcess = moduleExports && freeGlobal.process;
    var nodeUtil = (function() {
      try {
        return freeProcess && freeProcess.binding("util");
      } catch (e32) {
      }
    })();
    var nodeIsRegExp = nodeUtil && nodeUtil.isRegExp;
    var asciiSize = baseProperty("length");
    function asciiToArray(string) {
      return string.split("");
    }
    __name(asciiToArray, "asciiToArray");
    function baseProperty(key) {
      return function(object) {
        return object == null ? void 0 : object[key];
      };
    }
    __name(baseProperty, "baseProperty");
    function baseUnary(func) {
      return function(value) {
        return func(value);
      };
    }
    __name(baseUnary, "baseUnary");
    function hasUnicode(string) {
      return reHasUnicode.test(string);
    }
    __name(hasUnicode, "hasUnicode");
    function stringSize(string) {
      return hasUnicode(string) ? unicodeSize(string) : asciiSize(string);
    }
    __name(stringSize, "stringSize");
    function stringToArray(string) {
      return hasUnicode(string) ? unicodeToArray(string) : asciiToArray(string);
    }
    __name(stringToArray, "stringToArray");
    function unicodeSize(string) {
      var result2 = reUnicode.lastIndex = 0;
      while (reUnicode.test(string)) {
        result2++;
      }
      return result2;
    }
    __name(unicodeSize, "unicodeSize");
    function unicodeToArray(string) {
      return string.match(reUnicode) || [];
    }
    __name(unicodeToArray, "unicodeToArray");
    var objectProto = Object.prototype;
    var objectToString = objectProto.toString;
    var Symbol2 = root32.Symbol;
    var symbolProto = Symbol2 ? Symbol2.prototype : void 0;
    var symbolToString = symbolProto ? symbolProto.toString : void 0;
    function baseIsRegExp(value) {
      return isObject3(value) && objectToString.call(value) == regexpTag;
    }
    __name(baseIsRegExp, "baseIsRegExp");
    function baseSlice(array, start, end) {
      var index = -1, length = array.length;
      if (start < 0) {
        start = -start > length ? 0 : length + start;
      }
      end = end > length ? length : end;
      if (end < 0) {
        end += length;
      }
      length = start > end ? 0 : end - start >>> 0;
      start >>>= 0;
      var result2 = Array(length);
      while (++index < length) {
        result2[index] = array[index + start];
      }
      return result2;
    }
    __name(baseSlice, "baseSlice");
    function baseToString(value) {
      if (typeof value == "string") {
        return value;
      }
      if (isSymbol(value)) {
        return symbolToString ? symbolToString.call(value) : "";
      }
      var result2 = value + "";
      return result2 == "0" && 1 / value == -INFINITY ? "-0" : result2;
    }
    __name(baseToString, "baseToString");
    function castSlice(array, start, end) {
      var length = array.length;
      end = end === void 0 ? length : end;
      return !start && end >= length ? array : baseSlice(array, start, end);
    }
    __name(castSlice, "castSlice");
    function isObject3(value) {
      var type = typeof value;
      return !!value && (type == "object" || type == "function");
    }
    __name(isObject3, "isObject");
    function isObjectLike(value) {
      return !!value && typeof value == "object";
    }
    __name(isObjectLike, "isObjectLike");
    var isRegExp = nodeIsRegExp ? baseUnary(nodeIsRegExp) : baseIsRegExp;
    function isSymbol(value) {
      return typeof value == "symbol" || isObjectLike(value) && objectToString.call(value) == symbolTag;
    }
    __name(isSymbol, "isSymbol");
    function toFinite(value) {
      if (!value) {
        return value === 0 ? value : 0;
      }
      value = toNumber(value);
      if (value === INFINITY || value === -INFINITY) {
        var sign = value < 0 ? -1 : 1;
        return sign * MAX_INTEGER;
      }
      return value === value ? value : 0;
    }
    __name(toFinite, "toFinite");
    function toInteger(value) {
      var result2 = toFinite(value), remainder = result2 % 1;
      return result2 === result2 ? remainder ? result2 - remainder : result2 : 0;
    }
    __name(toInteger, "toInteger");
    function toNumber(value) {
      if (typeof value == "number") {
        return value;
      }
      if (isSymbol(value)) {
        return NAN;
      }
      if (isObject3(value)) {
        var other = typeof value.valueOf == "function" ? value.valueOf() : value;
        value = isObject3(other) ? other + "" : other;
      }
      if (typeof value != "string") {
        return value === 0 ? value : +value;
      }
      value = value.replace(reTrim, "");
      var isBinary = reIsBinary.test(value);
      return isBinary || reIsOctal.test(value) ? freeParseInt(value.slice(2), isBinary ? 2 : 8) : reIsBadHex.test(value) ? NAN : +value;
    }
    __name(toNumber, "toNumber");
    function toString(value) {
      return value == null ? "" : baseToString(value);
    }
    __name(toString, "toString");
    function truncate(string, options) {
      var length = DEFAULT_TRUNC_LENGTH, omission = DEFAULT_TRUNC_OMISSION;
      if (isObject3(options)) {
        var separator = "separator" in options ? options.separator : separator;
        length = "length" in options ? toInteger(options.length) : length;
        omission = "omission" in options ? baseToString(options.omission) : omission;
      }
      string = toString(string);
      var strLength = string.length;
      if (hasUnicode(string)) {
        var strSymbols = stringToArray(string);
        strLength = strSymbols.length;
      }
      if (length >= strLength) {
        return string;
      }
      var end = length - stringSize(omission);
      if (end < 1) {
        return omission;
      }
      var result2 = strSymbols ? castSlice(strSymbols, 0, end).join("") : string.slice(0, end);
      if (separator === void 0) {
        return result2 + omission;
      }
      if (strSymbols) {
        end += result2.length - end;
      }
      if (isRegExp(separator)) {
        if (string.slice(end).search(separator)) {
          var match, substring3 = result2;
          if (!separator.global) {
            separator = RegExp(separator.source, toString(reFlags.exec(separator)) + "g");
          }
          separator.lastIndex = 0;
          while (match = separator.exec(substring3)) {
            var newEnd = match.index;
          }
          result2 = result2.slice(0, newEnd === void 0 ? end : newEnd);
        }
      } else if (string.indexOf(baseToString(separator), end) != end) {
        var index = result2.lastIndexOf(separator);
        if (index > -1) {
          result2 = result2.slice(0, index);
        }
      }
      return result2 + omission;
    }
    __name(truncate, "truncate");
    module2.exports = truncate;
  }
});

// ../../node_modules/table/dist/src/truncateTableData.js
var require_truncateTableData = __commonJS({
  "../../node_modules/table/dist/src/truncateTableData.js"(exports2) {
    "use strict";
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.truncateTableData = exports2.truncateString = void 0;
    var lodash_truncate_1 = __importDefault2(require_lodash());
    var truncateString = /* @__PURE__ */ __name((input, length) => {
      return (0, lodash_truncate_1.default)(input, {
        length,
        omission: "\u2026"
      });
    }, "truncateString");
    exports2.truncateString = truncateString;
    var truncateTableData = /* @__PURE__ */ __name((rows, truncates) => {
      return rows.map((cells) => {
        return cells.map((cell, cellIndex) => {
          return (0, exports2.truncateString)(cell, truncates[cellIndex]);
        });
      });
    }, "truncateTableData");
    exports2.truncateTableData = truncateTableData;
  }
});

// ../../node_modules/table/dist/src/createStream.js
var require_createStream = __commonJS({
  "../../node_modules/table/dist/src/createStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createStream = void 0;
    var alignTableData_1 = require_alignTableData();
    var calculateRowHeights_1 = require_calculateRowHeights();
    var drawBorder_1 = require_drawBorder();
    var drawRow_1 = require_drawRow();
    var makeStreamConfig_1 = require_makeStreamConfig();
    var mapDataUsingRowHeights_1 = require_mapDataUsingRowHeights();
    var padTableData_1 = require_padTableData();
    var stringifyTableData_1 = require_stringifyTableData();
    var truncateTableData_1 = require_truncateTableData();
    var utils_1 = require_utils8();
    var prepareData = /* @__PURE__ */ __name((data3, config2) => {
      let rows = (0, stringifyTableData_1.stringifyTableData)(data3);
      rows = (0, truncateTableData_1.truncateTableData)(rows, (0, utils_1.extractTruncates)(config2));
      const rowHeights = (0, calculateRowHeights_1.calculateRowHeights)(rows, config2);
      rows = (0, mapDataUsingRowHeights_1.mapDataUsingRowHeights)(rows, rowHeights, config2);
      rows = (0, alignTableData_1.alignTableData)(rows, config2);
      rows = (0, padTableData_1.padTableData)(rows, config2);
      return rows;
    }, "prepareData");
    var create = /* @__PURE__ */ __name((row, columnWidths, config2) => {
      const rows = prepareData([row], config2);
      const body = rows.map((literalRow) => {
        return (0, drawRow_1.drawRow)(literalRow, config2);
      }).join("");
      let output;
      output = "";
      output += (0, drawBorder_1.drawBorderTop)(columnWidths, config2);
      output += body;
      output += (0, drawBorder_1.drawBorderBottom)(columnWidths, config2);
      output = output.trimEnd();
      process.stdout.write(output);
    }, "create");
    var append = /* @__PURE__ */ __name((row, columnWidths, config2) => {
      const rows = prepareData([row], config2);
      const body = rows.map((literalRow) => {
        return (0, drawRow_1.drawRow)(literalRow, config2);
      }).join("");
      let output = "";
      const bottom = (0, drawBorder_1.drawBorderBottom)(columnWidths, config2);
      if (bottom !== "\n") {
        output = "\r\x1B[K";
      }
      output += (0, drawBorder_1.drawBorderJoin)(columnWidths, config2);
      output += body;
      output += bottom;
      output = output.trimEnd();
      process.stdout.write(output);
    }, "append");
    var createStream = /* @__PURE__ */ __name((userConfig) => {
      const config2 = (0, makeStreamConfig_1.makeStreamConfig)(userConfig);
      const columnWidths = Object.values(config2.columns).map((column) => {
        return column.width + column.paddingLeft + column.paddingRight;
      });
      let empty = true;
      return {
        write: /* @__PURE__ */ __name((row) => {
          if (row.length !== config2.columnCount) {
            throw new Error("Row cell count does not match the config.columnCount.");
          }
          if (empty) {
            empty = false;
            create(row, columnWidths, config2);
          } else {
            append(row, columnWidths, config2);
          }
        }, "write")
      };
    }, "createStream");
    exports2.createStream = createStream;
  }
});

// ../../node_modules/table/dist/src/calculateOutputColumnWidths.js
var require_calculateOutputColumnWidths = __commonJS({
  "../../node_modules/table/dist/src/calculateOutputColumnWidths.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.calculateOutputColumnWidths = void 0;
    var calculateOutputColumnWidths = /* @__PURE__ */ __name((config2) => {
      return config2.columns.map((col) => {
        return col.paddingLeft + col.width + col.paddingRight;
      });
    }, "calculateOutputColumnWidths");
    exports2.calculateOutputColumnWidths = calculateOutputColumnWidths;
  }
});

// ../../node_modules/table/dist/src/drawTable.js
var require_drawTable = __commonJS({
  "../../node_modules/table/dist/src/drawTable.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.drawTable = void 0;
    var drawBorder_1 = require_drawBorder();
    var drawContent_1 = require_drawContent();
    var drawRow_1 = require_drawRow();
    var utils_1 = require_utils8();
    var drawTable = /* @__PURE__ */ __name((rows, outputColumnWidths, rowHeights, config2) => {
      const { drawHorizontalLine, singleLine } = config2;
      const contents = (0, utils_1.groupBySizes)(rows, rowHeights).map((group7, groupIndex) => {
        return group7.map((row) => {
          return (0, drawRow_1.drawRow)(row, {
            ...config2,
            rowIndex: groupIndex
          });
        }).join("");
      });
      return (0, drawContent_1.drawContent)({
        contents,
        drawSeparator: /* @__PURE__ */ __name((index, size) => {
          if (index === 0 || index === size) {
            return drawHorizontalLine(index, size);
          }
          return !singleLine && drawHorizontalLine(index, size);
        }, "drawSeparator"),
        elementType: "row",
        rowIndex: -1,
        separatorGetter: (0, drawBorder_1.createTableBorderGetter)(outputColumnWidths, {
          ...config2,
          rowCount: contents.length
        }),
        spanningCellManager: config2.spanningCellManager
      });
    }, "drawTable");
    exports2.drawTable = drawTable;
  }
});

// ../../node_modules/table/dist/src/injectHeaderConfig.js
var require_injectHeaderConfig = __commonJS({
  "../../node_modules/table/dist/src/injectHeaderConfig.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.injectHeaderConfig = void 0;
    var injectHeaderConfig = /* @__PURE__ */ __name((rows, config2) => {
      var _a10;
      let spanningCellConfig = (_a10 = config2.spanningCells) !== null && _a10 !== void 0 ? _a10 : [];
      const headerConfig = config2.header;
      const adjustedRows = [...rows];
      if (headerConfig) {
        spanningCellConfig = spanningCellConfig.map(({ row, ...rest }) => {
          return {
            ...rest,
            row: row + 1
          };
        });
        const { content, ...headerStyles } = headerConfig;
        spanningCellConfig.unshift({
          alignment: "center",
          col: 0,
          colSpan: rows[0].length,
          paddingLeft: 1,
          paddingRight: 1,
          row: 0,
          wrapWord: false,
          ...headerStyles
        });
        adjustedRows.unshift([content, ...Array.from({ length: rows[0].length - 1 }).fill("")]);
      }
      return [
        adjustedRows,
        spanningCellConfig
      ];
    }, "injectHeaderConfig");
    exports2.injectHeaderConfig = injectHeaderConfig;
  }
});

// ../../node_modules/table/dist/src/calculateMaximumColumnWidths.js
var require_calculateMaximumColumnWidths = __commonJS({
  "../../node_modules/table/dist/src/calculateMaximumColumnWidths.js"(exports2) {
    "use strict";
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.calculateMaximumColumnWidths = exports2.calculateMaximumCellWidth = void 0;
    var string_width_1 = __importDefault2(require_string_width());
    var utils_1 = require_utils8();
    var calculateMaximumCellWidth = /* @__PURE__ */ __name((cell) => {
      return Math.max(...cell.split("\n").map(string_width_1.default));
    }, "calculateMaximumCellWidth");
    exports2.calculateMaximumCellWidth = calculateMaximumCellWidth;
    var calculateMaximumColumnWidths = /* @__PURE__ */ __name((rows, spanningCellConfigs = []) => {
      const columnWidths = new Array(rows[0].length).fill(0);
      const rangeCoordinates = spanningCellConfigs.map(utils_1.calculateRangeCoordinate);
      const isSpanningCell = /* @__PURE__ */ __name((rowIndex, columnIndex) => {
        return rangeCoordinates.some((rangeCoordinate) => {
          return (0, utils_1.isCellInRange)({
            col: columnIndex,
            row: rowIndex
          }, rangeCoordinate);
        });
      }, "isSpanningCell");
      rows.forEach((row, rowIndex) => {
        row.forEach((cell, cellIndex) => {
          if (isSpanningCell(rowIndex, cellIndex)) {
            return;
          }
          columnWidths[cellIndex] = Math.max(columnWidths[cellIndex], (0, exports2.calculateMaximumCellWidth)(cell));
        });
      });
      return columnWidths;
    }, "calculateMaximumColumnWidths");
    exports2.calculateMaximumColumnWidths = calculateMaximumColumnWidths;
  }
});

// ../../node_modules/table/dist/src/alignSpanningCell.js
var require_alignSpanningCell = __commonJS({
  "../../node_modules/table/dist/src/alignSpanningCell.js"(exports2) {
    "use strict";
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.alignVerticalRangeContent = exports2.wrapRangeContent = void 0;
    var string_width_1 = __importDefault2(require_string_width());
    var alignString_1 = require_alignString();
    var mapDataUsingRowHeights_1 = require_mapDataUsingRowHeights();
    var padTableData_1 = require_padTableData();
    var truncateTableData_1 = require_truncateTableData();
    var utils_1 = require_utils8();
    var wrapCell_1 = require_wrapCell();
    var wrapRangeContent = /* @__PURE__ */ __name((rangeConfig, rangeWidth, context) => {
      const { topLeft, paddingRight, paddingLeft, truncate, wrapWord, alignment } = rangeConfig;
      const originalContent = context.rows[topLeft.row][topLeft.col];
      const contentWidth = rangeWidth - paddingLeft - paddingRight;
      return (0, wrapCell_1.wrapCell)((0, truncateTableData_1.truncateString)(originalContent, truncate), contentWidth, wrapWord).map((line) => {
        const alignedLine = (0, alignString_1.alignString)(line, contentWidth, alignment);
        return (0, padTableData_1.padString)(alignedLine, paddingLeft, paddingRight);
      });
    }, "wrapRangeContent");
    exports2.wrapRangeContent = wrapRangeContent;
    var alignVerticalRangeContent = /* @__PURE__ */ __name((range7, content, context) => {
      const { rows, drawHorizontalLine, rowHeights } = context;
      const { topLeft, bottomRight, verticalAlignment } = range7;
      if (rowHeights.length === 0) {
        return [];
      }
      const totalCellHeight = (0, utils_1.sumArray)(rowHeights.slice(topLeft.row, bottomRight.row + 1));
      const totalBorderHeight = bottomRight.row - topLeft.row;
      const hiddenHorizontalBorderCount = (0, utils_1.sequence)(topLeft.row + 1, bottomRight.row).filter((horizontalBorderIndex) => {
        return !drawHorizontalLine(horizontalBorderIndex, rows.length);
      }).length;
      const availableRangeHeight = totalCellHeight + totalBorderHeight - hiddenHorizontalBorderCount;
      return (0, mapDataUsingRowHeights_1.padCellVertically)(content, availableRangeHeight, verticalAlignment).map((line) => {
        if (line.length === 0) {
          return " ".repeat((0, string_width_1.default)(content[0]));
        }
        return line;
      });
    }, "alignVerticalRangeContent");
    exports2.alignVerticalRangeContent = alignVerticalRangeContent;
  }
});

// ../../node_modules/table/dist/src/calculateSpanningCellWidth.js
var require_calculateSpanningCellWidth = __commonJS({
  "../../node_modules/table/dist/src/calculateSpanningCellWidth.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.calculateSpanningCellWidth = void 0;
    var utils_1 = require_utils8();
    var calculateSpanningCellWidth = /* @__PURE__ */ __name((rangeConfig, dependencies) => {
      const { columnsConfig, drawVerticalLine } = dependencies;
      const { topLeft, bottomRight } = rangeConfig;
      const totalWidth = (0, utils_1.sumArray)(columnsConfig.slice(topLeft.col, bottomRight.col + 1).map(({ width }) => {
        return width;
      }));
      const totalPadding = topLeft.col === bottomRight.col ? columnsConfig[topLeft.col].paddingRight + columnsConfig[bottomRight.col].paddingLeft : (0, utils_1.sumArray)(columnsConfig.slice(topLeft.col, bottomRight.col + 1).map(({ paddingLeft, paddingRight }) => {
        return paddingLeft + paddingRight;
      }));
      const totalBorderWidths = bottomRight.col - topLeft.col;
      const totalHiddenVerticalBorders = (0, utils_1.sequence)(topLeft.col + 1, bottomRight.col).filter((verticalBorderIndex) => {
        return !drawVerticalLine(verticalBorderIndex, columnsConfig.length);
      }).length;
      return totalWidth + totalPadding + totalBorderWidths - totalHiddenVerticalBorders;
    }, "calculateSpanningCellWidth");
    exports2.calculateSpanningCellWidth = calculateSpanningCellWidth;
  }
});

// ../../node_modules/table/dist/src/makeRangeConfig.js
var require_makeRangeConfig = __commonJS({
  "../../node_modules/table/dist/src/makeRangeConfig.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.makeRangeConfig = void 0;
    var utils_1 = require_utils8();
    var makeRangeConfig = /* @__PURE__ */ __name((spanningCellConfig, columnsConfig) => {
      var _a10;
      const { topLeft, bottomRight } = (0, utils_1.calculateRangeCoordinate)(spanningCellConfig);
      const cellConfig = {
        ...columnsConfig[topLeft.col],
        ...spanningCellConfig,
        paddingRight: (_a10 = spanningCellConfig.paddingRight) !== null && _a10 !== void 0 ? _a10 : columnsConfig[bottomRight.col].paddingRight
      };
      return {
        ...cellConfig,
        bottomRight,
        topLeft
      };
    }, "makeRangeConfig");
    exports2.makeRangeConfig = makeRangeConfig;
  }
});

// ../../node_modules/table/dist/src/spanningCellManager.js
var require_spanningCellManager = __commonJS({
  "../../node_modules/table/dist/src/spanningCellManager.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createSpanningCellManager = void 0;
    var alignSpanningCell_1 = require_alignSpanningCell();
    var calculateSpanningCellWidth_1 = require_calculateSpanningCellWidth();
    var makeRangeConfig_1 = require_makeRangeConfig();
    var utils_1 = require_utils8();
    var findRangeConfig = /* @__PURE__ */ __name((cell, rangeConfigs) => {
      return rangeConfigs.find((rangeCoordinate) => {
        return (0, utils_1.isCellInRange)(cell, rangeCoordinate);
      });
    }, "findRangeConfig");
    var getContainingRange = /* @__PURE__ */ __name((rangeConfig, context) => {
      const width = (0, calculateSpanningCellWidth_1.calculateSpanningCellWidth)(rangeConfig, context);
      const wrappedContent = (0, alignSpanningCell_1.wrapRangeContent)(rangeConfig, width, context);
      const alignedContent = (0, alignSpanningCell_1.alignVerticalRangeContent)(rangeConfig, wrappedContent, context);
      const getCellContent = /* @__PURE__ */ __name((rowIndex) => {
        const { topLeft } = rangeConfig;
        const { drawHorizontalLine, rowHeights } = context;
        const totalWithinHorizontalBorderHeight = rowIndex - topLeft.row;
        const totalHiddenHorizontalBorderHeight = (0, utils_1.sequence)(topLeft.row + 1, rowIndex).filter((index) => {
          return !(drawHorizontalLine === null || drawHorizontalLine === void 0 ? void 0 : drawHorizontalLine(index, rowHeights.length));
        }).length;
        const offset = (0, utils_1.sumArray)(rowHeights.slice(topLeft.row, rowIndex)) + totalWithinHorizontalBorderHeight - totalHiddenHorizontalBorderHeight;
        return alignedContent.slice(offset, offset + rowHeights[rowIndex]);
      }, "getCellContent");
      const getBorderContent = /* @__PURE__ */ __name((borderIndex) => {
        const { topLeft } = rangeConfig;
        const offset = (0, utils_1.sumArray)(context.rowHeights.slice(topLeft.row, borderIndex)) + (borderIndex - topLeft.row - 1);
        return alignedContent[offset];
      }, "getBorderContent");
      return {
        ...rangeConfig,
        extractBorderContent: getBorderContent,
        extractCellContent: getCellContent,
        height: wrappedContent.length,
        width
      };
    }, "getContainingRange");
    var inSameRange = /* @__PURE__ */ __name((cell1, cell2, ranges) => {
      const range1 = findRangeConfig(cell1, ranges);
      const range22 = findRangeConfig(cell2, ranges);
      if (range1 && range22) {
        return (0, utils_1.areCellEqual)(range1.topLeft, range22.topLeft);
      }
      return false;
    }, "inSameRange");
    var hashRange = /* @__PURE__ */ __name((range7) => {
      const { row, col } = range7.topLeft;
      return `${row}/${col}`;
    }, "hashRange");
    var createSpanningCellManager = /* @__PURE__ */ __name((parameters) => {
      const { spanningCellConfigs, columnsConfig } = parameters;
      const ranges = spanningCellConfigs.map((config2) => {
        return (0, makeRangeConfig_1.makeRangeConfig)(config2, columnsConfig);
      });
      const rangeCache = {};
      let rowHeights = [];
      let rowIndexMapping = [];
      return {
        getContainingRange: /* @__PURE__ */ __name((cell, options) => {
          var _a10;
          const originalRow = (options === null || options === void 0 ? void 0 : options.mapped) ? rowIndexMapping[cell.row] : cell.row;
          const range7 = findRangeConfig({
            ...cell,
            row: originalRow
          }, ranges);
          if (!range7) {
            return void 0;
          }
          if (rowHeights.length === 0) {
            return getContainingRange(range7, {
              ...parameters,
              rowHeights
            });
          }
          const hash = hashRange(range7);
          (_a10 = rangeCache[hash]) !== null && _a10 !== void 0 ? _a10 : rangeCache[hash] = getContainingRange(range7, {
            ...parameters,
            rowHeights
          });
          return rangeCache[hash];
        }, "getContainingRange"),
        inSameRange: /* @__PURE__ */ __name((cell1, cell2) => {
          return inSameRange(cell1, cell2, ranges);
        }, "inSameRange"),
        rowHeights,
        rowIndexMapping,
        setRowHeights: /* @__PURE__ */ __name((_rowHeights) => {
          rowHeights = _rowHeights;
        }, "setRowHeights"),
        setRowIndexMapping: /* @__PURE__ */ __name((mappedRowHeights) => {
          rowIndexMapping = (0, utils_1.flatten)(mappedRowHeights.map((height, index) => {
            return Array.from({ length: height }, () => {
              return index;
            });
          }));
        }, "setRowIndexMapping")
      };
    }, "createSpanningCellManager");
    exports2.createSpanningCellManager = createSpanningCellManager;
  }
});

// ../../node_modules/table/dist/src/validateSpanningCellConfig.js
var require_validateSpanningCellConfig = __commonJS({
  "../../node_modules/table/dist/src/validateSpanningCellConfig.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.validateSpanningCellConfig = void 0;
    var utils_1 = require_utils8();
    var inRange = /* @__PURE__ */ __name((start, end, value) => {
      return start <= value && value <= end;
    }, "inRange");
    var validateSpanningCellConfig = /* @__PURE__ */ __name((rows, configs) => {
      const [nRow, nCol] = [rows.length, rows[0].length];
      configs.forEach((config2, configIndex) => {
        const { colSpan, rowSpan } = config2;
        if (colSpan === void 0 && rowSpan === void 0) {
          throw new Error(`Expect at least colSpan or rowSpan is provided in config.spanningCells[${configIndex}]`);
        }
        if (colSpan !== void 0 && colSpan < 1) {
          throw new Error(`Expect colSpan is not equal zero, instead got: ${colSpan} in config.spanningCells[${configIndex}]`);
        }
        if (rowSpan !== void 0 && rowSpan < 1) {
          throw new Error(`Expect rowSpan is not equal zero, instead got: ${rowSpan} in config.spanningCells[${configIndex}]`);
        }
      });
      const rangeCoordinates = configs.map(utils_1.calculateRangeCoordinate);
      rangeCoordinates.forEach(({ topLeft, bottomRight }, rangeIndex) => {
        if (!inRange(0, nCol - 1, topLeft.col) || !inRange(0, nRow - 1, topLeft.row) || !inRange(0, nCol - 1, bottomRight.col) || !inRange(0, nRow - 1, bottomRight.row)) {
          throw new Error(`Some cells in config.spanningCells[${rangeIndex}] are out of the table`);
        }
      });
      const configOccupy = Array.from({ length: nRow }, () => {
        return Array.from({ length: nCol });
      });
      rangeCoordinates.forEach(({ topLeft, bottomRight }, rangeIndex) => {
        (0, utils_1.sequence)(topLeft.row, bottomRight.row).forEach((row) => {
          (0, utils_1.sequence)(topLeft.col, bottomRight.col).forEach((col) => {
            if (configOccupy[row][col] !== void 0) {
              throw new Error(`Spanning cells in config.spanningCells[${configOccupy[row][col]}] and config.spanningCells[${rangeIndex}] are overlap each other`);
            }
            configOccupy[row][col] = rangeIndex;
          });
        });
      });
    }, "validateSpanningCellConfig");
    exports2.validateSpanningCellConfig = validateSpanningCellConfig;
  }
});

// ../../node_modules/table/dist/src/makeTableConfig.js
var require_makeTableConfig = __commonJS({
  "../../node_modules/table/dist/src/makeTableConfig.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.makeTableConfig = void 0;
    var calculateMaximumColumnWidths_1 = require_calculateMaximumColumnWidths();
    var spanningCellManager_1 = require_spanningCellManager();
    var utils_1 = require_utils8();
    var validateConfig_1 = require_validateConfig();
    var validateSpanningCellConfig_1 = require_validateSpanningCellConfig();
    var makeColumnsConfig = /* @__PURE__ */ __name((rows, columns, columnDefault, spanningCellConfigs) => {
      const columnWidths = (0, calculateMaximumColumnWidths_1.calculateMaximumColumnWidths)(rows, spanningCellConfigs);
      return rows[0].map((_, columnIndex) => {
        return {
          alignment: "left",
          paddingLeft: 1,
          paddingRight: 1,
          truncate: Number.POSITIVE_INFINITY,
          verticalAlignment: "top",
          width: columnWidths[columnIndex],
          wrapWord: false,
          ...columnDefault,
          ...columns === null || columns === void 0 ? void 0 : columns[columnIndex]
        };
      });
    }, "makeColumnsConfig");
    var makeTableConfig = /* @__PURE__ */ __name((rows, config2 = {}, injectedSpanningCellConfig) => {
      var _a10, _b, _c32, _d, _e32;
      (0, validateConfig_1.validateConfig)("config.json", config2);
      (0, validateSpanningCellConfig_1.validateSpanningCellConfig)(rows, (_a10 = config2.spanningCells) !== null && _a10 !== void 0 ? _a10 : []);
      const spanningCellConfigs = (_b = injectedSpanningCellConfig !== null && injectedSpanningCellConfig !== void 0 ? injectedSpanningCellConfig : config2.spanningCells) !== null && _b !== void 0 ? _b : [];
      const columnsConfig = makeColumnsConfig(rows, config2.columns, config2.columnDefault, spanningCellConfigs);
      const drawVerticalLine = (_c32 = config2.drawVerticalLine) !== null && _c32 !== void 0 ? _c32 : (() => {
        return true;
      });
      const drawHorizontalLine = (_d = config2.drawHorizontalLine) !== null && _d !== void 0 ? _d : (() => {
        return true;
      });
      return {
        ...config2,
        border: (0, utils_1.makeBorderConfig)(config2.border),
        columns: columnsConfig,
        drawHorizontalLine,
        drawVerticalLine,
        singleLine: (_e32 = config2.singleLine) !== null && _e32 !== void 0 ? _e32 : false,
        spanningCellManager: (0, spanningCellManager_1.createSpanningCellManager)({
          columnsConfig,
          drawHorizontalLine,
          drawVerticalLine,
          rows,
          spanningCellConfigs
        })
      };
    }, "makeTableConfig");
    exports2.makeTableConfig = makeTableConfig;
  }
});

// ../../node_modules/table/dist/src/validateTableData.js
var require_validateTableData = __commonJS({
  "../../node_modules/table/dist/src/validateTableData.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.validateTableData = void 0;
    var utils_1 = require_utils8();
    var validateTableData = /* @__PURE__ */ __name((rows) => {
      if (!Array.isArray(rows)) {
        throw new TypeError("Table data must be an array.");
      }
      if (rows.length === 0) {
        throw new Error("Table must define at least one row.");
      }
      if (rows[0].length === 0) {
        throw new Error("Table must define at least one column.");
      }
      const columnNumber = rows[0].length;
      for (const row of rows) {
        if (!Array.isArray(row)) {
          throw new TypeError("Table row data must be an array.");
        }
        if (row.length !== columnNumber) {
          throw new Error("Table must have a consistent number of cells.");
        }
        for (const cell of row) {
          if (/[\u0001-\u0006\u0008\u0009\u000B-\u001A]/.test((0, utils_1.normalizeString)(String(cell)))) {
            throw new Error("Table data must not contain control characters.");
          }
        }
      }
    }, "validateTableData");
    exports2.validateTableData = validateTableData;
  }
});

// ../../node_modules/table/dist/src/table.js
var require_table = __commonJS({
  "../../node_modules/table/dist/src/table.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.table = void 0;
    var alignTableData_1 = require_alignTableData();
    var calculateOutputColumnWidths_1 = require_calculateOutputColumnWidths();
    var calculateRowHeights_1 = require_calculateRowHeights();
    var drawTable_1 = require_drawTable();
    var injectHeaderConfig_1 = require_injectHeaderConfig();
    var makeTableConfig_1 = require_makeTableConfig();
    var mapDataUsingRowHeights_1 = require_mapDataUsingRowHeights();
    var padTableData_1 = require_padTableData();
    var stringifyTableData_1 = require_stringifyTableData();
    var truncateTableData_1 = require_truncateTableData();
    var utils_1 = require_utils8();
    var validateTableData_1 = require_validateTableData();
    var table3 = /* @__PURE__ */ __name((data3, userConfig = {}) => {
      (0, validateTableData_1.validateTableData)(data3);
      let rows = (0, stringifyTableData_1.stringifyTableData)(data3);
      const [injectedRows, injectedSpanningCellConfig] = (0, injectHeaderConfig_1.injectHeaderConfig)(rows, userConfig);
      const config2 = (0, makeTableConfig_1.makeTableConfig)(injectedRows, userConfig, injectedSpanningCellConfig);
      rows = (0, truncateTableData_1.truncateTableData)(injectedRows, (0, utils_1.extractTruncates)(config2));
      const rowHeights = (0, calculateRowHeights_1.calculateRowHeights)(rows, config2);
      config2.spanningCellManager.setRowHeights(rowHeights);
      config2.spanningCellManager.setRowIndexMapping(rowHeights);
      rows = (0, mapDataUsingRowHeights_1.mapDataUsingRowHeights)(rows, rowHeights, config2);
      rows = (0, alignTableData_1.alignTableData)(rows, config2);
      rows = (0, padTableData_1.padTableData)(rows, config2);
      const outputColumnWidths = (0, calculateOutputColumnWidths_1.calculateOutputColumnWidths)(config2);
      return (0, drawTable_1.drawTable)(rows, outputColumnWidths, rowHeights, config2);
    }, "table");
    exports2.table = table3;
  }
});

// ../../node_modules/table/dist/src/types/api.js
var require_api = __commonJS({
  "../../node_modules/table/dist/src/types/api.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
  }
});

// ../../node_modules/table/dist/src/index.js
var require_src = __commonJS({
  "../../node_modules/table/dist/src/index.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      Object.defineProperty(o10, k210, { enumerable: true, get: /* @__PURE__ */ __name(function() {
        return m20[k32];
      }, "get") });
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __exportStar3 = exports2 && exports2.__exportStar || function(m20, exports3) {
      for (var p10 in m20) if (p10 !== "default" && !Object.prototype.hasOwnProperty.call(exports3, p10)) __createBinding3(exports3, m20, p10);
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getBorderCharacters = exports2.createStream = exports2.table = void 0;
    var createStream_1 = require_createStream();
    Object.defineProperty(exports2, "createStream", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return createStream_1.createStream;
    }, "get") });
    var getBorderCharacters_1 = require_getBorderCharacters();
    Object.defineProperty(exports2, "getBorderCharacters", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return getBorderCharacters_1.getBorderCharacters;
    }, "get") });
    var table_1 = require_table();
    Object.defineProperty(exports2, "table", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return table_1.table;
    }, "get") });
    __exportStar3(require_api(), exports2);
  }
});

// ../@aws-cdk/cloudformation-diff/lib/format-table.ts
var format_table_exports = {};
__export(format_table_exports, {
  formatTable: () => formatTable
});
function formatTable(cells, columns, noHorizontalLines) {
  return table.table(cells, {
    border: TABLE_BORDER_CHARACTERS,
    columns: buildColumnConfig(columns !== void 0 ? calculateColumnWidths(cells, columns) : void 0),
    drawHorizontalLine: /* @__PURE__ */ __name((line) => {
      if (noHorizontalLines) {
        return line < 2 || line === cells.length;
      }
      return line < 2 || line === cells.length || lineBetween(cells[line - 1], cells[line]);
    }, "drawHorizontalLine")
  }).trimRight();
}
function lineBetween(rowA, rowB) {
  return rowA[1] !== rowB[1];
}
function buildColumnConfig(widths) {
  if (widths === void 0) {
    return void 0;
  }
  const ret = {};
  widths.forEach((width, i32) => {
    if (width === void 0) {
      return;
    }
    ret[i32] = { width };
  });
  return ret;
}
function calculateColumnWidths(rows, terminalWidth) {
  terminalWidth = Math.max(terminalWidth, 40);
  const columns = rows[0].map((_, i32) => Math.max(...rows.map((row) => (0, import_string_width.default)(String(row[i32])))));
  const contentWidth = terminalWidth - 2 - columns.length * 3;
  if (sum(columns) <= contentWidth) {
    return columns;
  }
  const fairShare = Math.min(contentWidth / columns.length);
  const smallColumns = columns.filter((w) => w < fairShare);
  let distributableWidth = contentWidth - sum(smallColumns);
  const fairDistributable = Math.floor(distributableWidth / (columns.length - smallColumns.length));
  const ret = new Array();
  for (const requestedWidth of columns) {
    if (requestedWidth < fairShare) {
      ret.push(requestedWidth);
    } else {
      const width = distributableWidth < 2 * fairDistributable ? distributableWidth : fairDistributable;
      ret.push(width);
      distributableWidth -= width;
    }
  }
  return ret;
}
function sum(xs) {
  let total = 0;
  for (const x of xs) {
    total += x;
  }
  return total;
}
var chalk6, import_string_width, table, tableColor, TABLE_BORDER_CHARACTERS;
var init_format_table = __esm({
  "../@aws-cdk/cloudformation-diff/lib/format-table.ts"() {
    "use strict";
    chalk6 = __toESM(require_source());
    import_string_width = __toESM(require_string_width());
    table = __toESM(require_src());
    __name(formatTable, "formatTable");
    __name(lineBetween, "lineBetween");
    __name(buildColumnConfig, "buildColumnConfig");
    __name(calculateColumnWidths, "calculateColumnWidths");
    __name(sum, "sum");
    tableColor = chalk6.gray;
    TABLE_BORDER_CHARACTERS = {
      topBody: tableColor("\u2500"),
      topJoin: tableColor("\u252C"),
      topLeft: tableColor("\u250C"),
      topRight: tableColor("\u2510"),
      bottomBody: tableColor("\u2500"),
      bottomJoin: tableColor("\u2534"),
      bottomLeft: tableColor("\u2514"),
      bottomRight: tableColor("\u2518"),
      bodyLeft: tableColor("\u2502"),
      bodyRight: tableColor("\u2502"),
      bodyJoin: tableColor("\u2502"),
      joinBody: tableColor("\u2500"),
      joinLeft: tableColor("\u251C"),
      joinRight: tableColor("\u2524"),
      joinJoin: tableColor("\u253C")
    };
  }
});

// ../../node_modules/diff/libcjs/diff/base.js
var require_base = __commonJS({
  "../../node_modules/diff/libcjs/diff/base.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var Diff = class {
      static {
        __name(this, "Diff");
      }
      diff(oldStr, newStr, options = {}) {
        let callback;
        if (typeof options === "function") {
          callback = options;
          options = {};
        } else if ("callback" in options) {
          callback = options.callback;
        }
        const oldString = this.castInput(oldStr, options);
        const newString = this.castInput(newStr, options);
        const oldTokens = this.removeEmpty(this.tokenize(oldString, options));
        const newTokens = this.removeEmpty(this.tokenize(newString, options));
        return this.diffWithOptionsObj(oldTokens, newTokens, options, callback);
      }
      diffWithOptionsObj(oldTokens, newTokens, options, callback) {
        var _a10;
        const done = /* @__PURE__ */ __name((value) => {
          value = this.postProcess(value, options);
          if (callback) {
            setTimeout(function() {
              callback(value);
            }, 0);
            return void 0;
          } else {
            return value;
          }
        }, "done");
        const newLen = newTokens.length, oldLen = oldTokens.length;
        let editLength = 1;
        let maxEditLength = newLen + oldLen;
        if (options.maxEditLength != null) {
          maxEditLength = Math.min(maxEditLength, options.maxEditLength);
        }
        const maxExecutionTime = (_a10 = options.timeout) !== null && _a10 !== void 0 ? _a10 : Infinity;
        const abortAfterTimestamp = Date.now() + maxExecutionTime;
        const bestPath = [{ oldPos: -1, lastComponent: void 0 }];
        let newPos = this.extractCommon(bestPath[0], newTokens, oldTokens, 0, options);
        if (bestPath[0].oldPos + 1 >= oldLen && newPos + 1 >= newLen) {
          return done(this.buildValues(bestPath[0].lastComponent, newTokens, oldTokens));
        }
        let minDiagonalToConsider = -Infinity, maxDiagonalToConsider = Infinity;
        const execEditLength = /* @__PURE__ */ __name(() => {
          for (let diagonalPath = Math.max(minDiagonalToConsider, -editLength); diagonalPath <= Math.min(maxDiagonalToConsider, editLength); diagonalPath += 2) {
            let basePath;
            const removePath = bestPath[diagonalPath - 1], addPath = bestPath[diagonalPath + 1];
            if (removePath) {
              bestPath[diagonalPath - 1] = void 0;
            }
            let canAdd = false;
            if (addPath) {
              const addPathNewPos = addPath.oldPos - diagonalPath;
              canAdd = addPath && 0 <= addPathNewPos && addPathNewPos < newLen;
            }
            const canRemove = removePath && removePath.oldPos + 1 < oldLen;
            if (!canAdd && !canRemove) {
              bestPath[diagonalPath] = void 0;
              continue;
            }
            if (!canRemove || canAdd && removePath.oldPos < addPath.oldPos) {
              basePath = this.addToPath(addPath, true, false, 0, options);
            } else {
              basePath = this.addToPath(removePath, false, true, 1, options);
            }
            newPos = this.extractCommon(basePath, newTokens, oldTokens, diagonalPath, options);
            if (basePath.oldPos + 1 >= oldLen && newPos + 1 >= newLen) {
              return done(this.buildValues(basePath.lastComponent, newTokens, oldTokens)) || true;
            } else {
              bestPath[diagonalPath] = basePath;
              if (basePath.oldPos + 1 >= oldLen) {
                maxDiagonalToConsider = Math.min(maxDiagonalToConsider, diagonalPath - 1);
              }
              if (newPos + 1 >= newLen) {
                minDiagonalToConsider = Math.max(minDiagonalToConsider, diagonalPath + 1);
              }
            }
          }
          editLength++;
        }, "execEditLength");
        if (callback) {
          (/* @__PURE__ */ __name(function exec5() {
            setTimeout(function() {
              if (editLength > maxEditLength || Date.now() > abortAfterTimestamp) {
                return callback(void 0);
              }
              if (!execEditLength()) {
                exec5();
              }
            }, 0);
          }, "exec"))();
        } else {
          while (editLength <= maxEditLength && Date.now() <= abortAfterTimestamp) {
            const ret = execEditLength();
            if (ret) {
              return ret;
            }
          }
        }
      }
      addToPath(path47, added, removed, oldPosInc, options) {
        const last = path47.lastComponent;
        if (last && !options.oneChangePerToken && last.added === added && last.removed === removed) {
          return {
            oldPos: path47.oldPos + oldPosInc,
            lastComponent: { count: last.count + 1, added, removed, previousComponent: last.previousComponent }
          };
        } else {
          return {
            oldPos: path47.oldPos + oldPosInc,
            lastComponent: { count: 1, added, removed, previousComponent: last }
          };
        }
      }
      extractCommon(basePath, newTokens, oldTokens, diagonalPath, options) {
        const newLen = newTokens.length, oldLen = oldTokens.length;
        let oldPos = basePath.oldPos, newPos = oldPos - diagonalPath, commonCount = 0;
        while (newPos + 1 < newLen && oldPos + 1 < oldLen && this.equals(oldTokens[oldPos + 1], newTokens[newPos + 1], options)) {
          newPos++;
          oldPos++;
          commonCount++;
          if (options.oneChangePerToken) {
            basePath.lastComponent = { count: 1, previousComponent: basePath.lastComponent, added: false, removed: false };
          }
        }
        if (commonCount && !options.oneChangePerToken) {
          basePath.lastComponent = { count: commonCount, previousComponent: basePath.lastComponent, added: false, removed: false };
        }
        basePath.oldPos = oldPos;
        return newPos;
      }
      equals(left, right, options) {
        if (options.comparator) {
          return options.comparator(left, right);
        } else {
          return left === right || !!options.ignoreCase && left.toLowerCase() === right.toLowerCase();
        }
      }
      removeEmpty(array) {
        const ret = [];
        for (let i32 = 0; i32 < array.length; i32++) {
          if (array[i32]) {
            ret.push(array[i32]);
          }
        }
        return ret;
      }
      // eslint-disable-next-line @typescript-eslint/no-unused-vars
      castInput(value, options) {
        return value;
      }
      // eslint-disable-next-line @typescript-eslint/no-unused-vars
      tokenize(value, options) {
        return Array.from(value);
      }
      join(chars6) {
        return chars6.join("");
      }
      postProcess(changeObjects, options) {
        return changeObjects;
      }
      get useLongestToken() {
        return false;
      }
      buildValues(lastComponent, newTokens, oldTokens) {
        const components = [];
        let nextComponent;
        while (lastComponent) {
          components.push(lastComponent);
          nextComponent = lastComponent.previousComponent;
          delete lastComponent.previousComponent;
          lastComponent = nextComponent;
        }
        components.reverse();
        const componentLen = components.length;
        let componentPos = 0, newPos = 0, oldPos = 0;
        for (; componentPos < componentLen; componentPos++) {
          const component = components[componentPos];
          if (!component.removed) {
            if (!component.added && this.useLongestToken) {
              let value = newTokens.slice(newPos, newPos + component.count);
              value = value.map(function(value2, i32) {
                const oldValue = oldTokens[oldPos + i32];
                return oldValue.length > value2.length ? oldValue : value2;
              });
              component.value = this.join(value);
            } else {
              component.value = this.join(newTokens.slice(newPos, newPos + component.count));
            }
            newPos += component.count;
            if (!component.added) {
              oldPos += component.count;
            }
          } else {
            component.value = this.join(oldTokens.slice(oldPos, oldPos + component.count));
            oldPos += component.count;
          }
        }
        return components;
      }
    };
    exports2.default = Diff;
  }
});

// ../../node_modules/diff/libcjs/diff/character.js
var require_character = __commonJS({
  "../../node_modules/diff/libcjs/diff/character.js"(exports2) {
    "use strict";
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.characterDiff = void 0;
    exports2.diffChars = diffChars;
    var base_js_1 = __importDefault2(require_base());
    var CharacterDiff = class extends base_js_1.default {
      static {
        __name(this, "CharacterDiff");
      }
    };
    exports2.characterDiff = new CharacterDiff();
    function diffChars(oldStr, newStr, options) {
      return exports2.characterDiff.diff(oldStr, newStr, options);
    }
    __name(diffChars, "diffChars");
  }
});

// ../../node_modules/diff/libcjs/util/string.js
var require_string2 = __commonJS({
  "../../node_modules/diff/libcjs/util/string.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.longestCommonPrefix = longestCommonPrefix;
    exports2.longestCommonSuffix = longestCommonSuffix;
    exports2.replacePrefix = replacePrefix;
    exports2.replaceSuffix = replaceSuffix;
    exports2.removePrefix = removePrefix;
    exports2.removeSuffix = removeSuffix;
    exports2.maximumOverlap = maximumOverlap;
    exports2.hasOnlyWinLineEndings = hasOnlyWinLineEndings;
    exports2.hasOnlyUnixLineEndings = hasOnlyUnixLineEndings;
    exports2.segment = segment;
    exports2.trailingWs = trailingWs;
    exports2.leadingWs = leadingWs;
    exports2.leadingAndTrailingWs = leadingAndTrailingWs;
    function longestCommonPrefix(str1, str2) {
      let i32;
      for (i32 = 0; i32 < str1.length && i32 < str2.length; i32++) {
        if (str1[i32] != str2[i32]) {
          return str1.slice(0, i32);
        }
      }
      return str1.slice(0, i32);
    }
    __name(longestCommonPrefix, "longestCommonPrefix");
    function longestCommonSuffix(str1, str2) {
      let i32;
      if (!str1 || !str2 || str1[str1.length - 1] != str2[str2.length - 1]) {
        return "";
      }
      for (i32 = 0; i32 < str1.length && i32 < str2.length; i32++) {
        if (str1[str1.length - (i32 + 1)] != str2[str2.length - (i32 + 1)]) {
          return str1.slice(-i32);
        }
      }
      return str1.slice(-i32);
    }
    __name(longestCommonSuffix, "longestCommonSuffix");
    function replacePrefix(string, oldPrefix, newPrefix) {
      if (string.slice(0, oldPrefix.length) != oldPrefix) {
        throw Error(`string ${JSON.stringify(string)} doesn't start with prefix ${JSON.stringify(oldPrefix)}; this is a bug`);
      }
      return newPrefix + string.slice(oldPrefix.length);
    }
    __name(replacePrefix, "replacePrefix");
    function replaceSuffix(string, oldSuffix, newSuffix) {
      if (!oldSuffix) {
        return string + newSuffix;
      }
      if (string.slice(-oldSuffix.length) != oldSuffix) {
        throw Error(`string ${JSON.stringify(string)} doesn't end with suffix ${JSON.stringify(oldSuffix)}; this is a bug`);
      }
      return string.slice(0, -oldSuffix.length) + newSuffix;
    }
    __name(replaceSuffix, "replaceSuffix");
    function removePrefix(string, oldPrefix) {
      return replacePrefix(string, oldPrefix, "");
    }
    __name(removePrefix, "removePrefix");
    function removeSuffix(string, oldSuffix) {
      return replaceSuffix(string, oldSuffix, "");
    }
    __name(removeSuffix, "removeSuffix");
    function maximumOverlap(string1, string2) {
      return string2.slice(0, overlapCount(string1, string2));
    }
    __name(maximumOverlap, "maximumOverlap");
    function overlapCount(a32, b32) {
      let startA = 0;
      if (a32.length > b32.length) {
        startA = a32.length - b32.length;
      }
      let endB = b32.length;
      if (a32.length < b32.length) {
        endB = a32.length;
      }
      const map5 = Array(endB);
      let k32 = 0;
      map5[0] = 0;
      for (let j32 = 1; j32 < endB; j32++) {
        if (b32[j32] == b32[k32]) {
          map5[j32] = map5[k32];
        } else {
          map5[j32] = k32;
        }
        while (k32 > 0 && b32[j32] != b32[k32]) {
          k32 = map5[k32];
        }
        if (b32[j32] == b32[k32]) {
          k32++;
        }
      }
      k32 = 0;
      for (let i32 = startA; i32 < a32.length; i32++) {
        while (k32 > 0 && a32[i32] != b32[k32]) {
          k32 = map5[k32];
        }
        if (a32[i32] == b32[k32]) {
          k32++;
        }
      }
      return k32;
    }
    __name(overlapCount, "overlapCount");
    function hasOnlyWinLineEndings(string) {
      return string.includes("\r\n") && !string.startsWith("\n") && !string.match(/[^\r]\n/);
    }
    __name(hasOnlyWinLineEndings, "hasOnlyWinLineEndings");
    function hasOnlyUnixLineEndings(string) {
      return !string.includes("\r\n") && string.includes("\n");
    }
    __name(hasOnlyUnixLineEndings, "hasOnlyUnixLineEndings");
    function segment(string, segmenter) {
      const parts = [];
      for (const segmentObj of Array.from(segmenter.segment(string))) {
        const segment2 = segmentObj.segment;
        if (parts.length && /\s/.test(parts[parts.length - 1]) && /\s/.test(segment2)) {
          parts[parts.length - 1] += segment2;
        } else {
          parts.push(segment2);
        }
      }
      return parts;
    }
    __name(segment, "segment");
    function trailingWs(string, segmenter) {
      if (segmenter) {
        return leadingAndTrailingWs(string, segmenter)[1];
      }
      let i32;
      for (i32 = string.length - 1; i32 >= 0; i32--) {
        if (!string[i32].match(/\s/)) {
          break;
        }
      }
      return string.substring(i32 + 1);
    }
    __name(trailingWs, "trailingWs");
    function leadingWs(string, segmenter) {
      if (segmenter) {
        return leadingAndTrailingWs(string, segmenter)[0];
      }
      const match = string.match(/^\s*/);
      return match ? match[0] : "";
    }
    __name(leadingWs, "leadingWs");
    function leadingAndTrailingWs(string, segmenter) {
      if (!segmenter) {
        return [leadingWs(string), trailingWs(string)];
      }
      if (segmenter.resolvedOptions().granularity != "word") {
        throw new Error('The segmenter passed must have a granularity of "word"');
      }
      const segments = segment(string, segmenter);
      const firstSeg = segments[0];
      const lastSeg = segments[segments.length - 1];
      const head = /\s/.test(firstSeg) ? firstSeg : "";
      const tail = /\s/.test(lastSeg) ? lastSeg : "";
      return [head, tail];
    }
    __name(leadingAndTrailingWs, "leadingAndTrailingWs");
  }
});

// ../../node_modules/diff/libcjs/diff/word.js
var require_word = __commonJS({
  "../../node_modules/diff/libcjs/diff/word.js"(exports2) {
    "use strict";
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.wordsWithSpaceDiff = exports2.wordDiff = void 0;
    exports2.diffWords = diffWords;
    exports2.diffWordsWithSpace = diffWordsWithSpace;
    var base_js_1 = __importDefault2(require_base());
    var string_js_1 = require_string2();
    var extendedWordChars = "a-zA-Z0-9_\\u{AD}\\u{C0}-\\u{D6}\\u{D8}-\\u{F6}\\u{F8}-\\u{2C6}\\u{2C8}-\\u{2D7}\\u{2DE}-\\u{2FF}\\u{1E00}-\\u{1EFF}";
    var tokenizeIncludingWhitespace = new RegExp(`[${extendedWordChars}]+|\\s+|[^${extendedWordChars}]`, "ug");
    var WordDiff = class extends base_js_1.default {
      static {
        __name(this, "WordDiff");
      }
      equals(left, right, options) {
        if (options.ignoreCase) {
          left = left.toLowerCase();
          right = right.toLowerCase();
        }
        return left.trim() === right.trim();
      }
      tokenize(value, options = {}) {
        let parts;
        if (options.intlSegmenter) {
          const segmenter = options.intlSegmenter;
          if (segmenter.resolvedOptions().granularity != "word") {
            throw new Error('The segmenter passed must have a granularity of "word"');
          }
          parts = (0, string_js_1.segment)(value, segmenter);
        } else {
          parts = value.match(tokenizeIncludingWhitespace) || [];
        }
        const tokens = [];
        let prevPart = null;
        parts.forEach((part) => {
          if (/\s/.test(part)) {
            if (prevPart == null) {
              tokens.push(part);
            } else {
              tokens.push(tokens.pop() + part);
            }
          } else if (prevPart != null && /\s/.test(prevPart)) {
            if (tokens[tokens.length - 1] == prevPart) {
              tokens.push(tokens.pop() + part);
            } else {
              tokens.push(prevPart + part);
            }
          } else {
            tokens.push(part);
          }
          prevPart = part;
        });
        return tokens;
      }
      join(tokens) {
        return tokens.map((token, i32) => {
          if (i32 == 0) {
            return token;
          } else {
            return token.replace(/^\s+/, "");
          }
        }).join("");
      }
      postProcess(changes, options) {
        if (!changes || options.oneChangePerToken) {
          return changes;
        }
        let lastKeep = null;
        let insertion = null;
        let deletion = null;
        changes.forEach((change) => {
          if (change.added) {
            insertion = change;
          } else if (change.removed) {
            deletion = change;
          } else {
            if (insertion || deletion) {
              dedupeWhitespaceInChangeObjects(lastKeep, deletion, insertion, change, options.intlSegmenter);
            }
            lastKeep = change;
            insertion = null;
            deletion = null;
          }
        });
        if (insertion || deletion) {
          dedupeWhitespaceInChangeObjects(lastKeep, deletion, insertion, null, options.intlSegmenter);
        }
        return changes;
      }
    };
    exports2.wordDiff = new WordDiff();
    function diffWords(oldStr, newStr, options) {
      if ((options === null || options === void 0 ? void 0 : options.ignoreWhitespace) != null && !options.ignoreWhitespace) {
        return diffWordsWithSpace(oldStr, newStr, options);
      }
      return exports2.wordDiff.diff(oldStr, newStr, options);
    }
    __name(diffWords, "diffWords");
    function dedupeWhitespaceInChangeObjects(startKeep, deletion, insertion, endKeep, segmenter) {
      if (deletion && insertion) {
        const [oldWsPrefix, oldWsSuffix] = (0, string_js_1.leadingAndTrailingWs)(deletion.value, segmenter);
        const [newWsPrefix, newWsSuffix] = (0, string_js_1.leadingAndTrailingWs)(insertion.value, segmenter);
        if (startKeep) {
          const commonWsPrefix = (0, string_js_1.longestCommonPrefix)(oldWsPrefix, newWsPrefix);
          startKeep.value = (0, string_js_1.replaceSuffix)(startKeep.value, newWsPrefix, commonWsPrefix);
          deletion.value = (0, string_js_1.removePrefix)(deletion.value, commonWsPrefix);
          insertion.value = (0, string_js_1.removePrefix)(insertion.value, commonWsPrefix);
        }
        if (endKeep) {
          const commonWsSuffix = (0, string_js_1.longestCommonSuffix)(oldWsSuffix, newWsSuffix);
          endKeep.value = (0, string_js_1.replacePrefix)(endKeep.value, newWsSuffix, commonWsSuffix);
          deletion.value = (0, string_js_1.removeSuffix)(deletion.value, commonWsSuffix);
          insertion.value = (0, string_js_1.removeSuffix)(insertion.value, commonWsSuffix);
        }
      } else if (insertion) {
        if (startKeep) {
          const ws = (0, string_js_1.leadingWs)(insertion.value, segmenter);
          insertion.value = insertion.value.substring(ws.length);
        }
        if (endKeep) {
          const ws = (0, string_js_1.leadingWs)(endKeep.value, segmenter);
          endKeep.value = endKeep.value.substring(ws.length);
        }
      } else if (startKeep && endKeep) {
        const newWsFull = (0, string_js_1.leadingWs)(endKeep.value, segmenter), [delWsStart, delWsEnd] = (0, string_js_1.leadingAndTrailingWs)(deletion.value, segmenter);
        const newWsStart = (0, string_js_1.longestCommonPrefix)(newWsFull, delWsStart);
        deletion.value = (0, string_js_1.removePrefix)(deletion.value, newWsStart);
        const newWsEnd = (0, string_js_1.longestCommonSuffix)((0, string_js_1.removePrefix)(newWsFull, newWsStart), delWsEnd);
        deletion.value = (0, string_js_1.removeSuffix)(deletion.value, newWsEnd);
        endKeep.value = (0, string_js_1.replacePrefix)(endKeep.value, newWsFull, newWsEnd);
        startKeep.value = (0, string_js_1.replaceSuffix)(startKeep.value, newWsFull, newWsFull.slice(0, newWsFull.length - newWsEnd.length));
      } else if (endKeep) {
        const endKeepWsPrefix = (0, string_js_1.leadingWs)(endKeep.value, segmenter);
        const deletionWsSuffix = (0, string_js_1.trailingWs)(deletion.value, segmenter);
        const overlap = (0, string_js_1.maximumOverlap)(deletionWsSuffix, endKeepWsPrefix);
        deletion.value = (0, string_js_1.removeSuffix)(deletion.value, overlap);
      } else if (startKeep) {
        const startKeepWsSuffix = (0, string_js_1.trailingWs)(startKeep.value, segmenter);
        const deletionWsPrefix = (0, string_js_1.leadingWs)(deletion.value, segmenter);
        const overlap = (0, string_js_1.maximumOverlap)(startKeepWsSuffix, deletionWsPrefix);
        deletion.value = (0, string_js_1.removePrefix)(deletion.value, overlap);
      }
    }
    __name(dedupeWhitespaceInChangeObjects, "dedupeWhitespaceInChangeObjects");
    var WordsWithSpaceDiff = class extends base_js_1.default {
      static {
        __name(this, "WordsWithSpaceDiff");
      }
      tokenize(value) {
        const regex = new RegExp(`(\\r?\\n)|[${extendedWordChars}]+|[^\\S\\n\\r]+|[^${extendedWordChars}]`, "ug");
        return value.match(regex) || [];
      }
    };
    exports2.wordsWithSpaceDiff = new WordsWithSpaceDiff();
    function diffWordsWithSpace(oldStr, newStr, options) {
      return exports2.wordsWithSpaceDiff.diff(oldStr, newStr, options);
    }
    __name(diffWordsWithSpace, "diffWordsWithSpace");
  }
});

// ../../node_modules/diff/libcjs/util/params.js
var require_params = __commonJS({
  "../../node_modules/diff/libcjs/util/params.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.generateOptions = generateOptions;
    function generateOptions(options, defaults) {
      if (typeof options === "function") {
        defaults.callback = options;
      } else if (options) {
        for (const name in options) {
          if (Object.prototype.hasOwnProperty.call(options, name)) {
            defaults[name] = options[name];
          }
        }
      }
      return defaults;
    }
    __name(generateOptions, "generateOptions");
  }
});

// ../../node_modules/diff/libcjs/diff/line.js
var require_line = __commonJS({
  "../../node_modules/diff/libcjs/diff/line.js"(exports2) {
    "use strict";
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.lineDiff = void 0;
    exports2.diffLines = diffLines;
    exports2.diffTrimmedLines = diffTrimmedLines;
    exports2.tokenize = tokenize;
    var base_js_1 = __importDefault2(require_base());
    var params_js_1 = require_params();
    var LineDiff = class extends base_js_1.default {
      static {
        __name(this, "LineDiff");
      }
      constructor() {
        super(...arguments);
        this.tokenize = tokenize;
      }
      equals(left, right, options) {
        if (options.ignoreWhitespace) {
          if (!options.newlineIsToken || !left.includes("\n")) {
            left = left.trim();
          }
          if (!options.newlineIsToken || !right.includes("\n")) {
            right = right.trim();
          }
        } else if (options.ignoreNewlineAtEof && !options.newlineIsToken) {
          if (left.endsWith("\n")) {
            left = left.slice(0, -1);
          }
          if (right.endsWith("\n")) {
            right = right.slice(0, -1);
          }
        }
        return super.equals(left, right, options);
      }
    };
    exports2.lineDiff = new LineDiff();
    function diffLines(oldStr, newStr, options) {
      return exports2.lineDiff.diff(oldStr, newStr, options);
    }
    __name(diffLines, "diffLines");
    function diffTrimmedLines(oldStr, newStr, options) {
      options = (0, params_js_1.generateOptions)(options, { ignoreWhitespace: true });
      return exports2.lineDiff.diff(oldStr, newStr, options);
    }
    __name(diffTrimmedLines, "diffTrimmedLines");
    function tokenize(value, options) {
      if (options.stripTrailingCr) {
        value = value.replace(/\r\n/g, "\n");
      }
      const retLines = [], linesAndNewlines = value.split(/(\n|\r\n)/);
      if (!linesAndNewlines[linesAndNewlines.length - 1]) {
        linesAndNewlines.pop();
      }
      for (let i32 = 0; i32 < linesAndNewlines.length; i32++) {
        const line = linesAndNewlines[i32];
        if (i32 % 2 && !options.newlineIsToken) {
          retLines[retLines.length - 1] += line;
        } else {
          retLines.push(line);
        }
      }
      return retLines;
    }
    __name(tokenize, "tokenize");
  }
});

// ../../node_modules/diff/libcjs/diff/sentence.js
var require_sentence = __commonJS({
  "../../node_modules/diff/libcjs/diff/sentence.js"(exports2) {
    "use strict";
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.sentenceDiff = void 0;
    exports2.diffSentences = diffSentences;
    var base_js_1 = __importDefault2(require_base());
    function isSentenceEndPunct(char) {
      return char == "." || char == "!" || char == "?";
    }
    __name(isSentenceEndPunct, "isSentenceEndPunct");
    var SentenceDiff = class extends base_js_1.default {
      static {
        __name(this, "SentenceDiff");
      }
      tokenize(value) {
        var _a10;
        const result2 = [];
        let tokenStartI = 0;
        for (let i32 = 0; i32 < value.length; i32++) {
          if (i32 == value.length - 1) {
            result2.push(value.slice(tokenStartI));
            break;
          }
          if (isSentenceEndPunct(value[i32]) && value[i32 + 1].match(/\s/)) {
            result2.push(value.slice(tokenStartI, i32 + 1));
            i32 = tokenStartI = i32 + 1;
            while ((_a10 = value[i32 + 1]) === null || _a10 === void 0 ? void 0 : _a10.match(/\s/)) {
              i32++;
            }
            result2.push(value.slice(tokenStartI, i32 + 1));
            tokenStartI = i32 + 1;
          }
        }
        return result2;
      }
    };
    exports2.sentenceDiff = new SentenceDiff();
    function diffSentences(oldStr, newStr, options) {
      return exports2.sentenceDiff.diff(oldStr, newStr, options);
    }
    __name(diffSentences, "diffSentences");
  }
});

// ../../node_modules/diff/libcjs/diff/css.js
var require_css = __commonJS({
  "../../node_modules/diff/libcjs/diff/css.js"(exports2) {
    "use strict";
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.cssDiff = void 0;
    exports2.diffCss = diffCss;
    var base_js_1 = __importDefault2(require_base());
    var CssDiff = class extends base_js_1.default {
      static {
        __name(this, "CssDiff");
      }
      tokenize(value) {
        return value.split(/([{}:;,]|\s+)/);
      }
    };
    exports2.cssDiff = new CssDiff();
    function diffCss(oldStr, newStr, options) {
      return exports2.cssDiff.diff(oldStr, newStr, options);
    }
    __name(diffCss, "diffCss");
  }
});

// ../../node_modules/diff/libcjs/diff/json.js
var require_json2 = __commonJS({
  "../../node_modules/diff/libcjs/diff/json.js"(exports2) {
    "use strict";
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.jsonDiff = void 0;
    exports2.diffJson = diffJson;
    exports2.canonicalize = canonicalize;
    var base_js_1 = __importDefault2(require_base());
    var line_js_1 = require_line();
    var JsonDiff = class extends base_js_1.default {
      static {
        __name(this, "JsonDiff");
      }
      constructor() {
        super(...arguments);
        this.tokenize = line_js_1.tokenize;
      }
      get useLongestToken() {
        return true;
      }
      castInput(value, options) {
        const { undefinedReplacement, stringifyReplacer = /* @__PURE__ */ __name((k32, v) => typeof v === "undefined" ? undefinedReplacement : v, "stringifyReplacer") } = options;
        return typeof value === "string" ? value : JSON.stringify(canonicalize(value, null, null, stringifyReplacer), null, "  ");
      }
      equals(left, right, options) {
        return super.equals(left.replace(/,([\r\n])/g, "$1"), right.replace(/,([\r\n])/g, "$1"), options);
      }
    };
    exports2.jsonDiff = new JsonDiff();
    function diffJson(oldStr, newStr, options) {
      return exports2.jsonDiff.diff(oldStr, newStr, options);
    }
    __name(diffJson, "diffJson");
    function canonicalize(obj, stack, replacementStack, replacer, key) {
      stack = stack || [];
      replacementStack = replacementStack || [];
      if (replacer) {
        obj = replacer(key === void 0 ? "" : key, obj);
      }
      let i32;
      for (i32 = 0; i32 < stack.length; i32 += 1) {
        if (stack[i32] === obj) {
          return replacementStack[i32];
        }
      }
      let canonicalizedObj;
      if ("[object Array]" === Object.prototype.toString.call(obj)) {
        stack.push(obj);
        canonicalizedObj = new Array(obj.length);
        replacementStack.push(canonicalizedObj);
        for (i32 = 0; i32 < obj.length; i32 += 1) {
          canonicalizedObj[i32] = canonicalize(obj[i32], stack, replacementStack, replacer, String(i32));
        }
        stack.pop();
        replacementStack.pop();
        return canonicalizedObj;
      }
      if (obj && obj.toJSON) {
        obj = obj.toJSON();
      }
      if (typeof obj === "object" && obj !== null) {
        stack.push(obj);
        canonicalizedObj = {};
        replacementStack.push(canonicalizedObj);
        const sortedKeys = [];
        let key2;
        for (key2 in obj) {
          if (Object.prototype.hasOwnProperty.call(obj, key2)) {
            sortedKeys.push(key2);
          }
        }
        sortedKeys.sort();
        for (i32 = 0; i32 < sortedKeys.length; i32 += 1) {
          key2 = sortedKeys[i32];
          canonicalizedObj[key2] = canonicalize(obj[key2], stack, replacementStack, replacer, key2);
        }
        stack.pop();
        replacementStack.pop();
      } else {
        canonicalizedObj = obj;
      }
      return canonicalizedObj;
    }
    __name(canonicalize, "canonicalize");
  }
});

// ../../node_modules/diff/libcjs/diff/array.js
var require_array2 = __commonJS({
  "../../node_modules/diff/libcjs/diff/array.js"(exports2) {
    "use strict";
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.arrayDiff = void 0;
    exports2.diffArrays = diffArrays;
    var base_js_1 = __importDefault2(require_base());
    var ArrayDiff = class extends base_js_1.default {
      static {
        __name(this, "ArrayDiff");
      }
      tokenize(value) {
        return value.slice();
      }
      join(value) {
        return value;
      }
      removeEmpty(value) {
        return value;
      }
    };
    exports2.arrayDiff = new ArrayDiff();
    function diffArrays(oldArr, newArr, options) {
      return exports2.arrayDiff.diff(oldArr, newArr, options);
    }
    __name(diffArrays, "diffArrays");
  }
});

// ../../node_modules/diff/libcjs/patch/line-endings.js
var require_line_endings = __commonJS({
  "../../node_modules/diff/libcjs/patch/line-endings.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.unixToWin = unixToWin;
    exports2.winToUnix = winToUnix;
    exports2.isUnix = isUnix;
    exports2.isWin = isWin;
    function unixToWin(patch) {
      if (Array.isArray(patch)) {
        return patch.map((p10) => unixToWin(p10));
      }
      return Object.assign(Object.assign({}, patch), { hunks: patch.hunks.map((hunk) => Object.assign(Object.assign({}, hunk), { lines: hunk.lines.map((line, i32) => {
        var _a10;
        return line.startsWith("\\") || line.endsWith("\r") || ((_a10 = hunk.lines[i32 + 1]) === null || _a10 === void 0 ? void 0 : _a10.startsWith("\\")) ? line : line + "\r";
      }) })) });
    }
    __name(unixToWin, "unixToWin");
    function winToUnix(patch) {
      if (Array.isArray(patch)) {
        return patch.map((p10) => winToUnix(p10));
      }
      return Object.assign(Object.assign({}, patch), { hunks: patch.hunks.map((hunk) => Object.assign(Object.assign({}, hunk), { lines: hunk.lines.map((line) => line.endsWith("\r") ? line.substring(0, line.length - 1) : line) })) });
    }
    __name(winToUnix, "winToUnix");
    function isUnix(patch) {
      if (!Array.isArray(patch)) {
        patch = [patch];
      }
      return !patch.some((index) => index.hunks.some((hunk) => hunk.lines.some((line) => !line.startsWith("\\") && line.endsWith("\r"))));
    }
    __name(isUnix, "isUnix");
    function isWin(patch) {
      if (!Array.isArray(patch)) {
        patch = [patch];
      }
      return patch.some((index) => index.hunks.some((hunk) => hunk.lines.some((line) => line.endsWith("\r")))) && patch.every((index) => index.hunks.every((hunk) => hunk.lines.every((line, i32) => {
        var _a10;
        return line.startsWith("\\") || line.endsWith("\r") || ((_a10 = hunk.lines[i32 + 1]) === null || _a10 === void 0 ? void 0 : _a10.startsWith("\\"));
      })));
    }
    __name(isWin, "isWin");
  }
});

// ../../node_modules/diff/libcjs/patch/parse.js
var require_parse6 = __commonJS({
  "../../node_modules/diff/libcjs/patch/parse.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.parsePatch = parsePatch;
    function parsePatch(uniDiff) {
      const diffstr = uniDiff.split(/\n/), list3 = [];
      let i32 = 0;
      function isGitDiffHeader(line) {
        return /^diff --git /.test(line);
      }
      __name(isGitDiffHeader, "isGitDiffHeader");
      function isDiffHeader(line) {
        return isGitDiffHeader(line) || /^Index:\s/.test(line) || /^diff(?: -r \w+)+\s/.test(line);
      }
      __name(isDiffHeader, "isDiffHeader");
      function isFileHeader(line) {
        return /^(---|\+\+\+)\s/.test(line);
      }
      __name(isFileHeader, "isFileHeader");
      function isHunkHeader(line) {
        return /^@@\s/.test(line);
      }
      __name(isHunkHeader, "isHunkHeader");
      function parseIndex() {
        var _a10;
        const index = {};
        index.hunks = [];
        list3.push(index);
        let seenDiffHeader = false;
        while (i32 < diffstr.length) {
          const line = diffstr[i32];
          if (isFileHeader(line) || isHunkHeader(line)) {
            break;
          }
          if (isGitDiffHeader(line)) {
            if (seenDiffHeader) {
              return;
            }
            seenDiffHeader = true;
            index.isGit = true;
            const paths = parseGitDiffHeader(line);
            if (paths) {
              index.oldFileName = paths.oldFileName;
              index.newFileName = paths.newFileName;
            }
            i32++;
            while (i32 < diffstr.length) {
              const extLine = diffstr[i32];
              if (isFileHeader(extLine) || isHunkHeader(extLine) || isDiffHeader(extLine)) {
                break;
              }
              const renameFromMatch = /^rename from (.*)/.exec(extLine);
              if (renameFromMatch) {
                index.oldFileName = "a/" + unquoteIfQuoted(renameFromMatch[1]);
                index.isRename = true;
              }
              const renameToMatch = /^rename to (.*)/.exec(extLine);
              if (renameToMatch) {
                index.newFileName = "b/" + unquoteIfQuoted(renameToMatch[1]);
                index.isRename = true;
              }
              const copyFromMatch = /^copy from (.*)/.exec(extLine);
              if (copyFromMatch) {
                index.oldFileName = "a/" + unquoteIfQuoted(copyFromMatch[1]);
                index.isCopy = true;
              }
              const copyToMatch = /^copy to (.*)/.exec(extLine);
              if (copyToMatch) {
                index.newFileName = "b/" + unquoteIfQuoted(copyToMatch[1]);
                index.isCopy = true;
              }
              const newFileModeMatch = /^new file mode (\d+)/.exec(extLine);
              if (newFileModeMatch) {
                index.isCreate = true;
                index.newMode = newFileModeMatch[1];
              }
              const deletedFileModeMatch = /^deleted file mode (\d+)/.exec(extLine);
              if (deletedFileModeMatch) {
                index.isDelete = true;
                index.oldMode = deletedFileModeMatch[1];
              }
              const oldModeMatch = /^old mode (\d+)/.exec(extLine);
              if (oldModeMatch) {
                index.oldMode = oldModeMatch[1];
              }
              const newModeMatch = /^new mode (\d+)/.exec(extLine);
              if (newModeMatch) {
                index.newMode = newModeMatch[1];
              }
              if (/^Binary files /.test(extLine)) {
                index.isBinary = true;
              }
              i32++;
            }
            continue;
          } else if (isDiffHeader(line)) {
            if (seenDiffHeader) {
              return;
            }
            seenDiffHeader = true;
            const headerMatch = /^(?:Index:|diff(?: -r \w+)+)\s+/.exec(line);
            if (headerMatch) {
              index.index = line.substring(headerMatch[0].length).trim();
            }
          }
          i32++;
        }
        parseFileHeader(index);
        parseFileHeader(index);
        if (index.oldFileName === void 0 !== (index.newFileName === void 0)) {
          throw new Error("Missing " + (index.oldFileName !== void 0 ? '"+++ ..."' : '"--- ..."') + " file header for " + ((_a10 = index.oldFileName) !== null && _a10 !== void 0 ? _a10 : index.newFileName));
        }
        while (i32 < diffstr.length) {
          const line = diffstr[i32];
          if (isDiffHeader(line) || isFileHeader(line) || /^===================================================================/.test(line)) {
            break;
          } else if (isHunkHeader(line)) {
            index.hunks.push(parseHunk());
          } else {
            i32++;
          }
        }
      }
      __name(parseIndex, "parseIndex");
      function parseGitDiffHeader(line) {
        const rest = line.substring("diff --git ".length);
        if (rest.startsWith('"')) {
          const oldPath = parseQuotedFileName(rest);
          if (oldPath === null) {
            return null;
          }
          const afterOld = rest.substring(oldPath.rawLength + 1);
          let newFileName;
          if (afterOld.startsWith('"')) {
            const newPath = parseQuotedFileName(afterOld);
            if (newPath === null) {
              return null;
            }
            newFileName = newPath.fileName;
          } else {
            newFileName = afterOld;
          }
          return {
            oldFileName: oldPath.fileName,
            newFileName
          };
        }
        const quoteIdx = rest.indexOf('"');
        if (quoteIdx > 0) {
          const oldFileName = rest.substring(0, quoteIdx - 1);
          const newPath = parseQuotedFileName(rest.substring(quoteIdx));
          if (newPath === null) {
            return null;
          }
          return {
            oldFileName,
            newFileName: newPath.fileName
          };
        }
        if (rest.startsWith("a/")) {
          const splits = [];
          let idx = 0;
          while (true) {
            idx = rest.indexOf(" b/", idx + 1);
            if (idx === -1) {
              break;
            }
            splits.push(idx);
          }
          if (splits.length > 0) {
            const mid = splits[Math.floor(splits.length / 2)];
            return {
              oldFileName: rest.substring(0, mid),
              newFileName: rest.substring(mid + 1)
            };
          }
        }
        return null;
      }
      __name(parseGitDiffHeader, "parseGitDiffHeader");
      function unquoteIfQuoted(s) {
        if (s.startsWith('"')) {
          const parsed = parseQuotedFileName(s);
          if (parsed) {
            return parsed.fileName;
          }
        }
        return s;
      }
      __name(unquoteIfQuoted, "unquoteIfQuoted");
      function parseQuotedFileName(s) {
        if (!s.startsWith('"')) {
          return null;
        }
        let result2 = "";
        let j32 = 1;
        while (j32 < s.length) {
          if (s[j32] === '"') {
            return { fileName: result2, rawLength: j32 + 1 };
          }
          if (s[j32] === "\\" && j32 + 1 < s.length) {
            j32++;
            switch (s[j32]) {
              case "a":
                result2 += "\x07";
                break;
              case "b":
                result2 += "\b";
                break;
              case "f":
                result2 += "\f";
                break;
              case "n":
                result2 += "\n";
                break;
              case "r":
                result2 += "\r";
                break;
              case "t":
                result2 += "	";
                break;
              case "v":
                result2 += "\v";
                break;
              case "\\":
                result2 += "\\";
                break;
              case '"':
                result2 += '"';
                break;
              case "0":
              case "1":
              case "2":
              case "3":
              case "4":
              case "5":
              case "6":
              case "7": {
                if (j32 + 2 >= s.length || s[j32 + 1] < "0" || s[j32 + 1] > "7" || s[j32 + 2] < "0" || s[j32 + 2] > "7") {
                  return null;
                }
                const bytes = [parseInt(s.substring(j32, j32 + 3), 8)];
                j32 += 3;
                while (s[j32] === "\\" && s[j32 + 1] >= "0" && s[j32 + 1] <= "7") {
                  if (j32 + 3 >= s.length || s[j32 + 2] < "0" || s[j32 + 2] > "7" || s[j32 + 3] < "0" || s[j32 + 3] > "7") {
                    return null;
                  }
                  bytes.push(parseInt(s.substring(j32 + 1, j32 + 4), 8));
                  j32 += 4;
                }
                result2 += new TextDecoder("utf-8").decode(new Uint8Array(bytes));
                continue;
              }
              // Note that in C, there are also three kinds of hex escape sequences:
              // - \xhh
              // - \uhhhh
              // - \Uhhhhhhhh
              // We do not bother to parse them here because, so far as we know,
              // they are never emitted by any tools that generate unified diff
              // format diffs, and so for now jsdiff does not consider them legal.
              default:
                return null;
            }
          } else {
            result2 += s[j32];
          }
          j32++;
        }
        return null;
      }
      __name(parseQuotedFileName, "parseQuotedFileName");
      function parseFileHeader(index) {
        const fileHeaderMatch = /^(---|\+\+\+)\s+/.exec(diffstr[i32]);
        if (fileHeaderMatch) {
          const prefix = fileHeaderMatch[1], data3 = diffstr[i32].substring(3).trim().split("	", 2), header = (data3[1] || "").trim();
          let fileName = data3[0];
          if (fileName.startsWith('"')) {
            fileName = unquoteIfQuoted(fileName);
          } else {
            fileName = fileName.replace(/\\\\/g, "\\");
          }
          if (prefix === "---") {
            index.oldFileName = fileName;
            index.oldHeader = header;
          } else {
            index.newFileName = fileName;
            index.newHeader = header;
          }
          i32++;
        }
      }
      __name(parseFileHeader, "parseFileHeader");
      function parseHunk() {
        var _a10;
        const chunkHeaderIndex = i32, chunkHeaderLine = diffstr[i32++], chunkHeader = chunkHeaderLine.split(/@@ -(\d+)(?:,(\d+))? \+(\d+)(?:,(\d+))? @@/);
        const hunk = {
          oldStart: +chunkHeader[1],
          oldLines: typeof chunkHeader[2] === "undefined" ? 1 : +chunkHeader[2],
          newStart: +chunkHeader[3],
          newLines: typeof chunkHeader[4] === "undefined" ? 1 : +chunkHeader[4],
          lines: []
        };
        if (hunk.oldLines === 0) {
          hunk.oldStart += 1;
        }
        if (hunk.newLines === 0) {
          hunk.newStart += 1;
        }
        let addCount = 0, removeCount = 0;
        for (; i32 < diffstr.length && (removeCount < hunk.oldLines || addCount < hunk.newLines || ((_a10 = diffstr[i32]) === null || _a10 === void 0 ? void 0 : _a10.startsWith("\\"))); i32++) {
          const operation3 = diffstr[i32].length == 0 && i32 != diffstr.length - 1 ? " " : diffstr[i32][0];
          if (operation3 === "+" || operation3 === "-" || operation3 === " " || operation3 === "\\") {
            hunk.lines.push(diffstr[i32]);
            if (operation3 === "+") {
              addCount++;
            } else if (operation3 === "-") {
              removeCount++;
            } else if (operation3 === " ") {
              addCount++;
              removeCount++;
            }
          } else {
            throw new Error(`Hunk at line ${chunkHeaderIndex + 1} contained invalid line ${diffstr[i32]}`);
          }
        }
        if (!addCount && hunk.newLines === 1) {
          hunk.newLines = 0;
        }
        if (!removeCount && hunk.oldLines === 1) {
          hunk.oldLines = 0;
        }
        if (addCount !== hunk.newLines) {
          throw new Error("Added line count did not match for hunk at line " + (chunkHeaderIndex + 1));
        }
        if (removeCount !== hunk.oldLines) {
          throw new Error("Removed line count did not match for hunk at line " + (chunkHeaderIndex + 1));
        }
        if (i32 < diffstr.length && diffstr[i32] && /^[+ -]/.test(diffstr[i32]) && !isFileHeader(diffstr[i32])) {
          throw new Error("Hunk at line " + (chunkHeaderIndex + 1) + " has more lines than expected (expected " + hunk.oldLines + " old lines and " + hunk.newLines + " new lines)");
        }
        return hunk;
      }
      __name(parseHunk, "parseHunk");
      while (i32 < diffstr.length) {
        parseIndex();
      }
      return list3;
    }
    __name(parsePatch, "parsePatch");
  }
});

// ../../node_modules/diff/libcjs/util/distance-iterator.js
var require_distance_iterator = __commonJS({
  "../../node_modules/diff/libcjs/util/distance-iterator.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.default = default_1;
    function default_1(start, minLine, maxLine) {
      let wantForward = true, backwardExhausted = false, forwardExhausted = false, localOffset = 1;
      return /* @__PURE__ */ __name(function iterator() {
        if (wantForward && !forwardExhausted) {
          if (backwardExhausted) {
            localOffset++;
          } else {
            wantForward = false;
          }
          if (start + localOffset <= maxLine) {
            return start + localOffset;
          }
          forwardExhausted = true;
        }
        if (!backwardExhausted) {
          if (!forwardExhausted) {
            wantForward = true;
          }
          if (minLine <= start - localOffset) {
            return start - localOffset++;
          }
          backwardExhausted = true;
          return iterator();
        }
        return void 0;
      }, "iterator");
    }
    __name(default_1, "default_1");
  }
});

// ../../node_modules/diff/libcjs/patch/apply.js
var require_apply = __commonJS({
  "../../node_modules/diff/libcjs/patch/apply.js"(exports2) {
    "use strict";
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.applyPatch = applyPatch;
    exports2.applyPatches = applyPatches;
    var string_js_1 = require_string2();
    var line_endings_js_1 = require_line_endings();
    var parse_js_1 = require_parse6();
    var distance_iterator_js_1 = __importDefault2(require_distance_iterator());
    function applyPatch(source, patch, options = {}) {
      let patches;
      if (typeof patch === "string") {
        patches = (0, parse_js_1.parsePatch)(patch);
      } else if (Array.isArray(patch)) {
        patches = patch;
      } else {
        patches = [patch];
      }
      if (patches.length > 1) {
        throw new Error("applyPatch only works with a single input.");
      }
      return applyStructuredPatch(source, patches[0], options);
    }
    __name(applyPatch, "applyPatch");
    function applyStructuredPatch(source, patch, options = {}) {
      if (options.autoConvertLineEndings || options.autoConvertLineEndings == null) {
        if ((0, string_js_1.hasOnlyWinLineEndings)(source) && (0, line_endings_js_1.isUnix)(patch)) {
          patch = (0, line_endings_js_1.unixToWin)(patch);
        } else if ((0, string_js_1.hasOnlyUnixLineEndings)(source) && (0, line_endings_js_1.isWin)(patch)) {
          patch = (0, line_endings_js_1.winToUnix)(patch);
        }
      }
      const lines = source.split("\n"), hunks = patch.hunks, compareLine = options.compareLine || ((lineNumber, line, operation3, patchContent) => line === patchContent), fuzzFactor = options.fuzzFactor || 0;
      let minLine = 0;
      if (fuzzFactor < 0 || !Number.isInteger(fuzzFactor)) {
        throw new Error("fuzzFactor must be a non-negative integer");
      }
      if (!hunks.length) {
        return source;
      }
      let prevLine = "", removeEOFNL = false, addEOFNL = false;
      for (let i32 = 0; i32 < hunks[hunks.length - 1].lines.length; i32++) {
        const line = hunks[hunks.length - 1].lines[i32];
        if (line[0] == "\\") {
          if (prevLine[0] == "+") {
            removeEOFNL = true;
          } else if (prevLine[0] == "-") {
            addEOFNL = true;
          }
        }
        prevLine = line;
      }
      if (removeEOFNL) {
        if (addEOFNL) {
          if (!fuzzFactor && lines[lines.length - 1] == "") {
            return false;
          }
        } else if (lines[lines.length - 1] == "") {
          lines.pop();
        } else if (!fuzzFactor) {
          return false;
        }
      } else if (addEOFNL) {
        if (lines[lines.length - 1] != "") {
          lines.push("");
        } else if (!fuzzFactor) {
          return false;
        }
      }
      function applyHunk(hunkLines, toPos, maxErrors, hunkLinesI = 0, lastContextLineMatched = true, patchedLines = [], patchedLinesLength = 0) {
        let nConsecutiveOldContextLines = 0;
        let nextContextLineMustMatch = false;
        for (; hunkLinesI < hunkLines.length; hunkLinesI++) {
          const hunkLine = hunkLines[hunkLinesI], operation3 = hunkLine.length > 0 ? hunkLine[0] : " ", content = hunkLine.length > 0 ? hunkLine.substr(1) : hunkLine;
          if (operation3 === "-") {
            if (compareLine(toPos + 1, lines[toPos], operation3, content)) {
              toPos++;
              nConsecutiveOldContextLines = 0;
            } else {
              if (!maxErrors || lines[toPos] == null) {
                return null;
              }
              patchedLines[patchedLinesLength] = lines[toPos];
              return applyHunk(hunkLines, toPos + 1, maxErrors - 1, hunkLinesI, false, patchedLines, patchedLinesLength + 1);
            }
          }
          if (operation3 === "+") {
            if (!lastContextLineMatched) {
              return null;
            }
            patchedLines[patchedLinesLength] = content;
            patchedLinesLength++;
            nConsecutiveOldContextLines = 0;
            nextContextLineMustMatch = true;
          }
          if (operation3 === " ") {
            nConsecutiveOldContextLines++;
            patchedLines[patchedLinesLength] = lines[toPos];
            if (compareLine(toPos + 1, lines[toPos], operation3, content)) {
              patchedLinesLength++;
              lastContextLineMatched = true;
              nextContextLineMustMatch = false;
              toPos++;
            } else {
              if (nextContextLineMustMatch || !maxErrors) {
                return null;
              }
              return lines[toPos] && (applyHunk(hunkLines, toPos + 1, maxErrors - 1, hunkLinesI + 1, false, patchedLines, patchedLinesLength + 1) || applyHunk(hunkLines, toPos + 1, maxErrors - 1, hunkLinesI, false, patchedLines, patchedLinesLength + 1)) || applyHunk(hunkLines, toPos, maxErrors - 1, hunkLinesI + 1, false, patchedLines, patchedLinesLength);
            }
          }
        }
        patchedLinesLength -= nConsecutiveOldContextLines;
        toPos -= nConsecutiveOldContextLines;
        patchedLines.length = patchedLinesLength;
        return {
          patchedLines,
          oldLineLastI: toPos - 1
        };
      }
      __name(applyHunk, "applyHunk");
      const resultLines = [];
      let prevHunkOffset = 0;
      for (let i32 = 0; i32 < hunks.length; i32++) {
        const hunk = hunks[i32];
        let hunkResult;
        const maxLine = lines.length - hunk.oldLines + fuzzFactor;
        let toPos;
        for (let maxErrors = 0; maxErrors <= fuzzFactor; maxErrors++) {
          toPos = hunk.oldStart + prevHunkOffset - 1;
          const iterator = (0, distance_iterator_js_1.default)(toPos, minLine, maxLine);
          for (; toPos !== void 0; toPos = iterator()) {
            hunkResult = applyHunk(hunk.lines, toPos, maxErrors);
            if (hunkResult) {
              break;
            }
          }
          if (hunkResult) {
            break;
          }
        }
        if (!hunkResult) {
          return false;
        }
        for (let i33 = minLine; i33 < toPos; i33++) {
          resultLines.push(lines[i33]);
        }
        for (let i33 = 0; i33 < hunkResult.patchedLines.length; i33++) {
          const line = hunkResult.patchedLines[i33];
          resultLines.push(line);
        }
        minLine = hunkResult.oldLineLastI + 1;
        prevHunkOffset = toPos + 1 - hunk.oldStart;
      }
      for (let i32 = minLine; i32 < lines.length; i32++) {
        resultLines.push(lines[i32]);
      }
      return resultLines.join("\n");
    }
    __name(applyStructuredPatch, "applyStructuredPatch");
    function applyPatches(uniDiff, options) {
      const spDiff = typeof uniDiff === "string" ? (0, parse_js_1.parsePatch)(uniDiff) : uniDiff;
      let currentIndex = 0;
      function processIndex() {
        const index = spDiff[currentIndex++];
        if (!index) {
          return options.complete();
        }
        options.loadFile(index, function(err, data3) {
          if (err) {
            return options.complete(err);
          }
          const updatedContent = applyPatch(data3, index, options);
          options.patched(index, updatedContent, function(err2) {
            if (err2) {
              return options.complete(err2);
            }
            processIndex();
          });
        });
      }
      __name(processIndex, "processIndex");
      processIndex();
    }
    __name(applyPatches, "applyPatches");
  }
});

// ../../node_modules/diff/libcjs/patch/reverse.js
var require_reverse = __commonJS({
  "../../node_modules/diff/libcjs/patch/reverse.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.reversePatch = reversePatch;
    function swapPrefix(fileName) {
      if (fileName === void 0 || fileName === "/dev/null") {
        return fileName;
      }
      if (fileName.startsWith("a/")) {
        return "b/" + fileName.slice(2);
      }
      if (fileName.startsWith("b/")) {
        return "a/" + fileName.slice(2);
      }
      return fileName;
    }
    __name(swapPrefix, "swapPrefix");
    function reversePatch(structuredPatch2) {
      if (Array.isArray(structuredPatch2)) {
        return structuredPatch2.map((patch) => reversePatch(patch)).reverse();
      }
      const reversed = Object.assign(Object.assign({}, structuredPatch2), { oldFileName: structuredPatch2.isGit ? swapPrefix(structuredPatch2.newFileName) : structuredPatch2.newFileName, oldHeader: structuredPatch2.newHeader, newFileName: structuredPatch2.isGit ? swapPrefix(structuredPatch2.oldFileName) : structuredPatch2.oldFileName, newHeader: structuredPatch2.oldHeader, oldMode: structuredPatch2.newMode, newMode: structuredPatch2.oldMode, isCreate: structuredPatch2.isDelete, isDelete: structuredPatch2.isCreate, hunks: structuredPatch2.hunks.map((hunk) => {
        return {
          oldLines: hunk.newLines,
          oldStart: hunk.newStart,
          newLines: hunk.oldLines,
          newStart: hunk.oldStart,
          lines: hunk.lines.map((l20) => {
            if (l20.startsWith("-")) {
              return `+${l20.slice(1)}`;
            }
            if (l20.startsWith("+")) {
              return `-${l20.slice(1)}`;
            }
            return l20;
          })
        };
      }) });
      if (structuredPatch2.isCopy) {
        reversed.newFileName = "/dev/null";
        reversed.newHeader = void 0;
        reversed.isDelete = true;
        delete reversed.isCreate;
        delete reversed.isCopy;
        delete reversed.isRename;
        reversed.hunks = [];
      }
      return reversed;
    }
    __name(reversePatch, "reversePatch");
  }
});

// ../../node_modules/diff/libcjs/patch/create.js
var require_create = __commonJS({
  "../../node_modules/diff/libcjs/patch/create.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.OMIT_HEADERS = exports2.FILE_HEADERS_ONLY = exports2.INCLUDE_HEADERS = void 0;
    exports2.structuredPatch = structuredPatch2;
    exports2.formatPatch = formatPatch;
    exports2.createTwoFilesPatch = createTwoFilesPatch;
    exports2.createPatch = createPatch;
    var line_js_1 = require_line();
    function needsQuoting(s) {
      for (let i32 = 0; i32 < s.length; i32++) {
        if (s[i32] < " " || s[i32] > "~" || s[i32] === '"' || s[i32] === "\\") {
          return true;
        }
      }
      return false;
    }
    __name(needsQuoting, "needsQuoting");
    function quoteFileNameIfNeeded(s) {
      if (!needsQuoting(s)) {
        return s;
      }
      let result2 = '"';
      const bytes = new TextEncoder().encode(s);
      let i32 = 0;
      while (i32 < bytes.length) {
        const b32 = bytes[i32];
        if (b32 === 7) {
          result2 += "\\a";
        } else if (b32 === 8) {
          result2 += "\\b";
        } else if (b32 === 9) {
          result2 += "\\t";
        } else if (b32 === 10) {
          result2 += "\\n";
        } else if (b32 === 11) {
          result2 += "\\v";
        } else if (b32 === 12) {
          result2 += "\\f";
        } else if (b32 === 13) {
          result2 += "\\r";
        } else if (b32 === 34) {
          result2 += '\\"';
        } else if (b32 === 92) {
          result2 += "\\\\";
        } else if (b32 >= 32 && b32 <= 126) {
          result2 += String.fromCharCode(b32);
        } else {
          result2 += "\\" + b32.toString(8).padStart(3, "0");
        }
        i32++;
      }
      result2 += '"';
      return result2;
    }
    __name(quoteFileNameIfNeeded, "quoteFileNameIfNeeded");
    exports2.INCLUDE_HEADERS = {
      includeIndex: true,
      includeUnderline: true,
      includeFileHeaders: true
    };
    exports2.FILE_HEADERS_ONLY = {
      includeIndex: false,
      includeUnderline: false,
      includeFileHeaders: true
    };
    exports2.OMIT_HEADERS = {
      includeIndex: false,
      includeUnderline: false,
      includeFileHeaders: false
    };
    function structuredPatch2(oldFileName, newFileName, oldStr, newStr, oldHeader, newHeader, options) {
      let optionsObj;
      if (!options) {
        optionsObj = {};
      } else if (typeof options === "function") {
        optionsObj = { callback: options };
      } else {
        optionsObj = options;
      }
      if (typeof optionsObj.context === "undefined") {
        optionsObj.context = 4;
      }
      const context = optionsObj.context;
      if (optionsObj.newlineIsToken) {
        throw new Error("newlineIsToken may not be used with patch-generation functions, only with diffing functions");
      }
      if (!optionsObj.callback) {
        return diffLinesResultToPatch((0, line_js_1.diffLines)(oldStr, newStr, optionsObj));
      } else {
        const { callback } = optionsObj;
        (0, line_js_1.diffLines)(oldStr, newStr, Object.assign(Object.assign({}, optionsObj), { callback: /* @__PURE__ */ __name((diff) => {
          const patch = diffLinesResultToPatch(diff);
          callback(patch);
        }, "callback") }));
      }
      function diffLinesResultToPatch(diff) {
        if (!diff) {
          return;
        }
        diff.push({ value: "", lines: [] });
        function contextLines(lines) {
          return lines.map(function(entry) {
            return " " + entry;
          });
        }
        __name(contextLines, "contextLines");
        const hunks = [];
        let oldRangeStart = 0, newRangeStart = 0, curRange = [], oldLine = 1, newLine = 1;
        for (let i32 = 0; i32 < diff.length; i32++) {
          const current = diff[i32], lines = current.lines || splitLines(current.value);
          current.lines = lines;
          if (current.added || current.removed) {
            if (!oldRangeStart) {
              const prev = diff[i32 - 1];
              oldRangeStart = oldLine;
              newRangeStart = newLine;
              if (prev) {
                curRange = context > 0 ? contextLines(prev.lines.slice(-context)) : [];
                oldRangeStart -= curRange.length;
                newRangeStart -= curRange.length;
              }
            }
            for (const line of lines) {
              curRange.push((current.added ? "+" : "-") + line);
            }
            if (current.added) {
              newLine += lines.length;
            } else {
              oldLine += lines.length;
            }
          } else {
            if (oldRangeStart) {
              if (lines.length <= context * 2 && i32 < diff.length - 2) {
                for (const line of contextLines(lines)) {
                  curRange.push(line);
                }
              } else {
                const contextSize = Math.min(lines.length, context);
                for (const line of contextLines(lines.slice(0, contextSize))) {
                  curRange.push(line);
                }
                const hunk = {
                  oldStart: oldRangeStart,
                  oldLines: oldLine - oldRangeStart + contextSize,
                  newStart: newRangeStart,
                  newLines: newLine - newRangeStart + contextSize,
                  lines: curRange
                };
                hunks.push(hunk);
                oldRangeStart = 0;
                newRangeStart = 0;
                curRange = [];
              }
            }
            oldLine += lines.length;
            newLine += lines.length;
          }
        }
        for (const hunk of hunks) {
          for (let i32 = 0; i32 < hunk.lines.length; i32++) {
            if (hunk.lines[i32].endsWith("\n")) {
              hunk.lines[i32] = hunk.lines[i32].slice(0, -1);
            } else {
              hunk.lines.splice(i32 + 1, 0, "\\ No newline at end of file");
              i32++;
            }
          }
        }
        return {
          oldFileName,
          newFileName,
          oldHeader,
          newHeader,
          hunks
        };
      }
      __name(diffLinesResultToPatch, "diffLinesResultToPatch");
    }
    __name(structuredPatch2, "structuredPatch");
    function formatPatch(patch, headerOptions) {
      var _a10, _b, _c32, _d, _e32, _f;
      if (!headerOptions) {
        headerOptions = exports2.INCLUDE_HEADERS;
      }
      if (Array.isArray(patch)) {
        if (patch.length > 1 && !headerOptions.includeFileHeaders && !patch.every((p10) => p10.isGit)) {
          throw new Error("Cannot omit file headers on a multi-file patch. (The result would be unparseable; how would a tool trying to apply the patch know which changes are to which file?)");
        }
        return patch.map((p10) => formatPatch(p10, headerOptions)).join("\n");
      }
      const ret = [];
      if (patch.isGit) {
        headerOptions = exports2.INCLUDE_HEADERS;
        if (!patch.oldFileName) {
          throw new Error("oldFileName must be specified for Git patches");
        }
        if (!patch.newFileName) {
          throw new Error("newFileName must be specified for Git patches");
        }
        let gitOldName = patch.oldFileName;
        let gitNewName = patch.newFileName;
        if (patch.isCreate && gitOldName === "/dev/null") {
          gitOldName = gitNewName.replace(/^b\//, "a/");
        } else if (patch.isDelete && gitNewName === "/dev/null") {
          gitNewName = gitOldName.replace(/^a\//, "b/");
        }
        ret.push("diff --git " + quoteFileNameIfNeeded(gitOldName) + " " + quoteFileNameIfNeeded(gitNewName));
        if (patch.isDelete) {
          ret.push("deleted file mode " + ((_a10 = patch.oldMode) !== null && _a10 !== void 0 ? _a10 : "100644"));
        }
        if (patch.isCreate) {
          ret.push("new file mode " + ((_b = patch.newMode) !== null && _b !== void 0 ? _b : "100644"));
        }
        if (patch.oldMode && patch.newMode && !patch.isDelete && !patch.isCreate) {
          ret.push("old mode " + patch.oldMode);
          ret.push("new mode " + patch.newMode);
        }
        if (patch.isRename) {
          ret.push("rename from " + quoteFileNameIfNeeded(((_c32 = patch.oldFileName) !== null && _c32 !== void 0 ? _c32 : "").replace(/^a\//, "")));
          ret.push("rename to " + quoteFileNameIfNeeded(((_d = patch.newFileName) !== null && _d !== void 0 ? _d : "").replace(/^b\//, "")));
        }
        if (patch.isCopy) {
          ret.push("copy from " + quoteFileNameIfNeeded(((_e32 = patch.oldFileName) !== null && _e32 !== void 0 ? _e32 : "").replace(/^a\//, "")));
          ret.push("copy to " + quoteFileNameIfNeeded(((_f = patch.newFileName) !== null && _f !== void 0 ? _f : "").replace(/^b\//, "")));
        }
      } else {
        if (headerOptions.includeIndex && patch.oldFileName == patch.newFileName && patch.oldFileName !== void 0) {
          ret.push("Index: " + patch.oldFileName);
        }
        if (headerOptions.includeUnderline) {
          ret.push("===================================================================");
        }
      }
      const hasHunks = patch.hunks.length > 0;
      if (headerOptions.includeFileHeaders && patch.oldFileName !== void 0 && patch.newFileName !== void 0 && (!patch.isGit || hasHunks)) {
        ret.push("--- " + quoteFileNameIfNeeded(patch.oldFileName) + (patch.oldHeader ? "	" + patch.oldHeader : ""));
        ret.push("+++ " + quoteFileNameIfNeeded(patch.newFileName) + (patch.newHeader ? "	" + patch.newHeader : ""));
      }
      for (let i32 = 0; i32 < patch.hunks.length; i32++) {
        const hunk = patch.hunks[i32];
        const oldStart = hunk.oldLines === 0 ? hunk.oldStart - 1 : hunk.oldStart;
        const newStart = hunk.newLines === 0 ? hunk.newStart - 1 : hunk.newStart;
        ret.push("@@ -" + oldStart + "," + hunk.oldLines + " +" + newStart + "," + hunk.newLines + " @@");
        for (const line of hunk.lines) {
          ret.push(line);
        }
      }
      return ret.join("\n") + "\n";
    }
    __name(formatPatch, "formatPatch");
    function createTwoFilesPatch(oldFileName, newFileName, oldStr, newStr, oldHeader, newHeader, options) {
      if (typeof options === "function") {
        options = { callback: options };
      }
      if (!(options === null || options === void 0 ? void 0 : options.callback)) {
        const patchObj = structuredPatch2(oldFileName, newFileName, oldStr, newStr, oldHeader, newHeader, options);
        if (!patchObj) {
          return;
        }
        return formatPatch(patchObj, options === null || options === void 0 ? void 0 : options.headerOptions);
      } else {
        const { callback } = options;
        structuredPatch2(oldFileName, newFileName, oldStr, newStr, oldHeader, newHeader, Object.assign(Object.assign({}, options), { callback: /* @__PURE__ */ __name((patchObj) => {
          if (!patchObj) {
            callback(void 0);
          } else {
            callback(formatPatch(patchObj, options.headerOptions));
          }
        }, "callback") }));
      }
    }
    __name(createTwoFilesPatch, "createTwoFilesPatch");
    function createPatch(fileName, oldStr, newStr, oldHeader, newHeader, options) {
      return createTwoFilesPatch(fileName, fileName, oldStr, newStr, oldHeader, newHeader, options);
    }
    __name(createPatch, "createPatch");
    function splitLines(text) {
      const hasTrailingNl = text.endsWith("\n");
      const result2 = text.split("\n").map((line) => line + "\n");
      if (hasTrailingNl) {
        result2.pop();
      } else {
        result2.push(result2.pop().slice(0, -1));
      }
      return result2;
    }
    __name(splitLines, "splitLines");
  }
});

// ../../node_modules/diff/libcjs/convert/dmp.js
var require_dmp = __commonJS({
  "../../node_modules/diff/libcjs/convert/dmp.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.convertChangesToDMP = convertChangesToDMP;
    function convertChangesToDMP(changes) {
      const ret = [];
      let change, operation3;
      for (let i32 = 0; i32 < changes.length; i32++) {
        change = changes[i32];
        if (change.added) {
          operation3 = 1;
        } else if (change.removed) {
          operation3 = -1;
        } else {
          operation3 = 0;
        }
        ret.push([operation3, change.value]);
      }
      return ret;
    }
    __name(convertChangesToDMP, "convertChangesToDMP");
  }
});

// ../../node_modules/diff/libcjs/convert/xml.js
var require_xml = __commonJS({
  "../../node_modules/diff/libcjs/convert/xml.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.convertChangesToXML = convertChangesToXML;
    function convertChangesToXML(changes) {
      const ret = [];
      for (let i32 = 0; i32 < changes.length; i32++) {
        const change = changes[i32];
        if (change.added) {
          ret.push("<ins>");
        } else if (change.removed) {
          ret.push("<del>");
        }
        ret.push(escapeHTML(change.value));
        if (change.added) {
          ret.push("</ins>");
        } else if (change.removed) {
          ret.push("</del>");
        }
      }
      return ret.join("");
    }
    __name(convertChangesToXML, "convertChangesToXML");
    function escapeHTML(s) {
      let n10 = s;
      n10 = n10.replace(/&/g, "&amp;");
      n10 = n10.replace(/</g, "&lt;");
      n10 = n10.replace(/>/g, "&gt;");
      n10 = n10.replace(/"/g, "&quot;");
      return n10;
    }
    __name(escapeHTML, "escapeHTML");
  }
});

// ../../node_modules/diff/libcjs/index.js
var require_libcjs = __commonJS({
  "../../node_modules/diff/libcjs/index.js"(exports2) {
    "use strict";
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.canonicalize = exports2.convertChangesToXML = exports2.convertChangesToDMP = exports2.reversePatch = exports2.parsePatch = exports2.applyPatches = exports2.applyPatch = exports2.OMIT_HEADERS = exports2.FILE_HEADERS_ONLY = exports2.INCLUDE_HEADERS = exports2.formatPatch = exports2.createPatch = exports2.createTwoFilesPatch = exports2.structuredPatch = exports2.arrayDiff = exports2.diffArrays = exports2.jsonDiff = exports2.diffJson = exports2.cssDiff = exports2.diffCss = exports2.sentenceDiff = exports2.diffSentences = exports2.diffTrimmedLines = exports2.lineDiff = exports2.diffLines = exports2.wordsWithSpaceDiff = exports2.diffWordsWithSpace = exports2.wordDiff = exports2.diffWords = exports2.characterDiff = exports2.diffChars = exports2.Diff = void 0;
    var base_js_1 = __importDefault2(require_base());
    exports2.Diff = base_js_1.default;
    var character_js_1 = require_character();
    Object.defineProperty(exports2, "diffChars", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return character_js_1.diffChars;
    }, "get") });
    Object.defineProperty(exports2, "characterDiff", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return character_js_1.characterDiff;
    }, "get") });
    var word_js_1 = require_word();
    Object.defineProperty(exports2, "diffWords", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return word_js_1.diffWords;
    }, "get") });
    Object.defineProperty(exports2, "diffWordsWithSpace", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return word_js_1.diffWordsWithSpace;
    }, "get") });
    Object.defineProperty(exports2, "wordDiff", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return word_js_1.wordDiff;
    }, "get") });
    Object.defineProperty(exports2, "wordsWithSpaceDiff", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return word_js_1.wordsWithSpaceDiff;
    }, "get") });
    var line_js_1 = require_line();
    Object.defineProperty(exports2, "diffLines", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return line_js_1.diffLines;
    }, "get") });
    Object.defineProperty(exports2, "diffTrimmedLines", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return line_js_1.diffTrimmedLines;
    }, "get") });
    Object.defineProperty(exports2, "lineDiff", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return line_js_1.lineDiff;
    }, "get") });
    var sentence_js_1 = require_sentence();
    Object.defineProperty(exports2, "diffSentences", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return sentence_js_1.diffSentences;
    }, "get") });
    Object.defineProperty(exports2, "sentenceDiff", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return sentence_js_1.sentenceDiff;
    }, "get") });
    var css_js_1 = require_css();
    Object.defineProperty(exports2, "diffCss", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return css_js_1.diffCss;
    }, "get") });
    Object.defineProperty(exports2, "cssDiff", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return css_js_1.cssDiff;
    }, "get") });
    var json_js_1 = require_json2();
    Object.defineProperty(exports2, "diffJson", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return json_js_1.diffJson;
    }, "get") });
    Object.defineProperty(exports2, "canonicalize", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return json_js_1.canonicalize;
    }, "get") });
    Object.defineProperty(exports2, "jsonDiff", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return json_js_1.jsonDiff;
    }, "get") });
    var array_js_1 = require_array2();
    Object.defineProperty(exports2, "diffArrays", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return array_js_1.diffArrays;
    }, "get") });
    Object.defineProperty(exports2, "arrayDiff", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return array_js_1.arrayDiff;
    }, "get") });
    var apply_js_1 = require_apply();
    Object.defineProperty(exports2, "applyPatch", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return apply_js_1.applyPatch;
    }, "get") });
    Object.defineProperty(exports2, "applyPatches", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return apply_js_1.applyPatches;
    }, "get") });
    var parse_js_1 = require_parse6();
    Object.defineProperty(exports2, "parsePatch", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return parse_js_1.parsePatch;
    }, "get") });
    var reverse_js_1 = require_reverse();
    Object.defineProperty(exports2, "reversePatch", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return reverse_js_1.reversePatch;
    }, "get") });
    var create_js_1 = require_create();
    Object.defineProperty(exports2, "structuredPatch", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return create_js_1.structuredPatch;
    }, "get") });
    Object.defineProperty(exports2, "createTwoFilesPatch", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return create_js_1.createTwoFilesPatch;
    }, "get") });
    Object.defineProperty(exports2, "createPatch", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return create_js_1.createPatch;
    }, "get") });
    Object.defineProperty(exports2, "formatPatch", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return create_js_1.formatPatch;
    }, "get") });
    Object.defineProperty(exports2, "INCLUDE_HEADERS", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return create_js_1.INCLUDE_HEADERS;
    }, "get") });
    Object.defineProperty(exports2, "FILE_HEADERS_ONLY", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return create_js_1.FILE_HEADERS_ONLY;
    }, "get") });
    Object.defineProperty(exports2, "OMIT_HEADERS", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return create_js_1.OMIT_HEADERS;
    }, "get") });
    var dmp_js_1 = require_dmp();
    Object.defineProperty(exports2, "convertChangesToDMP", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return dmp_js_1.convertChangesToDMP;
    }, "get") });
    var xml_js_1 = require_xml();
    Object.defineProperty(exports2, "convertChangesToXML", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return xml_js_1.convertChangesToXML;
    }, "get") });
  }
});

// ../@aws-cdk/cloudformation-diff/lib/format.ts
var format_exports = {};
__export(format_exports, {
  Formatter: () => Formatter,
  formatDifferences: () => formatDifferences,
  formatSecurityChanges: () => formatSecurityChanges
});
function formatDifferences(stream, templateDiff, logicalToPathMap = {}, context = 3) {
  const formatter = new Formatter(stream, logicalToPathMap, templateDiff, context);
  if (templateDiff.awsTemplateFormatVersion || templateDiff.transform || templateDiff.description) {
    formatter.printSectionHeader("Template");
    formatter.formatDifference("AWSTemplateFormatVersion", "AWSTemplateFormatVersion", templateDiff.awsTemplateFormatVersion);
    formatter.formatDifference("Transform", "Transform", templateDiff.transform);
    formatter.formatDifference("Description", "Description", templateDiff.description);
    formatter.printSectionFooter();
  }
  formatSecurityChangesWithBanner(formatter, templateDiff);
  formatter.formatSection("Parameters", "Parameter", templateDiff.parameters);
  formatter.formatSection("Metadata", "Metadata", templateDiff.metadata);
  formatter.formatSection("Mappings", "Mapping", templateDiff.mappings);
  formatter.formatSection("Conditions", "Condition", templateDiff.conditions);
  formatter.formatSection("Resources", "Resource", templateDiff.resources, formatter.formatResourceDifference.bind(formatter));
  formatter.formatSection("Outputs", "Output", templateDiff.outputs);
  formatter.formatSection("Other Changes", "Unknown", templateDiff.unknown);
}
function formatSecurityChanges(stream, templateDiff, logicalToPathMap = {}, context) {
  const formatter = new Formatter(stream, logicalToPathMap, templateDiff, context);
  formatSecurityChangesWithBanner(formatter, templateDiff);
}
function formatSecurityChangesWithBanner(formatter, templateDiff) {
  if (!templateDiff.iamChanges.hasChanges && !templateDiff.securityGroupChanges.hasChanges) {
    return;
  }
  formatter.formatIamChanges(templateDiff.iamChanges);
  formatter.formatSecurityGroupChanges(templateDiff.securityGroupChanges);
  formatter.warning("(NOTE: There may be security-related changes not in this list. See https://github.com/aws/aws-cdk/issues/1299)");
  formatter.printSectionFooter();
}
function _diffStrings(oldStr, newStr, context) {
  const patch = structuredPatch(null, null, oldStr, newStr, null, null, { context });
  const result2 = new Array();
  for (const hunk of patch.hunks) {
    result2.push(chalk7.magenta(`@@ -${hunk.oldStart},${hunk.oldLines} +${hunk.newStart},${hunk.newLines} @@`));
    const baseIndent = _findIndent(hunk.lines);
    for (const line of hunk.lines) {
      if (line === "\\ No newline at end of file") {
        continue;
      }
      const marker = line.charAt(0);
      const text = line.slice(1 + baseIndent);
      switch (marker) {
        case " ":
          result2.push(`${CONTEXT} ${text}`);
          break;
        case "+":
          result2.push(chalk7.bold(`${ADDITION2} ${chalk7.green(text)}`));
          break;
        case "-":
          result2.push(chalk7.bold(`${REMOVAL2} ${chalk7.red(text)}`));
          break;
        default:
          throw new Error(`Unexpected diff marker: ${marker} (full line: ${line})`);
      }
    }
  }
  return result2;
  function _findIndent(lines) {
    let indent = Number.MAX_SAFE_INTEGER;
    for (const line of lines) {
      for (let i32 = 1; i32 < line.length; i32++) {
        if (line.charAt(i32) !== " ") {
          indent = indent > i32 - 1 ? i32 - 1 : indent;
          break;
        }
      }
    }
    return indent;
  }
  __name(_findIndent, "_findIndent");
}
var import_util19, chalk7, PATH_METADATA_KEY3, structuredPatch, ADDITION2, CONTEXT, UPDATE2, REMOVAL2, IMPORT, Formatter;
var init_format = __esm({
  "../@aws-cdk/cloudformation-diff/lib/format.ts"() {
    "use strict";
    import_util19 = require("util");
    chalk7 = __toESM(require_source());
    init_util4();
    init_diff_template();
    init_format_foreach();
    init_format_table();
    PATH_METADATA_KEY3 = "aws:cdk:path";
    ({ structuredPatch } = require_libcjs());
    __name(formatDifferences, "formatDifferences");
    __name(formatSecurityChanges, "formatSecurityChanges");
    __name(formatSecurityChangesWithBanner, "formatSecurityChangesWithBanner");
    ADDITION2 = chalk7.green("[+]");
    CONTEXT = chalk7.grey("[ ]");
    UPDATE2 = chalk7.yellow("[~]");
    REMOVAL2 = chalk7.red("[-]");
    IMPORT = chalk7.blue("[\u2190]");
    Formatter = class {
      constructor(stream, logicalToPathMap, diff, context = 3) {
        this.stream = stream;
        this.logicalToPathMap = logicalToPathMap;
        this.context = context;
        if (diff) {
          this.readConstructPathsFrom(diff);
        }
      }
      static {
        __name(this, "Formatter");
      }
      print(fmt, ...args) {
        this.stream.write(chalk7.reset((0, import_util19.format)(fmt, ...args)) + "\n");
      }
      warning(fmt, ...args) {
        this.stream.write(chalk7.yellow((0, import_util19.format)(fmt, ...args)) + "\n");
      }
      formatSection(title, entryType, collection, formatter = this.formatDifference.bind(this)) {
        if (collection.differenceCount === 0) {
          return;
        }
        this.printSectionHeader(title);
        collection.forEachDifference((id, diff) => formatter(entryType, id, diff));
        this.printSectionFooter();
      }
      printSectionHeader(title) {
        this.print(chalk7.underline(chalk7.bold(title)));
      }
      printSectionFooter() {
        this.print("");
      }
      /**
       * Print a simple difference for a given named entity.
       *
       * @param logicalId - the name of the entity that is different.
       * @param diff - the difference to be rendered.
       */
      formatDifference(type, logicalId, diff) {
        if (!diff || !diff.isDifferent) {
          return;
        }
        let value;
        const oldValue = this.formatValue(diff.oldValue, chalk7.red);
        const newValue = this.formatValue(diff.newValue, chalk7.green);
        if (diff.isAddition) {
          value = newValue;
        } else if (diff.isUpdate) {
          value = `${oldValue} to ${newValue}`;
        } else if (diff.isRemoval) {
          value = oldValue;
        }
        this.print(`${this.formatPrefix(diff)} ${chalk7.cyan(type)} ${this.formatLogicalId(logicalId)}: ${value}`);
      }
      /**
       * Print a resource difference for a given logical ID.
       *
       * @param logicalId - the logical ID of the resource that changed.
       * @param diff      - the change to be rendered.
       */
      formatResourceDifference(_type, logicalId, diff) {
        if (!diff.isDifferent) {
          return;
        }
        if (isForEachKey(logicalId)) {
          const forEachFormatter = new ForEachDiffFormatter();
          const lines = forEachFormatter.formatForEach(logicalId, diff.oldValue, diff.newValue);
          for (const line of lines) {
            this.print(line);
          }
          return;
        }
        const resourceType = diff.isRemoval ? diff.oldResourceType : diff.newResourceType;
        const message2 = [
          this.formatResourcePrefix(diff),
          this.formatValue(resourceType, chalk7.cyan),
          this.formatLogicalId(logicalId),
          this.formatImpact(diff.changeImpact),
          this.formatMove(diff.move)
        ].filter(Boolean).join(" ");
        this.print(message2);
        if (diff.isUpdate) {
          const differenceCount = diff.differenceCount;
          let processedCount = 0;
          diff.forEachDifference((_, name, values) => {
            processedCount += 1;
            this.formatTreeDiff(name, values, processedCount === differenceCount);
          });
        }
      }
      formatResourcePrefix(diff) {
        if (diff.isImport) {
          return IMPORT;
        }
        return this.formatPrefix(diff);
      }
      formatPrefix(diff) {
        if (diff.isAddition) {
          return ADDITION2;
        }
        if (diff.isUpdate) {
          return UPDATE2;
        }
        if (diff.isRemoval) {
          return REMOVAL2;
        }
        return chalk7.reset("[?]");
      }
      /**
       * @param value - the value to be formatted.
       * @param color - the color to be used.
       *
       * @returns the formatted string, with color applied.
       */
      formatValue(value, color) {
        if (value == null) {
          return void 0;
        }
        if (typeof value === "string") {
          return color(value);
        }
        return color(JSON.stringify(value));
      }
      /**
       * @param impact - the impact to be formatted
       * @returns a user-friendly, colored string representing the impact.
       */
      formatImpact(impact) {
        switch (impact) {
          case "MAY_REPLACE" /* MAY_REPLACE */:
            return chalk7.italic(chalk7.yellow("may be replaced"));
          case "WILL_REPLACE" /* WILL_REPLACE */:
            return chalk7.italic(chalk7.bold(chalk7.red("replace")));
          case "WILL_DESTROY" /* WILL_DESTROY */:
            return chalk7.italic(chalk7.bold(chalk7.red("destroy")));
          case "WILL_ORPHAN" /* WILL_ORPHAN */:
            return chalk7.italic(chalk7.yellow("orphan"));
          case "WILL_IMPORT" /* WILL_IMPORT */:
            return chalk7.italic(chalk7.blue("import"));
          case "WILL_UPDATE" /* WILL_UPDATE */:
          case "WILL_CREATE" /* WILL_CREATE */:
          case "NO_CHANGE" /* NO_CHANGE */:
            return "";
        }
      }
      formatMove(move) {
        return !move ? "" : chalk7.yellow("(OR", chalk7.italic(chalk7.bold("move")), `${move.direction} ${move.stackName}.${move.resourceLogicalId} via refactoring)`);
      }
      /**
       * Renders a tree of differences under a particular name.
       * @param name    - the name of the root of the tree.
       * @param diff    - the difference on the tree.
       * @param last    - whether this is the last node of a parent tree.
       */
      formatTreeDiff(name, diff, last) {
        let additionalInfo = "";
        if (isPropertyDifference(diff)) {
          if (diff.changeImpact === "MAY_REPLACE" /* MAY_REPLACE */) {
            additionalInfo = " (may cause replacement)";
          } else if (diff.changeImpact === "WILL_REPLACE" /* WILL_REPLACE */) {
            additionalInfo = " (requires replacement)";
          }
        }
        this.print(" %s\u2500 %s %s%s", last ? "\u2514" : "\u251C", this.changeTag(diff.oldValue, diff.newValue), name, additionalInfo);
        return this.formatObjectDiff(diff.oldValue, diff.newValue, ` ${last ? " " : "\u2502"}`);
      }
      /**
       * Renders the difference between two objects, looking for the differences as deep as possible,
       * and rendering a tree graph of the path until the difference is found.
       *
       * @param oldObject  - the old object.
       * @param newObject  - the new object.
       * @param linePrefix - a prefix (indent-like) to be used on every line.
       */
      formatObjectDiff(oldObject, newObject, linePrefix) {
        if (typeof oldObject !== typeof newObject || Array.isArray(oldObject) || typeof oldObject === "string" || typeof oldObject === "number") {
          if (oldObject !== void 0 && newObject !== void 0) {
            if (typeof oldObject === "object" || typeof newObject === "object") {
              const oldStr = JSON.stringify(oldObject, null, 2);
              const newStr = JSON.stringify(newObject, null, 2);
              const diff = _diffStrings(oldStr, newStr, this.context);
              for (let i32 = 0; i32 < diff.length; i32++) {
                this.print("%s   %s %s", linePrefix, i32 === 0 ? "\u2514\u2500" : "  ", diff[i32]);
              }
            } else {
              this.print("%s   \u251C\u2500 %s %s", linePrefix, REMOVAL2, this.formatValue(oldObject, chalk7.red));
              this.print("%s   \u2514\u2500 %s %s", linePrefix, ADDITION2, this.formatValue(newObject, chalk7.green));
            }
          } else if (oldObject !== void 0) {
            this.print("%s   \u2514\u2500 %s", linePrefix, this.formatValue(oldObject, chalk7.red));
          } else {
            this.print("%s   \u2514\u2500 %s", linePrefix, this.formatValue(newObject, chalk7.green));
          }
          return;
        }
        const keySet = new Set(Object.keys(oldObject));
        Object.keys(newObject).forEach((k32) => keySet.add(k32));
        const keys = new Array(...keySet).filter((k32) => !deepEqual(oldObject[k32], newObject[k32])).sort();
        const lastKey = keys[keys.length - 1];
        for (const key of keys) {
          const oldValue = oldObject[key];
          const newValue = newObject[key];
          const treePrefix = key === lastKey ? "\u2514" : "\u251C";
          if (oldValue !== void 0 && newValue !== void 0) {
            this.print("%s   %s\u2500 %s %s:", linePrefix, treePrefix, this.changeTag(oldValue, newValue), chalk7.blue(`.${key}`));
            this.formatObjectDiff(oldValue, newValue, `${linePrefix}   ${key === lastKey ? " " : "\u2502"}`);
          } else if (oldValue !== void 0) {
            this.print("%s   %s\u2500 %s Removed: %s", linePrefix, treePrefix, REMOVAL2, chalk7.blue(`.${key}`));
          } else {
            this.print("%s   %s\u2500 %s Added: %s", linePrefix, treePrefix, ADDITION2, chalk7.blue(`.${key}`));
          }
        }
      }
      /**
       * @param oldValue - the old value of a difference.
       * @param newValue - the new value of a difference.
       *
       * @returns a tag to be rendered in the diff, reflecting whether the difference
       *      was an ADDITION, UPDATE or REMOVAL.
       */
      changeTag(oldValue, newValue) {
        if (oldValue !== void 0 && newValue !== void 0) {
          return UPDATE2;
        } else if (oldValue !== void 0) {
          return REMOVAL2;
        } else {
          return ADDITION2;
        }
      }
      /**
       * Find 'aws:cdk:path' metadata in the diff and add it to the logicalToPathMap
       *
       * There are multiple sources of logicalID -> path mappings: synth metadata
       * and resource metadata, and we combine all sources into a single map.
       */
      readConstructPathsFrom(templateDiff) {
        for (const [logicalId, resourceDiff] of Object.entries(templateDiff.resources)) {
          if (!resourceDiff) {
            continue;
          }
          const oldPathMetadata = resourceDiff.oldValue?.Metadata?.[PATH_METADATA_KEY3];
          if (oldPathMetadata && !(logicalId in this.logicalToPathMap)) {
            this.logicalToPathMap[logicalId] = oldPathMetadata;
          }
          const newPathMetadata = resourceDiff.newValue?.Metadata?.[PATH_METADATA_KEY3];
          if (newPathMetadata && !(logicalId in this.logicalToPathMap)) {
            this.logicalToPathMap[logicalId] = newPathMetadata;
          }
        }
      }
      formatLogicalId(logicalId) {
        const normalized = this.normalizedLogicalIdPath(logicalId);
        if (normalized) {
          return `${normalized} ${chalk7.gray(logicalId)}`;
        }
        return logicalId;
      }
      normalizedLogicalIdPath(logicalId) {
        const path47 = this.logicalToPathMap[logicalId];
        return path47 ? normalizePath2(path47) : void 0;
        function normalizePath2(p10) {
          if (p10.startsWith("/")) {
            p10 = p10.slice(1);
          }
          let parts = p10.split("/");
          if (parts.length > 1) {
            parts = parts.slice(1);
            if (parts.length > 1) {
              const last = parts[parts.length - 1];
              if (last === "Resource" || last === "Default") {
                parts = parts.slice(0, parts.length - 1);
              }
            }
            p10 = parts.join("/");
          }
          return p10;
        }
        __name(normalizePath2, "normalizePath");
      }
      formatIamChanges(changes) {
        if (!changes.hasChanges) {
          return;
        }
        if (changes.statements.hasChanges) {
          this.printSectionHeader("IAM Statement Changes");
          this.print(formatTable(this.deepSubstituteBracedLogicalIds(changes.summarizeStatements()), this.stream.columns));
        }
        if (changes.managedPolicies.hasChanges) {
          this.printSectionHeader("IAM Policy Changes");
          this.print(formatTable(this.deepSubstituteBracedLogicalIds(changes.summarizeManagedPolicies()), this.stream.columns));
        }
        if (changes.ssoPermissionSets.hasChanges || changes.ssoInstanceACAConfigs.hasChanges || changes.ssoAssignments.hasChanges) {
          this.printSectionHeader("IAM Identity Center Changes");
          if (changes.ssoPermissionSets.hasChanges) {
            this.print(formatTable(this.deepSubstituteBracedLogicalIds(changes.summarizeSsoPermissionSets()), this.stream.columns));
          }
          if (changes.ssoInstanceACAConfigs.hasChanges) {
            this.print(formatTable(this.deepSubstituteBracedLogicalIds(changes.summarizeSsoInstanceACAConfigs()), this.stream.columns));
          }
          if (changes.ssoAssignments.hasChanges) {
            this.print(formatTable(this.deepSubstituteBracedLogicalIds(changes.summarizeSsoAssignments()), this.stream.columns));
          }
        }
      }
      formatSecurityGroupChanges(changes) {
        if (!changes.hasChanges) {
          return;
        }
        this.printSectionHeader("Security Group Changes");
        this.print(formatTable(this.deepSubstituteBracedLogicalIds(changes.summarize()), this.stream.columns));
      }
      deepSubstituteBracedLogicalIds(rows) {
        return rows.map((row) => row.map(this.substituteBracedLogicalIds.bind(this)));
      }
      /**
       * Substitute all strings like ${LogId.xxx} with the path instead of the logical ID
       */
      substituteBracedLogicalIds(source) {
        return source.replace(/\$\{([^.}]+)(.[^}]+)?\}/ig, (_match, logId, suffix) => {
          return "${" + (this.normalizedLogicalIdPath(logId) || logId) + (suffix || "") + "}";
        });
      }
    };
    __name(_diffStrings, "_diffStrings");
  }
});

// ../@aws-cdk/cloudformation-diff/lib/mappings.ts
var mappings_exports = {};
__export(mappings_exports, {
  formatAmbiguousMappings: () => formatAmbiguousMappings,
  formatEnvironmentSectionHeader: () => formatEnvironmentSectionHeader,
  formatTypedMappings: () => formatTypedMappings
});
function formatEnvironmentSectionHeader(stream, env3) {
  const formatter = new Formatter(stream, {});
  formatter.printSectionHeader(`${env3}
`);
}
function formatTypedMappings(stream, mappings) {
  if (mappings.length > 0) {
    const header = [["Resource Type", "Old Construct Path", "New Construct Path"]];
    const rows = mappings.map((m20) => [m20.type, m20.sourcePath, m20.destinationPath]);
    const formatter = new Formatter(stream, {});
    formatter.print("The following resources were moved or renamed:");
    formatter.print(chalk8.green(formatTable(header.concat(rows), void 0)));
    formatter.print(" ");
  }
}
function formatAmbiguousMappings(stream, pairs) {
  const tables = pairs.map(renderTable2);
  const formatter = new Formatter(stream, {});
  formatter.print("Detected ambiguities:");
  formatter.print(tables.join("\n\n"));
  formatter.print(" ");
  formatter.print(chalk8.yellow("Please provide an override file to resolve these ambiguous mappings."));
  formatter.print(" ");
  function renderTable2([removed, added]) {
    return formatTable([["", "Resource"], renderRemoval(removed), renderAddition(added)], void 0);
  }
  __name(renderTable2, "renderTable");
  function renderRemoval(locations) {
    return [chalk8.red("-"), chalk8.red(renderLocations(locations))];
  }
  __name(renderRemoval, "renderRemoval");
  function renderAddition(locations) {
    return [chalk8.green("+"), chalk8.green(renderLocations(locations))];
  }
  __name(renderAddition, "renderAddition");
  function renderLocations(locs) {
    return locs.join("\n");
  }
  __name(renderLocations, "renderLocations");
}
var chalk8;
var init_mappings = __esm({
  "../@aws-cdk/cloudformation-diff/lib/mappings.ts"() {
    "use strict";
    chalk8 = __toESM(require_source());
    init_format();
    init_format_table();
    __name(formatEnvironmentSectionHeader, "formatEnvironmentSectionHeader");
    __name(formatTypedMappings, "formatTypedMappings");
    __name(formatAmbiguousMappings, "formatAmbiguousMappings");
  }
});

// ../@aws-cdk/cloudformation-diff/lib/index.js
var require_lib9 = __commonJS({
  "../@aws-cdk/cloudformation-diff/lib/index.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __exportStar3 = exports2 && exports2.__exportStar || function(m20, exports3) {
      for (var p10 in m20) if (p10 !== "default" && !Object.prototype.hasOwnProperty.call(exports3, p10)) __createBinding3(exports3, m20, p10);
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.mangleLikeCloudFormation = exports2.deepEqual = void 0;
    __exportStar3((init_diff_template(), __toCommonJS(diff_template_exports)), exports2);
    __exportStar3((init_format(), __toCommonJS(format_exports)), exports2);
    __exportStar3((init_format_foreach(), __toCommonJS(format_foreach_exports)), exports2);
    __exportStar3((init_format_table(), __toCommonJS(format_table_exports)), exports2);
    __exportStar3((init_mappings(), __toCommonJS(mappings_exports)), exports2);
    var util_1 = (init_util4(), __toCommonJS(util_exports));
    Object.defineProperty(exports2, "deepEqual", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return util_1.deepEqual;
    }, "get") });
    Object.defineProperty(exports2, "mangleLikeCloudFormation", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return util_1.mangleLikeCloudFormation;
    }, "get") });
  }
});

// ../@aws-cdk/toolkit-lib/lib/payloads/bootstrap-environment-progress.ts
var init_bootstrap_environment_progress = __esm({
  "../@aws-cdk/toolkit-lib/lib/payloads/bootstrap-environment-progress.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/payloads/deploy.ts
var init_deploy2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/payloads/deploy.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/payloads/destroy.ts
var init_destroy2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/payloads/destroy.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/payloads/drift.ts
var init_drift = __esm({
  "../@aws-cdk/toolkit-lib/lib/payloads/drift.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/payloads/list.ts
var init_list = __esm({
  "../@aws-cdk/toolkit-lib/lib/payloads/list.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/payloads/sdk.ts
var init_sdk = __esm({
  "../@aws-cdk/toolkit-lib/lib/payloads/sdk.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/payloads/context.ts
var init_context = __esm({
  "../@aws-cdk/toolkit-lib/lib/payloads/context.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/payloads/rollback.ts
var init_rollback = __esm({
  "../@aws-cdk/toolkit-lib/lib/payloads/rollback.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/payloads/stack-activity.ts
var init_stack_activity = __esm({
  "../@aws-cdk/toolkit-lib/lib/payloads/stack-activity.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/payloads/synth.ts
var init_synth = __esm({
  "../@aws-cdk/toolkit-lib/lib/payloads/synth.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/payloads/types.ts
var init_types6 = __esm({
  "../@aws-cdk/toolkit-lib/lib/payloads/types.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/payloads/progress.ts
var init_progress2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/payloads/progress.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/payloads/publish-assets.ts
var init_publish_assets = __esm({
  "../@aws-cdk/toolkit-lib/lib/payloads/publish-assets.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/payloads/refactor.ts
var init_refactor = __esm({
  "../@aws-cdk/toolkit-lib/lib/payloads/refactor.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/payloads/watch.ts
var init_watch = __esm({
  "../@aws-cdk/toolkit-lib/lib/payloads/watch.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/payloads/stack-details.ts
var init_stack_details = __esm({
  "../@aws-cdk/toolkit-lib/lib/payloads/stack-details.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/payloads/diff.ts
var PermissionChangeType;
var init_diff2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/payloads/diff.ts"() {
    "use strict";
    PermissionChangeType = /* @__PURE__ */ ((PermissionChangeType3) => {
      PermissionChangeType3["NONE"] = "none";
      PermissionChangeType3["BROADENING"] = "broadening";
      PermissionChangeType3["NON_BROADENING"] = "non-broadening";
      return PermissionChangeType3;
    })(PermissionChangeType || {});
  }
});

// ../@aws-cdk/toolkit-lib/lib/payloads/logs-monitor.ts
var init_logs_monitor = __esm({
  "../@aws-cdk/toolkit-lib/lib/payloads/logs-monitor.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/payloads/gc.ts
var init_gc = __esm({
  "../@aws-cdk/toolkit-lib/lib/payloads/gc.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/payloads/import.ts
var init_import = __esm({
  "../@aws-cdk/toolkit-lib/lib/payloads/import.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/payloads/index.ts
var payloads_exports = {};
__export(payloads_exports, {
  NonHotswappableReason: () => NonHotswappableReason,
  PermissionChangeType: () => PermissionChangeType
});
var init_payloads = __esm({
  "../@aws-cdk/toolkit-lib/lib/payloads/index.ts"() {
    "use strict";
    init_bootstrap_environment_progress();
    init_deploy2();
    init_destroy2();
    init_drift();
    init_list();
    init_sdk();
    init_context();
    init_rollback();
    init_stack_activity();
    init_synth();
    init_types6();
    init_progress2();
    init_publish_assets();
    init_refactor();
    init_watch();
    init_stack_details();
    init_diff2();
    init_logs_monitor();
    init_hotswap();
    init_gc();
    init_import();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/hotswap/appsync-mapping-templates.ts
async function isHotswappableAppSyncChange(logicalId, change, evaluateCfnTemplate) {
  const isResolver = change.newValue.Type === "AWS::AppSync::Resolver";
  const isFunction5 = change.newValue.Type === "AWS::AppSync::FunctionConfiguration";
  const isGraphQLSchema = change.newValue.Type === "AWS::AppSync::GraphQLSchema";
  const isAPIKey = change.newValue.Type === "AWS::AppSync::ApiKey";
  if (!isResolver && !isFunction5 && !isGraphQLSchema && !isAPIKey) {
    return [];
  }
  const ret = [];
  const classifiedChanges = classifyChanges(change, [
    "RequestMappingTemplate",
    "RequestMappingTemplateS3Location",
    "ResponseMappingTemplate",
    "ResponseMappingTemplateS3Location",
    "Code",
    "CodeS3Location",
    "Definition",
    "DefinitionS3Location",
    "Expires"
  ]);
  classifiedChanges.reportNonHotswappablePropertyChanges(ret);
  const namesOfHotswappableChanges = Object.keys(classifiedChanges.hotswappableProps);
  if (namesOfHotswappableChanges.length > 0) {
    let physicalName = void 0;
    const arn = await evaluateCfnTemplate.establishResourcePhysicalName(
      logicalId,
      isFunction5 ? change.newValue.Properties?.Name : void 0
    );
    if (isResolver) {
      const arnParts = arn?.split("/");
      physicalName = arnParts ? `${arnParts[3]}.${arnParts[5]}` : void 0;
    } else {
      physicalName = arn;
    }
    if (!physicalName) {
      return ret;
    }
    ret.push({
      change: {
        cause: change,
        resources: [{
          logicalId,
          resourceType: change.newValue.Type,
          physicalName,
          metadata: evaluateCfnTemplate.metadataFor(logicalId)
        }]
      },
      hotswappable: true,
      service: "appsync",
      apply: /* @__PURE__ */ __name(async (sdk) => {
        const sdkProperties = {
          ...change.oldValue.Properties,
          Definition: change.newValue.Properties?.Definition,
          DefinitionS3Location: change.newValue.Properties?.DefinitionS3Location,
          requestMappingTemplate: change.newValue.Properties?.RequestMappingTemplate,
          requestMappingTemplateS3Location: change.newValue.Properties?.RequestMappingTemplateS3Location,
          responseMappingTemplate: change.newValue.Properties?.ResponseMappingTemplate,
          responseMappingTemplateS3Location: change.newValue.Properties?.ResponseMappingTemplateS3Location,
          code: change.newValue.Properties?.Code,
          codeS3Location: change.newValue.Properties?.CodeS3Location,
          expires: change.newValue.Properties?.Expires
        };
        const evaluatedResourceProperties = await evaluateCfnTemplate.evaluateCfnExpression(sdkProperties);
        const sdkRequestObject = transformObjectKeys(evaluatedResourceProperties, lowerCaseFirstCharacter);
        if (sdkRequestObject.requestMappingTemplateS3Location) {
          sdkRequestObject.requestMappingTemplate = await fetchFileFromS3(
            sdkRequestObject.requestMappingTemplateS3Location,
            sdk
          );
          delete sdkRequestObject.requestMappingTemplateS3Location;
        }
        if (sdkRequestObject.responseMappingTemplateS3Location) {
          sdkRequestObject.responseMappingTemplate = await fetchFileFromS3(
            sdkRequestObject.responseMappingTemplateS3Location,
            sdk
          );
          delete sdkRequestObject.responseMappingTemplateS3Location;
        }
        if (sdkRequestObject.definitionS3Location) {
          sdkRequestObject.definition = await fetchFileFromS3(sdkRequestObject.definitionS3Location, sdk);
          delete sdkRequestObject.definitionS3Location;
        }
        if (sdkRequestObject.codeS3Location) {
          sdkRequestObject.code = await fetchFileFromS3(sdkRequestObject.codeS3Location, sdk);
          delete sdkRequestObject.codeS3Location;
        }
        if (isResolver) {
          await sdk.appsync().updateResolver(sdkRequestObject);
        } else if (isFunction5) {
          if (sdkRequestObject.code) {
            delete sdkRequestObject.functionVersion;
          } else {
            delete sdkRequestObject.runtime;
          }
          const functions = await sdk.appsync().listFunctions({ apiId: sdkRequestObject.apiId });
          const { functionId } = functions.find((fn) => fn.name === physicalName) ?? {};
          await exponentialBackOffRetry(
            () => sdk.appsync().updateFunction({
              ...sdkRequestObject,
              functionId
            }),
            6,
            1e3,
            "ConcurrentModificationException"
          );
        } else if (isGraphQLSchema) {
          let schemaCreationResponse = await sdk.appsync().startSchemaCreation(sdkRequestObject);
          while (schemaCreationResponse.status && ["PROCESSING", "DELETING"].some((status) => status === schemaCreationResponse.status)) {
            await sleep(1e3);
            const getSchemaCreationStatusRequest = {
              apiId: sdkRequestObject.apiId
            };
            schemaCreationResponse = await sdk.appsync().getSchemaCreationStatus(getSchemaCreationStatusRequest);
          }
          if (schemaCreationResponse.status === "FAILED") {
            throw new ToolkitError("SchemaCreationFailed", schemaCreationResponse.details ?? "Schema creation has failed.");
          }
        } else {
          if (!sdkRequestObject.id) {
            const arnParts = physicalName?.split("/");
            if (arnParts && arnParts.length === 4) {
              sdkRequestObject.id = arnParts[3];
            }
          }
          await sdk.appsync().updateApiKey(sdkRequestObject);
        }
      }, "apply")
    });
  }
  return ret;
}
async function fetchFileFromS3(s3Url, sdk) {
  const s3PathParts = s3Url.split("/");
  const s3Bucket = s3PathParts[2];
  const s3Key = s3PathParts.splice(3).join("/");
  return (await sdk.s3().getObject({ Bucket: s3Bucket, Key: s3Key })).Body?.transformToString();
}
async function exponentialBackOffRetry(fn, numOfRetries, backOff, errorCodeToRetry) {
  try {
    await fn();
  } catch (error4) {
    if (error4 && error4.name === errorCodeToRetry && numOfRetries > 0) {
      await sleep(backOff);
      await exponentialBackOffRetry(fn, numOfRetries - 1, backOff * 2, errorCodeToRetry);
    } else {
      throw error4;
    }
  }
}
async function sleep(ms) {
  return new Promise((ok) => setTimeout(ok, ms));
}
var init_appsync_mapping_templates = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/hotswap/appsync-mapping-templates.ts"() {
    "use strict";
    init_common9();
    init_toolkit_error();
    init_util3();
    __name(isHotswappableAppSyncChange, "isHotswappableAppSyncChange");
    __name(fetchFileFromS3, "fetchFileFromS3");
    __name(exponentialBackOffRetry, "exponentialBackOffRetry");
    __name(sleep, "sleep");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/hotswap/code-build-projects.ts
async function isHotswappableCodeBuildProjectChange(logicalId, change, evaluateCfnTemplate) {
  if (change.newValue.Type !== "AWS::CodeBuild::Project") {
    return [];
  }
  const ret = [];
  const classifiedChanges = classifyChanges(change, ["Source", "Environment", "SourceVersion"]);
  classifiedChanges.reportNonHotswappablePropertyChanges(ret);
  if (classifiedChanges.namesOfHotswappableProps.length > 0) {
    const updateProjectInput = {
      name: ""
    };
    const projectName = await evaluateCfnTemplate.establishResourcePhysicalName(
      logicalId,
      change.newValue.Properties?.Name
    );
    if (!projectName) {
      return ret;
    }
    ret.push({
      change: {
        cause: change,
        resources: [{
          logicalId,
          resourceType: change.newValue.Type,
          physicalName: projectName,
          metadata: evaluateCfnTemplate.metadataFor(logicalId)
        }]
      },
      hotswappable: true,
      service: "codebuild",
      apply: /* @__PURE__ */ __name(async (sdk) => {
        updateProjectInput.name = projectName;
        for (const updatedPropName in change.propertyUpdates) {
          const updatedProp = change.propertyUpdates[updatedPropName];
          switch (updatedPropName) {
            case "Source":
              updateProjectInput.source = transformObjectKeys(
                await evaluateCfnTemplate.evaluateCfnExpression(updatedProp.newValue),
                convertSourceCloudformationKeyToSdkKey
              );
              break;
            case "Environment":
              updateProjectInput.environment = await transformObjectKeys(
                await evaluateCfnTemplate.evaluateCfnExpression(updatedProp.newValue),
                lowerCaseFirstCharacter
              );
              break;
            case "SourceVersion":
              updateProjectInput.sourceVersion = await evaluateCfnTemplate.evaluateCfnExpression(updatedProp.newValue);
              break;
          }
        }
        await sdk.codeBuild().updateProject(updateProjectInput);
      }, "apply")
    });
  }
  return ret;
}
function convertSourceCloudformationKeyToSdkKey(key) {
  if (key.toLowerCase() === "buildspec") {
    return key.toLowerCase();
  }
  return lowerCaseFirstCharacter(key);
}
var init_code_build_projects = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/hotswap/code-build-projects.ts"() {
    "use strict";
    init_common9();
    init_util3();
    __name(isHotswappableCodeBuildProjectChange, "isHotswappableCodeBuildProjectChange");
    __name(convertSourceCloudformationKeyToSdkKey, "convertSourceCloudformationKeyToSdkKey");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/hotswap/ecs-services.ts
async function isHotswappableEcsServiceChange(logicalId, change, evaluateCfnTemplate, hotswapPropertyOverrides) {
  if (change.newValue.Type !== "AWS::ECS::TaskDefinition") {
    return [];
  }
  const ret = [];
  const classifiedChanges = classifyChanges(change, ["ContainerDefinitions"]);
  classifiedChanges.reportNonHotswappablePropertyChanges(ret);
  const resourcesReferencingTaskDef = evaluateCfnTemplate.findReferencesTo(logicalId);
  const ecsServiceResourcesReferencingTaskDef = resourcesReferencingTaskDef.filter(
    (r32) => r32.Type === ECS_SERVICE_RESOURCE_TYPE
  );
  const ecsServicesReferencingTaskDef = new Array();
  for (const ecsServiceResource of ecsServiceResourcesReferencingTaskDef) {
    const serviceArn = await evaluateCfnTemplate.findPhysicalNameFor(ecsServiceResource.LogicalId);
    if (serviceArn) {
      ecsServicesReferencingTaskDef.push({
        logicalId: ecsServiceResource.LogicalId,
        serviceArn
      });
    }
  }
  if (ecsServicesReferencingTaskDef.length === 0) {
    ret.push(nonHotswappableChange(
      change,
      "dependency-unsupported" /* DEPENDENCY_UNSUPPORTED */,
      "No ECS services reference the changed task definition",
      void 0,
      false
    ));
  }
  if (resourcesReferencingTaskDef.length > ecsServicesReferencingTaskDef.length) {
    const nonEcsServiceTaskDefRefs = resourcesReferencingTaskDef.filter((r32) => r32.Type !== ECS_SERVICE_RESOURCE_TYPE);
    for (const taskRef of nonEcsServiceTaskDefRefs) {
      ret.push(nonHotswappableChange(
        change,
        "dependency-unsupported" /* DEPENDENCY_UNSUPPORTED */,
        `A resource '${taskRef.LogicalId}' with Type '${taskRef.Type}' that is not an ECS Service was found referencing the changed TaskDefinition '${logicalId}'`
      ));
    }
  }
  const namesOfHotswappableChanges = Object.keys(classifiedChanges.hotswappableProps);
  if (namesOfHotswappableChanges.length > 0) {
    const taskDefinitionResource = await prepareTaskDefinitionChange(evaluateCfnTemplate, logicalId, change);
    ret.push({
      change: {
        cause: change,
        resources: [
          {
            logicalId,
            resourceType: change.newValue.Type,
            physicalName: await taskDefinitionResource.Family,
            metadata: evaluateCfnTemplate.metadataFor(logicalId)
          },
          ...ecsServicesReferencingTaskDef.map((ecsService) => ({
            resourceType: ECS_SERVICE_RESOURCE_TYPE,
            physicalName: ecsService.serviceArn.split("/")[2],
            logicalId: ecsService.logicalId,
            metadata: evaluateCfnTemplate.metadataFor(ecsService.logicalId)
          }))
        ]
      },
      hotswappable: true,
      service: "ecs-service",
      apply: /* @__PURE__ */ __name(async (sdk) => {
        renameCfnPropertiesToSdkProperties(taskDefinitionResource);
        const lowercasedTaskDef = transformObjectKeys(taskDefinitionResource, lowerCaseFirstCharacter, {
          // All the properties that take arbitrary string as keys i.e. { "string" : "string" }
          // https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_RegisterTaskDefinition.html#API_RegisterTaskDefinition_RequestSyntax
          ContainerDefinitions: {
            DockerLabels: true,
            FirelensConfiguration: {
              Options: true
            },
            LogConfiguration: {
              Options: true
            }
          },
          Volumes: {
            DockerVolumeConfiguration: {
              DriverOpts: true,
              Labels: true
            }
          }
        });
        const registerTaskDefResponse = await sdk.ecs().registerTaskDefinition(lowercasedTaskDef);
        const taskDefRevArn = registerTaskDefResponse.taskDefinition?.taskDefinitionArn;
        let ecsHotswapProperties = hotswapPropertyOverrides.ecs;
        let minimumHealthyPercent = ecsHotswapProperties?.minimumHealthyPercent;
        let maximumHealthyPercent = ecsHotswapProperties?.maximumHealthyPercent;
        let stabilizationTimeoutSeconds = ecsHotswapProperties?.stabilizationTimeoutSeconds;
        await Promise.all(
          ecsServicesReferencingTaskDef.map(async (service) => {
            const cluster = service.serviceArn.split("/")[1];
            const update = await sdk.ecs().updateService({
              service: service.serviceArn,
              taskDefinition: taskDefRevArn,
              cluster,
              forceNewDeployment: true,
              deploymentConfiguration: {
                minimumHealthyPercent: minimumHealthyPercent !== void 0 ? minimumHealthyPercent : 0,
                maximumPercent: maximumHealthyPercent !== void 0 ? maximumHealthyPercent : void 0
              }
            });
            await sdk.ecs().waitUntilServicesStable({
              cluster: update.service?.clusterArn,
              services: [service.serviceArn]
            }, stabilizationTimeoutSeconds);
          })
        );
      }, "apply")
    });
  }
  return ret;
}
function renameCfnPropertiesToSdkProperties(object) {
  if (object.ProxyConfiguration?.ProxyConfigurationProperties !== void 0) {
    object.ProxyConfiguration.properties = object.ProxyConfiguration.ProxyConfigurationProperties;
    delete object.ProxyConfiguration.ProxyConfigurationProperties;
  }
}
async function prepareTaskDefinitionChange(evaluateCfnTemplate, logicalId, change) {
  const taskDefinitionResource = {
    ...change.oldValue.Properties,
    ContainerDefinitions: change.newValue.Properties?.ContainerDefinitions
  };
  const familyNameOrArn = await evaluateCfnTemplate.establishResourcePhysicalName(
    logicalId,
    taskDefinitionResource?.Family
  );
  if (!familyNameOrArn) {
    return;
  }
  const familyNameOrArnParts = familyNameOrArn.split(":");
  const family = familyNameOrArnParts.length > 1 ? (
    // familyNameOrArn is actually an ARN, of the format 'arn:aws:ecs:region:account:task-definition/<family-name>:<revision-nr>'
    // so, take the 6th element, at index 5, and split it on '/'
    familyNameOrArnParts[5].split("/")[1]
  ) : (
    // otherwise, familyNameOrArn is just the simple name evaluated from the CloudFormation template
    familyNameOrArn
  );
  return {
    ...await evaluateCfnTemplate.evaluateCfnExpression({
      ...taskDefinitionResource ?? {},
      Family: void 0
    }),
    Family: family
  };
}
var ECS_SERVICE_RESOURCE_TYPE;
var init_ecs_services = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/hotswap/ecs-services.ts"() {
    "use strict";
    init_common9();
    init_hotswap();
    init_util3();
    ECS_SERVICE_RESOURCE_TYPE = "AWS::ECS::Service";
    __name(isHotswappableEcsServiceChange, "isHotswappableEcsServiceChange");
    __name(renameCfnPropertiesToSdkProperties, "renameCfnPropertiesToSdkProperties");
    __name(prepareTaskDefinitionChange, "prepareTaskDefinitionChange");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/hotswap/hotswap-template-cache.ts
function cachePath(assemblyDir, stackName) {
  return path18.join(assemblyDir, CACHE_DIR, `${stackName}.json`);
}
async function readHotswapTemplateCache(assemblyDir, stackName, newRootTemplate) {
  const cachedPath = cachePath(assemblyDir, stackName);
  try {
    const cached3 = await fs17.readJson(cachedPath);
    return {
      deployedRootTemplate: cached3.deployedRootTemplate,
      nestedStacks: hydrateNestedStacks(assemblyDir, newRootTemplate, cached3.nestedStacks)
    };
  } catch {
    return void 0;
  }
}
async function writeHotswapTemplateCache(assemblyDir, stackName, rootTemplate, nestedStacks) {
  const state13 = {
    deployedRootTemplate: rootTemplate,
    nestedStacks: toCachedNestedStacks(nestedStacks)
  };
  const cachedPath = cachePath(assemblyDir, stackName);
  await fs17.ensureDir(path18.dirname(cachedPath));
  await fs17.writeJson(cachedPath, state13, { spaces: 2 });
}
async function invalidateHotswapTemplateCache(assemblyDir, stackName) {
  await fs17.rm(cachePath(assemblyDir, stackName), { force: true });
}
function toCachedNestedStacks(nestedStacks) {
  const result2 = {};
  for (const [logicalId, ns] of Object.entries(nestedStacks)) {
    result2[logicalId] = {
      physicalName: ns.physicalName,
      deployedTemplate: ns.generatedTemplate,
      nestedStacks: toCachedNestedStacks(ns.nestedStackTemplates)
    };
  }
  return result2;
}
function hydrateNestedStacks(assemblyDir, parentTemplate, cachedNestedStacks) {
  const result2 = {};
  for (const [logicalId, resource] of Object.entries(parentTemplate.Resources ?? {})) {
    const res = resource;
    const assetPath = res?.Metadata?.["aws:asset:path"];
    if (res?.Type !== "AWS::CloudFormation::Stack" || !assetPath) {
      continue;
    }
    const cached3 = cachedNestedStacks[logicalId];
    if (!cached3) {
      continue;
    }
    const generatedTemplate = JSON.parse(
      fs17.readFileSync(path18.join(assemblyDir, assetPath), "utf-8")
    );
    result2[logicalId] = {
      physicalName: cached3.physicalName,
      deployedTemplate: cached3.deployedTemplate,
      generatedTemplate,
      nestedStackTemplates: hydrateNestedStacks(assemblyDir, generatedTemplate, cached3.nestedStacks ?? {})
    };
  }
  return result2;
}
var path18, fs17, CACHE_DIR;
var init_hotswap_template_cache = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/hotswap/hotswap-template-cache.ts"() {
    "use strict";
    path18 = __toESM(require("path"));
    fs17 = __toESM(require_lib4());
    CACHE_DIR = ".hotswap-cache";
    __name(cachePath, "cachePath");
    __name(readHotswapTemplateCache, "readHotswapTemplateCache");
    __name(writeHotswapTemplateCache, "writeHotswapTemplateCache");
    __name(invalidateHotswapTemplateCache, "invalidateHotswapTemplateCache");
    __name(toCachedNestedStacks, "toCachedNestedStacks");
    __name(hydrateNestedStacks, "hydrateNestedStacks");
  }
});

// ../@aws-cdk/toolkit-lib/lib/private/tools.ts
var tools_exports2 = {};
var init_tools2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/private/tools.ts"() {
    "use strict";
    __reExport(tools_exports2, __toESM(require_zip()));
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/hotswap/lambda-functions.ts
async function isHotswappableLambdaFunctionChange(logicalId, change, evaluateCfnTemplate) {
  if (change.newValue.Type === "AWS::Lambda::Version") {
    return [];
  }
  if (change.newValue.Type === "AWS::Lambda::Alias") {
    return classifyAliasChanges(change);
  }
  if (change.newValue.Type !== "AWS::Lambda::Function") {
    return [];
  }
  const ret = [];
  const classifiedChanges = classifyChanges(change, ["Code", "Environment", "Description"]);
  classifiedChanges.reportNonHotswappablePropertyChanges(ret);
  const functionName = await evaluateCfnTemplate.establishResourcePhysicalName(
    logicalId,
    change.newValue.Properties?.FunctionName
  );
  const namesOfHotswappableChanges = Object.keys(classifiedChanges.hotswappableProps);
  if (functionName && namesOfHotswappableChanges.length > 0) {
    const lambdaCodeChange = await evaluateLambdaFunctionProps(
      classifiedChanges.hotswappableProps,
      change.newValue.Properties?.Runtime,
      evaluateCfnTemplate
    );
    if (lambdaCodeChange === void 0) {
      return ret;
    }
    const dependencies = await dependantResources(logicalId, functionName, evaluateCfnTemplate);
    ret.push({
      change: {
        cause: change,
        resources: [
          {
            logicalId,
            resourceType: change.newValue.Type,
            physicalName: functionName,
            metadata: evaluateCfnTemplate.metadataFor(logicalId)
          },
          ...dependencies
        ]
      },
      hotswappable: true,
      service: "lambda",
      apply: /* @__PURE__ */ __name(async (sdk) => {
        const lambda = sdk.lambda();
        const operations = [];
        if (lambdaCodeChange.code !== void 0 || lambdaCodeChange.configurations !== void 0) {
          if (lambdaCodeChange.code !== void 0) {
            await lambda.updateFunctionCode({
              FunctionName: functionName,
              S3Bucket: lambdaCodeChange.code.s3Bucket,
              S3Key: lambdaCodeChange.code.s3Key,
              ImageUri: lambdaCodeChange.code.imageUri,
              ZipFile: lambdaCodeChange.code.functionCodeZip,
              S3ObjectVersion: lambdaCodeChange.code.s3ObjectVersion
            });
            await waitForLambdasPropertiesUpdateToFinish(lambda, functionName);
          }
          if (lambdaCodeChange.configurations !== void 0) {
            const updateRequest = {
              FunctionName: functionName
            };
            if (lambdaCodeChange.configurations.description !== void 0) {
              updateRequest.Description = lambdaCodeChange.configurations.description;
            }
            if (lambdaCodeChange.configurations.environment !== void 0) {
              updateRequest.Environment = lambdaCodeChange.configurations.environment;
            }
            await lambda.updateFunctionConfiguration(updateRequest);
            await waitForLambdasPropertiesUpdateToFinish(lambda, functionName);
          }
          const versions2 = dependencies.filter((d32) => d32.resourceType === "AWS::Lambda::Version");
          if (versions2.length) {
            const publishVersionPromise = lambda.publishVersion({
              FunctionName: functionName
            });
            const aliases = dependencies.filter((d32) => d32.resourceType === "AWS::Lambda::Alias");
            if (aliases.length) {
              const versionUpdate = await publishVersionPromise;
              for (const alias of aliases) {
                operations.push(
                  lambda.updateAlias({
                    FunctionName: functionName,
                    Name: alias.physicalName,
                    FunctionVersion: versionUpdate.Version
                  })
                );
              }
            } else {
              operations.push(publishVersionPromise);
            }
          }
        }
        await Promise.all(operations);
      }, "apply")
    });
  }
  return ret;
}
function classifyAliasChanges(change) {
  const ret = [];
  const classifiedChanges = classifyChanges(change, ["FunctionVersion"]);
  classifiedChanges.reportNonHotswappablePropertyChanges(ret);
  return ret;
}
async function evaluateLambdaFunctionProps(hotswappablePropChanges, runtime, evaluateCfnTemplate) {
  let code = void 0;
  let description = void 0;
  let environment = void 0;
  for (const updatedPropName in hotswappablePropChanges) {
    const updatedProp = hotswappablePropChanges[updatedPropName];
    switch (updatedPropName) {
      case "Code":
        let s3Bucket, s3Key, s3ObjectVersion, imageUri, functionCodeZip;
        for (const newPropName in updatedProp.newValue) {
          switch (newPropName) {
            case "S3Bucket":
              s3Bucket = await evaluateCfnTemplate.evaluateCfnExpression(updatedProp.newValue[newPropName]);
              break;
            case "S3Key":
              s3Key = await evaluateCfnTemplate.evaluateCfnExpression(updatedProp.newValue[newPropName]);
              break;
            case "S3ObjectVersion":
              s3ObjectVersion = await evaluateCfnTemplate.evaluateCfnExpression(updatedProp.newValue[newPropName]);
              break;
            case "ImageUri":
              imageUri = await evaluateCfnTemplate.evaluateCfnExpression(updatedProp.newValue[newPropName]);
              break;
            case "ZipFile":
              const functionCode = await evaluateCfnTemplate.evaluateCfnExpression(updatedProp.newValue[newPropName]);
              const functionRuntime = await evaluateCfnTemplate.evaluateCfnExpression(runtime);
              if (!functionRuntime) {
                return void 0;
              }
              const codeFileExt = determineCodeFileExtFromRuntime(functionRuntime);
              functionCodeZip = await (0, tools_exports2.zipString)(`index.${codeFileExt}`, functionCode);
              break;
          }
        }
        code = {
          s3Bucket,
          s3Key,
          s3ObjectVersion,
          imageUri,
          functionCodeZip
        };
        break;
      case "Description":
        description = await evaluateCfnTemplate.evaluateCfnExpression(updatedProp.newValue);
        break;
      case "Environment":
        environment = await evaluateCfnTemplate.evaluateCfnExpression(updatedProp.newValue);
        break;
      default:
        throw new ToolkitError(
          "UnexpectedHotswapProperty",
          "while apply()ing, found a property that cannot be hotswapped. Please report this at github.com/aws/aws-cdk/issues/new/choose"
        );
    }
  }
  const configurations = description || environment ? { description, environment } : void 0;
  return code || configurations ? { code, configurations } : void 0;
}
async function waitForLambdasPropertiesUpdateToFinish(lambda, functionName) {
  const minDelaySeconds = 1;
  const maxDelaySeconds = 10;
  await lambda.waitUntilFunctionUpdated(minDelaySeconds, maxDelaySeconds, {
    FunctionName: functionName
  });
}
function determineCodeFileExtFromRuntime(runtime) {
  if (runtime.startsWith("node")) {
    return "js";
  }
  if (runtime.startsWith("python")) {
    return "py";
  }
  throw new CfnEvaluationException(
    `runtime ${runtime} is unsupported, only node.js and python runtimes are currently supported.`
  );
}
async function versionsAndAliases(logicalId, evaluateCfnTemplate) {
  const versionsReferencingFunction = evaluateCfnTemplate.findReferencesTo(logicalId).filter((r32) => r32.Type === "AWS::Lambda::Version");
  const aliasesReferencingVersions = flatMap(versionsReferencingFunction, (v) => evaluateCfnTemplate.findReferencesTo(v.LogicalId));
  return { versionsReferencingFunction, aliasesReferencingVersions };
}
async function dependantResources(logicalId, functionName, evaluateCfnTemplate) {
  const candidates = await versionsAndAliases(logicalId, evaluateCfnTemplate);
  const aliases = await Promise.all(candidates.aliasesReferencingVersions.map(async (a32) => {
    const name = await evaluateCfnTemplate.evaluateCfnExpression(a32.Properties?.Name);
    return {
      logicalId: a32.LogicalId,
      resourceType: a32.Type,
      physicalName: name,
      description: `${a32.Type} '${name}' for AWS::Lambda::Function '${functionName}'`,
      metadata: evaluateCfnTemplate.metadataFor(a32.LogicalId)
    };
  }));
  const versions2 = candidates.versionsReferencingFunction.map((v) => ({
    logicalId: v.LogicalId,
    resourceType: v.Type,
    description: `${v.Type} for AWS::Lambda::Function '${functionName}'`,
    metadata: evaluateCfnTemplate.metadataFor(v.LogicalId)
  }));
  return [
    ...versions2,
    ...aliases
  ];
}
var init_lambda_functions = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/hotswap/lambda-functions.ts"() {
    "use strict";
    init_common9();
    init_tools2();
    init_toolkit_error();
    init_util3();
    init_cloudformation2();
    __name(isHotswappableLambdaFunctionChange, "isHotswappableLambdaFunctionChange");
    __name(classifyAliasChanges, "classifyAliasChanges");
    __name(evaluateLambdaFunctionProps, "evaluateLambdaFunctionProps");
    __name(waitForLambdasPropertiesUpdateToFinish, "waitForLambdasPropertiesUpdateToFinish");
    __name(determineCodeFileExtFromRuntime, "determineCodeFileExtFromRuntime");
    __name(versionsAndAliases, "versionsAndAliases");
    __name(dependantResources, "dependantResources");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/hotswap/s3-bucket-deployments.ts
async function isHotswappableS3BucketDeploymentChange(logicalId, change, evaluateCfnTemplate) {
  const ret = [];
  if (change.newValue.Type !== CDK_BUCKET_DEPLOYMENT_CFN_TYPE) {
    return [];
  }
  const customResourceProperties = await evaluateCfnTemplate.evaluateCfnExpression({
    ...change.newValue.Properties,
    ServiceToken: void 0
  });
  const functionName = await evaluateCfnTemplate.evaluateCfnExpression(change.newValue.Properties?.ServiceToken);
  if (!functionName) {
    return ret;
  }
  ret.push({
    change: {
      cause: change,
      resources: [{
        logicalId,
        physicalName: customResourceProperties.DestinationBucketName,
        resourceType: CDK_BUCKET_DEPLOYMENT_CFN_TYPE,
        description: `Contents of AWS::S3::Bucket '${customResourceProperties.DestinationBucketName}'`,
        metadata: evaluateCfnTemplate.metadataFor(logicalId)
      }]
    },
    hotswappable: true,
    service: "custom-s3-deployment",
    apply: /* @__PURE__ */ __name(async (sdk) => {
      await sdk.lambda().invokeCommand({
        FunctionName: functionName,
        // Lambda refuses to take a direct JSON object and requires it to be stringify()'d
        Payload: JSON.stringify({
          RequestType: "Update",
          ResponseURL: REQUIRED_BY_CFN,
          PhysicalResourceId: REQUIRED_BY_CFN,
          StackId: REQUIRED_BY_CFN,
          RequestId: REQUIRED_BY_CFN,
          LogicalResourceId: REQUIRED_BY_CFN,
          ResourceProperties: stringifyObject(customResourceProperties)
          // JSON.stringify() doesn't turn the actual objects to strings, but the lambda expects strings
        })
      });
    }, "apply")
  });
  return ret;
}
async function skipChangeForS3DeployCustomResourcePolicy(iamPolicyLogicalId, change, evaluateCfnTemplate) {
  if (change.newValue.Type !== "AWS::IAM::Policy") {
    return false;
  }
  const roles = change.newValue.Properties?.Roles;
  if (!roles || !roles.length) {
    return false;
  }
  for (const role of roles) {
    const roleArn = await evaluateCfnTemplate.evaluateCfnExpression(role);
    const roleLogicalId = await evaluateCfnTemplate.findLogicalIdForPhysicalName(roleArn);
    if (!roleLogicalId) {
      return false;
    }
    const roleRefs = evaluateCfnTemplate.findReferencesTo(roleLogicalId).filter((roleRef) => !(roleRef.Type == "AWS::IAM::Policy" && roleRef.LogicalId === iamPolicyLogicalId));
    const isRoleOnlyForS3Deployment = roleRefs.length >= 1 && roleRefs.every((roleRef) => {
      if (roleRef.Type === "AWS::Lambda::Function") {
        const lambdaRefs = evaluateCfnTemplate.findReferencesTo(roleRef.LogicalId);
        return lambdaRefs.length >= 1 && lambdaRefs.every((lambdaRef) => lambdaRef.Type === "Custom::CDKBucketDeployment");
      }
      return false;
    });
    if (!isRoleOnlyForS3Deployment) {
      return false;
    }
  }
  return true;
}
function stringifyObject(obj) {
  if (obj == null) {
    return obj;
  }
  if (Array.isArray(obj)) {
    return obj.map(stringifyObject);
  }
  if (typeof obj !== "object") {
    return obj.toString();
  }
  const ret = {};
  for (const [k32, v] of Object.entries(obj)) {
    ret[k32] = stringifyObject(v);
  }
  return ret;
}
var REQUIRED_BY_CFN, CDK_BUCKET_DEPLOYMENT_CFN_TYPE;
var init_s3_bucket_deployments = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/hotswap/s3-bucket-deployments.ts"() {
    "use strict";
    REQUIRED_BY_CFN = "required-to-be-present-by-cfn";
    CDK_BUCKET_DEPLOYMENT_CFN_TYPE = "Custom::CDKBucketDeployment";
    __name(isHotswappableS3BucketDeploymentChange, "isHotswappableS3BucketDeploymentChange");
    __name(skipChangeForS3DeployCustomResourcePolicy, "skipChangeForS3DeployCustomResourcePolicy");
    __name(stringifyObject, "stringifyObject");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/hotswap/cloud-control-resource.ts
async function isHotswappableCloudControlChange(logicalId, change, evaluateCfnTemplate, _hotswapPropertyOverrides) {
  const ret = [];
  const changedPropNames = Object.keys(change.propertyUpdates);
  if (changedPropNames.length === 0) {
    return ret;
  }
  const classifiedChanges = classifyChanges(change, changedPropNames);
  classifiedChanges.reportNonHotswappablePropertyChanges(ret);
  if (classifiedChanges.namesOfHotswappableProps.length === 0) {
    return ret;
  }
  const resourceType = change.newValue.Type;
  const identifier = await resolveCloudControlIdentifier(logicalId, resourceType, evaluateCfnTemplate);
  if (!identifier) {
    ret.push(nonHotswappableChange(
      change,
      "resource-unsupported" /* RESOURCE_UNSUPPORTED */,
      "Could not determine the physical name or primary identifier of the resource, so Cloud Control API cannot hotswap it."
    ));
    return ret;
  }
  const evaluatedProps = {};
  for (const propName of classifiedChanges.namesOfHotswappableProps) {
    try {
      evaluatedProps[propName] = await evaluateCfnTemplate.evaluateCfnExpression(
        change.propertyUpdates[propName].newValue
      );
    } catch (e32) {
      if (e32 instanceof CfnEvaluationException) {
        ret.push(nonHotswappableChange(
          change,
          "resource-unsupported" /* RESOURCE_UNSUPPORTED */,
          `Property '${propName}' of resource '${logicalId}' has been replaced and could not be resolved: ${e32.message}`
        ));
        return ret;
      }
      throw e32;
    }
  }
  ret.push({
    change: {
      cause: change,
      resources: [{
        logicalId,
        resourceType,
        physicalName: identifier,
        metadata: evaluateCfnTemplate.metadataFor(logicalId)
      }]
    },
    hotswappable: true,
    service: "cloudcontrol",
    apply: /* @__PURE__ */ __name(async (sdk) => {
      const cloudControl = sdk.cloudControl();
      const patchOps = [];
      for (const propName of classifiedChanges.namesOfHotswappableProps) {
        const diff = change.propertyUpdates[propName];
        const newValue = evaluatedProps[propName];
        if (diff.isRemoval) {
          patchOps.push({ op: "remove", path: `/${propName}` });
        } else if (diff.isAddition) {
          patchOps.push({ op: "add", path: `/${propName}`, value: newValue });
        } else {
          patchOps.push({ op: "replace", path: `/${propName}`, value: newValue });
        }
      }
      if (patchOps.length === 0) {
        return;
      }
      await cloudControl.updateResource({
        TypeName: resourceType,
        Identifier: identifier,
        PatchDocument: JSON.stringify(patchOps)
      });
    }, "apply")
  });
  return ret;
}
async function resolveCloudControlIdentifier(logicalId, resourceType, evaluateCfnTemplate) {
  const cfnPhysicalId = await evaluateCfnTemplate.findPhysicalNameFor(logicalId);
  if (!cfnPhysicalId) {
    return void 0;
  }
  return evaluateCfnTemplate.evaluateCloudControlIdentifier(logicalId, resourceType, cfnPhysicalId);
}
var init_cloud_control_resource = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/hotswap/cloud-control-resource.ts"() {
    "use strict";
    init_common9();
    init_payloads();
    init_cloudformation2();
    __name(isHotswappableCloudControlChange, "isHotswappableCloudControlChange");
    __name(resolveCloudControlIdentifier, "resolveCloudControlIdentifier");
  }
});

// ../../node_modules/yocto-queue/index.js
var require_yocto_queue = __commonJS({
  "../../node_modules/yocto-queue/index.js"(exports2, module2) {
    var Node2 = class {
      static {
        __name(this, "Node");
      }
      /// value;
      /// next;
      constructor(value) {
        this.value = value;
        this.next = void 0;
      }
    };
    var Queue = class {
      static {
        __name(this, "Queue");
      }
      // TODO: Use private class fields when targeting Node.js 12.
      // #_head;
      // #_tail;
      // #_size;
      constructor() {
        this.clear();
      }
      enqueue(value) {
        const node = new Node2(value);
        if (this._head) {
          this._tail.next = node;
          this._tail = node;
        } else {
          this._head = node;
          this._tail = node;
        }
        this._size++;
      }
      dequeue() {
        const current = this._head;
        if (!current) {
          return;
        }
        this._head = this._head.next;
        this._size--;
        return current.value;
      }
      clear() {
        this._head = void 0;
        this._tail = void 0;
        this._size = 0;
      }
      get size() {
        return this._size;
      }
      *[Symbol.iterator]() {
        let current = this._head;
        while (current) {
          yield current.value;
          current = current.next;
        }
      }
    };
    module2.exports = Queue;
  }
});

// ../../node_modules/p-limit/index.js
var require_p_limit = __commonJS({
  "../../node_modules/p-limit/index.js"(exports2, module2) {
    "use strict";
    var Queue = require_yocto_queue();
    var pLimit6 = /* @__PURE__ */ __name((concurrency) => {
      if (!((Number.isInteger(concurrency) || concurrency === Infinity) && concurrency > 0)) {
        throw new TypeError("Expected `concurrency` to be a number from 1 and up");
      }
      const queue = new Queue();
      let activeCount = 0;
      const next = /* @__PURE__ */ __name(() => {
        activeCount--;
        if (queue.size > 0) {
          queue.dequeue()();
        }
      }, "next");
      const run = /* @__PURE__ */ __name(async (fn, resolve13, ...args) => {
        activeCount++;
        const result2 = (async () => fn(...args))();
        resolve13(result2);
        try {
          await result2;
        } catch {
        }
        next();
      }, "run");
      const enqueue = /* @__PURE__ */ __name((fn, resolve13, ...args) => {
        queue.enqueue(run.bind(null, fn, resolve13, ...args));
        (async () => {
          await Promise.resolve();
          if (activeCount < concurrency && queue.size > 0) {
            queue.dequeue()();
          }
        })();
      }, "enqueue");
      const generator = /* @__PURE__ */ __name((fn, ...args) => new Promise((resolve13) => {
        enqueue(fn, resolve13, ...args);
      }), "generator");
      Object.defineProperties(generator, {
        activeCount: {
          get: /* @__PURE__ */ __name(() => activeCount, "get")
        },
        pendingCount: {
          get: /* @__PURE__ */ __name(() => queue.size, "get")
        },
        clearQueue: {
          value: /* @__PURE__ */ __name(() => {
            queue.clear();
          }, "value")
        }
      });
      return generator;
    }, "pLimit");
    module2.exports = pLimit6;
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/hotswap/hotswap-deployments.ts
async function tryHotswapDeployment(sdkProvider, ioHelper, assetParams, cloudFormationStack, stackArtifact, hotswapMode, hotswapPropertyOverrides) {
  const hotswapSpan = await ioHelper.span(SPAN.HOTSWAP).begin({
    stack: stackArtifact,
    mode: hotswapMode
  });
  const result2 = await hotswapDeployment(
    sdkProvider,
    hotswapSpan,
    assetParams,
    stackArtifact,
    hotswapMode,
    hotswapPropertyOverrides
  );
  await hotswapSpan.end(result2);
  if (result2.error) {
    throw result2.error;
  }
  if (result2?.hotswapped === true) {
    return {
      type: "did-deploy-stack",
      noOp: result2.hotswappableChanges.length === 0,
      stackArn: cloudFormationStack.stackId,
      outputs: cloudFormationStack.outputs,
      deleteFailures: []
    };
  }
  return void 0;
}
async function hotswapDeployment(sdkProvider, ioSpan, assetParams, stack, hotswapMode, hotswapPropertyOverrides) {
  const resolvedEnv = await sdkProvider.resolveEnvironment(stack.environment);
  const sdk = (await sdkProvider.forEnvironment(resolvedEnv, 1 /* ForWriting */)).sdk;
  const hotswapCache = await readHotswapTemplateCache(stack.assembly.directory, stack.stackName, stack.template);
  const currentTemplate = hotswapCache ?? await loadCurrentTemplateWithNestedStacks(stack, sdk);
  const evaluateCfnTemplate = new EvaluateCloudFormationTemplate({
    stackArtifact: stack,
    parameters: assetParams,
    account: resolvedEnv.account,
    region: resolvedEnv.region,
    partition: (await sdk.currentAccount()).partition,
    sdk,
    nestedStacks: currentTemplate.nestedStacks
  });
  const stackChanges = cfn_diff.fullDiff(currentTemplate.deployedRootTemplate, stack.template);
  const { hotswappable, nonHotswappable } = await classifyResourceChanges(
    stackChanges,
    evaluateCfnTemplate,
    sdk,
    currentTemplate.nestedStacks,
    hotswapPropertyOverrides
  );
  await logRejectedChanges(ioSpan, nonHotswappable, hotswapMode);
  const hotswappableChanges = hotswappable.map((o10) => o10.change);
  const nonHotswappableChanges = nonHotswappable.map((n10) => n10.change);
  await ioSpan.notify(IO.CDK_TOOLKIT_I5401.msg("Hotswap plan created", {
    stack,
    mode: hotswapMode,
    hotswappableChanges,
    nonHotswappableChanges
  }));
  if (hotswapMode === "fall-back") {
    if (nonHotswappableChanges.length > 0) {
      return {
        stack,
        mode: hotswapMode,
        hotswapped: false,
        hotswapFallback: true,
        hotswappableChanges,
        nonHotswappableChanges
      };
    }
  }
  let error4;
  try {
    await applyAllHotswapOperations(sdk, ioSpan, hotswappable);
    await writeHotswapTemplateCache(stack.assembly.directory, stack.stackName, stack.template, currentTemplate.nestedStacks);
  } catch (e32) {
    error4 = e32;
  }
  return {
    stack,
    mode: hotswapMode,
    hotswapped: !error4,
    hotswapFallback: false,
    hotswappableChanges,
    nonHotswappableChanges,
    error: error4
  };
}
async function classifyResourceChanges(stackChanges, evaluateCfnTemplate, sdk, nestedStackNames, hotswapPropertyOverrides) {
  const resourceDifferences = getStackResourceDifferences(stackChanges);
  const promises5 = [];
  const hotswappableResources = new Array();
  const nonHotswappableResources = new Array();
  const nestedStackTasks = [];
  const limit = pLimit2(10);
  for (const logicalId of Object.keys(stackChanges.outputs.changes)) {
    nonHotswappableResources.push({
      hotswappable: false,
      change: {
        reason: "output" /* OUTPUT */,
        description: "output was changed",
        subject: {
          type: "Output",
          logicalId,
          metadata: evaluateCfnTemplate.metadataFor(logicalId)
        }
      }
    });
  }
  for (const [logicalId, change] of Object.entries(resourceDifferences)) {
    if (change.newValue?.Type === "AWS::CloudFormation::Stack" && change.oldValue?.Type === "AWS::CloudFormation::Stack") {
      nestedStackTasks.push(limit(() => findNestedHotswappableChanges(
        logicalId,
        change,
        nestedStackNames,
        evaluateCfnTemplate,
        sdk,
        hotswapPropertyOverrides
      )));
      continue;
    }
    const hotswappableChangeCandidate = isCandidateForHotswapping(logicalId, change, evaluateCfnTemplate);
    if ("hotswappable" in hotswappableChangeCandidate) {
      if (!hotswappableChangeCandidate.hotswappable) {
        nonHotswappableResources.push(hotswappableChangeCandidate);
      }
      continue;
    }
    const resourceType = hotswappableChangeCandidate.newValue.Type;
    if (resourceType in RESOURCE_DETECTORS) {
      promises5.push(
        () => RESOURCE_DETECTORS[resourceType](logicalId, hotswappableChangeCandidate, evaluateCfnTemplate, hotswapPropertyOverrides)
      );
    } else {
      nonHotswappableResources.push(nonHotswappableResource(hotswappableChangeCandidate));
    }
  }
  const nestedResults = await Promise.all(nestedStackTasks);
  for (const nested of nestedResults) {
    hotswappableResources.push(...nested.hotswappable);
    nonHotswappableResources.push(...nested.nonHotswappable);
  }
  const changesDetectionResults = [];
  const detectorResults = await Promise.all(promises5.map((fn) => limit(fn)));
  for (const hotswapDetectionResults of detectorResults) {
    changesDetectionResults.push(hotswapDetectionResults);
  }
  for (const resourceDetectionResults of changesDetectionResults) {
    for (const propertyResult of resourceDetectionResults) {
      propertyResult.hotswappable ? hotswappableResources.push(propertyResult) : nonHotswappableResources.push(propertyResult);
    }
  }
  return {
    hotswappable: hotswappableResources,
    nonHotswappable: nonHotswappableResources
  };
}
function getStackResourceDifferences(stackChanges) {
  const allResourceChanges = stackChanges.resources.changes;
  const allRemovalChanges = filterDict2(allResourceChanges, (resChange) => resChange.isRemoval);
  const allNonRemovalChanges = filterDict2(allResourceChanges, (resChange) => !resChange.isRemoval);
  for (const [logId, nonRemovalChange] of Object.entries(allNonRemovalChanges)) {
    if (nonRemovalChange.isAddition) {
      const addChange = nonRemovalChange;
      const identicalRemovalChange = Object.entries(allRemovalChanges).find(([_, remChange]) => {
        return changesAreForSameResource(remChange, addChange);
      });
      if (identicalRemovalChange) {
        const [removedLogId, removedResourceChange] = identicalRemovalChange;
        allNonRemovalChanges[logId] = makeRenameDifference(removedResourceChange, addChange);
        delete allRemovalChanges[removedLogId];
      }
    }
  }
  return {
    ...allRemovalChanges,
    ...allNonRemovalChanges
  };
}
function filterDict2(dict, func) {
  return Object.entries(dict).reduce(
    (acc, [key, t]) => {
      if (func(t)) {
        acc[key] = t;
      }
      return acc;
    },
    {}
  );
}
async function findNestedHotswappableChanges(logicalId, change, nestedStackTemplates, evaluateCfnTemplate, sdk, hotswapPropertyOverrides) {
  const nestedStack = nestedStackTemplates[logicalId];
  if (!nestedStack.physicalName) {
    return {
      hotswappable: [],
      nonHotswappable: [
        {
          hotswappable: false,
          change: {
            reason: "nested-stack-creation" /* NESTED_STACK_CREATION */,
            description: "newly created nested stacks cannot be hotswapped",
            subject: {
              type: "Resource",
              logicalId,
              resourceType: "AWS::CloudFormation::Stack",
              metadata: evaluateCfnTemplate.metadataFor(logicalId)
            }
          }
        }
      ]
    };
  }
  const evaluateNestedCfnTemplate = await evaluateCfnTemplate.createNestedEvaluateCloudFormationTemplate(
    nestedStack.physicalName,
    nestedStack.generatedTemplate,
    change.newValue?.Properties?.Parameters
  );
  const nestedDiff = cfn_diff.fullDiff(
    nestedStackTemplates[logicalId].deployedTemplate,
    nestedStackTemplates[logicalId].generatedTemplate
  );
  return classifyResourceChanges(
    nestedDiff,
    evaluateNestedCfnTemplate,
    sdk,
    nestedStackTemplates[logicalId].nestedStackTemplates,
    hotswapPropertyOverrides
  );
}
function changesAreForSameResource(oldChange, newChange) {
  return oldChange.oldResourceType === newChange.newResourceType && // this isn't great, but I don't want to bring in something like underscore just for this comparison
  JSON.stringify(oldChange.oldProperties) === JSON.stringify(newChange.newProperties);
}
function makeRenameDifference(remChange, addChange) {
  return new cfn_diff.ResourceDifference(
    // we have to fill in the old value, because otherwise this will be classified as a non-hotswappable change
    remChange.oldValue,
    addChange.newValue,
    {
      resourceType: {
        oldType: remChange.oldResourceType,
        newType: addChange.newResourceType
      },
      propertyDiffs: addChange.propertyDiffs,
      otherDiffs: addChange.otherDiffs
    }
  );
}
function isCandidateForHotswapping(logicalId, change, evaluateCfnTemplate) {
  if (!change.oldValue) {
    return {
      hotswappable: false,
      change: {
        reason: "resource-creation" /* RESOURCE_CREATION */,
        description: `resource '${logicalId}' was created by this deployment`,
        subject: {
          type: "Resource",
          logicalId,
          resourceType: change.newValue.Type,
          metadata: evaluateCfnTemplate.metadataFor(logicalId)
        }
      }
    };
  } else if (!change.newValue) {
    return {
      hotswappable: false,
      logicalId,
      change: {
        reason: "resource-deletion" /* RESOURCE_DELETION */,
        description: `resource '${logicalId}' was destroyed by this deployment`,
        subject: {
          type: "Resource",
          logicalId,
          resourceType: change.oldValue.Type,
          metadata: evaluateCfnTemplate.metadataFor(logicalId)
        }
      }
    };
  }
  if (change.newValue.Type !== change.oldValue.Type) {
    return {
      hotswappable: false,
      change: {
        reason: "resource-type-changed" /* RESOURCE_TYPE_CHANGED */,
        description: `resource '${logicalId}' had its type changed from '${change.oldValue?.Type}' to '${change.newValue?.Type}'`,
        subject: {
          type: "Resource",
          logicalId,
          resourceType: change.newValue.Type,
          metadata: evaluateCfnTemplate.metadataFor(logicalId)
        }
      }
    };
  }
  return {
    logicalId,
    oldValue: change.oldValue,
    newValue: change.newValue,
    propertyUpdates: change.propertyUpdates,
    metadata: evaluateCfnTemplate.metadataFor(logicalId)
  };
}
async function applyAllHotswapOperations(sdk, ioSpan, hotswappableChanges) {
  if (hotswappableChanges.length === 0) {
    return Promise.resolve([]);
  }
  await ioSpan.defaults.info(`
${ICON} hotswapping resources:`);
  const limit = pLimit2(10);
  return Promise.all(hotswappableChanges.map((hotswapOperation) => limit(() => {
    return applyHotswapOperation(sdk, ioSpan, hotswapOperation);
  })));
}
async function applyHotswapOperation(sdk, ioSpan, hotswapOperation) {
  const customUserAgent = `cdk-hotswap/success-${hotswapOperation.service}`;
  sdk.appendCustomUserAgent(customUserAgent);
  const resourceText = /* @__PURE__ */ __name((r32) => r32.description ?? `${r32.resourceType} '${r32.physicalName ?? r32.logicalId}'`, "resourceText");
  await ioSpan.notify(IO.CDK_TOOLKIT_I5402.msg(
    hotswapOperation.change.resources.map((r32) => (0, import_util25.format)(`   ${ICON} %s`, chalk9.bold(resourceText(r32)))).join("\n"),
    hotswapOperation.change
  ));
  try {
    await hotswapOperation.apply(sdk);
  } catch (e32) {
    if (e32.name === "TimeoutError" || e32.name === "AbortError") {
      const result2 = JSON.parse(formatErrorMessage(e32));
      const error4 = new ToolkitError("HotswapWaiterFailed", formatWaiterErrorResult(result2));
      error4.name = e32.name;
      throw error4;
    }
    throw e32;
  }
  await ioSpan.notify(IO.CDK_TOOLKIT_I5403.msg(
    hotswapOperation.change.resources.map((r32) => (0, import_util25.format)(`   ${ICON} %s %s`, chalk9.bold(resourceText(r32)), chalk9.green("hotswapped!"))).join("\n"),
    hotswapOperation.change
  ));
  sdk.removeCustomUserAgent(customUserAgent);
}
function formatWaiterErrorResult(result2) {
  const main = [
    `Resource is not in the expected state due to waiter status: ${result2.state}`,
    result2.reason ? `${result2.reason}.` : ""
  ].join(". ");
  if (result2.observedResponses != null) {
    const observedResponses = Object.entries(result2.observedResponses).map(([msg, count]) => `  - ${msg} (${count})`).join("\n");
    return `${main} Observed responses:
${observedResponses}`;
  }
  return main;
}
async function logRejectedChanges(ioSpan, rejectedChanges, hotswapMode) {
  if (rejectedChanges.length === 0) {
    return;
  }
  if (hotswapMode === "hotswap-only") {
    rejectedChanges = rejectedChanges.filter((change) => change.hotswapOnlyVisible === true);
    if (rejectedChanges.length === 0) {
      return;
    }
  }
  const messages = [""];
  if (hotswapMode === "hotswap-only") {
    messages.push((0, import_util25.format)("%s %s", chalk9.red("\u26A0\uFE0F"), chalk9.red("The following non-hotswappable changes were found. To reconcile these using CloudFormation, specify --hotswap-fallback")));
  } else {
    messages.push((0, import_util25.format)("%s %s", chalk9.red("\u26A0\uFE0F"), chalk9.red("The following non-hotswappable changes were found:")));
  }
  for (const { change } of rejectedChanges) {
    messages.push("    " + nonHotswappableChangeMessage(change));
  }
  messages.push("");
  await ioSpan.defaults.info(messages.join("\n"));
}
function nonHotswappableChangeMessage(change) {
  const subject = change.subject;
  const reason = change.description ?? change.reason;
  switch (subject.type) {
    case "Output":
      return (0, import_util25.format)(
        "output: %s, reason: %s",
        chalk9.bold(subject.logicalId),
        chalk9.red(reason)
      );
    case "Resource":
      return nonHotswappableResourceMessage(subject, reason);
  }
}
function nonHotswappableResourceMessage(subject, reason) {
  if (subject.rejectedProperties?.length) {
    return (0, import_util25.format)(
      "resource: %s, type: %s, rejected changes: %s, reason: %s",
      chalk9.bold(subject.logicalId),
      chalk9.bold(subject.resourceType),
      chalk9.bold(subject.rejectedProperties),
      chalk9.red(reason)
    );
  }
  return (0, import_util25.format)(
    "resource: %s, type: %s, reason: %s",
    chalk9.bold(subject.logicalId),
    chalk9.bold(subject.resourceType),
    chalk9.red(reason)
  );
}
var import_util25, cfn_diff, chalk9, pLimit2, RESOURCE_DETECTORS;
var init_hotswap_deployments = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/hotswap/hotswap-deployments.ts"() {
    "use strict";
    import_util25 = require("util");
    cfn_diff = __toESM(require_lib9());
    chalk9 = __toESM(require_source());
    init_payloads();
    init_util3();
    init_cloudformation2();
    init_appsync_mapping_templates();
    init_code_build_projects();
    init_common9();
    init_ecs_services();
    init_hotswap_template_cache();
    init_lambda_functions();
    init_s3_bucket_deployments();
    init_toolkit_error();
    init_private();
    init_plugin2();
    init_cloud_control_resource();
    pLimit2 = require_p_limit();
    RESOURCE_DETECTORS = {
      // Lambda
      "AWS::Lambda::Function": isHotswappableLambdaFunctionChange,
      "AWS::Lambda::Version": isHotswappableLambdaFunctionChange,
      "AWS::Lambda::Alias": isHotswappableLambdaFunctionChange,
      // AppSync
      "AWS::AppSync::Resolver": isHotswappableAppSyncChange,
      "AWS::AppSync::FunctionConfiguration": isHotswappableAppSyncChange,
      "AWS::AppSync::GraphQLSchema": isHotswappableAppSyncChange,
      "AWS::AppSync::ApiKey": isHotswappableAppSyncChange,
      "AWS::ECS::TaskDefinition": isHotswappableEcsServiceChange,
      "AWS::CodeBuild::Project": isHotswappableCodeBuildProjectChange,
      "Custom::CDKBucketDeployment": isHotswappableS3BucketDeploymentChange,
      "AWS::IAM::Policy": /* @__PURE__ */ __name(async (logicalId, change, evaluateCfnTemplate) => {
        if (await skipChangeForS3DeployCustomResourcePolicy(logicalId, change, evaluateCfnTemplate)) {
          return [];
        }
        return [nonHotswappableResource(change)];
      }, "AWS::IAM::Policy"),
      "AWS::CDK::Metadata": /* @__PURE__ */ __name(async () => [], "AWS::CDK::Metadata"),
      // Resources that use CCAPIS
      "AWS::ApiGateway::RestApi": isHotswappableCloudControlChange,
      "AWS::ApiGateway::Deployment": isHotswappableCloudControlChange,
      "AWS::ApiGateway::Method": isHotswappableCloudControlChange,
      "AWS::ApiGatewayV2::Api": isHotswappableCloudControlChange,
      "AWS::ApiGatewayV2::Integration": isHotswappableCloudControlChange,
      "AWS::Bedrock::Agent": isHotswappableCloudControlChange,
      "AWS::Events::Rule": isHotswappableCloudControlChange,
      "AWS::DynamoDB::Table": isHotswappableCloudControlChange,
      "AWS::DynamoDB::GlobalTable": isHotswappableCloudControlChange,
      "AWS::SQS::Queue": isHotswappableCloudControlChange,
      "AWS::CloudWatch::Alarm": isHotswappableCloudControlChange,
      "AWS::CloudWatch::CompositeAlarm": isHotswappableCloudControlChange,
      "AWS::CloudWatch::Dashboard": isHotswappableCloudControlChange,
      "AWS::StepFunctions::StateMachine": isHotswappableCloudControlChange,
      "AWS::BedrockAgentCore::Runtime": isHotswappableCloudControlChange,
      // QuickSight
      "AWS::QuickSight::Dashboard": isHotswappableCloudControlChange,
      "AWS::QuickSight::Analysis": isHotswappableCloudControlChange,
      "AWS::QuickSight::Template": isHotswappableCloudControlChange,
      "AWS::QuickSight::DataSet": isHotswappableCloudControlChange,
      "AWS::QuickSight::DataSource": isHotswappableCloudControlChange
    };
    __name(tryHotswapDeployment, "tryHotswapDeployment");
    __name(hotswapDeployment, "hotswapDeployment");
    __name(classifyResourceChanges, "classifyResourceChanges");
    __name(getStackResourceDifferences, "getStackResourceDifferences");
    __name(filterDict2, "filterDict");
    __name(findNestedHotswappableChanges, "findNestedHotswappableChanges");
    __name(changesAreForSameResource, "changesAreForSameResource");
    __name(makeRenameDifference, "makeRenameDifference");
    __name(isCandidateForHotswapping, "isCandidateForHotswapping");
    __name(applyAllHotswapOperations, "applyAllHotswapOperations");
    __name(applyHotswapOperation, "applyHotswapOperation");
    __name(formatWaiterErrorResult, "formatWaiterErrorResult");
    __name(logRejectedChanges, "logRejectedChanges");
    __name(nonHotswappableChangeMessage, "nonHotswappableChangeMessage");
    __name(nonHotswappableResourceMessage, "nonHotswappableResourceMessage");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/deployments/deploy-stack.ts
async function deployStack(options, ioHelper) {
  const stackArtifact = options.stack;
  const stackEnv = options.resolvedEnvironment;
  const inputMethod = options.deploymentMethod ?? { method: "change-set" };
  let deploymentMethod = inputMethod;
  options.sdk.appendCustomUserAgent(options.extraUserAgent);
  const cfn = options.sdk.cloudFormation();
  const deployName = options.deployName || stackArtifact.stackName;
  let cloudFormationStack = await CloudFormationStack.lookup(cfn, deployName);
  if (deploymentMethod.method === "execute-change-set") {
    const fullDeployment2 = new FullCloudFormationDeployment(
      deploymentMethod,
      options,
      cloudFormationStack,
      stackArtifact,
      new ParameterValues({}, {}),
      {},
      ioHelper,
      options.diagnoser
    );
    return fullDeployment2.performDeployment();
  }
  if (cloudFormationStack.stackStatus.isCreationFailure) {
    await ioHelper.defaults.debug(
      `Found existing stack ${deployName} that had previously failed creation. Deleting it before attempting to re-create it.`
    );
    await cfn.deleteStack({ StackName: cloudFormationStack.stackId, ClientRequestToken: (0, import_node_crypto6.randomUUID)() });
    const deletedStack = await waitForStackDelete(cfn, ioHelper, cloudFormationStack.stackId);
    if (deletedStack && deletedStack.stackStatus.name !== "DELETE_COMPLETE") {
      throw new DeploymentError(
        `Failed deleting stack ${deployName} that had previously failed creation (current state: ${deletedStack.stackStatus})`,
        "FailedStackCleanupFailed"
      );
    }
    cloudFormationStack = CloudFormationStack.doesNotExist(cfn, deployName);
  }
  const legacyAssets = new AssetManifestBuilder();
  const assetParams = await addMetadataAssetsToManifest(
    ioHelper,
    stackArtifact,
    legacyAssets,
    options.envResources,
    options.reuseAssets
  );
  const finalParameterValues = { ...options.parameters, ...assetParams };
  const templateParams = TemplateParameters.fromTemplate(stackArtifact.template);
  const stackParams = options.usePreviousParameters ? templateParams.updateExisting(finalParameterValues, cloudFormationStack.parameters) : templateParams.supplyAll(finalParameterValues);
  if (await canSkipDeploy(options, cloudFormationStack, stackParams.hasChanges(cloudFormationStack.parameters), ioHelper)) {
    await ioHelper.defaults.debug(`${deployName}: skipping deployment (use --force to override)`);
    if (deploymentMethod?.method === "hotswap") {
      await ioHelper.defaults.info(
        (0, import_node_util2.format)(
          `
 ${ICON} %s
`,
          chalk10.bold("hotswap deployment skipped - no changes were detected (use --force to override)")
        )
      );
    }
    return {
      type: "did-deploy-stack",
      noOp: true,
      outputs: cloudFormationStack.outputs,
      stackArn: cloudFormationStack.stackId,
      deleteFailures: []
    };
  } else {
    await ioHelper.defaults.debug(`${deployName}: deploying...`);
  }
  const bodyParameter = await makeBodyParameter(
    ioHelper,
    stackArtifact,
    options.resolvedEnvironment,
    legacyAssets,
    options.envResources,
    options.overrideTemplate
  );
  let bootstrapStackName;
  try {
    bootstrapStackName = (await options.envResources.lookupToolkit()).stackName;
  } catch (e32) {
    await ioHelper.defaults.debug(`Could not determine the bootstrap stack name: ${e32}`);
  }
  await publishAssets(legacyAssets.toManifest(stackArtifact.assembly.directory), options.sdkProvider, stackEnv, {
    parallel: options.assetParallelism,
    allowCrossAccount: await determineAllowCrossAccountAssetPublishing(options.sdk, ioHelper, bootstrapStackName)
  }, ioHelper);
  if (deploymentMethod?.method === "hotswap") {
    try {
      const hotswapModeNew = deploymentMethod?.fallback ? "fall-back" : "hotswap-only";
      const hotswapPropertyOverrides = deploymentMethod.properties ? createHotswapPropertyOverrides(deploymentMethod.properties) : new HotswapPropertyOverrides();
      const hotswapDeploymentResult = await tryHotswapDeployment(
        options.sdkProvider,
        ioHelper,
        stackParams.values,
        cloudFormationStack,
        stackArtifact,
        hotswapModeNew,
        hotswapPropertyOverrides
      );
      if (hotswapDeploymentResult) {
        await ioHelper.defaults.info(
          `Your next non-hotswap deployment with ${stackEnv.name} should include '--revert-drift' to resolve the drift that was introduced while hotswapping.`
        );
        return hotswapDeploymentResult;
      }
      await ioHelper.defaults.info((0, import_node_util2.format)(
        "Could not perform a hotswap deployment, as the stack %s contains non-Asset changes",
        stackArtifact.displayName
      ));
    } catch (e32) {
      if (!(e32 instanceof CfnEvaluationException)) {
        throw e32;
      }
      await ioHelper.defaults.info((0, import_node_util2.format)(
        "Could not perform a hotswap deployment, because the CloudFormation template could not be resolved: %s",
        formatErrorMessage(e32)
      ));
    }
    if (deploymentMethod.fallback) {
      await ioHelper.defaults.info("Falling back to doing a full deployment");
      options.sdk.appendCustomUserAgent("cdk-hotswap/fallback");
      deploymentMethod = deploymentMethod.fallback;
    } else {
      return {
        type: "did-deploy-stack",
        noOp: true,
        stackArn: cloudFormationStack.stackId,
        outputs: cloudFormationStack.outputs,
        deleteFailures: []
      };
    }
  }
  const fullDeployment = new FullCloudFormationDeployment(
    deploymentMethod,
    options,
    cloudFormationStack,
    stackArtifact,
    stackParams,
    bodyParameter,
    ioHelper,
    options.diagnoser
  );
  return fullDeployment.performDeployment();
}
async function destroyStack(options, ioHelper) {
  const deployName = options.deployName || options.stack.stackName;
  const cfn = options.sdk.cloudFormation();
  const currentStack = await CloudFormationStack.lookup(cfn, deployName);
  if (!currentStack.exists) {
    return {};
  }
  const monitor = new StackActivityMonitor({
    cfn,
    stack: options.stack,
    stackArn: currentStack.stackId,
    ioHelper
  });
  await monitor.start();
  try {
    await cfn.deleteStack({ StackName: currentStack.stackId, RoleARN: options.roleArn, ClientRequestToken: (0, import_node_crypto6.randomUUID)() });
    const destroyedStack = await waitForStackDelete(cfn, ioHelper, currentStack.stackId);
    if (destroyedStack && destroyedStack.stackStatus.name !== "DELETE_COMPLETE") {
      throw new DeploymentError(`Failed to destroy ${deployName}: ${destroyedStack.stackStatus}`, "StackDestroyFailed");
    }
    return { stackArn: currentStack.stackId };
  } catch (e32) {
    throw new DeploymentError(suffixWithErrors(formatErrorMessage(e32), monitor.errors.allErrorMessages), monitor.errors.rootCauseErrorCode ?? "StackDestroyFailed");
  } finally {
    if (monitor) {
      await monitor.stop();
    }
  }
}
async function canSkipDeploy(deployStackOptions, cloudFormationStack, parameterChanges, ioHelper) {
  const deployName = deployStackOptions.deployName || deployStackOptions.stack.stackName;
  await ioHelper.defaults.debug(`${deployName}: checking if we can skip deploy`);
  if (deployStackOptions.forceDeployment) {
    await ioHelper.defaults.debug(`${deployName}: forced deployment`);
    return false;
  }
  if (deployStackOptions.deploymentMethod?.method === "change-set" && deployStackOptions.deploymentMethod.execute === false) {
    await ioHelper.defaults.debug(`${deployName}: --no-execute, always creating change set`);
    return false;
  }
  if (deployStackOptions.deploymentMethod?.method === "execute-change-set") {
    await ioHelper.defaults.debug(`${deployName}: executing existing change set, never skip`);
    return false;
  }
  if (deployStackOptions.deploymentMethod?.method === "change-set" && deployStackOptions.deploymentMethod.revertDrift) {
    await ioHelper.defaults.debug(`${deployName}: --revert-drift, always creating change set`);
    return false;
  }
  if (!cloudFormationStack.exists) {
    await ioHelper.defaults.debug(`${deployName}: no existing stack`);
    return false;
  }
  if (JSON.stringify(deployStackOptions.stack.template) !== JSON.stringify(await cloudFormationStack.template())) {
    await ioHelper.defaults.debug(`${deployName}: template has changed`);
    return false;
  }
  if (!compareTags(cloudFormationStack.tags, deployStackOptions.tags ?? [])) {
    await ioHelper.defaults.debug(`${deployName}: tags have changed`);
    return false;
  }
  if (!arrayEquals(cloudFormationStack.notificationArns, deployStackOptions.notificationArns ?? [])) {
    await ioHelper.defaults.debug(`${deployName}: notification arns have changed`);
    return false;
  }
  if (!!deployStackOptions.stack.terminationProtection !== !!cloudFormationStack.terminationProtection) {
    await ioHelper.defaults.debug(`${deployName}: termination protection has been updated`);
    return false;
  }
  if (parameterChanges) {
    if (parameterChanges === "ssm") {
      await ioHelper.defaults.debug(`${deployName}: some parameters come from SSM so we have to assume they may have changed`);
    } else {
      await ioHelper.defaults.debug(`${deployName}: parameters have changed`);
    }
    return false;
  }
  if (cloudFormationStack.stackStatus.isFailure) {
    await ioHelper.defaults.debug(`${deployName}: stack is in a failure state`);
    return false;
  }
  return true;
}
function compareTags(a32, b32) {
  if (a32.length !== b32.length) {
    return false;
  }
  for (const aTag of a32) {
    const bTag = b32.find((tag3) => tag3.Key === aTag.Key);
    if (!bTag || bTag.Value !== aTag.Value) {
      return false;
    }
  }
  return true;
}
function suffixWithErrors(msg, errors) {
  return errors && errors.length > 0 ? `${msg}: ${errors.join(", ")}` : msg;
}
function arrayEquals(a32, b32) {
  return a32.every((item) => b32.includes(item)) && b32.every((item) => a32.includes(item));
}
function hasReplacement(cs) {
  return (cs.Changes ?? []).some((c32) => {
    const a32 = c32.ResourceChange?.PolicyAction;
    return a32 === "ReplaceAndDelete" || a32 === "ReplaceAndRetain" || a32 === "ReplaceAndSnapshot";
  });
}
var import_node_crypto6, import_node_util2, chalk10, FullCloudFormationDeployment;
var init_deploy_stack = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/deployments/deploy-stack.ts"() {
    "use strict";
    import_node_crypto6 = require("node:crypto");
    import_node_util2 = require("node:util");
    chalk10 = __toESM(require_source());
    init_asset_manifest_builder();
    init_asset_publishing();
    init_assets3();
    init_cfn_api();
    init_cfn_api();
    init_checks();
    init_deployment_method();
    init_toolkit_error();
    init_util3();
    init_cloudformation();
    init_cloudformation2();
    init_diagnosis_formatting();
    init_stack_diagnoser();
    init_common9();
    init_hotswap_deployments();
    init_hotswap_template_cache();
    init_stack_events();
    __name(deployStack, "deployStack");
    FullCloudFormationDeployment = class {
      constructor(deploymentMethod, options, cloudFormationStack, stackArtifact, stackParams, bodyParameter, ioHelper, diagnoser) {
        this.deploymentMethod = deploymentMethod;
        this.options = options;
        this.cloudFormationStack = cloudFormationStack;
        this.stackArtifact = stackArtifact;
        this.stackParams = stackParams;
        this.bodyParameter = bodyParameter;
        this.ioHelper = ioHelper;
        this.diagnoser = diagnoser;
        this.cfn = options.sdk.cloudFormation();
        this.stackName = options.deployName ?? stackArtifact.stackName;
        this.update = cloudFormationStack.exists && cloudFormationStack.stackStatus.name !== "REVIEW_IN_PROGRESS";
        this.verb = this.update ? "update" : "create";
        this.uuid = (0, import_node_crypto6.randomUUID)();
      }
      deploymentMethod;
      options;
      cloudFormationStack;
      stackArtifact;
      stackParams;
      bodyParameter;
      ioHelper;
      diagnoser;
      static {
        __name(this, "FullCloudFormationDeployment");
      }
      cfn;
      stackName;
      update;
      verb;
      uuid;
      async performDeployment() {
        const deploymentMethod = this.deploymentMethod ?? { method: "change-set" };
        await invalidateHotswapTemplateCache(this.stackArtifact.assembly.directory, this.stackArtifact.stackName);
        if (deploymentMethod.method === "direct" && this.options.resourcesToImport) {
          throw new ToolkitError("ImportRequiresChangeSet", "Importing resources requires a changeset deployment");
        }
        switch (deploymentMethod.method) {
          case "change-set":
            return this.changeSetDeployment(deploymentMethod);
          case "execute-change-set":
            return this.executeExistingChangeSet(deploymentMethod);
          case "direct":
            return this.directDeployment();
        }
      }
      async changeSetDeployment(deploymentMethod) {
        const changeSetName = deploymentMethod.changeSetName ?? DEFAULT_DEPLOY_CHANGE_SET_NAME;
        const execute2 = deploymentMethod.execute ?? true;
        const importExistingResources = deploymentMethod.importExistingResources ?? false;
        const revertDrift = deploymentMethod.revertDrift ?? false;
        const changeSetDescription = await this.createChangeSet(changeSetName, execute2, importExistingResources, revertDrift);
        await this.updateTerminationProtection();
        if (changeSetHasNoChanges(changeSetDescription)) {
          await this.ioHelper.defaults.debug((0, import_node_util2.format)("No changes are to be performed on %s.", this.stackName));
          if (execute2) {
            await this.ioHelper.defaults.debug((0, import_node_util2.format)("Deleting empty change set %s", changeSetDescription.ChangeSetId));
            await this.cfn.deleteChangeSet({
              StackName: changeSetDescription.StackId ?? this.stackName,
              ChangeSetName: changeSetDescription.ChangeSetId ?? changeSetName
            });
          }
          if (this.options.forceDeployment) {
            await this.ioHelper.defaults.warn(
              [
                "You used the --force flag, but CloudFormation reported that the deployment would not make any changes.",
                "According to CloudFormation, all resources are already up-to-date with the state in your CDK app.",
                "",
                "You cannot use the --force flag to get rid of changes you made in the console. Try using",
                "CloudFormation drift detection instead: https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-cfn-stack-drift.html"
              ].join("\n")
            );
          }
          return {
            type: "did-deploy-stack",
            noOp: true,
            outputs: this.cloudFormationStack.outputs,
            stackArn: changeSetDescription.StackId,
            deleteFailures: []
          };
        }
        if (!execute2) {
          await this.ioHelper.defaults.info((0, import_node_util2.format)(
            "Changeset %s created and waiting in review for manual execution (--no-execute)",
            changeSetDescription.ChangeSetId
          ));
          return {
            type: "did-deploy-stack",
            noOp: false,
            outputs: this.cloudFormationStack.outputs,
            stackArn: changeSetDescription.StackId,
            changeSet: changeSetDescription,
            deleteFailures: []
          };
        }
        return this.checkAndExecuteChangeSet(changeSetDescription);
      }
      async executeExistingChangeSet(deploymentMethod) {
        await this.updateTerminationProtection();
        const changeSetDescription = await this.cfn.describeChangeSet({
          StackName: this.stackName,
          ChangeSetName: deploymentMethod.changeSetName
        });
        return this.checkAndExecuteChangeSet(changeSetDescription);
      }
      /**
       * Check rollback/replacement constraints and execute the change set if all checks pass.
       */
      async checkAndExecuteChangeSet(changeSetDescription) {
        if (changeSetDescription.Status !== "CREATE_COMPLETE") {
          const status = changeSetDescription.Status ?? "UNKNOWN";
          const reason = changeSetDescription.StatusReason ? `: ${changeSetDescription.StatusReason}` : "";
          throw new ToolkitError(
            "ChangeSetNotReady",
            `Change set '${changeSetDescription.ChangeSetName}' on stack '${this.stackName}' is not ready for execution (status: ${status}${reason})`
          );
        }
        const replacement = hasReplacement(changeSetDescription);
        const isPausedFailState = this.cloudFormationStack.stackStatus.isRollbackable;
        const rollback = this.options.rollback ?? true;
        if (isPausedFailState && replacement) {
          return { type: "failpaused-need-rollback-first", reason: "replacement", status: this.cloudFormationStack.stackStatus.name };
        }
        if (isPausedFailState && rollback) {
          return { type: "failpaused-need-rollback-first", reason: "not-norollback", status: this.cloudFormationStack.stackStatus.name };
        }
        if (!rollback && replacement) {
          return { type: "replacement-requires-rollback" };
        }
        return this.executeChangeSet(changeSetDescription);
      }
      async createChangeSet(changeSetName, willExecute, importExistingResources, revertDrift) {
        await this.cleanupOldChangeset(changeSetName);
        await this.ioHelper.defaults.debug(`Attempting to create ChangeSet with name ${changeSetName} to ${this.verb} stack ${this.stackName}`);
        await this.ioHelper.defaults.info((0, import_node_util2.format)("%s: creating CloudFormation changeset...", chalk10.bold(this.stackName)));
        const changeSet = await this.cfn.createChangeSet({
          StackName: this.stackName,
          ChangeSetName: changeSetName,
          ChangeSetType: this.options.resourcesToImport ? "IMPORT" : this.update ? "UPDATE" : "CREATE",
          ResourcesToImport: this.options.resourcesToImport,
          Description: `CDK Changeset for execution ${this.uuid}`,
          ClientToken: `create${this.uuid}`,
          ImportExistingResources: importExistingResources,
          DeploymentMode: revertDrift ? "REVERT_DRIFT" : void 0,
          IncludeNestedStacks: this.options.resourcesToImport || revertDrift ? void 0 : true,
          ...this.commonPrepareOptions()
        });
        await this.ioHelper.defaults.debug((0, import_node_util2.format)("Initiated creation of changeset: %s; waiting for it to finish creating...", changeSet.Id));
        return waitForChangeSet(this.cfn, this.ioHelper, changeSet.StackId ?? this.stackName, changeSet.Id ?? changeSetName, {
          fetchAll: willExecute,
          diagnoser: this.diagnoser
        });
      }
      async executeChangeSet(changeSet) {
        await this.ioHelper.defaults.debug((0, import_node_util2.format)("Initiating execution of changeset %s on stack %s", changeSet.ChangeSetId, this.stackName));
        await this.cfn.executeChangeSet({
          StackName: changeSet.StackId ?? this.stackName,
          ChangeSetName: changeSet.ChangeSetId,
          ClientRequestToken: `exec${this.uuid}`,
          ...this.commonExecuteOptions()
        });
        await this.ioHelper.defaults.debug(
          (0, import_node_util2.format)(
            "Execution of changeset %s on stack %s has started; waiting for the update to complete...",
            changeSet.ChangeSetId,
            this.stackName
          )
        );
        const changeSetLength = (changeSet.Changes ?? []).length + (this.update ? 1 : 0);
        return this.monitorDeployment(changeSet.CreationTime, changeSet.StackId, changeSetLength);
      }
      async cleanupOldChangeset(changeSetNameOrArn) {
        if (this.cloudFormationStack.exists) {
          const changeSetDisplayName = changeSetNameFromArn(changeSetNameOrArn);
          await this.ioHelper.defaults.debug(`Removing existing change set with name ${changeSetDisplayName} if it exists`);
          await this.cfn.deleteChangeSet({
            StackName: this.stackName,
            ChangeSetName: changeSetNameOrArn
          });
          await waitForChangeSetGone(this.cfn, this.ioHelper, this.stackName, changeSetNameOrArn);
        }
      }
      async updateTerminationProtection() {
        const terminationProtection = this.stackArtifact.terminationProtection ?? false;
        if (!!this.cloudFormationStack.terminationProtection !== terminationProtection) {
          await this.ioHelper.defaults.debug(
            (0, import_node_util2.format)(
              "Updating termination protection from %s to %s for stack %s",
              this.cloudFormationStack.terminationProtection,
              terminationProtection,
              this.stackName
            )
          );
          await this.cfn.updateTerminationProtection({
            StackName: this.stackName,
            EnableTerminationProtection: terminationProtection
          });
          await this.ioHelper.defaults.debug((0, import_node_util2.format)("Termination protection updated to %s for stack %s", terminationProtection, this.stackName));
        }
      }
      async directDeployment() {
        await this.ioHelper.defaults.info((0, import_node_util2.format)("%s: %s stack...", chalk10.bold(this.stackName), this.update ? "updating" : "creating"));
        const startTime = /* @__PURE__ */ new Date();
        if (this.update) {
          await this.updateTerminationProtection();
          try {
            const stack = await this.cfn.updateStack({
              StackName: this.stackName,
              ClientRequestToken: `update${this.uuid}`,
              ...this.commonPrepareOptions(),
              ...this.commonExecuteOptions()
            });
            return await this.monitorDeployment(startTime, stack.StackId, void 0);
          } catch (err) {
            if (err.message === "No updates are to be performed.") {
              await this.ioHelper.defaults.debug((0, import_node_util2.format)("No updates are to be performed for stack %s", this.stackName));
              return {
                type: "did-deploy-stack",
                noOp: true,
                outputs: this.cloudFormationStack.outputs,
                stackArn: this.cloudFormationStack.stackId,
                deleteFailures: []
              };
            }
            throw err;
          }
        } else {
          const terminationProtection = this.stackArtifact.terminationProtection ?? false;
          const stack = await this.cfn.createStack({
            StackName: this.stackName,
            ClientRequestToken: `create${this.uuid}`,
            ...terminationProtection ? { EnableTerminationProtection: true } : void 0,
            ...this.commonPrepareOptions(),
            ...this.commonExecuteOptions()
          });
          return this.monitorDeployment(startTime, stack.StackId, void 0);
        }
      }
      async monitorDeployment(startTime, stackArn, expectedChanges) {
        const monitor = new StackActivityMonitor({
          cfn: this.cfn,
          stack: this.stackArtifact,
          stackArn,
          resourcesTotal: expectedChanges,
          ioHelper: this.ioHelper,
          changeSetCreationTime: startTime,
          envResources: this.options.envResources,
          isStackUpdate: this.update
        });
        await monitor.start();
        let finalState = this.cloudFormationStack;
        try {
          const successStack = await waitForStackDeploy(this.cfn, this.ioHelper, this.stackName);
          if (!successStack) {
            throw new DeploymentError("Stack deploy failed (the stack disappeared while we were deploying it)", DeploymentErrorCodes.STACK_DISAPPEARED_ERROR_CODE);
          }
          finalState = successStack;
        } catch (e32) {
          if (ToolkitError.isDeploymentError(e32)) {
            const diagnosis = await this.diagnoser.diagnoseFromErrorCollection(monitor.errors, finalState.wrapped, true, {
              rollbackEnabled: this.options.rollback !== false
            });
            if (diagnosis.type !== "no-problem") {
              throwDeploymentErrorFromDiagnosis(diagnosis);
            }
          }
          throw e32;
        } finally {
          await monitor.stop();
        }
        await this.ioHelper.defaults.debug((0, import_node_util2.format)("Stack %s has completed updating", this.stackName));
        return {
          type: "did-deploy-stack",
          noOp: false,
          outputs: finalState.outputs,
          stackArn: finalState.stackId,
          deleteFailures: this.update ? monitor.deleteFailures : []
        };
      }
      /**
       * Return the options that are shared between CreateStack, UpdateStack and CreateChangeSet
       */
      commonPrepareOptions() {
        return {
          Capabilities: ["CAPABILITY_IAM", "CAPABILITY_NAMED_IAM", "CAPABILITY_AUTO_EXPAND"],
          NotificationARNs: this.options.notificationArns,
          Parameters: this.stackParams.apiParameters,
          RoleARN: this.options.roleArn,
          TemplateBody: this.bodyParameter.TemplateBody,
          TemplateURL: this.bodyParameter.TemplateURL,
          Tags: this.options.tags
        };
      }
      /**
       * Return the options that are shared between UpdateStack and CreateChangeSet
       *
       * Be careful not to add in keys for options that aren't used, as the features may not have been
       * deployed everywhere yet.
       */
      commonExecuteOptions() {
        const shouldDisableRollback = this.options.rollback === false;
        return {
          StackName: this.stackName,
          ...shouldDisableRollback ? { DisableRollback: true } : void 0
        };
      }
    };
    __name(destroyStack, "destroyStack");
    __name(canSkipDeploy, "canSkipDeploy");
    __name(compareTags, "compareTags");
    __name(suffixWithErrors, "suffixWithErrors");
    __name(arrayEquals, "arrayEquals");
    __name(hasReplacement, "hasReplacement");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/notices/cached-data-source.ts
var fs18, TIME_TO_LIVE_SUCCESS, TIME_TO_LIVE_ERROR, CachedDataSource;
var init_cached_data_source = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/notices/cached-data-source.ts"() {
    "use strict";
    fs18 = __toESM(require_lib4());
    init_toolkit_error();
    TIME_TO_LIVE_SUCCESS = 60 * 60 * 1e3;
    TIME_TO_LIVE_ERROR = 1 * 60 * 1e3;
    CachedDataSource = class {
      constructor(ioHelper, fileName, dataSource, skipCache) {
        this.ioHelper = ioHelper;
        this.fileName = fileName;
        this.dataSource = dataSource;
        this.skipCache = skipCache;
      }
      ioHelper;
      fileName;
      dataSource;
      skipCache;
      static {
        __name(this, "CachedDataSource");
      }
      async fetch() {
        const cachedData = await this.load();
        const data3 = cachedData.notices;
        const expiration = cachedData.expiration ?? 0;
        if (Date.now() > expiration || this.skipCache) {
          let updatedData = cachedData;
          try {
            updatedData = await this.fetchInner();
          } catch (e32) {
            await this.ioHelper.defaults.debug(`Could not refresh notices: ${e32}`);
            updatedData = {
              expiration: Date.now() + TIME_TO_LIVE_ERROR,
              notices: []
            };
            throw ToolkitError.withCause("NoticesFetchFailed", "Failed to load CDK notices. Please try again later.", e32);
          } finally {
            await this.save(updatedData);
          }
          return updatedData.notices;
        } else {
          await this.ioHelper.defaults.debug(`Reading cached notices from ${this.fileName}`);
          return data3;
        }
      }
      async fetchInner() {
        return {
          expiration: Date.now() + TIME_TO_LIVE_SUCCESS,
          notices: await this.dataSource.fetch()
        };
      }
      async load() {
        const defaultValue2 = {
          expiration: 0,
          notices: []
        };
        try {
          return fs18.existsSync(this.fileName) ? await fs18.readJSON(this.fileName) : defaultValue2;
        } catch (e32) {
          await this.ioHelper.defaults.debug(`Failed to load notices from cache: ${e32}`);
          return defaultValue2;
        }
      }
      async save(cached3) {
        try {
          await fs18.ensureFile(this.fileName);
          await fs18.writeJSON(this.fileName, cached3);
        } catch (e32) {
          await this.ioHelper.defaults.debug(`Failed to store notices in the cache: ${e32}`);
        }
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/tree.ts
function some(node, predicate) {
  return node != null && (predicate(node) || findInChildren());
  function findInChildren() {
    return Object.values(node?.children ?? {}).some((child) => some(child, predicate));
  }
  __name(findInChildren, "findInChildren");
}
async function loadTree(assembly, trace2) {
  try {
    const outdir = assembly.directory;
    const fileName = assembly.tree()?.file;
    return fileName ? fs19.readJSONSync(path19.join(outdir, fileName)).tree : void 0;
  } catch (e32) {
    await trace2(`Failed to get tree.json file: ${e32}. Proceeding with empty tree.`);
    return void 0;
  }
}
async function loadTreeFromDir(outdir, trace2) {
  try {
    return fs19.readJSONSync(path19.join(outdir, "tree.json")).tree;
  } catch (e32) {
    await trace2(`Failed to get tree.json file: ${e32}. Proceeding with empty tree.`);
    return void 0;
  }
}
var path19, fs19;
var init_tree = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/tree.ts"() {
    "use strict";
    path19 = __toESM(require("node:path"));
    fs19 = __toESM(require_lib4());
    __name(some, "some");
    __name(loadTree, "loadTree");
    __name(loadTreeFromDir, "loadTreeFromDir");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/notices/filter.ts
function normalizeComponents(xs) {
  return xs.map((x) => Array.isArray(x) ? x : [x]);
}
function dnfComponents(notice) {
  if (notice.schemaVersion === "2" && notice.componentsV2) {
    return normalizeComponents(notice.componentsV2);
  }
  return normalizeComponents(notice.components);
}
function renderComponent(c32) {
  if (c32.name.startsWith("language:")) {
    return `${languageDisplayName(c32.name.slice("language:".length))} apps`;
  }
  return `${c32.name}: ${c32.version}`;
}
function renderConjunction(xs) {
  return xs.map(renderComponent).join(" AND ");
}
var semver3, NoticesFilter, FilteredNotice;
var init_filter = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/notices/filter.ts"() {
    "use strict";
    semver3 = __toESM(require_semver4());
    init_guess_language();
    init_tree();
    __name(normalizeComponents, "normalizeComponents");
    __name(dnfComponents, "dnfComponents");
    __name(renderComponent, "renderComponent");
    __name(renderConjunction, "renderConjunction");
    NoticesFilter = class {
      static {
        __name(this, "NoticesFilter");
      }
      ioHelper;
      constructor(ioHelper) {
        this.ioHelper = ioHelper;
      }
      async filter(options) {
        const components = [
          ...await this.constructTreeComponents(options.outDir),
          ...await this.otherComponents(options)
        ];
        return this.findForNamedComponents(options.data, components);
      }
      /**
       * From a set of input options, return the notices components we are searching for
       */
      async otherComponents(options) {
        let bootstrappedEnvironments = [];
        for (const env3 of options.bootstrappedEnvironments) {
          const semverBootstrapVersion = semver3.coerce(env3.bootstrapStackVersion);
          if (!semverBootstrapVersion) {
            await this.ioHelper.defaults.warning(`While filtering notices, could not coerce bootstrap version '${env3.bootstrapStackVersion}' into semver`);
            continue;
          }
          bootstrappedEnvironments.push({
            name: "bootstrap",
            version: `${semverBootstrapVersion}`,
            dynamicName: "ENVIRONMENTS",
            dynamicValue: env3.environment.name
          });
        }
        return [
          // CLI
          {
            name: "cli",
            version: options.cliVersion
          },
          // Node version
          {
            name: "node",
            version: process.version.replace(/^v/, ""),
            // remove the 'v' prefix.
            dynamicName: "node"
          },
          // Bootstrap environments
          ...bootstrappedEnvironments,
          // Language
          ...options.language ? [{
            name: `language:${options.language}`,
            version: "0.0.0",
            dynamicName: "LANGUAGE",
            dynamicValue: languageDisplayName(options.language)
          }] : []
        ];
      }
      /**
       * Based on a set of component names, find all notices that match one of the given components
       */
      findForNamedComponents(data3, actualComponents) {
        return data3.flatMap((notice) => {
          const ors = this.resolveAliases(dnfComponents(notice));
          for (const ands of ors) {
            const matched = ands.map((affected) => actualComponents.filter((actual) => this.componentNameMatches(affected, actual) && semver3.satisfies(actual.version, affected.version, { includePrerelease: true })));
            if (matched.every((xs) => xs.length > 0)) {
              const ret = new FilteredNotice(notice);
              this.addDynamicValues(matched.flatMap((x) => x), ret, notice.dynamicValues);
              return [ret];
            }
          }
          return [];
        });
      }
      /**
       * Whether the given "affected component" name applies to the given actual component name.
       *
       * The name matches if the name is exactly the same, or the name in the notice
       * is a prefix of the node name when the query ends in '.'.
       */
      componentNameMatches(pattern, actual) {
        return pattern.name.endsWith(".") ? actual.name.startsWith(pattern.name) : pattern.name === actual.name;
      }
      /**
       * Adds dynamic values from the given ActualComponents
       *
       * If there are multiple components with the same dynamic name, they are joined
       * by the separator declared in `specs[name].separator`, defaulting to `','`.
       */
      addDynamicValues(comps, notice, specs) {
        const dynamicValues = {};
        for (const comp of comps) {
          if (comp.dynamicName) {
            dynamicValues[comp.dynamicName] = dynamicValues[comp.dynamicName] ?? [];
            dynamicValues[comp.dynamicName].push(comp.dynamicValue ?? comp.version);
          }
        }
        for (const [key, values] of Object.entries(dynamicValues)) {
          notice.addDynamicValue(key, values.join(specs?.[key]?.separator ?? ","));
        }
      }
      /**
       * Treat 'framework' as an alias for either `aws-cdk-lib.` or `@aws-cdk/core.`.
       *
       * Because it's EITHER `aws-cdk-lib` or `@aws-cdk/core`, we need to add multiple
       * arrays at the top level.
       */
      resolveAliases(ors) {
        return ors.flatMap((ands) => {
          const hasFramework = ands.find((c32) => c32.name === "framework");
          if (!hasFramework) {
            return [ands];
          }
          return [
            ands.map((c32) => c32.name === "framework" ? { ...c32, name: "@aws-cdk/core." } : c32),
            ands.map((c32) => c32.name === "framework" ? { ...c32, name: "aws-cdk-lib." } : c32)
          ];
        });
      }
      /**
       * Load the construct tree from the given directory and return its components
       */
      async constructTreeComponents(manifestDir) {
        const tree = await loadTreeFromDir(manifestDir, (msg) => this.ioHelper.defaults.trace(msg));
        if (!tree) {
          return [];
        }
        const ret = [];
        recurse(tree);
        return ret;
        function recurse(x) {
          if (x.constructInfo?.fqn && x.constructInfo?.version) {
            ret.push({
              name: x.constructInfo?.fqn,
              version: x.constructInfo?.version
            });
          }
          for (const child of Object.values(x.children ?? {})) {
            recurse(child);
          }
        }
        __name(recurse, "recurse");
      }
    };
    FilteredNotice = class {
      constructor(notice) {
        this.notice = notice;
      }
      notice;
      static {
        __name(this, "FilteredNotice");
      }
      dynamicValues = {};
      addDynamicValue(key, value) {
        this.dynamicValues[`{resolve:${key}}`] = value;
      }
      format() {
        const componentsValue = dnfComponents(this.notice).map(renderConjunction).join(", ");
        return this.resolveDynamicValues([
          `${this.notice.issueNumber}	${this.notice.title}`,
          this.formatOverview(),
          `	Affected versions: ${componentsValue}`,
          `	More information at: https://github.com/aws/aws-cdk/issues/${this.notice.issueNumber}`
        ].join("\n\n") + "\n");
      }
      formatOverview() {
        const wrap = /* @__PURE__ */ __name((s) => s.replace(/(?![^\n]{1,60}$)([^\n]{1,60})\s/g, "$1\n"), "wrap");
        const heading = "Overview: ";
        const separator = `
	${" ".repeat(heading.length)}`;
        const content = wrap(this.notice.overview).split("\n").join(separator);
        return "	" + heading + content;
      }
      resolveDynamicValues(input) {
        const pattern = new RegExp(Object.keys(this.dynamicValues).join("|"), "g");
        return input.replace(pattern, (matched) => this.dynamicValues[matched] ?? matched);
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/network-detector/network-detector.ts
var https, path20, fs20, TIME_TO_LIVE_SUCCESS2, CACHE_FILE_PATH, NetworkDetector;
var init_network_detector = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/network-detector/network-detector.ts"() {
    "use strict";
    https = __toESM(require("node:https"));
    path20 = __toESM(require("path"));
    fs20 = __toESM(require_lib4());
    init_util3();
    TIME_TO_LIVE_SUCCESS2 = 60 * 60 * 1e3;
    CACHE_FILE_PATH = path20.join(cdkCacheDir(), "connection.json");
    NetworkDetector = class _NetworkDetector {
      static {
        __name(this, "NetworkDetector");
      }
      /**
       * Check if internet connectivity is available
       */
      static async hasConnectivity(agent) {
        const cachedData = await this.load();
        const expiration = cachedData.expiration ?? 0;
        if (Date.now() > expiration) {
          try {
            const connected = await this.ping(agent);
            const updatedData = {
              expiration: Date.now() + TIME_TO_LIVE_SUCCESS2,
              hasConnectivity: connected
            };
            await this.save(updatedData);
            return connected;
          } catch {
            return false;
          }
        } else {
          return cachedData.hasConnectivity;
        }
      }
      // We are observing lots of timeouts when running in a massively parallel
      // integration test environment, so wait for a longer timeout there.
      //
      // In production, have a short timeout to not hold up the user experience.
      static TIMEOUT = process.env.TESTING_CDK ? 3e4 : 3e3;
      static URL = "https://cli.cdk.dev-tools.aws.dev/notices.json";
      static async load() {
        const defaultValue2 = {
          expiration: 0,
          hasConnectivity: false
        };
        try {
          return fs20.existsSync(CACHE_FILE_PATH) ? await fs20.readJSON(CACHE_FILE_PATH) : defaultValue2;
        } catch {
          return defaultValue2;
        }
      }
      static async save(cached3) {
        try {
          await fs20.ensureFile(CACHE_FILE_PATH);
          await fs20.writeJSON(CACHE_FILE_PATH, cached3);
        } catch {
        }
      }
      static ping(agent) {
        const options = {
          method: "HEAD",
          agent,
          timeout: this.TIMEOUT
        };
        return new Promise((resolve13) => {
          const req = https.request(
            _NetworkDetector.URL,
            options,
            (res) => {
              resolve13(res.statusCode !== void 0 && res.statusCode < 500);
            }
          );
          req.on("error", () => resolve13(false));
          req.on("timeout", () => {
            req.destroy();
            resolve13(false);
          });
          req.end();
        });
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/notices/web-data-source.ts
var https2, WebsiteNoticeDataSource;
var init_web_data_source = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/notices/web-data-source.ts"() {
    "use strict";
    https2 = __toESM(require("node:https"));
    init_toolkit_error();
    init_util3();
    init_network_detector();
    WebsiteNoticeDataSource = class {
      constructor(ioHelper, props = {}) {
        this.ioHelper = ioHelper;
        this.agent = props.agent;
        this.url = props.url ?? "https://cli.cdk.dev-tools.aws.dev/notices.json";
      }
      ioHelper;
      static {
        __name(this, "WebsiteNoticeDataSource");
      }
      /**
       * The URL notices are loaded from.
       */
      url;
      agent;
      async fetch() {
        const hasConnectivity = await NetworkDetector.hasConnectivity(this.agent);
        if (!hasConnectivity) {
          throw new ToolkitError("NoConnectivity", "No internet connectivity detected");
        }
        const timeout = process.env.CDK_NOTICES_TIMEOUT !== void 0 ? parseInt(process.env.CDK_NOTICES_TIMEOUT, 10) : process.env.TESTING_CDK ? 3e4 : 3e3;
        const options = {
          agent: this.agent
        };
        const notices = await new Promise((resolve13, reject) => {
          let req;
          let timer = setTimeout(() => {
            if (req) {
              req.destroy(new ToolkitError("RequestTimeout", "Request timed out"));
            }
          }, timeout);
          timer.unref();
          try {
            req = https2.get(
              this.url,
              options,
              (res) => {
                if (res.statusCode === 200) {
                  res.setEncoding("utf8");
                  let rawData = "";
                  res.on("data", (chunk) => {
                    rawData += chunk;
                  });
                  res.on("end", () => {
                    try {
                      const data3 = JSON.parse(rawData).notices;
                      if (!data3) {
                        throw new ToolkitError("MissingNoticesKey", "'notices' key is missing from received data");
                      }
                      resolve13(data3 ?? []);
                    } catch (e32) {
                      reject(ToolkitError.withCause("NoticesParseError", `Parse error: ${formatErrorMessage(e32)}`, e32));
                    }
                  });
                  res.on("error", (e32) => {
                    reject(ToolkitError.withCause("NoticesResponseError", formatErrorMessage(e32), e32));
                  });
                } else {
                  reject(new ToolkitError("HttpStatusError", `${humanHttpStatusError(res.statusCode)} (Status code: ${res.statusCode})`));
                }
              }
            );
            req.on("error", (e32) => {
              reject(ToolkitError.withCause("NetworkError", humanNetworkError(e32), e32));
            });
          } catch (e32) {
            reject(ToolkitError.withCause("NoticesRequestError", formatErrorMessage(e32), e32));
          }
        });
        await this.ioHelper.defaults.debug("Notices refreshed");
        return notices;
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/notices/notices.ts
var path21, CACHE_FILE_PATH2, Notices;
var init_notices = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/notices/notices.ts"() {
    "use strict";
    path21 = __toESM(require("path"));
    init_util3();
    init_cached_data_source();
    init_filter();
    init_web_data_source();
    init_private();
    CACHE_FILE_PATH2 = path21.join(cdkCacheDir(), "notices.json");
    Notices = class _Notices {
      static {
        __name(this, "Notices");
      }
      /**
       * Create an instance. Note that this replaces the singleton.
       */
      static create(props) {
        this._instance = new _Notices(props);
        return this._instance;
      }
      /**
       * Get the singleton instance. May return `undefined` if `create` has not been called.
       */
      static get() {
        return this._instance;
      }
      static _instance;
      context;
      output;
      language;
      acknowledgedIssueNumbers;
      httpOptions;
      ioHelper;
      cliVersion;
      data = /* @__PURE__ */ new Set();
      // sets don't deduplicate interfaces, so we use a map.
      bootstrappedEnvironments = /* @__PURE__ */ new Map();
      constructor(props) {
        this.context = props.context;
        this.acknowledgedIssueNumbers = new Set(this.context.get("acknowledged-issue-numbers") ?? []);
        this.output = props.output ?? "cdk.out";
        this.language = props.language;
        this.httpOptions = props.httpOptions ?? {};
        this.ioHelper = asIoHelper(
          props.ioHost,
          "notices"
          /* forcing a CliAction to a ToolkitAction */
        );
        this.cliVersion = props.cliVersion;
      }
      /**
       * Add a bootstrap information to filter on. Can have multiple values
       * in case of multi-environment deployments.
       */
      addBootstrappedEnvironment(bootstrapped) {
        const key = [
          bootstrapped.bootstrapStackVersion,
          bootstrapped.environment.account,
          bootstrapped.environment.region,
          bootstrapped.environment.name
        ].join(":");
        this.bootstrappedEnvironments.set(key, bootstrapped);
      }
      /**
       * Refresh the list of notices this instance is aware of.
       *
       * This method throws an error if the data source fails to fetch notices.
       * When using, consider if execution should halt immdiately or if catching the error and continuing is more appropriate
       *
       * @throws on failure to refresh the data source
       */
      async refresh(options = {}) {
        const innerDataSource = options.dataSource ?? new WebsiteNoticeDataSource(this.ioHelper, this.httpOptions);
        const dataSource = new CachedDataSource(this.ioHelper, CACHE_FILE_PATH2, innerDataSource, options.force ?? false);
        const notices = await dataSource.fetch();
        this.data = new Set(notices);
      }
      /**
       * Filter the data source for relevant notices
       */
      async filter(options = {}) {
        return new NoticesFilter(this.ioHelper).filter({
          data: this.noticesFromData(options.includeAcknowledged ?? false),
          cliVersion: this.cliVersion,
          outDir: this.output,
          bootstrappedEnvironments: Array.from(this.bootstrappedEnvironments.values()),
          language: this.language
        });
      }
      /**
       * Display the relevant notices (unless context dictates we shouldn't).
       */
      async display(options = {}) {
        const filteredNotices = await this.filter(options);
        if (filteredNotices.length > 0) {
          await this.ioHelper.notify(IO.CDK_TOOLKIT_I0100.msg([
            "",
            "NOTICES         (What's this? https://github.com/aws/aws-cdk/wiki/CLI-Notices)",
            ""
          ].join("\n")));
          for (const filtered of filteredNotices) {
            const formatted = filtered.format() + "\n";
            switch (filtered.notice.severity) {
              case "warning":
                await this.ioHelper.notify(IO.CDK_TOOLKIT_W0101.msg(formatted));
                break;
              case "error":
                await this.ioHelper.notify(IO.CDK_TOOLKIT_E0101.msg(formatted));
                break;
              default:
                await this.ioHelper.notify(IO.CDK_TOOLKIT_I0101.msg(formatted));
                break;
            }
          }
          await this.ioHelper.notify(IO.CDK_TOOLKIT_I0100.msg(
            `If you don't want to see a notice anymore, use "cdk acknowledge <id>". For example, "cdk acknowledge ${filteredNotices[0].notice.issueNumber}".`
          ));
        }
        if (options.showTotal ?? false) {
          await this.ioHelper.notify(IO.CDK_TOOLKIT_I0100.msg(
            `
There are ${filteredNotices.length} unacknowledged notice(s).`
          ));
        }
      }
      /**
       * List all notices available in the data source.
       *
       * @param includeAcknowlegded - Whether to include acknowledged notices.
       */
      noticesFromData(includeAcknowlegded = false) {
        const data3 = Array.from(this.data);
        if (includeAcknowlegded) {
          return data3;
        }
        return data3.filter((n10) => !this.acknowledgedIssueNumbers.has(n10.issueNumber));
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/notices/index.ts
var init_notices2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/notices/index.ts"() {
    "use strict";
    init_notices();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/toolkit-info.ts
var import_util31, chalk11, DEFAULT_TOOLKIT_STACK_NAME, ToolkitInfo, ExistingToolkitInfo, BootstrapStackNotFoundInfo;
var init_toolkit_info = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/toolkit-info.ts"() {
    "use strict";
    import_util31 = require("util");
    chalk11 = __toESM(require_source());
    init_bootstrap_props();
    init_toolkit_error();
    init_cfn_api();
    DEFAULT_TOOLKIT_STACK_NAME = "CDKToolkit";
    ToolkitInfo = class _ToolkitInfo {
      static {
        __name(this, "ToolkitInfo");
      }
      static determineName(overrideName) {
        return overrideName ?? DEFAULT_TOOLKIT_STACK_NAME;
      }
      static async lookup(environment, sdk, ioHelper, stackName) {
        const cfn = sdk.cloudFormation();
        stackName = _ToolkitInfo.determineName(stackName);
        try {
          const stack = await stabilizeStack(cfn, ioHelper, stackName);
          if (!stack) {
            await ioHelper.defaults.debug(
              (0, import_util31.format)(
                "The environment %s doesn't have the CDK toolkit stack (%s) installed. Use %s to setup your environment for use with the toolkit.",
                environment.name,
                stackName,
                chalk11.blue(`cdk bootstrap "${environment.name}"`)
              )
            );
            return _ToolkitInfo.bootstrapStackNotFoundInfo(stackName);
          }
          if (stack.stackStatus.isCreationFailure) {
            await ioHelper.defaults.debug(
              (0, import_util31.format)(
                "The environment %s has a CDK toolkit stack (%s) that failed to create. Use %s to try provisioning it again.",
                environment.name,
                stackName,
                chalk11.blue(`cdk bootstrap "${environment.name}"`)
              )
            );
            return _ToolkitInfo.bootstrapStackNotFoundInfo(stackName);
          }
          return new ExistingToolkitInfo(stack);
        } catch (e32) {
          return _ToolkitInfo.bootstrapStackLookupError(stackName, e32);
        }
      }
      static fromStack(stack) {
        return new ExistingToolkitInfo(stack);
      }
      static bootstrapStackNotFoundInfo(stackName) {
        return new BootstrapStackNotFoundInfo(
          stackName,
          "This deployment requires a bootstrap stack with a known name; pass '--toolkit-stack-name' or switch to using the 'DefaultStackSynthesizer' (see https://docs.aws.amazon.com/cdk/latest/guide/bootstrapping.html)"
        );
      }
      static bootstrapStackLookupError(stackName, e32) {
        return new BootstrapStackNotFoundInfo(
          stackName,
          `This deployment requires a bootstrap stack with a known name, but during its lookup the following error occurred: ${e32}; pass '--toolkit-stack-name' or switch to using the 'DefaultStackSynthesizer' (see https://docs.aws.amazon.com/cdk/latest/guide/bootstrapping.html)`
        );
      }
      constructor() {
      }
    };
    ExistingToolkitInfo = class extends ToolkitInfo {
      constructor(bootstrapStack) {
        super();
        this.bootstrapStack = bootstrapStack;
      }
      bootstrapStack;
      static {
        __name(this, "ExistingToolkitInfo");
      }
      found = true;
      get bucketUrl() {
        return `https://${this.requireOutput(BUCKET_DOMAIN_NAME_OUTPUT)}`;
      }
      get bucketName() {
        return this.requireOutput(BUCKET_NAME_OUTPUT);
      }
      get repositoryName() {
        return this.requireOutput(REPOSITORY_NAME_OUTPUT);
      }
      get version() {
        return parseInt(this.bootstrapStack.outputs[BOOTSTRAP_VERSION_OUTPUT] ?? "0", 10);
      }
      get variant() {
        return this.bootstrapStack.parameters[BOOTSTRAP_VARIANT_PARAMETER] ?? DEFAULT_BOOTSTRAP_VARIANT;
      }
      get parameters() {
        return this.bootstrapStack.parameters ?? {};
      }
      get terminationProtection() {
        return this.bootstrapStack.terminationProtection ?? false;
      }
      get stackName() {
        return this.bootstrapStack.stackName;
      }
      /**
       * Prepare an ECR repository for uploading to using Docker
       *
       */
      requireOutput(output) {
        if (!(output in this.bootstrapStack.outputs)) {
          throw new ToolkitError(
            "MissingBootstrapStackOutput",
            `The CDK toolkit stack (${this.bootstrapStack.stackName}) does not have an output named ${output}. Use 'cdk bootstrap' to correct this.`
          );
        }
        return this.bootstrapStack.outputs[output];
      }
    };
    BootstrapStackNotFoundInfo = class extends ToolkitInfo {
      constructor(stackName, errorMessage) {
        super();
        this.stackName = stackName;
        this.errorMessage = errorMessage;
      }
      stackName;
      errorMessage;
      static {
        __name(this, "BootstrapStackNotFoundInfo");
      }
      found = false;
      get bootstrapStack() {
        throw new ToolkitError("BootstrapStackNotFound", this.errorMessage);
      }
      get bucketUrl() {
        throw new ToolkitError("BootstrapStackNotFound", this.errorMessage);
      }
      get bucketName() {
        throw new ToolkitError("BootstrapStackNotFound", this.errorMessage);
      }
      get repositoryName() {
        throw new ToolkitError("BootstrapStackNotFound", this.errorMessage);
      }
      get version() {
        throw new ToolkitError("BootstrapStackNotFound", this.errorMessage);
      }
      get variant() {
        throw new ToolkitError("BootstrapStackNotFound", this.errorMessage);
      }
      prepareEcrRepository() {
        throw new ToolkitError("BootstrapStackNotFound", this.errorMessage);
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/environment/environment-resources.ts
function emptyCache() {
  return {
    ssmParameters: /* @__PURE__ */ new Map(),
    toolkitInfo: void 0
  };
}
var EnvironmentResourcesRegistry, EnvironmentResources, NoBootstrapStackEnvironmentResources, BOOTSTRAP_TEMPLATE_VERSION_INTRODUCING_GETPARAMETER;
var init_environment_resources = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/environment/environment-resources.ts"() {
    "use strict";
    init_toolkit_error();
    init_util3();
    init_notices2();
    init_toolkit_info();
    EnvironmentResourcesRegistry = class {
      constructor(toolkitStackName) {
        this.toolkitStackName = toolkitStackName;
      }
      toolkitStackName;
      static {
        __name(this, "EnvironmentResourcesRegistry");
      }
      cache = /* @__PURE__ */ new Map();
      for(resolvedEnvironment, sdk, ioHelper) {
        const key = `${resolvedEnvironment.account}:${resolvedEnvironment.region}`;
        let envCache = this.cache.get(key);
        if (!envCache) {
          envCache = emptyCache();
          this.cache.set(key, envCache);
        }
        return new EnvironmentResources(resolvedEnvironment, sdk, ioHelper, envCache, this.toolkitStackName);
      }
    };
    EnvironmentResources = class {
      constructor(environment, sdk, ioHelper, cache32, toolkitStackName) {
        this.environment = environment;
        this.sdk = sdk;
        this.ioHelper = ioHelper;
        this.cache = cache32;
        this.toolkitStackName = toolkitStackName;
      }
      environment;
      sdk;
      ioHelper;
      cache;
      toolkitStackName;
      static {
        __name(this, "EnvironmentResources");
      }
      /**
       * Look up the toolkit for a given environment, using a given SDK
       */
      async lookupToolkit() {
        if (!this.cache.toolkitInfo) {
          this.cache.toolkitInfo = await ToolkitInfo.lookup(this.environment, this.sdk, this.ioHelper, this.toolkitStackName);
        }
        return this.cache.toolkitInfo;
      }
      /**
       * Validate that the bootstrap stack version matches or exceeds the expected version
       *
       * Use the SSM parameter name to read the version number if given, otherwise use the version
       * discovered on the bootstrap stack.
       *
       * Pass in the SSM parameter name so we can cache the lookups an don't need to do the same
       * lookup again and again for every artifact.
       */
      async validateVersion(expectedVersion, ssmParameterName) {
        if (expectedVersion === void 0) {
          return;
        }
        const defExpectedVersion = expectedVersion;
        if (ssmParameterName !== void 0) {
          try {
            doValidate(await this.versionFromSsmParameter(ssmParameterName), this.environment);
            return;
          } catch (e32) {
            if (e32.name !== "AccessDeniedException") {
              throw e32;
            }
            const bootstrapStack2 = await this.lookupToolkit();
            if (bootstrapStack2.found && bootstrapStack2.version < BOOTSTRAP_TEMPLATE_VERSION_INTRODUCING_GETPARAMETER) {
              await this.ioHelper.defaults.warn(
                `Could not read SSM parameter ${ssmParameterName}: ${formatErrorMessage(e32)}, falling back to version from ${bootstrapStack2}`
              );
              doValidate(bootstrapStack2.version, this.environment);
              return;
            }
            throw new ToolkitError(
              "BootstrapVersionSsmConfirmationFailed",
              `This CDK deployment requires bootstrap stack version '${expectedVersion}', but during the confirmation via SSM parameter ${ssmParameterName} the following error occurred: ${e32}`
            );
          }
        }
        const bootstrapStack = await this.lookupToolkit();
        doValidate(bootstrapStack.version, this.environment);
        function doValidate(version, environment) {
          const notices = Notices.get();
          if (notices) {
            notices.addBootstrappedEnvironment({ bootstrapStackVersion: version, environment });
          }
          if (defExpectedVersion > version) {
            throw new ToolkitError(
              "OutdatedBootstrapStack",
              `This CDK deployment requires bootstrap stack version '${expectedVersion}', found '${version}'. Please run 'cdk bootstrap'.`
            );
          }
        }
        __name(doValidate, "doValidate");
      }
      /**
       * Read a version from an SSM parameter, cached
       */
      async versionFromSsmParameter(parameterName) {
        const existing = this.cache.ssmParameters.get(parameterName);
        if (existing !== void 0) {
          return existing;
        }
        const ssm = this.sdk.ssm();
        try {
          const result2 = await ssm.getParameter({
            Name: parameterName,
            // A custom template might use a SecureString for this, so we request the decrypted parameter.
            // The flag is safe to set, since it will be ignored for unencrypted parameters.
            // It is still up to user to ensure that all roles have sufficient permissions,
            // however when using AWS Managed Keys, SSM is granted decryption permissions by default.
            WithDecryption: true
          });
          const asNumber = parseInt(`${result2.Parameter?.Value}`, 10);
          if (isNaN(asNumber)) {
            throw new ToolkitError("SsmParameterNotANumber", `SSM parameter ${parameterName} not a number: ${result2.Parameter?.Value}`);
          }
          this.cache.ssmParameters.set(parameterName, asNumber);
          return asNumber;
        } catch (e32) {
          if (e32.name === "ParameterNotFound") {
            throw new ToolkitError(
              "SsmParameterNotFound",
              `SSM parameter ${parameterName} not found. Has the environment been bootstrapped? Please run 'cdk bootstrap' (see https://docs.aws.amazon.com/cdk/latest/guide/bootstrapping.html)`
            );
          }
          throw e32;
        }
      }
      async prepareEcrRepository(repositoryName) {
        if (!this.sdk) {
          throw new ToolkitError("SdkNotInitialized", "ToolkitInfo needs to have been initialized with an sdk to call prepareEcrRepository");
        }
        const ecr = this.sdk.ecr();
        try {
          await this.ioHelper.defaults.debug(`${repositoryName}: checking if ECR repository already exists`);
          const describeResponse = await ecr.describeRepositories({
            repositoryNames: [repositoryName]
          });
          const existingRepositoryUri = describeResponse.repositories[0]?.repositoryUri;
          if (existingRepositoryUri) {
            return { repositoryUri: existingRepositoryUri };
          }
        } catch (e32) {
          if (e32.name !== "RepositoryNotFoundException") {
            throw e32;
          }
        }
        await this.ioHelper.defaults.debug(`${repositoryName}: creating ECR repository`);
        const assetTag = { Key: "awscdk:asset", Value: "true" };
        const response = await ecr.createRepository({
          repositoryName,
          tags: [assetTag]
        });
        const repositoryUri2 = response.repository?.repositoryUri;
        if (!repositoryUri2) {
          throw new ToolkitError("EcrRepositoryCreateFailed", `CreateRepository did not return a repository URI for ${repositoryUri2}`);
        }
        await this.ioHelper.defaults.debug(`${repositoryName}: enable image scanning`);
        await ecr.putImageScanningConfiguration({
          repositoryName,
          imageScanningConfiguration: { scanOnPush: true }
        });
        return { repositoryUri: repositoryUri2 };
      }
    };
    NoBootstrapStackEnvironmentResources = class extends EnvironmentResources {
      static {
        __name(this, "NoBootstrapStackEnvironmentResources");
      }
      constructor(environment, sdk, ioHelper) {
        super(environment, sdk, ioHelper, emptyCache());
      }
      /**
       * Look up the toolkit for a given environment, using a given SDK
       */
      async lookupToolkit() {
        throw new ToolkitError(
          "BootstrapStackRequired",
          "Trying to perform an operation that requires a bootstrap stack; you should not see this error, this is a bug in the CDK CLI."
        );
      }
    };
    __name(emptyCache, "emptyCache");
    BOOTSTRAP_TEMPLATE_VERSION_INTRODUCING_GETPARAMETER = 5;
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/environment/placeholders.ts
async function replaceEnvPlaceholders(object, env3, sdkProvider) {
  return import_cloud_assembly_api5.EnvironmentPlaceholders.replaceAsync(object, {
    accountId: /* @__PURE__ */ __name(() => Promise.resolve(env3.account), "accountId"),
    region: /* @__PURE__ */ __name(() => Promise.resolve(env3.region), "region"),
    partition: /* @__PURE__ */ __name(async () => {
      return await sdkProvider.baseCredentialsPartition(env3, 0 /* ForReading */) ?? "aws";
    }, "partition")
  });
}
var import_cloud_assembly_api5;
var init_placeholders3 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/environment/placeholders.ts"() {
    "use strict";
    import_cloud_assembly_api5 = __toESM(require_lib3());
    init_plugin2();
    __name(replaceEnvPlaceholders, "replaceEnvPlaceholders");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/environment/environment-access.ts
var EnvironmentAccess;
var init_environment_access = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/environment/environment-access.ts"() {
    "use strict";
    init_environment_resources();
    init_placeholders3();
    init_toolkit_error();
    init_util3();
    init_plugin2();
    EnvironmentAccess = class {
      constructor(sdkProvider, toolkitStackName, ioHelper) {
        this.sdkProvider = sdkProvider;
        this.environmentResources = new EnvironmentResourcesRegistry(toolkitStackName);
        this.ioHelper = ioHelper;
      }
      sdkProvider;
      static {
        __name(this, "EnvironmentAccess");
      }
      sdkCache = /* @__PURE__ */ new Map();
      environmentResources;
      ioHelper;
      /**
       * Resolves the environment for a stack.
       */
      async resolveStackEnvironment(stack) {
        return this.sdkProvider.resolveEnvironment(stack.environment);
      }
      /**
       * Get an SDK to access the given stack's environment for stack operations
       *
       * Will ask plugins for readonly credentials if available, use the default
       * AWS credentials if not.
       *
       * Will assume the deploy role if configured on the stack. Check the default `deploy-role`
       * policies to see what you can do with this role.
       */
      async accessStackForReadOnlyStackOperations(stack) {
        return this.accessStackForStackOperations(stack, 0 /* ForReading */);
      }
      /**
       * Get an SDK to access the given stack's environment for stack operations
       *
       * Will ask plugins for mutating credentials if available, use the default AWS
       * credentials if not.  The `mode` parameter is only used for querying
       * plugins.
       *
       * Will assume the deploy role if configured on the stack. Check the default `deploy-role`
       * policies to see what you can do with this role.
       */
      async accessStackForMutableStackOperations(stack) {
        return this.accessStackForStackOperations(stack, 1 /* ForWriting */);
      }
      /**
       * Get an SDK to access the given stack's environment for environmental lookups
       *
       * Will use a plugin if available, use the default AWS credentials if not.
       * The `mode` parameter is only used for querying plugins.
       *
       * Will assume the lookup role if configured on the stack. Check the default `lookup-role`
       * policies to see what you can do with this role. It can generally read everything
       * in the account that does not require KMS access.
       *
       * ---
       *
       * For backwards compatibility reasons, there are some scenarios that are handled here:
       *
       *  1. The lookup role may not exist (it was added in bootstrap stack version 7). If so:
       *     a. Return the default credentials if the default credentials are for the stack account
       *        (you will notice this as `isFallbackCredentials=true`).
       *     b. Throw an error if the default credentials are not for the stack account.
       *
       *  2. The lookup role may not have the correct permissions (for example, ReadOnlyAccess was added in
       *     bootstrap stack version 8); the stack will have a minimum version number on it.
       *     a. If it does not we throw an error which should be handled in the calling
       *        function (and fallback to use a different role, etc)
       *
       * Upon success, caller will have an SDK for the right account, which may or may not have
       * the right permissions.
       */
      async accessStackForLookup(stack) {
        if (!stack.environment) {
          throw new ToolkitError("StackEnvironmentMissing", `The stack ${stack.displayName} does not have an environment`);
        }
        const lookupEnv = await this.prepareSdk({
          environment: stack.environment,
          mode: 0 /* ForReading */,
          assumeRoleArn: stack.lookupRole?.arn,
          assumeRoleExternalId: stack.lookupRole?.assumeRoleExternalId,
          assumeRoleAdditionalOptions: stack.lookupRole?.assumeRoleAdditionalOptions
        });
        if (lookupEnv.didAssumeRole && stack.lookupRole?.bootstrapStackVersionSsmParameter && stack.lookupRole.requiresBootstrapStackVersion) {
          const version = await lookupEnv.resources.versionFromSsmParameter(stack.lookupRole.bootstrapStackVersionSsmParameter);
          if (version < stack.lookupRole.requiresBootstrapStackVersion) {
            throw new ToolkitError("InsufficientBootstrapStackVersion", `Bootstrap stack version '${stack.lookupRole.requiresBootstrapStackVersion}' is required, found version '${version}'. To get rid of this error, please upgrade to bootstrap version >= ${stack.lookupRole.requiresBootstrapStackVersion}`);
          }
        }
        if (lookupEnv.isFallbackCredentials) {
          const arn = await lookupEnv.replacePlaceholders(stack.lookupRole?.arn);
          await this.ioHelper.defaults.warn(`Lookup role ${arn} was not assumed. Proceeding with default credentials.`);
        }
        return lookupEnv;
      }
      /**
       * Get an SDK to access the given stack's environment for reading stack attributes
       *
       * Will use a plugin if available, use the default AWS credentials if not.
       * The `mode` parameter is only used for querying plugins.
       *
       * Will try to assume the lookup role if given, will use the regular stack operations
       * access (deploy-role) otherwise. When calling this, you should assume that you will get
       * the least privileged role, so don't try to use it for anything the `deploy-role`
       * wouldn't be able to do. Also you cannot rely on being able to read encrypted anything.
       */
      async accessStackForLookupBestEffort(stack) {
        if (!stack.environment) {
          throw new ToolkitError("StackEnvironmentMissing", `The stack ${stack.displayName} does not have an environment`);
        }
        try {
          return await this.accessStackForLookup(stack);
        } catch (e32) {
          await this.ioHelper.defaults.warn(`${formatErrorMessage(e32)}`);
        }
        return this.accessStackForStackOperations(stack, 0 /* ForReading */);
      }
      /**
       * Get an SDK to access the given stack's environment for stack operations
       *
       * Will use a plugin if available, use the default AWS credentials if not.
       * The `mode` parameter is only used for querying plugins.
       *
       * Will assume the deploy role if configured on the stack. Check the default `deploy-role`
       * policies to see what you can do with this role.
       */
      async accessStackForStackOperations(stack, mode) {
        if (!stack.environment) {
          throw new ToolkitError("StackEnvironmentMissing", `The stack ${stack.displayName} does not have an environment`);
        }
        return this.prepareSdk({
          environment: stack.environment,
          mode,
          assumeRoleArn: stack.assumeRoleArn,
          assumeRoleExternalId: stack.assumeRoleExternalId,
          assumeRoleAdditionalOptions: stack.assumeRoleAdditionalOptions
        });
      }
      /**
       * Prepare an SDK for use in the given environment and optionally with a role assumed.
       */
      async prepareSdk(options) {
        const resolvedEnvironment = await this.sdkProvider.resolveEnvironment(options.environment);
        const { assumeRoleArn } = await replaceEnvPlaceholders({
          assumeRoleArn: options.assumeRoleArn
        }, resolvedEnvironment, this.sdkProvider);
        const stackSdk = await this.cachedSdkForEnvironment(resolvedEnvironment, options.mode, {
          assumeRoleArn,
          assumeRoleExternalId: options.assumeRoleExternalId,
          assumeRoleAdditionalOptions: options.assumeRoleAdditionalOptions
        });
        return {
          sdk: stackSdk.sdk,
          resolvedEnvironment,
          resources: this.environmentResources.for(resolvedEnvironment, stackSdk.sdk, this.ioHelper),
          // If we asked for a role, did not successfully assume it, and yet got here without an exception: that
          // means we must have fallback credentials.
          isFallbackCredentials: !stackSdk.didAssumeRole && !!assumeRoleArn,
          didAssumeRole: stackSdk.didAssumeRole,
          replacePlaceholders: /* @__PURE__ */ __name(async (str) => {
            const ret = await replaceEnvPlaceholders({ str }, resolvedEnvironment, this.sdkProvider);
            return ret.str;
          }, "replacePlaceholders")
        };
      }
      async cachedSdkForEnvironment(environment, mode, options) {
        const cacheKeyElements = [
          environment.account,
          environment.region,
          `${mode}`,
          options?.assumeRoleArn ?? "",
          options?.assumeRoleExternalId ?? ""
        ];
        if (options?.assumeRoleAdditionalOptions) {
          cacheKeyElements.push(JSON.stringify(options.assumeRoleAdditionalOptions));
        }
        const cacheKey = cacheKeyElements.join(":");
        const existing = this.sdkCache.get(cacheKey);
        if (existing) {
          return existing;
        }
        const ret = await this.sdkProvider.forEnvironment(environment, mode, options);
        this.sdkCache.set(cacheKey, ret);
        return ret;
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/environment/index.ts
var init_environment2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/environment/index.ts"() {
    "use strict";
    init_environment_access();
    init_environment_resources();
    init_placeholders3();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/deployments/deployments.ts
function suffixWithErrors2(msg, errors) {
  return errors && errors.length > 0 ? `${msg}: ${errors.join(", ")}` : msg;
}
var import_node_crypto7, cdk_assets, chalk12, BOOTSTRAP_STACK_VERSION_FOR_ROLLBACK, Deployments, ParallelSafeAssetProgress;
var init_deployments = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/deployments/deployments.ts"() {
    "use strict";
    import_node_crypto7 = require("node:crypto");
    cdk_assets = __toESM(require_lib5());
    chalk12 = __toESM(require_source());
    init_asset_manifest_builder();
    init_asset_publishing();
    init_cfn_api();
    init_checks();
    init_deploy_stack();
    init_deployment_method();
    init_toolkit_error();
    init_util3();
    init_cloudformation2();
    init_stack_diagnoser();
    init_environment2();
    init_stack_source_tracing();
    init_stack_events();
    init_toolkit_info();
    BOOTSTRAP_STACK_VERSION_FOR_ROLLBACK = 23;
    Deployments = class {
      constructor(props) {
        this.props = props;
        this.assetSdkProvider = props.sdkProvider;
        this.deployStackSdkProvider = props.sdkProvider;
        this.ioHelper = props.ioHelper;
        this.envs = new EnvironmentAccess(
          props.sdkProvider,
          props.toolkitStackName ?? DEFAULT_TOOLKIT_STACK_NAME,
          this.ioHelper
        );
      }
      props;
      static {
        __name(this, "Deployments");
      }
      envs;
      /**
       * SDK provider for asset publishing (do not use for anything else).
       *
       * This SDK provider is only allowed to be used for that purpose, nothing else.
       *
       * It's not a different object, but the field name should imply that this
       * object should not be used directly, except to pass to asset handling routines.
       */
      assetSdkProvider;
      /**
       * SDK provider for passing to deployStack
       *
       * This SDK provider is only allowed to be used for that purpose, nothing else.
       *
       * It's not a different object, but the field name should imply that this
       * object should not be used directly, except to pass to `deployStack`.
       */
      deployStackSdkProvider;
      publisherCache = /* @__PURE__ */ new Map();
      _allowCrossAccountAssetPublishing;
      ioHelper;
      /**
       * Resolves the environment for a stack.
       */
      async resolveEnvironment(stack) {
        return this.envs.resolveStackEnvironment(stack);
      }
      async readCurrentTemplateWithNestedStacks(rootStackArtifact, retrieveProcessedTemplate = false) {
        const env3 = await this.envs.accessStackForLookupBestEffort(rootStackArtifact);
        return loadCurrentTemplateWithNestedStacks(rootStackArtifact, env3.sdk, retrieveProcessedTemplate);
      }
      async readCurrentTemplate(stackArtifact) {
        await this.ioHelper.defaults.debug(`Reading existing template for stack ${stackArtifact.displayName}.`);
        const env3 = await this.envs.accessStackForLookupBestEffort(stackArtifact);
        return loadCurrentTemplate(stackArtifact, env3.sdk);
      }
      async resourceIdentifierSummaries(stackArtifact) {
        await this.ioHelper.defaults.debug(`Retrieving template summary for stack ${stackArtifact.displayName}.`);
        const env3 = await this.envs.accessStackForReadOnlyStackOperations(stackArtifact);
        const cfn = env3.sdk.cloudFormation();
        await uploadStackTemplateAssets(stackArtifact, this);
        const builder = new AssetManifestBuilder();
        const cfnParam = await makeBodyParameter(
          this.ioHelper,
          stackArtifact,
          env3.resolvedEnvironment,
          builder,
          env3.resources
        );
        const addedAssets = builder.toManifest(stackArtifact.assembly.directory);
        for (const entry of addedAssets.entries) {
          await this.buildSingleAsset("no-version-validation", addedAssets, entry, {
            stack: stackArtifact
          });
          await this.publishSingleAsset(addedAssets, entry, {
            stack: stackArtifact
          });
        }
        const response = await cfn.getTemplateSummary(cfnParam);
        if (!response.ResourceIdentifierSummaries) {
          await this.ioHelper.defaults.debug('GetTemplateSummary API call did not return "ResourceIdentifierSummaries"');
        }
        return response.ResourceIdentifierSummaries ?? [];
      }
      async deployStack(options) {
        const env3 = await this.envs.accessStackForMutableStackOperations(options.stack);
        await this.validateBootstrapStackVersion(
          options.stack.stackName,
          options.stack.requiresBootstrapStackVersion,
          options.stack.bootstrapStackVersionSsmParameter,
          env3.resources
        );
        const executionRoleArn = await env3.replacePlaceholders(options.roleArn ?? options.stack.cloudFormationExecutionRoleArn);
        return deployStack({
          stack: options.stack,
          resolvedEnvironment: env3.resolvedEnvironment,
          deployName: options.deployName,
          notificationArns: options.notificationArns,
          sdk: env3.sdk,
          sdkProvider: this.deployStackSdkProvider,
          roleArn: executionRoleArn,
          reuseAssets: options.reuseAssets,
          envResources: env3.resources,
          tags: options.tags,
          deploymentMethod: options.deploymentMethod,
          forceDeployment: options.forceDeployment,
          parameters: options.parameters,
          usePreviousParameters: options.usePreviousParameters,
          rollback: options.rollback,
          extraUserAgent: options.extraUserAgent,
          resourcesToImport: options.resourcesToImport,
          overrideTemplate: options.overrideTemplate,
          assetParallelism: options.assetParallelism,
          diagnoser: new CloudFormationStackDiagnoser({
            sdk: env3.sdk,
            envResources: env3.resources,
            sourceTracer: new StackArtifactSourceTracer(options.stack),
            ioHelper: this.ioHelper,
            topLevelStackHierarchicalId: options.stack.hierarchicalId,
            additionalExplorationSdkProvider: /* @__PURE__ */ __name(async () => (await this.envs.accessStackForLookupBestEffort(options.stack)).sdk, "additionalExplorationSdkProvider")
          })
        }, this.ioHelper);
      }
      /**
       * Create a change set for a stack without executing it.
       *
       * Returns the result if the change set was successfully created, or undefined
       * if the prepare returned a non-success result (e.g. rollback needed).
       */
      async prepareStack(options) {
        const result2 = await this.deployStack({
          ...options,
          deploymentMethod: { ...options.deploymentMethod, execute: false }
        });
        if (result2.type !== "did-deploy-stack") {
          return void 0;
        }
        if (result2.noOp && options.cleanupOnNoOp) {
          const changeSetName = options.deploymentMethod.changeSetName ?? DEFAULT_DEPLOY_CHANGE_SET_NAME;
          await this.cleanupChangeSet(options.stack, changeSetName);
        }
        return result2;
      }
      /**
       * Clean up a change set that was created by prepareStack but never executed.
       * If the stack was created in REVIEW_IN_PROGRESS state (new stack), delete the stack too.
       */
      async cleanupChangeSet(stack, changeSetName) {
        const env3 = await this.envs.accessStackForMutableStackOperations(stack);
        const cfn = env3.sdk.cloudFormation();
        const deployName = stack.stackName;
        const cloudFormationStack = await CloudFormationStack.lookup(cfn, deployName);
        if (!cloudFormationStack.exists) {
          return;
        }
        await cfn.deleteChangeSet({ StackName: deployName, ChangeSetName: changeSetName });
        if (cloudFormationStack.stackStatus.name === "REVIEW_IN_PROGRESS") {
          await cfn.deleteStack({ StackName: deployName, ClientRequestToken: (0, import_node_crypto7.randomUUID)() });
          await waitForStackDelete(cfn, this.ioHelper, deployName);
        }
      }
      /**
       * Describe a specific change set for a stack.
       *
       * @param stack - The Stack artifact
       * @param changeSetName - The name of the change set
       * @param stackArn - Optional the exact arn of the stack. Prefer this if you have it available.
       * @returns the DescribeChangeSet response
       */
      async describeChangeSet(stack, changeSetName, stackArn) {
        const env3 = await this.envs.accessStackForMutableStackOperations(stack);
        const cfn = env3.sdk.cloudFormation();
        return waitForChangeSet(cfn, this.ioHelper, stackArn ?? stack.stackName, changeSetName, {
          fetchAll: true,
          diagnoser: new CloudFormationStackDiagnoser({
            sdk: env3.sdk,
            envResources: env3.resources,
            sourceTracer: new StackArtifactSourceTracer(stack),
            ioHelper: this.ioHelper,
            topLevelStackHierarchicalId: stack.hierarchicalId,
            additionalExplorationSdkProvider: /* @__PURE__ */ __name(async () => (await this.envs.accessStackForLookupBestEffort(stack)).sdk, "additionalExplorationSdkProvider")
          })
        });
      }
      async rollbackStack(options) {
        let resourcesToSkip = options.orphanLogicalIds ?? [];
        if (options.orphanFailedResources && resourcesToSkip.length > 0) {
          throw new ToolkitError("ConflictingRollbackOptions", "Cannot combine --force with --orphan");
        }
        const env3 = await this.envs.accessStackForMutableStackOperations(options.stack);
        if (options.validateBootstrapStackVersion ?? true) {
          await this.validateBootstrapStackVersion(
            options.stack.stackName,
            BOOTSTRAP_STACK_VERSION_FOR_ROLLBACK,
            options.stack.bootstrapStackVersionSsmParameter,
            env3.resources
          );
        }
        const cfn = env3.sdk.cloudFormation();
        const deployName = options.stack.stackName;
        let maxLoops = 10;
        while (maxLoops--) {
          const cloudFormationStack = await CloudFormationStack.lookup(cfn, deployName);
          const stackArn = cloudFormationStack.stackId;
          const executionRoleArn = await env3.replacePlaceholders(options.roleArn ?? options.stack.cloudFormationExecutionRoleArn);
          switch (cloudFormationStack.stackStatus.rollbackChoice) {
            case 3 /* NONE */:
              await this.ioHelper.defaults.warn(`Stack ${deployName} does not need a rollback: ${cloudFormationStack.stackStatus}`);
              return { stackArn, notInRollbackableState: true };
            case 0 /* START_ROLLBACK */:
              await this.ioHelper.defaults.debug(`Initiating rollback of stack ${deployName}`);
              await cfn.rollbackStack({
                StackName: stackArn,
                RoleARN: executionRoleArn,
                ClientRequestToken: (0, import_node_crypto7.randomUUID)(),
                // Enabling this is just the better overall default, the only reason it isn't the upstream default is backwards compatibility
                RetainExceptOnCreate: true
              });
              break;
            case 1 /* CONTINUE_UPDATE_ROLLBACK */:
              if (options.orphanFailedResources) {
                const poller = new StackEventPoller(cfn, {
                  stackArn,
                  initialPollRange: PollRange.sinceStackStatus(["ROLLBACK_IN_PROGRESS", "UPDATE_ROLLBACK_IN_PROGRESS"])
                });
                await poller.poll();
                resourcesToSkip = poller.resourceErrors.filter((r32) => r32.parentStackLogicalIds.length === 0).map((r32) => r32.logicalId).filter((id) => typeof id === "string");
              }
              const skipDescription = resourcesToSkip.length > 0 ? ` (orphaning: ${resourcesToSkip.join(", ")})` : "";
              await this.ioHelper.defaults.warn(`Continuing rollback of stack ${deployName}${skipDescription}`);
              await cfn.continueUpdateRollback({
                StackName: stackArn,
                ClientRequestToken: (0, import_node_crypto7.randomUUID)(),
                RoleARN: executionRoleArn,
                ResourcesToSkip: resourcesToSkip
              });
              break;
            case 2 /* ROLLBACK_FAILED */:
              await this.ioHelper.defaults.warn(
                `Stack ${deployName} failed creation and rollback. This state cannot be rolled back. You can recreate this stack by running 'cdk deploy'.`
              );
              return { stackArn, notInRollbackableState: true };
            default:
              throw new ToolkitError("UnexpectedRollbackChoice", `Unexpected rollback choice: ${cloudFormationStack.stackStatus.rollbackChoice}`);
          }
          const monitor = new StackActivityMonitor({
            cfn,
            stack: options.stack,
            stackArn,
            ioHelper: this.ioHelper
          });
          await monitor.start();
          let stackErrorMessage = void 0;
          let finalStackState = cloudFormationStack;
          try {
            const successStack = await stabilizeStack(cfn, this.ioHelper, deployName);
            if (!successStack) {
              throw new ToolkitError("StackDisappeared", "Stack deploy failed (the stack disappeared while we were rolling it back)");
            }
            finalStackState = successStack;
            const errors = monitor.errors.allErrorMessages.join(", ");
            if (errors) {
              stackErrorMessage = errors;
            }
          } catch (e32) {
            stackErrorMessage = suffixWithErrors2(formatErrorMessage(e32), monitor.errors.allErrorMessages);
          } finally {
            await monitor.stop();
          }
          if (finalStackState.stackStatus.isRollbackSuccess || !stackErrorMessage) {
            return { stackArn, success: true };
          }
          if (finalStackState.stackStatus.rollbackChoice === 1 /* CONTINUE_UPDATE_ROLLBACK */ && options.orphanFailedResources) {
            continue;
          }
          throw new DeploymentError(
            `${stackErrorMessage} (fix problem and retry, or orphan these resources using --orphan or --force)`,
            monitor.errors.rootCauseErrorCode ?? "RollbackFailed"
          );
        }
        throw new ToolkitError(
          "RollbackStalled",
          "Rollback did not finish after a large number of iterations; stopping because it looks like we're not making progress anymore. You can retry if rollback was progressing as expected."
        );
      }
      async destroyStack(options) {
        const env3 = await this.envs.accessStackForMutableStackOperations(options.stack);
        const executionRoleArn = await env3.replacePlaceholders(options.roleArn ?? options.stack.cloudFormationExecutionRoleArn);
        return destroyStack({
          sdk: env3.sdk,
          roleArn: executionRoleArn,
          stack: options.stack,
          deployName: options.deployName
        }, this.ioHelper);
      }
      async stackExists(options) {
        let env3;
        if (options.tryLookupRole) {
          env3 = await this.envs.accessStackForLookupBestEffort(options.stack);
        } else {
          env3 = await this.envs.accessStackForReadOnlyStackOperations(options.stack);
        }
        const stack = await CloudFormationStack.lookup(env3.sdk.cloudFormation(), options.deployName ?? options.stack.stackName);
        return stack.exists;
      }
      /**
       * Build a single asset from an asset manifest
       *
       * If an assert manifest artifact is given, the bootstrap stack version
       * will be validated according to the constraints in that manifest artifact.
       * If that is not necessary, `'no-version-validation'` can be passed.
       */
      // eslint-disable-next-line @stylistic/max-len
      async buildSingleAsset(assetArtifact, assetManifest, asset, options) {
        if (assetArtifact !== "no-version-validation") {
          const env3 = await this.envs.accessStackForReadOnlyStackOperations(options.stack);
          await this.validateBootstrapStackVersion(
            options.stack.stackName,
            assetArtifact.requiresBootstrapStackVersion,
            assetArtifact.bootstrapStackVersionSsmParameter,
            env3.resources
          );
        }
        const resolvedEnvironment = await this.envs.resolveStackEnvironment(options.stack);
        const publisher = this.cachedPublisher(assetManifest, resolvedEnvironment, options.stackName);
        await publisher.buildEntry(asset);
        if (publisher.hasFailures) {
          throw new ToolkitError("AssetBuildFailed", `Failed to build asset ${asset.displayName(false)}`);
        }
      }
      /**
       * Publish a single asset from an asset manifest
       */
      async publishSingleAsset(assetManifest, asset, options) {
        const stackEnv = await this.envs.resolveStackEnvironment(options.stack);
        const publisher = this.cachedPublisher(assetManifest, stackEnv, options.stackName);
        await publisher.publishEntry(asset, {
          allowCrossAccount: await this.allowCrossAccountAssetPublishingForEnv(options.stack),
          force: options.forcePublish
        });
        if (publisher.hasFailures) {
          throw ToolkitError.withCause("AssetPublishFailed", `Failed to publish asset ${asset.displayName(true)}`, new AggregateError(publisher.failures.map((f32) => f32.error)));
        }
      }
      async allowCrossAccountAssetPublishingForEnv(stack) {
        if (this._allowCrossAccountAssetPublishing === void 0) {
          const env3 = await this.envs.accessStackForReadOnlyStackOperations(stack);
          this._allowCrossAccountAssetPublishing = await determineAllowCrossAccountAssetPublishing(env3.sdk, this.ioHelper, this.props.toolkitStackName);
        }
        return this._allowCrossAccountAssetPublishing;
      }
      /**
       * Return whether a single asset has been published already
       */
      async isSingleAssetPublished(assetManifest, asset, options) {
        const stackEnv = await this.envs.resolveStackEnvironment(options.stack);
        const publisher = this.cachedPublisher(assetManifest, stackEnv, options.stackName);
        return publisher.isEntryPublished(asset);
      }
      /**
       * Validate that the bootstrap stack has the right version for this stack
       *
       * Call into envResources.validateVersion, but prepend the stack name in case of failure.
       */
      async validateBootstrapStackVersion(stackName, requiresBootstrapStackVersion, bootstrapStackVersionSsmParameter, envResources) {
        try {
          await envResources.validateVersion(requiresBootstrapStackVersion, bootstrapStackVersionSsmParameter);
        } catch (e32) {
          throw new ToolkitError("BootstrapVersionValidation", `${stackName}: ${formatErrorMessage(e32)}`);
        }
      }
      cachedPublisher(assetManifest, env3, stackName) {
        const existing = this.publisherCache.get(assetManifest);
        if (existing) {
          return existing;
        }
        const prefix = stackName ? `${chalk12.bold(stackName)}: ` : "";
        const publisher = new cdk_assets.AssetPublishing(assetManifest, {
          // The AssetPublishing class takes care of role assuming etc, so it's okay to
          // give it a direct `SdkProvider`.
          aws: new PublishingAws(this.assetSdkProvider, env3),
          progressListener: new ParallelSafeAssetProgress(prefix, this.ioHelper)
        });
        this.publisherCache.set(assetManifest, publisher);
        return publisher;
      }
    };
    ParallelSafeAssetProgress = class extends BasePublishProgressListener {
      static {
        __name(this, "ParallelSafeAssetProgress");
      }
      prefix;
      constructor(prefix, ioHelper) {
        super(ioHelper);
        this.prefix = prefix;
      }
      getMessage(type, event) {
        return `${this.prefix}${type}: ${event.message}`;
      }
    };
    __name(suffixWithErrors2, "suffixWithErrors");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/deployments/deployment-result.ts
function assertIsSuccessfulDeployStackResult(x) {
  if (x.type !== "did-deploy-stack") {
    throw new ToolkitError("UnexpectedDeployResult", `Unexpected deployStack result. This should not happen: ${JSON.stringify(x)}. If you are seeing this error, please report it at https://github.com/aws/aws-cdk/issues/new/choose.`);
  }
}
var init_deployment_result = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/deployments/deployment-result.ts"() {
    "use strict";
    init_toolkit_error();
    __name(assertIsSuccessfulDeployStackResult, "assertIsSuccessfulDeployStackResult");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/deployments/index.ts
var init_deployments2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/deployments/index.ts"() {
    "use strict";
    init_deployments();
    init_deployment_result();
    init_checks();
    init_assets3();
    init_asset_manifest_builder();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/source-tracing/private/source-tracing.ts
var NO_SOURCE_TRACE;
var init_source_tracing = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/source-tracing/private/source-tracing.ts"() {
    "use strict";
    NO_SOURCE_TRACE = {
      traceResource: /* @__PURE__ */ __name(() => Promise.resolve(void 0), "traceResource"),
      traceStack: /* @__PURE__ */ __name(() => Promise.resolve(void 0), "traceStack")
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/bootstrap/deploy-bootstrap.ts
function bootstrapVersionFromTemplate(template) {
  const versionSources = [
    template.Outputs?.[BOOTSTRAP_VERSION_OUTPUT]?.Value,
    template.Resources?.[BOOTSTRAP_VERSION_RESOURCE]?.Properties?.Value
  ];
  for (const vs of versionSources) {
    if (typeof vs === "number") {
      return vs;
    }
    if (typeof vs === "string" && !isNaN(parseInt(vs, 10))) {
      return parseInt(vs, 10);
    }
  }
  return 0;
}
function bootstrapVariantFromTemplate(template) {
  return template.Parameters?.[BOOTSTRAP_VARIANT_PARAMETER]?.Default ?? DEFAULT_BOOTSTRAP_VARIANT;
}
var os6, path22, import_cloud_assembly_api6, import_cloud_assembly_schema4, fs21, BootstrapStack;
var init_deploy_bootstrap = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/bootstrap/deploy-bootstrap.ts"() {
    "use strict";
    os6 = __toESM(require("os"));
    path22 = __toESM(require("path"));
    import_cloud_assembly_api6 = __toESM(require_lib3());
    import_cloud_assembly_schema4 = __toESM(require_lib2());
    fs21 = __toESM(require_lib4());
    init_bootstrap_props();
    init_deployments2();
    init_deploy_stack();
    init_stack_diagnoser();
    init_environment2();
    init_plugin2();
    init_source_tracing();
    init_toolkit_info();
    BootstrapStack = class _BootstrapStack {
      constructor(sdkProvider, sdk, resolvedEnvironment, toolkitStackName, currentToolkitInfo, ioHelper) {
        this.sdkProvider = sdkProvider;
        this.sdk = sdk;
        this.resolvedEnvironment = resolvedEnvironment;
        this.toolkitStackName = toolkitStackName;
        this.currentToolkitInfo = currentToolkitInfo;
        this.ioHelper = ioHelper;
      }
      sdkProvider;
      sdk;
      resolvedEnvironment;
      toolkitStackName;
      currentToolkitInfo;
      ioHelper;
      static {
        __name(this, "BootstrapStack");
      }
      static async lookup(sdkProvider, environment, toolkitStackName, ioHelper) {
        toolkitStackName = toolkitStackName ?? DEFAULT_TOOLKIT_STACK_NAME;
        const resolvedEnvironment = await sdkProvider.resolveEnvironment(environment);
        const sdk = (await sdkProvider.forEnvironment(resolvedEnvironment, 1 /* ForWriting */)).sdk;
        const currentToolkitInfo = await ToolkitInfo.lookup(resolvedEnvironment, sdk, ioHelper, toolkitStackName);
        return new _BootstrapStack(sdkProvider, sdk, resolvedEnvironment, toolkitStackName, currentToolkitInfo, ioHelper);
      }
      get parameters() {
        return this.currentToolkitInfo.found ? this.currentToolkitInfo.bootstrapStack.parameters : {};
      }
      get terminationProtection() {
        return this.currentToolkitInfo.found ? this.currentToolkitInfo.bootstrapStack.terminationProtection : void 0;
      }
      async partition() {
        return (await this.sdk.currentAccount()).partition;
      }
      /**
       * Perform the actual deployment of a bootstrap stack, given a template and some parameters
       */
      async update(template, parameters, options) {
        if (this.currentToolkitInfo.found && !options.forceDeployment) {
          const abortResponse = {
            type: "did-deploy-stack",
            noOp: true,
            outputs: {},
            stackArn: this.currentToolkitInfo.bootstrapStack.stackId,
            deleteFailures: []
          };
          const currentVariant = this.currentToolkitInfo.variant;
          const newVariant = bootstrapVariantFromTemplate(template);
          if (currentVariant !== newVariant) {
            await this.ioHelper.defaults.warn(
              `Bootstrap stack already exists, containing '${currentVariant}'. Not overwriting it with a template containing '${newVariant}' (use --force if you intend to overwrite)`
            );
            return abortResponse;
          }
          const newVersion = bootstrapVersionFromTemplate(template);
          const currentVersion = this.currentToolkitInfo.version;
          if (newVersion < currentVersion) {
            await this.ioHelper.defaults.warn(
              `Bootstrap stack already at version ${currentVersion}. Not downgrading it to version ${newVersion} (use --force if you intend to downgrade)`
            );
            if (newVersion === 0) {
              await this.ioHelper.defaults.warn(
                "(Did you set the '@aws-cdk/core:newStyleStackSynthesis' feature flag in cdk.json?)"
              );
            }
            return abortResponse;
          }
        }
        const outdir = await fs21.mkdtemp(path22.join(os6.tmpdir(), "cdk-bootstrap"));
        try {
          const builder = new import_cloud_assembly_api6.CloudAssemblyBuilder(outdir);
          const templateFile = `${this.toolkitStackName}.template.json`;
          await fs21.writeJson(path22.join(builder.outdir, templateFile), template, {
            spaces: 2
          });
          builder.addArtifact(this.toolkitStackName, {
            type: import_cloud_assembly_schema4.ArtifactType.AWS_CLOUDFORMATION_STACK,
            environment: import_cloud_assembly_api6.EnvironmentUtils.format(this.resolvedEnvironment.account, this.resolvedEnvironment.region),
            properties: {
              templateFile,
              terminationProtection: options.terminationProtection ?? false
            }
          });
          const assembly = builder.buildAssembly();
          const ret = await deployStack({
            stack: assembly.getStackByName(this.toolkitStackName),
            resolvedEnvironment: this.resolvedEnvironment,
            sdk: this.sdk,
            sdkProvider: this.sdkProvider,
            forceDeployment: options.forceDeployment,
            roleArn: options.roleArn,
            tags: options.tags,
            deploymentMethod: {
              method: "change-set",
              execute: options.execute,
              importExistingResources: options.importExistingResources ?? true
            },
            parameters,
            usePreviousParameters: options.usePreviousParameters ?? true,
            // Obviously we can't need a bootstrap stack to deploy a bootstrap stack
            envResources: new NoBootstrapStackEnvironmentResources(this.resolvedEnvironment, this.sdk, this.ioHelper),
            diagnoser: new CloudFormationStackDiagnoser({
              sdk: this.sdk,
              sourceTracer: NO_SOURCE_TRACE,
              ioHelper: this.ioHelper,
              topLevelStackHierarchicalId: this.toolkitStackName
            })
          }, this.ioHelper);
          assertIsSuccessfulDeployStackResult(ret);
          return ret;
        } finally {
          await fs21.rm(outdir, { recursive: true, force: true });
        }
      }
    };
    __name(bootstrapVersionFromTemplate, "bootstrapVersionFromTemplate");
    __name(bootstrapVariantFromTemplate, "bootstrapVariantFromTemplate");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/bootstrap/legacy-template.ts
function legacyBootstrapTemplate(params) {
  return {
    Description: "The CDK Toolkit Stack. It was created by `cdk bootstrap` and manages resources necessary for managing your Cloud Applications with AWS CDK.",
    Conditions: {
      UsePublicAccessBlockConfiguration: {
        "Fn::Equals": [
          params.publicAccessBlockConfiguration || params.publicAccessBlockConfiguration === void 0 ? "true" : "false",
          "true"
        ]
      }
    },
    Resources: {
      StagingBucket: {
        Type: "AWS::S3::Bucket",
        Properties: {
          BucketName: params.bucketName,
          AccessControl: "Private",
          BucketEncryption: {
            ServerSideEncryptionConfiguration: [{
              ServerSideEncryptionByDefault: {
                SSEAlgorithm: "aws:kms",
                KMSMasterKeyID: params.kmsKeyId
              }
            }]
          },
          PublicAccessBlockConfiguration: {
            "Fn::If": [
              "UsePublicAccessBlockConfiguration",
              {
                BlockPublicAcls: true,
                BlockPublicPolicy: true,
                IgnorePublicAcls: true,
                RestrictPublicBuckets: true
              },
              { Ref: "AWS::NoValue" }
            ]
          }
        }
      },
      StagingBucketPolicy: {
        Type: "AWS::S3::BucketPolicy",
        Properties: {
          Bucket: { Ref: "StagingBucket" },
          PolicyDocument: {
            Id: "AccessControl",
            Version: "2012-10-17",
            Statement: [
              {
                Sid: "AllowSSLRequestsOnly",
                Action: "s3:*",
                Effect: "Deny",
                Resource: [
                  { "Fn::Sub": "${StagingBucket.Arn}" },
                  { "Fn::Sub": "${StagingBucket.Arn}/*" }
                ],
                Condition: {
                  Bool: { "aws:SecureTransport": "false" }
                },
                Principal: "*"
              }
            ]
          }
        }
      }
    },
    Outputs: {
      [BUCKET_NAME_OUTPUT]: {
        Description: "The name of the S3 bucket owned by the CDK toolkit stack",
        Value: { Ref: "StagingBucket" }
      },
      [BUCKET_DOMAIN_NAME_OUTPUT]: {
        Description: "The domain name of the S3 bucket owned by the CDK toolkit stack",
        Value: { "Fn::GetAtt": ["StagingBucket", "RegionalDomainName"] }
      }
    }
  };
}
var init_legacy_template = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/bootstrap/legacy-template.ts"() {
    "use strict";
    init_bootstrap_props();
    __name(legacyBootstrapTemplate, "legacyBootstrapTemplate");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/bootstrap/bootstrap-environment.ts
function splitCfnArray(xs) {
  if (xs === "" || xs === void 0) {
    return [];
  }
  return xs.split(",");
}
function intersection(xs, ys) {
  return new Set(Array.from(xs).filter((x) => ys.has(x)));
}
var path23, Bootstrapper, USE_AWS_MANAGED_KEY, CREATE_NEW_KEY, CDK_BOOTSTRAP_PERMISSIONS_BOUNDARY;
var init_bootstrap_environment = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/bootstrap/bootstrap-environment.ts"() {
    "use strict";
    path23 = __toESM(require("path"));
    init_deploy_bootstrap();
    init_legacy_template();
    init_toolkit_error();
    init_util3();
    init_plugin2();
    init_toolkit_info();
    Bootstrapper = class {
      constructor(source = { source: "default" }, ioHelper) {
        this.source = source;
        this.ioHelper = ioHelper;
      }
      source;
      static {
        __name(this, "Bootstrapper");
      }
      ioHelper;
      bootstrapEnvironment(environment, sdkProvider, options = {}) {
        switch (this.source.source) {
          case "legacy":
            return this.legacyBootstrap(environment, sdkProvider, options);
          case "default":
            return this.modernBootstrap(environment, sdkProvider, options);
          case "custom":
            return this.customBootstrap(environment, sdkProvider, options);
        }
      }
      async showTemplate(json) {
        const template = await this.loadTemplate();
        process.stdout.write(`${serializeStructure(template, json)}
`);
      }
      /**
       * Deploy legacy bootstrap stack
       *
       */
      async legacyBootstrap(environment, sdkProvider, options) {
        const params = options.parameters ?? {};
        if (params.trustedAccounts?.length) {
          throw new ToolkitError("TrustRequiresModernBootstrap", "--trust can only be passed for the modern bootstrap experience.");
        }
        if (params.cloudFormationExecutionPolicies?.length) {
          throw new ToolkitError("ExecutionPoliciesRequiresModernBootstrap", "--cloudformation-execution-policies can only be passed for the modern bootstrap experience.");
        }
        if (params.createCustomerMasterKey !== void 0) {
          throw new ToolkitError("CustomerKeyRequiresModernBootstrap", "--bootstrap-customer-key can only be passed for the modern bootstrap experience.");
        }
        if (params.qualifier) {
          throw new ToolkitError("QualifierRequiresModernBootstrap", "--qualifier can only be passed for the modern bootstrap experience.");
        }
        const toolkitStackName = options.toolkitStackName ?? DEFAULT_TOOLKIT_STACK_NAME;
        const current = await BootstrapStack.lookup(sdkProvider, environment, toolkitStackName, this.ioHelper);
        return current.update(
          await this.loadTemplate(params),
          {},
          {
            ...options,
            terminationProtection: options.terminationProtection ?? current.terminationProtection
          }
        );
      }
      /**
       * Deploy CI/CD-ready bootstrap stack from template
       *
       */
      async modernBootstrap(environment, sdkProvider, options) {
        const params = options.parameters ?? {};
        const bootstrapTemplate = await this.loadTemplate();
        const toolkitStackName = options.toolkitStackName ?? DEFAULT_TOOLKIT_STACK_NAME;
        const current = await BootstrapStack.lookup(sdkProvider, environment, toolkitStackName, this.ioHelper);
        const partition4 = await current.partition();
        if (params.createCustomerMasterKey !== void 0 && params.kmsKeyId) {
          throw new ToolkitError(
            "ConflictingKmsKeyOptions",
            "You cannot pass '--bootstrap-kms-key-id' and '--bootstrap-customer-key' together. Specify one or the other"
          );
        }
        const allTrusted = /* @__PURE__ */ new Set([
          ...params.trustedAccounts ?? [],
          ...params.trustedAccountsForLookup ?? []
        ]);
        const invalid = intersection(allTrusted, new Set(params.untrustedAccounts));
        if (invalid.size > 0) {
          throw new ToolkitError("AccountBothTrustedAndUntrusted", `Accounts cannot be both trusted and untrusted. Found: ${[...invalid].join(",")}`);
        }
        const removeUntrusted = /* @__PURE__ */ __name((accounts) => accounts.filter((acc) => !params.untrustedAccounts?.map(String).includes(String(acc))), "removeUntrusted");
        const trustedAccounts = removeUntrusted(params.trustedAccounts ?? splitCfnArray(current.parameters.TrustedAccounts));
        await this.ioHelper.defaults.info(
          `Trusted accounts for deployment: ${trustedAccounts.length > 0 ? trustedAccounts.join(", ") : "(none)"}`
        );
        const trustedAccountsForLookup = removeUntrusted(
          params.trustedAccountsForLookup ?? splitCfnArray(current.parameters.TrustedAccountsForLookup)
        );
        await this.ioHelper.defaults.info(
          `Trusted accounts for lookup: ${trustedAccountsForLookup.length > 0 ? trustedAccountsForLookup.join(", ") : "(none)"}`
        );
        const cloudFormationExecutionPolicies = params.cloudFormationExecutionPolicies ?? splitCfnArray(current.parameters.CloudFormationExecutionPolicies);
        if (trustedAccounts.length === 0 && cloudFormationExecutionPolicies.length === 0) {
          const implicitPolicy = `arn:${partition4}:iam::aws:policy/AdministratorAccess`;
          await this.ioHelper.defaults.warn(
            `Using default execution policy of '${implicitPolicy}'. Pass '--cloudformation-execution-policies' to customize.`
          );
        } else if (cloudFormationExecutionPolicies.length === 0) {
          throw new ToolkitError(
            "MissingExecutionPoliciesForTrust",
            `Please pass '--cloudformation-execution-policies' when using '--trust' to specify deployment permissions. Try a managed policy of the form 'arn:${partition4}:iam::aws:policy/<PolicyName>'.`
          );
        } else {
          await this.ioHelper.defaults.info(`Execution policies: ${cloudFormationExecutionPolicies.join(", ")}`);
        }
        const currentKmsKeyId = current.parameters.FileAssetsBucketKmsKeyId;
        const kmsKeyId = params.kmsKeyId ?? (params.createCustomerMasterKey === true ? CREATE_NEW_KEY : params.createCustomerMasterKey === false || currentKmsKeyId === void 0 ? USE_AWS_MANAGED_KEY : void 0);
        const currentPermissionsBoundary = current.parameters.InputPermissionsBoundary || void 0;
        const inputPolicyName = params.examplePermissionsBoundary ? CDK_BOOTSTRAP_PERMISSIONS_BOUNDARY : params.customPermissionsBoundary;
        let policyName;
        if (inputPolicyName) {
          const sdk = (await sdkProvider.forEnvironment(environment, 1 /* ForWriting */)).sdk;
          policyName = await this.getPolicyName(environment, sdk, inputPolicyName, partition4, params);
        }
        if (currentPermissionsBoundary !== policyName) {
          if (!currentPermissionsBoundary) {
            await this.ioHelper.defaults.warn(
              `Adding new permissions boundary ${policyName}`
            );
          } else if (!policyName) {
            await this.ioHelper.defaults.warn(
              `Removing existing permissions boundary ${currentPermissionsBoundary}`
            );
          } else {
            await this.ioHelper.defaults.warn(
              `Changing permissions boundary from ${currentPermissionsBoundary} to ${policyName}`
            );
          }
        }
        const bootstrapTemplateParameters = {
          FileAssetsBucketName: params.bucketName,
          FileAssetsBucketKmsKeyId: kmsKeyId,
          // Empty array becomes empty string
          TrustedAccounts: trustedAccounts.join(","),
          TrustedAccountsForLookup: trustedAccountsForLookup.join(","),
          CloudFormationExecutionPolicies: cloudFormationExecutionPolicies.join(","),
          Qualifier: params.qualifier,
          PublicAccessBlockConfiguration: params.publicAccessBlockConfiguration || params.publicAccessBlockConfiguration === void 0 ? "true" : "false",
          InputPermissionsBoundary: policyName
        };
        const templateParameters = await this.templateParameters();
        if (params.denyExternalId !== void 0) {
          if (!templateParameters.includes("DenyExternalId")) {
            throw new ToolkitError("DenyExternalIdNotSupported", "The selected bootstrap template does not accept the DenyExternalId parameter");
          }
          bootstrapTemplateParameters.DenyExternalId = `${params.denyExternalId}`;
        }
        return current.update(bootstrapTemplate, bootstrapTemplateParameters, {
          ...options,
          terminationProtection: options.terminationProtection ?? current.terminationProtection
        });
      }
      async getPolicyName(environment, sdk, permissionsBoundary, partition4, params) {
        if (permissionsBoundary !== CDK_BOOTSTRAP_PERMISSIONS_BOUNDARY) {
          this.validatePolicyName(permissionsBoundary);
          return Promise.resolve(permissionsBoundary);
        }
        const arn = await this.getExamplePermissionsBoundary(
          params.qualifier ?? "hnb659fds",
          partition4,
          environment.account,
          sdk
        );
        const policyName = arn.split("/").pop();
        if (!policyName) {
          throw new ToolkitError("PermissionBoundaryRetrievalFailed", "Could not retrieve the example permission boundary!");
        }
        return Promise.resolve(policyName);
      }
      async getExamplePermissionsBoundary(qualifier, partition4, account, sdk) {
        const iam = sdk.iam();
        let policyName = `cdk-${qualifier}-permissions-boundary`;
        const arn = `arn:${partition4}:iam::${account}:policy/${policyName}`;
        try {
          let getPolicyResp = await iam.getPolicy({ PolicyArn: arn });
          if (getPolicyResp.Policy) {
            return arn;
          }
        } catch (e32) {
          if (e32.name === "NoSuchEntity") {
          } else {
            throw e32;
          }
        }
        const policyDoc = {
          Version: "2012-10-17",
          Statement: [
            {
              Action: ["*"],
              Resource: "*",
              Effect: "Allow",
              Sid: "ExplicitAllowAll"
            },
            {
              Condition: {
                StringEquals: {
                  "iam:PermissionsBoundary": `arn:${partition4}:iam::${account}:policy/cdk-${qualifier}-permissions-boundary`
                }
              },
              Action: [
                "iam:CreateUser",
                "iam:CreateRole",
                "iam:PutRolePermissionsBoundary",
                "iam:PutUserPermissionsBoundary"
              ],
              Resource: "*",
              Effect: "Allow",
              Sid: "DenyAccessIfRequiredPermBoundaryIsNotBeingApplied"
            },
            {
              Action: [
                "iam:CreatePolicyVersion",
                "iam:DeletePolicy",
                "iam:DeletePolicyVersion",
                "iam:SetDefaultPolicyVersion"
              ],
              Resource: `arn:${partition4}:iam::${account}:policy/cdk-${qualifier}-permissions-boundary`,
              Effect: "Deny",
              Sid: "DenyPermBoundaryIAMPolicyAlteration"
            },
            {
              Action: ["iam:DeleteUserPermissionsBoundary", "iam:DeleteRolePermissionsBoundary"],
              Resource: "*",
              Effect: "Deny",
              Sid: "DenyRemovalOfPermBoundaryFromAnyUserOrRole"
            }
          ]
        };
        const request4 = {
          PolicyName: policyName,
          PolicyDocument: JSON.stringify(policyDoc)
        };
        const createPolicyResponse = await iam.createPolicy(request4);
        if (createPolicyResponse.Policy?.Arn) {
          return createPolicyResponse.Policy.Arn;
        } else {
          throw new ToolkitError("PermissionBoundaryCreateFailed", `Could not retrieve the example permission boundary ${arn}!`);
        }
      }
      validatePolicyName(permissionsBoundary) {
        const regexp = /[\w+\/=,.@-]+/;
        const matches = regexp.exec(permissionsBoundary);
        if (!(matches && matches.length === 1 && matches[0] === permissionsBoundary)) {
          throw new ToolkitError("InvalidPermissionBoundaryName", `The permissions boundary name ${permissionsBoundary} does not match the IAM conventions.`);
        }
      }
      async customBootstrap(environment, sdkProvider, options) {
        const version = bootstrapVersionFromTemplate(await this.loadTemplate());
        if (version === 0) {
          return this.legacyBootstrap(environment, sdkProvider, options);
        } else {
          return this.modernBootstrap(environment, sdkProvider, options);
        }
      }
      /**
       * Return the set of parameter names accepted by the current bootstrapping template
       */
      async templateParameters(legacyParams = {}) {
        const template = await this.loadTemplate(legacyParams);
        return Object.keys(template.Parameters ?? {});
      }
      async loadTemplate(legacyParams = {}) {
        switch (this.source.source) {
          case "custom":
            return loadStructuredFile(this.source.templateFile);
          case "default":
            return loadStructuredFile(path23.join(bundledPackageRootDir(__dirname), "lib", "api", "bootstrap", "bootstrap-template.yaml"));
          case "legacy":
            return legacyBootstrapTemplate(legacyParams);
        }
      }
    };
    USE_AWS_MANAGED_KEY = "AWS_MANAGED_KEY";
    CREATE_NEW_KEY = "";
    CDK_BOOTSTRAP_PERMISSIONS_BOUNDARY = "CDK_BOOTSTRAP_PERMISSIONS_BOUNDARY";
    __name(splitCfnArray, "splitCfnArray");
    __name(intersection, "intersection");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/bootstrap/index.ts
var init_bootstrap2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/bootstrap/index.ts"() {
    "use strict";
    init_bootstrap_environment();
    init_bootstrap_props();
    init_legacy_template();
  }
});

// lib/api/bootstrap.ts
var init_bootstrap3 = __esm({
  "lib/api/bootstrap.ts"() {
    "use strict";
    init_bootstrap2();
  }
});

// lib/api/cloudformation.ts
var init_cloudformation3 = __esm({
  "lib/api/cloudformation.ts"() {
    "use strict";
    init_cloudformation2();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/stack-selector.ts
var StackSelectionStrategy, ExpandStackSelection;
var init_stack_selector = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/stack-selector.ts"() {
    "use strict";
    StackSelectionStrategy = /* @__PURE__ */ ((StackSelectionStrategy3) => {
      StackSelectionStrategy3["ALL_STACKS"] = "all-stacks";
      StackSelectionStrategy3["MAIN_ASSEMBLY"] = "main-assembly";
      StackSelectionStrategy3["ONLY_SINGLE"] = "only-single";
      StackSelectionStrategy3["PATTERN_MATCH"] = "pattern-match";
      StackSelectionStrategy3["PATTERN_MUST_MATCH"] = "pattern-must-match";
      StackSelectionStrategy3["PATTERN_MUST_MATCH_SINGLE"] = "pattern-must-match-single";
      return StackSelectionStrategy3;
    })(StackSelectionStrategy || {});
    ExpandStackSelection = /* @__PURE__ */ ((ExpandStackSelection3) => {
      ExpandStackSelection3["NONE"] = "none";
      ExpandStackSelection3["UPSTREAM"] = "upstream";
      ExpandStackSelection3["DOWNSTREAM"] = "downstream";
      return ExpandStackSelection3;
    })(ExpandStackSelection || {});
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/private/borrowed-assembly.ts
var import_dispose_polyfill2, BorrowedAssembly;
var init_borrowed_assembly = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/private/borrowed-assembly.ts"() {
    "use strict";
    import_dispose_polyfill2 = __toESM(require_dispose_polyfill());
    BorrowedAssembly = class {
      constructor(cloudAssembly) {
        this.cloudAssembly = cloudAssembly;
      }
      cloudAssembly;
      static {
        __name(this, "BorrowedAssembly");
      }
      async _unlock() {
      }
      async dispose() {
      }
      async [Symbol.asyncDispose]() {
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/cached-source.ts
var import_dispose_polyfill3, CachedCloudAssembly;
var init_cached_source = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/cached-source.ts"() {
    "use strict";
    import_dispose_polyfill3 = __toESM(require_dispose_polyfill());
    init_borrowed_assembly();
    CachedCloudAssembly = class {
      static {
        __name(this, "CachedCloudAssembly");
      }
      asm;
      constructor(asm) {
        this.asm = asm;
      }
      get cloudAssembly() {
        return this.asm.cloudAssembly;
      }
      async produce() {
        return new BorrowedAssembly(this.asm.cloudAssembly);
      }
      _unlock() {
        return this.asm._unlock();
      }
      dispose() {
        return this.asm.dispose();
      }
      [Symbol.asyncDispose]() {
        return this.dispose();
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/settings.ts
function expandHomeDir(x) {
  if (x.startsWith("~")) {
    return fs_path.join(os7.homedir(), x.slice(1));
  }
  return x;
}
function stripTransientValues(obj) {
  const ret = {};
  for (const [key, value] of Object.entries(obj)) {
    if (!isTransientValue(value)) {
      ret[key] = value;
    }
  }
  return ret;
}
function isTransientValue(value) {
  return typeof value === "object" && value !== null && value[TRANSIENT_CONTEXT_KEY];
}
var os7, fs_path, fs22, TRANSIENT_CONTEXT_KEY, Settings;
var init_settings = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/settings.ts"() {
    "use strict";
    os7 = __toESM(require("os"));
    fs_path = __toESM(require("path"));
    fs22 = __toESM(require_lib4());
    init_toolkit_error();
    init_util3();
    TRANSIENT_CONTEXT_KEY = "$dontSaveContext";
    Settings = class _Settings {
      constructor(settings = {}, readOnly = false) {
        this.settings = settings;
        this._readOnly = readOnly;
      }
      settings;
      static {
        __name(this, "Settings");
      }
      static mergeAll(...settings) {
        let ret = new _Settings();
        for (const setting of settings) {
          ret = ret.merge(setting);
        }
        return ret;
      }
      _readOnly = false;
      get readOnly() {
        return this._readOnly;
      }
      async save(fileName) {
        const expanded = expandHomeDir(fileName);
        await fs22.writeJson(expanded, stripTransientValues(this.settings), {
          spaces: 2
        });
        return this;
      }
      get all() {
        return this.get([]);
      }
      merge(other) {
        return new _Settings(deepMerge(this.settings, other.settings));
      }
      subSettings(keyPrefix) {
        return new _Settings(this.get(keyPrefix) || {}, false);
      }
      makeReadOnly() {
        return new _Settings(this.settings, true);
      }
      temporarilyMutable(block) {
        const old = this.readOnly;
        this._readOnly = false;
        try {
          block(this);
        } finally {
          this._readOnly = old;
        }
      }
      clear() {
        if (this.readOnly) {
          throw new ToolkitError("SettingsReadOnly", "Cannot clear(): settings are readonly");
        }
        this.settings = {};
      }
      get empty() {
        return Object.keys(this.settings).length === 0;
      }
      get(path47) {
        return deepClone(deepGet(this.settings, path47));
      }
      set(path47, value) {
        if (this.readOnly) {
          throw new ToolkitError("SettingsReadOnly", `Can't set ${path47}: settings object is readonly`);
        }
        if (path47.length === 0) {
          this.settings = value;
        } else {
          deepSet(this.settings, path47, value);
        }
        return this;
      }
      unset(path47) {
        this.set(path47, void 0);
      }
    };
    __name(expandHomeDir, "expandHomeDir");
    __name(stripTransientValues, "stripTransientValues");
    __name(isTransientValue, "isTransientValue");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/context.ts
var PROJECT_CONTEXT, Context;
var init_context2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/context.ts"() {
    "use strict";
    init_settings();
    init_toolkit_error();
    init_settings();
    PROJECT_CONTEXT = "cdk.context.json";
    Context = class {
      static {
        __name(this, "Context");
      }
      bags;
      fileNames;
      constructor(...bags) {
        this.bags = bags.length > 0 ? bags.map((b32) => b32.bag) : [new Settings()];
        this.fileNames = bags.length > 0 ? bags.map((b32) => b32.fileName) : ["default"];
      }
      get keys() {
        return Object.keys(this.all);
      }
      has(key) {
        return this.keys.indexOf(key) > -1;
      }
      get all() {
        let ret = new Settings();
        for (const bag of [...this.bags].reverse()) {
          ret = ret.merge(bag);
        }
        return ret.all;
      }
      get(key) {
        for (const bag of this.bags) {
          const v = bag.get([key]);
          if (v !== void 0) {
            return v;
          }
        }
        return void 0;
      }
      set(key, value) {
        for (const bag of this.bags) {
          if (bag.readOnly) {
            continue;
          }
          bag.set([key], value);
          value = void 0;
        }
      }
      unset(key) {
        this.set(key, void 0);
      }
      clear() {
        for (const key of this.keys) {
          this.unset(key);
        }
      }
      /**
       * Save a specific context file
       */
      async save(fileName) {
        const index = this.fileNames.indexOf(fileName);
        if (index === -1) {
          return this;
        }
        const bag = this.bags[index];
        if (bag.readOnly) {
          throw new ToolkitError("ContextReadOnly", `Context file ${fileName} is read only!`);
        }
        await bag.save(fileName);
        return this;
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/context-store.ts
function persistableContext(context) {
  return Object.fromEntries(Object.entries(context).filter(([_, value]) => !isTransientValue2(value)));
}
function isTransientValue2(x) {
  return x && typeof x === "object" && x[TRANSIENT_CONTEXT_KEY];
}
async function settingsFromFile(filename) {
  try {
    const data3 = JSON.parse(await import_fs2.promises.readFile(filename, "utf-8"));
    return new Settings(data3);
  } catch (e32) {
    if (e32.code === "ENOENT") {
      return new Settings();
    }
    throw e32;
  }
}
var import_fs2, os8, path24, CdkAppMultiContext, FileContext, MemoryContext;
var init_context_store = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/context-store.ts"() {
    "use strict";
    import_fs2 = require("fs");
    os8 = __toESM(require("os"));
    path24 = __toESM(require("path"));
    init_toolkit_error();
    init_context2();
    init_settings();
    CdkAppMultiContext = class {
      constructor(appDirectory, commandlineContext) {
        this.commandlineContext = commandlineContext;
        this.configContextFile = path24.join(appDirectory, "cdk.json");
        this.projectContextFile = path24.join(appDirectory, "cdk.context.json");
        this.userConfigFile = path24.join(os8.homedir() ?? "/tmp", ".cdk.json");
      }
      commandlineContext;
      static {
        __name(this, "CdkAppMultiContext");
      }
      _context;
      configContextFile;
      projectContextFile;
      userConfigFile;
      async read() {
        const context = await this.asyncInitialize();
        return context.all;
      }
      async update(updates) {
        const context = await this.asyncInitialize();
        for (const [key, value] of Object.entries(updates)) {
          context.set(key, value);
        }
        await context.save(this.projectContextFile);
      }
      /**
       * Initialize the `Context` object
       *
       * This code all exists to reuse code that's already there, to minimize
       * the chances of the new code behaving subtly differently than the
       * old code.
       *
       * It might be most of this is unnecessary now...
       */
      async asyncInitialize() {
        if (this._context) {
          return this._context;
        }
        const contextSources = [
          { bag: new Settings(this.commandlineContext, true) },
          {
            fileName: this.configContextFile,
            bag: (await settingsFromFile(this.configContextFile)).subSettings(["context"]).makeReadOnly()
          },
          {
            fileName: this.projectContextFile,
            bag: await settingsFromFile(this.projectContextFile)
          },
          {
            fileName: this.userConfigFile,
            bag: (await settingsFromFile(this.userConfigFile)).subSettings(["context"]).makeReadOnly()
          }
        ];
        this._context = new Context(...contextSources);
        return this._context;
      }
    };
    FileContext = class {
      constructor(fileName) {
        this.fileName = fileName;
      }
      fileName;
      static {
        __name(this, "FileContext");
      }
      _cache;
      async read() {
        if (!this._cache) {
          try {
            this._cache = JSON.parse(await import_fs2.promises.readFile(this.fileName, "utf-8"));
          } catch (e32) {
            if (e32.code === "ENOENT") {
              this._cache = {};
            } else {
              throw e32;
            }
          }
        }
        if (!this._cache || typeof this._cache !== "object") {
          throw new ToolkitError("InvalidContextFile", `${this.fileName} must contain an object, got: ${JSON.stringify(this._cache)}`);
        }
        return this._cache;
      }
      async update(updates) {
        this._cache = {
          ...await this.read(),
          ...updates
        };
        const persistable = persistableContext(this._cache);
        await import_fs2.promises.writeFile(this.fileName, JSON.stringify(persistable, void 0, 2), "utf-8");
      }
    };
    MemoryContext = class {
      static {
        __name(this, "MemoryContext");
      }
      context = {};
      constructor(initialContext) {
        this.context = { ...initialContext };
      }
      read() {
        return Promise.resolve(this.context);
      }
      update(updates) {
        this.context = {
          ...this.context,
          ...updates
        };
        return Promise.resolve();
      }
    };
    __name(persistableContext, "persistableContext");
    __name(isTransientValue2, "isTransientValue");
    __name(settingsFromFile, "settingsFromFile");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/rwlock.ts
async function readFileIfExists(filename) {
  try {
    return await import_fs3.promises.readFile(filename, { encoding: "utf-8" });
  } catch (e32) {
    if (e32.code === "ENOENT") {
      return void 0;
    }
    throw e32;
  }
}
async function writeFileAtomic(filename, contents) {
  await import_fs3.promises.mkdir(path25.dirname(filename), { recursive: true });
  const tmpFile = `${filename}.${process.pid}_${++tmpCounter}`;
  await import_fs3.promises.writeFile(tmpFile, contents, { encoding: "utf-8" });
  await import_fs3.promises.rename(tmpFile, filename);
}
async function deleteFile(filename) {
  try {
    await import_fs3.promises.unlink(filename);
  } catch (e32) {
    if (e32.code === "ENOENT") {
      return;
    }
    throw e32;
  }
}
function processExists(pid) {
  try {
    process.kill(pid, 0);
    return true;
  } catch (e32) {
    return false;
  }
}
var import_fs3, path25, RWLock, tmpCounter;
var init_rwlock = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/rwlock.ts"() {
    "use strict";
    import_fs3 = require("fs");
    path25 = __toESM(require("path"));
    init_toolkit_error();
    RWLock = class {
      constructor(directory) {
        this.directory = directory;
        this.pidString = `${process.pid}`;
        this.writerFile = path25.join(this.directory, "synth.lock");
      }
      directory;
      static {
        __name(this, "RWLock");
      }
      pidString;
      writerFile;
      readCounter = 0;
      /**
       * Acquire a writer lock.
       *
       * No other readers or writers must exist for the given directory.
       */
      async acquireWrite() {
        await this.assertNoOtherWriters();
        const readers = await this._currentReaders();
        if (readers.length > 0) {
          throw new ToolkitError("ConcurrentReadLock", `Other CLIs (PID=${readers}) are currently reading from ${this.directory}. Invoke the CLI in sequence, or use '--output' to synth into different directories.`);
        }
        await writeFileAtomic(this.writerFile, this.pidString);
        let released = false;
        return {
          release: /* @__PURE__ */ __name(async () => {
            if (!released) {
              await deleteFile(this.writerFile);
              released = true;
            }
          }, "release"),
          convertToReaderLock: /* @__PURE__ */ __name(async () => {
            const ret = await this.doAcquireRead();
            await deleteFile(this.writerFile);
            return ret;
          }, "convertToReaderLock")
        };
      }
      /**
       * Acquire a read lock
       *
       * Will fail if there are any writers.
       */
      async acquireRead() {
        await this.assertNoOtherWriters();
        return this.doAcquireRead();
      }
      /**
       * Obtains the name fo a (new) `readerFile` to use. This includes a counter so
       * that if multiple threads of the same PID attempt to concurrently acquire
       * the same lock, they're guaranteed to use a different reader file name (only
       * one thread will ever execute JS code at once, guaranteeing the readCounter
       * is incremented "atomically" from the point of view of this PID.).
       */
      readerFile() {
        return path25.join(this.directory, `read.${this.pidString}.${++this.readCounter}.lock`);
      }
      /**
       * Do the actual acquiring of a read lock.
       */
      async doAcquireRead() {
        const readerFile = this.readerFile();
        await writeFileAtomic(readerFile, this.pidString);
        let released = false;
        return {
          release: /* @__PURE__ */ __name(async () => {
            if (!released) {
              await deleteFile(readerFile);
              released = true;
            }
          }, "release")
        };
      }
      async assertNoOtherWriters() {
        const writer = await this._currentWriter();
        if (writer) {
          throw new ToolkitError("ConcurrentWriteLock", `Another CLI (PID=${writer}) is currently synthing to ${this.directory}. Invoke the CLI in sequence, or use '--output' to synth into different directories.`);
        }
      }
      /**
       * Check the current writer (if any)
       *
       * Publicly accessible for testing purposes. Do not use.
       *
       * @internal
       */
      async _currentWriter() {
        const contents = await readFileIfExists(this.writerFile);
        if (!contents) {
          return void 0;
        }
        const pid = parseInt(contents, 10);
        if (!processExists(pid)) {
          await deleteFile(this.writerFile);
          return void 0;
        }
        return pid;
      }
      /**
       * Check the current readers (if any)
       *
       * Publicly accessible for testing purposes. Do not use.
       *
       * @internal
       */
      async _currentReaders() {
        const re = /^read\.([^.]+)\.[^.]+\.lock$/;
        const ret = new Array();
        let children;
        try {
          children = await import_fs3.promises.readdir(this.directory, { encoding: "utf-8" });
        } catch (e32) {
          if (e32.code === "ENOENT") {
            return [];
          }
          throw e32;
        }
        for (const fname of children) {
          const m20 = fname.match(re);
          if (m20) {
            const pid = parseInt(m20[1], 10);
            if (processExists(pid)) {
              ret.push(pid);
            } else {
              await deleteFile(path25.join(this.directory, fname));
            }
          }
        }
        return ret;
      }
    };
    __name(readFileIfExists, "readFileIfExists");
    tmpCounter = 0;
    __name(writeFileAtomic, "writeFileAtomic");
    __name(deleteFile, "deleteFile");
    __name(processExists, "processExists");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/private/disposable-box.ts
var import_dispose_polyfill4, AsyncDisposableBox;
var init_disposable_box = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/private/disposable-box.ts"() {
    "use strict";
    import_dispose_polyfill4 = __toESM(require_dispose_polyfill());
    AsyncDisposableBox = class {
      constructor(value) {
        this.value = value;
      }
      value;
      static {
        __name(this, "AsyncDisposableBox");
      }
      shouldDispose = true;
      /**
       * Remove the value from the Box, preventing it from being disposed in the future.
       *
       * Should be the last line of the containing function.
       */
      take() {
        this.shouldDispose = false;
        return this.value;
      }
      [Symbol.asyncDispose]() {
        if (this.shouldDispose) {
          return this.value[Symbol.asyncDispose]();
        }
        return Promise.resolve();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/emitWarningIfUnsupportedVersion.js
var state9, emitWarningIfUnsupportedVersion27;
var init_emitWarningIfUnsupportedVersion9 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/emitWarningIfUnsupportedVersion.js"() {
    state9 = {
      warningEmitted: false
    };
    emitWarningIfUnsupportedVersion27 = /* @__PURE__ */ __name((version) => {
      if (version && !state9.warningEmitted) {
        if (process.env.AWS_SDK_JS_NODE_VERSION_SUPPORT_WARNING_DISABLED === "true") {
          state9.warningEmitted = true;
          return;
        }
        const userMajorVersion = parseInt(version.substring(1, version.indexOf(".")));
        const vv = 22;
        if (userMajorVersion < vv) {
          state9.warningEmitted = true;
          process.emitWarning(`NodeVersionSupportWarning: The AWS SDK for JavaScript (v3)
versions published after the first week of January 2027
will require node >=${vv}. You are running node ${version}.

To continue receiving updates to AWS services, bug fixes,
and security updates please upgrade to node >=${vv}.

More information can be found at: https://a.co/c895JFp`);
        }
      }
    }, "emitWarningIfUnsupportedVersion");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/longPollMiddleware.js
var longPollMiddleware9, longPollMiddlewareOptions9, getLongPollPlugin9;
var init_longPollMiddleware9 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/longPollMiddleware.js"() {
    longPollMiddleware9 = /* @__PURE__ */ __name(() => (next, context) => async (args) => {
      context.__retryLongPoll = true;
      return next(args);
    }, "longPollMiddleware");
    longPollMiddlewareOptions9 = {
      name: "longPollMiddleware",
      tags: ["RETRY"],
      step: "initialize",
      override: true
    };
    getLongPollPlugin9 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(longPollMiddleware9(), longPollMiddlewareOptions9);
      }, "applyToStack")
    }), "getLongPollPlugin");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/setCredentialFeature.js
function setCredentialFeature9(credentials, feature, value) {
  if (!credentials.$source) {
    credentials.$source = {};
  }
  credentials.$source[feature] = value;
  return credentials;
}
var init_setCredentialFeature9 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/setCredentialFeature.js"() {
    __name(setCredentialFeature9, "setCredentialFeature");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/isStreamingPayload/isStreamingPayload.js
var import_node_stream5, isStreamingPayload2;
var init_isStreamingPayload2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/isStreamingPayload/isStreamingPayload.js"() {
    import_node_stream5 = require("node:stream");
    isStreamingPayload2 = /* @__PURE__ */ __name((request4) => request4?.body instanceof import_node_stream5.Readable || typeof ReadableStream !== "undefined" && request4?.body instanceof ReadableStream, "isStreamingPayload");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/middleware-stack/MiddlewareStack.js
var getAllAliases, getMiddlewareNameWithAliases, constructStack, stepWeights, priorityWeights;
var init_MiddlewareStack = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/middleware-stack/MiddlewareStack.js"() {
    getAllAliases = /* @__PURE__ */ __name((name, aliases) => {
      const _aliases = [];
      if (name) {
        _aliases.push(name);
      }
      if (aliases) {
        for (const alias of aliases) {
          _aliases.push(alias);
        }
      }
      return _aliases;
    }, "getAllAliases");
    getMiddlewareNameWithAliases = /* @__PURE__ */ __name((name, aliases) => {
      return `${name || "anonymous"}${aliases && aliases.length > 0 ? ` (a.k.a. ${aliases.join(",")})` : ""}`;
    }, "getMiddlewareNameWithAliases");
    constructStack = /* @__PURE__ */ __name(() => {
      let absoluteEntries = [];
      let relativeEntries = [];
      let identifyOnResolve = false;
      const entriesNameSet = /* @__PURE__ */ new Set();
      const sort = /* @__PURE__ */ __name((entries) => entries.sort((a32, b32) => stepWeights[b32.step] - stepWeights[a32.step] || priorityWeights[b32.priority || "normal"] - priorityWeights[a32.priority || "normal"]), "sort");
      const removeByName = /* @__PURE__ */ __name((toRemove) => {
        let isRemoved = false;
        const filterCb = /* @__PURE__ */ __name((entry) => {
          const aliases = getAllAliases(entry.name, entry.aliases);
          if (aliases.includes(toRemove)) {
            isRemoved = true;
            for (const alias of aliases) {
              entriesNameSet.delete(alias);
            }
            return false;
          }
          return true;
        }, "filterCb");
        absoluteEntries = absoluteEntries.filter(filterCb);
        relativeEntries = relativeEntries.filter(filterCb);
        return isRemoved;
      }, "removeByName");
      const removeByReference = /* @__PURE__ */ __name((toRemove) => {
        let isRemoved = false;
        const filterCb = /* @__PURE__ */ __name((entry) => {
          if (entry.middleware === toRemove) {
            isRemoved = true;
            for (const alias of getAllAliases(entry.name, entry.aliases)) {
              entriesNameSet.delete(alias);
            }
            return false;
          }
          return true;
        }, "filterCb");
        absoluteEntries = absoluteEntries.filter(filterCb);
        relativeEntries = relativeEntries.filter(filterCb);
        return isRemoved;
      }, "removeByReference");
      const cloneTo = /* @__PURE__ */ __name((toStack) => {
        absoluteEntries.forEach((entry) => {
          toStack.add(entry.middleware, { ...entry });
        });
        relativeEntries.forEach((entry) => {
          toStack.addRelativeTo(entry.middleware, { ...entry });
        });
        toStack.identifyOnResolve?.(stack.identifyOnResolve());
        return toStack;
      }, "cloneTo");
      const expandRelativeMiddlewareList = /* @__PURE__ */ __name((from) => {
        const expandedMiddlewareList = [];
        from.before.forEach((entry) => {
          if (entry.before.length === 0 && entry.after.length === 0) {
            expandedMiddlewareList.push(entry);
          } else {
            expandedMiddlewareList.push(...expandRelativeMiddlewareList(entry));
          }
        });
        expandedMiddlewareList.push(from);
        from.after.reverse().forEach((entry) => {
          if (entry.before.length === 0 && entry.after.length === 0) {
            expandedMiddlewareList.push(entry);
          } else {
            expandedMiddlewareList.push(...expandRelativeMiddlewareList(entry));
          }
        });
        return expandedMiddlewareList;
      }, "expandRelativeMiddlewareList");
      const getMiddlewareList = /* @__PURE__ */ __name((debug2 = false) => {
        const normalizedAbsoluteEntries = [];
        const normalizedRelativeEntries = [];
        const normalizedEntriesNameMap = {};
        absoluteEntries.forEach((entry) => {
          const normalizedEntry = {
            ...entry,
            before: [],
            after: []
          };
          for (const alias of getAllAliases(normalizedEntry.name, normalizedEntry.aliases)) {
            normalizedEntriesNameMap[alias] = normalizedEntry;
          }
          normalizedAbsoluteEntries.push(normalizedEntry);
        });
        relativeEntries.forEach((entry) => {
          const normalizedEntry = {
            ...entry,
            before: [],
            after: []
          };
          for (const alias of getAllAliases(normalizedEntry.name, normalizedEntry.aliases)) {
            normalizedEntriesNameMap[alias] = normalizedEntry;
          }
          normalizedRelativeEntries.push(normalizedEntry);
        });
        normalizedRelativeEntries.forEach((entry) => {
          if (entry.toMiddleware) {
            const toMiddleware = normalizedEntriesNameMap[entry.toMiddleware];
            if (toMiddleware === void 0) {
              if (debug2) {
                return;
              }
              throw new Error(`${entry.toMiddleware} is not found when adding ${getMiddlewareNameWithAliases(entry.name, entry.aliases)} middleware ${entry.relation} ${entry.toMiddleware}`);
            }
            if (entry.relation === "after") {
              toMiddleware.after.push(entry);
            }
            if (entry.relation === "before") {
              toMiddleware.before.push(entry);
            }
          }
        });
        const mainChain = sort(normalizedAbsoluteEntries).map(expandRelativeMiddlewareList).reduce((wholeList, expandedMiddlewareList) => {
          wholeList.push(...expandedMiddlewareList);
          return wholeList;
        }, []);
        return mainChain;
      }, "getMiddlewareList");
      const stack = {
        add: /* @__PURE__ */ __name((middleware, options = {}) => {
          const { name, override, aliases: _aliases } = options;
          const entry = {
            step: "initialize",
            priority: "normal",
            middleware,
            ...options
          };
          const aliases = getAllAliases(name, _aliases);
          if (aliases.length > 0) {
            if (aliases.some((alias) => entriesNameSet.has(alias))) {
              if (!override)
                throw new Error(`Duplicate middleware name '${getMiddlewareNameWithAliases(name, _aliases)}'`);
              for (const alias of aliases) {
                const toOverrideIndex = absoluteEntries.findIndex((entry2) => entry2.name === alias || entry2.aliases?.some((a32) => a32 === alias));
                if (toOverrideIndex === -1) {
                  continue;
                }
                const toOverride = absoluteEntries[toOverrideIndex];
                if (toOverride.step !== entry.step || entry.priority !== toOverride.priority) {
                  throw new Error(`"${getMiddlewareNameWithAliases(toOverride.name, toOverride.aliases)}" middleware with ${toOverride.priority} priority in ${toOverride.step} step cannot be overridden by "${getMiddlewareNameWithAliases(name, _aliases)}" middleware with ${entry.priority} priority in ${entry.step} step.`);
                }
                absoluteEntries.splice(toOverrideIndex, 1);
              }
            }
            for (const alias of aliases) {
              entriesNameSet.add(alias);
            }
          }
          absoluteEntries.push(entry);
        }, "add"),
        addRelativeTo: /* @__PURE__ */ __name((middleware, options) => {
          const { name, override, aliases: _aliases } = options;
          const entry = {
            middleware,
            ...options
          };
          const aliases = getAllAliases(name, _aliases);
          if (aliases.length > 0) {
            if (aliases.some((alias) => entriesNameSet.has(alias))) {
              if (!override)
                throw new Error(`Duplicate middleware name '${getMiddlewareNameWithAliases(name, _aliases)}'`);
              for (const alias of aliases) {
                const toOverrideIndex = relativeEntries.findIndex((entry2) => entry2.name === alias || entry2.aliases?.some((a32) => a32 === alias));
                if (toOverrideIndex === -1) {
                  continue;
                }
                const toOverride = relativeEntries[toOverrideIndex];
                if (toOverride.toMiddleware !== entry.toMiddleware || toOverride.relation !== entry.relation) {
                  throw new Error(`"${getMiddlewareNameWithAliases(toOverride.name, toOverride.aliases)}" middleware ${toOverride.relation} "${toOverride.toMiddleware}" middleware cannot be overridden by "${getMiddlewareNameWithAliases(name, _aliases)}" middleware ${entry.relation} "${entry.toMiddleware}" middleware.`);
                }
                relativeEntries.splice(toOverrideIndex, 1);
              }
            }
            for (const alias of aliases) {
              entriesNameSet.add(alias);
            }
          }
          relativeEntries.push(entry);
        }, "addRelativeTo"),
        clone: /* @__PURE__ */ __name(() => cloneTo(constructStack()), "clone"),
        use: /* @__PURE__ */ __name((plugin) => {
          plugin.applyToStack(stack);
        }, "use"),
        remove: /* @__PURE__ */ __name((toRemove) => {
          if (typeof toRemove === "string")
            return removeByName(toRemove);
          else
            return removeByReference(toRemove);
        }, "remove"),
        removeByTag: /* @__PURE__ */ __name((toRemove) => {
          let isRemoved = false;
          const filterCb = /* @__PURE__ */ __name((entry) => {
            const { tags, name, aliases: _aliases } = entry;
            if (tags && tags.includes(toRemove)) {
              const aliases = getAllAliases(name, _aliases);
              for (const alias of aliases) {
                entriesNameSet.delete(alias);
              }
              isRemoved = true;
              return false;
            }
            return true;
          }, "filterCb");
          absoluteEntries = absoluteEntries.filter(filterCb);
          relativeEntries = relativeEntries.filter(filterCb);
          return isRemoved;
        }, "removeByTag"),
        concat: /* @__PURE__ */ __name((from) => {
          const cloned = cloneTo(constructStack());
          cloned.use(from);
          cloned.identifyOnResolve(identifyOnResolve || cloned.identifyOnResolve() || (from.identifyOnResolve?.() ?? false));
          return cloned;
        }, "concat"),
        applyToStack: cloneTo,
        identify: /* @__PURE__ */ __name(() => {
          return getMiddlewareList(true).map((mw) => {
            const step = mw.step ?? mw.relation + " " + mw.toMiddleware;
            return getMiddlewareNameWithAliases(mw.name, mw.aliases) + " - " + step;
          });
        }, "identify"),
        identifyOnResolve(toggle) {
          if (typeof toggle === "boolean")
            identifyOnResolve = toggle;
          return identifyOnResolve;
        },
        resolve: /* @__PURE__ */ __name((handler, context) => {
          for (const middleware of getMiddlewareList().map((entry) => entry.middleware).reverse()) {
            handler = middleware(handler, context);
          }
          if (identifyOnResolve) {
            console.log(stack.identify());
          }
          return handler;
        }, "resolve")
      };
      return stack;
    }, "constructStack");
    stepWeights = {
      initialize: 5,
      serialize: 4,
      build: 3,
      finalizeRequest: 2,
      deserialize: 1
    };
    priorityWeights = {
      high: 3,
      normal: 2,
      low: 1
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/util-middleware/getSmithyContext.js
var import_types21, getSmithyContext26;
var init_getSmithyContext3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/util-middleware/getSmithyContext.js"() {
    import_types21 = __toESM(require_dist_cjs());
    getSmithyContext26 = /* @__PURE__ */ __name((context) => context[import_types21.SMITHY_CONTEXT_KEY] || (context[import_types21.SMITHY_CONTEXT_KEY] = {}), "getSmithyContext");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/util-middleware/normalizeProvider.js
var normalizeProvider22;
var init_normalizeProvider4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/util-middleware/normalizeProvider.js"() {
    normalizeProvider22 = /* @__PURE__ */ __name((input) => {
      if (typeof input === "function")
        return input;
      const promisified = Promise.resolve(input);
      return () => promisified;
    }, "normalizeProvider");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/invalid-dependency/invalidFunction.js
var invalidFunction;
var init_invalidFunction = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/invalid-dependency/invalidFunction.js"() {
    invalidFunction = /* @__PURE__ */ __name((message2) => () => {
      throw new Error(message2);
    }, "invalidFunction");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/invalid-dependency/invalidProvider.js
var invalidProvider;
var init_invalidProvider = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/invalid-dependency/invalidProvider.js"() {
    invalidProvider = /* @__PURE__ */ __name((message2) => () => Promise.reject(message2), "invalidProvider");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/util-waiter/circularReplacer.js
var getCircularReplacer;
var init_circularReplacer = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/util-waiter/circularReplacer.js"() {
    getCircularReplacer = /* @__PURE__ */ __name(() => {
      const seen = /* @__PURE__ */ new WeakSet();
      return (key, value) => {
        if (typeof value === "object" && value !== null) {
          if (seen.has(value)) {
            return "[Circular]";
          }
          seen.add(value);
        }
        return value;
      };
    }, "getCircularReplacer");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/util-waiter/utils/sleep.js
var sleep2;
var init_sleep = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/util-waiter/utils/sleep.js"() {
    sleep2 = /* @__PURE__ */ __name((seconds) => {
      return new Promise((resolve13) => setTimeout(resolve13, seconds * 1e3));
    }, "sleep");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/util-waiter/waiter.js
var waiterServiceDefaults, WaiterState, checkExceptions;
var init_waiter = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/util-waiter/waiter.js"() {
    init_circularReplacer();
    waiterServiceDefaults = {
      minDelay: 2,
      maxDelay: 120
    };
    (function(WaiterState3) {
      WaiterState3["ABORTED"] = "ABORTED";
      WaiterState3["FAILURE"] = "FAILURE";
      WaiterState3["SUCCESS"] = "SUCCESS";
      WaiterState3["RETRY"] = "RETRY";
      WaiterState3["TIMEOUT"] = "TIMEOUT";
    })(WaiterState || (WaiterState = {}));
    checkExceptions = /* @__PURE__ */ __name((result2) => {
      if (result2.state === WaiterState.ABORTED) {
        const abortError = new Error(`${JSON.stringify({
          ...result2,
          reason: "Request was aborted"
        }, getCircularReplacer())}`);
        abortError.name = "AbortError";
        throw abortError;
      } else if (result2.state === WaiterState.TIMEOUT) {
        const timeoutError = new Error(`${JSON.stringify({
          ...result2,
          reason: "Waiter has timed out"
        }, getCircularReplacer())}`);
        timeoutError.name = "TimeoutError";
        throw timeoutError;
      } else if (result2.state !== WaiterState.SUCCESS) {
        throw new Error(`${JSON.stringify(result2, getCircularReplacer())}`);
      }
      return result2;
    }, "checkExceptions");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/util-waiter/poller.js
var runPolling, checkWarn403, createMessageFromResponse, exponentialBackoffWithJitter, randomInRange;
var init_poller = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/util-waiter/poller.js"() {
    init_circularReplacer();
    init_sleep();
    init_waiter();
    runPolling = /* @__PURE__ */ __name(async ({ minDelay, maxDelay, maxWaitTime, abortController, client, abortSignal }, input, acceptorChecks) => {
      const observedResponses = {};
      const [minDelayMs, maxDelayMs] = [minDelay * 1e3, maxDelay * 1e3];
      let currentAttempt = 0;
      const waitUntil = Date.now() + maxWaitTime * 1e3;
      const warn403Time = Date.now() + 6e4;
      let didWarn403 = false;
      while (true) {
        if (currentAttempt > 0) {
          const delayMs = exponentialBackoffWithJitter(minDelayMs, maxDelayMs, currentAttempt, waitUntil);
          if (abortController?.signal?.aborted || abortSignal?.aborted) {
            const message2 = "AbortController signal aborted.";
            observedResponses[message2] |= 0;
            observedResponses[message2] += 1;
            return { state: WaiterState.ABORTED, observedResponses };
          }
          if (Date.now() + delayMs > waitUntil) {
            return { state: WaiterState.TIMEOUT, observedResponses };
          }
          await sleep2(delayMs / 1e3);
        }
        const { state: state13, reason } = await acceptorChecks(client, input);
        if (reason) {
          const message2 = createMessageFromResponse(reason);
          observedResponses[message2] |= 0;
          observedResponses[message2] += 1;
        }
        if (state13 !== WaiterState.RETRY) {
          return { state: state13, reason, final: reason, observedResponses };
        }
        currentAttempt += 1;
        if (!didWarn403 && Date.now() >= warn403Time) {
          checkWarn403(observedResponses, client);
          didWarn403 = true;
        }
      }
    }, "runPolling");
    checkWarn403 = /* @__PURE__ */ __name((observedResponses = {}, client) => {
      const orderedErrors = Object.keys(observedResponses);
      let maxCount = 0;
      let count403 = 0;
      for (const response of orderedErrors) {
        const n10 = observedResponses[response] | 0;
        maxCount = Math.max(n10, maxCount);
        if (response.startsWith("403:")) {
          count403 += n10;
        }
      }
      const clientLogger = client?.config?.logger;
      const warningLogger = typeof clientLogger?.warn === "function" && !clientLogger.constructor?.name?.includes?.("NoOpLogger") ? clientLogger : console;
      if (count403 >= 3 || orderedErrors[orderedErrors.length - 1]?.startsWith("403:")) {
        warningLogger.warn(`@smithy/util-waiter WARN - 403 status code encountered during waiter polling.`);
      }
    }, "checkWarn403");
    createMessageFromResponse = /* @__PURE__ */ __name((reason) => {
      const status = reason?.$response?.statusCode ?? reason?.$metadata?.httpStatusCode;
      if (reason?.$responseBodyText) {
        return `${status ? status + ": " : ""}Deserialization error for body: ${reason.$responseBodyText}`;
      }
      if (status) {
        if (reason?.$response || reason?.message) {
          return `${status ?? "Unknown"}: ${reason?.message}`;
        }
        return `${status}: OK`;
      }
      return String(reason?.message ?? JSON.stringify(reason, getCircularReplacer()) ?? "Unknown");
    }, "createMessageFromResponse");
    exponentialBackoffWithJitter = /* @__PURE__ */ __name((minDelayMs, maxDelayMs, attempt, waitUntil) => {
      const attemptCountCeiling = Math.log(maxDelayMs / minDelayMs) / Math.log(2) + 1;
      if (attempt > attemptCountCeiling) {
        return maxDelayMs;
      }
      const delay = minDelayMs * 2 ** (attempt - 1);
      const capped = Math.min(delay, maxDelayMs);
      const waitFor2 = randomInRange(minDelayMs, capped);
      if (Date.now() + waitFor2 > waitUntil) {
        const timeRemaining = waitUntil - Date.now();
        return Math.max(0, timeRemaining - 500);
      }
      return waitFor2;
    }, "exponentialBackoffWithJitter");
    randomInRange = /* @__PURE__ */ __name((min, max) => min + Math.random() * (max - min), "randomInRange");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/util-waiter/utils/validate.js
var validateWaiterOptions;
var init_validate = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/util-waiter/utils/validate.js"() {
    validateWaiterOptions = /* @__PURE__ */ __name((options) => {
      if (options.maxWaitTime <= 0) {
        throw new Error(`WaiterConfiguration.maxWaitTime must be greater than 0`);
      } else if (options.minDelay <= 0) {
        throw new Error(`WaiterConfiguration.minDelay must be greater than 0`);
      } else if (options.maxDelay <= 0) {
        throw new Error(`WaiterConfiguration.maxDelay must be greater than 0`);
      } else if (options.maxWaitTime <= options.minDelay) {
        throw new Error(`WaiterConfiguration.maxWaitTime [${options.maxWaitTime}] must be greater than WaiterConfiguration.minDelay [${options.minDelay}] for this waiter`);
      } else if (options.maxDelay < options.minDelay) {
        throw new Error(`WaiterConfiguration.maxDelay [${options.maxDelay}] must be greater than WaiterConfiguration.minDelay [${options.minDelay}] for this waiter`);
      }
    }, "validateWaiterOptions");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/util-waiter/createWaiter.js
var abortTimeout, createWaiter;
var init_createWaiter = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/util-waiter/createWaiter.js"() {
    init_poller();
    init_validate();
    init_waiter();
    abortTimeout = /* @__PURE__ */ __name((abortSignal) => {
      let onAbort;
      const promise = new Promise((resolve13) => {
        onAbort = /* @__PURE__ */ __name(() => resolve13({ state: WaiterState.ABORTED }), "onAbort");
        if (typeof abortSignal.addEventListener === "function") {
          abortSignal.addEventListener("abort", onAbort);
        } else {
          abortSignal.onabort = onAbort;
        }
      });
      return {
        clearListener() {
          if (typeof abortSignal.removeEventListener === "function") {
            abortSignal.removeEventListener("abort", onAbort);
          }
        },
        aborted: promise
      };
    }, "abortTimeout");
    createWaiter = /* @__PURE__ */ __name(async (options, input, acceptorChecks) => {
      const params = {
        ...waiterServiceDefaults,
        ...options
      };
      validateWaiterOptions(params);
      const exitConditions = [runPolling(params, input, acceptorChecks)];
      const finalize = [];
      if (options.abortSignal) {
        const { aborted, clearListener } = abortTimeout(options.abortSignal);
        finalize.push(clearListener);
        exitConditions.push(aborted);
      }
      if (options.abortController?.signal) {
        const { aborted, clearListener } = abortTimeout(options.abortController.signal);
        finalize.push(clearListener);
        exitConditions.push(aborted);
      }
      return Promise.race(exitConditions).then((result2) => {
        for (const fn of finalize) {
          fn();
        }
        return result2;
      });
    }, "createWaiter");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/client.js
var Client;
var init_client11 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/client.js"() {
    init_MiddlewareStack();
    Client = class {
      static {
        __name(this, "Client");
      }
      config;
      middlewareStack = constructStack();
      initConfig;
      handlers;
      constructor(config2) {
        this.config = config2;
        const { protocol, protocolSettings } = config2;
        if (protocolSettings) {
          if (typeof protocol === "function") {
            config2.protocol = new protocol(protocolSettings);
          }
        }
      }
      send(command, optionsOrCb, cb) {
        const options = typeof optionsOrCb !== "function" ? optionsOrCb : void 0;
        const callback = typeof optionsOrCb === "function" ? optionsOrCb : cb;
        const useHandlerCache = options === void 0 && this.config.cacheMiddleware === true;
        let handler;
        if (useHandlerCache) {
          if (!this.handlers) {
            this.handlers = /* @__PURE__ */ new WeakMap();
          }
          const handlers = this.handlers;
          if (handlers.has(command.constructor)) {
            handler = handlers.get(command.constructor);
          } else {
            handler = command.resolveMiddleware(this.middlewareStack, this.config, options);
            handlers.set(command.constructor, handler);
          }
        } else {
          delete this.handlers;
          handler = command.resolveMiddleware(this.middlewareStack, this.config, options);
        }
        if (callback) {
          handler(command).then((result2) => callback(null, result2.output), (err) => callback(err)).catch(() => {
          });
        } else {
          return handler(command).then((result2) => result2.output);
        }
      }
      destroy() {
        this.config?.requestHandler?.destroy?.();
        delete this.handlers;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/deref.js
var deref3;
var init_deref3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/deref.js"() {
    deref3 = /* @__PURE__ */ __name((schemaRef) => {
      if (typeof schemaRef === "function") {
        return schemaRef();
      }
      return schemaRef;
    }, "deref");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/is-array-buffer/is-array-buffer.js
var isArrayBuffer3;
var init_is_array_buffer3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/is-array-buffer/is-array-buffer.js"() {
    isArrayBuffer3 = /* @__PURE__ */ __name((arg) => typeof ArrayBuffer === "function" && arg instanceof ArrayBuffer || Object.prototype.toString.call(arg) === "[object ArrayBuffer]", "isArrayBuffer");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-buffer-from/buffer-from.js
var fromArrayBuffer3, fromString3;
var init_buffer_from3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-buffer-from/buffer-from.js"() {
    init_is_array_buffer3();
    fromArrayBuffer3 = /* @__PURE__ */ __name((input, offset = 0, length = input.byteLength - offset) => {
      if (!isArrayBuffer3(input)) {
        throw new TypeError(`The "input" argument must be ArrayBuffer. Received type ${typeof input} (${input})`);
      }
      return Buffer.from(input, offset, length);
    }, "fromArrayBuffer");
    fromString3 = /* @__PURE__ */ __name((input, encoding) => {
      if (typeof input !== "string") {
        throw new TypeError(`The "input" argument must be of type string. Received type ${typeof input} (${input})`);
      }
      return encoding ? Buffer.from(input, encoding) : Buffer.from(input);
    }, "fromString");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/fromBase64.js
var BASE64_REGEX3, fromBase6436;
var init_fromBase643 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/fromBase64.js"() {
    init_buffer_from3();
    BASE64_REGEX3 = /^[A-Za-z0-9+/]*={0,2}$/;
    fromBase6436 = /* @__PURE__ */ __name((input) => {
      if (input.length * 3 % 4 !== 0) {
        throw new TypeError(`Incorrect padding on base64 string.`);
      }
      if (!BASE64_REGEX3.exec(input)) {
        throw new TypeError(`Invalid base64 string.`);
      }
      const buffer = fromString3(input, "base64");
      return new Uint8Array(buffer.buffer, buffer.byteOffset, buffer.byteLength);
    }, "fromBase64");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/fromUtf8.js
var fromUtf825;
var init_fromUtf83 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/fromUtf8.js"() {
    init_buffer_from3();
    fromUtf825 = /* @__PURE__ */ __name((input) => {
      const buf = fromString3(input, "utf8");
      return new Uint8Array(buf.buffer, buf.byteOffset, buf.byteLength / Uint8Array.BYTES_PER_ELEMENT);
    }, "fromUtf8");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/toBase64.js
var toBase6441;
var init_toBase643 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/toBase64.js"() {
    init_buffer_from3();
    init_fromUtf83();
    toBase6441 = /* @__PURE__ */ __name((_input) => {
      let input;
      if (typeof _input === "string") {
        input = fromUtf825(_input);
      } else {
        input = _input;
      }
      if (typeof input !== "object" || typeof input.byteOffset !== "number" || typeof input.byteLength !== "number") {
        throw new Error("@smithy/util-base64: toBase64 encoder function only accepts string | Uint8Array.");
      }
      return fromArrayBuffer3(input.buffer, input.byteOffset, input.byteLength).toString("base64");
    }, "toBase64");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/blob/Uint8ArrayBlobAdapter.js
function bindUint8ArrayBlobAdapter3(toUtf862, fromUtf842, toBase6467, fromBase6459) {
  return class Uint8ArrayBlobAdapter8 extends Uint8Array {
    static {
      __name(this, "Uint8ArrayBlobAdapter");
    }
    static fromString(source, encoding = "utf-8") {
      if (typeof source === "string") {
        if (encoding === "base64") {
          return Uint8ArrayBlobAdapter8.mutate(fromBase6459(source));
        }
        return Uint8ArrayBlobAdapter8.mutate(fromUtf842(source));
      }
      throw new Error(`Unsupported conversion from ${typeof source} to Uint8ArrayBlobAdapter.`);
    }
    static mutate(source) {
      Object.setPrototypeOf(source, Uint8ArrayBlobAdapter8.prototype);
      return source;
    }
    transformToString(encoding = "utf-8") {
      if (encoding === "base64") {
        return toBase6467(this);
      }
      return toUtf862(this);
    }
  };
}
var init_Uint8ArrayBlobAdapter3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/blob/Uint8ArrayBlobAdapter.js"() {
    __name(bindUint8ArrayBlobAdapter3, "bindUint8ArrayBlobAdapter");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/toUtf8.js
var toUtf839;
var init_toUtf83 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/toUtf8.js"() {
    init_buffer_from3();
    toUtf839 = /* @__PURE__ */ __name((input) => {
      if (typeof input === "string") {
        return input;
      }
      if (typeof input !== "object" || typeof input.byteOffset !== "number" || typeof input.byteLength !== "number") {
        throw new Error("@smithy/util-utf8: toUtf8 encoder function only accepts string | Uint8Array.");
      }
      return fromArrayBuffer3(input.buffer, input.byteOffset, input.byteLength).toString("utf8");
    }, "toUtf8");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/uuid/v4.js
function bindV43(getRandomValues7) {
  if (typeof crypto !== "undefined" && typeof crypto.randomUUID === "function") {
    return () => crypto.randomUUID();
  }
  return () => {
    const rnds = new Uint8Array(16);
    getRandomValues7(rnds);
    rnds[6] = rnds[6] & 15 | 64;
    rnds[8] = rnds[8] & 63 | 128;
    return decimalToHex3[rnds[0]] + decimalToHex3[rnds[1]] + decimalToHex3[rnds[2]] + decimalToHex3[rnds[3]] + "-" + decimalToHex3[rnds[4]] + decimalToHex3[rnds[5]] + "-" + decimalToHex3[rnds[6]] + decimalToHex3[rnds[7]] + "-" + decimalToHex3[rnds[8]] + decimalToHex3[rnds[9]] + "-" + decimalToHex3[rnds[10]] + decimalToHex3[rnds[11]] + decimalToHex3[rnds[12]] + decimalToHex3[rnds[13]] + decimalToHex3[rnds[14]] + decimalToHex3[rnds[15]];
  };
}
var decimalToHex3;
var init_v43 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/uuid/v4.js"() {
    decimalToHex3 = Array.from({ length: 256 }, (_, i32) => i32.toString(16).padStart(2, "0"));
    __name(bindV43, "bindV4");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/copyDocumentWithTransform.js
var copyDocumentWithTransform2;
var init_copyDocumentWithTransform2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/copyDocumentWithTransform.js"() {
    copyDocumentWithTransform2 = /* @__PURE__ */ __name((source, schemaRef, transform = (_) => _) => source, "copyDocumentWithTransform");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/parse-utils.js
var parseBoolean2, expectBoolean2, expectNumber3, MAX_FLOAT3, expectFloat323, expectLong3, expectInt2, expectInt322, expectShort3, expectByte3, expectSizedInt3, castInt3, expectNonNull2, expectObject2, expectString3, expectUnion7, strictParseDouble3, strictParseFloat2, strictParseFloat323, NUMBER_REGEX3, parseNumber3, limitedParseDouble2, handleFloat2, limitedParseFloat2, limitedParseFloat322, parseFloatString2, strictParseLong2, strictParseInt2, strictParseInt322, strictParseShort3, strictParseByte3, stackTraceWarning3, logger3;
var init_parse_utils3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/parse-utils.js"() {
    parseBoolean2 = /* @__PURE__ */ __name((value) => {
      switch (value) {
        case "true":
          return true;
        case "false":
          return false;
        default:
          throw new Error(`Unable to parse boolean value "${value}"`);
      }
    }, "parseBoolean");
    expectBoolean2 = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      if (typeof value === "number") {
        if (value === 0 || value === 1) {
          logger3.warn(stackTraceWarning3(`Expected boolean, got ${typeof value}: ${value}`));
        }
        if (value === 0) {
          return false;
        }
        if (value === 1) {
          return true;
        }
      }
      if (typeof value === "string") {
        const lower = value.toLowerCase();
        if (lower === "false" || lower === "true") {
          logger3.warn(stackTraceWarning3(`Expected boolean, got ${typeof value}: ${value}`));
        }
        if (lower === "false") {
          return false;
        }
        if (lower === "true") {
          return true;
        }
      }
      if (typeof value === "boolean") {
        return value;
      }
      throw new TypeError(`Expected boolean, got ${typeof value}: ${value}`);
    }, "expectBoolean");
    expectNumber3 = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      if (typeof value === "string") {
        const parsed = parseFloat(value);
        if (!Number.isNaN(parsed)) {
          if (String(parsed) !== String(value)) {
            logger3.warn(stackTraceWarning3(`Expected number but observed string: ${value}`));
          }
          return parsed;
        }
      }
      if (typeof value === "number") {
        return value;
      }
      throw new TypeError(`Expected number, got ${typeof value}: ${value}`);
    }, "expectNumber");
    MAX_FLOAT3 = Math.ceil(2 ** 127 * (2 - 2 ** -23));
    expectFloat323 = /* @__PURE__ */ __name((value) => {
      const expected = expectNumber3(value);
      if (expected !== void 0 && !Number.isNaN(expected) && expected !== Infinity && expected !== -Infinity) {
        if (Math.abs(expected) > MAX_FLOAT3) {
          throw new TypeError(`Expected 32-bit float, got ${value}`);
        }
      }
      return expected;
    }, "expectFloat32");
    expectLong3 = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      if (Number.isInteger(value) && !Number.isNaN(value)) {
        return value;
      }
      throw new TypeError(`Expected integer, got ${typeof value}: ${value}`);
    }, "expectLong");
    expectInt2 = expectLong3;
    expectInt322 = /* @__PURE__ */ __name((value) => expectSizedInt3(value, 32), "expectInt32");
    expectShort3 = /* @__PURE__ */ __name((value) => expectSizedInt3(value, 16), "expectShort");
    expectByte3 = /* @__PURE__ */ __name((value) => expectSizedInt3(value, 8), "expectByte");
    expectSizedInt3 = /* @__PURE__ */ __name((value, size) => {
      const expected = expectLong3(value);
      if (expected !== void 0 && castInt3(expected, size) !== expected) {
        throw new TypeError(`Expected ${size}-bit integer, got ${value}`);
      }
      return expected;
    }, "expectSizedInt");
    castInt3 = /* @__PURE__ */ __name((value, size) => {
      switch (size) {
        case 32:
          return Int32Array.of(value)[0];
        case 16:
          return Int16Array.of(value)[0];
        case 8:
          return Int8Array.of(value)[0];
      }
    }, "castInt");
    expectNonNull2 = /* @__PURE__ */ __name((value, location) => {
      if (value === null || value === void 0) {
        if (location) {
          throw new TypeError(`Expected a non-null value for ${location}`);
        }
        throw new TypeError("Expected a non-null value");
      }
      return value;
    }, "expectNonNull");
    expectObject2 = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      if (typeof value === "object" && !Array.isArray(value)) {
        return value;
      }
      const receivedType = Array.isArray(value) ? "array" : typeof value;
      throw new TypeError(`Expected object, got ${receivedType}: ${value}`);
    }, "expectObject");
    expectString3 = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      if (typeof value === "string") {
        return value;
      }
      if (["boolean", "number", "bigint"].includes(typeof value)) {
        logger3.warn(stackTraceWarning3(`Expected string, got ${typeof value}: ${value}`));
        return String(value);
      }
      throw new TypeError(`Expected string, got ${typeof value}: ${value}`);
    }, "expectString");
    expectUnion7 = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      const asObject = expectObject2(value);
      const setKeys = [];
      for (const k32 in asObject) {
        if (asObject[k32] != null) {
          setKeys.push(k32);
        }
      }
      if (setKeys.length === 0) {
        throw new TypeError(`Unions must have exactly one non-null member. None were found.`);
      }
      if (setKeys.length > 1) {
        throw new TypeError(`Unions must have exactly one non-null member. Keys ${setKeys} were not null.`);
      }
      return asObject;
    }, "expectUnion");
    strictParseDouble3 = /* @__PURE__ */ __name((value) => {
      if (typeof value == "string") {
        return expectNumber3(parseNumber3(value));
      }
      return expectNumber3(value);
    }, "strictParseDouble");
    strictParseFloat2 = strictParseDouble3;
    strictParseFloat323 = /* @__PURE__ */ __name((value) => {
      if (typeof value == "string") {
        return expectFloat323(parseNumber3(value));
      }
      return expectFloat323(value);
    }, "strictParseFloat32");
    NUMBER_REGEX3 = /(-?(?:0|[1-9]\d*)(?:\.\d+)?(?:[eE][+-]?\d+)?)|(-?Infinity)|(NaN)/g;
    parseNumber3 = /* @__PURE__ */ __name((value) => {
      const matches = value.match(NUMBER_REGEX3);
      if (matches === null || matches[0].length !== value.length) {
        throw new TypeError(`Expected real number, got implicit NaN`);
      }
      return parseFloat(value);
    }, "parseNumber");
    limitedParseDouble2 = /* @__PURE__ */ __name((value) => {
      if (typeof value == "string") {
        return parseFloatString2(value);
      }
      return expectNumber3(value);
    }, "limitedParseDouble");
    handleFloat2 = limitedParseDouble2;
    limitedParseFloat2 = limitedParseDouble2;
    limitedParseFloat322 = /* @__PURE__ */ __name((value) => {
      if (typeof value == "string") {
        return parseFloatString2(value);
      }
      return expectFloat323(value);
    }, "limitedParseFloat32");
    parseFloatString2 = /* @__PURE__ */ __name((value) => {
      switch (value) {
        case "NaN":
          return NaN;
        case "Infinity":
          return Infinity;
        case "-Infinity":
          return -Infinity;
        default:
          throw new Error(`Unable to parse float value: ${value}`);
      }
    }, "parseFloatString");
    strictParseLong2 = /* @__PURE__ */ __name((value) => {
      if (typeof value === "string") {
        return expectLong3(parseNumber3(value));
      }
      return expectLong3(value);
    }, "strictParseLong");
    strictParseInt2 = strictParseLong2;
    strictParseInt322 = /* @__PURE__ */ __name((value) => {
      if (typeof value === "string") {
        return expectInt322(parseNumber3(value));
      }
      return expectInt322(value);
    }, "strictParseInt32");
    strictParseShort3 = /* @__PURE__ */ __name((value) => {
      if (typeof value === "string") {
        return expectShort3(parseNumber3(value));
      }
      return expectShort3(value);
    }, "strictParseShort");
    strictParseByte3 = /* @__PURE__ */ __name((value) => {
      if (typeof value === "string") {
        return expectByte3(parseNumber3(value));
      }
      return expectByte3(value);
    }, "strictParseByte");
    stackTraceWarning3 = /* @__PURE__ */ __name((message2) => {
      return String(new TypeError(message2).stack || message2).split("\n").slice(0, 5).filter((s) => !s.includes("stackTraceWarning")).join("\n");
    }, "stackTraceWarning");
    logger3 = {
      warn: console.warn
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/date-utils.js
function dateToUtcString15(date7) {
  const year7 = date7.getUTCFullYear();
  const month = date7.getUTCMonth();
  const dayOfWeek = date7.getUTCDay();
  const dayOfMonthInt = date7.getUTCDate();
  const hoursInt = date7.getUTCHours();
  const minutesInt = date7.getUTCMinutes();
  const secondsInt = date7.getUTCSeconds();
  const dayOfMonthString = dayOfMonthInt < 10 ? `0${dayOfMonthInt}` : `${dayOfMonthInt}`;
  const hoursString = hoursInt < 10 ? `0${hoursInt}` : `${hoursInt}`;
  const minutesString = minutesInt < 10 ? `0${minutesInt}` : `${minutesInt}`;
  const secondsString = secondsInt < 10 ? `0${secondsInt}` : `${secondsInt}`;
  return `${DAYS3[dayOfWeek]}, ${dayOfMonthString} ${MONTHS4[month]} ${year7} ${hoursString}:${minutesString}:${secondsString} GMT`;
}
var DAYS3, MONTHS4, RFC33394, parseRfc3339DateTime4, RFC3339_WITH_OFFSET6, parseRfc3339DateTimeWithOffset4, IMF_FIXDATE6, RFC_850_DATE6, ASC_TIME6, parseRfc7231DateTime4, parseEpochTimestamp4, buildDate3, parseTwoDigitYear3, FIFTY_YEARS_IN_MILLIS4, adjustRfc850Year3, parseMonthByShortName3, DAYS_IN_MONTH3, validateDayOfMonth3, isLeapYear3, parseDateValue3, parseMilliseconds3, parseOffsetToMilliseconds2, stripLeadingZeroes3;
var init_date_utils4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/date-utils.js"() {
    init_parse_utils3();
    DAYS3 = ["Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"];
    MONTHS4 = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"];
    __name(dateToUtcString15, "dateToUtcString");
    RFC33394 = new RegExp(/^(\d{4})-(\d{2})-(\d{2})[tT](\d{2}):(\d{2}):(\d{2})(?:\.(\d+))?[zZ]$/);
    parseRfc3339DateTime4 = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      if (typeof value !== "string") {
        throw new TypeError("RFC-3339 date-times must be expressed as strings");
      }
      const match = RFC33394.exec(value);
      if (!match) {
        throw new TypeError("Invalid RFC-3339 date-time value");
      }
      const [_, yearStr, monthStr, dayStr, hours, minutes, seconds, fractionalMilliseconds] = match;
      const year7 = strictParseShort3(stripLeadingZeroes3(yearStr));
      const month = parseDateValue3(monthStr, "month", 1, 12);
      const day = parseDateValue3(dayStr, "day", 1, 31);
      return buildDate3(year7, month, day, { hours, minutes, seconds, fractionalMilliseconds });
    }, "parseRfc3339DateTime");
    RFC3339_WITH_OFFSET6 = new RegExp(/^(\d{4})-(\d{2})-(\d{2})[tT](\d{2}):(\d{2}):(\d{2})(?:\.(\d+))?(([-+]\d{2}\:\d{2})|[zZ])$/);
    parseRfc3339DateTimeWithOffset4 = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      if (typeof value !== "string") {
        throw new TypeError("RFC-3339 date-times must be expressed as strings");
      }
      const match = RFC3339_WITH_OFFSET6.exec(value);
      if (!match) {
        throw new TypeError("Invalid RFC-3339 date-time value");
      }
      const [_, yearStr, monthStr, dayStr, hours, minutes, seconds, fractionalMilliseconds, offsetStr] = match;
      const year7 = strictParseShort3(stripLeadingZeroes3(yearStr));
      const month = parseDateValue3(monthStr, "month", 1, 12);
      const day = parseDateValue3(dayStr, "day", 1, 31);
      const date7 = buildDate3(year7, month, day, { hours, minutes, seconds, fractionalMilliseconds });
      if (offsetStr.toUpperCase() != "Z") {
        date7.setTime(date7.getTime() - parseOffsetToMilliseconds2(offsetStr));
      }
      return date7;
    }, "parseRfc3339DateTimeWithOffset");
    IMF_FIXDATE6 = new RegExp(/^(?:Mon|Tue|Wed|Thu|Fri|Sat|Sun), (\d{2}) (Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec) (\d{4}) (\d{1,2}):(\d{2}):(\d{2})(?:\.(\d+))? GMT$/);
    RFC_850_DATE6 = new RegExp(/^(?:Monday|Tuesday|Wednesday|Thursday|Friday|Saturday|Sunday), (\d{2})-(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)-(\d{2}) (\d{1,2}):(\d{2}):(\d{2})(?:\.(\d+))? GMT$/);
    ASC_TIME6 = new RegExp(/^(?:Mon|Tue|Wed|Thu|Fri|Sat|Sun) (Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec) ( [1-9]|\d{2}) (\d{1,2}):(\d{2}):(\d{2})(?:\.(\d+))? (\d{4})$/);
    parseRfc7231DateTime4 = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      if (typeof value !== "string") {
        throw new TypeError("RFC-7231 date-times must be expressed as strings");
      }
      let match = IMF_FIXDATE6.exec(value);
      if (match) {
        const [_, dayStr, monthStr, yearStr, hours, minutes, seconds, fractionalMilliseconds] = match;
        return buildDate3(strictParseShort3(stripLeadingZeroes3(yearStr)), parseMonthByShortName3(monthStr), parseDateValue3(dayStr, "day", 1, 31), { hours, minutes, seconds, fractionalMilliseconds });
      }
      match = RFC_850_DATE6.exec(value);
      if (match) {
        const [_, dayStr, monthStr, yearStr, hours, minutes, seconds, fractionalMilliseconds] = match;
        return adjustRfc850Year3(buildDate3(parseTwoDigitYear3(yearStr), parseMonthByShortName3(monthStr), parseDateValue3(dayStr, "day", 1, 31), {
          hours,
          minutes,
          seconds,
          fractionalMilliseconds
        }));
      }
      match = ASC_TIME6.exec(value);
      if (match) {
        const [_, monthStr, dayStr, hours, minutes, seconds, fractionalMilliseconds, yearStr] = match;
        return buildDate3(strictParseShort3(stripLeadingZeroes3(yearStr)), parseMonthByShortName3(monthStr), parseDateValue3(dayStr.trimLeft(), "day", 1, 31), { hours, minutes, seconds, fractionalMilliseconds });
      }
      throw new TypeError("Invalid RFC-7231 date-time value");
    }, "parseRfc7231DateTime");
    parseEpochTimestamp4 = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      let valueAsDouble;
      if (typeof value === "number") {
        valueAsDouble = value;
      } else if (typeof value === "string") {
        valueAsDouble = strictParseDouble3(value);
      } else if (typeof value === "object" && value.tag === 1) {
        valueAsDouble = value.value;
      } else {
        throw new TypeError("Epoch timestamps must be expressed as floating point numbers or their string representation");
      }
      if (Number.isNaN(valueAsDouble) || valueAsDouble === Infinity || valueAsDouble === -Infinity) {
        throw new TypeError("Epoch timestamps must be valid, non-Infinite, non-NaN numerics");
      }
      return new Date(Math.round(valueAsDouble * 1e3));
    }, "parseEpochTimestamp");
    buildDate3 = /* @__PURE__ */ __name((year7, month, day, time7) => {
      const adjustedMonth = month - 1;
      validateDayOfMonth3(year7, adjustedMonth, day);
      return new Date(Date.UTC(year7, adjustedMonth, day, parseDateValue3(time7.hours, "hour", 0, 23), parseDateValue3(time7.minutes, "minute", 0, 59), parseDateValue3(time7.seconds, "seconds", 0, 60), parseMilliseconds3(time7.fractionalMilliseconds)));
    }, "buildDate");
    parseTwoDigitYear3 = /* @__PURE__ */ __name((value) => {
      const thisYear = (/* @__PURE__ */ new Date()).getUTCFullYear();
      const valueInThisCentury = Math.floor(thisYear / 100) * 100 + strictParseShort3(stripLeadingZeroes3(value));
      if (valueInThisCentury < thisYear) {
        return valueInThisCentury + 100;
      }
      return valueInThisCentury;
    }, "parseTwoDigitYear");
    FIFTY_YEARS_IN_MILLIS4 = 50 * 365 * 24 * 60 * 60 * 1e3;
    adjustRfc850Year3 = /* @__PURE__ */ __name((input) => {
      if (input.getTime() - (/* @__PURE__ */ new Date()).getTime() > FIFTY_YEARS_IN_MILLIS4) {
        return new Date(Date.UTC(input.getUTCFullYear() - 100, input.getUTCMonth(), input.getUTCDate(), input.getUTCHours(), input.getUTCMinutes(), input.getUTCSeconds(), input.getUTCMilliseconds()));
      }
      return input;
    }, "adjustRfc850Year");
    parseMonthByShortName3 = /* @__PURE__ */ __name((value) => {
      const monthIdx = MONTHS4.indexOf(value);
      if (monthIdx < 0) {
        throw new TypeError(`Invalid month: ${value}`);
      }
      return monthIdx + 1;
    }, "parseMonthByShortName");
    DAYS_IN_MONTH3 = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];
    validateDayOfMonth3 = /* @__PURE__ */ __name((year7, month, day) => {
      let maxDays = DAYS_IN_MONTH3[month];
      if (month === 1 && isLeapYear3(year7)) {
        maxDays = 29;
      }
      if (day > maxDays) {
        throw new TypeError(`Invalid day for ${MONTHS4[month]} in ${year7}: ${day}`);
      }
    }, "validateDayOfMonth");
    isLeapYear3 = /* @__PURE__ */ __name((year7) => {
      return year7 % 4 === 0 && (year7 % 100 !== 0 || year7 % 400 === 0);
    }, "isLeapYear");
    parseDateValue3 = /* @__PURE__ */ __name((value, type, lower, upper) => {
      const dateVal = strictParseByte3(stripLeadingZeroes3(value));
      if (dateVal < lower || dateVal > upper) {
        throw new TypeError(`${type} must be between ${lower} and ${upper}, inclusive`);
      }
      return dateVal;
    }, "parseDateValue");
    parseMilliseconds3 = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return 0;
      }
      return strictParseFloat323("0." + value) * 1e3;
    }, "parseMilliseconds");
    parseOffsetToMilliseconds2 = /* @__PURE__ */ __name((value) => {
      const directionStr = value[0];
      let direction = 1;
      if (directionStr == "+") {
        direction = 1;
      } else if (directionStr == "-") {
        direction = -1;
      } else {
        throw new TypeError(`Offset direction, ${directionStr}, must be "+" or "-"`);
      }
      const hour = Number(value.substring(1, 3));
      const minute = Number(value.substring(4, 6));
      return direction * (hour * 60 + minute) * 60 * 1e3;
    }, "parseOffsetToMilliseconds");
    stripLeadingZeroes3 = /* @__PURE__ */ __name((value) => {
      let idx = 0;
      while (idx < value.length - 1 && value.charAt(idx) === "0") {
        idx++;
      }
      if (idx === 0) {
        return value;
      }
      return value.slice(idx);
    }, "stripLeadingZeroes");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/lazy-json.js
var LazyJsonString5;
var init_lazy_json3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/lazy-json.js"() {
    LazyJsonString5 = /* @__PURE__ */ __name(function LazyJsonString6(val) {
      const str = Object.assign(new String(val), {
        deserializeJSON() {
          return JSON.parse(String(val));
        },
        toString() {
          return String(val);
        },
        toJSON() {
          return String(val);
        }
      });
      return str;
    }, "LazyJsonString");
    LazyJsonString5.from = (object) => {
      if (object && typeof object === "object" && (object instanceof LazyJsonString5 || "deserializeJSON" in object)) {
        return object;
      } else if (typeof object === "string" || Object.getPrototypeOf(object) === String.prototype) {
        return LazyJsonString5(String(object));
      }
      return LazyJsonString5(JSON.stringify(object));
    };
    LazyJsonString5.fromObject = LazyJsonString5.from;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/quote-header.js
function quoteHeader3(part) {
  if (part.includes(",") || part.includes('"')) {
    part = `"${part.replace(/"/g, '\\"')}"`;
  }
  return part;
}
var init_quote_header3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/quote-header.js"() {
    __name(quoteHeader3, "quoteHeader");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/schema-serde-lib/schema-date-utils.js
function range3(v, min, max) {
  const _v = Number(v);
  if (_v < min || _v > max) {
    throw new Error(`Value ${_v} out of range [${min}, ${max}]`);
  }
}
var ddd3, mmm3, time3, date3, year3, RFC3339_WITH_OFFSET7, IMF_FIXDATE7, RFC_850_DATE7, ASC_TIME7, months3, _parseEpochTimestamp3, _parseRfc3339DateTimeWithOffset3, _parseRfc7231DateTime3;
var init_schema_date_utils3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/schema-serde-lib/schema-date-utils.js"() {
    ddd3 = `(?:Mon|Tue|Wed|Thu|Fri|Sat|Sun)(?:[ne|u?r]?s?day)?`;
    mmm3 = `(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)`;
    time3 = `(\\d?\\d):(\\d{2}):(\\d{2})(?:\\.(\\d+))?`;
    date3 = `(\\d?\\d)`;
    year3 = `(\\d{4})`;
    RFC3339_WITH_OFFSET7 = new RegExp(/^(\d{4})-(\d\d)-(\d\d)[tT](\d\d):(\d\d):(\d\d)(\.(\d+))?(([-+]\d\d:\d\d)|[zZ])$/);
    IMF_FIXDATE7 = new RegExp(`^${ddd3}, ${date3} ${mmm3} ${year3} ${time3} GMT$`);
    RFC_850_DATE7 = new RegExp(`^${ddd3}, ${date3}-${mmm3}-(\\d\\d) ${time3} GMT$`);
    ASC_TIME7 = new RegExp(`^${ddd3} ${mmm3} ( [1-9]|\\d\\d) ${time3} ${year3}$`);
    months3 = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"];
    _parseEpochTimestamp3 = /* @__PURE__ */ __name((value) => {
      if (value == null) {
        return void 0;
      }
      let num = NaN;
      if (typeof value === "number") {
        num = value;
      } else if (typeof value === "string") {
        if (!/^-?\d*\.?\d+$/.test(value)) {
          throw new TypeError(`parseEpochTimestamp - numeric string invalid.`);
        }
        num = Number.parseFloat(value);
      } else if (typeof value === "object" && value.tag === 1) {
        num = value.value;
      }
      if (isNaN(num) || Math.abs(num) === Infinity) {
        throw new TypeError("Epoch timestamps must be valid finite numbers.");
      }
      return new Date(Math.round(num * 1e3));
    }, "_parseEpochTimestamp");
    _parseRfc3339DateTimeWithOffset3 = /* @__PURE__ */ __name((value) => {
      if (value == null) {
        return void 0;
      }
      if (typeof value !== "string") {
        throw new TypeError("RFC3339 timestamps must be strings");
      }
      const matches = RFC3339_WITH_OFFSET7.exec(value);
      if (!matches) {
        throw new TypeError(`Invalid RFC3339 timestamp format ${value}`);
      }
      const [, yearStr, monthStr, dayStr, hours, minutes, seconds, , ms, offsetStr] = matches;
      range3(monthStr, 1, 12);
      range3(dayStr, 1, 31);
      range3(hours, 0, 23);
      range3(minutes, 0, 59);
      range3(seconds, 0, 60);
      const date7 = new Date(Date.UTC(Number(yearStr), Number(monthStr) - 1, Number(dayStr), Number(hours), Number(minutes), Number(seconds), Number(ms) ? Math.round(parseFloat(`0.${ms}`) * 1e3) : 0));
      date7.setUTCFullYear(Number(yearStr));
      if (offsetStr.toUpperCase() != "Z") {
        const [, sign, offsetH, offsetM] = /([+-])(\d\d):(\d\d)/.exec(offsetStr) || [void 0, "+", 0, 0];
        const scalar = sign === "-" ? 1 : -1;
        date7.setTime(date7.getTime() + scalar * (Number(offsetH) * 60 * 60 * 1e3 + Number(offsetM) * 60 * 1e3));
      }
      return date7;
    }, "_parseRfc3339DateTimeWithOffset");
    _parseRfc7231DateTime3 = /* @__PURE__ */ __name((value) => {
      if (value == null) {
        return void 0;
      }
      if (typeof value !== "string") {
        throw new TypeError("RFC7231 timestamps must be strings.");
      }
      let day;
      let month;
      let year7;
      let hour;
      let minute;
      let second;
      let fraction;
      let matches;
      if (matches = IMF_FIXDATE7.exec(value)) {
        [, day, month, year7, hour, minute, second, fraction] = matches;
      } else if (matches = RFC_850_DATE7.exec(value)) {
        [, day, month, year7, hour, minute, second, fraction] = matches;
        year7 = (Number(year7) + 1900).toString();
      } else if (matches = ASC_TIME7.exec(value)) {
        [, month, day, hour, minute, second, fraction, year7] = matches;
      }
      if (year7 && second) {
        const timestamp = Date.UTC(Number(year7), months3.indexOf(month), Number(day), Number(hour), Number(minute), Number(second), fraction ? Math.round(parseFloat(`0.${fraction}`) * 1e3) : 0);
        range3(day, 1, 31);
        range3(hour, 0, 23);
        range3(minute, 0, 59);
        range3(second, 0, 60);
        const date7 = new Date(timestamp);
        date7.setUTCFullYear(Number(year7));
        return date7;
      }
      throw new TypeError(`Invalid RFC7231 date-time value ${value}.`);
    }, "_parseRfc7231DateTime");
    __name(range3, "range");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/split-every.js
function splitEvery3(value, delimiter2, numDelimiters) {
  if (numDelimiters <= 0 || !Number.isInteger(numDelimiters)) {
    throw new Error("Invalid number of delimiters (" + numDelimiters + ") for splitEvery.");
  }
  const segments = value.split(delimiter2);
  if (numDelimiters === 1) {
    return segments;
  }
  const compoundSegments = [];
  let currentSegment = "";
  for (let i32 = 0; i32 < segments.length; i32++) {
    if (currentSegment === "") {
      currentSegment = segments[i32];
    } else {
      currentSegment += delimiter2 + segments[i32];
    }
    if ((i32 + 1) % numDelimiters === 0) {
      compoundSegments.push(currentSegment);
      currentSegment = "";
    }
  }
  if (currentSegment !== "") {
    compoundSegments.push(currentSegment);
  }
  return compoundSegments;
}
var init_split_every3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/split-every.js"() {
    __name(splitEvery3, "splitEvery");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/split-header.js
var splitHeader3;
var init_split_header3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/split-header.js"() {
    splitHeader3 = /* @__PURE__ */ __name((value) => {
      const z = value.length;
      const values = [];
      let withinQuotes = false;
      let prevChar = void 0;
      let anchor = 0;
      for (let i32 = 0; i32 < z; ++i32) {
        const char = value[i32];
        switch (char) {
          case `"`:
            if (prevChar !== "\\") {
              withinQuotes = !withinQuotes;
            }
            break;
          case ",":
            if (!withinQuotes) {
              values.push(value.slice(anchor, i32));
              anchor = i32 + 1;
            }
            break;
          default:
        }
        prevChar = char;
      }
      values.push(value.slice(anchor));
      return values.map((v) => {
        v = v.trim();
        const z2 = v.length;
        if (z2 < 2) {
          return v;
        }
        if (v[0] === `"` && v[z2 - 1] === `"`) {
          v = v.slice(1, z2 - 1);
        }
        return v.replace(/\\"/g, '"');
      });
    }, "splitHeader");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/value/NumericValue.js
function nv3(input) {
  return new NumericValue3(String(input), "bigDecimal");
}
var format13, NumericValue3;
var init_NumericValue3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/value/NumericValue.js"() {
    format13 = /^-?\d*(\.\d+)?$/;
    NumericValue3 = class _NumericValue {
      static {
        __name(this, "NumericValue");
      }
      string;
      type;
      constructor(string, type) {
        this.string = string;
        this.type = type;
        if (!format13.test(string)) {
          throw new Error(`@smithy/core/serde - NumericValue must only contain [0-9], at most one decimal point ".", and an optional negation prefix "-".`);
        }
      }
      toString() {
        return this.string;
      }
      static [Symbol.hasInstance](object) {
        if (!object || typeof object !== "object") {
          return false;
        }
        const _nv = object;
        return _NumericValue.prototype.isPrototypeOf(object) || _nv.type === "bigDecimal" && format13.test(_nv.string);
      }
    };
    __name(nv3, "nv");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-hex-encoding/hex-encoding.js
function fromHex2(encoded) {
  if (encoded.length % 2 !== 0) {
    throw new Error("Hex encoded strings must have an even number length");
  }
  const out = new Uint8Array(encoded.length / 2);
  for (let i32 = 0; i32 < encoded.length; i32 += 2) {
    const encodedByte = encoded.slice(i32, i32 + 2).toLowerCase();
    if (encodedByte in HEX_TO_SHORT2) {
      out[i32 / 2] = HEX_TO_SHORT2[encodedByte];
    } else {
      throw new Error(`Cannot decode unrecognized sequence ${encodedByte} as hexadecimal`);
    }
  }
  return out;
}
function toHex2(bytes) {
  let out = "";
  for (let i32 = 0; i32 < bytes.byteLength; i32++) {
    out += SHORT_TO_HEX2[bytes[i32]];
  }
  return out;
}
var SHORT_TO_HEX2, HEX_TO_SHORT2;
var init_hex_encoding2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-hex-encoding/hex-encoding.js"() {
    SHORT_TO_HEX2 = {};
    HEX_TO_SHORT2 = {};
    for (let i32 = 0; i32 < 256; i32++) {
      let encodedByte = i32.toString(16).toLowerCase();
      if (encodedByte.length === 1) {
        encodedByte = `0${encodedByte}`;
      }
      SHORT_TO_HEX2[i32] = encodedByte;
      HEX_TO_SHORT2[encodedByte] = i32;
    }
    __name(fromHex2, "fromHex");
    __name(toHex2, "toHex");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-body-length/calculateBodyLength.js
var import_node_fs, calculateBodyLength19;
var init_calculateBodyLength = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-body-length/calculateBodyLength.js"() {
    import_node_fs = require("node:fs");
    calculateBodyLength19 = /* @__PURE__ */ __name((body) => {
      if (!body) {
        return 0;
      }
      if (typeof body === "string") {
        return Buffer.byteLength(body);
      } else if (typeof body.byteLength === "number") {
        return body.byteLength;
      } else if (typeof body.size === "number") {
        return body.size;
      } else if (typeof body.start === "number" && typeof body.end === "number") {
        return body.end + 1 - body.start;
      } else if (body instanceof import_node_fs.ReadStream) {
        if (body.path != null) {
          return (0, import_node_fs.lstatSync)(body.path).size;
        } else if (typeof body.fd === "number") {
          return (0, import_node_fs.fstatSync)(body.fd).size;
        }
      }
      throw new Error(`Body Length computation failed for ${body}`);
    }, "calculateBodyLength");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/toUint8Array.js
var toUint8Array2;
var init_toUint8Array = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/toUint8Array.js"() {
    init_fromUtf83();
    toUint8Array2 = /* @__PURE__ */ __name((data3) => {
      if (typeof data3 === "string") {
        return fromUtf825(data3);
      }
      if (ArrayBuffer.isView(data3)) {
        return new Uint8Array(data3.buffer, data3.byteOffset, data3.byteLength / Uint8Array.BYTES_PER_ELEMENT);
      }
      return new Uint8Array(data3);
    }, "toUint8Array");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/middleware-serde/deserializerMiddleware.js
var deserializerMiddleware, findHeader2;
var init_deserializerMiddleware = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/middleware-serde/deserializerMiddleware.js"() {
    init_protocols11();
    deserializerMiddleware = /* @__PURE__ */ __name((options, deserializer) => (next, context) => async (args) => {
      const { response } = await next(args);
      try {
        const parsed = await deserializer(response, options);
        return {
          response,
          output: parsed
        };
      } catch (error4) {
        Object.defineProperty(error4, "$response", {
          value: response,
          enumerable: false,
          writable: false,
          configurable: false
        });
        if (!("$metadata" in error4)) {
          const hint = `Deserialization error: to see the raw response, inspect the hidden field {error}.$response on this object.`;
          try {
            error4.message += "\n  " + hint;
          } catch (e32) {
            if (!context.logger || context.logger?.constructor?.name === "NoOpLogger") {
              console.warn(hint);
            } else {
              context.logger?.warn?.(hint);
            }
          }
          if (typeof error4.$responseBodyText !== "undefined") {
            if (error4.$response) {
              error4.$response.body = error4.$responseBodyText;
            }
          }
          try {
            if (HttpResponse11.isInstance(response)) {
              const { headers = {} } = response;
              const headerEntries = Object.entries(headers);
              error4.$metadata = {
                httpStatusCode: response.statusCode,
                requestId: findHeader2(/^x-[\w-]+-request-?id$/, headerEntries),
                extendedRequestId: findHeader2(/^x-[\w-]+-id-2$/, headerEntries),
                cfId: findHeader2(/^x-[\w-]+-cf-id$/, headerEntries)
              };
            }
          } catch (e32) {
          }
        }
        throw error4;
      }
    }, "deserializerMiddleware");
    findHeader2 = /* @__PURE__ */ __name((pattern, headers) => {
      return (headers.find(([k32]) => {
        return k32.match(pattern);
      }) || [void 0, void 0])[1];
    }, "findHeader");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/property-provider/ProviderError.js
var ProviderError8;
var init_ProviderError2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/property-provider/ProviderError.js"() {
    ProviderError8 = class _ProviderError extends Error {
      static {
        __name(this, "ProviderError");
      }
      name = "ProviderError";
      tryNextLink;
      constructor(message2, options = true) {
        let logger5;
        let tryNextLink = true;
        if (typeof options === "boolean") {
          logger5 = void 0;
          tryNextLink = options;
        } else if (options != null && typeof options === "object") {
          logger5 = options.logger;
          tryNextLink = options.tryNextLink ?? true;
        }
        super(message2);
        this.tryNextLink = tryNextLink;
        Object.setPrototypeOf(this, _ProviderError.prototype);
        logger5?.debug?.(`@smithy/property-provider ${tryNextLink ? "->" : "(!)"} ${message2}`);
      }
      static from(error4, options = true) {
        return Object.assign(new this(error4.message, options), error4);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/property-provider/CredentialsProviderError.js
var CredentialsProviderError2;
var init_CredentialsProviderError2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/property-provider/CredentialsProviderError.js"() {
    init_ProviderError2();
    CredentialsProviderError2 = class _CredentialsProviderError extends ProviderError8 {
      static {
        __name(this, "CredentialsProviderError");
      }
      name = "CredentialsProviderError";
      constructor(message2, options = true) {
        super(message2, options);
        Object.setPrototypeOf(this, _CredentialsProviderError.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/property-provider/TokenProviderError.js
var TokenProviderError;
var init_TokenProviderError = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/property-provider/TokenProviderError.js"() {
    init_ProviderError2();
    TokenProviderError = class _TokenProviderError extends ProviderError8 {
      static {
        __name(this, "TokenProviderError");
      }
      name = "TokenProviderError";
      constructor(message2, options = true) {
        super(message2, options);
        Object.setPrototypeOf(this, _TokenProviderError.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/property-provider/chain.js
var chain2;
var init_chain2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/property-provider/chain.js"() {
    init_ProviderError2();
    chain2 = /* @__PURE__ */ __name((...providers) => async () => {
      if (providers.length === 0) {
        throw new ProviderError8("No providers in chain");
      }
      let lastProviderError;
      for (const provider of providers) {
        try {
          const credentials = await provider();
          return credentials;
        } catch (err) {
          lastProviderError = err;
          if (err?.tryNextLink) {
            continue;
          }
          throw err;
        }
      }
      throw lastProviderError;
    }, "chain");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/property-provider/fromValue.js
var fromValue2;
var init_fromValue2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/property-provider/fromValue.js"() {
    fromValue2 = /* @__PURE__ */ __name((staticValue) => () => Promise.resolve(staticValue), "fromValue");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/property-provider/memoize.js
var memoize2;
var init_memoize2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/property-provider/memoize.js"() {
    memoize2 = /* @__PURE__ */ __name((provider, isExpired, requiresRefresh) => {
      let resolved;
      let pending;
      let hasResult;
      let isConstant = false;
      const coalesceProvider = /* @__PURE__ */ __name(async () => {
        if (!pending) {
          pending = provider();
        }
        try {
          resolved = await pending;
          hasResult = true;
          isConstant = false;
        } finally {
          pending = void 0;
        }
        return resolved;
      }, "coalesceProvider");
      if (isExpired === void 0) {
        return async (options) => {
          if (!hasResult || options?.forceRefresh) {
            resolved = await coalesceProvider();
          }
          return resolved;
        };
      }
      return async (options) => {
        if (!hasResult || options?.forceRefresh) {
          resolved = await coalesceProvider();
        }
        if (isConstant) {
          return resolved;
        }
        if (requiresRefresh && !requiresRefresh(resolved)) {
          isConstant = true;
          return resolved;
        }
        if (isExpired(resolved)) {
          await coalesceProvider();
          return resolved;
        }
        return resolved;
      };
    }, "memoize");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/util-config-provider/booleanSelector.js
var booleanSelector;
var init_booleanSelector = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/util-config-provider/booleanSelector.js"() {
    booleanSelector = /* @__PURE__ */ __name((obj, key, type) => {
      if (!(key in obj))
        return void 0;
      if (obj[key] === "true")
        return true;
      if (obj[key] === "false")
        return false;
      throw new Error(`Cannot load ${type} "${key}". Expected "true" or "false", got ${obj[key]}.`);
    }, "booleanSelector");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/util-config-provider/numberSelector.js
var numberSelector;
var init_numberSelector = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/util-config-provider/numberSelector.js"() {
    numberSelector = /* @__PURE__ */ __name((obj, key, type) => {
      if (!(key in obj))
        return void 0;
      const numberValue = parseInt(obj[key], 10);
      if (Number.isNaN(numberValue)) {
        throw new TypeError(`Cannot load ${type} '${key}'. Expected number, got '${obj[key]}'.`);
      }
      return numberValue;
    }, "numberSelector");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/util-config-provider/types.js
var SelectorType;
var init_types7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/util-config-provider/types.js"() {
    (function(SelectorType3) {
      SelectorType3["ENV"] = "env";
      SelectorType3["CONFIG"] = "shared config entry";
    })(SelectorType || (SelectorType = {}));
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getHomeDir.js
var import_node_os2, import_node_path5, homeDirCache2, getHomeDirCacheKey2, getHomeDir2;
var init_getHomeDir2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getHomeDir.js"() {
    import_node_os2 = require("node:os");
    import_node_path5 = require("node:path");
    homeDirCache2 = {};
    getHomeDirCacheKey2 = /* @__PURE__ */ __name(() => {
      if (process && process.geteuid) {
        return `${process.geteuid()}`;
      }
      return "DEFAULT";
    }, "getHomeDirCacheKey");
    getHomeDir2 = /* @__PURE__ */ __name(() => {
      const { HOME, USERPROFILE, HOMEPATH, HOMEDRIVE = `C:${import_node_path5.sep}` } = process.env;
      if (HOME)
        return HOME;
      if (USERPROFILE)
        return USERPROFILE;
      if (HOMEPATH)
        return `${HOMEDRIVE}${HOMEPATH}`;
      const homeDirCacheKey = getHomeDirCacheKey2();
      if (!homeDirCache2[homeDirCacheKey])
        homeDirCache2[homeDirCacheKey] = (0, import_node_os2.homedir)();
      return homeDirCache2[homeDirCacheKey];
    }, "getHomeDir");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getProfileName.js
var ENV_PROFILE2, DEFAULT_PROFILE2, getProfileName2;
var init_getProfileName2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getProfileName.js"() {
    ENV_PROFILE2 = "AWS_PROFILE";
    DEFAULT_PROFILE2 = "default";
    getProfileName2 = /* @__PURE__ */ __name((init) => init.profile || process.env[ENV_PROFILE2] || DEFAULT_PROFILE2, "getProfileName");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getSSOTokenFilepath.js
var import_node_crypto8, import_node_path6, getSSOTokenFilepath;
var init_getSSOTokenFilepath = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getSSOTokenFilepath.js"() {
    import_node_crypto8 = require("node:crypto");
    import_node_path6 = require("node:path");
    init_getHomeDir2();
    getSSOTokenFilepath = /* @__PURE__ */ __name((id) => {
      const hasher = (0, import_node_crypto8.createHash)("sha1");
      const cacheName = hasher.update(id).digest("hex");
      return (0, import_node_path6.join)(getHomeDir2(), ".aws", "sso", "cache", `${cacheName}.json`);
    }, "getSSOTokenFilepath");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getSSOTokenFromFile.js
var import_promises2, tokenIntercept, getSSOTokenFromFile;
var init_getSSOTokenFromFile = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getSSOTokenFromFile.js"() {
    import_promises2 = require("node:fs/promises");
    init_getSSOTokenFilepath();
    tokenIntercept = {};
    getSSOTokenFromFile = /* @__PURE__ */ __name(async (id) => {
      if (tokenIntercept[id]) {
        return tokenIntercept[id];
      }
      const ssoTokenFilepath = getSSOTokenFilepath(id);
      const ssoTokenText = await (0, import_promises2.readFile)(ssoTokenFilepath, "utf8");
      return JSON.parse(ssoTokenText);
    }, "getSSOTokenFromFile");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/constants.js
var CONFIG_PREFIX_SEPARATOR2;
var init_constants4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/constants.js"() {
    CONFIG_PREFIX_SEPARATOR2 = ".";
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getConfigData.js
var import_types22, getConfigData2;
var init_getConfigData2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getConfigData.js"() {
    import_types22 = __toESM(require_dist_cjs());
    init_constants4();
    getConfigData2 = /* @__PURE__ */ __name((data3) => Object.entries(data3).filter(([key]) => {
      const indexOfSeparator = key.indexOf(CONFIG_PREFIX_SEPARATOR2);
      if (indexOfSeparator === -1) {
        return false;
      }
      return Object.values(import_types22.IniSectionType).includes(key.substring(0, indexOfSeparator));
    }).reduce((acc, [key, value]) => {
      const indexOfSeparator = key.indexOf(CONFIG_PREFIX_SEPARATOR2);
      const updatedKey = key.substring(0, indexOfSeparator) === import_types22.IniSectionType.PROFILE ? key.substring(indexOfSeparator + 1) : key;
      acc[updatedKey] = value;
      return acc;
    }, {
      ...data3.default && { default: data3.default }
    }), "getConfigData");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getConfigFilepath.js
var import_node_path7, ENV_CONFIG_PATH2, getConfigFilepath2;
var init_getConfigFilepath2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getConfigFilepath.js"() {
    import_node_path7 = require("node:path");
    init_getHomeDir2();
    ENV_CONFIG_PATH2 = "AWS_CONFIG_FILE";
    getConfigFilepath2 = /* @__PURE__ */ __name(() => process.env[ENV_CONFIG_PATH2] || (0, import_node_path7.join)(getHomeDir2(), ".aws", "config"), "getConfigFilepath");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getCredentialsFilepath.js
var import_node_path8, ENV_CREDENTIALS_PATH2, getCredentialsFilepath2;
var init_getCredentialsFilepath2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getCredentialsFilepath.js"() {
    import_node_path8 = require("node:path");
    init_getHomeDir2();
    ENV_CREDENTIALS_PATH2 = "AWS_SHARED_CREDENTIALS_FILE";
    getCredentialsFilepath2 = /* @__PURE__ */ __name(() => process.env[ENV_CREDENTIALS_PATH2] || (0, import_node_path8.join)(getHomeDir2(), ".aws", "credentials"), "getCredentialsFilepath");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/parseIni.js
var import_types23, prefixKeyRegex2, profileNameBlockList2, parseIni2;
var init_parseIni2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/parseIni.js"() {
    import_types23 = __toESM(require_dist_cjs());
    init_constants4();
    prefixKeyRegex2 = /^([\w-]+)\s(["'])?([\w-@\+\.%:/]+)\2$/;
    profileNameBlockList2 = ["__proto__", "profile __proto__"];
    parseIni2 = /* @__PURE__ */ __name((iniData) => {
      const map5 = {};
      let currentSection;
      let currentSubSection;
      for (const iniLine of iniData.split(/\r?\n/)) {
        const trimmedLine = iniLine.split(/(^|\s)[;#]/)[0].trim();
        const isSection = trimmedLine[0] === "[" && trimmedLine[trimmedLine.length - 1] === "]";
        if (isSection) {
          currentSection = void 0;
          currentSubSection = void 0;
          const sectionName = trimmedLine.substring(1, trimmedLine.length - 1);
          const matches = prefixKeyRegex2.exec(sectionName);
          if (matches) {
            const [, prefix, , name] = matches;
            if (Object.values(import_types23.IniSectionType).includes(prefix)) {
              currentSection = [prefix, name].join(CONFIG_PREFIX_SEPARATOR2);
            }
          } else {
            currentSection = sectionName;
          }
          if (profileNameBlockList2.includes(sectionName)) {
            throw new Error(`Found invalid profile name "${sectionName}"`);
          }
        } else if (currentSection) {
          const indexOfEqualsSign = trimmedLine.indexOf("=");
          if (![0, -1].includes(indexOfEqualsSign)) {
            const [name, value] = [
              trimmedLine.substring(0, indexOfEqualsSign).trim(),
              trimmedLine.substring(indexOfEqualsSign + 1).trim()
            ];
            if (value === "") {
              currentSubSection = name;
            } else {
              if (currentSubSection && iniLine.trimStart() === iniLine) {
                currentSubSection = void 0;
              }
              map5[currentSection] = map5[currentSection] || {};
              const key = currentSubSection ? [currentSubSection, name].join(CONFIG_PREFIX_SEPARATOR2) : name;
              map5[currentSection][key] = value;
            }
          }
        }
      }
      return map5;
    }, "parseIni");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/readFile.js
var import_promises3, filePromises2, fileIntercept2, readFile5;
var init_readFile2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/readFile.js"() {
    import_promises3 = require("node:fs/promises");
    filePromises2 = {};
    fileIntercept2 = {};
    readFile5 = /* @__PURE__ */ __name((path47, options) => {
      if (fileIntercept2[path47] !== void 0) {
        return fileIntercept2[path47];
      }
      if (!filePromises2[path47] || options?.ignoreCache) {
        filePromises2[path47] = (0, import_promises3.readFile)(path47, "utf8");
      }
      return filePromises2[path47];
    }, "readFile");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/loadSharedConfigFiles.js
var import_node_path9, swallowError2, loadSharedConfigFiles2;
var init_loadSharedConfigFiles2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/loadSharedConfigFiles.js"() {
    import_node_path9 = require("node:path");
    init_getConfigData2();
    init_getConfigFilepath2();
    init_getCredentialsFilepath2();
    init_getHomeDir2();
    init_parseIni2();
    init_readFile2();
    init_constants4();
    swallowError2 = /* @__PURE__ */ __name(() => ({}), "swallowError");
    loadSharedConfigFiles2 = /* @__PURE__ */ __name(async (init = {}) => {
      const { filepath = getCredentialsFilepath2(), configFilepath = getConfigFilepath2() } = init;
      const homeDir = getHomeDir2();
      const relativeHomeDirPrefix = "~/";
      let resolvedFilepath = filepath;
      if (filepath.startsWith(relativeHomeDirPrefix)) {
        resolvedFilepath = (0, import_node_path9.join)(homeDir, filepath.slice(2));
      }
      let resolvedConfigFilepath = configFilepath;
      if (configFilepath.startsWith(relativeHomeDirPrefix)) {
        resolvedConfigFilepath = (0, import_node_path9.join)(homeDir, configFilepath.slice(2));
      }
      const parsedFiles = await Promise.all([
        readFile5(resolvedConfigFilepath, {
          ignoreCache: init.ignoreCache
        }).then(parseIni2).then(getConfigData2).catch(swallowError2),
        readFile5(resolvedFilepath, {
          ignoreCache: init.ignoreCache
        }).then(parseIni2).catch(swallowError2)
      ]);
      return {
        configFile: parsedFiles[0],
        credentialsFile: parsedFiles[1]
      };
    }, "loadSharedConfigFiles");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getSsoSessionData.js
var import_types24, getSsoSessionData;
var init_getSsoSessionData = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getSsoSessionData.js"() {
    import_types24 = __toESM(require_dist_cjs());
    init_loadSharedConfigFiles2();
    getSsoSessionData = /* @__PURE__ */ __name((data3) => Object.entries(data3).filter(([key]) => key.startsWith(import_types24.IniSectionType.SSO_SESSION + CONFIG_PREFIX_SEPARATOR2)).reduce((acc, [key, value]) => ({ ...acc, [key.substring(key.indexOf(CONFIG_PREFIX_SEPARATOR2) + 1)]: value }), {}), "getSsoSessionData");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/loadSsoSessionData.js
var swallowError3, loadSsoSessionData;
var init_loadSsoSessionData = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/loadSsoSessionData.js"() {
    init_getConfigFilepath2();
    init_getSsoSessionData();
    init_parseIni2();
    init_readFile2();
    swallowError3 = /* @__PURE__ */ __name(() => ({}), "swallowError");
    loadSsoSessionData = /* @__PURE__ */ __name(async (init = {}) => readFile5(init.configFilepath ?? getConfigFilepath2()).then(parseIni2).then(getSsoSessionData).catch(swallowError3), "loadSsoSessionData");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/mergeConfigFiles.js
var mergeConfigFiles;
var init_mergeConfigFiles = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/mergeConfigFiles.js"() {
    mergeConfigFiles = /* @__PURE__ */ __name((...files) => {
      const merged = {};
      for (const file of files) {
        for (const [key, values] of Object.entries(file)) {
          if (merged[key] !== void 0) {
            Object.assign(merged[key], values);
          } else {
            merged[key] = values;
          }
        }
      }
      return merged;
    }, "mergeConfigFiles");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/parseKnownFiles.js
var parseKnownFiles;
var init_parseKnownFiles = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/parseKnownFiles.js"() {
    init_loadSharedConfigFiles2();
    init_mergeConfigFiles();
    parseKnownFiles = /* @__PURE__ */ __name(async (init) => {
      const parsedFiles = await loadSharedConfigFiles2(init);
      return mergeConfigFiles(parsedFiles.configFile, parsedFiles.credentialsFile);
    }, "parseKnownFiles");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/externalDataInterceptor.js
var externalDataInterceptor;
var init_externalDataInterceptor = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/externalDataInterceptor.js"() {
    init_getSSOTokenFromFile();
    init_readFile2();
    externalDataInterceptor = {
      getFileRecord() {
        return fileIntercept2;
      },
      interceptFile(path47, contents) {
        fileIntercept2[path47] = Promise.resolve(contents);
      },
      getTokenRecord() {
        return tokenIntercept;
      },
      interceptToken(id, contents) {
        tokenIntercept[id] = contents;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/getSelectorName.js
function getSelectorName2(functionString) {
  try {
    const constants3 = new Set(Array.from(functionString.match(/([A-Z_]){3,}/g) ?? []));
    constants3.delete("CONFIG");
    constants3.delete("CONFIG_PREFIX_SEPARATOR");
    constants3.delete("ENV");
    return [...constants3].join(", ");
  } catch (e32) {
    return functionString;
  }
}
var init_getSelectorName2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/getSelectorName.js"() {
    __name(getSelectorName2, "getSelectorName");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/fromEnv.js
var fromEnv2;
var init_fromEnv2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/fromEnv.js"() {
    init_CredentialsProviderError2();
    init_getSelectorName2();
    fromEnv2 = /* @__PURE__ */ __name((envVarSelector, options) => async () => {
      try {
        const config2 = envVarSelector(process.env, options);
        if (config2 === void 0) {
          throw new Error();
        }
        return config2;
      } catch (e32) {
        throw new CredentialsProviderError2(e32.message || `Not found in ENV: ${getSelectorName2(envVarSelector.toString())}`, { logger: options?.logger });
      }
    }, "fromEnv");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/fromSharedConfigFiles.js
var fromSharedConfigFiles2;
var init_fromSharedConfigFiles2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/fromSharedConfigFiles.js"() {
    init_CredentialsProviderError2();
    init_getProfileName2();
    init_loadSharedConfigFiles2();
    init_getSelectorName2();
    fromSharedConfigFiles2 = /* @__PURE__ */ __name((configSelector, { preferredFile = "config", ...init } = {}) => async () => {
      const profile = getProfileName2(init);
      const { configFile, credentialsFile } = await loadSharedConfigFiles2(init);
      const profileFromCredentials = credentialsFile[profile] || {};
      const profileFromConfig = configFile[profile] || {};
      const mergedProfile = preferredFile === "config" ? { ...profileFromCredentials, ...profileFromConfig } : { ...profileFromConfig, ...profileFromCredentials };
      try {
        const cfgFile = preferredFile === "config" ? configFile : credentialsFile;
        const configValue = configSelector(mergedProfile, cfgFile);
        if (configValue === void 0) {
          throw new Error();
        }
        return configValue;
      } catch (e32) {
        throw new CredentialsProviderError2(e32.message || `Not found in config files w/ profile [${profile}]: ${getSelectorName2(configSelector.toString())}`, { logger: init.logger });
      }
    }, "fromSharedConfigFiles");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/fromStatic.js
var isFunction2, fromStatic2;
var init_fromStatic2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/fromStatic.js"() {
    init_fromValue2();
    isFunction2 = /* @__PURE__ */ __name((func) => typeof func === "function", "isFunction");
    fromStatic2 = /* @__PURE__ */ __name((defaultValue2) => isFunction2(defaultValue2) ? async () => await defaultValue2() : fromValue2(defaultValue2), "fromStatic");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/configLoader.js
var loadConfig3;
var init_configLoader2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/configLoader.js"() {
    init_chain2();
    init_memoize2();
    init_fromEnv2();
    init_fromSharedConfigFiles2();
    init_fromStatic2();
    loadConfig3 = /* @__PURE__ */ __name(({ environmentVariableSelector, configFileSelector, default: defaultValue2 }, configuration = {}) => {
      const { signingName, logger: logger5 } = configuration;
      const envOptions = { signingName, logger: logger5 };
      return memoize2(chain2(fromEnv2(environmentVariableSelector, envOptions), fromSharedConfigFiles2(configFileSelector, configuration), fromStatic2(defaultValue2)));
    }, "loadConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/endpointsConfig/NodeUseDualstackEndpointConfigOptions.js
var ENV_USE_DUALSTACK_ENDPOINT, CONFIG_USE_DUALSTACK_ENDPOINT, DEFAULT_USE_DUALSTACK_ENDPOINT, NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS19, nodeDualstackConfigSelectors;
var init_NodeUseDualstackEndpointConfigOptions = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/endpointsConfig/NodeUseDualstackEndpointConfigOptions.js"() {
    init_booleanSelector();
    init_types7();
    ENV_USE_DUALSTACK_ENDPOINT = "AWS_USE_DUALSTACK_ENDPOINT";
    CONFIG_USE_DUALSTACK_ENDPOINT = "use_dualstack_endpoint";
    DEFAULT_USE_DUALSTACK_ENDPOINT = false;
    NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS19 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => booleanSelector(env3, ENV_USE_DUALSTACK_ENDPOINT, SelectorType.ENV), "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => booleanSelector(profile, CONFIG_USE_DUALSTACK_ENDPOINT, SelectorType.CONFIG), "configFileSelector"),
      default: false
    };
    nodeDualstackConfigSelectors = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => booleanSelector(env3, ENV_USE_DUALSTACK_ENDPOINT, SelectorType.ENV), "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => booleanSelector(profile, CONFIG_USE_DUALSTACK_ENDPOINT, SelectorType.CONFIG), "configFileSelector"),
      default: void 0
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/endpointsConfig/NodeUseFipsEndpointConfigOptions.js
var ENV_USE_FIPS_ENDPOINT, CONFIG_USE_FIPS_ENDPOINT, DEFAULT_USE_FIPS_ENDPOINT, NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS19, nodeFipsConfigSelectors;
var init_NodeUseFipsEndpointConfigOptions = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/endpointsConfig/NodeUseFipsEndpointConfigOptions.js"() {
    init_booleanSelector();
    init_types7();
    ENV_USE_FIPS_ENDPOINT = "AWS_USE_FIPS_ENDPOINT";
    CONFIG_USE_FIPS_ENDPOINT = "use_fips_endpoint";
    DEFAULT_USE_FIPS_ENDPOINT = false;
    NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS19 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => booleanSelector(env3, ENV_USE_FIPS_ENDPOINT, SelectorType.ENV), "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => booleanSelector(profile, CONFIG_USE_FIPS_ENDPOINT, SelectorType.CONFIG), "configFileSelector"),
      default: false
    };
    nodeFipsConfigSelectors = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => booleanSelector(env3, ENV_USE_FIPS_ENDPOINT, SelectorType.ENV), "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => booleanSelector(profile, CONFIG_USE_FIPS_ENDPOINT, SelectorType.CONFIG), "configFileSelector"),
      default: void 0
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/endpointsConfig/resolveCustomEndpointsConfig.js
var resolveCustomEndpointsConfig;
var init_resolveCustomEndpointsConfig = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/endpointsConfig/resolveCustomEndpointsConfig.js"() {
    init_client12();
    resolveCustomEndpointsConfig = /* @__PURE__ */ __name((input) => {
      const { tls, endpoint, urlParser, useDualstackEndpoint } = input;
      return Object.assign(input, {
        tls: tls ?? true,
        endpoint: normalizeProvider22(typeof endpoint === "string" ? urlParser(endpoint) : endpoint),
        isCustomEndpoint: true,
        useDualstackEndpoint: normalizeProvider22(useDualstackEndpoint ?? false)
      });
    }, "resolveCustomEndpointsConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/endpointsConfig/utils/getEndpointFromRegion.js
var getEndpointFromRegion;
var init_getEndpointFromRegion = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/endpointsConfig/utils/getEndpointFromRegion.js"() {
    getEndpointFromRegion = /* @__PURE__ */ __name(async (input) => {
      const { tls = true } = input;
      const region = await input.region();
      const dnsHostRegex = new RegExp(/^([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9-]{0,61}[a-zA-Z0-9])$/);
      if (!dnsHostRegex.test(region)) {
        throw new Error("Invalid region in client config");
      }
      const useDualstackEndpoint = await input.useDualstackEndpoint();
      const useFipsEndpoint = await input.useFipsEndpoint();
      const { hostname } = await input.regionInfoProvider(region, { useDualstackEndpoint, useFipsEndpoint }) ?? {};
      if (!hostname) {
        throw new Error("Cannot resolve hostname from client config");
      }
      return input.urlParser(`${tls ? "https:" : "http:"}//${hostname}`);
    }, "getEndpointFromRegion");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/endpointsConfig/resolveEndpointsConfig.js
var resolveEndpointsConfig;
var init_resolveEndpointsConfig = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/endpointsConfig/resolveEndpointsConfig.js"() {
    init_client12();
    init_getEndpointFromRegion();
    resolveEndpointsConfig = /* @__PURE__ */ __name((input) => {
      const useDualstackEndpoint = normalizeProvider22(input.useDualstackEndpoint ?? false);
      const { endpoint, useFipsEndpoint, urlParser, tls } = input;
      return Object.assign(input, {
        tls: tls ?? true,
        endpoint: endpoint ? normalizeProvider22(typeof endpoint === "string" ? urlParser(endpoint) : endpoint) : () => getEndpointFromRegion({ ...input, useDualstackEndpoint, useFipsEndpoint }),
        isCustomEndpoint: !!endpoint,
        useDualstackEndpoint
      });
    }, "resolveEndpointsConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionConfig/config.js
var REGION_ENV_NAME, REGION_INI_NAME, NODE_REGION_CONFIG_OPTIONS20, NODE_REGION_CONFIG_FILE_OPTIONS20;
var init_config3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionConfig/config.js"() {
    REGION_ENV_NAME = "AWS_REGION";
    REGION_INI_NAME = "region";
    NODE_REGION_CONFIG_OPTIONS20 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[REGION_ENV_NAME], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[REGION_INI_NAME], "configFileSelector"),
      default: /* @__PURE__ */ __name(() => {
        throw new Error("Region is missing");
      }, "default")
    };
    NODE_REGION_CONFIG_FILE_OPTIONS20 = {
      preferredFile: "credentials"
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionConfig/checkRegion.js
var validRegions, checkRegion;
var init_checkRegion = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionConfig/checkRegion.js"() {
    init_endpoints3();
    validRegions = /* @__PURE__ */ new Set();
    checkRegion = /* @__PURE__ */ __name((region, check = isValidHostLabel2) => {
      if (!validRegions.has(region) && !check(region)) {
        if (region === "*") {
          console.warn(`@smithy/config-resolver WARN - Please use the caller region instead of "*". See "sigv4a" in https://github.com/aws/aws-sdk-js-v3/blob/main/supplemental-docs/CLIENTS.md.`);
        } else {
          throw new Error(`Region not accepted: region="${region}" is not a valid hostname component.`);
        }
      } else {
        validRegions.add(region);
      }
    }, "checkRegion");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionConfig/isFipsRegion.js
var isFipsRegion;
var init_isFipsRegion = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionConfig/isFipsRegion.js"() {
    isFipsRegion = /* @__PURE__ */ __name((region) => typeof region === "string" && (region.startsWith("fips-") || region.endsWith("-fips")), "isFipsRegion");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionConfig/getRealRegion.js
var getRealRegion;
var init_getRealRegion = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionConfig/getRealRegion.js"() {
    init_isFipsRegion();
    getRealRegion = /* @__PURE__ */ __name((region) => isFipsRegion(region) ? ["fips-aws-global", "aws-fips"].includes(region) ? "us-east-1" : region.replace(/fips-(dkr-|prod-)?|-fips/, "") : region, "getRealRegion");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionConfig/resolveRegionConfig.js
var resolveRegionConfig19;
var init_resolveRegionConfig = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionConfig/resolveRegionConfig.js"() {
    init_checkRegion();
    init_getRealRegion();
    init_isFipsRegion();
    resolveRegionConfig19 = /* @__PURE__ */ __name((input) => {
      const { region, useFipsEndpoint } = input;
      if (!region) {
        throw new Error("Region is missing");
      }
      return Object.assign(input, {
        region: /* @__PURE__ */ __name(async () => {
          const providedRegion = typeof region === "function" ? await region() : region;
          const realRegion = getRealRegion(providedRegion);
          checkRegion(realRegion);
          return realRegion;
        }, "region"),
        useFipsEndpoint: /* @__PURE__ */ __name(async () => {
          const providedRegion = typeof region === "string" ? region : await region();
          if (isFipsRegion(providedRegion)) {
            return true;
          }
          return typeof useFipsEndpoint !== "function" ? Promise.resolve(!!useFipsEndpoint) : useFipsEndpoint();
        }, "useFipsEndpoint")
      });
    }, "resolveRegionConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionInfo/getHostnameFromVariants.js
var getHostnameFromVariants;
var init_getHostnameFromVariants = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionInfo/getHostnameFromVariants.js"() {
    getHostnameFromVariants = /* @__PURE__ */ __name((variants = [], { useFipsEndpoint, useDualstackEndpoint }) => variants.find(({ tags }) => useFipsEndpoint === tags.includes("fips") && useDualstackEndpoint === tags.includes("dualstack"))?.hostname, "getHostnameFromVariants");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionInfo/getResolvedHostname.js
var getResolvedHostname;
var init_getResolvedHostname = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionInfo/getResolvedHostname.js"() {
    getResolvedHostname = /* @__PURE__ */ __name((resolvedRegion, { regionHostname, partitionHostname }) => regionHostname ? regionHostname : partitionHostname ? partitionHostname.replace("{region}", resolvedRegion) : void 0, "getResolvedHostname");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionInfo/getResolvedPartition.js
var getResolvedPartition;
var init_getResolvedPartition = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionInfo/getResolvedPartition.js"() {
    getResolvedPartition = /* @__PURE__ */ __name((region, { partitionHash }) => Object.keys(partitionHash || {}).find((key) => partitionHash[key].regions.includes(region)) ?? "aws", "getResolvedPartition");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionInfo/getResolvedSigningRegion.js
var getResolvedSigningRegion;
var init_getResolvedSigningRegion = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionInfo/getResolvedSigningRegion.js"() {
    getResolvedSigningRegion = /* @__PURE__ */ __name((hostname, { signingRegion, regionRegex, useFipsEndpoint }) => {
      if (signingRegion) {
        return signingRegion;
      } else if (useFipsEndpoint) {
        const regionRegexJs = regionRegex.replace("\\\\", "\\").replace(/^\^/g, "\\.").replace(/\$$/g, "\\.");
        const regionRegexmatchArray = hostname.match(regionRegexJs);
        if (regionRegexmatchArray) {
          return regionRegexmatchArray[0].slice(1, -1);
        }
      }
    }, "getResolvedSigningRegion");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionInfo/getRegionInfo.js
var getRegionInfo;
var init_getRegionInfo = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionInfo/getRegionInfo.js"() {
    init_getHostnameFromVariants();
    init_getResolvedHostname();
    init_getResolvedPartition();
    init_getResolvedSigningRegion();
    getRegionInfo = /* @__PURE__ */ __name((region, { useFipsEndpoint = false, useDualstackEndpoint = false, signingService, regionHash, partitionHash }) => {
      const partition4 = getResolvedPartition(region, { partitionHash });
      const resolvedRegion = region in regionHash ? region : partitionHash[partition4]?.endpoint ?? region;
      const hostnameOptions = { useFipsEndpoint, useDualstackEndpoint };
      const regionHostname = getHostnameFromVariants(regionHash[resolvedRegion]?.variants, hostnameOptions);
      const partitionHostname = getHostnameFromVariants(partitionHash[partition4]?.variants, hostnameOptions);
      const hostname = getResolvedHostname(resolvedRegion, { regionHostname, partitionHostname });
      if (hostname === void 0) {
        throw new Error(`Endpoint resolution failed for: ${{ resolvedRegion, useFipsEndpoint, useDualstackEndpoint }}`);
      }
      const signingRegion = getResolvedSigningRegion(hostname, {
        signingRegion: regionHash[resolvedRegion]?.signingRegion,
        regionRegex: partitionHash[partition4].regionRegex,
        useFipsEndpoint
      });
      return {
        partition: partition4,
        signingService,
        hostname,
        ...signingRegion && { signingRegion },
        ...regionHash[resolvedRegion]?.signingService && {
          signingService: regionHash[resolvedRegion].signingService
        }
      };
    }, "getRegionInfo");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/defaults-mode/constants.js
var AWS_EXECUTION_ENV, AWS_REGION_ENV, AWS_DEFAULT_REGION_ENV, ENV_IMDS_DISABLED, DEFAULTS_MODE_OPTIONS, IMDS_REGION_PATH;
var init_constants5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/defaults-mode/constants.js"() {
    AWS_EXECUTION_ENV = "AWS_EXECUTION_ENV";
    AWS_REGION_ENV = "AWS_REGION";
    AWS_DEFAULT_REGION_ENV = "AWS_DEFAULT_REGION";
    ENV_IMDS_DISABLED = "AWS_EC2_METADATA_DISABLED";
    DEFAULTS_MODE_OPTIONS = ["in-region", "cross-region", "mobile", "standard", "legacy"];
    IMDS_REGION_PATH = "/latest/meta-data/placement/region";
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/defaults-mode/defaultsModeConfig.js
var AWS_DEFAULTS_MODE_ENV, AWS_DEFAULTS_MODE_CONFIG, NODE_DEFAULTS_MODE_CONFIG_OPTIONS;
var init_defaultsModeConfig = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/defaults-mode/defaultsModeConfig.js"() {
    AWS_DEFAULTS_MODE_ENV = "AWS_DEFAULTS_MODE";
    AWS_DEFAULTS_MODE_CONFIG = "defaults_mode";
    NODE_DEFAULTS_MODE_CONFIG_OPTIONS = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => {
        return env3[AWS_DEFAULTS_MODE_ENV];
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => {
        return profile[AWS_DEFAULTS_MODE_CONFIG];
      }, "configFileSelector"),
      default: "legacy"
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/defaults-mode/resolveDefaultsModeConfig.js
var resolveDefaultsModeConfig19, resolveNodeDefaultsModeAuto, inferPhysicalRegion, getImdsEndpoint, imdsHttpGet;
var init_resolveDefaultsModeConfig = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/defaults-mode/resolveDefaultsModeConfig.js"() {
    init_config3();
    init_configLoader2();
    init_memoize2();
    init_constants5();
    init_defaultsModeConfig();
    resolveDefaultsModeConfig19 = /* @__PURE__ */ __name(({ region = loadConfig3(NODE_REGION_CONFIG_OPTIONS20), defaultsMode = loadConfig3(NODE_DEFAULTS_MODE_CONFIG_OPTIONS) } = {}) => memoize2(async () => {
      const mode = typeof defaultsMode === "function" ? await defaultsMode() : defaultsMode;
      switch (mode?.toLowerCase()) {
        case "auto":
          return resolveNodeDefaultsModeAuto(region);
        case "in-region":
        case "cross-region":
        case "mobile":
        case "standard":
        case "legacy":
          return Promise.resolve(mode?.toLocaleLowerCase());
        case void 0:
          return Promise.resolve("legacy");
        default:
          throw new Error(`Invalid parameter for "defaultsMode", expect ${DEFAULTS_MODE_OPTIONS.join(", ")}, got ${mode}`);
      }
    }), "resolveDefaultsModeConfig");
    resolveNodeDefaultsModeAuto = /* @__PURE__ */ __name(async (clientRegion) => {
      if (clientRegion) {
        const resolvedRegion = typeof clientRegion === "function" ? await clientRegion() : clientRegion;
        const inferredRegion = await inferPhysicalRegion();
        if (!inferredRegion) {
          return "standard";
        }
        if (resolvedRegion === inferredRegion) {
          return "in-region";
        } else {
          return "cross-region";
        }
      }
      return "standard";
    }, "resolveNodeDefaultsModeAuto");
    inferPhysicalRegion = /* @__PURE__ */ __name(async () => {
      if (process.env[AWS_EXECUTION_ENV] && (process.env[AWS_REGION_ENV] || process.env[AWS_DEFAULT_REGION_ENV])) {
        return process.env[AWS_REGION_ENV] ?? process.env[AWS_DEFAULT_REGION_ENV];
      }
      if (!process.env[ENV_IMDS_DISABLED]) {
        try {
          const endpoint = await getImdsEndpoint();
          return (await imdsHttpGet({ hostname: endpoint.hostname, path: IMDS_REGION_PATH })).toString();
        } catch (e32) {
        }
      }
    }, "inferPhysicalRegion");
    getImdsEndpoint = /* @__PURE__ */ __name(async () => {
      const envEndpoint = process.env.AWS_EC2_METADATA_SERVICE_ENDPOINT;
      if (envEndpoint) {
        const url = new URL(envEndpoint);
        return { hostname: url.hostname, path: url.pathname };
      }
      const envMode = process.env.AWS_EC2_METADATA_SERVICE_ENDPOINT_MODE;
      if (envMode === "IPv6") {
        return { hostname: "fd00:ec2::254", path: "/" };
      }
      return { hostname: "169.254.169.254", path: "/" };
    }, "getImdsEndpoint");
    imdsHttpGet = /* @__PURE__ */ __name(async ({ hostname, path: path47 }) => {
      const { request: request4 } = await import("node:http");
      return new Promise((resolve13, reject) => {
        const req = request4({
          method: "GET",
          hostname: hostname.replace(/^\[(.+)]$/, "$1"),
          path: path47,
          timeout: 1e3,
          signal: AbortSignal.timeout(1e3)
        });
        req.on("error", (err) => {
          reject(err);
          req.destroy();
        });
        req.on("timeout", () => {
          reject(new Error("TimeoutError from instance metadata service"));
          req.destroy();
        });
        req.on("response", (res) => {
          const { statusCode = 400 } = res;
          if (statusCode < 200 || 300 <= statusCode) {
            reject(Object.assign(new Error("Error response received from instance metadata service"), { statusCode }));
            req.destroy();
            return;
          }
          const chunks2 = [];
          res.on("data", (chunk) => chunks2.push(chunk));
          res.on("end", () => {
            resolve13(Buffer.concat(chunks2));
            req.destroy();
          });
        });
        req.end();
      });
    }, "imdsHttpGet");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/index.js
var config_exports = {};
__export(config_exports, {
  CONFIG_PREFIX_SEPARATOR: () => CONFIG_PREFIX_SEPARATOR2,
  CONFIG_USE_DUALSTACK_ENDPOINT: () => CONFIG_USE_DUALSTACK_ENDPOINT,
  CONFIG_USE_FIPS_ENDPOINT: () => CONFIG_USE_FIPS_ENDPOINT,
  CredentialsProviderError: () => CredentialsProviderError2,
  DEFAULT_PROFILE: () => DEFAULT_PROFILE2,
  DEFAULT_USE_DUALSTACK_ENDPOINT: () => DEFAULT_USE_DUALSTACK_ENDPOINT,
  DEFAULT_USE_FIPS_ENDPOINT: () => DEFAULT_USE_FIPS_ENDPOINT,
  ENV_PROFILE: () => ENV_PROFILE2,
  ENV_USE_DUALSTACK_ENDPOINT: () => ENV_USE_DUALSTACK_ENDPOINT,
  ENV_USE_FIPS_ENDPOINT: () => ENV_USE_FIPS_ENDPOINT,
  NODE_REGION_CONFIG_FILE_OPTIONS: () => NODE_REGION_CONFIG_FILE_OPTIONS20,
  NODE_REGION_CONFIG_OPTIONS: () => NODE_REGION_CONFIG_OPTIONS20,
  NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS: () => NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS19,
  NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS: () => NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS19,
  ProviderError: () => ProviderError8,
  REGION_ENV_NAME: () => REGION_ENV_NAME,
  REGION_INI_NAME: () => REGION_INI_NAME,
  SelectorType: () => SelectorType,
  TokenProviderError: () => TokenProviderError,
  booleanSelector: () => booleanSelector,
  chain: () => chain2,
  externalDataInterceptor: () => externalDataInterceptor,
  fromStatic: () => fromStatic2,
  fromValue: () => fromValue2,
  getHomeDir: () => getHomeDir2,
  getProfileName: () => getProfileName2,
  getRegionInfo: () => getRegionInfo,
  getSSOTokenFilepath: () => getSSOTokenFilepath,
  getSSOTokenFromFile: () => getSSOTokenFromFile,
  loadConfig: () => loadConfig3,
  loadSharedConfigFiles: () => loadSharedConfigFiles2,
  loadSsoSessionData: () => loadSsoSessionData,
  memoize: () => memoize2,
  nodeDualstackConfigSelectors: () => nodeDualstackConfigSelectors,
  nodeFipsConfigSelectors: () => nodeFipsConfigSelectors,
  numberSelector: () => numberSelector,
  parseKnownFiles: () => parseKnownFiles,
  readFile: () => readFile5,
  resolveCustomEndpointsConfig: () => resolveCustomEndpointsConfig,
  resolveDefaultsModeConfig: () => resolveDefaultsModeConfig19,
  resolveEndpointsConfig: () => resolveEndpointsConfig,
  resolveRegionConfig: () => resolveRegionConfig19
});
var init_config4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/config/index.js"() {
    init_ProviderError2();
    init_CredentialsProviderError2();
    init_TokenProviderError();
    init_chain2();
    init_fromValue2();
    init_memoize2();
    init_booleanSelector();
    init_numberSelector();
    init_types7();
    init_getHomeDir2();
    init_getProfileName2();
    init_getSSOTokenFilepath();
    init_getSSOTokenFromFile();
    init_constants4();
    init_loadSharedConfigFiles2();
    init_loadSsoSessionData();
    init_parseKnownFiles();
    init_externalDataInterceptor();
    init_readFile2();
    init_configLoader2();
    init_fromStatic2();
    init_NodeUseDualstackEndpointConfigOptions();
    init_NodeUseFipsEndpointConfigOptions();
    init_resolveCustomEndpointsConfig();
    init_resolveEndpointsConfig();
    init_config3();
    init_resolveRegionConfig();
    init_getRegionInfo();
    init_resolveDefaultsModeConfig();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/getEndpointUrlConfig.js
var ENV_ENDPOINT_URL2, CONFIG_ENDPOINT_URL2, getEndpointUrlConfig2;
var init_getEndpointUrlConfig2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/getEndpointUrlConfig.js"() {
    init_config4();
    ENV_ENDPOINT_URL2 = "AWS_ENDPOINT_URL";
    CONFIG_ENDPOINT_URL2 = "endpoint_url";
    getEndpointUrlConfig2 = /* @__PURE__ */ __name((serviceId) => ({
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => {
        const serviceSuffixParts = serviceId.split(" ").map((w) => w.toUpperCase());
        const serviceEndpointUrl = env3[[ENV_ENDPOINT_URL2, ...serviceSuffixParts].join("_")];
        if (serviceEndpointUrl)
          return serviceEndpointUrl;
        const endpointUrl = env3[ENV_ENDPOINT_URL2];
        if (endpointUrl)
          return endpointUrl;
        return void 0;
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile, config2) => {
        if (config2 && profile.services) {
          const servicesSection = config2[["services", profile.services].join(CONFIG_PREFIX_SEPARATOR2)];
          if (servicesSection) {
            const servicePrefixParts = serviceId.split(" ").map((w) => w.toLowerCase());
            const endpointUrl2 = servicesSection[[servicePrefixParts.join("_"), CONFIG_ENDPOINT_URL2].join(CONFIG_PREFIX_SEPARATOR2)];
            if (endpointUrl2)
              return endpointUrl2;
          }
        }
        const endpointUrl = profile[CONFIG_ENDPOINT_URL2];
        if (endpointUrl)
          return endpointUrl;
        return void 0;
      }, "configFileSelector"),
      default: void 0
    }), "getEndpointUrlConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/getEndpointFromConfig.js
var getEndpointFromConfig2;
var init_getEndpointFromConfig2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/getEndpointFromConfig.js"() {
    init_config4();
    init_getEndpointUrlConfig2();
    getEndpointFromConfig2 = /* @__PURE__ */ __name(async (serviceId) => loadConfig3(getEndpointUrlConfig2(serviceId ?? ""))(), "getEndpointFromConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/service-customizations/s3.js
var resolveParamsForS32, DOMAIN_PATTERN2, IP_ADDRESS_PATTERN2, DOTS_PATTERN2, isDnsCompatibleBucketName2, isArnBucketName2;
var init_s32 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/service-customizations/s3.js"() {
    resolveParamsForS32 = /* @__PURE__ */ __name(async (endpointParams) => {
      const bucket = endpointParams?.Bucket || "";
      if (typeof endpointParams.Bucket === "string") {
        endpointParams.Bucket = bucket.replace(/#/g, encodeURIComponent("#")).replace(/\?/g, encodeURIComponent("?"));
      }
      if (isArnBucketName2(bucket)) {
        if (endpointParams.ForcePathStyle === true) {
          throw new Error("Path-style addressing cannot be used with ARN buckets");
        }
      } else if (!isDnsCompatibleBucketName2(bucket) || bucket.indexOf(".") !== -1 && !String(endpointParams.Endpoint).startsWith("http:") || bucket.toLowerCase() !== bucket || bucket.length < 3) {
        endpointParams.ForcePathStyle = true;
      }
      if (endpointParams.DisableMultiRegionAccessPoints) {
        endpointParams.disableMultiRegionAccessPoints = true;
        endpointParams.DisableMRAP = true;
      }
      return endpointParams;
    }, "resolveParamsForS3");
    DOMAIN_PATTERN2 = /^[a-z0-9][a-z0-9\.\-]{1,61}[a-z0-9]$/;
    IP_ADDRESS_PATTERN2 = /(\d+\.){3}\d+/;
    DOTS_PATTERN2 = /\.\./;
    isDnsCompatibleBucketName2 = /* @__PURE__ */ __name((bucketName) => DOMAIN_PATTERN2.test(bucketName) && !IP_ADDRESS_PATTERN2.test(bucketName) && !DOTS_PATTERN2.test(bucketName), "isDnsCompatibleBucketName");
    isArnBucketName2 = /* @__PURE__ */ __name((bucketName) => {
      const [arn, partition4, service, , , bucket] = bucketName.split(":");
      const isArn = arn === "arn" && bucketName.split(":").length >= 6;
      const isValidArn = Boolean(isArn && partition4 && service && bucket);
      if (isArn && !isValidArn) {
        throw new Error(`Invalid ARN: ${bucketName} was an invalid ARN.`);
      }
      return isValidArn;
    }, "isArnBucketName");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/service-customizations/index.js
var init_service_customizations2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/service-customizations/index.js"() {
    init_s32();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/createConfigValueProvider.js
var createConfigValueProvider2;
var init_createConfigValueProvider2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/createConfigValueProvider.js"() {
    createConfigValueProvider2 = /* @__PURE__ */ __name((configKey, canonicalEndpointParamKey, config2, isClientContextParam = false) => {
      const configProvider = /* @__PURE__ */ __name(async () => {
        let configValue;
        if (isClientContextParam) {
          const clientContextParams = config2.clientContextParams;
          const nestedValue = clientContextParams?.[configKey];
          configValue = nestedValue ?? config2[configKey] ?? config2[canonicalEndpointParamKey];
        } else {
          configValue = config2[configKey] ?? config2[canonicalEndpointParamKey];
        }
        if (typeof configValue === "function") {
          return configValue();
        }
        return configValue;
      }, "configProvider");
      if (configKey === "credentialScope" || canonicalEndpointParamKey === "CredentialScope") {
        return async () => {
          const credentials = typeof config2.credentials === "function" ? await config2.credentials() : config2.credentials;
          const configValue = credentials?.credentialScope ?? credentials?.CredentialScope;
          return configValue;
        };
      }
      if (configKey === "accountId" || canonicalEndpointParamKey === "AccountId") {
        return async () => {
          const credentials = typeof config2.credentials === "function" ? await config2.credentials() : config2.credentials;
          const configValue = credentials?.accountId ?? credentials?.AccountId;
          return configValue;
        };
      }
      if (configKey === "endpoint" || canonicalEndpointParamKey === "endpoint") {
        return async () => {
          if (config2.isCustomEndpoint === false) {
            return void 0;
          }
          const endpoint = await configProvider();
          if (endpoint && typeof endpoint === "object") {
            if ("url" in endpoint) {
              return endpoint.url.href;
            }
            if ("hostname" in endpoint) {
              const { protocol, hostname, port, path: path47 } = endpoint;
              return `${protocol}//${hostname}${port ? ":" + port : ""}${path47}`;
            }
          }
          return endpoint;
        };
      }
      return configProvider;
    }, "createConfigValueProvider");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/toEndpointV1.js
var toEndpointV13;
var init_toEndpointV14 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/toEndpointV1.js"() {
    init_protocols11();
    toEndpointV13 = /* @__PURE__ */ __name((endpoint) => {
      if (typeof endpoint === "object") {
        if ("url" in endpoint) {
          const v1Endpoint = parseUrl21(endpoint.url);
          if (endpoint.headers) {
            v1Endpoint.headers = {};
            for (const name in endpoint.headers) {
              v1Endpoint.headers[name.toLowerCase()] = endpoint.headers[name].join(", ");
            }
          }
          return v1Endpoint;
        }
        return endpoint;
      }
      return parseUrl21(endpoint);
    }, "toEndpointV1");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/toEndpointV1.js
var init_toEndpointV15 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/toEndpointV1.js"() {
    init_toEndpointV14();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/getEndpointFromInstructions.js
function bindGetEndpointFromInstructions2(getEndpointFromConfig5) {
  return async (commandInput, instructionsSupplier, clientConfig, context) => {
    if (!clientConfig.isCustomEndpoint) {
      let endpointFromConfig;
      if (clientConfig.serviceConfiguredEndpoint) {
        endpointFromConfig = await clientConfig.serviceConfiguredEndpoint();
      } else {
        endpointFromConfig = await getEndpointFromConfig5(clientConfig.serviceId);
      }
      if (endpointFromConfig) {
        clientConfig.endpoint = () => Promise.resolve(toEndpointV13(endpointFromConfig));
        clientConfig.isCustomEndpoint = true;
      }
    }
    const endpointParams = await resolveParams7(commandInput, instructionsSupplier, clientConfig);
    if (typeof clientConfig.endpointProvider !== "function") {
      throw new Error("config.endpointProvider is not set.");
    }
    const endpoint = clientConfig.endpointProvider(endpointParams, context);
    if (clientConfig.isCustomEndpoint && clientConfig.endpoint) {
      const customEndpoint = await clientConfig.endpoint();
      if (customEndpoint?.headers) {
        endpoint.headers ??= {};
        for (const [name, value] of Object.entries(customEndpoint.headers)) {
          endpoint.headers[name] = Array.isArray(value) ? value : [value];
        }
      }
    }
    return endpoint;
  };
}
var resolveParams7;
var init_getEndpointFromInstructions2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/getEndpointFromInstructions.js"() {
    init_service_customizations2();
    init_createConfigValueProvider2();
    init_toEndpointV15();
    __name(bindGetEndpointFromInstructions2, "bindGetEndpointFromInstructions");
    resolveParams7 = /* @__PURE__ */ __name(async (commandInput, instructionsSupplier, clientConfig) => {
      const endpointParams = {};
      const instructions = instructionsSupplier?.getEndpointParameterInstructions?.() || {};
      for (const [name, instruction] of Object.entries(instructions)) {
        switch (instruction.type) {
          case "staticContextParams":
            endpointParams[name] = instruction.value;
            break;
          case "contextParams":
            endpointParams[name] = commandInput[instruction.name];
            break;
          case "clientContextParams":
          case "builtInParams":
            endpointParams[name] = await createConfigValueProvider2(instruction.name, name, clientConfig, instruction.type !== "builtInParams")();
            break;
          case "operationContextParams":
            endpointParams[name] = instruction.get(commandInput);
            break;
          default:
            throw new Error("Unrecognized endpoint parameter instruction: " + JSON.stringify(instruction));
        }
      }
      if (Object.keys(instructions).length === 0) {
        Object.assign(endpointParams, clientConfig);
      }
      if (String(clientConfig.serviceId).toLowerCase() === "s3") {
        await resolveParamsForS32(endpointParams);
      }
      return endpointParams;
    }, "resolveParams");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/endpointMiddleware.js
function setFeature11(context, feature, value) {
  if (!context.__smithy_context) {
    context.__smithy_context = { features: {} };
  } else if (!context.__smithy_context.features) {
    context.__smithy_context.features = {};
  }
  context.__smithy_context.features[feature] = value;
}
function bindEndpointMiddleware2(getEndpointFromConfig5) {
  const getEndpointFromInstructions7 = bindGetEndpointFromInstructions2(getEndpointFromConfig5);
  return ({ config: config2, instructions }) => {
    return (next, context) => async (args) => {
      if (config2.isCustomEndpoint) {
        setFeature11(context, "ENDPOINT_OVERRIDE", "N");
      }
      const endpoint = await getEndpointFromInstructions7(args.input, {
        getEndpointParameterInstructions() {
          return instructions;
        }
      }, { ...config2 }, context);
      context.endpointV2 = endpoint;
      context.authSchemes = endpoint.properties?.authSchemes;
      const authScheme = context.authSchemes?.[0];
      if (authScheme) {
        context["signing_region"] = authScheme.signingRegion;
        context["signing_service"] = authScheme.signingName;
        const smithyContext = getSmithyContext26(context);
        const httpAuthOption = smithyContext?.selectedHttpAuthScheme?.httpAuthOption;
        if (httpAuthOption) {
          httpAuthOption.signingProperties = Object.assign(httpAuthOption.signingProperties || {}, {
            signing_region: authScheme.signingRegion,
            signingRegion: authScheme.signingRegion,
            signing_service: authScheme.signingName,
            signingName: authScheme.signingName,
            signingRegionSet: authScheme.signingRegionSet
          }, authScheme.properties);
        }
      }
      return next({
        ...args
      });
    };
  };
}
var init_endpointMiddleware2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/endpointMiddleware.js"() {
    init_client12();
    init_getEndpointFromInstructions2();
    __name(setFeature11, "setFeature");
    __name(bindEndpointMiddleware2, "bindEndpointMiddleware");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/getEndpointPlugin.js
function bindGetEndpointPlugin2(getEndpointFromConfig5) {
  const endpointMiddleware5 = bindEndpointMiddleware2(getEndpointFromConfig5);
  return (config2, instructions) => ({
    applyToStack: /* @__PURE__ */ __name((clientStack) => {
      clientStack.addRelativeTo(endpointMiddleware5({
        config: config2,
        instructions
      }), endpointMiddlewareOptions2);
    }, "applyToStack")
  });
}
var serializerMiddlewareOption3, endpointMiddlewareOptions2;
var init_getEndpointPlugin2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/getEndpointPlugin.js"() {
    init_endpointMiddleware2();
    serializerMiddlewareOption3 = {
      name: "serializerMiddleware",
      step: "serialize",
      tags: ["SERIALIZER"],
      override: true
    };
    endpointMiddlewareOptions2 = {
      step: "serialize",
      tags: ["ENDPOINT_PARAMETERS", "ENDPOINT_V2", "ENDPOINT"],
      name: "endpointV2Middleware",
      override: true,
      relation: "before",
      toMiddleware: serializerMiddlewareOption3.name
    };
    __name(bindGetEndpointPlugin2, "bindGetEndpointPlugin");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/resolveEndpointConfig.js
function bindResolveEndpointConfig2(getEndpointFromConfig5) {
  return (input) => {
    const tls = input.tls ?? true;
    const { endpoint, useDualstackEndpoint, useFipsEndpoint } = input;
    const customEndpointProvider = endpoint != null ? async () => toEndpointV13(await normalizeProvider22(endpoint)()) : void 0;
    const isCustomEndpoint = !!endpoint;
    const resolvedConfig = Object.assign(input, {
      endpoint: customEndpointProvider,
      tls,
      isCustomEndpoint,
      useDualstackEndpoint: normalizeProvider22(useDualstackEndpoint ?? false),
      useFipsEndpoint: normalizeProvider22(useFipsEndpoint ?? false)
    });
    let configuredEndpointPromise = void 0;
    resolvedConfig.serviceConfiguredEndpoint = async () => {
      if (input.serviceId && !configuredEndpointPromise) {
        configuredEndpointPromise = getEndpointFromConfig5(input.serviceId);
      }
      return configuredEndpointPromise;
    };
    return resolvedConfig;
  };
}
var init_resolveEndpointConfig2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/resolveEndpointConfig.js"() {
    init_client12();
    init_toEndpointV15();
    __name(bindResolveEndpointConfig2, "bindResolveEndpointConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/bdd/BinaryDecisionDiagram.js
var BinaryDecisionDiagram20;
var init_BinaryDecisionDiagram2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/bdd/BinaryDecisionDiagram.js"() {
    BinaryDecisionDiagram20 = class _BinaryDecisionDiagram {
      static {
        __name(this, "BinaryDecisionDiagram");
      }
      nodes;
      root;
      conditions;
      results;
      constructor(bdd32, root32, conditions, results) {
        this.nodes = bdd32;
        this.root = root32;
        this.conditions = conditions;
        this.results = results;
      }
      static from(bdd32, root32, conditions, results) {
        return new _BinaryDecisionDiagram(bdd32, root32, conditions, results);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/cache/EndpointCache.js
var EndpointCache20;
var init_EndpointCache2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/cache/EndpointCache.js"() {
    EndpointCache20 = class {
      static {
        __name(this, "EndpointCache");
      }
      capacity;
      data = /* @__PURE__ */ new Map();
      parameters = [];
      constructor({ size, params }) {
        this.capacity = size ?? 50;
        if (params) {
          this.parameters = params;
        }
      }
      get(endpointParams, resolver) {
        const key = this.hash(endpointParams);
        if (key === false) {
          return resolver();
        }
        if (!this.data.has(key)) {
          if (this.data.size > this.capacity + 10) {
            const keys = this.data.keys();
            let i32 = 0;
            while (true) {
              const { value, done } = keys.next();
              this.data.delete(value);
              if (done || ++i32 > 10) {
                break;
              }
            }
          }
          this.data.set(key, resolver());
        }
        return this.data.get(key);
      }
      size() {
        return this.data.size;
      }
      hash(endpointParams) {
        let buffer = "";
        const { parameters } = this;
        if (parameters.length === 0) {
          return false;
        }
        for (const param of parameters) {
          const val = String(endpointParams[param] ?? "");
          if (val.includes("|;")) {
            return false;
          }
          buffer += val + "|;";
        }
        return buffer;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/EndpointError.js
var EndpointError2;
var init_EndpointError2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/EndpointError.js"() {
    EndpointError2 = class extends Error {
      static {
        __name(this, "EndpointError");
      }
      constructor(message2) {
        super(message2);
        this.name = "EndpointError";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/EndpointFunctions.js
var init_EndpointFunctions2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/EndpointFunctions.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/EndpointRuleObject.js
var init_EndpointRuleObject2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/EndpointRuleObject.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/ErrorRuleObject.js
var init_ErrorRuleObject2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/ErrorRuleObject.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/RuleSetObject.js
var init_RuleSetObject2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/RuleSetObject.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/TreeRuleObject.js
var init_TreeRuleObject2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/TreeRuleObject.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/shared.js
var init_shared2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/shared.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/index.js
var init_types8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/index.js"() {
    init_EndpointError2();
    init_EndpointFunctions2();
    init_EndpointRuleObject2();
    init_ErrorRuleObject2();
    init_RuleSetObject2();
    init_TreeRuleObject2();
    init_shared2();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/debug/debugId.js
var debugId2;
var init_debugId2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/debug/debugId.js"() {
    debugId2 = "endpoints";
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/debug/toDebugString.js
function toDebugString2(input) {
  if (typeof input !== "object" || input == null) {
    return input;
  }
  if ("ref" in input) {
    return `$${toDebugString2(input.ref)}`;
  }
  if ("fn" in input) {
    return `${input.fn}(${(input.argv || []).map(toDebugString2).join(", ")})`;
  }
  return JSON.stringify(input, null, 2);
}
var init_toDebugString2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/debug/toDebugString.js"() {
    __name(toDebugString2, "toDebugString");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/debug/index.js
var init_debug2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/debug/index.js"() {
    init_debugId2();
    init_toDebugString2();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/customEndpointFunctions.js
var customEndpointFunctions20;
var init_customEndpointFunctions2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/customEndpointFunctions.js"() {
    customEndpointFunctions20 = {};
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/booleanEquals.js
var booleanEquals2;
var init_booleanEquals2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/booleanEquals.js"() {
    booleanEquals2 = /* @__PURE__ */ __name((value1, value2) => value1 === value2, "booleanEquals");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/coalesce.js
function coalesce2(...args) {
  for (const arg of args) {
    if (arg != null) {
      return arg;
    }
  }
  return void 0;
}
var init_coalesce2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/coalesce.js"() {
    __name(coalesce2, "coalesce");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/getAttrPathList.js
var getAttrPathList2;
var init_getAttrPathList2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/getAttrPathList.js"() {
    init_types8();
    getAttrPathList2 = /* @__PURE__ */ __name((path47) => {
      const parts = path47.split(".");
      const pathList = [];
      for (const part of parts) {
        const squareBracketIndex = part.indexOf("[");
        if (squareBracketIndex !== -1) {
          if (part.indexOf("]") !== part.length - 1) {
            throw new EndpointError2(`Path: '${path47}' does not end with ']'`);
          }
          const arrayIndex = part.slice(squareBracketIndex + 1, -1);
          if (Number.isNaN(parseInt(arrayIndex))) {
            throw new EndpointError2(`Invalid array index: '${arrayIndex}' in path: '${path47}'`);
          }
          if (squareBracketIndex !== 0) {
            pathList.push(part.slice(0, squareBracketIndex));
          }
          pathList.push(arrayIndex);
        } else {
          pathList.push(part);
        }
      }
      return pathList;
    }, "getAttrPathList");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/getAttr.js
var getAttr2;
var init_getAttr2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/getAttr.js"() {
    init_types8();
    init_getAttrPathList2();
    getAttr2 = /* @__PURE__ */ __name((value, path47) => getAttrPathList2(path47).reduce((acc, index) => {
      if (typeof acc !== "object") {
        throw new EndpointError2(`Index '${index}' in '${path47}' not found in '${JSON.stringify(value)}'`);
      } else if (Array.isArray(acc)) {
        const i32 = parseInt(index);
        return acc[i32 < 0 ? acc.length + i32 : i32];
      }
      return acc[index];
    }, value), "getAttr");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/isSet.js
var isSet2;
var init_isSet2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/isSet.js"() {
    isSet2 = /* @__PURE__ */ __name((value) => value != null, "isSet");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/isValidHostLabel.js
var VALID_HOST_LABEL_REGEX2, isValidHostLabel2;
var init_isValidHostLabel2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/isValidHostLabel.js"() {
    VALID_HOST_LABEL_REGEX2 = new RegExp(`^(?!.*-$)(?!-)[a-zA-Z0-9-]{1,63}$`);
    isValidHostLabel2 = /* @__PURE__ */ __name((value, allowSubDomains = false) => {
      if (!allowSubDomains) {
        return VALID_HOST_LABEL_REGEX2.test(value);
      }
      const labels = value.split(".");
      for (const label of labels) {
        if (!isValidHostLabel2(label)) {
          return false;
        }
      }
      return true;
    }, "isValidHostLabel");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/ite.js
function ite2(condition, trueValue, falseValue) {
  return condition ? trueValue : falseValue;
}
var init_ite2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/ite.js"() {
    __name(ite2, "ite");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/not.js
var not2;
var init_not2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/not.js"() {
    not2 = /* @__PURE__ */ __name((value) => !value, "not");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/isIpAddress.js
var IP_V4_REGEX2, isIpAddress2;
var init_isIpAddress2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/isIpAddress.js"() {
    IP_V4_REGEX2 = new RegExp(`^(?:25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]\\d|\\d)(?:\\.(?:25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]\\d|\\d)){3}$`);
    isIpAddress2 = /* @__PURE__ */ __name((value) => IP_V4_REGEX2.test(value) || value.startsWith("[") && value.endsWith("]"), "isIpAddress");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/parseURL.js
var import_types30, DEFAULT_PORTS2, parseURL2;
var init_parseURL2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/parseURL.js"() {
    import_types30 = __toESM(require_dist_cjs());
    init_isIpAddress2();
    DEFAULT_PORTS2 = {
      [import_types30.EndpointURLScheme.HTTP]: 80,
      [import_types30.EndpointURLScheme.HTTPS]: 443
    };
    parseURL2 = /* @__PURE__ */ __name((value) => {
      const whatwgURL = (() => {
        try {
          if (value instanceof URL) {
            return value;
          }
          if (typeof value === "object" && "hostname" in value) {
            const { hostname: hostname2, port, protocol: protocol2 = "", path: path47 = "", query = {} } = value;
            const url = new URL(`${protocol2}//${hostname2}${port ? `:${port}` : ""}${path47}`);
            url.search = Object.entries(query).map(([k32, v]) => `${k32}=${v}`).join("&");
            return url;
          }
          return new URL(value);
        } catch (error4) {
          return null;
        }
      })();
      if (!whatwgURL) {
        console.error(`Unable to parse ${JSON.stringify(value)} as a whatwg URL.`);
        return null;
      }
      const urlString = whatwgURL.href;
      const { host, hostname, pathname, protocol, search } = whatwgURL;
      if (search) {
        return null;
      }
      const scheme = protocol.slice(0, -1);
      if (!Object.values(import_types30.EndpointURLScheme).includes(scheme)) {
        return null;
      }
      const isIp = isIpAddress2(hostname);
      const inputContainsDefaultPort = urlString.includes(`${host}:${DEFAULT_PORTS2[scheme]}`) || typeof value === "string" && value.includes(`${host}:${DEFAULT_PORTS2[scheme]}`);
      const authority = `${host}${inputContainsDefaultPort ? `:${DEFAULT_PORTS2[scheme]}` : ``}`;
      return {
        scheme,
        authority,
        path: pathname,
        normalizedPath: pathname.endsWith("/") ? pathname : `${pathname}/`,
        isIp
      };
    }, "parseURL");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/split.js
function split2(value, delimiter2, limit) {
  if (limit === 1) {
    return [value];
  }
  if (value === "") {
    return [""];
  }
  const parts = value.split(delimiter2);
  if (limit === 0) {
    return parts;
  }
  return parts.slice(0, limit - 1).concat(parts.slice(1).join(delimiter2));
}
var init_split2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/split.js"() {
    __name(split2, "split");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/stringEquals.js
var stringEquals2;
var init_stringEquals2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/stringEquals.js"() {
    stringEquals2 = /* @__PURE__ */ __name((value1, value2) => value1 === value2, "stringEquals");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/substring.js
var substring2;
var init_substring2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/substring.js"() {
    substring2 = /* @__PURE__ */ __name((input, start, stop, reverse) => {
      if (input == null || start >= stop || input.length < stop || /[^\u0000-\u007f]/.test(input)) {
        return null;
      }
      if (!reverse) {
        return input.substring(start, stop);
      }
      return input.substring(input.length - stop, input.length - start);
    }, "substring");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/uriEncode.js
var uriEncode2;
var init_uriEncode2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/uriEncode.js"() {
    uriEncode2 = /* @__PURE__ */ __name((value) => encodeURIComponent(value).replace(/[!*'()]/g, (c32) => `%${c32.charCodeAt(0).toString(16).toUpperCase()}`), "uriEncode");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/index.js
var init_lib2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/index.js"() {
    init_booleanEquals2();
    init_coalesce2();
    init_getAttr2();
    init_isSet2();
    init_isValidHostLabel2();
    init_ite2();
    init_not2();
    init_parseURL2();
    init_split2();
    init_stringEquals2();
    init_substring2();
    init_uriEncode2();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/endpointFunctions.js
var endpointFunctions2;
var init_endpointFunctions2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/endpointFunctions.js"() {
    init_lib2();
    endpointFunctions2 = {
      booleanEquals: booleanEquals2,
      coalesce: coalesce2,
      getAttr: getAttr2,
      isSet: isSet2,
      isValidHostLabel: isValidHostLabel2,
      ite: ite2,
      not: not2,
      parseURL: parseURL2,
      split: split2,
      stringEquals: stringEquals2,
      substring: substring2,
      uriEncode: uriEncode2
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/evaluateTemplate.js
var evaluateTemplate2;
var init_evaluateTemplate2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/evaluateTemplate.js"() {
    init_lib2();
    evaluateTemplate2 = /* @__PURE__ */ __name((template, options) => {
      const evaluatedTemplateArr = [];
      const { referenceRecord, endpointParams } = options;
      let currentIndex = 0;
      while (currentIndex < template.length) {
        const openingBraceIndex = template.indexOf("{", currentIndex);
        if (openingBraceIndex === -1) {
          evaluatedTemplateArr.push(template.slice(currentIndex));
          break;
        }
        evaluatedTemplateArr.push(template.slice(currentIndex, openingBraceIndex));
        const closingBraceIndex = template.indexOf("}", openingBraceIndex);
        if (closingBraceIndex === -1) {
          evaluatedTemplateArr.push(template.slice(openingBraceIndex));
          break;
        }
        if (template[openingBraceIndex + 1] === "{" && template[closingBraceIndex + 1] === "}") {
          evaluatedTemplateArr.push(template.slice(openingBraceIndex + 1, closingBraceIndex));
          currentIndex = closingBraceIndex + 2;
        }
        const parameterName = template.substring(openingBraceIndex + 1, closingBraceIndex);
        if (parameterName.includes("#")) {
          const [refName, attrName] = parameterName.split("#");
          evaluatedTemplateArr.push(getAttr2(referenceRecord[refName] ?? endpointParams[refName], attrName));
        } else {
          evaluatedTemplateArr.push(referenceRecord[parameterName] ?? endpointParams[parameterName]);
        }
        currentIndex = closingBraceIndex + 1;
      }
      return evaluatedTemplateArr.join("");
    }, "evaluateTemplate");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/getReferenceValue.js
var getReferenceValue2;
var init_getReferenceValue2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/getReferenceValue.js"() {
    getReferenceValue2 = /* @__PURE__ */ __name(({ ref }, options) => {
      return options.referenceRecord[ref] ?? options.endpointParams[ref];
    }, "getReferenceValue");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/evaluateExpression.js
var evaluateExpression2, callFunction2, group4;
var init_evaluateExpression2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/evaluateExpression.js"() {
    init_types8();
    init_customEndpointFunctions2();
    init_endpointFunctions2();
    init_evaluateTemplate2();
    init_getReferenceValue2();
    evaluateExpression2 = /* @__PURE__ */ __name((obj, keyName, options) => {
      if (typeof obj === "string") {
        return evaluateTemplate2(obj, options);
      } else if (obj["fn"]) {
        return group4.callFunction(obj, options);
      } else if (obj["ref"]) {
        return getReferenceValue2(obj, options);
      }
      throw new EndpointError2(`'${keyName}': ${String(obj)} is not a string, function or reference.`);
    }, "evaluateExpression");
    callFunction2 = /* @__PURE__ */ __name(({ fn, argv }, options) => {
      const evaluatedArgs = Array(argv.length);
      for (let i32 = 0; i32 < evaluatedArgs.length; ++i32) {
        const arg = argv[i32];
        if (typeof arg === "boolean" || typeof arg === "number") {
          evaluatedArgs[i32] = arg;
        } else {
          evaluatedArgs[i32] = group4.evaluateExpression(arg, "arg", options);
        }
      }
      const namespaceSeparatorIndex = fn.indexOf(".");
      if (namespaceSeparatorIndex !== -1) {
        const namespaceFunctions = customEndpointFunctions20[fn.slice(0, namespaceSeparatorIndex)];
        const customFunction = namespaceFunctions?.[fn.slice(namespaceSeparatorIndex + 1)];
        if (typeof customFunction === "function") {
          return customFunction(...evaluatedArgs);
        }
      }
      const callable = endpointFunctions2[fn];
      if (typeof callable === "function") {
        return callable(...evaluatedArgs);
      }
      throw new Error(`function ${fn} not loaded in endpointFunctions.`);
    }, "callFunction");
    group4 = {
      evaluateExpression: evaluateExpression2,
      callFunction: callFunction2
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/callFunction.js
var init_callFunction2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/callFunction.js"() {
    init_evaluateExpression2();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/evaluateCondition.js
var evaluateCondition2;
var init_evaluateCondition2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/evaluateCondition.js"() {
    init_debug2();
    init_types8();
    init_callFunction2();
    evaluateCondition2 = /* @__PURE__ */ __name((condition, options) => {
      const { assign } = condition;
      if (assign && assign in options.referenceRecord) {
        throw new EndpointError2(`'${assign}' is already defined in Reference Record.`);
      }
      const value = callFunction2(condition, options);
      options.logger?.debug?.(`${debugId2} evaluateCondition: ${toDebugString2(condition)} = ${toDebugString2(value)}`);
      const result2 = value === "" ? true : !!value;
      if (assign != null) {
        return { result: result2, toAssign: { name: assign, value } };
      }
      return { result: result2 };
    }, "evaluateCondition");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/getEndpointHeaders.js
var getEndpointHeaders2;
var init_getEndpointHeaders2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/getEndpointHeaders.js"() {
    init_types8();
    init_evaluateExpression2();
    getEndpointHeaders2 = /* @__PURE__ */ __name((headers, options) => Object.entries(headers ?? {}).reduce((acc, [headerKey, headerVal]) => {
      acc[headerKey] = headerVal.map((headerValEntry) => {
        const processedExpr = evaluateExpression2(headerValEntry, "Header value entry", options);
        if (typeof processedExpr !== "string") {
          throw new EndpointError2(`Header '${headerKey}' value '${processedExpr}' is not a string`);
        }
        return processedExpr;
      });
      return acc;
    }, {}), "getEndpointHeaders");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/getEndpointProperties.js
var getEndpointProperties2, getEndpointProperty2, group5;
var init_getEndpointProperties2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/getEndpointProperties.js"() {
    init_types8();
    init_evaluateTemplate2();
    getEndpointProperties2 = /* @__PURE__ */ __name((properties, options) => Object.entries(properties).reduce((acc, [propertyKey, propertyVal]) => {
      acc[propertyKey] = group5.getEndpointProperty(propertyVal, options);
      return acc;
    }, {}), "getEndpointProperties");
    getEndpointProperty2 = /* @__PURE__ */ __name((property, options) => {
      if (Array.isArray(property)) {
        return property.map((propertyEntry) => getEndpointProperty2(propertyEntry, options));
      }
      switch (typeof property) {
        case "string":
          return evaluateTemplate2(property, options);
        case "object":
          if (property === null) {
            throw new EndpointError2(`Unexpected endpoint property: ${property}`);
          }
          return group5.getEndpointProperties(property, options);
        case "boolean":
          return property;
        default:
          throw new EndpointError2(`Unexpected endpoint property type: ${typeof property}`);
      }
    }, "getEndpointProperty");
    group5 = {
      getEndpointProperty: getEndpointProperty2,
      getEndpointProperties: getEndpointProperties2
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/getEndpointUrl.js
var getEndpointUrl2;
var init_getEndpointUrl2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/getEndpointUrl.js"() {
    init_types8();
    init_evaluateExpression2();
    getEndpointUrl2 = /* @__PURE__ */ __name((endpointUrl, options) => {
      const expression = evaluateExpression2(endpointUrl, "Endpoint URL", options);
      if (typeof expression === "string") {
        try {
          return new URL(expression);
        } catch (error4) {
          console.error(`Failed to construct URL with ${expression}`, error4);
          throw error4;
        }
      }
      throw new EndpointError2(`Endpoint URL must be a string, got ${typeof expression}`);
    }, "getEndpointUrl");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/decideEndpoint.js
var RESULT2, decideEndpoint20;
var init_decideEndpoint2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/decideEndpoint.js"() {
    init_types8();
    init_evaluateCondition2();
    init_evaluateExpression2();
    init_getEndpointHeaders2();
    init_getEndpointProperties2();
    init_getEndpointUrl2();
    RESULT2 = 1e8;
    decideEndpoint20 = /* @__PURE__ */ __name((bdd32, options) => {
      const { nodes: nodes32, root: root32, results, conditions } = bdd32;
      let ref = root32;
      const referenceRecord = {};
      const closure = {
        referenceRecord,
        endpointParams: options.endpointParams,
        logger: options.logger
      };
      while (ref !== 1 && ref !== -1 && ref < RESULT2) {
        const node_i = 3 * (Math.abs(ref) - 1);
        const [condition_i, highRef, lowRef] = [nodes32[node_i], nodes32[node_i + 1], nodes32[node_i + 2]];
        const [fn, argv, assign] = conditions[condition_i];
        const evaluation = evaluateCondition2({ fn, assign, argv }, closure);
        if (evaluation.toAssign) {
          const { name, value } = evaluation.toAssign;
          referenceRecord[name] = value;
        }
        ref = ref >= 0 === evaluation.result ? highRef : lowRef;
      }
      if (ref >= RESULT2) {
        const result2 = results[ref - RESULT2];
        if (result2[0] === -1) {
          const [, errorExpression] = result2;
          throw new EndpointError2(evaluateExpression2(errorExpression, "Error", closure));
        }
        const [url, properties, headers] = result2;
        return {
          url: getEndpointUrl2(url, closure),
          properties: getEndpointProperties2(properties, closure),
          headers: getEndpointHeaders2(headers ?? {}, closure)
        };
      }
      throw new EndpointError2(`No matching endpoint.`);
    }, "decideEndpoint");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/evaluateConditions.js
var evaluateConditions2;
var init_evaluateConditions2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/evaluateConditions.js"() {
    init_debug2();
    init_evaluateCondition2();
    evaluateConditions2 = /* @__PURE__ */ __name((conditions = [], options) => {
      const conditionsReferenceRecord = {};
      const conditionOptions = {
        ...options,
        referenceRecord: { ...options.referenceRecord }
      };
      let didAssign = false;
      for (const condition of conditions) {
        const { result: result2, toAssign } = evaluateCondition2(condition, conditionOptions);
        if (!result2) {
          return { result: result2 };
        }
        if (toAssign) {
          didAssign = true;
          conditionsReferenceRecord[toAssign.name] = toAssign.value;
          conditionOptions.referenceRecord[toAssign.name] = toAssign.value;
          options.logger?.debug?.(`${debugId2} assign: ${toAssign.name} := ${toDebugString2(toAssign.value)}`);
        }
      }
      if (didAssign) {
        return { result: true, referenceRecord: conditionsReferenceRecord };
      }
      return { result: true };
    }, "evaluateConditions");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/evaluateEndpointRule.js
var evaluateEndpointRule2;
var init_evaluateEndpointRule2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/evaluateEndpointRule.js"() {
    init_debug2();
    init_evaluateConditions2();
    init_getEndpointHeaders2();
    init_getEndpointProperties2();
    init_getEndpointUrl2();
    evaluateEndpointRule2 = /* @__PURE__ */ __name((endpointRule, options) => {
      const { conditions, endpoint } = endpointRule;
      const { result: result2, referenceRecord } = evaluateConditions2(conditions, options);
      if (!result2) {
        return;
      }
      const endpointRuleOptions = referenceRecord ? {
        ...options,
        referenceRecord: { ...options.referenceRecord, ...referenceRecord }
      } : options;
      const { url, properties, headers } = endpoint;
      options.logger?.debug?.(`${debugId2} Resolving endpoint from template: ${toDebugString2(endpoint)}`);
      const endpointToReturn = { url: getEndpointUrl2(url, endpointRuleOptions) };
      if (headers != null) {
        endpointToReturn.headers = getEndpointHeaders2(headers, endpointRuleOptions);
      }
      if (properties != null) {
        endpointToReturn.properties = getEndpointProperties2(properties, endpointRuleOptions);
      }
      return endpointToReturn;
    }, "evaluateEndpointRule");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/evaluateErrorRule.js
var evaluateErrorRule2;
var init_evaluateErrorRule2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/evaluateErrorRule.js"() {
    init_types8();
    init_evaluateConditions2();
    init_evaluateExpression2();
    evaluateErrorRule2 = /* @__PURE__ */ __name((errorRule, options) => {
      const { conditions, error: error4 } = errorRule;
      const { result: result2, referenceRecord } = evaluateConditions2(conditions, options);
      if (!result2) {
        return;
      }
      const errorRuleOptions = referenceRecord ? {
        ...options,
        referenceRecord: { ...options.referenceRecord, ...referenceRecord }
      } : options;
      throw new EndpointError2(evaluateExpression2(error4, "Error", errorRuleOptions));
    }, "evaluateErrorRule");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/evaluateRules.js
var evaluateRules2, evaluateTreeRule2, group6;
var init_evaluateRules2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/evaluateRules.js"() {
    init_types8();
    init_evaluateConditions2();
    init_evaluateEndpointRule2();
    init_evaluateErrorRule2();
    evaluateRules2 = /* @__PURE__ */ __name((rules, options) => {
      for (const rule of rules) {
        if (rule.type === "endpoint") {
          const endpointOrUndefined = evaluateEndpointRule2(rule, options);
          if (endpointOrUndefined) {
            return endpointOrUndefined;
          }
        } else if (rule.type === "error") {
          evaluateErrorRule2(rule, options);
        } else if (rule.type === "tree") {
          const endpointOrUndefined = group6.evaluateTreeRule(rule, options);
          if (endpointOrUndefined) {
            return endpointOrUndefined;
          }
        } else {
          throw new EndpointError2(`Unknown endpoint rule: ${rule}`);
        }
      }
      throw new EndpointError2(`Rules evaluation failed`);
    }, "evaluateRules");
    evaluateTreeRule2 = /* @__PURE__ */ __name((treeRule, options) => {
      const { conditions, rules } = treeRule;
      const { result: result2, referenceRecord } = evaluateConditions2(conditions, options);
      if (!result2) {
        return;
      }
      const treeRuleOptions = referenceRecord ? { ...options, referenceRecord: { ...options.referenceRecord, ...referenceRecord } } : options;
      return group6.evaluateRules(rules, treeRuleOptions);
    }, "evaluateTreeRule");
    group6 = {
      evaluateRules: evaluateRules2,
      evaluateTreeRule: evaluateTreeRule2
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/index.js
var init_utils9 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/utils/index.js"() {
    init_customEndpointFunctions2();
    init_evaluateRules2();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/resolveEndpoint.js
var resolveEndpoint2;
var init_resolveEndpoint2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/resolveEndpoint.js"() {
    init_debug2();
    init_types8();
    init_utils9();
    resolveEndpoint2 = /* @__PURE__ */ __name((ruleSetObject, options) => {
      const { endpointParams, logger: logger5 } = options;
      const { parameters, rules } = ruleSetObject;
      options.logger?.debug?.(`${debugId2} Initial EndpointParams: ${toDebugString2(endpointParams)}`);
      for (const paramKey in parameters) {
        const parameter = parameters[paramKey];
        const endpointParam = endpointParams[paramKey];
        if (endpointParam == null && parameter.default != null) {
          endpointParams[paramKey] = parameter.default;
          continue;
        }
        if (parameter.required && endpointParam == null) {
          throw new EndpointError2(`Missing required parameter: '${paramKey}'`);
        }
      }
      const endpoint = evaluateRules2(rules, { endpointParams, logger: logger5, referenceRecord: {} });
      options.logger?.debug?.(`${debugId2} Resolved endpoint: ${toDebugString2(endpoint)}`);
      return endpoint;
    }, "resolveEndpoint");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/resolveEndpointRequiredConfig.js
var resolveEndpointRequiredConfig2;
var init_resolveEndpointRequiredConfig2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/resolveEndpointRequiredConfig.js"() {
    resolveEndpointRequiredConfig2 = /* @__PURE__ */ __name((input) => {
      const { endpoint } = input;
      if (endpoint === void 0) {
        input.endpoint = async () => {
          throw new Error("@smithy/middleware-endpoint: (default endpointRuleSet) endpoint is not set - you must configure an endpoint.");
        };
      }
      return input;
    }, "resolveEndpointRequiredConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/index.js
var endpoints_exports3 = {};
__export(endpoints_exports3, {
  BinaryDecisionDiagram: () => BinaryDecisionDiagram20,
  EndpointCache: () => EndpointCache20,
  EndpointError: () => EndpointError2,
  customEndpointFunctions: () => customEndpointFunctions20,
  decideEndpoint: () => decideEndpoint20,
  endpointMiddleware: () => endpointMiddleware2,
  endpointMiddlewareOptions: () => endpointMiddlewareOptions2,
  getEndpointFromInstructions: () => getEndpointFromInstructions3,
  getEndpointPlugin: () => getEndpointPlugin26,
  isIpAddress: () => isIpAddress2,
  isValidHostLabel: () => isValidHostLabel2,
  middlewareEndpointToEndpointV1: () => toEndpointV13,
  resolveEndpoint: () => resolveEndpoint2,
  resolveEndpointConfig: () => resolveEndpointConfig20,
  resolveEndpointRequiredConfig: () => resolveEndpointRequiredConfig2,
  resolveParams: () => resolveParams7,
  toEndpointV1: () => toEndpointV13
});
var getEndpointFromInstructions3, resolveEndpointConfig20, endpointMiddleware2, getEndpointPlugin26;
var init_endpoints3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/endpoints/index.js"() {
    init_getEndpointFromConfig2();
    init_getEndpointFromInstructions2();
    init_endpointMiddleware2();
    init_getEndpointPlugin2();
    init_resolveEndpointConfig2();
    init_toEndpointV14();
    init_BinaryDecisionDiagram2();
    init_EndpointCache2();
    init_decideEndpoint2();
    init_isIpAddress2();
    init_isValidHostLabel2();
    init_customEndpointFunctions2();
    init_resolveEndpoint2();
    init_types8();
    init_getEndpointFromInstructions2();
    init_toEndpointV15();
    init_getEndpointPlugin2();
    init_resolveEndpointRequiredConfig2();
    getEndpointFromInstructions3 = bindGetEndpointFromInstructions2(getEndpointFromConfig2);
    resolveEndpointConfig20 = bindResolveEndpointConfig2(getEndpointFromConfig2);
    endpointMiddleware2 = bindEndpointMiddleware2(getEndpointFromConfig2);
    getEndpointPlugin26 = bindGetEndpointPlugin2(getEndpointFromConfig2);
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/middleware-serde/serializerMiddleware.js
var serializerMiddleware;
var init_serializerMiddleware = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/middleware-serde/serializerMiddleware.js"() {
    init_endpoints3();
    serializerMiddleware = /* @__PURE__ */ __name((options, serializer) => (next, context) => async (args) => {
      const endpointConfig = options;
      const endpoint = context.endpointV2 ? async () => toEndpointV13(context.endpointV2) : endpointConfig.endpoint;
      if (!endpoint) {
        throw new Error("No valid endpoint provider available.");
      }
      const request4 = await serializer(args.input, { ...options, endpoint });
      return next({
        ...args,
        request: request4
      });
    }, "serializerMiddleware");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/middleware-serde/serdePlugin.js
function getSerdePlugin(config2, serializer, deserializer) {
  return {
    applyToStack: /* @__PURE__ */ __name((commandStack) => {
      commandStack.add(deserializerMiddleware(config2, deserializer), deserializerMiddlewareOption2);
      commandStack.add(serializerMiddleware(config2, serializer), serializerMiddlewareOption4);
    }, "applyToStack")
  };
}
var deserializerMiddlewareOption2, serializerMiddlewareOption4;
var init_serdePlugin = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/middleware-serde/serdePlugin.js"() {
    init_deserializerMiddleware();
    init_serializerMiddleware();
    deserializerMiddlewareOption2 = {
      name: "deserializerMiddleware",
      step: "deserialize",
      tags: ["DESERIALIZER"],
      override: true
    };
    serializerMiddlewareOption4 = {
      name: "serializerMiddleware",
      step: "serialize",
      tags: ["SERIALIZER"],
      override: true
    };
    __name(getSerdePlugin, "getSerdePlugin");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/hash-node/hash-node.js
function castSourceData(toCast, encoding) {
  if (Buffer.isBuffer(toCast)) {
    return toCast;
  }
  if (typeof toCast === "string") {
    return fromString3(toCast, encoding);
  }
  if (ArrayBuffer.isView(toCast)) {
    return fromArrayBuffer3(toCast.buffer, toCast.byteOffset, toCast.byteLength);
  }
  return fromArrayBuffer3(toCast);
}
var import_node_crypto9, Hash19;
var init_hash_node = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/hash-node/hash-node.js"() {
    import_node_crypto9 = require("node:crypto");
    init_buffer_from3();
    init_toUint8Array();
    Hash19 = class {
      static {
        __name(this, "Hash");
      }
      algorithmIdentifier;
      secret;
      hash;
      constructor(algorithmIdentifier, secret) {
        this.algorithmIdentifier = algorithmIdentifier;
        this.secret = secret;
        this.reset();
      }
      update(toHash, encoding) {
        this.hash.update(toUint8Array2(castSourceData(toHash, encoding)));
      }
      digest() {
        return Promise.resolve(this.hash.digest());
      }
      reset() {
        this.hash = this.secret ? (0, import_node_crypto9.createHmac)(this.algorithmIdentifier, castSourceData(this.secret)) : (0, import_node_crypto9.createHash)(this.algorithmIdentifier);
      }
    };
    __name(castSourceData, "castSourceData");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/checksum/ChecksumStream.js
var import_node_stream6, ChecksumStream;
var init_ChecksumStream = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/checksum/ChecksumStream.js"() {
    import_node_stream6 = require("node:stream");
    init_toBase643();
    ChecksumStream = class extends import_node_stream6.Duplex {
      static {
        __name(this, "ChecksumStream");
      }
      expectedChecksum;
      checksumSourceLocation;
      checksum;
      source;
      base64Encoder;
      pendingCallback = null;
      constructor({ expectedChecksum, checksum, source, checksumSourceLocation, base64Encoder }) {
        super();
        if (typeof source.pipe === "function") {
          this.source = source;
        } else {
          throw new Error(`@smithy/util-stream: unsupported source type ${source?.constructor?.name ?? source} in ChecksumStream.`);
        }
        this.base64Encoder = base64Encoder ?? toBase6441;
        this.expectedChecksum = expectedChecksum;
        this.checksum = checksum;
        this.checksumSourceLocation = checksumSourceLocation;
        this.source.pipe(this);
      }
      _read(size) {
        if (this.pendingCallback) {
          const callback = this.pendingCallback;
          this.pendingCallback = null;
          callback();
        }
      }
      _write(chunk, encoding, callback) {
        try {
          this.checksum.update(chunk);
          const canPushMore = this.push(chunk);
          if (!canPushMore) {
            this.pendingCallback = callback;
            return;
          }
        } catch (e32) {
          return callback(e32);
        }
        return callback();
      }
      async _final(callback) {
        try {
          const digest = await this.checksum.digest();
          const received = this.base64Encoder(digest);
          if (this.expectedChecksum !== received) {
            return callback(new Error(`Checksum mismatch: expected "${this.expectedChecksum}" but received "${received}" in response header "${this.checksumSourceLocation}".`));
          }
        } catch (e32) {
          return callback(e32);
        }
        this.push(null);
        return callback();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-type-check.js
var isReadableStream2, isBlob;
var init_stream_type_check2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-type-check.js"() {
    isReadableStream2 = /* @__PURE__ */ __name((stream) => typeof ReadableStream === "function" && (stream?.constructor?.name === ReadableStream.name || stream instanceof ReadableStream), "isReadableStream");
    isBlob = /* @__PURE__ */ __name((blob) => {
      return typeof Blob === "function" && (blob?.constructor?.name === Blob.name || blob instanceof Blob);
    }, "isBlob");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/fromUtf8.browser.js
var fromUtf826;
var init_fromUtf8_browser2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/fromUtf8.browser.js"() {
    fromUtf826 = /* @__PURE__ */ __name((input) => new TextEncoder().encode(input), "fromUtf8");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/constants-for-browser.js
var chars2, alphabetByEncoding2, alphabetByValue2, bitsPerLetter2, bitsPerByte2, maxLetterValue2;
var init_constants_for_browser2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/constants-for-browser.js"() {
    chars2 = `ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/`;
    alphabetByEncoding2 = Object.entries(chars2).reduce((acc, [i32, c32]) => {
      acc[c32] = Number(i32);
      return acc;
    }, {});
    alphabetByValue2 = chars2.split("");
    bitsPerLetter2 = 6;
    bitsPerByte2 = 8;
    maxLetterValue2 = 63;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/toBase64.browser.js
function toBase6442(_input) {
  let input;
  if (typeof _input === "string") {
    input = fromUtf826(_input);
  } else {
    input = _input;
  }
  const isArrayLike = typeof input === "object" && typeof input.length === "number";
  const isUint8Array = typeof input === "object" && typeof input.byteOffset === "number" && typeof input.byteLength === "number";
  if (!isArrayLike && !isUint8Array) {
    throw new Error("@smithy/util-base64: toBase64 encoder function only accepts string | Uint8Array.");
  }
  let str = "";
  for (let i32 = 0; i32 < input.length; i32 += 3) {
    let bits = 0;
    let bitLength = 0;
    for (let j32 = i32, limit = Math.min(i32 + 3, input.length); j32 < limit; j32++) {
      bits |= input[j32] << (limit - j32 - 1) * bitsPerByte2;
      bitLength += bitsPerByte2;
    }
    const bitClusterCount = Math.ceil(bitLength / bitsPerLetter2);
    bits <<= bitClusterCount * bitsPerLetter2 - bitLength;
    for (let k32 = 1; k32 <= bitClusterCount; k32++) {
      const offset = (bitClusterCount - k32) * bitsPerLetter2;
      str += alphabetByValue2[(bits & maxLetterValue2 << offset) >> offset];
    }
    str += "==".slice(0, 4 - bitClusterCount);
  }
  return str;
}
var init_toBase64_browser2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/toBase64.browser.js"() {
    init_fromUtf8_browser2();
    init_constants_for_browser2();
    __name(toBase6442, "toBase64");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/checksum/ChecksumStream.browser.js
var ReadableStreamRef, ChecksumStream2;
var init_ChecksumStream_browser = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/checksum/ChecksumStream.browser.js"() {
    ReadableStreamRef = typeof ReadableStream === "function" ? ReadableStream : function() {
    };
    ChecksumStream2 = class extends ReadableStreamRef {
      static {
        __name(this, "ChecksumStream");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/checksum/createChecksumStream.browser.js
var createChecksumStream;
var init_createChecksumStream_browser = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/checksum/createChecksumStream.browser.js"() {
    init_toBase64_browser2();
    init_stream_type_check2();
    init_ChecksumStream_browser();
    createChecksumStream = /* @__PURE__ */ __name(({ expectedChecksum, checksum, source, checksumSourceLocation, base64Encoder }) => {
      if (!isReadableStream2(source)) {
        throw new Error(`@smithy/util-stream: unsupported source type ${source?.constructor?.name ?? source} in ChecksumStream.`);
      }
      const encoder = base64Encoder ?? toBase6442;
      if (typeof TransformStream !== "function") {
        throw new Error("@smithy/util-stream: unable to instantiate ChecksumStream because API unavailable: ReadableStream/TransformStream.");
      }
      const transform = new TransformStream({
        start() {
        },
        async transform(chunk, controller) {
          checksum.update(chunk);
          controller.enqueue(chunk);
        },
        async flush(controller) {
          const digest = await checksum.digest();
          const received = encoder(digest);
          if (expectedChecksum !== received) {
            const error4 = new Error(`Checksum mismatch: expected "${expectedChecksum}" but received "${received}" in response header "${checksumSourceLocation}".`);
            controller.error(error4);
          } else {
            controller.terminate();
          }
        }
      });
      source.pipeThrough(transform);
      const readable = transform.readable;
      Object.setPrototypeOf(readable, ChecksumStream2.prototype);
      return readable;
    }, "createChecksumStream");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/checksum/createChecksumStream.js
function createChecksumStream2(init) {
  if (typeof ReadableStream === "function" && isReadableStream2(init.source)) {
    return createChecksumStream(init);
  }
  return new ChecksumStream(init);
}
var init_createChecksumStream = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/checksum/createChecksumStream.js"() {
    init_stream_type_check2();
    init_ChecksumStream();
    init_createChecksumStream_browser();
    __name(createChecksumStream2, "createChecksumStream");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/ByteArrayCollector.js
var ByteArrayCollector;
var init_ByteArrayCollector = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/ByteArrayCollector.js"() {
    ByteArrayCollector = class {
      static {
        __name(this, "ByteArrayCollector");
      }
      allocByteArray;
      byteLength = 0;
      byteArrays = [];
      constructor(allocByteArray) {
        this.allocByteArray = allocByteArray;
      }
      push(byteArray) {
        this.byteArrays.push(byteArray);
        this.byteLength += byteArray.byteLength;
      }
      flush() {
        if (this.byteArrays.length === 1) {
          const bytes = this.byteArrays[0];
          this.reset();
          return bytes;
        }
        const aggregation = this.allocByteArray(this.byteLength);
        let cursor3 = 0;
        for (let i32 = 0; i32 < this.byteArrays.length; ++i32) {
          const bytes = this.byteArrays[i32];
          aggregation.set(bytes, cursor3);
          cursor3 += bytes.byteLength;
        }
        this.reset();
        return aggregation;
      }
      reset() {
        this.byteArrays = [];
        this.byteLength = 0;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/createBufferedReadable.browser.js
function createBufferedReadableStream(upstream, size, logger5) {
  const reader = upstream.getReader();
  let streamBufferingLoggedWarning = false;
  let bytesSeen = 0;
  const buffers = ["", new ByteArrayCollector((size2) => new Uint8Array(size2))];
  let mode = -1;
  const pull = /* @__PURE__ */ __name(async (controller) => {
    const { value, done } = await reader.read();
    const chunk = value;
    if (done) {
      if (mode !== -1) {
        const remainder = flush(buffers, mode);
        if (sizeOf(remainder) > 0) {
          controller.enqueue(remainder);
        }
      }
      controller.close();
    } else {
      const chunkMode = modeOf(chunk, false);
      if (mode !== chunkMode) {
        if (mode >= 0) {
          controller.enqueue(flush(buffers, mode));
        }
        mode = chunkMode;
      }
      if (mode === -1) {
        controller.enqueue(chunk);
        return;
      }
      const chunkSize = sizeOf(chunk);
      bytesSeen += chunkSize;
      const bufferSize = sizeOf(buffers[mode]);
      if (chunkSize >= size && bufferSize === 0) {
        controller.enqueue(chunk);
      } else {
        const newSize = merge(buffers, mode, chunk);
        if (!streamBufferingLoggedWarning && bytesSeen > size * 2) {
          streamBufferingLoggedWarning = true;
          logger5?.warn(`@smithy/util-stream - stream chunk size ${chunkSize} is below threshold of ${size}, automatically buffering.`);
        }
        if (newSize >= size) {
          controller.enqueue(flush(buffers, mode));
        } else {
          await pull(controller);
        }
      }
    }
  }, "pull");
  return new ReadableStream({
    pull
  });
}
function merge(buffers, mode, chunk) {
  switch (mode) {
    case 0:
      buffers[0] += chunk;
      return sizeOf(buffers[0]);
    case 1:
    case 2:
      buffers[mode].push(chunk);
      return sizeOf(buffers[mode]);
  }
}
function flush(buffers, mode) {
  switch (mode) {
    case 0:
      const s = buffers[0];
      buffers[0] = "";
      return s;
    case 1:
    case 2:
      return buffers[mode].flush();
  }
  throw new Error(`@smithy/util-stream - invalid index ${mode} given to flush()`);
}
function sizeOf(chunk) {
  return chunk?.byteLength ?? chunk?.length ?? 0;
}
function modeOf(chunk, allowBuffer = true) {
  if (allowBuffer && typeof Buffer !== "undefined" && chunk instanceof Buffer) {
    return 2;
  }
  if (chunk instanceof Uint8Array) {
    return 1;
  }
  if (typeof chunk === "string") {
    return 0;
  }
  return -1;
}
var init_createBufferedReadable_browser = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/createBufferedReadable.browser.js"() {
    init_ByteArrayCollector();
    __name(createBufferedReadableStream, "createBufferedReadableStream");
    __name(merge, "merge");
    __name(flush, "flush");
    __name(sizeOf, "sizeOf");
    __name(modeOf, "modeOf");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/createBufferedReadable.js
function createBufferedReadable(upstream, size, logger5) {
  if (isReadableStream2(upstream)) {
    return createBufferedReadableStream(upstream, size, logger5);
  }
  const downstream = new import_node_stream7.Readable({ read() {
  } });
  let streamBufferingLoggedWarning = false;
  let bytesSeen = 0;
  const buffers = [
    "",
    new ByteArrayCollector((size2) => new Uint8Array(size2)),
    new ByteArrayCollector((size2) => Buffer.from(new Uint8Array(size2)))
  ];
  let mode = -1;
  upstream.on("data", (chunk) => {
    const chunkMode = modeOf(chunk, true);
    if (mode !== chunkMode) {
      if (mode >= 0) {
        downstream.push(flush(buffers, mode));
      }
      mode = chunkMode;
    }
    if (mode === -1) {
      downstream.push(chunk);
      return;
    }
    const chunkSize = sizeOf(chunk);
    bytesSeen += chunkSize;
    const bufferSize = sizeOf(buffers[mode]);
    if (chunkSize >= size && bufferSize === 0) {
      downstream.push(chunk);
    } else {
      const newSize = merge(buffers, mode, chunk);
      if (!streamBufferingLoggedWarning && bytesSeen > size * 2) {
        streamBufferingLoggedWarning = true;
        logger5?.warn(`@smithy/util-stream - stream chunk size ${chunkSize} is below threshold of ${size}, automatically buffering.`);
      }
      if (newSize >= size) {
        downstream.push(flush(buffers, mode));
      }
    }
  });
  upstream.on("end", () => {
    if (mode !== -1) {
      const remainder = flush(buffers, mode);
      if (sizeOf(remainder) > 0) {
        downstream.push(remainder);
      }
    }
    downstream.push(null);
  });
  return downstream;
}
var import_node_stream7;
var init_createBufferedReadable = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/createBufferedReadable.js"() {
    import_node_stream7 = require("node:stream");
    init_ByteArrayCollector();
    init_createBufferedReadable_browser();
    init_stream_type_check2();
    __name(createBufferedReadable, "createBufferedReadable");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/getAwsChunkedEncodingStream.browser.js
var getAwsChunkedEncodingStream;
var init_getAwsChunkedEncodingStream_browser = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/getAwsChunkedEncodingStream.browser.js"() {
    getAwsChunkedEncodingStream = /* @__PURE__ */ __name((readableStream, options) => {
      const { base64Encoder, bodyLengthChecker, checksumAlgorithmFn, checksumLocationName, streamHasher } = options;
      const checksumRequired = base64Encoder !== void 0 && bodyLengthChecker !== void 0 && checksumAlgorithmFn !== void 0 && checksumLocationName !== void 0 && streamHasher !== void 0;
      const digest = checksumRequired ? streamHasher(checksumAlgorithmFn, readableStream) : void 0;
      const reader = readableStream.getReader();
      return new ReadableStream({
        async pull(controller) {
          const { value, done } = await reader.read();
          if (done) {
            controller.enqueue(`0\r
`);
            if (checksumRequired) {
              const checksum = base64Encoder(await digest);
              controller.enqueue(`${checksumLocationName}:${checksum}\r
`);
              controller.enqueue(`\r
`);
            }
            controller.close();
          } else {
            controller.enqueue(`${(bodyLengthChecker(value) || 0).toString(16)}\r
${value}\r
`);
          }
        }
      });
    }, "getAwsChunkedEncodingStream");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/getAwsChunkedEncodingStream.js
function getAwsChunkedEncodingStream2(stream, options) {
  const readable = stream;
  const readableStream = stream;
  if (isReadableStream2(readableStream)) {
    return getAwsChunkedEncodingStream(readableStream, options);
  }
  const { base64Encoder, bodyLengthChecker, checksumAlgorithmFn, checksumLocationName, streamHasher } = options;
  const checksumRequired = base64Encoder !== void 0 && checksumAlgorithmFn !== void 0 && checksumLocationName !== void 0 && streamHasher !== void 0;
  const digest = checksumRequired ? streamHasher(checksumAlgorithmFn, readable) : void 0;
  const awsChunkedEncodingStream = new import_node_stream8.Readable({
    read: /* @__PURE__ */ __name(() => {
    }, "read")
  });
  readable.on("data", (data3) => {
    const length = bodyLengthChecker(data3) || 0;
    if (length === 0) {
      return;
    }
    awsChunkedEncodingStream.push(`${length.toString(16)}\r
`);
    awsChunkedEncodingStream.push(data3);
    awsChunkedEncodingStream.push("\r\n");
  });
  readable.on("end", async () => {
    awsChunkedEncodingStream.push(`0\r
`);
    if (checksumRequired) {
      const checksum = base64Encoder(await digest);
      awsChunkedEncodingStream.push(`${checksumLocationName}:${checksum}\r
`);
      awsChunkedEncodingStream.push(`\r
`);
    }
    awsChunkedEncodingStream.push(null);
  });
  return awsChunkedEncodingStream;
}
var import_node_stream8;
var init_getAwsChunkedEncodingStream = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/getAwsChunkedEncodingStream.js"() {
    import_node_stream8 = require("node:stream");
    init_getAwsChunkedEncodingStream_browser();
    init_stream_type_check2();
    __name(getAwsChunkedEncodingStream2, "getAwsChunkedEncodingStream");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/headStream.browser.js
async function headStream(stream, bytes) {
  let byteLengthCounter = 0;
  const chunks2 = [];
  const reader = stream.getReader();
  let isDone = false;
  while (!isDone) {
    const { done, value } = await reader.read();
    if (value) {
      chunks2.push(value);
      byteLengthCounter += value?.byteLength ?? 0;
    }
    if (byteLengthCounter >= bytes) {
      break;
    }
    isDone = done;
  }
  reader.releaseLock();
  const collected = new Uint8Array(Math.min(bytes, byteLengthCounter));
  let offset = 0;
  for (const chunk of chunks2) {
    if (chunk.byteLength > collected.byteLength - offset) {
      collected.set(chunk.subarray(0, collected.byteLength - offset), offset);
      break;
    } else {
      collected.set(chunk, offset);
    }
    offset += chunk.length;
  }
  return collected;
}
var init_headStream_browser = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/headStream.browser.js"() {
    __name(headStream, "headStream");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/headStream.js
var import_node_stream9, headStream2, Collector2;
var init_headStream = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/headStream.js"() {
    import_node_stream9 = require("node:stream");
    init_headStream_browser();
    init_stream_type_check2();
    headStream2 = /* @__PURE__ */ __name((stream, bytes) => {
      if (isReadableStream2(stream)) {
        return headStream(stream, bytes);
      }
      return new Promise((resolve13, reject) => {
        const collector = new Collector2();
        collector.limit = bytes;
        stream.pipe(collector);
        stream.on("error", (err) => {
          collector.end();
          reject(err);
        });
        collector.on("error", reject);
        collector.on("finish", function() {
          const bytes2 = new Uint8Array(Buffer.concat(this.buffers));
          resolve13(bytes2);
        });
      });
    }, "headStream");
    Collector2 = class extends import_node_stream9.Writable {
      static {
        __name(this, "Collector");
      }
      buffers = [];
      limit = Infinity;
      bytesBuffered = 0;
      _write(chunk, encoding, callback) {
        this.buffers.push(chunk);
        this.bytesBuffered += chunk.byteLength ?? 0;
        if (this.bytesBuffered >= this.limit) {
          const excess = this.bytesBuffered - this.limit;
          const tailBuffer = this.buffers[this.buffers.length - 1];
          this.buffers[this.buffers.length - 1] = tailBuffer.subarray(0, tailBuffer.byteLength - excess);
          this.emit("finish");
        }
        callback();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/toUtf8.browser.js
var toUtf840;
var init_toUtf8_browser2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/toUtf8.browser.js"() {
    toUtf840 = /* @__PURE__ */ __name((input) => {
      if (typeof input === "string") {
        return input;
      }
      if (typeof input !== "object" || typeof input.byteOffset !== "number" || typeof input.byteLength !== "number") {
        throw new Error("@smithy/util-utf8: toUtf8 encoder function only accepts string | Uint8Array.");
      }
      return new TextDecoder("utf-8").decode(input);
    }, "toUtf8");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/fromBase64.browser.js
var fromBase6437;
var init_fromBase64_browser2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/fromBase64.browser.js"() {
    init_constants_for_browser2();
    fromBase6437 = /* @__PURE__ */ __name((input) => {
      let totalByteLength = input.length / 4 * 3;
      if (input.slice(-2) === "==") {
        totalByteLength -= 2;
      } else if (input.slice(-1) === "=") {
        totalByteLength--;
      }
      const out = new ArrayBuffer(totalByteLength);
      const dataView5 = new DataView(out);
      for (let i32 = 0; i32 < input.length; i32 += 4) {
        let bits = 0;
        let bitLength = 0;
        for (let j32 = i32, limit = i32 + 3; j32 <= limit; j32++) {
          if (input[j32] !== "=") {
            if (!(input[j32] in alphabetByEncoding2)) {
              throw new TypeError(`Invalid character ${input[j32]} in base64 string.`);
            }
            bits |= alphabetByEncoding2[input[j32]] << (limit - j32) * bitsPerLetter2;
            bitLength += bitsPerLetter2;
          } else {
            bits >>= bitsPerLetter2;
          }
        }
        const chunkOffset = i32 / 4 * 3;
        bits >>= bitLength % bitsPerByte2;
        const byteLength = Math.floor(bitLength / bitsPerByte2);
        for (let k32 = 0; k32 < byteLength; k32++) {
          const offset = (byteLength - k32 - 1) * bitsPerByte2;
          dataView5.setUint8(chunkOffset + k32, (bits & 255 << offset) >> offset);
        }
      }
      return new Uint8Array(out);
    }, "fromBase64");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-collector.browser.js
async function collectBlob2(blob) {
  const base64 = await readToBase642(blob);
  const arrayBuffer = fromBase6437(base64);
  return new Uint8Array(arrayBuffer);
}
async function collectStream2(stream) {
  const chunks2 = [];
  const reader = stream.getReader();
  let isDone = false;
  let length = 0;
  while (!isDone) {
    const { done, value } = await reader.read();
    if (value) {
      chunks2.push(value);
      length += value.length;
    }
    isDone = done;
  }
  const collected = new Uint8Array(length);
  let offset = 0;
  for (const chunk of chunks2) {
    collected.set(chunk, offset);
    offset += chunk.length;
  }
  return collected;
}
function readToBase642(blob) {
  return new Promise((resolve13, reject) => {
    const reader = new FileReader();
    reader.onloadend = () => {
      if (reader.readyState !== 2) {
        return reject(new Error("Reader aborted too early"));
      }
      const result2 = reader.result ?? "";
      const commaIndex = result2.indexOf(",");
      const dataOffset = commaIndex > -1 ? commaIndex + 1 : result2.length;
      resolve13(result2.substring(dataOffset));
    };
    reader.onabort = () => reject(new Error("Read aborted"));
    reader.onerror = () => reject(reader.error);
    reader.readAsDataURL(blob);
  });
}
var streamCollector21;
var init_stream_collector_browser2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-collector.browser.js"() {
    init_fromBase64_browser2();
    streamCollector21 = /* @__PURE__ */ __name(async (stream) => {
      if (typeof Blob === "function" && stream instanceof Blob || stream.constructor?.name === "Blob") {
        if (Blob.prototype.arrayBuffer !== void 0) {
          return new Uint8Array(await stream.arrayBuffer());
        }
        return collectBlob2(stream);
      }
      return collectStream2(stream);
    }, "streamCollector");
    __name(collectBlob2, "collectBlob");
    __name(collectStream2, "collectStream");
    __name(readToBase642, "readToBase64");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/sdk-stream-mixin.browser.js
var ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED3, sdkStreamMixin4, isBlobInstance2;
var init_sdk_stream_mixin_browser2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/sdk-stream-mixin.browser.js"() {
    init_toBase64_browser2();
    init_hex_encoding2();
    init_toUtf8_browser2();
    init_stream_collector_browser2();
    init_stream_type_check2();
    ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED3 = "The stream has already been transformed.";
    sdkStreamMixin4 = /* @__PURE__ */ __name((stream) => {
      if (!isBlobInstance2(stream) && !isReadableStream2(stream)) {
        const name = stream?.__proto__?.constructor?.name || stream;
        throw new Error(`Unexpected stream implementation, expect Blob or ReadableStream, got ${name}`);
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED3);
        }
        transformed = true;
        return await streamCollector21(stream);
      }, "transformToByteArray");
      const blobToWebStream = /* @__PURE__ */ __name((blob) => {
        if (typeof blob.stream !== "function") {
          throw new Error("Cannot transform payload Blob to web stream. Please make sure the Blob.stream() is polyfilled.\nIf you are using React Native, this API is not yet supported, see: https://react-native.canny.io/feature-requests/p/fetch-streaming-body");
        }
        return blob.stream();
      }, "blobToWebStream");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === "base64") {
            return toBase6442(buf);
          } else if (encoding === "hex") {
            return toHex2(buf);
          } else if (encoding === void 0 || encoding === "utf8" || encoding === "utf-8") {
            return toUtf840(buf);
          } else if (typeof TextDecoder === "function") {
            return new TextDecoder(encoding).decode(buf);
          } else {
            throw new Error("TextDecoder is not available, please make sure polyfill is provided.");
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED3);
          }
          transformed = true;
          if (isBlobInstance2(stream)) {
            return blobToWebStream(stream);
          } else if (isReadableStream2(stream)) {
            return stream;
          } else {
            throw new Error(`Cannot transform payload to web stream, got ${stream}`);
          }
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
    isBlobInstance2 = /* @__PURE__ */ __name((stream) => typeof Blob === "function" && stream instanceof Blob, "isBlobInstance");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-collector.js
async function collectReadableStream2(stream) {
  const chunks2 = [];
  const reader = stream.getReader();
  let isDone = false;
  let length = 0;
  while (!isDone) {
    const { done, value } = await reader.read();
    if (value) {
      chunks2.push(value);
      length += value.length;
    }
    isDone = done;
  }
  const collected = new Uint8Array(length);
  let offset = 0;
  for (const chunk of chunks2) {
    collected.set(chunk, offset);
    offset += chunk.length;
  }
  return collected;
}
var import_node_stream10, Collector3, isReadableStreamInstance2, streamCollector22;
var init_stream_collector2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-collector.js"() {
    import_node_stream10 = require("node:stream");
    Collector3 = class extends import_node_stream10.Writable {
      static {
        __name(this, "Collector");
      }
      bufferedBytes = [];
      _write(chunk, encoding, callback) {
        this.bufferedBytes.push(chunk);
        callback();
      }
    };
    isReadableStreamInstance2 = /* @__PURE__ */ __name((stream) => typeof ReadableStream === "function" && stream instanceof ReadableStream, "isReadableStreamInstance");
    __name(collectReadableStream2, "collectReadableStream");
    streamCollector22 = /* @__PURE__ */ __name((stream) => {
      if (isReadableStreamInstance2(stream)) {
        return collectReadableStream2(stream);
      }
      return new Promise((resolve13, reject) => {
        const collector = new Collector3();
        stream.pipe(collector);
        stream.on("error", (err) => {
          collector.end();
          reject(err);
        });
        collector.on("error", reject);
        collector.on("finish", function() {
          const bytes = new Uint8Array(Buffer.concat(this.bufferedBytes));
          resolve13(bytes);
        });
      });
    }, "streamCollector");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/sdk-stream-mixin.js
var import_node_stream11, ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED4, sdkStreamMixin5;
var init_sdk_stream_mixin2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/sdk-stream-mixin.js"() {
    import_node_stream11 = require("node:stream");
    init_buffer_from3();
    init_sdk_stream_mixin_browser2();
    init_stream_collector2();
    ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED4 = "The stream has already been transformed.";
    sdkStreamMixin5 = /* @__PURE__ */ __name((stream) => {
      if (!(stream instanceof import_node_stream11.Readable)) {
        try {
          return sdkStreamMixin4(stream);
        } catch (e32) {
          const name = stream?.__proto__?.constructor?.name || stream;
          throw new Error(`Unexpected stream implementation, expect Stream.Readable instance, got ${name}`);
        }
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED4);
        }
        transformed = true;
        return await streamCollector22(stream);
      }, "transformToByteArray");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === void 0 || Buffer.isEncoding(encoding)) {
            return fromArrayBuffer3(buf.buffer, buf.byteOffset, buf.byteLength).toString(encoding);
          } else {
            const decoder = new TextDecoder(encoding);
            return decoder.decode(buf);
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED4);
          }
          if (stream.readableFlowing !== null) {
            throw new Error("The stream has been consumed by other callbacks.");
          }
          if (typeof import_node_stream11.Readable.toWeb !== "function") {
            throw new Error("Readable.toWeb() is not supported. Please ensure a polyfill is available.");
          }
          transformed = true;
          return import_node_stream11.Readable.toWeb(stream);
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/splitStream.browser.js
async function splitStream(stream) {
  if (typeof stream.stream === "function") {
    stream = stream.stream();
  }
  const readableStream = stream;
  return readableStream.tee();
}
var init_splitStream_browser = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/splitStream.browser.js"() {
    __name(splitStream, "splitStream");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/splitStream.js
async function splitStream2(stream) {
  if (isReadableStream2(stream) || isBlob(stream)) {
    return splitStream(stream);
  }
  const stream1 = new import_node_stream12.PassThrough();
  const stream2 = new import_node_stream12.PassThrough();
  stream.pipe(stream1);
  stream.pipe(stream2);
  return [stream1, stream2];
}
var import_node_stream12;
var init_splitStream = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/splitStream.js"() {
    import_node_stream12 = require("node:stream");
    init_splitStream_browser();
    init_stream_type_check2();
    __name(splitStream2, "splitStream");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/index.js
var serde_exports2 = {};
__export(serde_exports2, {
  ChecksumStream: () => ChecksumStream,
  Hash: () => Hash19,
  LazyJsonString: () => LazyJsonString5,
  NumericValue: () => NumericValue3,
  Uint8ArrayBlobAdapter: () => Uint8ArrayBlobAdapter4,
  _parseEpochTimestamp: () => _parseEpochTimestamp3,
  _parseRfc3339DateTimeWithOffset: () => _parseRfc3339DateTimeWithOffset3,
  _parseRfc7231DateTime: () => _parseRfc7231DateTime3,
  calculateBodyLength: () => calculateBodyLength19,
  copyDocumentWithTransform: () => copyDocumentWithTransform2,
  createBufferedReadable: () => createBufferedReadable,
  createChecksumStream: () => createChecksumStream2,
  dateToUtcString: () => dateToUtcString15,
  deserializerMiddleware: () => deserializerMiddleware,
  deserializerMiddlewareOption: () => deserializerMiddlewareOption2,
  expectBoolean: () => expectBoolean2,
  expectByte: () => expectByte3,
  expectFloat32: () => expectFloat323,
  expectInt: () => expectInt2,
  expectInt32: () => expectInt322,
  expectLong: () => expectLong3,
  expectNonNull: () => expectNonNull2,
  expectNumber: () => expectNumber3,
  expectObject: () => expectObject2,
  expectShort: () => expectShort3,
  expectString: () => expectString3,
  expectUnion: () => expectUnion7,
  fromArrayBuffer: () => fromArrayBuffer3,
  fromBase64: () => fromBase6436,
  fromHex: () => fromHex2,
  fromString: () => fromString3,
  fromUtf8: () => fromUtf825,
  generateIdempotencyToken: () => generateIdempotencyToken3,
  getAwsChunkedEncodingStream: () => getAwsChunkedEncodingStream2,
  getSerdePlugin: () => getSerdePlugin,
  handleFloat: () => handleFloat2,
  headStream: () => headStream2,
  isArrayBuffer: () => isArrayBuffer3,
  isBlob: () => isBlob,
  isReadableStream: () => isReadableStream2,
  limitedParseDouble: () => limitedParseDouble2,
  limitedParseFloat: () => limitedParseFloat2,
  limitedParseFloat32: () => limitedParseFloat322,
  logger: () => logger3,
  nv: () => nv3,
  parseBoolean: () => parseBoolean2,
  parseEpochTimestamp: () => parseEpochTimestamp4,
  parseRfc3339DateTime: () => parseRfc3339DateTime4,
  parseRfc3339DateTimeWithOffset: () => parseRfc3339DateTimeWithOffset4,
  parseRfc7231DateTime: () => parseRfc7231DateTime4,
  quoteHeader: () => quoteHeader3,
  sdkStreamMixin: () => sdkStreamMixin5,
  serializerMiddleware: () => serializerMiddleware,
  serializerMiddlewareOption: () => serializerMiddlewareOption4,
  splitEvery: () => splitEvery3,
  splitHeader: () => splitHeader3,
  splitStream: () => splitStream2,
  strictParseByte: () => strictParseByte3,
  strictParseDouble: () => strictParseDouble3,
  strictParseFloat: () => strictParseFloat2,
  strictParseFloat32: () => strictParseFloat323,
  strictParseInt: () => strictParseInt2,
  strictParseInt32: () => strictParseInt322,
  strictParseLong: () => strictParseLong2,
  strictParseShort: () => strictParseShort3,
  toBase64: () => toBase6441,
  toHex: () => toHex2,
  toUint8Array: () => toUint8Array2,
  toUtf8: () => toUtf839,
  v4: () => v43
});
var import_node_crypto10, Uint8ArrayBlobAdapter4, _getRandomValues3, v43, generateIdempotencyToken3;
var init_serde4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/serde/index.js"() {
    import_node_crypto10 = require("node:crypto");
    init_fromBase643();
    init_toBase643();
    init_Uint8ArrayBlobAdapter3();
    init_fromUtf83();
    init_toUtf83();
    init_v43();
    init_copyDocumentWithTransform2();
    init_date_utils4();
    init_lazy_json3();
    init_parse_utils3();
    init_quote_header3();
    init_schema_date_utils3();
    init_split_every3();
    init_split_header3();
    init_NumericValue3();
    init_hex_encoding2();
    init_calculateBodyLength();
    init_toUint8Array();
    init_buffer_from3();
    init_is_array_buffer3();
    init_deserializerMiddleware();
    init_serdePlugin();
    init_serializerMiddleware();
    init_hash_node();
    init_ChecksumStream();
    init_createChecksumStream();
    init_createBufferedReadable();
    init_getAwsChunkedEncodingStream();
    init_headStream();
    init_sdk_stream_mixin2();
    init_splitStream();
    init_stream_type_check2();
    Uint8ArrayBlobAdapter4 = class extends bindUint8ArrayBlobAdapter3(toUtf839, fromUtf825, toBase6441, fromBase6436) {
      static {
        __name(this, "Uint8ArrayBlobAdapter");
      }
    };
    _getRandomValues3 = import_node_crypto10.getRandomValues;
    v43 = bindV43(_getRandomValues3);
    generateIdempotencyToken3 = v43;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/collect-stream-body.js
var collectBody10;
var init_collect_stream_body4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/collect-stream-body.js"() {
    init_serde4();
    collectBody10 = /* @__PURE__ */ __name(async (streamBody = new Uint8Array(), context) => {
      if (streamBody instanceof Uint8Array) {
        return Uint8ArrayBlobAdapter4.mutate(streamBody);
      }
      if (!streamBody) {
        return Uint8ArrayBlobAdapter4.mutate(new Uint8Array());
      }
      const fromContext = context.streamCollector(streamBody);
      return Uint8ArrayBlobAdapter4.mutate(await fromContext);
    }, "collectBody");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/extended-encode-uri-component.js
function extendedEncodeURIComponent3(str) {
  return encodeURIComponent(str).replace(/[!'()*]/g, function(c32) {
    return "%" + c32.charCodeAt(0).toString(16).toUpperCase();
  });
}
var init_extended_encode_uri_component4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/extended-encode-uri-component.js"() {
    __name(extendedEncodeURIComponent3, "extendedEncodeURIComponent");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/SerdeContext.js
var SerdeContext3;
var init_SerdeContext4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/SerdeContext.js"() {
    SerdeContext3 = class {
      static {
        __name(this, "SerdeContext");
      }
      serdeContext;
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/httpRequest.js
function cloneQuery3(query) {
  return Object.keys(query).reduce((carry, paramName) => {
    const param = query[paramName];
    return {
      ...carry,
      [paramName]: Array.isArray(param) ? [...param] : param
    };
  }, {});
}
var HttpRequest22;
var init_httpRequest3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/httpRequest.js"() {
    HttpRequest22 = class _HttpRequest {
      static {
        __name(this, "HttpRequest");
      }
      method;
      protocol;
      hostname;
      port;
      path;
      query;
      headers;
      username;
      password;
      fragment;
      body;
      constructor(options) {
        this.method = options.method || "GET";
        this.hostname = options.hostname || "localhost";
        this.port = options.port;
        this.query = options.query || {};
        this.headers = options.headers || {};
        this.body = options.body;
        this.protocol = options.protocol ? options.protocol.slice(-1) !== ":" ? `${options.protocol}:` : options.protocol : "https:";
        this.path = options.path ? options.path.charAt(0) !== "/" ? `/${options.path}` : options.path : "/";
        this.username = options.username;
        this.password = options.password;
        this.fragment = options.fragment;
      }
      static clone(request4) {
        const cloned = new _HttpRequest({
          ...request4,
          headers: { ...request4.headers }
        });
        if (cloned.query) {
          cloned.query = cloneQuery3(cloned.query);
        }
        return cloned;
      }
      static isInstance(request4) {
        if (!request4) {
          return false;
        }
        const req = request4;
        return "method" in req && "protocol" in req && "hostname" in req && "path" in req && typeof req["query"] === "object" && typeof req["headers"] === "object";
      }
      clone() {
        return _HttpRequest.clone(this);
      }
    };
    __name(cloneQuery3, "cloneQuery");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/httpResponse.js
var HttpResponse11;
var init_httpResponse3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/httpResponse.js"() {
    HttpResponse11 = class {
      static {
        __name(this, "HttpResponse");
      }
      statusCode;
      reason;
      headers;
      body;
      constructor(options) {
        this.statusCode = options.statusCode;
        this.reason = options.reason;
        this.headers = options.headers || {};
        this.body = options.body;
      }
      static isInstance(response) {
        if (!response)
          return false;
        const resp = response;
        return typeof resp.statusCode === "number" && typeof resp.headers === "object";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/Int64.js
function negate2(bytes) {
  for (let i32 = 0; i32 < 8; i32++) {
    bytes[i32] ^= 255;
  }
  for (let i32 = 7; i32 > -1; i32--) {
    bytes[i32]++;
    if (bytes[i32] !== 0)
      break;
  }
}
var Int642;
var init_Int642 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/Int64.js"() {
    init_serde4();
    Int642 = class _Int64 {
      static {
        __name(this, "Int64");
      }
      bytes;
      constructor(bytes) {
        this.bytes = bytes;
        if (bytes.byteLength !== 8) {
          throw new Error("Int64 buffers must be exactly 8 bytes");
        }
      }
      static fromNumber(number) {
        if (number > 9223372036854776e3 || number < -9223372036854776e3) {
          throw new Error(`${number} is too large (or, if negative, too small) to represent as an Int64`);
        }
        const bytes = new Uint8Array(8);
        for (let i32 = 7, remaining = Math.abs(Math.round(number)); i32 > -1 && remaining > 0; i32--, remaining /= 256) {
          bytes[i32] = remaining;
        }
        if (number < 0) {
          negate2(bytes);
        }
        return new _Int64(bytes);
      }
      valueOf() {
        const bytes = this.bytes.slice(0);
        const negative = bytes[0] & 128;
        if (negative) {
          negate2(bytes);
        }
        return parseInt(toHex2(bytes), 16) * (negative ? -1 : 1);
      }
      toString() {
        return String(this.valueOf());
      }
    };
    __name(negate2, "negate");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/HeaderMarshaller.js
var HeaderMarshaller2, HEADER_VALUE_TYPE2, BOOLEAN_TAG2, BYTE_TAG2, SHORT_TAG2, INT_TAG2, LONG_TAG2, BINARY_TAG2, STRING_TAG2, TIMESTAMP_TAG2, UUID_TAG2, UUID_PATTERN2;
var init_HeaderMarshaller2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/HeaderMarshaller.js"() {
    init_serde4();
    init_Int642();
    HeaderMarshaller2 = class {
      static {
        __name(this, "HeaderMarshaller");
      }
      toUtf8;
      fromUtf8;
      constructor(toUtf862, fromUtf842) {
        this.toUtf8 = toUtf862;
        this.fromUtf8 = fromUtf842;
      }
      format(headers) {
        const chunks2 = [];
        for (const headerName of Object.keys(headers)) {
          const bytes = this.fromUtf8(headerName);
          chunks2.push(Uint8Array.from([bytes.byteLength]), bytes, this.formatHeaderValue(headers[headerName]));
        }
        const out = new Uint8Array(chunks2.reduce((carry, bytes) => carry + bytes.byteLength, 0));
        let position = 0;
        for (const chunk of chunks2) {
          out.set(chunk, position);
          position += chunk.byteLength;
        }
        return out;
      }
      formatHeaderValue(header) {
        switch (header.type) {
          case "boolean":
            return Uint8Array.from([header.value ? 0 : 1]);
          case "byte":
            return Uint8Array.from([2, header.value]);
          case "short":
            const shortView = new DataView(new ArrayBuffer(3));
            shortView.setUint8(0, 3);
            shortView.setInt16(1, header.value, false);
            return new Uint8Array(shortView.buffer);
          case "integer":
            const intView = new DataView(new ArrayBuffer(5));
            intView.setUint8(0, 4);
            intView.setInt32(1, header.value, false);
            return new Uint8Array(intView.buffer);
          case "long":
            const longBytes = new Uint8Array(9);
            longBytes[0] = 5;
            longBytes.set(header.value.bytes, 1);
            return longBytes;
          case "binary":
            const binView = new DataView(new ArrayBuffer(3 + header.value.byteLength));
            binView.setUint8(0, 6);
            binView.setUint16(1, header.value.byteLength, false);
            const binBytes = new Uint8Array(binView.buffer);
            binBytes.set(header.value, 3);
            return binBytes;
          case "string":
            const utf8Bytes = this.fromUtf8(header.value);
            const strView = new DataView(new ArrayBuffer(3 + utf8Bytes.byteLength));
            strView.setUint8(0, 7);
            strView.setUint16(1, utf8Bytes.byteLength, false);
            const strBytes = new Uint8Array(strView.buffer);
            strBytes.set(utf8Bytes, 3);
            return strBytes;
          case "timestamp":
            const tsBytes = new Uint8Array(9);
            tsBytes[0] = 8;
            tsBytes.set(Int642.fromNumber(header.value.valueOf()).bytes, 1);
            return tsBytes;
          case "uuid":
            if (!UUID_PATTERN2.test(header.value)) {
              throw new Error(`Invalid UUID received: ${header.value}`);
            }
            const uuidBytes = new Uint8Array(17);
            uuidBytes[0] = 9;
            uuidBytes.set(fromHex2(header.value.replace(/\-/g, "")), 1);
            return uuidBytes;
        }
      }
      parse(headers) {
        const out = {};
        let position = 0;
        while (position < headers.byteLength) {
          const nameLength = headers.getUint8(position++);
          const name = this.toUtf8(new Uint8Array(headers.buffer, headers.byteOffset + position, nameLength));
          position += nameLength;
          switch (headers.getUint8(position++)) {
            case 0:
              out[name] = {
                type: BOOLEAN_TAG2,
                value: true
              };
              break;
            case 1:
              out[name] = {
                type: BOOLEAN_TAG2,
                value: false
              };
              break;
            case 2:
              out[name] = {
                type: BYTE_TAG2,
                value: headers.getInt8(position++)
              };
              break;
            case 3:
              out[name] = {
                type: SHORT_TAG2,
                value: headers.getInt16(position, false)
              };
              position += 2;
              break;
            case 4:
              out[name] = {
                type: INT_TAG2,
                value: headers.getInt32(position, false)
              };
              position += 4;
              break;
            case 5:
              out[name] = {
                type: LONG_TAG2,
                value: new Int642(new Uint8Array(headers.buffer, headers.byteOffset + position, 8))
              };
              position += 8;
              break;
            case 6:
              const binaryLength = headers.getUint16(position, false);
              position += 2;
              out[name] = {
                type: BINARY_TAG2,
                value: new Uint8Array(headers.buffer, headers.byteOffset + position, binaryLength)
              };
              position += binaryLength;
              break;
            case 7:
              const stringLength = headers.getUint16(position, false);
              position += 2;
              out[name] = {
                type: STRING_TAG2,
                value: this.toUtf8(new Uint8Array(headers.buffer, headers.byteOffset + position, stringLength))
              };
              position += stringLength;
              break;
            case 8:
              out[name] = {
                type: TIMESTAMP_TAG2,
                value: new Date(new Int642(new Uint8Array(headers.buffer, headers.byteOffset + position, 8)).valueOf())
              };
              position += 8;
              break;
            case 9:
              const uuidBytes = new Uint8Array(headers.buffer, headers.byteOffset + position, 16);
              position += 16;
              out[name] = {
                type: UUID_TAG2,
                value: `${toHex2(uuidBytes.subarray(0, 4))}-${toHex2(uuidBytes.subarray(4, 6))}-${toHex2(uuidBytes.subarray(6, 8))}-${toHex2(uuidBytes.subarray(8, 10))}-${toHex2(uuidBytes.subarray(10))}`
              };
              break;
            default:
              throw new Error(`Unrecognized header type tag`);
          }
        }
        return out;
      }
    };
    (function(HEADER_VALUE_TYPE6) {
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["boolTrue"] = 0] = "boolTrue";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["boolFalse"] = 1] = "boolFalse";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["byte"] = 2] = "byte";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["short"] = 3] = "short";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["integer"] = 4] = "integer";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["long"] = 5] = "long";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["byteArray"] = 6] = "byteArray";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["string"] = 7] = "string";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["timestamp"] = 8] = "timestamp";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["uuid"] = 9] = "uuid";
    })(HEADER_VALUE_TYPE2 || (HEADER_VALUE_TYPE2 = {}));
    BOOLEAN_TAG2 = "boolean";
    BYTE_TAG2 = "byte";
    SHORT_TAG2 = "short";
    INT_TAG2 = "integer";
    LONG_TAG2 = "long";
    BINARY_TAG2 = "binary";
    STRING_TAG2 = "string";
    TIMESTAMP_TAG2 = "timestamp";
    UUID_TAG2 = "uuid";
    UUID_PATTERN2 = /^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$/;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/splitMessage.js
function splitMessage2({ byteLength, byteOffset, buffer }) {
  if (byteLength < MINIMUM_MESSAGE_LENGTH2) {
    throw new Error("Provided message too short to accommodate event stream message overhead");
  }
  const view = new DataView(buffer, byteOffset, byteLength);
  const messageLength = view.getUint32(0, false);
  if (byteLength !== messageLength) {
    throw new Error("Reported message length does not match received message length");
  }
  const headerLength = view.getUint32(PRELUDE_MEMBER_LENGTH2, false);
  const expectedPreludeChecksum = view.getUint32(PRELUDE_LENGTH2, false);
  const expectedMessageChecksum = view.getUint32(byteLength - CHECKSUM_LENGTH2, false);
  const checksummer = new import_crc323.Crc32().update(new Uint8Array(buffer, byteOffset, PRELUDE_LENGTH2));
  if (expectedPreludeChecksum !== checksummer.digest()) {
    throw new Error(`The prelude checksum specified in the message (${expectedPreludeChecksum}) does not match the calculated CRC32 checksum (${checksummer.digest()})`);
  }
  checksummer.update(new Uint8Array(buffer, byteOffset + PRELUDE_LENGTH2, byteLength - (PRELUDE_LENGTH2 + CHECKSUM_LENGTH2)));
  if (expectedMessageChecksum !== checksummer.digest()) {
    throw new Error(`The message checksum (${checksummer.digest()}) did not match the expected value of ${expectedMessageChecksum}`);
  }
  return {
    headers: new DataView(buffer, byteOffset + PRELUDE_LENGTH2 + CHECKSUM_LENGTH2, headerLength),
    body: new Uint8Array(buffer, byteOffset + PRELUDE_LENGTH2 + CHECKSUM_LENGTH2 + headerLength, messageLength - headerLength - (PRELUDE_LENGTH2 + CHECKSUM_LENGTH2 + CHECKSUM_LENGTH2))
  };
}
var import_crc323, PRELUDE_MEMBER_LENGTH2, PRELUDE_LENGTH2, CHECKSUM_LENGTH2, MINIMUM_MESSAGE_LENGTH2;
var init_splitMessage2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/splitMessage.js"() {
    import_crc323 = __toESM(require_main3());
    PRELUDE_MEMBER_LENGTH2 = 4;
    PRELUDE_LENGTH2 = PRELUDE_MEMBER_LENGTH2 * 2;
    CHECKSUM_LENGTH2 = 4;
    MINIMUM_MESSAGE_LENGTH2 = PRELUDE_LENGTH2 + CHECKSUM_LENGTH2 * 2;
    __name(splitMessage2, "splitMessage");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/EventStreamCodec.js
var import_crc324, EventStreamCodec2;
var init_EventStreamCodec2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/EventStreamCodec.js"() {
    import_crc324 = __toESM(require_main3());
    init_HeaderMarshaller2();
    init_splitMessage2();
    EventStreamCodec2 = class {
      static {
        __name(this, "EventStreamCodec");
      }
      headerMarshaller;
      messageBuffer;
      isEndOfStream;
      constructor(toUtf862, fromUtf842) {
        this.headerMarshaller = new HeaderMarshaller2(toUtf862, fromUtf842);
        this.messageBuffer = [];
        this.isEndOfStream = false;
      }
      feed(message2) {
        this.messageBuffer.push(this.decode(message2));
      }
      endOfStream() {
        this.isEndOfStream = true;
      }
      getMessage() {
        const message2 = this.messageBuffer.pop();
        const isEndOfStream = this.isEndOfStream;
        return {
          getMessage() {
            return message2;
          },
          isEndOfStream() {
            return isEndOfStream;
          }
        };
      }
      getAvailableMessages() {
        const messages = this.messageBuffer;
        this.messageBuffer = [];
        const isEndOfStream = this.isEndOfStream;
        return {
          getMessages() {
            return messages;
          },
          isEndOfStream() {
            return isEndOfStream;
          }
        };
      }
      encode({ headers: rawHeaders, body }) {
        const headers = this.headerMarshaller.format(rawHeaders);
        const length = headers.byteLength + body.byteLength + 16;
        const out = new Uint8Array(length);
        const view = new DataView(out.buffer, out.byteOffset, out.byteLength);
        const checksum = new import_crc324.Crc32();
        view.setUint32(0, length, false);
        view.setUint32(4, headers.byteLength, false);
        view.setUint32(8, checksum.update(out.subarray(0, 8)).digest(), false);
        out.set(headers, 12);
        out.set(body, headers.byteLength + 12);
        view.setUint32(length - 4, checksum.update(out.subarray(8, length - 4)).digest(), false);
        return out;
      }
      decode(message2) {
        const { headers, body } = splitMessage2(message2);
        return { headers: this.headerMarshaller.parse(headers), body };
      }
      formatHeaders(rawHeaders) {
        return this.headerMarshaller.format(rawHeaders);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/MessageDecoderStream.js
var MessageDecoderStream2;
var init_MessageDecoderStream2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/MessageDecoderStream.js"() {
    MessageDecoderStream2 = class {
      static {
        __name(this, "MessageDecoderStream");
      }
      options;
      constructor(options) {
        this.options = options;
      }
      [Symbol.asyncIterator]() {
        return this.asyncIterator();
      }
      async *asyncIterator() {
        for await (const bytes of this.options.inputStream) {
          const decoded = this.options.decoder.decode(bytes);
          yield decoded;
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/MessageEncoderStream.js
var MessageEncoderStream2;
var init_MessageEncoderStream2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/MessageEncoderStream.js"() {
    MessageEncoderStream2 = class {
      static {
        __name(this, "MessageEncoderStream");
      }
      options;
      constructor(options) {
        this.options = options;
      }
      [Symbol.asyncIterator]() {
        return this.asyncIterator();
      }
      async *asyncIterator() {
        for await (const msg of this.options.messageStream) {
          const encoded = this.options.encoder.encode(msg);
          yield encoded;
        }
        if (this.options.includeEndFrame) {
          yield new Uint8Array(0);
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/SmithyMessageDecoderStream.js
var SmithyMessageDecoderStream2;
var init_SmithyMessageDecoderStream2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/SmithyMessageDecoderStream.js"() {
    SmithyMessageDecoderStream2 = class {
      static {
        __name(this, "SmithyMessageDecoderStream");
      }
      options;
      constructor(options) {
        this.options = options;
      }
      [Symbol.asyncIterator]() {
        return this.asyncIterator();
      }
      async *asyncIterator() {
        for await (const message2 of this.options.messageStream) {
          const deserialized = await this.options.deserializer(message2);
          if (deserialized === void 0)
            continue;
          yield deserialized;
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/SmithyMessageEncoderStream.js
var SmithyMessageEncoderStream2;
var init_SmithyMessageEncoderStream2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/SmithyMessageEncoderStream.js"() {
    SmithyMessageEncoderStream2 = class {
      static {
        __name(this, "SmithyMessageEncoderStream");
      }
      options;
      constructor(options) {
        this.options = options;
      }
      [Symbol.asyncIterator]() {
        return this.asyncIterator();
      }
      async *asyncIterator() {
        for await (const chunk of this.options.inputStream) {
          const payloadBuf = this.options.serializer(chunk);
          yield payloadBuf;
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/getChunkedStream.js
function getChunkedStream2(source) {
  let currentMessageTotalLength = 0;
  let currentMessagePendingLength = 0;
  let currentMessage = null;
  let messageLengthBuffer = null;
  const allocateMessage = /* @__PURE__ */ __name((size) => {
    if (typeof size !== "number") {
      throw new Error("Attempted to allocate an event message where size was not a number: " + size);
    }
    currentMessageTotalLength = size;
    currentMessagePendingLength = 4;
    currentMessage = new Uint8Array(size);
    const currentMessageView = new DataView(currentMessage.buffer);
    currentMessageView.setUint32(0, size, false);
  }, "allocateMessage");
  const iterator = /* @__PURE__ */ __name(async function* () {
    const sourceIterator = source[Symbol.asyncIterator]();
    while (true) {
      const { value, done } = await sourceIterator.next();
      if (done) {
        if (!currentMessageTotalLength) {
          return;
        } else if (currentMessageTotalLength === currentMessagePendingLength) {
          yield currentMessage;
        } else {
          throw new Error("Truncated event message received.");
        }
        return;
      }
      const chunkLength = value.length;
      let currentOffset = 0;
      while (currentOffset < chunkLength) {
        if (!currentMessage) {
          const bytesRemaining = chunkLength - currentOffset;
          if (!messageLengthBuffer) {
            messageLengthBuffer = new Uint8Array(4);
          }
          const numBytesForTotal = Math.min(4 - currentMessagePendingLength, bytesRemaining);
          messageLengthBuffer.set(value.slice(currentOffset, currentOffset + numBytesForTotal), currentMessagePendingLength);
          currentMessagePendingLength += numBytesForTotal;
          currentOffset += numBytesForTotal;
          if (currentMessagePendingLength < 4) {
            break;
          }
          allocateMessage(new DataView(messageLengthBuffer.buffer).getUint32(0, false));
          messageLengthBuffer = null;
        }
        const numBytesToWrite = Math.min(currentMessageTotalLength - currentMessagePendingLength, chunkLength - currentOffset);
        currentMessage.set(value.slice(currentOffset, currentOffset + numBytesToWrite), currentMessagePendingLength);
        currentMessagePendingLength += numBytesToWrite;
        currentOffset += numBytesToWrite;
        if (currentMessageTotalLength && currentMessageTotalLength === currentMessagePendingLength) {
          yield currentMessage;
          currentMessage = null;
          currentMessageTotalLength = 0;
          currentMessagePendingLength = 0;
        }
      }
    }
  }, "iterator");
  return {
    [Symbol.asyncIterator]: iterator
  };
}
var init_getChunkedStream2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/getChunkedStream.js"() {
    __name(getChunkedStream2, "getChunkedStream");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/getUnmarshalledStream.js
function getUnmarshalledStream2(source, options) {
  const messageUnmarshaller = getMessageUnmarshaller2(options.deserializer, options.toUtf8);
  return {
    [Symbol.asyncIterator]: async function* () {
      for await (const chunk of source) {
        const message2 = options.eventStreamCodec.decode(chunk);
        const type = await messageUnmarshaller(message2);
        if (type === void 0)
          continue;
        yield type;
      }
    }
  };
}
function getMessageUnmarshaller2(deserializer, toUtf862) {
  return async function(message2) {
    const { value: messageType } = message2.headers[":message-type"];
    if (messageType === "error") {
      const unmodeledError = new Error(message2.headers[":error-message"].value || "UnknownError");
      unmodeledError.name = message2.headers[":error-code"].value;
      throw unmodeledError;
    } else if (messageType === "exception") {
      const code = message2.headers[":exception-type"].value;
      const exception = { [code]: message2 };
      const deserializedException = await deserializer(exception);
      if (deserializedException.$unknown) {
        const error4 = new Error(toUtf862(message2.body));
        error4.name = code;
        throw error4;
      }
      throw deserializedException[code];
    } else if (messageType === "event") {
      const event = {
        [message2.headers[":event-type"].value]: message2
      };
      const deserialized = await deserializer(event);
      if (deserialized.$unknown)
        return;
      return deserialized;
    } else {
      throw Error(`Unrecognizable event type: ${message2.headers[":event-type"].value}`);
    }
  };
}
var init_getUnmarshalledStream2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/getUnmarshalledStream.js"() {
    __name(getUnmarshalledStream2, "getUnmarshalledStream");
    __name(getMessageUnmarshaller2, "getMessageUnmarshaller");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/EventStreamMarshaller.js
var EventStreamMarshaller3, eventStreamSerdeProvider3;
var init_EventStreamMarshaller3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/EventStreamMarshaller.js"() {
    init_EventStreamCodec2();
    init_MessageDecoderStream2();
    init_MessageEncoderStream2();
    init_SmithyMessageDecoderStream2();
    init_SmithyMessageEncoderStream2();
    init_getChunkedStream2();
    init_getUnmarshalledStream2();
    EventStreamMarshaller3 = class {
      static {
        __name(this, "EventStreamMarshaller");
      }
      eventStreamCodec;
      utfEncoder;
      constructor({ utf8Encoder, utf8Decoder }) {
        this.eventStreamCodec = new EventStreamCodec2(utf8Encoder, utf8Decoder);
        this.utfEncoder = utf8Encoder;
      }
      deserialize(body, deserializer) {
        const inputStream = getChunkedStream2(body);
        return new SmithyMessageDecoderStream2({
          messageStream: new MessageDecoderStream2({ inputStream, decoder: this.eventStreamCodec }),
          deserializer: getMessageUnmarshaller2(deserializer, this.utfEncoder)
        });
      }
      serialize(inputStream, serializer) {
        return new MessageEncoderStream2({
          messageStream: new SmithyMessageEncoderStream2({ inputStream, serializer }),
          encoder: this.eventStreamCodec,
          includeEndFrame: true
        });
      }
    };
    eventStreamSerdeProvider3 = /* @__PURE__ */ __name((options) => new EventStreamMarshaller3(options), "eventStreamSerdeProvider");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde/EventStreamMarshaller.js
async function* readableToIterable2(readStream) {
  let streamEnded = false;
  let generationEnded = false;
  const records = new Array();
  readStream.on("error", (err) => {
    if (!streamEnded) {
      streamEnded = true;
    }
    if (err) {
      throw err;
    }
  });
  readStream.on("data", (data3) => {
    records.push(data3);
  });
  readStream.on("end", () => {
    streamEnded = true;
  });
  while (!generationEnded) {
    const value = await new Promise((resolve13) => setTimeout(() => resolve13(records.shift()), 0));
    if (value) {
      yield value;
    }
    generationEnded = streamEnded && records.length === 0;
  }
}
var import_node_stream13, EventStreamMarshaller4, eventStreamSerdeProvider4;
var init_EventStreamMarshaller4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde/EventStreamMarshaller.js"() {
    import_node_stream13 = require("node:stream");
    init_EventStreamMarshaller3();
    EventStreamMarshaller4 = class {
      static {
        __name(this, "EventStreamMarshaller");
      }
      universalMarshaller;
      constructor({ utf8Encoder, utf8Decoder }) {
        this.universalMarshaller = new EventStreamMarshaller3({
          utf8Decoder,
          utf8Encoder
        });
      }
      deserialize(body, deserializer) {
        const bodyIterable = typeof body[Symbol.asyncIterator] === "function" ? body : readableToIterable2(body);
        return this.universalMarshaller.deserialize(bodyIterable, deserializer);
      }
      serialize(input, serializer) {
        return import_node_stream13.Readable.from(this.universalMarshaller.serialize(input, serializer));
      }
    };
    eventStreamSerdeProvider4 = /* @__PURE__ */ __name((options) => new EventStreamMarshaller4(options), "eventStreamSerdeProvider");
    __name(readableToIterable2, "readableToIterable");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde/utils.js
var readableStreamToIterable2, iterableToReadableStream2;
var init_utils10 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde/utils.js"() {
    readableStreamToIterable2 = /* @__PURE__ */ __name((readableStream) => ({
      [Symbol.asyncIterator]: async function* () {
        const reader = readableStream.getReader();
        try {
          while (true) {
            const { done, value } = await reader.read();
            if (done)
              return;
            yield value;
          }
        } finally {
          reader.releaseLock();
        }
      }
    }), "readableStreamToIterable");
    iterableToReadableStream2 = /* @__PURE__ */ __name((asyncIterable) => {
      const iterator = asyncIterable[Symbol.asyncIterator]();
      return new ReadableStream({
        async pull(controller) {
          const { done, value } = await iterator.next();
          if (done) {
            return controller.close();
          }
          controller.enqueue(value);
        }
      });
    }, "iterableToReadableStream");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-config-resolver/EventStreamSerdeConfig.js
var resolveEventStreamSerdeConfig2;
var init_EventStreamSerdeConfig2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-config-resolver/EventStreamSerdeConfig.js"() {
    resolveEventStreamSerdeConfig2 = /* @__PURE__ */ __name((input) => Object.assign(input, {
      eventStreamMarshaller: input.eventStreamSerdeProvider(input)
    }), "resolveEventStreamSerdeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/EventStreamSerde.js
var EventStreamSerde3;
var init_EventStreamSerde3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/EventStreamSerde.js"() {
    init_serde4();
    EventStreamSerde3 = class {
      static {
        __name(this, "EventStreamSerde");
      }
      marshaller;
      serializer;
      deserializer;
      serdeContext;
      defaultContentType;
      constructor({ marshaller, serializer, deserializer, serdeContext, defaultContentType }) {
        this.marshaller = marshaller;
        this.serializer = serializer;
        this.deserializer = deserializer;
        this.serdeContext = serdeContext;
        this.defaultContentType = defaultContentType;
      }
      async serializeEventStream({ eventStream, requestSchema, initialRequest }) {
        const marshaller = this.marshaller;
        const eventStreamMember = requestSchema.getEventStreamMember();
        const unionSchema = requestSchema.getMemberSchema(eventStreamMember);
        const serializer = this.serializer;
        const defaultContentType = this.defaultContentType;
        const initialRequestMarker = /* @__PURE__ */ Symbol("initialRequestMarker");
        const eventStreamIterable = {
          async *[Symbol.asyncIterator]() {
            if (initialRequest) {
              const headers = {
                ":event-type": { type: "string", value: "initial-request" },
                ":message-type": { type: "string", value: "event" },
                ":content-type": { type: "string", value: defaultContentType }
              };
              serializer.write(requestSchema, initialRequest);
              const body = serializer.flush();
              yield {
                [initialRequestMarker]: true,
                headers,
                body
              };
            }
            for await (const page of eventStream) {
              yield page;
            }
          }
        };
        return marshaller.serialize(eventStreamIterable, (event) => {
          if (event[initialRequestMarker]) {
            return {
              headers: event.headers,
              body: event.body
            };
          }
          let unionMember = "";
          for (const key in event) {
            if (key !== "__type") {
              unionMember = key;
              break;
            }
          }
          const { additionalHeaders, body, eventType, explicitPayloadContentType } = this.writeEventBody(unionMember, unionSchema, event);
          const headers = {
            ":event-type": { type: "string", value: eventType },
            ":message-type": { type: "string", value: "event" },
            ":content-type": { type: "string", value: explicitPayloadContentType ?? defaultContentType },
            ...additionalHeaders
          };
          return {
            headers,
            body
          };
        });
      }
      async deserializeEventStream({ response, responseSchema, initialResponseContainer }) {
        const marshaller = this.marshaller;
        const eventStreamMember = responseSchema.getEventStreamMember();
        const unionSchema = responseSchema.getMemberSchema(eventStreamMember);
        const memberSchemas = unionSchema.getMemberSchemas();
        const initialResponseMarker = /* @__PURE__ */ Symbol("initialResponseMarker");
        const asyncIterable = marshaller.deserialize(response.body, async (event) => {
          let unionMember = "";
          for (const key in event) {
            if (key !== "__type") {
              unionMember = key;
              break;
            }
          }
          const body = event[unionMember].body;
          if (unionMember === "initial-response") {
            const dataObject = await this.deserializer.read(responseSchema, body);
            delete dataObject[eventStreamMember];
            return {
              [initialResponseMarker]: true,
              ...dataObject
            };
          } else if (unionMember in memberSchemas) {
            const eventStreamSchema = memberSchemas[unionMember];
            if (eventStreamSchema.isStructSchema()) {
              const out = {};
              let hasBindings = false;
              for (const [name, member7] of eventStreamSchema.structIterator()) {
                const { eventHeader, eventPayload } = member7.getMergedTraits();
                hasBindings = hasBindings || Boolean(eventHeader || eventPayload);
                if (eventPayload) {
                  if (member7.isBlobSchema()) {
                    out[name] = body;
                  } else if (member7.isStringSchema()) {
                    out[name] = (this.serdeContext?.utf8Encoder ?? toUtf839)(body);
                  } else if (member7.isStructSchema()) {
                    out[name] = await this.deserializer.read(member7, body);
                  }
                } else if (eventHeader) {
                  const value = event[unionMember].headers[name]?.value;
                  if (value != null) {
                    if (member7.isNumericSchema()) {
                      if (value && typeof value === "object" && "bytes" in value) {
                        out[name] = BigInt(value.toString());
                      } else {
                        out[name] = Number(value);
                      }
                    } else {
                      out[name] = value;
                    }
                  }
                }
              }
              if (hasBindings) {
                return {
                  [unionMember]: out
                };
              }
              if (body.byteLength === 0) {
                return {
                  [unionMember]: {}
                };
              }
            }
            return {
              [unionMember]: await this.deserializer.read(eventStreamSchema, body)
            };
          } else {
            return {
              $unknown: event
            };
          }
        });
        const asyncIterator = asyncIterable[Symbol.asyncIterator]();
        const firstEvent = await asyncIterator.next();
        if (firstEvent.done) {
          return asyncIterable;
        }
        if (firstEvent.value?.[initialResponseMarker]) {
          if (!responseSchema) {
            throw new Error("@smithy::core/protocols - initial-response event encountered in event stream but no response schema given.");
          }
          for (const key in firstEvent.value) {
            initialResponseContainer[key] = firstEvent.value[key];
          }
        }
        return {
          async *[Symbol.asyncIterator]() {
            if (!firstEvent?.value?.[initialResponseMarker]) {
              yield firstEvent.value;
            }
            while (true) {
              const { done, value } = await asyncIterator.next();
              if (done) {
                break;
              }
              yield value;
            }
          }
        };
      }
      writeEventBody(unionMember, unionSchema, event) {
        const serializer = this.serializer;
        let eventType = unionMember;
        let explicitPayloadMember = null;
        let explicitPayloadContentType;
        const isKnownSchema = (() => {
          const struct3 = unionSchema.getSchema();
          return struct3[4].includes(unionMember);
        })();
        const additionalHeaders = {};
        if (!isKnownSchema) {
          const [type, value] = event[unionMember];
          eventType = type;
          serializer.write(15, value);
        } else {
          const eventSchema = unionSchema.getMemberSchema(unionMember);
          if (eventSchema.isStructSchema()) {
            for (const [memberName, memberSchema] of eventSchema.structIterator()) {
              const { eventHeader, eventPayload } = memberSchema.getMergedTraits();
              if (eventPayload) {
                explicitPayloadMember = memberName;
              } else if (eventHeader) {
                const value = event[unionMember][memberName];
                let type = "binary";
                if (memberSchema.isNumericSchema()) {
                  if ((-2) ** 31 <= value && value <= 2 ** 31 - 1) {
                    type = "integer";
                  } else {
                    type = "long";
                  }
                } else if (memberSchema.isTimestampSchema()) {
                  type = "timestamp";
                } else if (memberSchema.isStringSchema()) {
                  type = "string";
                } else if (memberSchema.isBooleanSchema()) {
                  type = "boolean";
                }
                if (value != null) {
                  additionalHeaders[memberName] = {
                    type,
                    value
                  };
                  delete event[unionMember][memberName];
                }
              }
            }
            if (explicitPayloadMember !== null) {
              const payloadSchema = eventSchema.getMemberSchema(explicitPayloadMember);
              if (payloadSchema.isBlobSchema()) {
                explicitPayloadContentType = "application/octet-stream";
              } else if (payloadSchema.isStringSchema()) {
                explicitPayloadContentType = "text/plain";
              }
              serializer.write(payloadSchema, event[unionMember][explicitPayloadMember]);
            } else {
              serializer.write(eventSchema, event[unionMember]);
            }
          } else if (eventSchema.isUnitSchema()) {
            serializer.write(eventSchema, {});
          } else {
            throw new Error("@smithy/core/event-streams - non-struct member not supported in event stream union.");
          }
        }
        const messageSerialization = serializer.flush() ?? new Uint8Array();
        const body = typeof messageSerialization === "string" ? (this.serdeContext?.utf8Decoder ?? fromUtf825)(messageSerialization) : messageSerialization;
        return {
          body,
          eventType,
          explicitPayloadContentType,
          additionalHeaders
        };
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/index.js
var event_streams_exports3 = {};
__export(event_streams_exports3, {
  EventStreamCodec: () => EventStreamCodec2,
  EventStreamMarshaller: () => EventStreamMarshaller4,
  EventStreamSerde: () => EventStreamSerde3,
  HeaderMarshaller: () => HeaderMarshaller2,
  Int64: () => Int642,
  MessageDecoderStream: () => MessageDecoderStream2,
  MessageEncoderStream: () => MessageEncoderStream2,
  SmithyMessageDecoderStream: () => SmithyMessageDecoderStream2,
  SmithyMessageEncoderStream: () => SmithyMessageEncoderStream2,
  UniversalEventStreamMarshaller: () => EventStreamMarshaller3,
  eventStreamSerdeProvider: () => eventStreamSerdeProvider4,
  getChunkedStream: () => getChunkedStream2,
  getMessageUnmarshaller: () => getMessageUnmarshaller2,
  getUnmarshalledStream: () => getUnmarshalledStream2,
  iterableToReadableStream: () => iterableToReadableStream2,
  readableStreamToIterable: () => readableStreamToIterable2,
  resolveEventStreamSerdeConfig: () => resolveEventStreamSerdeConfig2,
  universalEventStreamSerdeProvider: () => eventStreamSerdeProvider3
});
var init_event_streams3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/event-streams/index.js"() {
    init_EventStreamCodec2();
    init_HeaderMarshaller2();
    init_Int642();
    init_MessageDecoderStream2();
    init_MessageEncoderStream2();
    init_SmithyMessageDecoderStream2();
    init_SmithyMessageEncoderStream2();
    init_EventStreamMarshaller4();
    init_utils10();
    init_EventStreamMarshaller3();
    init_getChunkedStream2();
    init_getUnmarshalledStream2();
    init_EventStreamSerdeConfig2();
    init_EventStreamSerde3();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/HttpProtocol.js
var HttpProtocol3;
var init_HttpProtocol4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/HttpProtocol.js"() {
    init_schema6();
    init_SerdeContext4();
    init_httpRequest3();
    init_httpResponse3();
    HttpProtocol3 = class extends SerdeContext3 {
      static {
        __name(this, "HttpProtocol");
      }
      options;
      compositeErrorRegistry;
      constructor(options) {
        super();
        this.options = options;
        this.compositeErrorRegistry = TypeRegistry3.for(options.defaultNamespace);
        for (const etr of options.errorTypeRegistries ?? []) {
          this.compositeErrorRegistry.copyFrom(etr);
        }
      }
      getRequestType() {
        return HttpRequest22;
      }
      getResponseType() {
        return HttpResponse11;
      }
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
        this.serializer.setSerdeContext(serdeContext);
        this.deserializer.setSerdeContext(serdeContext);
        if (this.getPayloadCodec()) {
          this.getPayloadCodec().setSerdeContext(serdeContext);
        }
      }
      updateServiceEndpoint(request4, endpoint) {
        if ("url" in endpoint) {
          request4.protocol = endpoint.url.protocol;
          request4.hostname = endpoint.url.hostname;
          request4.port = endpoint.url.port ? Number(endpoint.url.port) : void 0;
          request4.path = endpoint.url.pathname;
          request4.fragment = endpoint.url.hash || void 0;
          request4.username = endpoint.url.username || void 0;
          request4.password = endpoint.url.password || void 0;
          if (!request4.query) {
            request4.query = {};
          }
          for (const [k32, v] of endpoint.url.searchParams.entries()) {
            request4.query[k32] = v;
          }
          if (endpoint.headers) {
            for (const name in endpoint.headers) {
              request4.headers[name] = endpoint.headers[name].join(", ");
            }
          }
          return request4;
        } else {
          request4.protocol = endpoint.protocol;
          request4.hostname = endpoint.hostname;
          request4.port = endpoint.port ? Number(endpoint.port) : void 0;
          request4.path = endpoint.path;
          request4.query = {
            ...endpoint.query
          };
          if (endpoint.headers) {
            for (const name in endpoint.headers) {
              request4.headers[name] = endpoint.headers[name];
            }
          }
          return request4;
        }
      }
      setHostPrefix(request4, operationSchema, input) {
        if (this.serdeContext?.disableHostPrefix) {
          return;
        }
        const inputNs = NormalizedSchema3.of(operationSchema.input);
        const opTraits = translateTraits3(operationSchema.traits ?? {});
        if (opTraits.endpoint) {
          let hostPrefix = opTraits.endpoint?.[0];
          if (typeof hostPrefix === "string") {
            for (const [name, member7] of inputNs.structIterator()) {
              if (!member7.getMergedTraits().hostLabel) {
                continue;
              }
              const replacement = input[name];
              if (typeof replacement !== "string") {
                throw new Error(`@smithy/core/schema - ${name} in input must be a string as hostLabel.`);
              }
              hostPrefix = hostPrefix.replace(`{${name}}`, replacement);
            }
            request4.hostname = hostPrefix + request4.hostname;
          }
        }
      }
      deserializeMetadata(output) {
        return {
          httpStatusCode: output.statusCode,
          requestId: output.headers["x-amzn-requestid"] ?? output.headers["x-amzn-request-id"] ?? output.headers["x-amz-request-id"],
          extendedRequestId: output.headers["x-amz-id-2"],
          cfId: output.headers["x-amz-cf-id"]
        };
      }
      async serializeEventStream({ eventStream, requestSchema, initialRequest }) {
        const eventStreamSerde = await this.loadEventStreamCapability();
        return eventStreamSerde.serializeEventStream({
          eventStream,
          requestSchema,
          initialRequest
        });
      }
      async deserializeEventStream({ response, responseSchema, initialResponseContainer }) {
        const eventStreamSerde = await this.loadEventStreamCapability();
        return eventStreamSerde.deserializeEventStream({
          response,
          responseSchema,
          initialResponseContainer
        });
      }
      async loadEventStreamCapability() {
        const { EventStreamSerde: EventStreamSerde7 } = await Promise.resolve().then(() => (init_event_streams3(), event_streams_exports3));
        return new EventStreamSerde7({
          marshaller: this.getEventStreamMarshaller(),
          serializer: this.serializer,
          deserializer: this.deserializer,
          serdeContext: this.serdeContext,
          defaultContentType: this.getDefaultContentType()
        });
      }
      getDefaultContentType() {
        throw new Error(`@smithy/core/protocols - ${this.constructor.name} getDefaultContentType() implementation missing.`);
      }
      async deserializeHttpMessage(schema, context, response, arg4, arg5) {
        void schema;
        void context;
        void response;
        void arg4;
        void arg5;
        return [];
      }
      getEventStreamMarshaller() {
        const context = this.serdeContext;
        if (!context.eventStreamMarshaller) {
          throw new Error("@smithy/core - HttpProtocol: eventStreamMarshaller missing in serdeContext.");
        }
        return context.eventStreamMarshaller;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/HttpBindingProtocol.js
var HttpBindingProtocol3;
var init_HttpBindingProtocol4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/HttpBindingProtocol.js"() {
    init_schema6();
    init_serde4();
    init_HttpProtocol4();
    init_collect_stream_body4();
    init_extended_encode_uri_component4();
    init_httpRequest3();
    HttpBindingProtocol3 = class extends HttpProtocol3 {
      static {
        __name(this, "HttpBindingProtocol");
      }
      async serializeRequest(operationSchema, _input, context) {
        const input = _input && typeof _input === "object" ? _input : {};
        const serializer = this.serializer;
        const query = {};
        const headers = {};
        const endpoint = await context.endpoint();
        const ns = NormalizedSchema3.of(operationSchema?.input);
        const payloadMemberNames = [];
        const payloadMemberSchemas = [];
        let hasNonHttpBindingMember = false;
        let payload3;
        const request4 = new HttpRequest22({
          protocol: "",
          hostname: "",
          port: void 0,
          path: "",
          fragment: void 0,
          query,
          headers,
          body: void 0
        });
        if (endpoint) {
          this.updateServiceEndpoint(request4, endpoint);
          this.setHostPrefix(request4, operationSchema, input);
          const opTraits = translateTraits3(operationSchema.traits);
          if (opTraits.http) {
            request4.method = opTraits.http[0];
            const [path47, search] = opTraits.http[1].split("?");
            if (request4.path == "/") {
              request4.path = path47;
            } else {
              request4.path += path47;
            }
            const traitSearchParams = new URLSearchParams(search ?? "");
            for (const [key, value] of traitSearchParams) {
              query[key] = value;
            }
          }
        }
        for (const [memberName, memberNs] of ns.structIterator()) {
          const memberTraits = memberNs.getMergedTraits() ?? {};
          const inputMemberValue = input[memberName];
          if (inputMemberValue == null && !memberNs.isIdempotencyToken()) {
            if (memberTraits.httpLabel) {
              if (request4.path.includes(`{${memberName}+}`) || request4.path.includes(`{${memberName}}`)) {
                throw new Error(`No value provided for input HTTP label: ${memberName}.`);
              }
            }
            continue;
          }
          if (memberTraits.httpPayload) {
            const isStreaming = memberNs.isStreaming();
            if (isStreaming) {
              const isEventStream = memberNs.isStructSchema();
              if (isEventStream) {
                if (input[memberName]) {
                  payload3 = await this.serializeEventStream({
                    eventStream: input[memberName],
                    requestSchema: ns
                  });
                }
              } else {
                payload3 = inputMemberValue;
              }
            } else {
              serializer.write(memberNs, inputMemberValue);
              payload3 = serializer.flush();
            }
          } else if (memberTraits.httpLabel) {
            serializer.write(memberNs, inputMemberValue);
            const replacement = serializer.flush();
            if (request4.path.includes(`{${memberName}+}`)) {
              request4.path = request4.path.replace(`{${memberName}+}`, replacement.split("/").map(extendedEncodeURIComponent3).join("/"));
            } else if (request4.path.includes(`{${memberName}}`)) {
              request4.path = request4.path.replace(`{${memberName}}`, extendedEncodeURIComponent3(replacement));
            }
          } else if (memberTraits.httpHeader) {
            serializer.write(memberNs, inputMemberValue);
            headers[memberTraits.httpHeader.toLowerCase()] = String(serializer.flush());
          } else if (typeof memberTraits.httpPrefixHeaders === "string") {
            for (const key in inputMemberValue) {
              const val = inputMemberValue[key];
              const amalgam = memberTraits.httpPrefixHeaders + key;
              serializer.write([memberNs.getValueSchema(), { httpHeader: amalgam }], val);
              headers[amalgam.toLowerCase()] = serializer.flush();
            }
          } else if (memberTraits.httpQuery || memberTraits.httpQueryParams) {
            this.serializeQuery(memberNs, inputMemberValue, query);
          } else {
            hasNonHttpBindingMember = true;
            payloadMemberNames.push(memberName);
            payloadMemberSchemas.push(memberNs);
          }
        }
        if (hasNonHttpBindingMember && input) {
          const [namespace, name] = (ns.getName(true) ?? "#Unknown").split("#");
          const requiredMembers = ns.getSchema()[6];
          const payloadSchema = [
            3,
            namespace,
            name,
            ns.getMergedTraits(),
            payloadMemberNames,
            payloadMemberSchemas,
            void 0
          ];
          if (requiredMembers) {
            payloadSchema[6] = requiredMembers;
          } else {
            payloadSchema.pop();
          }
          serializer.write(payloadSchema, input);
          payload3 = serializer.flush();
        }
        request4.headers = headers;
        request4.query = query;
        request4.body = payload3;
        return request4;
      }
      serializeQuery(ns, data3, query) {
        const serializer = this.serializer;
        const traits = ns.getMergedTraits();
        if (traits.httpQueryParams) {
          for (const key in data3) {
            if (!(key in query)) {
              const val = data3[key];
              const valueSchema = ns.getValueSchema();
              Object.assign(valueSchema.getMergedTraits(), {
                ...traits,
                httpQuery: key,
                httpQueryParams: void 0
              });
              this.serializeQuery(valueSchema, val, query);
            }
          }
          return;
        }
        if (ns.isListSchema()) {
          const sparse = !!ns.getMergedTraits().sparse;
          const buffer = [];
          for (const item of data3) {
            serializer.write([ns.getValueSchema(), traits], item);
            const serializable = serializer.flush();
            if (sparse || serializable !== void 0) {
              buffer.push(serializable);
            }
          }
          query[traits.httpQuery] = buffer;
        } else {
          serializer.write([ns, traits], data3);
          query[traits.httpQuery] = serializer.flush();
        }
      }
      async deserializeResponse(operationSchema, context, response) {
        const deserializer = this.deserializer;
        const ns = NormalizedSchema3.of(operationSchema.output);
        const dataObject = {};
        if (response.statusCode >= 300) {
          const bytes = await collectBody10(response.body, context);
          if (bytes.byteLength > 0) {
            Object.assign(dataObject, await deserializer.read(15, bytes));
          }
          await this.handleError(operationSchema, context, response, dataObject, this.deserializeMetadata(response));
          throw new Error("@smithy/core/protocols - HTTP Protocol error handler failed to throw.");
        }
        for (const header in response.headers) {
          const value = response.headers[header];
          delete response.headers[header];
          response.headers[header.toLowerCase()] = value;
        }
        const nonHttpBindingMembers = await this.deserializeHttpMessage(ns, context, response, dataObject);
        if (nonHttpBindingMembers.length) {
          const bytes = await collectBody10(response.body, context);
          if (bytes.byteLength > 0) {
            const dataFromBody = await deserializer.read(ns, bytes);
            for (const member7 of nonHttpBindingMembers) {
              if (dataFromBody[member7] != null) {
                dataObject[member7] = dataFromBody[member7];
              }
            }
          }
        } else if (nonHttpBindingMembers.discardResponseBody) {
          await collectBody10(response.body, context);
        }
        dataObject.$metadata = this.deserializeMetadata(response);
        return dataObject;
      }
      async deserializeHttpMessage(schema, context, response, arg4, arg5) {
        let dataObject;
        if (arg4 instanceof Set) {
          dataObject = arg5;
        } else {
          dataObject = arg4;
        }
        let discardResponseBody = true;
        const deserializer = this.deserializer;
        const ns = NormalizedSchema3.of(schema);
        const nonHttpBindingMembers = [];
        for (const [memberName, memberSchema] of ns.structIterator()) {
          const memberTraits = memberSchema.getMemberTraits();
          if (memberTraits.httpPayload) {
            discardResponseBody = false;
            const isStreaming = memberSchema.isStreaming();
            if (isStreaming) {
              const isEventStream = memberSchema.isStructSchema();
              if (isEventStream) {
                dataObject[memberName] = await this.deserializeEventStream({
                  response,
                  responseSchema: ns
                });
              } else {
                dataObject[memberName] = sdkStreamMixin5(response.body);
              }
            } else if (response.body) {
              const bytes = await collectBody10(response.body, context);
              if (bytes.byteLength > 0) {
                dataObject[memberName] = await deserializer.read(memberSchema, bytes);
              }
            }
          } else if (memberTraits.httpHeader) {
            const key = String(memberTraits.httpHeader).toLowerCase();
            const value = response.headers[key];
            if (null != value) {
              if (memberSchema.isListSchema()) {
                const headerListValueSchema = memberSchema.getValueSchema();
                headerListValueSchema.getMergedTraits().httpHeader = key;
                let sections;
                if (headerListValueSchema.isTimestampSchema() && headerListValueSchema.getSchema() === 4) {
                  sections = splitEvery3(value, ",", 2);
                } else {
                  sections = splitHeader3(value);
                }
                const list3 = [];
                for (const section of sections) {
                  list3.push(await deserializer.read(headerListValueSchema, section.trim()));
                }
                dataObject[memberName] = list3;
              } else {
                dataObject[memberName] = await deserializer.read(memberSchema, value);
              }
            }
          } else if (memberTraits.httpPrefixHeaders !== void 0) {
            dataObject[memberName] = {};
            for (const header in response.headers) {
              if (header.startsWith(memberTraits.httpPrefixHeaders)) {
                const value = response.headers[header];
                const valueSchema = memberSchema.getValueSchema();
                valueSchema.getMergedTraits().httpHeader = header;
                dataObject[memberName][header.slice(memberTraits.httpPrefixHeaders.length)] = await deserializer.read(valueSchema, value);
              }
            }
          } else if (memberTraits.httpResponseCode) {
            dataObject[memberName] = response.statusCode;
          } else {
            nonHttpBindingMembers.push(memberName);
          }
        }
        nonHttpBindingMembers.discardResponseBody = discardResponseBody;
        return nonHttpBindingMembers;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/RpcProtocol.js
var RpcProtocol3;
var init_RpcProtocol4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/RpcProtocol.js"() {
    init_schema6();
    init_HttpProtocol4();
    init_collect_stream_body4();
    init_httpRequest3();
    RpcProtocol3 = class extends HttpProtocol3 {
      static {
        __name(this, "RpcProtocol");
      }
      async serializeRequest(operationSchema, _input, context) {
        const serializer = this.serializer;
        const query = {};
        const headers = {};
        const endpoint = await context.endpoint();
        const ns = NormalizedSchema3.of(operationSchema?.input);
        const schema = ns.getSchema();
        let payload3;
        const input = _input && typeof _input === "object" ? _input : {};
        const request4 = new HttpRequest22({
          protocol: "",
          hostname: "",
          port: void 0,
          path: "/",
          fragment: void 0,
          query,
          headers,
          body: void 0
        });
        if (endpoint) {
          this.updateServiceEndpoint(request4, endpoint);
          this.setHostPrefix(request4, operationSchema, input);
        }
        if (input) {
          const eventStreamMember = ns.getEventStreamMember();
          if (eventStreamMember) {
            if (input[eventStreamMember]) {
              const initialRequest = {};
              for (const [memberName, memberSchema] of ns.structIterator()) {
                if (memberName !== eventStreamMember && input[memberName]) {
                  serializer.write(memberSchema, input[memberName]);
                  initialRequest[memberName] = serializer.flush();
                }
              }
              payload3 = await this.serializeEventStream({
                eventStream: input[eventStreamMember],
                requestSchema: ns,
                initialRequest
              });
            }
          } else {
            serializer.write(schema, input);
            payload3 = serializer.flush();
          }
        }
        request4.headers = Object.assign(request4.headers, headers);
        request4.query = query;
        request4.body = payload3;
        request4.method = "POST";
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        const deserializer = this.deserializer;
        const ns = NormalizedSchema3.of(operationSchema.output);
        const dataObject = {};
        if (response.statusCode >= 300) {
          const bytes = await collectBody10(response.body, context);
          if (bytes.byteLength > 0) {
            Object.assign(dataObject, await deserializer.read(15, bytes));
          }
          await this.handleError(operationSchema, context, response, dataObject, this.deserializeMetadata(response));
          throw new Error("@smithy/core/protocols - RPC Protocol error handler failed to throw.");
        }
        for (const header in response.headers) {
          const value = response.headers[header];
          delete response.headers[header];
          response.headers[header.toLowerCase()] = value;
        }
        const eventStreamMember = ns.getEventStreamMember();
        if (eventStreamMember) {
          dataObject[eventStreamMember] = await this.deserializeEventStream({
            response,
            responseSchema: ns,
            initialResponseContainer: dataObject
          });
        } else {
          const bytes = await collectBody10(response.body, context);
          if (bytes.byteLength > 0) {
            Object.assign(dataObject, await deserializer.read(ns, bytes));
          }
        }
        dataObject.$metadata = this.deserializeMetadata(response);
        return dataObject;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/resolve-path.js
var resolvedPath3;
var init_resolve_path4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/resolve-path.js"() {
    init_extended_encode_uri_component4();
    resolvedPath3 = /* @__PURE__ */ __name((resolvedPath7, input, memberName, labelValueProvider, uriLabel, isGreedyLabel) => {
      if (input != null && input[memberName] !== void 0) {
        const labelValue = labelValueProvider();
        if (labelValue == null || labelValue.length <= 0) {
          throw new Error("Empty value provided for input HTTP label: " + memberName + ".");
        }
        resolvedPath7 = resolvedPath7.replace(uriLabel, isGreedyLabel ? labelValue.split("/").map((segment) => extendedEncodeURIComponent3(segment)).join("/") : extendedEncodeURIComponent3(labelValue));
      } else {
        throw new Error("No value provided for input HTTP label: " + memberName + ".");
      }
      return resolvedPath7;
    }, "resolvedPath");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/requestBuilder.js
function requestBuilder3(input, context) {
  return new RequestBuilder3(input, context);
}
var RequestBuilder3;
var init_requestBuilder5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/requestBuilder.js"() {
    init_httpRequest3();
    init_resolve_path4();
    __name(requestBuilder3, "requestBuilder");
    RequestBuilder3 = class {
      static {
        __name(this, "RequestBuilder");
      }
      input;
      context;
      query = {};
      method = "";
      headers = {};
      path = "";
      body = null;
      hostname = "";
      resolvePathStack = [];
      constructor(input, context) {
        this.input = input;
        this.context = context;
      }
      async build() {
        const { hostname, protocol = "https", port, path: basePath } = await this.context.endpoint();
        this.path = basePath;
        for (const resolvePath of this.resolvePathStack) {
          resolvePath(this.path);
        }
        return new HttpRequest22({
          protocol,
          hostname: this.hostname || hostname,
          port,
          method: this.method,
          path: this.path,
          query: this.query,
          body: this.body,
          headers: this.headers
        });
      }
      hn(hostname) {
        this.hostname = hostname;
        return this;
      }
      bp(uriLabel) {
        this.resolvePathStack.push((basePath) => {
          this.path = `${basePath?.endsWith("/") ? basePath.slice(0, -1) : basePath || ""}` + uriLabel;
        });
        return this;
      }
      p(memberName, labelValueProvider, uriLabel, isGreedyLabel) {
        this.resolvePathStack.push((path47) => {
          this.path = resolvedPath3(path47, this.input, memberName, labelValueProvider, uriLabel, isGreedyLabel);
        });
        return this;
      }
      h(headers) {
        this.headers = headers;
        return this;
      }
      q(query) {
        this.query = query;
        return this;
      }
      b(body) {
        this.body = body;
        return this;
      }
      m(method) {
        this.method = method;
        return this;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/serde/determineTimestampFormat.js
function determineTimestampFormat3(ns, settings) {
  if (settings.timestampFormat.useTrait) {
    if (ns.isTimestampSchema() && (ns.getSchema() === 5 || ns.getSchema() === 6 || ns.getSchema() === 7)) {
      return ns.getSchema();
    }
  }
  const { httpLabel, httpPrefixHeaders, httpHeader, httpQuery } = ns.getMergedTraits();
  const bindingFormat = settings.httpBindings ? typeof httpPrefixHeaders === "string" || Boolean(httpHeader) ? 6 : Boolean(httpQuery) || Boolean(httpLabel) ? 5 : void 0 : void 0;
  return bindingFormat ?? settings.timestampFormat.default;
}
var init_determineTimestampFormat4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/serde/determineTimestampFormat.js"() {
    __name(determineTimestampFormat3, "determineTimestampFormat");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/serde/FromStringShapeDeserializer.js
var FromStringShapeDeserializer3;
var init_FromStringShapeDeserializer4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/serde/FromStringShapeDeserializer.js"() {
    init_schema6();
    init_serde4();
    init_SerdeContext4();
    init_determineTimestampFormat4();
    FromStringShapeDeserializer3 = class extends SerdeContext3 {
      static {
        __name(this, "FromStringShapeDeserializer");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      read(_schema, data3) {
        const ns = NormalizedSchema3.of(_schema);
        if (ns.isListSchema()) {
          return splitHeader3(data3).map((item) => this.read(ns.getValueSchema(), item));
        }
        if (ns.isBlobSchema()) {
          return (this.serdeContext?.base64Decoder ?? fromBase6436)(data3);
        }
        if (ns.isTimestampSchema()) {
          const format32 = determineTimestampFormat3(ns, this.settings);
          switch (format32) {
            case 5:
              return _parseRfc3339DateTimeWithOffset3(data3);
            case 6:
              return _parseRfc7231DateTime3(data3);
            case 7:
              return _parseEpochTimestamp3(data3);
            default:
              console.warn("Missing timestamp format, parsing value with Date constructor:", data3);
              return new Date(data3);
          }
        }
        if (ns.isStringSchema()) {
          const mediaType = ns.getMergedTraits().mediaType;
          let intermediateValue = data3;
          if (mediaType) {
            if (ns.getMergedTraits().httpHeader) {
              intermediateValue = this.base64ToUtf8(intermediateValue);
            }
            const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
            if (isJson) {
              intermediateValue = LazyJsonString5.from(intermediateValue);
            }
            return intermediateValue;
          }
        }
        if (ns.isNumericSchema()) {
          return Number(data3);
        }
        if (ns.isBigIntegerSchema()) {
          return BigInt(data3);
        }
        if (ns.isBigDecimalSchema()) {
          return new NumericValue3(data3, "bigDecimal");
        }
        if (ns.isBooleanSchema()) {
          return String(data3).toLowerCase() === "true";
        }
        return data3;
      }
      base64ToUtf8(base64String) {
        return (this.serdeContext?.utf8Encoder ?? toUtf839)((this.serdeContext?.base64Decoder ?? fromBase6436)(base64String));
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/serde/HttpInterceptingShapeDeserializer.js
var HttpInterceptingShapeDeserializer3;
var init_HttpInterceptingShapeDeserializer4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/serde/HttpInterceptingShapeDeserializer.js"() {
    init_schema6();
    init_serde4();
    init_SerdeContext4();
    init_FromStringShapeDeserializer4();
    HttpInterceptingShapeDeserializer3 = class extends SerdeContext3 {
      static {
        __name(this, "HttpInterceptingShapeDeserializer");
      }
      codecDeserializer;
      stringDeserializer;
      constructor(codecDeserializer, codecSettings) {
        super();
        this.codecDeserializer = codecDeserializer;
        this.stringDeserializer = new FromStringShapeDeserializer3(codecSettings);
      }
      setSerdeContext(serdeContext) {
        this.stringDeserializer.setSerdeContext(serdeContext);
        this.codecDeserializer.setSerdeContext(serdeContext);
        this.serdeContext = serdeContext;
      }
      read(schema, data3) {
        const ns = NormalizedSchema3.of(schema);
        const traits = ns.getMergedTraits();
        const toString = this.serdeContext?.utf8Encoder ?? toUtf839;
        if (traits.httpHeader || traits.httpResponseCode) {
          return this.stringDeserializer.read(ns, toString(data3));
        }
        if (traits.httpPayload) {
          if (ns.isBlobSchema()) {
            const toBytes = this.serdeContext?.utf8Decoder ?? fromUtf825;
            if (typeof data3 === "string") {
              return toBytes(data3);
            }
            return data3;
          } else if (ns.isStringSchema()) {
            if ("byteLength" in data3) {
              return toString(data3);
            }
            return data3;
          }
        }
        return this.codecDeserializer.read(ns, data3);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/serde/ToStringShapeSerializer.js
var ToStringShapeSerializer3;
var init_ToStringShapeSerializer4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/serde/ToStringShapeSerializer.js"() {
    init_schema6();
    init_serde4();
    init_SerdeContext4();
    init_determineTimestampFormat4();
    ToStringShapeSerializer3 = class extends SerdeContext3 {
      static {
        __name(this, "ToStringShapeSerializer");
      }
      settings;
      stringBuffer = "";
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value) {
        const ns = NormalizedSchema3.of(schema);
        switch (typeof value) {
          case "object":
            if (value === null) {
              this.stringBuffer = "null";
              return;
            }
            if (ns.isTimestampSchema()) {
              if (!(value instanceof Date)) {
                throw new Error(`@smithy/core/protocols - received non-Date value ${value} when schema expected Date in ${ns.getName(true)}`);
              }
              const format32 = determineTimestampFormat3(ns, this.settings);
              switch (format32) {
                case 5:
                  this.stringBuffer = value.toISOString().replace(".000Z", "Z");
                  break;
                case 6:
                  this.stringBuffer = dateToUtcString15(value);
                  break;
                case 7:
                  this.stringBuffer = String(value.getTime() / 1e3);
                  break;
                default:
                  console.warn("Missing timestamp format, using epoch seconds", value);
                  this.stringBuffer = String(value.getTime() / 1e3);
              }
              return;
            }
            if (ns.isBlobSchema() && "byteLength" in value) {
              this.stringBuffer = (this.serdeContext?.base64Encoder ?? toBase6441)(value);
              return;
            }
            if (ns.isListSchema() && Array.isArray(value)) {
              let buffer = "";
              for (const item of value) {
                this.write([ns.getValueSchema(), ns.getMergedTraits()], item);
                const headerItem = this.flush();
                const serialized = ns.getValueSchema().isTimestampSchema() ? headerItem : quoteHeader3(headerItem);
                if (buffer !== "") {
                  buffer += ", ";
                }
                buffer += serialized;
              }
              this.stringBuffer = buffer;
              return;
            }
            this.stringBuffer = JSON.stringify(value, null, 2);
            break;
          case "string":
            const mediaType = ns.getMergedTraits().mediaType;
            let intermediateValue = value;
            if (mediaType) {
              const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
              if (isJson) {
                intermediateValue = LazyJsonString5.from(intermediateValue);
              }
              if (ns.getMergedTraits().httpHeader) {
                this.stringBuffer = (this.serdeContext?.base64Encoder ?? toBase6441)(intermediateValue.toString());
                return;
              }
            }
            this.stringBuffer = value;
            break;
          default:
            if (ns.isIdempotencyToken()) {
              this.stringBuffer = generateIdempotencyToken3();
            } else {
              this.stringBuffer = String(value);
            }
        }
      }
      flush() {
        const buffer = this.stringBuffer;
        this.stringBuffer = "";
        return buffer;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/serde/HttpInterceptingShapeSerializer.js
var HttpInterceptingShapeSerializer3;
var init_HttpInterceptingShapeSerializer4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/serde/HttpInterceptingShapeSerializer.js"() {
    init_schema6();
    init_ToStringShapeSerializer4();
    HttpInterceptingShapeSerializer3 = class {
      static {
        __name(this, "HttpInterceptingShapeSerializer");
      }
      codecSerializer;
      stringSerializer;
      buffer;
      constructor(codecSerializer, codecSettings, stringSerializer = new ToStringShapeSerializer3(codecSettings)) {
        this.codecSerializer = codecSerializer;
        this.stringSerializer = stringSerializer;
      }
      setSerdeContext(serdeContext) {
        this.codecSerializer.setSerdeContext(serdeContext);
        this.stringSerializer.setSerdeContext(serdeContext);
      }
      write(schema, value) {
        const ns = NormalizedSchema3.of(schema);
        const traits = ns.getMergedTraits();
        if (traits.httpHeader || traits.httpLabel || traits.httpQuery) {
          this.stringSerializer.write(ns, value);
          this.buffer = this.stringSerializer.flush();
          return;
        }
        return this.codecSerializer.write(ns, value);
      }
      flush() {
        if (this.buffer !== void 0) {
          const buffer = this.buffer;
          this.buffer = void 0;
          return buffer;
        }
        return this.codecSerializer.flush();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/Field.js
var import_types40, Field2;
var init_Field2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/Field.js"() {
    import_types40 = __toESM(require_dist_cjs());
    Field2 = class {
      static {
        __name(this, "Field");
      }
      name;
      kind;
      values;
      constructor({ name, kind = import_types40.FieldPosition.HEADER, values = [] }) {
        this.name = name;
        this.kind = kind;
        this.values = values;
      }
      add(value) {
        this.values.push(value);
      }
      set(values) {
        this.values = values;
      }
      remove(value) {
        this.values = this.values.filter((v) => v !== value);
      }
      toString() {
        return this.values.map((v) => v.includes(",") || v.includes(" ") ? `"${v}"` : v).join(", ");
      }
      get() {
        return this.values;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/Fields.js
var Fields2;
var init_Fields2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/Fields.js"() {
    Fields2 = class {
      static {
        __name(this, "Fields");
      }
      entries = {};
      encoding;
      constructor({ fields = [], encoding = "utf-8" }) {
        fields.forEach(this.setField.bind(this));
        this.encoding = encoding;
      }
      setField(field) {
        this.entries[field.name.toLowerCase()] = field;
      }
      getField(name) {
        return this.entries[name.toLowerCase()];
      }
      removeField(name) {
        delete this.entries[name.toLowerCase()];
      }
      getByType(kind) {
        return Object.values(this.entries).filter((field) => field.kind === kind);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/isValidHostname.js
function isValidHostname2(hostname) {
  const hostPattern = /^[a-z0-9][a-z0-9\.\-]*[a-z0-9]$/;
  return hostPattern.test(hostname);
}
var init_isValidHostname2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/isValidHostname.js"() {
    __name(isValidHostname2, "isValidHostname");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/extensions/httpExtensionConfiguration.js
var getHttpHandlerExtensionConfiguration20, resolveHttpHandlerRuntimeConfig20;
var init_httpExtensionConfiguration2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/extensions/httpExtensionConfiguration.js"() {
    getHttpHandlerExtensionConfiguration20 = /* @__PURE__ */ __name((runtimeConfig) => {
      return {
        setHttpHandler(handler) {
          runtimeConfig.httpHandler = handler;
        },
        httpHandler() {
          return runtimeConfig.httpHandler;
        },
        updateHttpClientConfig(key, value) {
          runtimeConfig.httpHandler?.updateHttpClientConfig(key, value);
        },
        httpHandlerConfigs() {
          return runtimeConfig.httpHandler.httpHandlerConfigs();
        }
      };
    }, "getHttpHandlerExtensionConfiguration");
    resolveHttpHandlerRuntimeConfig20 = /* @__PURE__ */ __name((httpHandlerExtensionConfiguration) => {
      return {
        httpHandler: httpHandlerExtensionConfiguration.httpHandler()
      };
    }, "resolveHttpHandlerRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/middleware-content-length/contentLengthMiddleware.js
function contentLengthMiddleware2(bodyLengthChecker) {
  return (next) => async (args) => {
    const request4 = args.request;
    if (HttpRequest22.isInstance(request4)) {
      const { body, headers } = request4;
      if (body && Object.keys(headers).map((str) => str.toLowerCase()).indexOf(CONTENT_LENGTH_HEADER2) === -1) {
        try {
          const length = bodyLengthChecker(body);
          request4.headers = {
            ...request4.headers,
            [CONTENT_LENGTH_HEADER2]: String(length)
          };
        } catch (error4) {
        }
      }
    }
    return next({
      ...args,
      request: request4
    });
  };
}
var CONTENT_LENGTH_HEADER2, contentLengthMiddlewareOptions2, getContentLengthPlugin20;
var init_contentLengthMiddleware2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/middleware-content-length/contentLengthMiddleware.js"() {
    init_httpRequest3();
    CONTENT_LENGTH_HEADER2 = "content-length";
    __name(contentLengthMiddleware2, "contentLengthMiddleware");
    contentLengthMiddlewareOptions2 = {
      step: "build",
      tags: ["SET_CONTENT_LENGTH", "CONTENT_LENGTH"],
      name: "contentLengthMiddleware",
      override: true
    };
    getContentLengthPlugin20 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(contentLengthMiddleware2(options.bodyLengthChecker), contentLengthMiddlewareOptions2);
      }, "applyToStack")
    }), "getContentLengthPlugin");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/util-uri-escape/escape-uri.js
var escapeUri2, hexEncode2;
var init_escape_uri2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/util-uri-escape/escape-uri.js"() {
    escapeUri2 = /* @__PURE__ */ __name((uri) => encodeURIComponent(uri).replace(/[!'()*]/g, hexEncode2), "escapeUri");
    hexEncode2 = /* @__PURE__ */ __name((c32) => `%${c32.charCodeAt(0).toString(16).toUpperCase()}`, "hexEncode");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/util-uri-escape/escape-uri-path.js
var escapeUriPath2;
var init_escape_uri_path2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/util-uri-escape/escape-uri-path.js"() {
    init_escape_uri2();
    escapeUriPath2 = /* @__PURE__ */ __name((uri) => uri.split("/").map(escapeUri2).join("/"), "escapeUriPath");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/querystring-builder/buildQueryString.js
function buildQueryString2(query) {
  const parts = [];
  for (let key of Object.keys(query).sort()) {
    const value = query[key];
    key = escapeUri2(key);
    if (Array.isArray(value)) {
      for (let i32 = 0, iLen = value.length; i32 < iLen; i32++) {
        parts.push(`${key}=${escapeUri2(value[i32])}`);
      }
    } else {
      let qsEntry = key;
      if (value || typeof value === "string") {
        qsEntry += `=${escapeUri2(value)}`;
      }
      parts.push(qsEntry);
    }
  }
  return parts.join("&");
}
var init_buildQueryString2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/querystring-builder/buildQueryString.js"() {
    init_escape_uri2();
    __name(buildQueryString2, "buildQueryString");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/querystring-parser/parseQueryString.js
function parseQueryString2(querystring) {
  const query = {};
  querystring = querystring.replace(/^\?/, "");
  if (querystring) {
    for (const pair of querystring.split("&")) {
      let [key, value = null] = pair.split("=");
      key = decodeURIComponent(key);
      if (value) {
        value = decodeURIComponent(value);
      }
      if (!(key in query)) {
        query[key] = value;
      } else if (Array.isArray(query[key])) {
        query[key].push(value);
      } else {
        query[key] = [query[key], value];
      }
    }
  }
  return query;
}
var init_parseQueryString2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/querystring-parser/parseQueryString.js"() {
    __name(parseQueryString2, "parseQueryString");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/url-parser/parseUrl.js
var parseUrl21;
var init_parseUrl2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/url-parser/parseUrl.js"() {
    init_parseQueryString2();
    parseUrl21 = /* @__PURE__ */ __name((url) => {
      if (typeof url === "string") {
        return parseUrl21(new URL(url));
      }
      const { hostname, pathname, port, protocol, search } = url;
      let query;
      if (search) {
        query = parseQueryString2(search);
      }
      return {
        hostname,
        port: port ? parseInt(port) : void 0,
        protocol,
        path: pathname,
        query
      };
    }, "parseUrl");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/index.js
var protocols_exports8 = {};
__export(protocols_exports8, {
  Field: () => Field2,
  Fields: () => Fields2,
  FromStringShapeDeserializer: () => FromStringShapeDeserializer3,
  HttpBindingProtocol: () => HttpBindingProtocol3,
  HttpInterceptingShapeDeserializer: () => HttpInterceptingShapeDeserializer3,
  HttpInterceptingShapeSerializer: () => HttpInterceptingShapeSerializer3,
  HttpProtocol: () => HttpProtocol3,
  HttpRequest: () => HttpRequest22,
  HttpResponse: () => HttpResponse11,
  RequestBuilder: () => RequestBuilder3,
  RpcProtocol: () => RpcProtocol3,
  SerdeContext: () => SerdeContext3,
  ToStringShapeSerializer: () => ToStringShapeSerializer3,
  buildQueryString: () => buildQueryString2,
  collectBody: () => collectBody10,
  contentLengthMiddleware: () => contentLengthMiddleware2,
  contentLengthMiddlewareOptions: () => contentLengthMiddlewareOptions2,
  determineTimestampFormat: () => determineTimestampFormat3,
  escapeUri: () => escapeUri2,
  escapeUriPath: () => escapeUriPath2,
  extendedEncodeURIComponent: () => extendedEncodeURIComponent3,
  getContentLengthPlugin: () => getContentLengthPlugin20,
  getHttpHandlerExtensionConfiguration: () => getHttpHandlerExtensionConfiguration20,
  isValidHostname: () => isValidHostname2,
  parseQueryString: () => parseQueryString2,
  parseUrl: () => parseUrl21,
  requestBuilder: () => requestBuilder3,
  resolveHttpHandlerRuntimeConfig: () => resolveHttpHandlerRuntimeConfig20,
  resolvedPath: () => resolvedPath3
});
var init_protocols11 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/protocols/index.js"() {
    init_collect_stream_body4();
    init_extended_encode_uri_component4();
    init_HttpBindingProtocol4();
    init_HttpProtocol4();
    init_RpcProtocol4();
    init_requestBuilder5();
    init_resolve_path4();
    init_FromStringShapeDeserializer4();
    init_HttpInterceptingShapeDeserializer4();
    init_HttpInterceptingShapeSerializer4();
    init_ToStringShapeSerializer4();
    init_determineTimestampFormat4();
    init_SerdeContext4();
    init_Field2();
    init_Fields2();
    init_httpRequest3();
    init_httpResponse3();
    init_isValidHostname2();
    init_httpExtensionConfiguration2();
    init_contentLengthMiddleware2();
    init_escape_uri2();
    init_escape_uri_path2();
    init_buildQueryString2();
    init_parseQueryString2();
    init_parseUrl2();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/schemas/operation.js
var operation2;
var init_operation3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/schemas/operation.js"() {
    operation2 = /* @__PURE__ */ __name((namespace, name, traits, input, output) => ({
      name,
      namespace,
      traits,
      input,
      output
    }), "operation");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/middleware/schemaDeserializationMiddleware.js
var schemaDeserializationMiddleware2, findHeader3;
var init_schemaDeserializationMiddleware2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/middleware/schemaDeserializationMiddleware.js"() {
    init_client12();
    init_protocols11();
    init_operation3();
    schemaDeserializationMiddleware2 = /* @__PURE__ */ __name((config2) => (next, context) => async (args) => {
      const { response } = await next(args);
      const { operationSchema } = getSmithyContext26(context);
      const [, ns, n10, t, i32, o10] = operationSchema ?? [];
      try {
        const parsed = await config2.protocol.deserializeResponse(operation2(ns, n10, t, i32, o10), {
          ...config2,
          ...context
        }, response);
        return {
          response,
          output: parsed
        };
      } catch (error4) {
        Object.defineProperty(error4, "$response", {
          value: response,
          enumerable: false,
          writable: false,
          configurable: false
        });
        if (!("$metadata" in error4)) {
          const hint = `Deserialization error: to see the raw response, inspect the hidden field {error}.$response on this object.`;
          try {
            error4.message += "\n  " + hint;
          } catch (e32) {
            if (!context.logger || context.logger?.constructor?.name === "NoOpLogger") {
              console.warn(hint);
            } else {
              context.logger?.warn?.(hint);
            }
          }
          if (typeof error4.$responseBodyText !== "undefined") {
            if (error4.$response) {
              error4.$response.body = error4.$responseBodyText;
            }
          }
          try {
            if (HttpResponse11.isInstance(response)) {
              const { headers = {} } = response;
              const headerEntries = Object.entries(headers);
              error4.$metadata = {
                httpStatusCode: response.statusCode,
                requestId: findHeader3(/^x-[\w-]+-request-?id$/, headerEntries),
                extendedRequestId: findHeader3(/^x-[\w-]+-id-2$/, headerEntries),
                cfId: findHeader3(/^x-[\w-]+-cf-id$/, headerEntries)
              };
            }
          } catch (e32) {
          }
        }
        throw error4;
      }
    }, "schemaDeserializationMiddleware");
    findHeader3 = /* @__PURE__ */ __name((pattern, headers) => {
      return (headers.find(([k32]) => {
        return k32.match(pattern);
      }) || [void 0, void 0])[1];
    }, "findHeader");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/middleware/schemaSerializationMiddleware.js
var schemaSerializationMiddleware2;
var init_schemaSerializationMiddleware2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/middleware/schemaSerializationMiddleware.js"() {
    init_client12();
    init_endpoints3();
    init_operation3();
    schemaSerializationMiddleware2 = /* @__PURE__ */ __name((config2) => (next, context) => async (args) => {
      const { operationSchema } = getSmithyContext26(context);
      const [, ns, n10, t, i32, o10] = operationSchema ?? [];
      const endpoint = context.endpointV2 ? async () => toEndpointV13(context.endpointV2) : config2.endpoint;
      const request4 = await config2.protocol.serializeRequest(operation2(ns, n10, t, i32, o10), args.input, {
        ...config2,
        ...context,
        endpoint
      });
      return next({
        ...args,
        request: request4
      });
    }, "schemaSerializationMiddleware");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/middleware/getSchemaSerdePlugin.js
function getSchemaSerdePlugin2(config2) {
  return {
    applyToStack: /* @__PURE__ */ __name((commandStack) => {
      commandStack.add(schemaSerializationMiddleware2(config2), serializerMiddlewareOption5);
      commandStack.add(schemaDeserializationMiddleware2(config2), deserializerMiddlewareOption3);
      config2.protocol.setSerdeContext(config2);
    }, "applyToStack")
  };
}
var deserializerMiddlewareOption3, serializerMiddlewareOption5;
var init_getSchemaSerdePlugin3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/middleware/getSchemaSerdePlugin.js"() {
    init_schemaDeserializationMiddleware2();
    init_schemaSerializationMiddleware2();
    deserializerMiddlewareOption3 = {
      name: "deserializerMiddleware",
      step: "deserialize",
      tags: ["DESERIALIZER"],
      override: true
    };
    serializerMiddlewareOption5 = {
      name: "serializerMiddleware",
      step: "serialize",
      tags: ["SERIALIZER"],
      override: true
    };
    __name(getSchemaSerdePlugin2, "getSchemaSerdePlugin");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/schemas/Schema.js
var Schema3;
var init_Schema3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/schemas/Schema.js"() {
    Schema3 = class {
      static {
        __name(this, "Schema");
      }
      name;
      namespace;
      traits;
      static assign(instance, values) {
        const schema = Object.assign(instance, values);
        return schema;
      }
      static [Symbol.hasInstance](lhs) {
        const isPrototype = this.prototype.isPrototypeOf(lhs);
        if (!isPrototype && typeof lhs === "object" && lhs !== null) {
          const list3 = lhs;
          return list3.symbol === this.symbol;
        }
        return isPrototype;
      }
      getName() {
        return this.namespace + "#" + this.name;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/schemas/ListSchema.js
var ListSchema2, list2;
var init_ListSchema3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/schemas/ListSchema.js"() {
    init_Schema3();
    ListSchema2 = class _ListSchema extends Schema3 {
      static {
        __name(this, "ListSchema");
      }
      static symbol = /* @__PURE__ */ Symbol.for("@smithy/lis");
      name;
      traits;
      valueSchema;
      symbol = _ListSchema.symbol;
    };
    list2 = /* @__PURE__ */ __name((namespace, name, traits, valueSchema) => Schema3.assign(new ListSchema2(), {
      name,
      namespace,
      traits,
      valueSchema
    }), "list");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/schemas/MapSchema.js
var MapSchema2, map2;
var init_MapSchema3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/schemas/MapSchema.js"() {
    init_Schema3();
    MapSchema2 = class _MapSchema extends Schema3 {
      static {
        __name(this, "MapSchema");
      }
      static symbol = /* @__PURE__ */ Symbol.for("@smithy/map");
      name;
      traits;
      keySchema;
      valueSchema;
      symbol = _MapSchema.symbol;
    };
    map2 = /* @__PURE__ */ __name((namespace, name, traits, keySchema, valueSchema) => Schema3.assign(new MapSchema2(), {
      name,
      namespace,
      traits,
      keySchema,
      valueSchema
    }), "map");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/schemas/OperationSchema.js
var OperationSchema2, op2;
var init_OperationSchema3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/schemas/OperationSchema.js"() {
    init_Schema3();
    OperationSchema2 = class _OperationSchema extends Schema3 {
      static {
        __name(this, "OperationSchema");
      }
      static symbol = /* @__PURE__ */ Symbol.for("@smithy/ope");
      name;
      traits;
      input;
      output;
      symbol = _OperationSchema.symbol;
    };
    op2 = /* @__PURE__ */ __name((namespace, name, traits, input, output) => Schema3.assign(new OperationSchema2(), {
      name,
      namespace,
      traits,
      input,
      output
    }), "op");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/schemas/StructureSchema.js
var StructureSchema2, struct2;
var init_StructureSchema3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/schemas/StructureSchema.js"() {
    init_Schema3();
    StructureSchema2 = class _StructureSchema extends Schema3 {
      static {
        __name(this, "StructureSchema");
      }
      static symbol = /* @__PURE__ */ Symbol.for("@smithy/str");
      name;
      traits;
      memberNames;
      memberList;
      symbol = _StructureSchema.symbol;
    };
    struct2 = /* @__PURE__ */ __name((namespace, name, traits, memberNames, memberList) => Schema3.assign(new StructureSchema2(), {
      name,
      namespace,
      traits,
      memberNames,
      memberList
    }), "struct");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/schemas/ErrorSchema.js
var ErrorSchema2, error3;
var init_ErrorSchema3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/schemas/ErrorSchema.js"() {
    init_Schema3();
    init_StructureSchema3();
    ErrorSchema2 = class _ErrorSchema extends StructureSchema2 {
      static {
        __name(this, "ErrorSchema");
      }
      static symbol = /* @__PURE__ */ Symbol.for("@smithy/err");
      ctor;
      symbol = _ErrorSchema.symbol;
    };
    error3 = /* @__PURE__ */ __name((namespace, name, traits, memberNames, memberList, ctor) => Schema3.assign(new ErrorSchema2(), {
      name,
      namespace,
      traits,
      memberNames,
      memberList,
      ctor: null
    }), "error");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/schemas/translateTraits.js
function translateTraits3(indicator) {
  if (typeof indicator === "object") {
    return indicator;
  }
  indicator = indicator | 0;
  if (traitsCache3[indicator]) {
    return traitsCache3[indicator];
  }
  const traits = {};
  let i32 = 0;
  for (const trait of [
    "httpLabel",
    "idempotent",
    "idempotencyToken",
    "sensitive",
    "httpPayload",
    "httpResponseCode",
    "httpQueryParams"
  ]) {
    if ((indicator >> i32++ & 1) === 1) {
      traits[trait] = 1;
    }
  }
  return traitsCache3[indicator] = traits;
}
var traitsCache3;
var init_translateTraits3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/schemas/translateTraits.js"() {
    traitsCache3 = [];
    __name(translateTraits3, "translateTraits");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/schemas/NormalizedSchema.js
function member3(memberSchema, memberName) {
  if (memberSchema instanceof NormalizedSchema3) {
    return Object.assign(memberSchema, {
      memberName,
      _isMemberSchema: true
    });
  }
  const internalCtorAccess = NormalizedSchema3;
  return new internalCtorAccess(memberSchema, memberName);
}
var anno3, simpleSchemaCacheN3, simpleSchemaCacheS3, NormalizedSchema3, isMemberSchema3, isStaticSchema3;
var init_NormalizedSchema3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/schemas/NormalizedSchema.js"() {
    init_deref3();
    init_translateTraits3();
    anno3 = {
      it: /* @__PURE__ */ Symbol.for("@smithy/nor-struct-it"),
      ns: /* @__PURE__ */ Symbol.for("@smithy/ns")
    };
    simpleSchemaCacheN3 = [];
    simpleSchemaCacheS3 = {};
    NormalizedSchema3 = class _NormalizedSchema {
      static {
        __name(this, "NormalizedSchema");
      }
      ref;
      memberName;
      static symbol = /* @__PURE__ */ Symbol.for("@smithy/nor");
      symbol = _NormalizedSchema.symbol;
      name;
      schema;
      _isMemberSchema;
      traits;
      memberTraits;
      normalizedTraits;
      constructor(ref, memberName) {
        this.ref = ref;
        this.memberName = memberName;
        const traitStack = [];
        let _ref = ref;
        let schema = ref;
        this._isMemberSchema = false;
        while (isMemberSchema3(_ref)) {
          traitStack.push(_ref[1]);
          _ref = _ref[0];
          schema = deref3(_ref);
          this._isMemberSchema = true;
        }
        if (traitStack.length > 0) {
          this.memberTraits = {};
          for (let i32 = traitStack.length - 1; i32 >= 0; --i32) {
            const traitSet = traitStack[i32];
            Object.assign(this.memberTraits, translateTraits3(traitSet));
          }
        } else {
          this.memberTraits = 0;
        }
        if (schema instanceof _NormalizedSchema) {
          const computedMemberTraits = this.memberTraits;
          Object.assign(this, schema);
          this.memberTraits = Object.assign({}, computedMemberTraits, schema.getMemberTraits(), this.getMemberTraits());
          this.normalizedTraits = void 0;
          this.memberName = memberName ?? schema.memberName;
          return;
        }
        this.schema = deref3(schema);
        if (isStaticSchema3(this.schema)) {
          this.name = `${this.schema[1]}#${this.schema[2]}`;
          this.traits = this.schema[3];
        } else {
          this.name = this.memberName ?? String(schema);
          this.traits = 0;
        }
        if (this._isMemberSchema && !memberName) {
          throw new Error(`@smithy/core/schema - NormalizedSchema member init ${this.getName(true)} missing member name.`);
        }
      }
      static [Symbol.hasInstance](lhs) {
        const isPrototype = this.prototype.isPrototypeOf(lhs);
        if (!isPrototype && typeof lhs === "object" && lhs !== null) {
          const ns = lhs;
          return ns.symbol === this.symbol;
        }
        return isPrototype;
      }
      static of(ref) {
        const keyAble = typeof ref === "function" || typeof ref === "object" && ref !== null;
        if (typeof ref === "number") {
          if (simpleSchemaCacheN3[ref]) {
            return simpleSchemaCacheN3[ref];
          }
        } else if (typeof ref === "string") {
          if (simpleSchemaCacheS3[ref]) {
            return simpleSchemaCacheS3[ref];
          }
        } else if (keyAble) {
          if (ref[anno3.ns]) {
            return ref[anno3.ns];
          }
        }
        const sc = deref3(ref);
        if (sc instanceof _NormalizedSchema) {
          return sc;
        }
        if (isMemberSchema3(sc)) {
          const [ns2, traits] = sc;
          if (ns2 instanceof _NormalizedSchema) {
            Object.assign(ns2.getMergedTraits(), translateTraits3(traits));
            return ns2;
          }
          throw new Error(`@smithy/core/schema - may not init unwrapped member schema=${JSON.stringify(ref, null, 2)}.`);
        }
        const ns = new _NormalizedSchema(sc);
        if (keyAble) {
          return ref[anno3.ns] = ns;
        }
        if (typeof sc === "string") {
          return simpleSchemaCacheS3[sc] = ns;
        }
        if (typeof sc === "number") {
          return simpleSchemaCacheN3[sc] = ns;
        }
        return ns;
      }
      getSchema() {
        const sc = this.schema;
        if (Array.isArray(sc) && sc[0] === 0) {
          return sc[4];
        }
        return sc;
      }
      getName(withNamespace = false) {
        const { name } = this;
        const short = !withNamespace && name && name.includes("#");
        return short ? name.split("#")[1] : name || void 0;
      }
      getMemberName() {
        return this.memberName;
      }
      isMemberSchema() {
        return this._isMemberSchema;
      }
      isListSchema() {
        const sc = this.getSchema();
        return typeof sc === "number" ? sc >= 64 && sc < 128 : sc[0] === 1;
      }
      isMapSchema() {
        const sc = this.getSchema();
        return typeof sc === "number" ? sc >= 128 && sc <= 255 : sc[0] === 2;
      }
      isStructSchema() {
        const sc = this.getSchema();
        if (typeof sc !== "object") {
          return false;
        }
        const id = sc[0];
        return id === 3 || id === -3 || id === 4;
      }
      isUnionSchema() {
        const sc = this.getSchema();
        if (typeof sc !== "object") {
          return false;
        }
        return sc[0] === 4;
      }
      isBlobSchema() {
        const sc = this.getSchema();
        return sc === 21 || sc === 42;
      }
      isTimestampSchema() {
        const sc = this.getSchema();
        return typeof sc === "number" && sc >= 4 && sc <= 7;
      }
      isUnitSchema() {
        return this.getSchema() === "unit";
      }
      isDocumentSchema() {
        return this.getSchema() === 15;
      }
      isStringSchema() {
        return this.getSchema() === 0;
      }
      isBooleanSchema() {
        return this.getSchema() === 2;
      }
      isNumericSchema() {
        return this.getSchema() === 1;
      }
      isBigIntegerSchema() {
        return this.getSchema() === 17;
      }
      isBigDecimalSchema() {
        return this.getSchema() === 19;
      }
      isStreaming() {
        const { streaming } = this.getMergedTraits();
        return !!streaming || this.getSchema() === 42;
      }
      isIdempotencyToken() {
        return !!this.getMergedTraits().idempotencyToken;
      }
      getMergedTraits() {
        return this.normalizedTraits ?? (this.normalizedTraits = {
          ...this.getOwnTraits(),
          ...this.getMemberTraits()
        });
      }
      getMemberTraits() {
        return translateTraits3(this.memberTraits);
      }
      getOwnTraits() {
        return translateTraits3(this.traits);
      }
      getKeySchema() {
        const [isDoc, isMap] = [this.isDocumentSchema(), this.isMapSchema()];
        if (!isDoc && !isMap) {
          throw new Error(`@smithy/core/schema - cannot get key for non-map: ${this.getName(true)}`);
        }
        const schema = this.getSchema();
        const memberSchema = isDoc ? 15 : schema[4] ?? 0;
        return member3([memberSchema, 0], "key");
      }
      getValueSchema() {
        const sc = this.getSchema();
        const [isDoc, isMap, isList] = [this.isDocumentSchema(), this.isMapSchema(), this.isListSchema()];
        const memberSchema = typeof sc === "number" ? 63 & sc : sc && typeof sc === "object" && (isMap || isList) ? sc[3 + sc[0]] : isDoc ? 15 : void 0;
        if (memberSchema != null) {
          return member3([memberSchema, 0], isMap ? "value" : "member");
        }
        throw new Error(`@smithy/core/schema - ${this.getName(true)} has no value member.`);
      }
      getMemberSchema(memberName) {
        const struct3 = this.getSchema();
        if (this.isStructSchema() && struct3[4].includes(memberName)) {
          const i32 = struct3[4].indexOf(memberName);
          const memberSchema = struct3[5][i32];
          return member3(isMemberSchema3(memberSchema) ? memberSchema : [memberSchema, 0], memberName);
        }
        if (this.isDocumentSchema()) {
          return member3([15, 0], memberName);
        }
        throw new Error(`@smithy/core/schema - ${this.getName(true)} has no member=${memberName}.`);
      }
      getMemberSchemas() {
        const buffer = {};
        try {
          for (const [k32, v] of this.structIterator()) {
            buffer[k32] = v;
          }
        } catch (ignored) {
        }
        return buffer;
      }
      getEventStreamMember() {
        if (this.isStructSchema()) {
          for (const [memberName, memberSchema] of this.structIterator()) {
            if (memberSchema.isStreaming() && memberSchema.isStructSchema()) {
              return memberName;
            }
          }
        }
        return "";
      }
      *structIterator() {
        if (this.isUnitSchema()) {
          return;
        }
        if (!this.isStructSchema()) {
          throw new Error("@smithy/core/schema - cannot iterate non-struct schema.");
        }
        const struct3 = this.getSchema();
        const z = struct3[4].length;
        let it = struct3[anno3.it];
        if (it && z === it.length) {
          yield* it;
          return;
        }
        it = Array(z);
        for (let i32 = 0; i32 < z; ++i32) {
          const k32 = struct3[4][i32];
          const v = member3([struct3[5][i32], 0], k32);
          yield it[i32] = [k32, v];
        }
        struct3[anno3.it] = it;
      }
    };
    __name(member3, "member");
    isMemberSchema3 = /* @__PURE__ */ __name((sc) => Array.isArray(sc) && sc.length === 2, "isMemberSchema");
    isStaticSchema3 = /* @__PURE__ */ __name((sc) => Array.isArray(sc) && sc.length >= 5, "isStaticSchema");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/schemas/SimpleSchema.js
var SimpleSchema2, sim2, simAdapter2;
var init_SimpleSchema3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/schemas/SimpleSchema.js"() {
    init_Schema3();
    SimpleSchema2 = class _SimpleSchema extends Schema3 {
      static {
        __name(this, "SimpleSchema");
      }
      static symbol = /* @__PURE__ */ Symbol.for("@smithy/sim");
      name;
      schemaRef;
      traits;
      symbol = _SimpleSchema.symbol;
    };
    sim2 = /* @__PURE__ */ __name((namespace, name, schemaRef, traits) => Schema3.assign(new SimpleSchema2(), {
      name,
      namespace,
      traits,
      schemaRef
    }), "sim");
    simAdapter2 = /* @__PURE__ */ __name((namespace, name, traits, schemaRef) => Schema3.assign(new SimpleSchema2(), {
      name,
      namespace,
      traits,
      schemaRef
    }), "simAdapter");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/schemas/sentinels.js
var SCHEMA2;
var init_sentinels3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/schemas/sentinels.js"() {
    SCHEMA2 = {
      BLOB: 21,
      STREAMING_BLOB: 42,
      BOOLEAN: 2,
      STRING: 0,
      NUMERIC: 1,
      BIG_INTEGER: 17,
      BIG_DECIMAL: 19,
      DOCUMENT: 15,
      TIMESTAMP_DEFAULT: 4,
      TIMESTAMP_DATE_TIME: 5,
      TIMESTAMP_HTTP_DATE: 6,
      TIMESTAMP_EPOCH_SECONDS: 7,
      LIST_MODIFIER: 64,
      MAP_MODIFIER: 128
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/TypeRegistry.js
var TypeRegistry3;
var init_TypeRegistry3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/TypeRegistry.js"() {
    TypeRegistry3 = class _TypeRegistry {
      static {
        __name(this, "TypeRegistry");
      }
      namespace;
      schemas;
      exceptions;
      static registries = /* @__PURE__ */ new Map();
      constructor(namespace, schemas = /* @__PURE__ */ new Map(), exceptions = /* @__PURE__ */ new Map()) {
        this.namespace = namespace;
        this.schemas = schemas;
        this.exceptions = exceptions;
      }
      static for(namespace) {
        if (!_TypeRegistry.registries.has(namespace)) {
          _TypeRegistry.registries.set(namespace, new _TypeRegistry(namespace));
        }
        return _TypeRegistry.registries.get(namespace);
      }
      copyFrom(other) {
        const { schemas, exceptions } = this;
        for (const [k32, v] of other.schemas) {
          if (!schemas.has(k32)) {
            schemas.set(k32, v);
          }
        }
        for (const [k32, v] of other.exceptions) {
          if (!exceptions.has(k32)) {
            exceptions.set(k32, v);
          }
        }
      }
      register(shapeId, schema) {
        const qualifiedName = this.normalizeShapeId(shapeId);
        for (const r32 of [this, _TypeRegistry.for(qualifiedName.split("#")[0])]) {
          r32.schemas.set(qualifiedName, schema);
        }
      }
      getSchema(shapeId) {
        const id = this.normalizeShapeId(shapeId);
        if (!this.schemas.has(id)) {
          if (!shapeId.includes("#")) {
            const suffix = "#" + shapeId;
            const candidates = [];
            for (const [shapeId2, schema] of this.schemas.entries()) {
              if (shapeId2.endsWith(suffix)) {
                candidates.push(schema);
              }
            }
            if (candidates.length === 1) {
              return candidates[0];
            }
          }
          throw new Error(`@smithy/core/schema - schema not found for ${id}`);
        }
        return this.schemas.get(id);
      }
      registerError(es, ctor) {
        const $error = es;
        const ns = $error[1];
        for (const r32 of [this, _TypeRegistry.for(ns)]) {
          r32.schemas.set(ns + "#" + $error[2], $error);
          r32.exceptions.set($error, ctor);
        }
      }
      getErrorCtor(es) {
        const $error = es;
        if (this.exceptions.has($error)) {
          return this.exceptions.get($error);
        }
        const registry = _TypeRegistry.for($error[1]);
        return registry.exceptions.get($error);
      }
      getBaseException() {
        for (const exceptionKey of this.exceptions.keys()) {
          if (Array.isArray(exceptionKey)) {
            const [, ns, name] = exceptionKey;
            const id = ns + "#" + name;
            if (id.startsWith("smithy.ts.sdk.synthetic.") && id.endsWith("ServiceException")) {
              return exceptionKey;
            }
          }
        }
        return void 0;
      }
      find(predicate) {
        for (const schema of this.schemas.values()) {
          if (predicate(schema)) {
            return schema;
          }
        }
        return void 0;
      }
      clear() {
        this.schemas.clear();
        this.exceptions.clear();
      }
      normalizeShapeId(shapeId) {
        if (shapeId.includes("#")) {
          return shapeId;
        }
        return this.namespace + "#" + shapeId;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/index.js
var schema_exports2 = {};
__export(schema_exports2, {
  ErrorSchema: () => ErrorSchema2,
  ListSchema: () => ListSchema2,
  MapSchema: () => MapSchema2,
  NormalizedSchema: () => NormalizedSchema3,
  OperationSchema: () => OperationSchema2,
  SCHEMA: () => SCHEMA2,
  Schema: () => Schema3,
  SimpleSchema: () => SimpleSchema2,
  StructureSchema: () => StructureSchema2,
  TypeRegistry: () => TypeRegistry3,
  deref: () => deref3,
  deserializerMiddlewareOption: () => deserializerMiddlewareOption3,
  error: () => error3,
  getSchemaSerdePlugin: () => getSchemaSerdePlugin2,
  isStaticSchema: () => isStaticSchema3,
  list: () => list2,
  map: () => map2,
  op: () => op2,
  operation: () => operation2,
  serializerMiddlewareOption: () => serializerMiddlewareOption5,
  sim: () => sim2,
  simAdapter: () => simAdapter2,
  simpleSchemaCacheN: () => simpleSchemaCacheN3,
  simpleSchemaCacheS: () => simpleSchemaCacheS3,
  struct: () => struct2,
  traitsCache: () => traitsCache3,
  translateTraits: () => translateTraits3
});
var init_schema6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/schema/index.js"() {
    init_deref3();
    init_getSchemaSerdePlugin3();
    init_ListSchema3();
    init_MapSchema3();
    init_OperationSchema3();
    init_operation3();
    init_ErrorSchema3();
    init_NormalizedSchema3();
    init_Schema3();
    init_SimpleSchema3();
    init_StructureSchema3();
    init_sentinels3();
    init_translateTraits3();
    init_TypeRegistry3();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/schemaLogFilter.js
function schemaLogFilter(schema, data3) {
  if (data3 == null) {
    return data3;
  }
  const ns = NormalizedSchema3.of(schema);
  if (ns.getMergedTraits().sensitive) {
    return SENSITIVE_STRING;
  }
  if (ns.isListSchema()) {
    const isSensitive = !!ns.getValueSchema().getMergedTraits().sensitive;
    if (isSensitive) {
      return SENSITIVE_STRING;
    }
  } else if (ns.isMapSchema()) {
    const isSensitive = !!ns.getKeySchema().getMergedTraits().sensitive || !!ns.getValueSchema().getMergedTraits().sensitive;
    if (isSensitive) {
      return SENSITIVE_STRING;
    }
  } else if (ns.isStructSchema() && typeof data3 === "object") {
    const object = data3;
    const newObject = {};
    for (const [member7, memberNs] of ns.structIterator()) {
      if (object[member7] != null) {
        newObject[member7] = schemaLogFilter(memberNs, object[member7]);
      }
    }
    return newObject;
  }
  return data3;
}
var SENSITIVE_STRING;
var init_schemaLogFilter = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/schemaLogFilter.js"() {
    init_schema6();
    SENSITIVE_STRING = "***SensitiveInformation***";
    __name(schemaLogFilter, "schemaLogFilter");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/command.js
var import_types41, Command, ClassBuilder;
var init_command = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/command.js"() {
    import_types41 = __toESM(require_dist_cjs());
    init_MiddlewareStack();
    init_schemaLogFilter();
    Command = class {
      static {
        __name(this, "Command");
      }
      middlewareStack = constructStack();
      schema;
      static classBuilder() {
        return new ClassBuilder();
      }
      resolveMiddlewareWithContext(clientStack, configuration, options, { middlewareFn, clientName, commandName, inputFilterSensitiveLog, outputFilterSensitiveLog, smithyContext, additionalContext, CommandCtor }) {
        for (const mw of middlewareFn.bind(this)(CommandCtor, clientStack, configuration, options)) {
          this.middlewareStack.use(mw);
        }
        const stack = clientStack.concat(this.middlewareStack);
        const { logger: logger5 } = configuration;
        const handlerExecutionContext = {
          logger: logger5,
          clientName,
          commandName,
          inputFilterSensitiveLog,
          outputFilterSensitiveLog,
          [import_types41.SMITHY_CONTEXT_KEY]: {
            commandInstance: this,
            ...smithyContext
          },
          ...additionalContext
        };
        const { requestHandler } = configuration;
        let requestOptions = options ?? {};
        if (smithyContext.eventStream) {
          requestOptions = {
            isEventStream: true,
            ...requestOptions
          };
        }
        return stack.resolve((request4) => requestHandler.handle(request4.request, requestOptions), handlerExecutionContext);
      }
    };
    ClassBuilder = class {
      static {
        __name(this, "ClassBuilder");
      }
      _init = /* @__PURE__ */ __name(() => {
      }, "_init");
      _ep = {};
      _middlewareFn = /* @__PURE__ */ __name(() => [], "_middlewareFn");
      _commandName = "";
      _clientName = "";
      _additionalContext = {};
      _smithyContext = {};
      _inputFilterSensitiveLog = void 0;
      _outputFilterSensitiveLog = void 0;
      _serializer = null;
      _deserializer = null;
      _operationSchema;
      init(cb) {
        this._init = cb;
      }
      ep(endpointParameterInstructions) {
        this._ep = endpointParameterInstructions;
        return this;
      }
      m(middlewareSupplier) {
        this._middlewareFn = middlewareSupplier;
        return this;
      }
      s(service, operation3, smithyContext = {}) {
        this._smithyContext = {
          service,
          operation: operation3,
          ...smithyContext
        };
        return this;
      }
      c(additionalContext = {}) {
        this._additionalContext = additionalContext;
        return this;
      }
      n(clientName, commandName) {
        this._clientName = clientName;
        this._commandName = commandName;
        return this;
      }
      f(inputFilter = (_) => _, outputFilter = (_) => _) {
        this._inputFilterSensitiveLog = inputFilter;
        this._outputFilterSensitiveLog = outputFilter;
        return this;
      }
      ser(serializer) {
        this._serializer = serializer;
        return this;
      }
      de(deserializer) {
        this._deserializer = deserializer;
        return this;
      }
      sc(operation3) {
        this._operationSchema = operation3;
        this._smithyContext.operationSchema = operation3;
        return this;
      }
      build() {
        const closure = this;
        let CommandRef;
        return CommandRef = class extends Command {
          static {
            __name(this, "CommandRef");
          }
          input;
          static getEndpointParameterInstructions() {
            return closure._ep;
          }
          constructor(...[input]) {
            super();
            this.input = input ?? {};
            closure._init(this);
            this.schema = closure._operationSchema;
          }
          resolveMiddleware(stack, configuration, options) {
            const op3 = closure._operationSchema;
            const input = op3?.[4] ?? op3?.input;
            const output = op3?.[5] ?? op3?.output;
            return this.resolveMiddlewareWithContext(stack, configuration, options, {
              CommandCtor: CommandRef,
              middlewareFn: closure._middlewareFn,
              clientName: closure._clientName,
              commandName: closure._commandName,
              inputFilterSensitiveLog: closure._inputFilterSensitiveLog ?? (op3 ? schemaLogFilter.bind(null, input) : (_) => _),
              outputFilterSensitiveLog: closure._outputFilterSensitiveLog ?? (op3 ? schemaLogFilter.bind(null, output) : (_) => _),
              smithyContext: closure._smithyContext,
              additionalContext: closure._additionalContext
            });
          }
          serialize = closure._serializer;
          deserialize = closure._deserializer;
        };
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/constants.js
var SENSITIVE_STRING2;
var init_constants6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/constants.js"() {
    SENSITIVE_STRING2 = "***SensitiveInformation***";
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/create-aggregated-client.js
var createAggregatedClient19;
var init_create_aggregated_client = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/create-aggregated-client.js"() {
    createAggregatedClient19 = /* @__PURE__ */ __name((commands32, Client3, options) => {
      for (const [command, CommandCtor] of Object.entries(commands32)) {
        const methodImpl = /* @__PURE__ */ __name(async function(args, optionsOrCb, cb) {
          const command2 = new CommandCtor(args);
          if (typeof optionsOrCb === "function") {
            this.send(command2, optionsOrCb);
          } else if (typeof cb === "function") {
            if (typeof optionsOrCb !== "object")
              throw new Error(`Expected http options but got ${typeof optionsOrCb}`);
            this.send(command2, optionsOrCb || {}, cb);
          } else {
            return this.send(command2, optionsOrCb);
          }
        }, "methodImpl");
        const methodName = (command[0].toLowerCase() + command.slice(1)).replace(/Command$/, "");
        Client3.prototype[methodName] = methodImpl;
      }
      const { paginators = {}, waiters = {} } = options ?? {};
      for (const [paginatorName, paginatorFn] of Object.entries(paginators)) {
        if (Client3.prototype[paginatorName] === void 0) {
          Client3.prototype[paginatorName] = function(commandInput = {}, paginationConfiguration, ...rest) {
            return paginatorFn({
              ...paginationConfiguration,
              client: this
            }, commandInput, ...rest);
          };
        }
      }
      for (const [waiterName, waiterFn] of Object.entries(waiters)) {
        if (Client3.prototype[waiterName] === void 0) {
          Client3.prototype[waiterName] = async function(commandInput = {}, waiterConfiguration, ...rest) {
            let config2 = waiterConfiguration;
            if (typeof waiterConfiguration === "number") {
              config2 = {
                maxWaitTime: waiterConfiguration
              };
            }
            return waiterFn({
              ...config2,
              client: this
            }, commandInput, ...rest);
          };
        }
      }
    }, "createAggregatedClient");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/exceptions.js
var ServiceException, decorateServiceException8;
var init_exceptions = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/exceptions.js"() {
    ServiceException = class _ServiceException extends Error {
      static {
        __name(this, "ServiceException");
      }
      $fault;
      $response;
      $retryable;
      $metadata;
      constructor(options) {
        super(options.message);
        Object.setPrototypeOf(this, Object.getPrototypeOf(this).constructor.prototype);
        this.name = options.name;
        this.$fault = options.$fault;
        this.$metadata = options.$metadata;
      }
      static isInstance(value) {
        if (!value)
          return false;
        const candidate = value;
        return _ServiceException.prototype.isPrototypeOf(candidate) || Boolean(candidate.$fault) && Boolean(candidate.$metadata) && (candidate.$fault === "client" || candidate.$fault === "server");
      }
      static [Symbol.hasInstance](instance) {
        if (!instance)
          return false;
        const candidate = instance;
        if (this === _ServiceException) {
          return _ServiceException.isInstance(instance);
        }
        if (_ServiceException.isInstance(instance)) {
          if (candidate.name && this.name) {
            return this.prototype.isPrototypeOf(instance) || candidate.name === this.name;
          }
          return this.prototype.isPrototypeOf(instance);
        }
        return false;
      }
    };
    decorateServiceException8 = /* @__PURE__ */ __name((exception, additions = {}) => {
      Object.entries(additions).filter(([, v]) => v !== void 0).forEach(([k32, v]) => {
        if (exception[k32] == void 0 || exception[k32] === "") {
          exception[k32] = v;
        }
      });
      const message2 = exception.message || exception.Message || "UnknownError";
      exception.message = message2;
      delete exception.Message;
      return exception;
    }, "decorateServiceException");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/default-error-handler.js
var throwDefaultError, withBaseException, deserializeMetadata;
var init_default_error_handler = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/default-error-handler.js"() {
    init_exceptions();
    throwDefaultError = /* @__PURE__ */ __name(({ output, parsedBody, exceptionCtor, errorCode }) => {
      const $metadata = deserializeMetadata(output);
      const statusCode = $metadata.httpStatusCode ? $metadata.httpStatusCode + "" : void 0;
      const response = new exceptionCtor({
        name: parsedBody?.code || parsedBody?.Code || errorCode || statusCode || "UnknownError",
        $fault: "client",
        $metadata
      });
      throw decorateServiceException8(response, parsedBody);
    }, "throwDefaultError");
    withBaseException = /* @__PURE__ */ __name((ExceptionCtor) => {
      return ({ output, parsedBody, errorCode }) => {
        throwDefaultError({ output, parsedBody, exceptionCtor: ExceptionCtor, errorCode });
      };
    }, "withBaseException");
    deserializeMetadata = /* @__PURE__ */ __name((output) => ({
      httpStatusCode: output.statusCode,
      requestId: output.headers["x-amzn-requestid"] ?? output.headers["x-amzn-request-id"] ?? output.headers["x-amz-request-id"],
      extendedRequestId: output.headers["x-amz-id-2"],
      cfId: output.headers["x-amz-cf-id"]
    }), "deserializeMetadata");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/defaults-mode.js
var loadConfigsForDefaultMode19;
var init_defaults_mode = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/defaults-mode.js"() {
    loadConfigsForDefaultMode19 = /* @__PURE__ */ __name((mode) => {
      switch (mode) {
        case "standard":
          return {
            retryMode: "standard",
            connectionTimeout: 3100
          };
        case "in-region":
          return {
            retryMode: "standard",
            connectionTimeout: 1100
          };
        case "cross-region":
          return {
            retryMode: "standard",
            connectionTimeout: 3100
          };
        case "mobile":
          return {
            retryMode: "standard",
            connectionTimeout: 3e4
          };
        default:
          return {};
      }
    }, "loadConfigsForDefaultMode");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/emitWarningIfUnsupportedVersion.js
var warningEmitted, emitWarningIfUnsupportedVersion28;
var init_emitWarningIfUnsupportedVersion10 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/emitWarningIfUnsupportedVersion.js"() {
    warningEmitted = false;
    emitWarningIfUnsupportedVersion28 = /* @__PURE__ */ __name((version) => {
      if (version && !warningEmitted && parseInt(version.substring(1, version.indexOf("."))) < 16) {
        warningEmitted = true;
      }
    }, "emitWarningIfUnsupportedVersion");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/extensions/checksum.js
var import_types42, knownAlgorithms, getChecksumConfiguration, resolveChecksumRuntimeConfig;
var init_checksum = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/extensions/checksum.js"() {
    import_types42 = __toESM(require_dist_cjs());
    knownAlgorithms = Object.values(import_types42.AlgorithmId);
    getChecksumConfiguration = /* @__PURE__ */ __name((runtimeConfig) => {
      const checksumAlgorithms = [];
      for (const id in import_types42.AlgorithmId) {
        const algorithmId = import_types42.AlgorithmId[id];
        if (runtimeConfig[algorithmId] === void 0) {
          continue;
        }
        checksumAlgorithms.push({
          algorithmId: /* @__PURE__ */ __name(() => algorithmId, "algorithmId"),
          checksumConstructor: /* @__PURE__ */ __name(() => runtimeConfig[algorithmId], "checksumConstructor")
        });
      }
      for (const [id, ChecksumCtor] of Object.entries(runtimeConfig.checksumAlgorithms ?? {})) {
        checksumAlgorithms.push({
          algorithmId: /* @__PURE__ */ __name(() => id, "algorithmId"),
          checksumConstructor: /* @__PURE__ */ __name(() => ChecksumCtor, "checksumConstructor")
        });
      }
      return {
        addChecksumAlgorithm(algo) {
          runtimeConfig.checksumAlgorithms = runtimeConfig.checksumAlgorithms ?? {};
          const id = algo.algorithmId();
          const ctor = algo.checksumConstructor();
          if (knownAlgorithms.includes(id)) {
            runtimeConfig.checksumAlgorithms[id.toUpperCase()] = ctor;
          } else {
            runtimeConfig.checksumAlgorithms[id] = ctor;
          }
          checksumAlgorithms.push(algo);
        },
        checksumAlgorithms() {
          return checksumAlgorithms;
        }
      };
    }, "getChecksumConfiguration");
    resolveChecksumRuntimeConfig = /* @__PURE__ */ __name((clientConfig) => {
      const runtimeConfig = {};
      clientConfig.checksumAlgorithms().forEach((checksumAlgorithm) => {
        const id = checksumAlgorithm.algorithmId();
        if (knownAlgorithms.includes(id)) {
          runtimeConfig[id] = checksumAlgorithm.checksumConstructor();
        }
      });
      return runtimeConfig;
    }, "resolveChecksumRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/extensions/retry.js
var getRetryConfiguration, resolveRetryRuntimeConfig;
var init_retry2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/extensions/retry.js"() {
    getRetryConfiguration = /* @__PURE__ */ __name((runtimeConfig) => {
      return {
        setRetryStrategy(retryStrategy) {
          runtimeConfig.retryStrategy = retryStrategy;
        },
        retryStrategy() {
          return runtimeConfig.retryStrategy;
        }
      };
    }, "getRetryConfiguration");
    resolveRetryRuntimeConfig = /* @__PURE__ */ __name((retryStrategyConfiguration) => {
      const runtimeConfig = {};
      runtimeConfig.retryStrategy = retryStrategyConfiguration.retryStrategy();
      return runtimeConfig;
    }, "resolveRetryRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/extensions/defaultExtensionConfiguration.js
var getDefaultExtensionConfiguration19, getDefaultClientConfiguration, resolveDefaultRuntimeConfig19;
var init_defaultExtensionConfiguration = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/extensions/defaultExtensionConfiguration.js"() {
    init_checksum();
    init_retry2();
    getDefaultExtensionConfiguration19 = /* @__PURE__ */ __name((runtimeConfig) => {
      return Object.assign(getChecksumConfiguration(runtimeConfig), getRetryConfiguration(runtimeConfig));
    }, "getDefaultExtensionConfiguration");
    getDefaultClientConfiguration = getDefaultExtensionConfiguration19;
    resolveDefaultRuntimeConfig19 = /* @__PURE__ */ __name((config2) => {
      return Object.assign(resolveChecksumRuntimeConfig(config2), resolveRetryRuntimeConfig(config2));
    }, "resolveDefaultRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/get-array-if-single-item.js
var getArrayIfSingleItem;
var init_get_array_if_single_item = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/get-array-if-single-item.js"() {
    getArrayIfSingleItem = /* @__PURE__ */ __name((mayBeArray) => Array.isArray(mayBeArray) ? mayBeArray : [mayBeArray], "getArrayIfSingleItem");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/get-value-from-text-node.js
var getValueFromTextNode12;
var init_get_value_from_text_node = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/get-value-from-text-node.js"() {
    getValueFromTextNode12 = /* @__PURE__ */ __name((obj) => {
      const textNodeName = "#text";
      for (const key in obj) {
        if (obj.hasOwnProperty(key) && obj[key][textNodeName] !== void 0) {
          obj[key] = obj[key][textNodeName];
        } else if (typeof obj[key] === "object" && obj[key] !== null) {
          obj[key] = getValueFromTextNode12(obj[key]);
        }
      }
      return obj;
    }, "getValueFromTextNode");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/is-serializable-header-value.js
var isSerializableHeaderValue;
var init_is_serializable_header_value = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/is-serializable-header-value.js"() {
    isSerializableHeaderValue = /* @__PURE__ */ __name((value) => {
      return value != null;
    }, "isSerializableHeaderValue");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/NoOpLogger.js
var NoOpLogger20;
var init_NoOpLogger2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/NoOpLogger.js"() {
    NoOpLogger20 = class {
      static {
        __name(this, "NoOpLogger");
      }
      trace() {
      }
      debug() {
      }
      info() {
      }
      warn() {
      }
      error() {
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/object-mapping.js
function map3(arg0, arg1, arg2) {
  let target;
  let filter;
  let instructions;
  if (typeof arg1 === "undefined" && typeof arg2 === "undefined") {
    target = {};
    instructions = arg0;
  } else {
    target = arg0;
    if (typeof arg1 === "function") {
      filter = arg1;
      instructions = arg2;
      return mapWithFilter(target, filter, instructions);
    } else {
      instructions = arg1;
    }
  }
  for (const key of Object.keys(instructions)) {
    if (!Array.isArray(instructions[key])) {
      target[key] = instructions[key];
      continue;
    }
    applyInstruction(target, null, instructions, key);
  }
  return target;
}
var convertMap, take, mapWithFilter, applyInstruction, nonNullish, pass;
var init_object_mapping = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/object-mapping.js"() {
    __name(map3, "map");
    convertMap = /* @__PURE__ */ __name((target) => {
      const output = {};
      for (const [k32, v] of Object.entries(target || {})) {
        output[k32] = [, v];
      }
      return output;
    }, "convertMap");
    take = /* @__PURE__ */ __name((source, instructions) => {
      const out = {};
      for (const key in instructions) {
        applyInstruction(out, source, instructions, key);
      }
      return out;
    }, "take");
    mapWithFilter = /* @__PURE__ */ __name((target, filter, instructions) => {
      return map3(target, Object.entries(instructions).reduce((_instructions, [key, value]) => {
        if (Array.isArray(value)) {
          _instructions[key] = value;
        } else {
          if (typeof value === "function") {
            _instructions[key] = [filter, value()];
          } else {
            _instructions[key] = [filter, value];
          }
        }
        return _instructions;
      }, {}));
    }, "mapWithFilter");
    applyInstruction = /* @__PURE__ */ __name((target, source, instructions, targetKey) => {
      if (source !== null) {
        let instruction = instructions[targetKey];
        if (typeof instruction === "function") {
          instruction = [, instruction];
        }
        const [filter2 = nonNullish, valueFn = pass, sourceKey = targetKey] = instruction;
        if (typeof filter2 === "function" && filter2(source[sourceKey]) || typeof filter2 !== "function" && !!filter2) {
          target[targetKey] = valueFn(source[sourceKey]);
        }
        return;
      }
      let [filter, value] = instructions[targetKey];
      if (typeof value === "function") {
        let _value;
        const defaultFilterPassed = filter === void 0 && (_value = value()) != null;
        const customFilterPassed = typeof filter === "function" && !!filter(void 0) || typeof filter !== "function" && !!filter;
        if (defaultFilterPassed) {
          target[targetKey] = _value;
        } else if (customFilterPassed) {
          target[targetKey] = value();
        }
      } else {
        const defaultFilterPassed = filter === void 0 && value != null;
        const customFilterPassed = typeof filter === "function" && !!filter(value) || typeof filter !== "function" && !!filter;
        if (defaultFilterPassed || customFilterPassed) {
          target[targetKey] = value;
        }
      }
    }, "applyInstruction");
    nonNullish = /* @__PURE__ */ __name((_) => _ != null, "nonNullish");
    pass = /* @__PURE__ */ __name((_) => _, "pass");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/ser-utils.js
var serializeFloat, serializeDateTime;
var init_ser_utils = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/ser-utils.js"() {
    serializeFloat = /* @__PURE__ */ __name((value) => {
      if (value !== value) {
        return "NaN";
      }
      switch (value) {
        case Infinity:
          return "Infinity";
        case -Infinity:
          return "-Infinity";
        default:
          return value;
      }
    }, "serializeFloat");
    serializeDateTime = /* @__PURE__ */ __name((date7) => date7.toISOString().replace(".000Z", "Z"), "serializeDateTime");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/serde-json.js
var _json;
var init_serde_json = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/serde-json.js"() {
    _json = /* @__PURE__ */ __name((obj) => {
      if (obj == null) {
        return {};
      }
      if (Array.isArray(obj)) {
        return obj.filter((_) => _ != null).map(_json);
      }
      if (typeof obj === "object") {
        const target = {};
        for (const key of Object.keys(obj)) {
          if (obj[key] == null) {
            continue;
          }
          target[key] = _json(obj[key]);
        }
        return target;
      }
      return obj;
    }, "_json");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/index.js
var client_exports9 = {};
__export(client_exports9, {
  AlgorithmId: () => import_types42.AlgorithmId,
  Client: () => Client,
  Command: () => Command,
  NoOpLogger: () => NoOpLogger20,
  SENSITIVE_STRING: () => SENSITIVE_STRING2,
  ServiceException: () => ServiceException,
  WaiterState: () => WaiterState,
  _json: () => _json,
  checkExceptions: () => checkExceptions,
  constructStack: () => constructStack,
  convertMap: () => convertMap,
  createAggregatedClient: () => createAggregatedClient19,
  createWaiter: () => createWaiter,
  decorateServiceException: () => decorateServiceException8,
  emitWarningIfUnsupportedVersion: () => emitWarningIfUnsupportedVersion28,
  getArrayIfSingleItem: () => getArrayIfSingleItem,
  getChecksumConfiguration: () => getChecksumConfiguration,
  getDefaultClientConfiguration: () => getDefaultClientConfiguration,
  getDefaultExtensionConfiguration: () => getDefaultExtensionConfiguration19,
  getRetryConfiguration: () => getRetryConfiguration,
  getSmithyContext: () => getSmithyContext26,
  getValueFromTextNode: () => getValueFromTextNode12,
  invalidFunction: () => invalidFunction,
  invalidProvider: () => invalidProvider,
  isSerializableHeaderValue: () => isSerializableHeaderValue,
  loadConfigsForDefaultMode: () => loadConfigsForDefaultMode19,
  map: () => map3,
  normalizeProvider: () => normalizeProvider22,
  resolveChecksumRuntimeConfig: () => resolveChecksumRuntimeConfig,
  resolveDefaultRuntimeConfig: () => resolveDefaultRuntimeConfig19,
  resolveRetryRuntimeConfig: () => resolveRetryRuntimeConfig,
  schemaLogFilter: () => schemaLogFilter,
  serializeDateTime: () => serializeDateTime,
  serializeFloat: () => serializeFloat,
  take: () => take,
  throwDefaultError: () => throwDefaultError,
  waiterServiceDefaults: () => waiterServiceDefaults,
  withBaseException: () => withBaseException
});
var init_client12 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/client/index.js"() {
    init_MiddlewareStack();
    init_getSmithyContext3();
    init_normalizeProvider4();
    init_invalidFunction();
    init_invalidProvider();
    init_createWaiter();
    init_waiter();
    init_client11();
    init_command();
    init_constants6();
    init_create_aggregated_client();
    init_default_error_handler();
    init_defaults_mode();
    init_emitWarningIfUnsupportedVersion10();
    init_exceptions();
    init_defaultExtensionConfiguration();
    init_checksum();
    init_retry2();
    init_get_array_if_single_item();
    init_get_value_from_text_node();
    init_is_serializable_header_value();
    init_NoOpLogger2();
    init_object_mapping();
    init_schemaLogFilter();
    init_ser_utils();
    init_serde_json();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/service-error-classification/constants.js
var CLOCK_SKEW_ERROR_CODES2, THROTTLING_ERROR_CODES2, TRANSIENT_ERROR_CODES2, TRANSIENT_ERROR_STATUS_CODES2, NODEJS_TIMEOUT_ERROR_CODES2, NODEJS_NETWORK_ERROR_CODES2;
var init_constants7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/service-error-classification/constants.js"() {
    CLOCK_SKEW_ERROR_CODES2 = [
      "AuthFailure",
      "InvalidSignatureException",
      "RequestExpired",
      "RequestInTheFuture",
      "RequestTimeTooSkewed",
      "SignatureDoesNotMatch"
    ];
    THROTTLING_ERROR_CODES2 = [
      "BandwidthLimitExceeded",
      "EC2ThrottledException",
      "LimitExceededException",
      "PriorRequestNotComplete",
      "ProvisionedThroughputExceededException",
      "RequestLimitExceeded",
      "RequestThrottled",
      "RequestThrottledException",
      "SlowDown",
      "ThrottledException",
      "Throttling",
      "ThrottlingException",
      "TooManyRequestsException",
      "TransactionInProgressException"
    ];
    TRANSIENT_ERROR_CODES2 = ["TimeoutError", "RequestTimeout", "RequestTimeoutException"];
    TRANSIENT_ERROR_STATUS_CODES2 = [500, 502, 503, 504];
    NODEJS_TIMEOUT_ERROR_CODES2 = ["ECONNRESET", "ECONNREFUSED", "EPIPE", "ETIMEDOUT"];
    NODEJS_NETWORK_ERROR_CODES2 = ["EHOSTUNREACH", "ENETUNREACH", "ENOTFOUND"];
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/service-error-classification/service-error-classification.js
function isNodeJsHttp2TransientError2(error4) {
  return error4.code === "ERR_HTTP2_STREAM_ERROR" && error4.message.includes("NGHTTP2_REFUSED_STREAM");
}
var isRetryableByTrait2, isClockSkewError2, isClockSkewCorrectedError2, isBrowserNetworkError2, isThrottlingError2, isTransientError2, isServerError2;
var init_service_error_classification2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/service-error-classification/service-error-classification.js"() {
    init_constants7();
    isRetryableByTrait2 = /* @__PURE__ */ __name((error4) => error4?.$retryable !== void 0, "isRetryableByTrait");
    isClockSkewError2 = /* @__PURE__ */ __name((error4) => CLOCK_SKEW_ERROR_CODES2.includes(error4.name), "isClockSkewError");
    isClockSkewCorrectedError2 = /* @__PURE__ */ __name((error4) => error4.$metadata?.clockSkewCorrected, "isClockSkewCorrectedError");
    isBrowserNetworkError2 = /* @__PURE__ */ __name((error4) => {
      const errorMessages = /* @__PURE__ */ new Set([
        "Failed to fetch",
        "NetworkError when attempting to fetch resource",
        "The Internet connection appears to be offline",
        "Load failed",
        "Network request failed"
      ]);
      const isValid = error4 && error4 instanceof TypeError;
      if (!isValid) {
        return false;
      }
      return errorMessages.has(error4.message);
    }, "isBrowserNetworkError");
    isThrottlingError2 = /* @__PURE__ */ __name((error4) => error4.$metadata?.httpStatusCode === 429 || THROTTLING_ERROR_CODES2.includes(error4.name) || error4.$retryable?.throttling == true, "isThrottlingError");
    isTransientError2 = /* @__PURE__ */ __name((error4, depth = 0) => isRetryableByTrait2(error4) || isClockSkewCorrectedError2(error4) || error4.name === "InvalidSignatureException" && error4.message?.includes("Signature expired") || TRANSIENT_ERROR_CODES2.includes(error4.name) || NODEJS_TIMEOUT_ERROR_CODES2.includes(error4?.code || "") || NODEJS_NETWORK_ERROR_CODES2.includes(error4?.code || "") || TRANSIENT_ERROR_STATUS_CODES2.includes(error4.$metadata?.httpStatusCode || 0) || isBrowserNetworkError2(error4) || isNodeJsHttp2TransientError2(error4) || error4.cause !== void 0 && depth <= 10 && isTransientError2(error4.cause, depth + 1), "isTransientError");
    isServerError2 = /* @__PURE__ */ __name((error4) => {
      if (error4.$metadata?.httpStatusCode !== void 0) {
        const statusCode = error4.$metadata.httpStatusCode;
        if (500 <= statusCode && statusCode <= 599 && !isTransientError2(error4)) {
          return true;
        }
        return false;
      }
      return false;
    }, "isServerError");
    __name(isNodeJsHttp2TransientError2, "isNodeJsHttp2TransientError");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/constants.js
var DEFAULT_RETRY_DELAY_BASE2, MAXIMUM_RETRY_DELAY2, THROTTLING_RETRY_DELAY_BASE2, INITIAL_RETRY_TOKENS2, RETRY_COST2, TIMEOUT_RETRY_COST2, NO_RETRY_INCREMENT2, INVOCATION_ID_HEADER2, REQUEST_HEADER2;
var init_constants8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/constants.js"() {
    DEFAULT_RETRY_DELAY_BASE2 = 100;
    MAXIMUM_RETRY_DELAY2 = 20 * 1e3;
    THROTTLING_RETRY_DELAY_BASE2 = 500;
    INITIAL_RETRY_TOKENS2 = 500;
    RETRY_COST2 = 5;
    TIMEOUT_RETRY_COST2 = 10;
    NO_RETRY_INCREMENT2 = 1;
    INVOCATION_ID_HEADER2 = "amz-sdk-invocation-id";
    REQUEST_HEADER2 = "amz-sdk-request";
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/parseRetryAfterHeader.js
function parseRetryAfterHeader2(response, logger5) {
  if (!HttpResponse11.isInstance(response)) {
    return;
  }
  for (const header of Object.keys(response.headers)) {
    const h32 = header.toLowerCase();
    if (h32 === "retry-after") {
      const retryAfter = response.headers[header];
      let retryAfterSeconds = NaN;
      if (retryAfter.endsWith("GMT")) {
        try {
          const date7 = parseRfc7231DateTime4(retryAfter);
          retryAfterSeconds = (date7.getTime() - Date.now()) / 1e3;
        } catch (e32) {
          logger5?.trace?.("Failed to parse retry-after header");
          logger5?.trace?.(e32);
        }
      } else if (retryAfter.match(/ GMT, ((\d+)|(\d+\.\d+))$/)) {
        retryAfterSeconds = Number(retryAfter.match(/ GMT, ([\d.]+)$/)?.[1]);
      } else if (retryAfter.match(/^((\d+)|(\d+\.\d+))$/)) {
        retryAfterSeconds = Number(retryAfter);
      } else if (Date.parse(retryAfter) >= Date.now()) {
        retryAfterSeconds = (Date.parse(retryAfter) - Date.now()) / 1e3;
      }
      if (isNaN(retryAfterSeconds)) {
        return;
      }
      return new Date(Date.now() + retryAfterSeconds * 1e3);
    } else if (h32 === "x-amz-retry-after") {
      const v = response.headers[header];
      const backoffMilliseconds = Number(v);
      if (isNaN(backoffMilliseconds)) {
        logger5?.trace?.(`Failed to parse x-amz-retry-after=${v}`);
        return;
      }
      return new Date(Date.now() + backoffMilliseconds);
    }
  }
}
function getRetryAfterHint2(response, logger5) {
  return parseRetryAfterHeader2(response, logger5);
}
var init_parseRetryAfterHeader2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/parseRetryAfterHeader.js"() {
    init_protocols11();
    init_serde4();
    __name(parseRetryAfterHeader2, "parseRetryAfterHeader");
    __name(getRetryAfterHint2, "getRetryAfterHint");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/util.js
var asSdkError2;
var init_util6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/util.js"() {
    asSdkError2 = /* @__PURE__ */ __name((error4) => {
      if (error4 instanceof Error)
        return error4;
      if (error4 instanceof Object)
        return Object.assign(new Error(), error4);
      if (typeof error4 === "string")
        return new Error(error4);
      return new Error(`AWS SDK error wrapper for ${error4}`);
    }, "asSdkError");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/retryMiddleware.js
function bindRetryMiddleware2(isStreamingPayload3) {
  return (options) => (next, context) => async (args) => {
    let retryStrategy = await options.retryStrategy();
    const maxAttempts = await options.maxAttempts();
    if (isRetryStrategyV22(retryStrategy)) {
      retryStrategy = retryStrategy;
      let retryToken = await retryStrategy.acquireInitialRetryToken((context["partition_id"] ?? "") + (context.__retryLongPoll ? ":longpoll" : ""));
      let lastError = new Error();
      let attempts = 0;
      let totalRetryDelay = 0;
      const { request: request4 } = args;
      const isRequest = HttpRequest22.isInstance(request4);
      if (isRequest) {
        request4.headers[INVOCATION_ID_HEADER2] = v43();
      }
      while (true) {
        try {
          if (isRequest) {
            request4.headers[REQUEST_HEADER2] = `attempt=${attempts + 1}; max=${maxAttempts}`;
          }
          const { response, output } = await next(args);
          retryStrategy.recordSuccess(retryToken);
          output.$metadata.attempts = attempts + 1;
          output.$metadata.totalRetryDelay = totalRetryDelay;
          return { response, output };
        } catch (e32) {
          const retryErrorInfo = getRetryErrorInfo2(e32, options.logger);
          lastError = asSdkError2(e32);
          if (isRequest && isStreamingPayload3(request4)) {
            (context.logger instanceof NoOpLogger20 ? console : context.logger)?.warn("An error was encountered in a non-retryable streaming request.");
            throw lastError;
          }
          try {
            retryToken = await retryStrategy.refreshRetryTokenForRetry(retryToken, retryErrorInfo);
          } catch (refreshError) {
            if (typeof refreshError.$backoff === "number") {
              await cooldown2(refreshError.$backoff);
            }
            if (!lastError.$metadata) {
              lastError.$metadata = {};
            }
            lastError.$metadata.attempts = attempts + 1;
            lastError.$metadata.totalRetryDelay = totalRetryDelay;
            throw lastError;
          }
          attempts = retryToken.getRetryCount();
          const delay = retryToken.getRetryDelay();
          totalRetryDelay += delay;
          await cooldown2(delay);
        }
      }
    } else {
      retryStrategy = retryStrategy;
      if (retryStrategy?.mode) {
        context.userAgent = [...context.userAgent || [], ["cfg/retry-mode", retryStrategy.mode]];
      }
      return retryStrategy.retry(next, args);
    }
  };
}
function bindGetRetryPlugin2(isStreamingPayload3) {
  const retryMiddleware3 = bindRetryMiddleware2(isStreamingPayload3);
  return (options) => ({
    applyToStack: /* @__PURE__ */ __name((clientStack) => {
      clientStack.add(retryMiddleware3(options), retryMiddlewareOptions2);
    }, "applyToStack")
  });
}
var cooldown2, isRetryStrategyV22, getRetryErrorInfo2, getRetryErrorType2, retryMiddlewareOptions2;
var init_retryMiddleware2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/retryMiddleware.js"() {
    init_client12();
    init_protocols11();
    init_serde4();
    init_service_error_classification2();
    init_constants8();
    init_parseRetryAfterHeader2();
    init_util6();
    __name(bindRetryMiddleware2, "bindRetryMiddleware");
    cooldown2 = /* @__PURE__ */ __name((ms) => new Promise((resolve13) => setTimeout(resolve13, ms)), "cooldown");
    isRetryStrategyV22 = /* @__PURE__ */ __name((retryStrategy) => typeof retryStrategy.acquireInitialRetryToken !== "undefined" && typeof retryStrategy.refreshRetryTokenForRetry !== "undefined" && typeof retryStrategy.recordSuccess !== "undefined", "isRetryStrategyV2");
    getRetryErrorInfo2 = /* @__PURE__ */ __name((error4, logger5) => {
      const errorInfo = {
        error: error4,
        errorType: getRetryErrorType2(error4)
      };
      const retryAfterHint = parseRetryAfterHeader2(error4.$response, logger5);
      if (retryAfterHint) {
        errorInfo.retryAfterHint = retryAfterHint;
      }
      return errorInfo;
    }, "getRetryErrorInfo");
    getRetryErrorType2 = /* @__PURE__ */ __name((error4) => {
      if (isThrottlingError2(error4))
        return "THROTTLING";
      if (isTransientError2(error4))
        return "TRANSIENT";
      if (isServerError2(error4))
        return "SERVER_ERROR";
      return "CLIENT_ERROR";
    }, "getRetryErrorType");
    retryMiddlewareOptions2 = {
      name: "retryMiddleware",
      tags: ["RETRY"],
      step: "finalizeRequest",
      priority: "high",
      override: true
    };
    __name(bindGetRetryPlugin2, "bindGetRetryPlugin");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/DefaultRateLimiter.js
var DefaultRateLimiter2;
var init_DefaultRateLimiter2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/DefaultRateLimiter.js"() {
    init_service_error_classification2();
    DefaultRateLimiter2 = class _DefaultRateLimiter {
      static {
        __name(this, "DefaultRateLimiter");
      }
      static setTimeoutFn = setTimeout;
      beta;
      minCapacity;
      minFillRate;
      scaleConstant;
      smooth;
      enabled = false;
      availableTokens = 0;
      lastMaxRate = 0;
      measuredTxRate = 0;
      requestCount = 0;
      fillRate;
      lastThrottleTime;
      lastTimestamp = 0;
      lastTxRateBucket;
      maxCapacity;
      timeWindow = 0;
      constructor(options) {
        this.beta = options?.beta ?? 0.7;
        this.minCapacity = options?.minCapacity ?? 1;
        this.minFillRate = options?.minFillRate ?? 0.5;
        this.scaleConstant = options?.scaleConstant ?? 0.4;
        this.smooth = options?.smooth ?? 0.8;
        this.lastThrottleTime = this.getCurrentTimeInSeconds();
        this.lastTxRateBucket = Math.floor(this.getCurrentTimeInSeconds());
        this.fillRate = this.minFillRate;
        this.maxCapacity = this.minCapacity;
      }
      async getSendToken() {
        return this.acquireTokenBucket(1);
      }
      updateClientSendingRate(response) {
        let calculatedRate;
        this.updateMeasuredRate();
        const retryErrorInfo = response;
        const isThrottling = retryErrorInfo?.errorType === "THROTTLING" || isThrottlingError2(retryErrorInfo?.error ?? response);
        if (isThrottling) {
          const rateToUse = !this.enabled ? this.measuredTxRate : Math.min(this.measuredTxRate, this.fillRate);
          this.lastMaxRate = rateToUse;
          this.calculateTimeWindow();
          this.lastThrottleTime = this.getCurrentTimeInSeconds();
          calculatedRate = this.cubicThrottle(rateToUse);
          this.enableTokenBucket();
        } else {
          this.calculateTimeWindow();
          calculatedRate = this.cubicSuccess(this.getCurrentTimeInSeconds());
        }
        const newRate = Math.min(calculatedRate, 2 * this.measuredTxRate);
        this.updateTokenBucketRate(newRate);
      }
      getCurrentTimeInSeconds() {
        return Date.now() / 1e3;
      }
      async acquireTokenBucket(amount) {
        if (!this.enabled) {
          return;
        }
        this.refillTokenBucket();
        while (amount > this.availableTokens) {
          const delay = (amount - this.availableTokens) / this.fillRate * 1e3;
          await new Promise((resolve13) => _DefaultRateLimiter.setTimeoutFn(resolve13, delay));
          this.refillTokenBucket();
        }
        this.availableTokens = this.availableTokens - amount;
      }
      refillTokenBucket() {
        const timestamp = this.getCurrentTimeInSeconds();
        if (!this.lastTimestamp) {
          this.lastTimestamp = timestamp;
          return;
        }
        const fillAmount = (timestamp - this.lastTimestamp) * this.fillRate;
        this.availableTokens = Math.min(this.maxCapacity, this.availableTokens + fillAmount);
        this.lastTimestamp = timestamp;
      }
      calculateTimeWindow() {
        this.timeWindow = this.getPrecise(Math.pow(this.lastMaxRate * (1 - this.beta) / this.scaleConstant, 1 / 3));
      }
      cubicThrottle(rateToUse) {
        return this.getPrecise(rateToUse * this.beta);
      }
      cubicSuccess(timestamp) {
        return this.getPrecise(this.scaleConstant * Math.pow(timestamp - this.lastThrottleTime - this.timeWindow, 3) + this.lastMaxRate);
      }
      enableTokenBucket() {
        this.enabled = true;
      }
      updateTokenBucketRate(newRate) {
        this.refillTokenBucket();
        this.fillRate = Math.max(newRate, this.minFillRate);
        this.maxCapacity = Math.max(newRate, this.minCapacity);
        this.availableTokens = Math.min(this.availableTokens, this.maxCapacity);
      }
      updateMeasuredRate() {
        const t = this.getCurrentTimeInSeconds();
        const timeBucket = Math.floor(t * 2) / 2;
        this.requestCount++;
        if (timeBucket > this.lastTxRateBucket) {
          const currentRate = this.requestCount / (timeBucket - this.lastTxRateBucket);
          this.measuredTxRate = this.getPrecise(currentRate * this.smooth + this.measuredTxRate * (1 - this.smooth));
          this.requestCount = 0;
          this.lastTxRateBucket = timeBucket;
        }
      }
      getPrecise(num) {
        return parseFloat(num.toFixed(8));
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/retries-2026-config.js
var Retry10;
var init_retries_2026_config2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/retries-2026-config.js"() {
    Retry10 = class _Retry {
      static {
        __name(this, "Retry");
      }
      static v2026 = typeof process !== "undefined" && process.env?.SMITHY_NEW_RETRIES_2026 === "true";
      static delay() {
        return _Retry.v2026 ? 50 : 100;
      }
      static throttlingDelay() {
        return _Retry.v2026 ? 1e3 : 500;
      }
      static cost() {
        return _Retry.v2026 ? 14 : 5;
      }
      static throttlingCost() {
        return _Retry.v2026 ? 5 : 10;
      }
      static modifiedCostType() {
        return _Retry.v2026 ? "THROTTLING" : "TRANSIENT";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/DefaultRetryBackoffStrategy.js
var DefaultRetryBackoffStrategy2;
var init_DefaultRetryBackoffStrategy2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/DefaultRetryBackoffStrategy.js"() {
    init_constants8();
    init_retries_2026_config2();
    DefaultRetryBackoffStrategy2 = class {
      static {
        __name(this, "DefaultRetryBackoffStrategy");
      }
      x = Retry10.delay();
      computeNextBackoffDelay(i32) {
        const b32 = Math.random();
        const r32 = 2;
        const t_i = b32 * Math.min(this.x * r32 ** i32, MAXIMUM_RETRY_DELAY2);
        return Math.floor(t_i);
      }
      setDelayBase(delay) {
        this.x = delay;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/DefaultRetryToken.js
var DefaultRetryToken2;
var init_DefaultRetryToken2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/DefaultRetryToken.js"() {
    init_constants8();
    DefaultRetryToken2 = class {
      static {
        __name(this, "DefaultRetryToken");
      }
      delay;
      count;
      cost;
      longPoll;
      constructor(delay, count, cost, longPoll) {
        this.delay = delay;
        this.count = count;
        this.cost = cost;
        this.longPoll = longPoll;
      }
      getRetryCount() {
        return this.count;
      }
      getRetryDelay() {
        return Math.min(MAXIMUM_RETRY_DELAY2, this.delay);
      }
      getRetryCost() {
        return this.cost;
      }
      isLongPoll() {
        return this.longPoll;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/config.js
var RETRY_MODES2, DEFAULT_MAX_ATTEMPTS2, DEFAULT_RETRY_MODE20;
var init_config5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/config.js"() {
    (function(RETRY_MODES3) {
      RETRY_MODES3["STANDARD"] = "standard";
      RETRY_MODES3["ADAPTIVE"] = "adaptive";
    })(RETRY_MODES2 || (RETRY_MODES2 = {}));
    DEFAULT_MAX_ATTEMPTS2 = 3;
    DEFAULT_RETRY_MODE20 = RETRY_MODES2.STANDARD;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/StandardRetryStrategy.js
var refusal2, StandardRetryStrategy3;
var init_StandardRetryStrategy3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/StandardRetryStrategy.js"() {
    init_DefaultRetryBackoffStrategy2();
    init_DefaultRetryToken2();
    init_config5();
    init_constants8();
    init_retries_2026_config2();
    refusal2 = {
      incompatible: 1,
      attempts: 2,
      capacity: 3
    };
    StandardRetryStrategy3 = class {
      static {
        __name(this, "StandardRetryStrategy");
      }
      mode = RETRY_MODES2.STANDARD;
      capacity = INITIAL_RETRY_TOKENS2;
      retryBackoffStrategy;
      maxAttemptsProvider;
      baseDelay;
      constructor(arg1) {
        if (typeof arg1 === "number") {
          this.maxAttemptsProvider = async () => arg1;
        } else if (typeof arg1 === "function") {
          this.maxAttemptsProvider = arg1;
        } else if (arg1 && typeof arg1 === "object") {
          this.maxAttemptsProvider = async () => arg1.maxAttempts;
          this.baseDelay = arg1.baseDelay;
          this.retryBackoffStrategy = arg1.backoff;
        }
        this.maxAttemptsProvider ??= async () => DEFAULT_MAX_ATTEMPTS2;
        this.baseDelay ??= Retry10.delay();
        this.retryBackoffStrategy ??= new DefaultRetryBackoffStrategy2();
      }
      async acquireInitialRetryToken(retryTokenScope) {
        return new DefaultRetryToken2(Retry10.delay(), 0, void 0, Retry10.v2026 && retryTokenScope.includes(":longpoll"));
      }
      async refreshRetryTokenForRetry(token, errorInfo) {
        const maxAttempts = await this.getMaxAttempts();
        const retryCode = this.retryCode(token, errorInfo, maxAttempts);
        const shouldRetry = retryCode === 0;
        const isLongPoll = token.isLongPoll?.();
        if (shouldRetry || isLongPoll) {
          const errorType = errorInfo.errorType;
          this.retryBackoffStrategy.setDelayBase(errorType === "THROTTLING" ? Retry10.throttlingDelay() : this.baseDelay);
          const delayFromErrorType = this.retryBackoffStrategy.computeNextBackoffDelay(token.getRetryCount());
          let retryDelay = delayFromErrorType;
          if (errorInfo.retryAfterHint instanceof Date) {
            retryDelay = Math.max(delayFromErrorType, Math.min(errorInfo.retryAfterHint.getTime() - Date.now(), delayFromErrorType + 5e3));
          }
          if (!shouldRetry) {
            throw Object.assign(new Error("No retry token available"), {
              $backoff: Retry10.v2026 && retryCode === refusal2.capacity && isLongPoll ? retryDelay : 0
            });
          } else {
            const capacityCost = this.getCapacityCost(errorType);
            this.capacity -= capacityCost;
            return new DefaultRetryToken2(retryDelay, token.getRetryCount() + 1, capacityCost, token.isLongPoll?.() ?? false);
          }
        }
        throw new Error("No retry token available");
      }
      recordSuccess(token) {
        this.capacity = Math.min(INITIAL_RETRY_TOKENS2, this.capacity + (token.getRetryCost() ?? NO_RETRY_INCREMENT2));
      }
      getCapacity() {
        return this.capacity;
      }
      async maxAttempts() {
        return this.maxAttemptsProvider();
      }
      async getMaxAttempts() {
        try {
          return await this.maxAttemptsProvider();
        } catch (error4) {
          console.warn(`Max attempts provider could not resolve. Using default of ${DEFAULT_MAX_ATTEMPTS2}`);
          return DEFAULT_MAX_ATTEMPTS2;
        }
      }
      retryCode(tokenToRenew, errorInfo, maxAttempts) {
        const attempts = tokenToRenew.getRetryCount() + 1;
        const retryableStatus = this.isRetryableError(errorInfo.errorType) ? 0 : refusal2.incompatible;
        const attemptStatus = attempts < maxAttempts ? 0 : refusal2.attempts;
        const capacityStatus = this.capacity >= this.getCapacityCost(errorInfo.errorType) ? 0 : refusal2.capacity;
        return retryableStatus || attemptStatus || capacityStatus;
      }
      getCapacityCost(errorType) {
        return errorType === Retry10.modifiedCostType() ? Retry10.throttlingCost() : Retry10.cost();
      }
      isRetryableError(errorType) {
        return errorType === "THROTTLING" || errorType === "TRANSIENT";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/AdaptiveRetryStrategy.js
var AdaptiveRetryStrategy3;
var init_AdaptiveRetryStrategy3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/AdaptiveRetryStrategy.js"() {
    init_DefaultRateLimiter2();
    init_StandardRetryStrategy3();
    init_config5();
    AdaptiveRetryStrategy3 = class {
      static {
        __name(this, "AdaptiveRetryStrategy");
      }
      mode = RETRY_MODES2.ADAPTIVE;
      rateLimiter;
      standardRetryStrategy;
      constructor(maxAttemptsProvider, options) {
        const { rateLimiter } = options ?? {};
        this.rateLimiter = rateLimiter ?? new DefaultRateLimiter2();
        this.standardRetryStrategy = options ? new StandardRetryStrategy3({
          maxAttempts: typeof maxAttemptsProvider === "number" ? maxAttemptsProvider : 3,
          ...options
        }) : new StandardRetryStrategy3(maxAttemptsProvider);
      }
      async acquireInitialRetryToken(retryTokenScope) {
        const token = await this.standardRetryStrategy.acquireInitialRetryToken(retryTokenScope);
        await this.rateLimiter.getSendToken();
        return token;
      }
      async refreshRetryTokenForRetry(tokenToRenew, errorInfo) {
        this.rateLimiter.updateClientSendingRate(errorInfo);
        const token = await this.standardRetryStrategy.refreshRetryTokenForRetry(tokenToRenew, errorInfo);
        await this.rateLimiter.getSendToken();
        return token;
      }
      recordSuccess(token) {
        this.rateLimiter.updateClientSendingRate({});
        this.standardRetryStrategy.recordSuccess(token);
      }
      async maxAttemptsProvider() {
        return this.standardRetryStrategy.maxAttempts();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/ConfiguredRetryStrategy.js
var ConfiguredRetryStrategy2;
var init_ConfiguredRetryStrategy2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/util-retry/ConfiguredRetryStrategy.js"() {
    init_StandardRetryStrategy3();
    init_retries_2026_config2();
    ConfiguredRetryStrategy2 = class extends StandardRetryStrategy3 {
      static {
        __name(this, "ConfiguredRetryStrategy");
      }
      computeNextBackoffDelay;
      constructor(maxAttempts, computeNextBackoffDelay = Retry10.delay()) {
        super(typeof maxAttempts === "function" ? maxAttempts : async () => maxAttempts);
        if (typeof computeNextBackoffDelay === "number") {
          this.computeNextBackoffDelay = () => computeNextBackoffDelay;
        } else {
          this.computeNextBackoffDelay = computeNextBackoffDelay;
        }
      }
      async refreshRetryTokenForRetry(tokenToRenew, errorInfo) {
        const token = await super.refreshRetryTokenForRetry(tokenToRenew, errorInfo);
        token.getRetryDelay = () => this.computeNextBackoffDelay(token.getRetryCount());
        return token;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/retry-pre-sra-deprecated/defaultRetryQuota.js
var getDefaultRetryQuota2;
var init_defaultRetryQuota2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/retry-pre-sra-deprecated/defaultRetryQuota.js"() {
    init_constants8();
    getDefaultRetryQuota2 = /* @__PURE__ */ __name((initialRetryTokens, options) => {
      const MAX_CAPACITY = initialRetryTokens;
      const noRetryIncrement = options?.noRetryIncrement ?? NO_RETRY_INCREMENT2;
      const retryCost = options?.retryCost ?? RETRY_COST2;
      const timeoutRetryCost = options?.timeoutRetryCost ?? TIMEOUT_RETRY_COST2;
      let availableCapacity = initialRetryTokens;
      const getCapacityAmount = /* @__PURE__ */ __name((error4) => error4.name === "TimeoutError" ? timeoutRetryCost : retryCost, "getCapacityAmount");
      const hasRetryTokens = /* @__PURE__ */ __name((error4) => getCapacityAmount(error4) <= availableCapacity, "hasRetryTokens");
      const retrieveRetryTokens = /* @__PURE__ */ __name((error4) => {
        if (!hasRetryTokens(error4)) {
          throw new Error("No retry token available");
        }
        const capacityAmount = getCapacityAmount(error4);
        availableCapacity -= capacityAmount;
        return capacityAmount;
      }, "retrieveRetryTokens");
      const releaseRetryTokens = /* @__PURE__ */ __name((capacityReleaseAmount) => {
        availableCapacity += capacityReleaseAmount ?? noRetryIncrement;
        availableCapacity = Math.min(availableCapacity, MAX_CAPACITY);
      }, "releaseRetryTokens");
      return Object.freeze({
        hasRetryTokens,
        retrieveRetryTokens,
        releaseRetryTokens
      });
    }, "getDefaultRetryQuota");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/retry-pre-sra-deprecated/delayDecider.js
var defaultDelayDecider2;
var init_delayDecider2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/retry-pre-sra-deprecated/delayDecider.js"() {
    init_constants8();
    defaultDelayDecider2 = /* @__PURE__ */ __name((delayBase, attempts) => Math.floor(Math.min(MAXIMUM_RETRY_DELAY2, Math.random() * 2 ** attempts * delayBase)), "defaultDelayDecider");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/retry-pre-sra-deprecated/retryDecider.js
var defaultRetryDecider2;
var init_retryDecider2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/retry-pre-sra-deprecated/retryDecider.js"() {
    init_service_error_classification2();
    defaultRetryDecider2 = /* @__PURE__ */ __name((error4) => {
      if (!error4) {
        return false;
      }
      return isRetryableByTrait2(error4) || isClockSkewError2(error4) || isThrottlingError2(error4) || isTransientError2(error4);
    }, "defaultRetryDecider");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/retry-pre-sra-deprecated/StandardRetryStrategy.js
var StandardRetryStrategy4, getDelayFromRetryAfterHeader2;
var init_StandardRetryStrategy4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/retry-pre-sra-deprecated/StandardRetryStrategy.js"() {
    init_protocols11();
    init_serde4();
    init_service_error_classification2();
    init_config5();
    init_constants8();
    init_util6();
    init_defaultRetryQuota2();
    init_delayDecider2();
    init_retryDecider2();
    StandardRetryStrategy4 = class {
      static {
        __name(this, "StandardRetryStrategy");
      }
      maxAttemptsProvider;
      retryDecider;
      delayDecider;
      retryQuota;
      mode = RETRY_MODES2.STANDARD;
      constructor(maxAttemptsProvider, options) {
        this.maxAttemptsProvider = maxAttemptsProvider;
        this.retryDecider = options?.retryDecider ?? defaultRetryDecider2;
        this.delayDecider = options?.delayDecider ?? defaultDelayDecider2;
        this.retryQuota = options?.retryQuota ?? getDefaultRetryQuota2(INITIAL_RETRY_TOKENS2);
      }
      shouldRetry(error4, attempts, maxAttempts) {
        return attempts < maxAttempts && this.retryDecider(error4) && this.retryQuota.hasRetryTokens(error4);
      }
      async getMaxAttempts() {
        let maxAttempts;
        try {
          maxAttempts = await this.maxAttemptsProvider();
        } catch (error4) {
          maxAttempts = DEFAULT_MAX_ATTEMPTS2;
        }
        return maxAttempts;
      }
      async retry(next, args, options) {
        let retryTokenAmount;
        let attempts = 0;
        let totalDelay = 0;
        const maxAttempts = await this.getMaxAttempts();
        const { request: request4 } = args;
        if (HttpRequest22.isInstance(request4)) {
          request4.headers[INVOCATION_ID_HEADER2] = v43();
        }
        while (true) {
          try {
            if (HttpRequest22.isInstance(request4)) {
              request4.headers[REQUEST_HEADER2] = `attempt=${attempts + 1}; max=${maxAttempts}`;
            }
            if (options?.beforeRequest) {
              await options.beforeRequest();
            }
            const { response, output } = await next(args);
            if (options?.afterRequest) {
              options.afterRequest(response);
            }
            this.retryQuota.releaseRetryTokens(retryTokenAmount);
            output.$metadata.attempts = attempts + 1;
            output.$metadata.totalRetryDelay = totalDelay;
            return { response, output };
          } catch (e32) {
            const err = asSdkError2(e32);
            attempts++;
            if (this.shouldRetry(err, attempts, maxAttempts)) {
              retryTokenAmount = this.retryQuota.retrieveRetryTokens(err);
              const delayFromDecider = this.delayDecider(isThrottlingError2(err) ? THROTTLING_RETRY_DELAY_BASE2 : DEFAULT_RETRY_DELAY_BASE2, attempts);
              const delayFromResponse = getDelayFromRetryAfterHeader2(err.$response);
              const delay = Math.max(delayFromResponse || 0, delayFromDecider);
              totalDelay += delay;
              await new Promise((resolve13) => setTimeout(resolve13, delay));
              continue;
            }
            if (!err.$metadata) {
              err.$metadata = {};
            }
            err.$metadata.attempts = attempts;
            err.$metadata.totalRetryDelay = totalDelay;
            throw err;
          }
        }
      }
    };
    getDelayFromRetryAfterHeader2 = /* @__PURE__ */ __name((response) => {
      if (!HttpResponse11.isInstance(response))
        return;
      const retryAfterHeaderName = Object.keys(response.headers).find((key) => key.toLowerCase() === "retry-after");
      if (!retryAfterHeaderName)
        return;
      const retryAfter = response.headers[retryAfterHeaderName];
      const retryAfterSeconds = Number(retryAfter);
      if (!Number.isNaN(retryAfterSeconds))
        return retryAfterSeconds * 1e3;
      const retryAfterDate = new Date(retryAfter);
      return retryAfterDate.getTime() - Date.now();
    }, "getDelayFromRetryAfterHeader");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/retry-pre-sra-deprecated/AdaptiveRetryStrategy.js
var AdaptiveRetryStrategy4;
var init_AdaptiveRetryStrategy4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/retry-pre-sra-deprecated/AdaptiveRetryStrategy.js"() {
    init_DefaultRateLimiter2();
    init_config5();
    init_StandardRetryStrategy4();
    AdaptiveRetryStrategy4 = class extends StandardRetryStrategy4 {
      static {
        __name(this, "AdaptiveRetryStrategy");
      }
      rateLimiter;
      constructor(maxAttemptsProvider, options) {
        const { rateLimiter, ...superOptions } = options ?? {};
        super(maxAttemptsProvider, superOptions);
        this.rateLimiter = rateLimiter ?? new DefaultRateLimiter2();
        this.mode = RETRY_MODES2.ADAPTIVE;
      }
      async retry(next, args) {
        return super.retry(next, args, {
          beforeRequest: /* @__PURE__ */ __name(async () => {
            return this.rateLimiter.getSendToken();
          }, "beforeRequest"),
          afterRequest: /* @__PURE__ */ __name((response) => {
            this.rateLimiter.updateClientSendingRate(response);
          }, "afterRequest")
        });
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/configurations.js
var ENV_MAX_ATTEMPTS2, CONFIG_MAX_ATTEMPTS2, NODE_MAX_ATTEMPT_CONFIG_OPTIONS20, resolveRetryConfig20, ENV_RETRY_MODE2, CONFIG_RETRY_MODE2, NODE_RETRY_MODE_CONFIG_OPTIONS20;
var init_configurations2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/configurations.js"() {
    init_client12();
    init_AdaptiveRetryStrategy3();
    init_StandardRetryStrategy3();
    init_config5();
    ENV_MAX_ATTEMPTS2 = "AWS_MAX_ATTEMPTS";
    CONFIG_MAX_ATTEMPTS2 = "max_attempts";
    NODE_MAX_ATTEMPT_CONFIG_OPTIONS20 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => {
        const value = env3[ENV_MAX_ATTEMPTS2];
        if (!value)
          return void 0;
        const maxAttempt = parseInt(value);
        if (Number.isNaN(maxAttempt)) {
          throw new Error(`Environment variable ${ENV_MAX_ATTEMPTS2} mast be a number, got "${value}"`);
        }
        return maxAttempt;
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => {
        const value = profile[CONFIG_MAX_ATTEMPTS2];
        if (!value)
          return void 0;
        const maxAttempt = parseInt(value);
        if (Number.isNaN(maxAttempt)) {
          throw new Error(`Shared config file entry ${CONFIG_MAX_ATTEMPTS2} mast be a number, got "${value}"`);
        }
        return maxAttempt;
      }, "configFileSelector"),
      default: DEFAULT_MAX_ATTEMPTS2
    };
    resolveRetryConfig20 = /* @__PURE__ */ __name((input) => {
      const { retryStrategy, retryMode } = input;
      const maxAttempts = normalizeProvider22(input.maxAttempts ?? DEFAULT_MAX_ATTEMPTS2);
      let controller = retryStrategy ? Promise.resolve(retryStrategy) : void 0;
      const getDefault = /* @__PURE__ */ __name(async () => await normalizeProvider22(retryMode)() === RETRY_MODES2.ADAPTIVE ? new AdaptiveRetryStrategy3(maxAttempts) : new StandardRetryStrategy3(maxAttempts), "getDefault");
      return Object.assign(input, {
        maxAttempts,
        retryStrategy: /* @__PURE__ */ __name(() => controller ??= getDefault(), "retryStrategy")
      });
    }, "resolveRetryConfig");
    ENV_RETRY_MODE2 = "AWS_RETRY_MODE";
    CONFIG_RETRY_MODE2 = "retry_mode";
    NODE_RETRY_MODE_CONFIG_OPTIONS20 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[ENV_RETRY_MODE2], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[CONFIG_RETRY_MODE2], "configFileSelector"),
      default: DEFAULT_RETRY_MODE20
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/omitRetryHeadersMiddleware.js
var omitRetryHeadersMiddleware2, omitRetryHeadersMiddlewareOptions2, getOmitRetryHeadersPlugin2;
var init_omitRetryHeadersMiddleware2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/middleware-retry/omitRetryHeadersMiddleware.js"() {
    init_protocols11();
    init_constants8();
    omitRetryHeadersMiddleware2 = /* @__PURE__ */ __name(() => (next) => async (args) => {
      const { request: request4 } = args;
      if (HttpRequest22.isInstance(request4)) {
        delete request4.headers[INVOCATION_ID_HEADER2];
        delete request4.headers[REQUEST_HEADER2];
      }
      return next(args);
    }, "omitRetryHeadersMiddleware");
    omitRetryHeadersMiddlewareOptions2 = {
      name: "omitRetryHeadersMiddleware",
      tags: ["RETRY", "HEADERS", "OMIT_RETRY_HEADERS"],
      relation: "before",
      toMiddleware: "awsAuthMiddleware",
      override: true
    };
    getOmitRetryHeadersPlugin2 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.addRelativeTo(omitRetryHeadersMiddleware2(), omitRetryHeadersMiddlewareOptions2);
      }, "applyToStack")
    }), "getOmitRetryHeadersPlugin");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/index.js
var retry_exports2 = {};
__export(retry_exports2, {
  AdaptiveRetryStrategy: () => AdaptiveRetryStrategy3,
  CONFIG_MAX_ATTEMPTS: () => CONFIG_MAX_ATTEMPTS2,
  CONFIG_RETRY_MODE: () => CONFIG_RETRY_MODE2,
  ConfiguredRetryStrategy: () => ConfiguredRetryStrategy2,
  DEFAULT_MAX_ATTEMPTS: () => DEFAULT_MAX_ATTEMPTS2,
  DEFAULT_RETRY_DELAY_BASE: () => DEFAULT_RETRY_DELAY_BASE2,
  DEFAULT_RETRY_MODE: () => DEFAULT_RETRY_MODE20,
  DefaultRateLimiter: () => DefaultRateLimiter2,
  DeprecatedAdaptiveRetryStrategy: () => AdaptiveRetryStrategy4,
  DeprecatedStandardRetryStrategy: () => StandardRetryStrategy4,
  ENV_MAX_ATTEMPTS: () => ENV_MAX_ATTEMPTS2,
  ENV_RETRY_MODE: () => ENV_RETRY_MODE2,
  INITIAL_RETRY_TOKENS: () => INITIAL_RETRY_TOKENS2,
  INVOCATION_ID_HEADER: () => INVOCATION_ID_HEADER2,
  MAXIMUM_RETRY_DELAY: () => MAXIMUM_RETRY_DELAY2,
  NODE_MAX_ATTEMPT_CONFIG_OPTIONS: () => NODE_MAX_ATTEMPT_CONFIG_OPTIONS20,
  NODE_RETRY_MODE_CONFIG_OPTIONS: () => NODE_RETRY_MODE_CONFIG_OPTIONS20,
  NO_RETRY_INCREMENT: () => NO_RETRY_INCREMENT2,
  REQUEST_HEADER: () => REQUEST_HEADER2,
  RETRY_COST: () => RETRY_COST2,
  RETRY_MODES: () => RETRY_MODES2,
  Retry: () => Retry10,
  StandardRetryStrategy: () => StandardRetryStrategy3,
  THROTTLING_RETRY_DELAY_BASE: () => THROTTLING_RETRY_DELAY_BASE2,
  TIMEOUT_RETRY_COST: () => TIMEOUT_RETRY_COST2,
  defaultDelayDecider: () => defaultDelayDecider2,
  defaultRetryDecider: () => defaultRetryDecider2,
  getOmitRetryHeadersPlugin: () => getOmitRetryHeadersPlugin2,
  getRetryAfterHint: () => getRetryAfterHint2,
  getRetryPlugin: () => getRetryPlugin20,
  isBrowserNetworkError: () => isBrowserNetworkError2,
  isClockSkewCorrectedError: () => isClockSkewCorrectedError2,
  isClockSkewError: () => isClockSkewError2,
  isNodeJsHttp2TransientError: () => isNodeJsHttp2TransientError2,
  isRetryableByTrait: () => isRetryableByTrait2,
  isServerError: () => isServerError2,
  isThrottlingError: () => isThrottlingError2,
  isTransientError: () => isTransientError2,
  omitRetryHeadersMiddleware: () => omitRetryHeadersMiddleware2,
  omitRetryHeadersMiddlewareOptions: () => omitRetryHeadersMiddlewareOptions2,
  resolveRetryConfig: () => resolveRetryConfig20,
  retryMiddleware: () => retryMiddleware2,
  retryMiddlewareOptions: () => retryMiddlewareOptions2
});
var retryMiddleware2, getRetryPlugin20;
var init_retry3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/retry/index.js"() {
    init_isStreamingPayload2();
    init_retryMiddleware2();
    init_service_error_classification2();
    init_AdaptiveRetryStrategy3();
    init_ConfiguredRetryStrategy2();
    init_DefaultRateLimiter2();
    init_StandardRetryStrategy3();
    init_config5();
    init_constants8();
    init_retries_2026_config2();
    init_AdaptiveRetryStrategy4();
    init_StandardRetryStrategy4();
    init_delayDecider2();
    init_retryDecider2();
    init_configurations2();
    init_omitRetryHeadersMiddleware2();
    init_retryMiddleware2();
    init_parseRetryAfterHeader2();
    retryMiddleware2 = bindRetryMiddleware2(isStreamingPayload2);
    getRetryPlugin20 = bindGetRetryPlugin2(isStreamingPayload2);
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/setFeature.js
function setFeature12(context, feature, value) {
  if (!context.__aws_sdk_context) {
    context.__aws_sdk_context = {
      features: {}
    };
  } else if (!context.__aws_sdk_context.features) {
    context.__aws_sdk_context.features = {};
  }
  context.__aws_sdk_context.features[feature] = value;
}
var init_setFeature10 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/setFeature.js"() {
    init_retry3();
    Retry10.v2026 ||= typeof process === "object" && process.env?.AWS_NEW_RETRIES_2026 === "true";
    __name(setFeature12, "setFeature");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/setTokenFeature.js
function setTokenFeature9(token, feature, value) {
  if (!token.$source) {
    token.$source = {};
  }
  token.$source[feature] = value;
  return token;
}
var init_setTokenFeature9 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/setTokenFeature.js"() {
    __name(setTokenFeature9, "setTokenFeature");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/middleware-host-header/hostHeaderMiddleware.js
function resolveHostHeaderConfig19(input) {
  return input;
}
var hostHeaderMiddleware, hostHeaderMiddlewareOptions, getHostHeaderPlugin19;
var init_hostHeaderMiddleware = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/middleware-host-header/hostHeaderMiddleware.js"() {
    init_protocols11();
    __name(resolveHostHeaderConfig19, "resolveHostHeaderConfig");
    hostHeaderMiddleware = /* @__PURE__ */ __name((options) => (next) => async (args) => {
      if (!HttpRequest22.isInstance(args.request))
        return next(args);
      const { request: request4 } = args;
      const { handlerProtocol = "" } = options.requestHandler.metadata || {};
      if (handlerProtocol.indexOf("h2") >= 0 && !request4.headers[":authority"]) {
        delete request4.headers["host"];
        request4.headers[":authority"] = request4.hostname + (request4.port ? ":" + request4.port : "");
      } else if (!request4.headers["host"]) {
        let host = request4.hostname;
        if (request4.port != null)
          host += `:${request4.port}`;
        request4.headers["host"] = host;
      }
      return next(args);
    }, "hostHeaderMiddleware");
    hostHeaderMiddlewareOptions = {
      name: "hostHeaderMiddleware",
      step: "build",
      priority: "low",
      tags: ["HOST"],
      override: true
    };
    getHostHeaderPlugin19 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(hostHeaderMiddleware(options), hostHeaderMiddlewareOptions);
      }, "applyToStack")
    }), "getHostHeaderPlugin");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/middleware-logger/loggerMiddleware.js
var loggerMiddleware, loggerMiddlewareOptions, getLoggerPlugin19;
var init_loggerMiddleware = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/middleware-logger/loggerMiddleware.js"() {
    loggerMiddleware = /* @__PURE__ */ __name(() => (next, context) => async (args) => {
      try {
        const response = await next(args);
        const { clientName, commandName, logger: logger5, dynamoDbDocumentClientOptions = {} } = context;
        const { overrideInputFilterSensitiveLog, overrideOutputFilterSensitiveLog } = dynamoDbDocumentClientOptions;
        const inputFilterSensitiveLog = overrideInputFilterSensitiveLog ?? context.inputFilterSensitiveLog;
        const outputFilterSensitiveLog = overrideOutputFilterSensitiveLog ?? context.outputFilterSensitiveLog;
        const { $metadata, ...outputWithoutMetadata } = response.output;
        logger5?.info?.({
          clientName,
          commandName,
          input: inputFilterSensitiveLog(args.input),
          output: outputFilterSensitiveLog(outputWithoutMetadata),
          metadata: $metadata
        });
        return response;
      } catch (error4) {
        const { clientName, commandName, logger: logger5, dynamoDbDocumentClientOptions = {} } = context;
        const { overrideInputFilterSensitiveLog } = dynamoDbDocumentClientOptions;
        const inputFilterSensitiveLog = overrideInputFilterSensitiveLog ?? context.inputFilterSensitiveLog;
        logger5?.error?.({
          clientName,
          commandName,
          input: inputFilterSensitiveLog(args.input),
          error: error4,
          metadata: error4.$metadata
        });
        throw error4;
      }
    }, "loggerMiddleware");
    loggerMiddlewareOptions = {
      name: "loggerMiddleware",
      tags: ["LOGGER"],
      step: "initialize",
      override: true
    };
    getLoggerPlugin19 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(loggerMiddleware(), loggerMiddlewareOptions);
      }, "applyToStack")
    }), "getLoggerPlugin");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/middleware-recursion-detection/configuration.js
var recursionDetectionMiddlewareOptions;
var init_configuration = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/middleware-recursion-detection/configuration.js"() {
    recursionDetectionMiddlewareOptions = {
      step: "build",
      tags: ["RECURSION_DETECTION"],
      name: "recursionDetectionMiddleware",
      override: true,
      priority: "low"
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/middleware-recursion-detection/recursionDetectionMiddleware.js
var TRACE_ID_HEADER_NAME, ENV_LAMBDA_FUNCTION_NAME, ENV_TRACE_ID, recursionDetectionMiddleware;
var init_recursionDetectionMiddleware = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/middleware-recursion-detection/recursionDetectionMiddleware.js"() {
    init_invoke_store();
    init_protocols11();
    TRACE_ID_HEADER_NAME = "X-Amzn-Trace-Id";
    ENV_LAMBDA_FUNCTION_NAME = "AWS_LAMBDA_FUNCTION_NAME";
    ENV_TRACE_ID = "_X_AMZN_TRACE_ID";
    recursionDetectionMiddleware = /* @__PURE__ */ __name(() => (next) => async (args) => {
      const { request: request4 } = args;
      if (!HttpRequest22.isInstance(request4)) {
        return next(args);
      }
      const traceIdHeader = Object.keys(request4.headers ?? {}).find((h32) => h32.toLowerCase() === TRACE_ID_HEADER_NAME.toLowerCase()) ?? TRACE_ID_HEADER_NAME;
      if (request4.headers.hasOwnProperty(traceIdHeader)) {
        return next(args);
      }
      const functionName = process.env[ENV_LAMBDA_FUNCTION_NAME];
      const traceIdFromEnv = process.env[ENV_TRACE_ID];
      const invokeStore = await InvokeStore.getInstanceAsync();
      const traceIdFromInvokeStore = invokeStore?.getXRayTraceId();
      const traceId = traceIdFromInvokeStore ?? traceIdFromEnv;
      const nonEmptyString = /* @__PURE__ */ __name((str) => typeof str === "string" && str.length > 0, "nonEmptyString");
      if (nonEmptyString(functionName) && nonEmptyString(traceId)) {
        request4.headers[TRACE_ID_HEADER_NAME] = traceId;
      }
      return next({
        ...args,
        request: request4
      });
    }, "recursionDetectionMiddleware");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/middleware-recursion-detection/getRecursionDetectionPlugin.js
var getRecursionDetectionPlugin19;
var init_getRecursionDetectionPlugin = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/middleware-recursion-detection/getRecursionDetectionPlugin.js"() {
    init_configuration();
    init_recursionDetectionMiddleware();
    getRecursionDetectionPlugin19 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(recursionDetectionMiddleware(), recursionDetectionMiddlewareOptions);
      }, "applyToStack")
    }), "getRecursionDetectionPlugin");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/getSmithyContext.js
var import_types43, getSmithyContext27;
var init_getSmithyContext4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/getSmithyContext.js"() {
    import_types43 = __toESM(require_dist_cjs());
    getSmithyContext27 = /* @__PURE__ */ __name((context) => context[import_types43.SMITHY_CONTEXT_KEY] || (context[import_types43.SMITHY_CONTEXT_KEY] = {}), "getSmithyContext");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/middleware-http-auth-scheme/resolveAuthOptions.js
var resolveAuthOptions2;
var init_resolveAuthOptions2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/middleware-http-auth-scheme/resolveAuthOptions.js"() {
    resolveAuthOptions2 = /* @__PURE__ */ __name((candidateAuthOptions, authSchemePreference) => {
      if (!authSchemePreference || authSchemePreference.length === 0) {
        return candidateAuthOptions;
      }
      const preferredAuthOptions = [];
      for (const preferredSchemeName of authSchemePreference) {
        for (const candidateAuthOption of candidateAuthOptions) {
          const candidateAuthSchemeName = candidateAuthOption.schemeId.split("#")[1];
          if (candidateAuthSchemeName === preferredSchemeName) {
            preferredAuthOptions.push(candidateAuthOption);
          }
        }
      }
      for (const candidateAuthOption of candidateAuthOptions) {
        if (!preferredAuthOptions.find(({ schemeId }) => schemeId === candidateAuthOption.schemeId)) {
          preferredAuthOptions.push(candidateAuthOption);
        }
      }
      return preferredAuthOptions;
    }, "resolveAuthOptions");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/middleware-http-auth-scheme/httpAuthSchemeMiddleware.js
function convertHttpAuthSchemesToMap2(httpAuthSchemes) {
  const map5 = /* @__PURE__ */ new Map();
  for (const scheme of httpAuthSchemes) {
    map5.set(scheme.schemeId, scheme);
  }
  return map5;
}
var httpAuthSchemeMiddleware2;
var init_httpAuthSchemeMiddleware2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/middleware-http-auth-scheme/httpAuthSchemeMiddleware.js"() {
    init_client12();
    init_resolveAuthOptions2();
    __name(convertHttpAuthSchemesToMap2, "convertHttpAuthSchemesToMap");
    httpAuthSchemeMiddleware2 = /* @__PURE__ */ __name((config2, mwOptions) => (next, context) => async (args) => {
      const options = config2.httpAuthSchemeProvider(await mwOptions.httpAuthSchemeParametersProvider(config2, context, args.input));
      const authSchemePreference = config2.authSchemePreference ? await config2.authSchemePreference() : [];
      const resolvedOptions = resolveAuthOptions2(options, authSchemePreference);
      const authSchemes = convertHttpAuthSchemesToMap2(config2.httpAuthSchemes);
      const smithyContext = getSmithyContext26(context);
      const failureReasons = [];
      for (const option of resolvedOptions) {
        const scheme = authSchemes.get(option.schemeId);
        if (!scheme) {
          failureReasons.push(`HttpAuthScheme \`${option.schemeId}\` was not enabled for this service.`);
          continue;
        }
        const identityProvider = scheme.identityProvider(await mwOptions.identityProviderConfigProvider(config2));
        if (!identityProvider) {
          failureReasons.push(`HttpAuthScheme \`${option.schemeId}\` did not have an IdentityProvider configured.`);
          continue;
        }
        const { identityProperties = {}, signingProperties = {} } = option.propertiesExtractor?.(config2, context) || {};
        option.identityProperties = Object.assign(option.identityProperties || {}, identityProperties);
        option.signingProperties = Object.assign(option.signingProperties || {}, signingProperties);
        smithyContext.selectedHttpAuthScheme = {
          httpAuthOption: option,
          identity: await identityProvider(option.identityProperties),
          signer: scheme.signer
        };
        break;
      }
      if (!smithyContext.selectedHttpAuthScheme) {
        throw new Error(failureReasons.join("\n"));
      }
      return next(args);
    }, "httpAuthSchemeMiddleware");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/middleware-http-auth-scheme/getHttpAuthSchemeEndpointRuleSetPlugin.js
var httpAuthSchemeEndpointRuleSetMiddlewareOptions2, getHttpAuthSchemeEndpointRuleSetPlugin2;
var init_getHttpAuthSchemeEndpointRuleSetPlugin2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/middleware-http-auth-scheme/getHttpAuthSchemeEndpointRuleSetPlugin.js"() {
    init_httpAuthSchemeMiddleware2();
    httpAuthSchemeEndpointRuleSetMiddlewareOptions2 = {
      step: "serialize",
      tags: ["HTTP_AUTH_SCHEME"],
      name: "httpAuthSchemeMiddleware",
      override: true,
      relation: "before",
      toMiddleware: "endpointV2Middleware"
    };
    getHttpAuthSchemeEndpointRuleSetPlugin2 = /* @__PURE__ */ __name((config2, { httpAuthSchemeParametersProvider, identityProviderConfigProvider }) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.addRelativeTo(httpAuthSchemeMiddleware2(config2, {
          httpAuthSchemeParametersProvider,
          identityProviderConfigProvider
        }), httpAuthSchemeEndpointRuleSetMiddlewareOptions2);
      }, "applyToStack")
    }), "getHttpAuthSchemeEndpointRuleSetPlugin");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/middleware-http-auth-scheme/getHttpAuthSchemePlugin.js
var httpAuthSchemeMiddlewareOptions2, getHttpAuthSchemePlugin2;
var init_getHttpAuthSchemePlugin2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/middleware-http-auth-scheme/getHttpAuthSchemePlugin.js"() {
    init_httpAuthSchemeMiddleware2();
    httpAuthSchemeMiddlewareOptions2 = {
      step: "serialize",
      tags: ["HTTP_AUTH_SCHEME"],
      name: "httpAuthSchemeMiddleware",
      override: true,
      relation: "before",
      toMiddleware: "serializerMiddleware"
    };
    getHttpAuthSchemePlugin2 = /* @__PURE__ */ __name((config2, { httpAuthSchemeParametersProvider, identityProviderConfigProvider }) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.addRelativeTo(httpAuthSchemeMiddleware2(config2, {
          httpAuthSchemeParametersProvider,
          identityProviderConfigProvider
        }), httpAuthSchemeMiddlewareOptions2);
      }, "applyToStack")
    }), "getHttpAuthSchemePlugin");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/middleware-http-auth-scheme/index.js
var init_middleware_http_auth_scheme2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/middleware-http-auth-scheme/index.js"() {
    init_httpAuthSchemeMiddleware2();
    init_getHttpAuthSchemeEndpointRuleSetPlugin2();
    init_getHttpAuthSchemePlugin2();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/middleware-http-signing/httpSigningMiddleware.js
var defaultErrorHandler2, defaultSuccessHandler2, httpSigningMiddleware2;
var init_httpSigningMiddleware2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/middleware-http-signing/httpSigningMiddleware.js"() {
    init_client12();
    init_protocols11();
    defaultErrorHandler2 = /* @__PURE__ */ __name((signingProperties) => (error4) => {
      throw error4;
    }, "defaultErrorHandler");
    defaultSuccessHandler2 = /* @__PURE__ */ __name((httpResponse, signingProperties) => {
    }, "defaultSuccessHandler");
    httpSigningMiddleware2 = /* @__PURE__ */ __name((config2) => (next, context) => async (args) => {
      if (!HttpRequest22.isInstance(args.request)) {
        return next(args);
      }
      const smithyContext = getSmithyContext26(context);
      const scheme = smithyContext.selectedHttpAuthScheme;
      if (!scheme) {
        throw new Error(`No HttpAuthScheme was selected: unable to sign request`);
      }
      const { httpAuthOption: { signingProperties = {} }, identity, signer } = scheme;
      const output = await next({
        ...args,
        request: await signer.sign(args.request, identity, signingProperties)
      }).catch((signer.errorHandler || defaultErrorHandler2)(signingProperties));
      (signer.successHandler || defaultSuccessHandler2)(output.response, signingProperties);
      return output;
    }, "httpSigningMiddleware");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/middleware-http-signing/getHttpSigningMiddleware.js
var httpSigningMiddlewareOptions2, getHttpSigningPlugin2;
var init_getHttpSigningMiddleware2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/middleware-http-signing/getHttpSigningMiddleware.js"() {
    init_httpSigningMiddleware2();
    httpSigningMiddlewareOptions2 = {
      step: "finalizeRequest",
      tags: ["HTTP_SIGNING"],
      name: "httpSigningMiddleware",
      aliases: ["apiKeyMiddleware", "tokenMiddleware", "awsAuthMiddleware"],
      override: true,
      relation: "after",
      toMiddleware: "retryMiddleware"
    };
    getHttpSigningPlugin2 = /* @__PURE__ */ __name((config2) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.addRelativeTo(httpSigningMiddleware2(config2), httpSigningMiddlewareOptions2);
      }, "applyToStack")
    }), "getHttpSigningPlugin");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/middleware-http-signing/index.js
var init_middleware_http_signing2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/middleware-http-signing/index.js"() {
    init_httpSigningMiddleware2();
    init_getHttpSigningMiddleware2();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/normalizeProvider.js
var normalizeProvider23;
var init_normalizeProvider5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/normalizeProvider.js"() {
    normalizeProvider23 = /* @__PURE__ */ __name((input) => {
      if (typeof input === "function")
        return input;
      const promisified = Promise.resolve(input);
      return () => promisified;
    }, "normalizeProvider");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/pagination/createPaginator.js
function createPaginator2(ClientCtor, CommandCtor, inputTokenName, outputTokenName, pageSizeTokenName) {
  return /* @__PURE__ */ __name(async function* paginateOperation(config2, input, ...additionalArguments) {
    const _input = input;
    let token = config2.startingToken ?? _input[inputTokenName];
    let hasNext = true;
    let page;
    while (hasNext) {
      _input[inputTokenName] = token;
      if (pageSizeTokenName) {
        _input[pageSizeTokenName] = _input[pageSizeTokenName] ?? config2.pageSize;
      }
      if (config2.client instanceof ClientCtor) {
        page = await makePagedClientRequest2(CommandCtor, config2.client, input, config2.withCommand, ...additionalArguments);
      } else {
        throw new Error(`Invalid client, expected instance of ${ClientCtor.name}`);
      }
      yield page;
      const prevToken = token;
      token = get3(page, outputTokenName);
      hasNext = !!(token && (!config2.stopOnSameToken || token !== prevToken));
    }
    return void 0;
  }, "paginateOperation");
}
var makePagedClientRequest2, get3;
var init_createPaginator2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/pagination/createPaginator.js"() {
    makePagedClientRequest2 = /* @__PURE__ */ __name(async (CommandCtor, client, input, withCommand = (_) => _, ...args) => {
      let command = new CommandCtor(input);
      command = withCommand(command) ?? command;
      return await client.send(command, ...args);
    }, "makePagedClientRequest");
    __name(createPaginator2, "createPaginator");
    get3 = /* @__PURE__ */ __name((fromObject, path47) => {
      let cursor3 = fromObject;
      const pathComponents = path47.split(".");
      for (const step of pathComponents) {
        if (!cursor3 || typeof cursor3 !== "object") {
          return void 0;
        }
        cursor3 = cursor3[step];
      }
      return cursor3;
    }, "get");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/request-builder/requestBuilder.js
var init_requestBuilder6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/request-builder/requestBuilder.js"() {
    init_protocols11();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/setFeature.js
function setFeature13(context, feature, value) {
  if (!context.__smithy_context) {
    context.__smithy_context = {
      features: {}
    };
  } else if (!context.__smithy_context.features) {
    context.__smithy_context.features = {};
  }
  context.__smithy_context.features[feature] = value;
}
var init_setFeature11 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/setFeature.js"() {
    __name(setFeature13, "setFeature");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/util-identity-and-auth/DefaultIdentityProviderConfig.js
var DefaultIdentityProviderConfig2;
var init_DefaultIdentityProviderConfig2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/util-identity-and-auth/DefaultIdentityProviderConfig.js"() {
    DefaultIdentityProviderConfig2 = class {
      static {
        __name(this, "DefaultIdentityProviderConfig");
      }
      authSchemes = /* @__PURE__ */ new Map();
      constructor(config2) {
        for (const key in config2) {
          const value = config2[key];
          if (value !== void 0) {
            this.authSchemes.set(key, value);
          }
        }
      }
      getIdentityProvider(schemeId) {
        return this.authSchemes.get(schemeId);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/util-identity-and-auth/httpAuthSchemes/httpApiKeyAuth.js
var import_types44, HttpApiKeyAuthSigner2;
var init_httpApiKeyAuth2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/util-identity-and-auth/httpAuthSchemes/httpApiKeyAuth.js"() {
    init_protocols11();
    import_types44 = __toESM(require_dist_cjs());
    HttpApiKeyAuthSigner2 = class {
      static {
        __name(this, "HttpApiKeyAuthSigner");
      }
      async sign(httpRequest, identity, signingProperties) {
        if (!signingProperties) {
          throw new Error("request could not be signed with `apiKey` since the `name` and `in` signer properties are missing");
        }
        if (!signingProperties.name) {
          throw new Error("request could not be signed with `apiKey` since the `name` signer property is missing");
        }
        if (!signingProperties.in) {
          throw new Error("request could not be signed with `apiKey` since the `in` signer property is missing");
        }
        if (!identity.apiKey) {
          throw new Error("request could not be signed with `apiKey` since the `apiKey` is not defined");
        }
        const clonedRequest = HttpRequest22.clone(httpRequest);
        if (signingProperties.in === import_types44.HttpApiKeyAuthLocation.QUERY) {
          clonedRequest.query[signingProperties.name] = identity.apiKey;
        } else if (signingProperties.in === import_types44.HttpApiKeyAuthLocation.HEADER) {
          clonedRequest.headers[signingProperties.name] = signingProperties.scheme ? `${signingProperties.scheme} ${identity.apiKey}` : identity.apiKey;
        } else {
          throw new Error("request can only be signed with `apiKey` locations `query` or `header`, but found: `" + signingProperties.in + "`");
        }
        return clonedRequest;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/util-identity-and-auth/httpAuthSchemes/httpBearerAuth.js
var HttpBearerAuthSigner2;
var init_httpBearerAuth2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/util-identity-and-auth/httpAuthSchemes/httpBearerAuth.js"() {
    init_protocols11();
    HttpBearerAuthSigner2 = class {
      static {
        __name(this, "HttpBearerAuthSigner");
      }
      async sign(httpRequest, identity, signingProperties) {
        const clonedRequest = HttpRequest22.clone(httpRequest);
        if (!identity.token) {
          throw new Error("request could not be signed with `token` since the `token` is not defined");
        }
        clonedRequest.headers["Authorization"] = `Bearer ${identity.token}`;
        return clonedRequest;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/util-identity-and-auth/httpAuthSchemes/noAuth.js
var NoAuthSigner2;
var init_noAuth2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/util-identity-and-auth/httpAuthSchemes/noAuth.js"() {
    NoAuthSigner2 = class {
      static {
        __name(this, "NoAuthSigner");
      }
      async sign(httpRequest, identity, signingProperties) {
        return httpRequest;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/util-identity-and-auth/httpAuthSchemes/index.js
var init_httpAuthSchemes8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/util-identity-and-auth/httpAuthSchemes/index.js"() {
    init_httpApiKeyAuth2();
    init_httpBearerAuth2();
    init_noAuth2();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/util-identity-and-auth/memoizeIdentityProvider.js
var createIsIdentityExpiredFunction2, EXPIRATION_MS2, isIdentityExpired2, doesIdentityRequireRefresh2, memoizeIdentityProvider2;
var init_memoizeIdentityProvider2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/util-identity-and-auth/memoizeIdentityProvider.js"() {
    createIsIdentityExpiredFunction2 = /* @__PURE__ */ __name((expirationMs) => /* @__PURE__ */ __name(function isIdentityExpired3(identity) {
      return doesIdentityRequireRefresh2(identity) && identity.expiration.getTime() - Date.now() < expirationMs;
    }, "isIdentityExpired"), "createIsIdentityExpiredFunction");
    EXPIRATION_MS2 = 3e5;
    isIdentityExpired2 = createIsIdentityExpiredFunction2(EXPIRATION_MS2);
    doesIdentityRequireRefresh2 = /* @__PURE__ */ __name((identity) => identity.expiration !== void 0, "doesIdentityRequireRefresh");
    memoizeIdentityProvider2 = /* @__PURE__ */ __name((provider, isExpired, requiresRefresh) => {
      if (provider === void 0) {
        return void 0;
      }
      const normalizedProvider = typeof provider !== "function" ? async () => Promise.resolve(provider) : provider;
      let resolved;
      let pending;
      let hasResult;
      let isConstant = false;
      const coalesceProvider = /* @__PURE__ */ __name(async (options) => {
        if (!pending) {
          pending = normalizedProvider(options);
        }
        try {
          resolved = await pending;
          hasResult = true;
          isConstant = false;
        } finally {
          pending = void 0;
        }
        return resolved;
      }, "coalesceProvider");
      if (isExpired === void 0) {
        return async (options) => {
          if (!hasResult || options?.forceRefresh) {
            resolved = await coalesceProvider(options);
          }
          return resolved;
        };
      }
      return async (options) => {
        if (!hasResult || options?.forceRefresh) {
          resolved = await coalesceProvider(options);
        }
        if (isConstant) {
          return resolved;
        }
        if (!requiresRefresh(resolved)) {
          isConstant = true;
          return resolved;
        }
        if (isExpired(resolved)) {
          await coalesceProvider(options);
          return resolved;
        }
        return resolved;
      };
    }, "memoizeIdentityProvider");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/util-identity-and-auth/index.js
var init_util_identity_and_auth2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/util-identity-and-auth/index.js"() {
    init_DefaultIdentityProviderConfig2();
    init_httpAuthSchemes8();
    init_memoizeIdentityProvider2();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/index.js
var dist_es_exports2 = {};
__export(dist_es_exports2, {
  DefaultIdentityProviderConfig: () => DefaultIdentityProviderConfig2,
  EXPIRATION_MS: () => EXPIRATION_MS2,
  HttpApiKeyAuthSigner: () => HttpApiKeyAuthSigner2,
  HttpBearerAuthSigner: () => HttpBearerAuthSigner2,
  NoAuthSigner: () => NoAuthSigner2,
  createIsIdentityExpiredFunction: () => createIsIdentityExpiredFunction2,
  createPaginator: () => createPaginator2,
  doesIdentityRequireRefresh: () => doesIdentityRequireRefresh2,
  getHttpAuthSchemeEndpointRuleSetPlugin: () => getHttpAuthSchemeEndpointRuleSetPlugin2,
  getHttpAuthSchemePlugin: () => getHttpAuthSchemePlugin2,
  getHttpSigningPlugin: () => getHttpSigningPlugin2,
  getSmithyContext: () => getSmithyContext27,
  httpAuthSchemeEndpointRuleSetMiddlewareOptions: () => httpAuthSchemeEndpointRuleSetMiddlewareOptions2,
  httpAuthSchemeMiddleware: () => httpAuthSchemeMiddleware2,
  httpAuthSchemeMiddlewareOptions: () => httpAuthSchemeMiddlewareOptions2,
  httpSigningMiddleware: () => httpSigningMiddleware2,
  httpSigningMiddlewareOptions: () => httpSigningMiddlewareOptions2,
  isIdentityExpired: () => isIdentityExpired2,
  memoizeIdentityProvider: () => memoizeIdentityProvider2,
  normalizeProvider: () => normalizeProvider23,
  requestBuilder: () => requestBuilder3,
  setFeature: () => setFeature13
});
var init_dist_es2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/index.js"() {
    init_getSmithyContext4();
    init_middleware_http_auth_scheme2();
    init_middleware_http_signing2();
    init_normalizeProvider5();
    init_createPaginator2();
    init_requestBuilder6();
    init_setFeature11();
    init_util_identity_and_auth2();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/middleware-user-agent/configurations.js
function isValidUserAgentAppId(appId) {
  if (appId === void 0) {
    return true;
  }
  return typeof appId === "string" && appId.length <= 50;
}
function resolveUserAgentConfig19(input) {
  const normalizedAppIdProvider = normalizeProvider23(input.userAgentAppId ?? DEFAULT_UA_APP_ID);
  const { customUserAgent } = input;
  return Object.assign(input, {
    customUserAgent: typeof customUserAgent === "string" ? [[customUserAgent]] : customUserAgent,
    userAgentAppId: /* @__PURE__ */ __name(async () => {
      const appId = await normalizedAppIdProvider();
      if (!isValidUserAgentAppId(appId)) {
        const logger5 = input.logger?.constructor?.name === "NoOpLogger" || !input.logger ? console : input.logger;
        if (typeof appId !== "string") {
          logger5?.warn("userAgentAppId must be a string or undefined.");
        } else if (appId.length > 50) {
          logger5?.warn("The provided userAgentAppId exceeds the maximum length of 50 characters.");
        }
      }
      return appId;
    }, "userAgentAppId")
  });
}
var DEFAULT_UA_APP_ID;
var init_configurations3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/middleware-user-agent/configurations.js"() {
    init_dist_es2();
    DEFAULT_UA_APP_ID = void 0;
    __name(isValidUserAgentAppId, "isValidUserAgentAppId");
    __name(resolveUserAgentConfig19, "resolveUserAgentConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-endpoints/lib/aws/partitions.js
var partitionsInfo;
var init_partitions = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-endpoints/lib/aws/partitions.js"() {
    partitionsInfo = { "partitions": [{ "id": "aws", "outputs": { "dnsSuffix": "amazonaws.com", "dualStackDnsSuffix": "api.aws", "implicitGlobalRegion": "us-east-1", "name": "aws", "supportsDualStack": true, "supportsFIPS": true }, "regionRegex": "^(us|eu|ap|sa|ca|me|af|il|mx)\\-\\w+\\-\\d+$", "regions": { "af-south-1": { "description": "Africa (Cape Town)" }, "ap-east-1": { "description": "Asia Pacific (Hong Kong)" }, "ap-east-2": { "description": "Asia Pacific (Taipei)" }, "ap-northeast-1": { "description": "Asia Pacific (Tokyo)" }, "ap-northeast-2": { "description": "Asia Pacific (Seoul)" }, "ap-northeast-3": { "description": "Asia Pacific (Osaka)" }, "ap-south-1": { "description": "Asia Pacific (Mumbai)" }, "ap-south-2": { "description": "Asia Pacific (Hyderabad)" }, "ap-southeast-1": { "description": "Asia Pacific (Singapore)" }, "ap-southeast-2": { "description": "Asia Pacific (Sydney)" }, "ap-southeast-3": { "description": "Asia Pacific (Jakarta)" }, "ap-southeast-4": { "description": "Asia Pacific (Melbourne)" }, "ap-southeast-5": { "description": "Asia Pacific (Malaysia)" }, "ap-southeast-6": { "description": "Asia Pacific (New Zealand)" }, "ap-southeast-7": { "description": "Asia Pacific (Thailand)" }, "aws-global": { "description": "aws global region" }, "ca-central-1": { "description": "Canada (Central)" }, "ca-west-1": { "description": "Canada West (Calgary)" }, "eu-central-1": { "description": "Europe (Frankfurt)" }, "eu-central-2": { "description": "Europe (Zurich)" }, "eu-north-1": { "description": "Europe (Stockholm)" }, "eu-south-1": { "description": "Europe (Milan)" }, "eu-south-2": { "description": "Europe (Spain)" }, "eu-west-1": { "description": "Europe (Ireland)" }, "eu-west-2": { "description": "Europe (London)" }, "eu-west-3": { "description": "Europe (Paris)" }, "il-central-1": { "description": "Israel (Tel Aviv)" }, "me-central-1": { "description": "Middle East (UAE)" }, "me-south-1": { "description": "Middle East (Bahrain)" }, "mx-central-1": { "description": "Mexico (Central)" }, "sa-east-1": { "description": "South America (Sao Paulo)" }, "us-east-1": { "description": "US East (N. Virginia)" }, "us-east-2": { "description": "US East (Ohio)" }, "us-west-1": { "description": "US West (N. California)" }, "us-west-2": { "description": "US West (Oregon)" } } }, { "id": "aws-cn", "outputs": { "dnsSuffix": "amazonaws.com.cn", "dualStackDnsSuffix": "api.amazonwebservices.com.cn", "implicitGlobalRegion": "cn-northwest-1", "name": "aws-cn", "supportsDualStack": true, "supportsFIPS": true }, "regionRegex": "^cn\\-\\w+\\-\\d+$", "regions": { "aws-cn-global": { "description": "aws-cn global region" }, "cn-north-1": { "description": "China (Beijing)" }, "cn-northwest-1": { "description": "China (Ningxia)" } } }, { "id": "aws-eusc", "outputs": { "dnsSuffix": "amazonaws.eu", "dualStackDnsSuffix": "api.amazonwebservices.eu", "implicitGlobalRegion": "eusc-de-east-1", "name": "aws-eusc", "supportsDualStack": true, "supportsFIPS": true }, "regionRegex": "^eusc\\-(de)\\-\\w+\\-\\d+$", "regions": { "eusc-de-east-1": { "description": "AWS European Sovereign Cloud (Germany)" } } }, { "id": "aws-iso", "outputs": { "dnsSuffix": "c2s.ic.gov", "dualStackDnsSuffix": "api.aws.ic.gov", "implicitGlobalRegion": "us-iso-east-1", "name": "aws-iso", "supportsDualStack": true, "supportsFIPS": true }, "regionRegex": "^us\\-iso\\-\\w+\\-\\d+$", "regions": { "aws-iso-global": { "description": "aws-iso global region" }, "us-iso-east-1": { "description": "US ISO East" }, "us-iso-west-1": { "description": "US ISO WEST" } } }, { "id": "aws-iso-b", "outputs": { "dnsSuffix": "sc2s.sgov.gov", "dualStackDnsSuffix": "api.aws.scloud", "implicitGlobalRegion": "us-isob-east-1", "name": "aws-iso-b", "supportsDualStack": true, "supportsFIPS": true }, "regionRegex": "^us\\-isob\\-\\w+\\-\\d+$", "regions": { "aws-iso-b-global": { "description": "aws-iso-b global region" }, "us-isob-east-1": { "description": "US ISOB East (Ohio)" }, "us-isob-west-1": { "description": "US ISOB West" } } }, { "id": "aws-iso-e", "outputs": { "dnsSuffix": "cloud.adc-e.uk", "dualStackDnsSuffix": "api.cloud-aws.adc-e.uk", "implicitGlobalRegion": "eu-isoe-west-1", "name": "aws-iso-e", "supportsDualStack": true, "supportsFIPS": true }, "regionRegex": "^eu\\-isoe\\-\\w+\\-\\d+$", "regions": { "aws-iso-e-global": { "description": "aws-iso-e global region" }, "eu-isoe-west-1": { "description": "EU ISOE West" } } }, { "id": "aws-iso-f", "outputs": { "dnsSuffix": "csp.hci.ic.gov", "dualStackDnsSuffix": "api.aws.hci.ic.gov", "implicitGlobalRegion": "us-isof-south-1", "name": "aws-iso-f", "supportsDualStack": true, "supportsFIPS": true }, "regionRegex": "^us\\-isof\\-\\w+\\-\\d+$", "regions": { "aws-iso-f-global": { "description": "aws-iso-f global region" }, "us-isof-east-1": { "description": "US ISOF EAST" }, "us-isof-south-1": { "description": "US ISOF SOUTH" } } }, { "id": "aws-us-gov", "outputs": { "dnsSuffix": "amazonaws.com", "dualStackDnsSuffix": "api.aws", "implicitGlobalRegion": "us-gov-west-1", "name": "aws-us-gov", "supportsDualStack": true, "supportsFIPS": true }, "regionRegex": "^us\\-gov\\-\\w+\\-\\d+$", "regions": { "aws-us-gov-global": { "description": "aws-us-gov global region" }, "us-gov-east-1": { "description": "AWS GovCloud (US-East)" }, "us-gov-west-1": { "description": "AWS GovCloud (US-West)" } } }], "version": "1.1" };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-endpoints/lib/aws/partition.js
var selectedPartitionsInfo, selectedUserAgentPrefix, partition2, setPartitionInfo, useDefaultPartitionInfo, getUserAgentPrefix;
var init_partition = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-endpoints/lib/aws/partition.js"() {
    init_partitions();
    selectedPartitionsInfo = partitionsInfo;
    selectedUserAgentPrefix = "";
    partition2 = /* @__PURE__ */ __name((value) => {
      const { partitions } = selectedPartitionsInfo;
      for (const partition4 of partitions) {
        const { regions, outputs } = partition4;
        for (const [region, regionData] of Object.entries(regions)) {
          if (region === value) {
            return {
              ...outputs,
              ...regionData
            };
          }
        }
      }
      for (const partition4 of partitions) {
        const { regionRegex, outputs } = partition4;
        if (new RegExp(regionRegex).test(value)) {
          return {
            ...outputs
          };
        }
      }
      const DEFAULT_PARTITION = partitions.find((partition4) => partition4.id === "aws");
      if (!DEFAULT_PARTITION) {
        throw new Error("Provided region was not found in the partition array or regex, and default partition with id 'aws' doesn't exist.");
      }
      return {
        ...DEFAULT_PARTITION.outputs
      };
    }, "partition");
    setPartitionInfo = /* @__PURE__ */ __name((partitionsInfo2, userAgentPrefix = "") => {
      selectedPartitionsInfo = partitionsInfo2;
      selectedUserAgentPrefix = userAgentPrefix;
    }, "setPartitionInfo");
    useDefaultPartitionInfo = /* @__PURE__ */ __name(() => {
      setPartitionInfo(partitionsInfo, "");
    }, "useDefaultPartitionInfo");
    getUserAgentPrefix = /* @__PURE__ */ __name(() => selectedUserAgentPrefix, "getUserAgentPrefix");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/middleware-user-agent/check-features.js
async function checkFeatures(context, config2, args) {
  const request4 = args.request;
  if (request4?.headers?.["smithy-protocol"] === "rpc-v2-cbor") {
    setFeature12(context, "PROTOCOL_RPC_V2_CBOR", "M");
  }
  if (typeof config2.retryStrategy === "function") {
    const retryStrategy = await config2.retryStrategy();
    if (typeof retryStrategy.mode === "string") {
      switch (retryStrategy.mode) {
        case RETRY_MODES2.ADAPTIVE:
          setFeature12(context, "RETRY_MODE_ADAPTIVE", "F");
          break;
        case RETRY_MODES2.STANDARD:
          setFeature12(context, "RETRY_MODE_STANDARD", "E");
          break;
      }
    }
  }
  if (typeof config2.accountIdEndpointMode === "function") {
    const endpointV2 = context.endpointV2;
    if (String(endpointV2?.url?.hostname).match(ACCOUNT_ID_ENDPOINT_REGEX)) {
      setFeature12(context, "ACCOUNT_ID_ENDPOINT", "O");
    }
    switch (await config2.accountIdEndpointMode?.()) {
      case "disabled":
        setFeature12(context, "ACCOUNT_ID_MODE_DISABLED", "Q");
        break;
      case "preferred":
        setFeature12(context, "ACCOUNT_ID_MODE_PREFERRED", "P");
        break;
      case "required":
        setFeature12(context, "ACCOUNT_ID_MODE_REQUIRED", "R");
        break;
    }
  }
  const identity = context.__smithy_context?.selectedHttpAuthScheme?.identity;
  if (identity?.$source) {
    const credentials = identity;
    if (credentials.accountId) {
      setFeature12(context, "RESOLVED_ACCOUNT_ID", "T");
    }
    for (const [key, value] of Object.entries(credentials.$source ?? {})) {
      setFeature12(context, key, value);
    }
  }
}
var ACCOUNT_ID_ENDPOINT_REGEX;
var init_check_features = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/middleware-user-agent/check-features.js"() {
    init_retry3();
    init_setFeature10();
    ACCOUNT_ID_ENDPOINT_REGEX = /\d{12}\.ddb/;
    __name(checkFeatures, "checkFeatures");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/middleware-user-agent/constants.js
var USER_AGENT2, X_AMZ_USER_AGENT, SPACE, UA_NAME_SEPARATOR, UA_NAME_ESCAPE_REGEX, UA_VALUE_ESCAPE_REGEX, UA_ESCAPE_CHAR;
var init_constants9 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/middleware-user-agent/constants.js"() {
    USER_AGENT2 = "user-agent";
    X_AMZ_USER_AGENT = "x-amz-user-agent";
    SPACE = " ";
    UA_NAME_SEPARATOR = "/";
    UA_NAME_ESCAPE_REGEX = /[^!$%&'*+\-.^_`|~\w]/g;
    UA_VALUE_ESCAPE_REGEX = /[^!$%&'*+\-.^_`|~\w#]/g;
    UA_ESCAPE_CHAR = "-";
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/middleware-user-agent/encode-features.js
function encodeFeatures(features) {
  let buffer = "";
  for (const key in features) {
    const val = features[key];
    if (buffer.length + val.length + 1 <= BYTE_LIMIT) {
      if (buffer.length) {
        buffer += "," + val;
      } else {
        buffer += val;
      }
      continue;
    }
    break;
  }
  return buffer;
}
var BYTE_LIMIT;
var init_encode_features = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/middleware-user-agent/encode-features.js"() {
    BYTE_LIMIT = 1024;
    __name(encodeFeatures, "encodeFeatures");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/middleware-user-agent/user-agent-middleware.js
var userAgentMiddleware, escapeUserAgent, getUserAgentMiddlewareOptions, getUserAgentPlugin19;
var init_user_agent_middleware = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/middleware-user-agent/user-agent-middleware.js"() {
    init_protocols11();
    init_partition();
    init_check_features();
    init_constants9();
    init_encode_features();
    userAgentMiddleware = /* @__PURE__ */ __name((options) => (next, context) => async (args) => {
      const { request: request4 } = args;
      if (!HttpRequest22.isInstance(request4)) {
        return next(args);
      }
      const { headers } = request4;
      const userAgent = context?.userAgent?.map(escapeUserAgent) || [];
      const defaultUserAgent2 = (await options.defaultUserAgentProvider()).map(escapeUserAgent);
      await checkFeatures(context, options, args);
      const awsContext = context;
      defaultUserAgent2.push(`m/${encodeFeatures(Object.assign({}, context.__smithy_context?.features, awsContext.__aws_sdk_context?.features))}`);
      const customUserAgent = options?.customUserAgent?.map(escapeUserAgent) || [];
      const appId = await options.userAgentAppId();
      if (appId) {
        defaultUserAgent2.push(escapeUserAgent([`app`, `${appId}`]));
      }
      const prefix = getUserAgentPrefix();
      const sdkUserAgentValue = (prefix ? [prefix] : []).concat([...defaultUserAgent2, ...userAgent, ...customUserAgent]).join(SPACE);
      const normalUAValue = [
        ...defaultUserAgent2.filter((section) => section.startsWith("aws-sdk-")),
        ...customUserAgent
      ].join(SPACE);
      if (options.runtime !== "browser") {
        if (normalUAValue) {
          headers[X_AMZ_USER_AGENT] = headers[X_AMZ_USER_AGENT] ? `${headers[USER_AGENT2]} ${normalUAValue}` : normalUAValue;
        }
        headers[USER_AGENT2] = sdkUserAgentValue;
      } else {
        headers[X_AMZ_USER_AGENT] = sdkUserAgentValue;
      }
      return next({
        ...args,
        request: request4
      });
    }, "userAgentMiddleware");
    escapeUserAgent = /* @__PURE__ */ __name((userAgentPair) => {
      const name = userAgentPair[0].split(UA_NAME_SEPARATOR).map((part) => part.replace(UA_NAME_ESCAPE_REGEX, UA_ESCAPE_CHAR)).join(UA_NAME_SEPARATOR);
      const version = userAgentPair[1]?.replace(UA_VALUE_ESCAPE_REGEX, UA_ESCAPE_CHAR);
      const prefixSeparatorIndex = name.indexOf(UA_NAME_SEPARATOR);
      const prefix = name.substring(0, prefixSeparatorIndex);
      let uaName = name.substring(prefixSeparatorIndex + 1);
      if (prefix === "api") {
        uaName = uaName.toLowerCase();
      }
      return [prefix, uaName, version].filter((item) => item && item.length > 0).reduce((acc, item, index) => {
        switch (index) {
          case 0:
            return item;
          case 1:
            return `${acc}/${item}`;
          default:
            return `${acc}#${item}`;
        }
      }, "");
    }, "escapeUserAgent");
    getUserAgentMiddlewareOptions = {
      name: "getUserAgentMiddleware",
      step: "build",
      priority: "low",
      tags: ["SET_USER_AGENT", "USER_AGENT"],
      override: true
    };
    getUserAgentPlugin19 = /* @__PURE__ */ __name((config2) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(userAgentMiddleware(config2), getUserAgentMiddlewareOptions);
      }, "applyToStack")
    }), "getUserAgentPlugin");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-user-agent-node/getRuntimeUserAgentPair.js
var import_node_process, getRuntimeUserAgentPair;
var init_getRuntimeUserAgentPair = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-user-agent-node/getRuntimeUserAgentPair.js"() {
    import_node_process = require("node:process");
    getRuntimeUserAgentPair = /* @__PURE__ */ __name(() => {
      const runtimesToCheck = ["deno", "bun", "llrt"];
      for (const runtime of runtimesToCheck) {
        if (import_node_process.versions[runtime]) {
          return [`md/${runtime}`, import_node_process.versions[runtime]];
        }
      }
      return ["md/nodejs", import_node_process.versions.node];
    }, "getRuntimeUserAgentPair");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-user-agent-node/getNodeModulesParentDirs.js
var import_node_path10, getNodeModulesParentDirs;
var init_getNodeModulesParentDirs = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-user-agent-node/getNodeModulesParentDirs.js"() {
    import_node_path10 = require("node:path");
    getNodeModulesParentDirs = /* @__PURE__ */ __name((dirname14) => {
      const cwd = process.cwd();
      if (!dirname14) {
        return [cwd];
      }
      const normalizedPath = (0, import_node_path10.normalize)(dirname14);
      const parts = normalizedPath.split(import_node_path10.sep);
      const nodeModulesIndex = parts.indexOf("node_modules");
      const parentDir = nodeModulesIndex !== -1 ? parts.slice(0, nodeModulesIndex).join(import_node_path10.sep) : normalizedPath;
      if (cwd === parentDir) {
        return [cwd];
      }
      return [parentDir, cwd];
    }, "getNodeModulesParentDirs");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-user-agent-node/getSanitizedTypeScriptVersion.js
var SEMVER_REGEX, getSanitizedTypeScriptVersion;
var init_getSanitizedTypeScriptVersion = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-user-agent-node/getSanitizedTypeScriptVersion.js"() {
    SEMVER_REGEX = /^(0|[1-9]\d*)\.(0|[1-9]\d*)\.(0|[1-9]\d*)(?:-((?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*)(?:\.(?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*))*))?(?:\+[0-9a-zA-Z-]+(?:\.[0-9a-zA-Z-]+)*)?$/;
    getSanitizedTypeScriptVersion = /* @__PURE__ */ __name((version = "") => {
      const match = version.match(SEMVER_REGEX);
      if (!match) {
        return void 0;
      }
      const [major6, minor, patch, prerelease] = [match[1], match[2], match[3], match[4]];
      return prerelease ? `${major6}.${minor}.${patch}-${prerelease}` : `${major6}.${minor}.${patch}`;
    }, "getSanitizedTypeScriptVersion");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-user-agent-node/getSanitizedDevTypeScriptVersion.js
var ALLOWED_PREFIXES, ALLOWED_DIST_TAGS, getSanitizedDevTypeScriptVersion;
var init_getSanitizedDevTypeScriptVersion = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-user-agent-node/getSanitizedDevTypeScriptVersion.js"() {
    init_getSanitizedTypeScriptVersion();
    ALLOWED_PREFIXES = ["^", "~", ">=", "<=", ">", "<"];
    ALLOWED_DIST_TAGS = ["latest", "beta", "dev", "rc", "insiders", "next"];
    getSanitizedDevTypeScriptVersion = /* @__PURE__ */ __name((version = "") => {
      if (ALLOWED_DIST_TAGS.includes(version)) {
        return version;
      }
      const prefix = ALLOWED_PREFIXES.find((p10) => version.startsWith(p10)) ?? "";
      const sanitizedTypeScriptVersion = getSanitizedTypeScriptVersion(version.slice(prefix.length));
      if (!sanitizedTypeScriptVersion) {
        return void 0;
      }
      return `${prefix}${sanitizedTypeScriptVersion}`;
    }, "getSanitizedDevTypeScriptVersion");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-user-agent-node/getTypeScriptUserAgentPair.js
var import_promises4, import_node_path11, tscVersion, TS_PACKAGE_JSON, getTypeScriptUserAgentPair;
var init_getTypeScriptUserAgentPair = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-user-agent-node/getTypeScriptUserAgentPair.js"() {
    init_config4();
    import_promises4 = require("node:fs/promises");
    import_node_path11 = require("node:path");
    init_getNodeModulesParentDirs();
    init_getSanitizedDevTypeScriptVersion();
    init_getSanitizedTypeScriptVersion();
    TS_PACKAGE_JSON = (0, import_node_path11.join)("node_modules", "typescript", "package.json");
    getTypeScriptUserAgentPair = /* @__PURE__ */ __name(async () => {
      if (tscVersion === null) {
        return void 0;
      } else if (typeof tscVersion === "string") {
        return ["md/tsc", tscVersion];
      }
      let isTypeScriptDetectionDisabled = false;
      try {
        isTypeScriptDetectionDisabled = booleanSelector(process.env, "AWS_SDK_JS_TYPESCRIPT_DETECTION_DISABLED", SelectorType.ENV) || false;
      } catch {
      }
      if (isTypeScriptDetectionDisabled) {
        tscVersion = null;
        return void 0;
      }
      const dirname14 = typeof __dirname !== "undefined" ? __dirname : void 0;
      const nodeModulesParentDirs = getNodeModulesParentDirs(dirname14);
      let versionFromApp;
      for (const nodeModulesParentDir of nodeModulesParentDirs) {
        try {
          const appPackageJsonPath = (0, import_node_path11.join)(nodeModulesParentDir, "package.json");
          const packageJson = await (0, import_promises4.readFile)(appPackageJsonPath, "utf-8");
          const { dependencies, devDependencies } = JSON.parse(packageJson);
          const version = devDependencies?.typescript ?? dependencies?.typescript;
          if (typeof version !== "string") {
            continue;
          }
          versionFromApp = version;
          break;
        } catch {
        }
      }
      if (!versionFromApp) {
        tscVersion = null;
        return void 0;
      }
      let versionFromNodeModules;
      for (const nodeModulesParentDir of nodeModulesParentDirs) {
        try {
          const tsPackageJsonPath = (0, import_node_path11.join)(nodeModulesParentDir, TS_PACKAGE_JSON);
          const packageJson = await (0, import_promises4.readFile)(tsPackageJsonPath, "utf-8");
          const { version } = JSON.parse(packageJson);
          const sanitizedVersion2 = getSanitizedTypeScriptVersion(version);
          if (typeof sanitizedVersion2 !== "string") {
            continue;
          }
          versionFromNodeModules = sanitizedVersion2;
          break;
        } catch {
        }
      }
      if (versionFromNodeModules) {
        tscVersion = versionFromNodeModules;
        return ["md/tsc", tscVersion];
      }
      const sanitizedVersion = getSanitizedDevTypeScriptVersion(versionFromApp);
      if (typeof sanitizedVersion !== "string") {
        tscVersion = null;
        return void 0;
      }
      tscVersion = `dev_${sanitizedVersion}`;
      return ["md/tsc", tscVersion];
    }, "getTypeScriptUserAgentPair");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-user-agent-node/crt-availability.js
var crtAvailability;
var init_crt_availability = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-user-agent-node/crt-availability.js"() {
    crtAvailability = {
      isCrtAvailable: false
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-user-agent-node/is-crt-available.js
var isCrtAvailable;
var init_is_crt_available = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-user-agent-node/is-crt-available.js"() {
    init_crt_availability();
    isCrtAvailable = /* @__PURE__ */ __name(() => {
      if (crtAvailability.isCrtAvailable) {
        return ["md/crt-avail"];
      }
      return null;
    }, "isCrtAvailable");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-user-agent-node/defaultUserAgent.js
var import_node_os3, import_node_process2, createDefaultUserAgentProvider19, defaultUserAgent;
var init_defaultUserAgent = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-user-agent-node/defaultUserAgent.js"() {
    import_node_os3 = require("node:os");
    import_node_process2 = require("node:process");
    init_getRuntimeUserAgentPair();
    init_getTypeScriptUserAgentPair();
    init_is_crt_available();
    init_crt_availability();
    createDefaultUserAgentProvider19 = /* @__PURE__ */ __name(({ serviceId, clientVersion }) => {
      const runtimeUserAgentPair = getRuntimeUserAgentPair();
      return async (config2) => {
        const sections = [
          ["aws-sdk-js", clientVersion],
          ["ua", "2.1"],
          [`os/${(0, import_node_os3.platform)()}`, (0, import_node_os3.release)()],
          ["lang/js"],
          runtimeUserAgentPair
        ];
        const typescriptUserAgentPair = await getTypeScriptUserAgentPair();
        if (typescriptUserAgentPair) {
          sections.push(typescriptUserAgentPair);
        }
        const crtAvailable = isCrtAvailable();
        if (crtAvailable) {
          sections.push(crtAvailable);
        }
        if (serviceId) {
          sections.push([`api/${serviceId}`, clientVersion]);
        }
        if (import_node_process2.env.AWS_EXECUTION_ENV) {
          sections.push([`exec-env/${import_node_process2.env.AWS_EXECUTION_ENV}`]);
        }
        const appId = await config2?.userAgentAppId?.();
        const resolvedUserAgent = appId ? [...sections, [`app/${appId}`]] : [...sections];
        return resolvedUserAgent;
      };
    }, "createDefaultUserAgentProvider");
    defaultUserAgent = createDefaultUserAgentProvider19;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-user-agent-node/nodeAppIdConfigOptions.js
var UA_APP_ID_ENV_NAME, UA_APP_ID_INI_NAME, UA_APP_ID_INI_NAME_DEPRECATED, NODE_APP_ID_CONFIG_OPTIONS19;
var init_nodeAppIdConfigOptions = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-user-agent-node/nodeAppIdConfigOptions.js"() {
    init_configurations3();
    UA_APP_ID_ENV_NAME = "AWS_SDK_UA_APP_ID";
    UA_APP_ID_INI_NAME = "sdk_ua_app_id";
    UA_APP_ID_INI_NAME_DEPRECATED = "sdk-ua-app-id";
    NODE_APP_ID_CONFIG_OPTIONS19 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[UA_APP_ID_ENV_NAME], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[UA_APP_ID_INI_NAME] ?? profile[UA_APP_ID_INI_NAME_DEPRECATED], "configFileSelector"),
      default: DEFAULT_UA_APP_ID
    };
  }
});

// ../../node_modules/bowser/es5.js
var require_es5 = __commonJS({
  "../../node_modules/bowser/es5.js"(exports2, module2) {
    !(function(e32, t) {
      "object" == typeof exports2 && "object" == typeof module2 ? module2.exports = t() : "function" == typeof define && define.amd ? define([], t) : "object" == typeof exports2 ? exports2.bowser = t() : e32.bowser = t();
    })(exports2, (function() {
      return (function(e32) {
        var t = {};
        function r32(i32) {
          if (t[i32]) return t[i32].exports;
          var n10 = t[i32] = { i: i32, l: false, exports: {} };
          return e32[i32].call(n10.exports, n10, n10.exports, r32), n10.l = true, n10.exports;
        }
        __name(r32, "r");
        return r32.m = e32, r32.c = t, r32.d = function(e33, t2, i32) {
          r32.o(e33, t2) || Object.defineProperty(e33, t2, { enumerable: true, get: i32 });
        }, r32.r = function(e33) {
          "undefined" != typeof Symbol && Symbol.toStringTag && Object.defineProperty(e33, Symbol.toStringTag, { value: "Module" }), Object.defineProperty(e33, "__esModule", { value: true });
        }, r32.t = function(e33, t2) {
          if (1 & t2 && (e33 = r32(e33)), 8 & t2) return e33;
          if (4 & t2 && "object" == typeof e33 && e33 && e33.__esModule) return e33;
          var i32 = /* @__PURE__ */ Object.create(null);
          if (r32.r(i32), Object.defineProperty(i32, "default", { enumerable: true, value: e33 }), 2 & t2 && "string" != typeof e33) for (var n10 in e33) r32.d(i32, n10, function(t3) {
            return e33[t3];
          }.bind(null, n10));
          return i32;
        }, r32.n = function(e33) {
          var t2 = e33 && e33.__esModule ? function() {
            return e33.default;
          } : function() {
            return e33;
          };
          return r32.d(t2, "a", t2), t2;
        }, r32.o = function(e33, t2) {
          return Object.prototype.hasOwnProperty.call(e33, t2);
        }, r32.p = "", r32(r32.s = 90);
      })({ 17: function(e32, t, r32) {
        "use strict";
        t.__esModule = true, t.default = void 0;
        var i32 = r32(18), n10 = (function() {
          function e33() {
          }
          __name(e33, "e");
          return e33.getFirstMatch = function(e34, t2) {
            var r33 = t2.match(e34);
            return r33 && r33.length > 0 && r33[1] || "";
          }, e33.getSecondMatch = function(e34, t2) {
            var r33 = t2.match(e34);
            return r33 && r33.length > 1 && r33[2] || "";
          }, e33.matchAndReturnConst = function(e34, t2, r33) {
            if (e34.test(t2)) return r33;
          }, e33.getWindowsVersionName = function(e34) {
            switch (e34) {
              case "NT":
                return "NT";
              case "XP":
                return "XP";
              case "NT 5.0":
                return "2000";
              case "NT 5.1":
                return "XP";
              case "NT 5.2":
                return "2003";
              case "NT 6.0":
                return "Vista";
              case "NT 6.1":
                return "7";
              case "NT 6.2":
                return "8";
              case "NT 6.3":
                return "8.1";
              case "NT 10.0":
                return "10";
              default:
                return;
            }
          }, e33.getMacOSVersionName = function(e34) {
            var t2 = e34.split(".").splice(0, 2).map((function(e35) {
              return parseInt(e35, 10) || 0;
            }));
            t2.push(0);
            var r33 = t2[0], i33 = t2[1];
            if (10 === r33) switch (i33) {
              case 5:
                return "Leopard";
              case 6:
                return "Snow Leopard";
              case 7:
                return "Lion";
              case 8:
                return "Mountain Lion";
              case 9:
                return "Mavericks";
              case 10:
                return "Yosemite";
              case 11:
                return "El Capitan";
              case 12:
                return "Sierra";
              case 13:
                return "High Sierra";
              case 14:
                return "Mojave";
              case 15:
                return "Catalina";
              default:
                return;
            }
            switch (r33) {
              case 11:
                return "Big Sur";
              case 12:
                return "Monterey";
              case 13:
                return "Ventura";
              case 14:
                return "Sonoma";
              case 15:
                return "Sequoia";
              default:
                return;
            }
          }, e33.getAndroidVersionName = function(e34) {
            var t2 = e34.split(".").splice(0, 2).map((function(e35) {
              return parseInt(e35, 10) || 0;
            }));
            if (t2.push(0), !(1 === t2[0] && t2[1] < 5)) return 1 === t2[0] && t2[1] < 6 ? "Cupcake" : 1 === t2[0] && t2[1] >= 6 ? "Donut" : 2 === t2[0] && t2[1] < 2 ? "Eclair" : 2 === t2[0] && 2 === t2[1] ? "Froyo" : 2 === t2[0] && t2[1] > 2 ? "Gingerbread" : 3 === t2[0] ? "Honeycomb" : 4 === t2[0] && t2[1] < 1 ? "Ice Cream Sandwich" : 4 === t2[0] && t2[1] < 4 ? "Jelly Bean" : 4 === t2[0] && t2[1] >= 4 ? "KitKat" : 5 === t2[0] ? "Lollipop" : 6 === t2[0] ? "Marshmallow" : 7 === t2[0] ? "Nougat" : 8 === t2[0] ? "Oreo" : 9 === t2[0] ? "Pie" : void 0;
          }, e33.getVersionPrecision = function(e34) {
            return e34.split(".").length;
          }, e33.compareVersions = function(t2, r33, i33) {
            void 0 === i33 && (i33 = false);
            var n11 = e33.getVersionPrecision(t2), a32 = e33.getVersionPrecision(r33), o10 = Math.max(n11, a32), s = 0, u = e33.map([t2, r33], (function(t3) {
              var r34 = o10 - e33.getVersionPrecision(t3), i34 = t3 + new Array(r34 + 1).join(".0");
              return e33.map(i34.split("."), (function(e34) {
                return new Array(20 - e34.length).join("0") + e34;
              })).reverse();
            }));
            for (i33 && (s = o10 - Math.min(n11, a32)), o10 -= 1; o10 >= s; ) {
              if (u[0][o10] > u[1][o10]) return 1;
              if (u[0][o10] === u[1][o10]) {
                if (o10 === s) return 0;
                o10 -= 1;
              } else if (u[0][o10] < u[1][o10]) return -1;
            }
          }, e33.map = function(e34, t2) {
            var r33, i33 = [];
            if (Array.prototype.map) return Array.prototype.map.call(e34, t2);
            for (r33 = 0; r33 < e34.length; r33 += 1) i33.push(t2(e34[r33]));
            return i33;
          }, e33.find = function(e34, t2) {
            var r33, i33;
            if (Array.prototype.find) return Array.prototype.find.call(e34, t2);
            for (r33 = 0, i33 = e34.length; r33 < i33; r33 += 1) {
              var n11 = e34[r33];
              if (t2(n11, r33)) return n11;
            }
          }, e33.assign = function(e34) {
            for (var t2, r33, i33 = e34, n11 = arguments.length, a32 = new Array(n11 > 1 ? n11 - 1 : 0), o10 = 1; o10 < n11; o10++) a32[o10 - 1] = arguments[o10];
            if (Object.assign) return Object.assign.apply(Object, [e34].concat(a32));
            var s = /* @__PURE__ */ __name(function() {
              var e35 = a32[t2];
              "object" == typeof e35 && null !== e35 && Object.keys(e35).forEach((function(t3) {
                i33[t3] = e35[t3];
              }));
            }, "s");
            for (t2 = 0, r33 = a32.length; t2 < r33; t2 += 1) s();
            return e34;
          }, e33.getBrowserAlias = function(e34) {
            return i32.BROWSER_ALIASES_MAP[e34];
          }, e33.getBrowserTypeByAlias = function(e34) {
            return i32.BROWSER_MAP[e34] || "";
          }, e33;
        })();
        t.default = n10, e32.exports = t.default;
      }, 18: function(e32, t, r32) {
        "use strict";
        t.__esModule = true, t.ENGINE_MAP = t.OS_MAP = t.PLATFORMS_MAP = t.BROWSER_MAP = t.BROWSER_ALIASES_MAP = void 0;
        t.BROWSER_ALIASES_MAP = { AmazonBot: "amazonbot", "Amazon Silk": "amazon_silk", "Android Browser": "android", BaiduSpider: "baiduspider", Bada: "bada", BingCrawler: "bingcrawler", Brave: "brave", BlackBerry: "blackberry", "ChatGPT-User": "chatgpt_user", Chrome: "chrome", ClaudeBot: "claudebot", Chromium: "chromium", Diffbot: "diffbot", DuckDuckBot: "duckduckbot", DuckDuckGo: "duckduckgo", Electron: "electron", Epiphany: "epiphany", FacebookExternalHit: "facebookexternalhit", Firefox: "firefox", Focus: "focus", Generic: "generic", "Google Search": "google_search", Googlebot: "googlebot", GPTBot: "gptbot", "Internet Explorer": "ie", InternetArchiveCrawler: "internetarchivecrawler", "K-Meleon": "k_meleon", LibreWolf: "librewolf", Linespider: "linespider", Maxthon: "maxthon", "Meta-ExternalAds": "meta_externalads", "Meta-ExternalAgent": "meta_externalagent", "Meta-ExternalFetcher": "meta_externalfetcher", "Meta-WebIndexer": "meta_webindexer", "Microsoft Edge": "edge", "MZ Browser": "mz", "NAVER Whale Browser": "naver", "OAI-SearchBot": "oai_searchbot", Omgilibot: "omgilibot", Opera: "opera", "Opera Coast": "opera_coast", "Pale Moon": "pale_moon", PerplexityBot: "perplexitybot", "Perplexity-User": "perplexity_user", PhantomJS: "phantomjs", PingdomBot: "pingdombot", Puffin: "puffin", QQ: "qq", QQLite: "qqlite", QupZilla: "qupzilla", Roku: "roku", Safari: "safari", Sailfish: "sailfish", "Samsung Internet for Android": "samsung_internet", SlackBot: "slackbot", SeaMonkey: "seamonkey", Sleipnir: "sleipnir", "Sogou Browser": "sogou", Swing: "swing", Tizen: "tizen", "UC Browser": "uc", Vivaldi: "vivaldi", "WebOS Browser": "webos", WeChat: "wechat", YahooSlurp: "yahooslurp", "Yandex Browser": "yandex", YandexBot: "yandexbot", YouBot: "youbot" };
        t.BROWSER_MAP = { amazonbot: "AmazonBot", amazon_silk: "Amazon Silk", android: "Android Browser", baiduspider: "BaiduSpider", bada: "Bada", bingcrawler: "BingCrawler", blackberry: "BlackBerry", brave: "Brave", chatgpt_user: "ChatGPT-User", chrome: "Chrome", claudebot: "ClaudeBot", chromium: "Chromium", diffbot: "Diffbot", duckduckbot: "DuckDuckBot", duckduckgo: "DuckDuckGo", edge: "Microsoft Edge", electron: "Electron", epiphany: "Epiphany", facebookexternalhit: "FacebookExternalHit", firefox: "Firefox", focus: "Focus", generic: "Generic", google_search: "Google Search", googlebot: "Googlebot", gptbot: "GPTBot", ie: "Internet Explorer", internetarchivecrawler: "InternetArchiveCrawler", k_meleon: "K-Meleon", librewolf: "LibreWolf", linespider: "Linespider", maxthon: "Maxthon", meta_externalads: "Meta-ExternalAds", meta_externalagent: "Meta-ExternalAgent", meta_externalfetcher: "Meta-ExternalFetcher", meta_webindexer: "Meta-WebIndexer", mz: "MZ Browser", naver: "NAVER Whale Browser", oai_searchbot: "OAI-SearchBot", omgilibot: "Omgilibot", opera: "Opera", opera_coast: "Opera Coast", pale_moon: "Pale Moon", perplexitybot: "PerplexityBot", perplexity_user: "Perplexity-User", phantomjs: "PhantomJS", pingdombot: "PingdomBot", puffin: "Puffin", qq: "QQ Browser", qqlite: "QQ Browser Lite", qupzilla: "QupZilla", roku: "Roku", safari: "Safari", sailfish: "Sailfish", samsung_internet: "Samsung Internet for Android", seamonkey: "SeaMonkey", slackbot: "SlackBot", sleipnir: "Sleipnir", sogou: "Sogou Browser", swing: "Swing", tizen: "Tizen", uc: "UC Browser", vivaldi: "Vivaldi", webos: "WebOS Browser", wechat: "WeChat", yahooslurp: "YahooSlurp", yandex: "Yandex Browser", yandexbot: "YandexBot", youbot: "YouBot" };
        t.PLATFORMS_MAP = { bot: "bot", desktop: "desktop", mobile: "mobile", tablet: "tablet", tv: "tv" };
        t.OS_MAP = { Android: "Android", Bada: "Bada", BlackBerry: "BlackBerry", ChromeOS: "Chrome OS", HarmonyOS: "HarmonyOS", iOS: "iOS", Linux: "Linux", MacOS: "macOS", PlayStation4: "PlayStation 4", Roku: "Roku", Tizen: "Tizen", WebOS: "WebOS", Windows: "Windows", WindowsPhone: "Windows Phone" };
        t.ENGINE_MAP = { Blink: "Blink", EdgeHTML: "EdgeHTML", Gecko: "Gecko", Presto: "Presto", Trident: "Trident", WebKit: "WebKit" };
      }, 90: function(e32, t, r32) {
        "use strict";
        t.__esModule = true, t.default = void 0;
        var i32, n10 = (i32 = r32(91)) && i32.__esModule ? i32 : { default: i32 }, a32 = r32(18);
        function o10(e33, t2) {
          for (var r33 = 0; r33 < t2.length; r33++) {
            var i33 = t2[r33];
            i33.enumerable = i33.enumerable || false, i33.configurable = true, "value" in i33 && (i33.writable = true), Object.defineProperty(e33, i33.key, i33);
          }
        }
        __name(o10, "o");
        var s = (function() {
          function e33() {
          }
          __name(e33, "e");
          var t2, r33, i33;
          return e33.getParser = function(e34, t3, r34) {
            if (void 0 === t3 && (t3 = false), void 0 === r34 && (r34 = null), "string" != typeof e34) throw new Error("UserAgent should be a string");
            return new n10.default(e34, t3, r34);
          }, e33.parse = function(e34, t3) {
            return void 0 === t3 && (t3 = null), new n10.default(e34, t3).getResult();
          }, t2 = e33, i33 = [{ key: "BROWSER_MAP", get: /* @__PURE__ */ __name(function() {
            return a32.BROWSER_MAP;
          }, "get") }, { key: "ENGINE_MAP", get: /* @__PURE__ */ __name(function() {
            return a32.ENGINE_MAP;
          }, "get") }, { key: "OS_MAP", get: /* @__PURE__ */ __name(function() {
            return a32.OS_MAP;
          }, "get") }, { key: "PLATFORMS_MAP", get: /* @__PURE__ */ __name(function() {
            return a32.PLATFORMS_MAP;
          }, "get") }], (r33 = null) && o10(t2.prototype, r33), i33 && o10(t2, i33), e33;
        })();
        t.default = s, e32.exports = t.default;
      }, 91: function(e32, t, r32) {
        "use strict";
        t.__esModule = true, t.default = void 0;
        var i32 = u(r32(92)), n10 = u(r32(93)), a32 = u(r32(94)), o10 = u(r32(95)), s = u(r32(17));
        function u(e33) {
          return e33 && e33.__esModule ? e33 : { default: e33 };
        }
        __name(u, "u");
        var d32 = (function() {
          function e33(e34, t3, r33) {
            if (void 0 === t3 && (t3 = false), void 0 === r33 && (r33 = null), null == e34 || "" === e34) throw new Error("UserAgent parameter can't be empty");
            this._ua = e34;
            var i33 = false;
            "boolean" == typeof t3 ? (i33 = t3, this._hints = r33) : this._hints = null != t3 && "object" == typeof t3 ? t3 : null, this.parsedResult = {}, true !== i33 && this.parse();
          }
          __name(e33, "e");
          var t2 = e33.prototype;
          return t2.getHints = function() {
            return this._hints;
          }, t2.hasBrand = function(e34) {
            if (!this._hints || !Array.isArray(this._hints.brands)) return false;
            var t3 = e34.toLowerCase();
            return this._hints.brands.some((function(e35) {
              return e35.brand && e35.brand.toLowerCase() === t3;
            }));
          }, t2.getBrandVersion = function(e34) {
            if (this._hints && Array.isArray(this._hints.brands)) {
              var t3 = e34.toLowerCase(), r33 = this._hints.brands.find((function(e35) {
                return e35.brand && e35.brand.toLowerCase() === t3;
              }));
              return r33 ? r33.version : void 0;
            }
          }, t2.getUA = function() {
            return this._ua;
          }, t2.test = function(e34) {
            return e34.test(this._ua);
          }, t2.parseBrowser = function() {
            var e34 = this;
            this.parsedResult.browser = {};
            var t3 = s.default.find(i32.default, (function(t4) {
              if ("function" == typeof t4.test) return t4.test(e34);
              if (Array.isArray(t4.test)) return t4.test.some((function(t5) {
                return e34.test(t5);
              }));
              throw new Error("Browser's test function is not valid");
            }));
            return t3 && (this.parsedResult.browser = t3.describe(this.getUA(), this)), this.parsedResult.browser;
          }, t2.getBrowser = function() {
            return this.parsedResult.browser ? this.parsedResult.browser : this.parseBrowser();
          }, t2.getBrowserName = function(e34) {
            return e34 ? String(this.getBrowser().name).toLowerCase() || "" : this.getBrowser().name || "";
          }, t2.getBrowserVersion = function() {
            return this.getBrowser().version;
          }, t2.getOS = function() {
            return this.parsedResult.os ? this.parsedResult.os : this.parseOS();
          }, t2.parseOS = function() {
            var e34 = this;
            this.parsedResult.os = {};
            var t3 = s.default.find(n10.default, (function(t4) {
              if ("function" == typeof t4.test) return t4.test(e34);
              if (Array.isArray(t4.test)) return t4.test.some((function(t5) {
                return e34.test(t5);
              }));
              throw new Error("Browser's test function is not valid");
            }));
            return t3 && (this.parsedResult.os = t3.describe(this.getUA())), this.parsedResult.os;
          }, t2.getOSName = function(e34) {
            var t3 = this.getOS().name;
            return e34 ? String(t3).toLowerCase() || "" : t3 || "";
          }, t2.getOSVersion = function() {
            return this.getOS().version;
          }, t2.getPlatform = function() {
            return this.parsedResult.platform ? this.parsedResult.platform : this.parsePlatform();
          }, t2.getPlatformType = function(e34) {
            void 0 === e34 && (e34 = false);
            var t3 = this.getPlatform().type;
            return e34 ? String(t3).toLowerCase() || "" : t3 || "";
          }, t2.parsePlatform = function() {
            var e34 = this;
            this.parsedResult.platform = {};
            var t3 = s.default.find(a32.default, (function(t4) {
              if ("function" == typeof t4.test) return t4.test(e34);
              if (Array.isArray(t4.test)) return t4.test.some((function(t5) {
                return e34.test(t5);
              }));
              throw new Error("Browser's test function is not valid");
            }));
            return t3 && (this.parsedResult.platform = t3.describe(this.getUA())), this.parsedResult.platform;
          }, t2.getEngine = function() {
            return this.parsedResult.engine ? this.parsedResult.engine : this.parseEngine();
          }, t2.getEngineName = function(e34) {
            return e34 ? String(this.getEngine().name).toLowerCase() || "" : this.getEngine().name || "";
          }, t2.parseEngine = function() {
            var e34 = this;
            this.parsedResult.engine = {};
            var t3 = s.default.find(o10.default, (function(t4) {
              if ("function" == typeof t4.test) return t4.test(e34);
              if (Array.isArray(t4.test)) return t4.test.some((function(t5) {
                return e34.test(t5);
              }));
              throw new Error("Browser's test function is not valid");
            }));
            return t3 && (this.parsedResult.engine = t3.describe(this.getUA())), this.parsedResult.engine;
          }, t2.parse = function() {
            return this.parseBrowser(), this.parseOS(), this.parsePlatform(), this.parseEngine(), this;
          }, t2.getResult = function() {
            return s.default.assign({}, this.parsedResult);
          }, t2.satisfies = function(e34) {
            var t3 = this, r33 = {}, i33 = 0, n11 = {}, a33 = 0;
            if (Object.keys(e34).forEach((function(t4) {
              var o12 = e34[t4];
              "string" == typeof o12 ? (n11[t4] = o12, a33 += 1) : "object" == typeof o12 && (r33[t4] = o12, i33 += 1);
            })), i33 > 0) {
              var o11 = Object.keys(r33), u2 = s.default.find(o11, (function(e35) {
                return t3.isOS(e35);
              }));
              if (u2) {
                var d33 = this.satisfies(r33[u2]);
                if (void 0 !== d33) return d33;
              }
              var c32 = s.default.find(o11, (function(e35) {
                return t3.isPlatform(e35);
              }));
              if (c32) {
                var f32 = this.satisfies(r33[c32]);
                if (void 0 !== f32) return f32;
              }
            }
            if (a33 > 0) {
              var l20 = Object.keys(n11), b32 = s.default.find(l20, (function(e35) {
                return t3.isBrowser(e35, true);
              }));
              if (void 0 !== b32) return this.compareVersion(n11[b32]);
            }
          }, t2.isBrowser = function(e34, t3) {
            void 0 === t3 && (t3 = false);
            var r33 = this.getBrowserName().toLowerCase(), i33 = e34.toLowerCase(), n11 = s.default.getBrowserTypeByAlias(i33);
            return t3 && n11 && (i33 = n11.toLowerCase()), i33 === r33;
          }, t2.compareVersion = function(e34) {
            var t3 = [0], r33 = e34, i33 = false, n11 = this.getBrowserVersion();
            if ("string" == typeof n11) return ">" === e34[0] || "<" === e34[0] ? (r33 = e34.substr(1), "=" === e34[1] ? (i33 = true, r33 = e34.substr(2)) : t3 = [], ">" === e34[0] ? t3.push(1) : t3.push(-1)) : "=" === e34[0] ? r33 = e34.substr(1) : "~" === e34[0] && (i33 = true, r33 = e34.substr(1)), t3.indexOf(s.default.compareVersions(n11, r33, i33)) > -1;
          }, t2.isOS = function(e34) {
            return this.getOSName(true) === String(e34).toLowerCase();
          }, t2.isPlatform = function(e34) {
            return this.getPlatformType(true) === String(e34).toLowerCase();
          }, t2.isEngine = function(e34) {
            return this.getEngineName(true) === String(e34).toLowerCase();
          }, t2.is = function(e34, t3) {
            return void 0 === t3 && (t3 = false), this.isBrowser(e34, t3) || this.isOS(e34) || this.isPlatform(e34);
          }, t2.some = function(e34) {
            var t3 = this;
            return void 0 === e34 && (e34 = []), e34.some((function(e35) {
              return t3.is(e35);
            }));
          }, e33;
        })();
        t.default = d32, e32.exports = t.default;
      }, 92: function(e32, t, r32) {
        "use strict";
        t.__esModule = true, t.default = void 0;
        var i32, n10 = (i32 = r32(17)) && i32.__esModule ? i32 : { default: i32 };
        var a32 = /version\/(\d+(\.?_?\d+)+)/i, o10 = [{ test: [/gptbot/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "GPTBot" }, r33 = n10.default.getFirstMatch(/gptbot\/(\d+(\.\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/chatgpt-user/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "ChatGPT-User" }, r33 = n10.default.getFirstMatch(/chatgpt-user\/(\d+(\.\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/oai-searchbot/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "OAI-SearchBot" }, r33 = n10.default.getFirstMatch(/oai-searchbot\/(\d+(\.\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/claudebot/i, /claude-web/i, /claude-user/i, /claude-searchbot/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "ClaudeBot" }, r33 = n10.default.getFirstMatch(/(?:claudebot|claude-web|claude-user|claude-searchbot)\/(\d+(\.\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/omgilibot/i, /webzio-extended/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Omgilibot" }, r33 = n10.default.getFirstMatch(/(?:omgilibot|webzio-extended)\/(\d+(\.\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/diffbot/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Diffbot" }, r33 = n10.default.getFirstMatch(/diffbot\/(\d+(\.\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/perplexitybot/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "PerplexityBot" }, r33 = n10.default.getFirstMatch(/perplexitybot\/(\d+(\.\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/perplexity-user/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Perplexity-User" }, r33 = n10.default.getFirstMatch(/perplexity-user\/(\d+(\.\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/youbot/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "YouBot" }, r33 = n10.default.getFirstMatch(/youbot\/(\d+(\.\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/meta-webindexer/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Meta-WebIndexer" }, r33 = n10.default.getFirstMatch(/meta-webindexer\/(\d+(\.\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/meta-externalads/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Meta-ExternalAds" }, r33 = n10.default.getFirstMatch(/meta-externalads\/(\d+(\.\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/meta-externalagent/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Meta-ExternalAgent" }, r33 = n10.default.getFirstMatch(/meta-externalagent\/(\d+(\.\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/meta-externalfetcher/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Meta-ExternalFetcher" }, r33 = n10.default.getFirstMatch(/meta-externalfetcher\/(\d+(\.\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/googlebot/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Googlebot" }, r33 = n10.default.getFirstMatch(/googlebot\/(\d+(\.\d+))/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/linespider/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Linespider" }, r33 = n10.default.getFirstMatch(/(?:linespider)(?:-[-\w]+)?[\s/](\d+(\.\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/amazonbot/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "AmazonBot" }, r33 = n10.default.getFirstMatch(/amazonbot\/(\d+(\.\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/bingbot/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "BingCrawler" }, r33 = n10.default.getFirstMatch(/bingbot\/(\d+(\.\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/baiduspider/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "BaiduSpider" }, r33 = n10.default.getFirstMatch(/baiduspider\/(\d+(\.\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/duckduckbot/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "DuckDuckBot" }, r33 = n10.default.getFirstMatch(/duckduckbot\/(\d+(\.\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/ia_archiver/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "InternetArchiveCrawler" }, r33 = n10.default.getFirstMatch(/ia_archiver\/(\d+(\.\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/facebookexternalhit/i, /facebookcatalog/i], describe: /* @__PURE__ */ __name(function() {
          return { name: "FacebookExternalHit" };
        }, "describe") }, { test: [/slackbot/i, /slack-imgProxy/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "SlackBot" }, r33 = n10.default.getFirstMatch(/(?:slackbot|slack-imgproxy)(?:-[-\w]+)?[\s/](\d+(\.\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/yahoo!?[\s/]*slurp/i], describe: /* @__PURE__ */ __name(function() {
          return { name: "YahooSlurp" };
        }, "describe") }, { test: [/yandexbot/i, /yandexmobilebot/i], describe: /* @__PURE__ */ __name(function() {
          return { name: "YandexBot" };
        }, "describe") }, { test: [/pingdom/i], describe: /* @__PURE__ */ __name(function() {
          return { name: "PingdomBot" };
        }, "describe") }, { test: [/opera/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Opera" }, r33 = n10.default.getFirstMatch(a32, e33) || n10.default.getFirstMatch(/(?:opera)[\s/](\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/opr\/|opios/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Opera" }, r33 = n10.default.getFirstMatch(/(?:opr|opios)[\s/](\S+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/SamsungBrowser/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Samsung Internet for Android" }, r33 = n10.default.getFirstMatch(a32, e33) || n10.default.getFirstMatch(/(?:SamsungBrowser)[\s/](\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/Whale/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "NAVER Whale Browser" }, r33 = n10.default.getFirstMatch(a32, e33) || n10.default.getFirstMatch(/(?:whale)[\s/](\d+(?:\.\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/PaleMoon/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Pale Moon" }, r33 = n10.default.getFirstMatch(a32, e33) || n10.default.getFirstMatch(/(?:PaleMoon)[\s/](\d+(?:\.\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/MZBrowser/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "MZ Browser" }, r33 = n10.default.getFirstMatch(/(?:MZBrowser)[\s/](\d+(?:\.\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/focus/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Focus" }, r33 = n10.default.getFirstMatch(/(?:focus)[\s/](\d+(?:\.\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/swing/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Swing" }, r33 = n10.default.getFirstMatch(/(?:swing)[\s/](\d+(?:\.\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/coast/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Opera Coast" }, r33 = n10.default.getFirstMatch(a32, e33) || n10.default.getFirstMatch(/(?:coast)[\s/](\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/opt\/\d+(?:.?_?\d+)+/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Opera Touch" }, r33 = n10.default.getFirstMatch(/(?:opt)[\s/](\d+(\.?_?\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/yabrowser/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Yandex Browser" }, r33 = n10.default.getFirstMatch(/(?:yabrowser)[\s/](\d+(\.?_?\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/ucbrowser/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "UC Browser" }, r33 = n10.default.getFirstMatch(a32, e33) || n10.default.getFirstMatch(/(?:ucbrowser)[\s/](\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/Maxthon|mxios/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Maxthon" }, r33 = n10.default.getFirstMatch(a32, e33) || n10.default.getFirstMatch(/(?:Maxthon|mxios)[\s/](\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/epiphany/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Epiphany" }, r33 = n10.default.getFirstMatch(a32, e33) || n10.default.getFirstMatch(/(?:epiphany)[\s/](\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/puffin/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Puffin" }, r33 = n10.default.getFirstMatch(a32, e33) || n10.default.getFirstMatch(/(?:puffin)[\s/](\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/sleipnir/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Sleipnir" }, r33 = n10.default.getFirstMatch(a32, e33) || n10.default.getFirstMatch(/(?:sleipnir)[\s/](\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/k-meleon/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "K-Meleon" }, r33 = n10.default.getFirstMatch(a32, e33) || n10.default.getFirstMatch(/(?:k-meleon)[\s/](\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/micromessenger/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "WeChat" }, r33 = n10.default.getFirstMatch(/(?:micromessenger)[\s/](\d+(\.?_?\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/qqbrowser/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: /qqbrowserlite/i.test(e33) ? "QQ Browser Lite" : "QQ Browser" }, r33 = n10.default.getFirstMatch(/(?:qqbrowserlite|qqbrowser)[/](\d+(\.?_?\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/msie|trident/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Internet Explorer" }, r33 = n10.default.getFirstMatch(/(?:msie |rv:)(\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/\sedg\//i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Microsoft Edge" }, r33 = n10.default.getFirstMatch(/\sedg\/(\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/edg([ea]|ios)/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Microsoft Edge" }, r33 = n10.default.getSecondMatch(/edg([ea]|ios)\/(\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/vivaldi/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Vivaldi" }, r33 = n10.default.getFirstMatch(/vivaldi\/(\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/seamonkey/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "SeaMonkey" }, r33 = n10.default.getFirstMatch(/seamonkey\/(\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/sailfish/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Sailfish" }, r33 = n10.default.getFirstMatch(/sailfish\s?browser\/(\d+(\.\d+)?)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/silk/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Amazon Silk" }, r33 = n10.default.getFirstMatch(/silk\/(\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/phantom/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "PhantomJS" }, r33 = n10.default.getFirstMatch(/phantomjs\/(\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/slimerjs/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "SlimerJS" }, r33 = n10.default.getFirstMatch(/slimerjs\/(\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/blackberry|\bbb\d+/i, /rim\stablet/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "BlackBerry" }, r33 = n10.default.getFirstMatch(a32, e33) || n10.default.getFirstMatch(/blackberry[\d]+\/(\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/(web|hpw)[o0]s/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "WebOS Browser" }, r33 = n10.default.getFirstMatch(a32, e33) || n10.default.getFirstMatch(/w(?:eb)?[o0]sbrowser\/(\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/bada/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Bada" }, r33 = n10.default.getFirstMatch(/dolfin\/(\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/tizen/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Tizen" }, r33 = n10.default.getFirstMatch(/(?:tizen\s?)?browser\/(\d+(\.?_?\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/qupzilla/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "QupZilla" }, r33 = n10.default.getFirstMatch(/(?:qupzilla)[\s/](\d+(\.?_?\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/librewolf/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "LibreWolf" }, r33 = n10.default.getFirstMatch(/(?:librewolf)[\s/](\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/firefox|iceweasel|fxios/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Firefox" }, r33 = n10.default.getFirstMatch(/(?:firefox|iceweasel|fxios)[\s/](\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/electron/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Electron" }, r33 = n10.default.getFirstMatch(/(?:electron)\/(\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/sogoumobilebrowser/i, /metasr/i, /se 2\.[x]/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Sogou Browser" }, r33 = n10.default.getFirstMatch(/(?:sogoumobilebrowser)[\s/](\d+(\.?_?\d+)+)/i, e33), i33 = n10.default.getFirstMatch(/(?:chrome|crios|crmo)\/(\d+(\.?_?\d+)+)/i, e33), a33 = n10.default.getFirstMatch(/se ([\d.]+)x/i, e33), o11 = r33 || i33 || a33;
          return o11 && (t2.version = o11), t2;
        }, "describe") }, { test: [/MiuiBrowser/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Miui" }, r33 = n10.default.getFirstMatch(/(?:MiuiBrowser)[\s/](\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: /* @__PURE__ */ __name(function(e33) {
          return !!e33.hasBrand("DuckDuckGo") || e33.test(/\sDdg\/[\d.]+$/i);
        }, "test"), describe: /* @__PURE__ */ __name(function(e33, t2) {
          var r33 = { name: "DuckDuckGo" };
          if (t2) {
            var i33 = t2.getBrandVersion("DuckDuckGo");
            if (i33) return r33.version = i33, r33;
          }
          var a33 = n10.default.getFirstMatch(/\sDdg\/([\d.]+)$/i, e33);
          return a33 && (r33.version = a33), r33;
        }, "describe") }, { test: /* @__PURE__ */ __name(function(e33) {
          return e33.hasBrand("Brave");
        }, "test"), describe: /* @__PURE__ */ __name(function(e33, t2) {
          var r33 = { name: "Brave" };
          if (t2) {
            var i33 = t2.getBrandVersion("Brave");
            if (i33) return r33.version = i33, r33;
          }
          return r33;
        }, "describe") }, { test: [/chromium/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Chromium" }, r33 = n10.default.getFirstMatch(/(?:chromium)[\s/](\d+(\.?_?\d+)+)/i, e33) || n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/chrome|crios|crmo/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Chrome" }, r33 = n10.default.getFirstMatch(/(?:chrome|crios|crmo)\/(\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/GSA/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Google Search" }, r33 = n10.default.getFirstMatch(/(?:GSA)\/(\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: /* @__PURE__ */ __name(function(e33) {
          var t2 = !e33.test(/like android/i), r33 = e33.test(/android/i);
          return t2 && r33;
        }, "test"), describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Android Browser" }, r33 = n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/playstation 4/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "PlayStation 4" }, r33 = n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/safari|applewebkit/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: "Safari" }, r33 = n10.default.getFirstMatch(a32, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/.*/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = -1 !== e33.search("\\(") ? /^(.*)\/(.*)[ \t]\((.*)/ : /^(.*)\/(.*) /;
          return { name: n10.default.getFirstMatch(t2, e33), version: n10.default.getSecondMatch(t2, e33) };
        }, "describe") }];
        t.default = o10, e32.exports = t.default;
      }, 93: function(e32, t, r32) {
        "use strict";
        t.__esModule = true, t.default = void 0;
        var i32, n10 = (i32 = r32(17)) && i32.__esModule ? i32 : { default: i32 }, a32 = r32(18);
        var o10 = [{ test: [/Roku\/DVP/], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = n10.default.getFirstMatch(/Roku\/DVP-(\d+\.\d+)/i, e33);
          return { name: a32.OS_MAP.Roku, version: t2 };
        }, "describe") }, { test: [/windows phone/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = n10.default.getFirstMatch(/windows phone (?:os)?\s?(\d+(\.\d+)*)/i, e33);
          return { name: a32.OS_MAP.WindowsPhone, version: t2 };
        }, "describe") }, { test: [/windows /i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = n10.default.getFirstMatch(/Windows ((NT|XP)( \d\d?.\d)?)/i, e33), r33 = n10.default.getWindowsVersionName(t2);
          return { name: a32.OS_MAP.Windows, version: t2, versionName: r33 };
        }, "describe") }, { test: [/Macintosh(.*?) FxiOS(.*?)\//], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: a32.OS_MAP.iOS }, r33 = n10.default.getSecondMatch(/(Version\/)(\d[\d.]+)/, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/macintosh/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = n10.default.getFirstMatch(/mac os x (\d+(\.?_?\d+)+)/i, e33).replace(/[_\s]/g, "."), r33 = n10.default.getMacOSVersionName(t2), i33 = { name: a32.OS_MAP.MacOS, version: t2 };
          return r33 && (i33.versionName = r33), i33;
        }, "describe") }, { test: [/(ipod|iphone|ipad)/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = n10.default.getFirstMatch(/os (\d+([_\s]\d+)*) like mac os x/i, e33).replace(/[_\s]/g, ".");
          return { name: a32.OS_MAP.iOS, version: t2 };
        }, "describe") }, { test: [/OpenHarmony/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = n10.default.getFirstMatch(/OpenHarmony\s+(\d+(\.\d+)*)/i, e33);
          return { name: a32.OS_MAP.HarmonyOS, version: t2 };
        }, "describe") }, { test: /* @__PURE__ */ __name(function(e33) {
          var t2 = !e33.test(/like android/i), r33 = e33.test(/android/i);
          return t2 && r33;
        }, "test"), describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = n10.default.getFirstMatch(/android[\s/-](\d+(\.\d+)*)/i, e33), r33 = n10.default.getAndroidVersionName(t2), i33 = { name: a32.OS_MAP.Android, version: t2 };
          return r33 && (i33.versionName = r33), i33;
        }, "describe") }, { test: [/(web|hpw)[o0]s/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = n10.default.getFirstMatch(/(?:web|hpw)[o0]s\/(\d+(\.\d+)*)/i, e33), r33 = { name: a32.OS_MAP.WebOS };
          return t2 && t2.length && (r33.version = t2), r33;
        }, "describe") }, { test: [/blackberry|\bbb\d+/i, /rim\stablet/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = n10.default.getFirstMatch(/rim\stablet\sos\s(\d+(\.\d+)*)/i, e33) || n10.default.getFirstMatch(/blackberry\d+\/(\d+([_\s]\d+)*)/i, e33) || n10.default.getFirstMatch(/\bbb(\d+)/i, e33);
          return { name: a32.OS_MAP.BlackBerry, version: t2 };
        }, "describe") }, { test: [/bada/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = n10.default.getFirstMatch(/bada\/(\d+(\.\d+)*)/i, e33);
          return { name: a32.OS_MAP.Bada, version: t2 };
        }, "describe") }, { test: [/tizen/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = n10.default.getFirstMatch(/tizen[/\s](\d+(\.\d+)*)/i, e33);
          return { name: a32.OS_MAP.Tizen, version: t2 };
        }, "describe") }, { test: [/linux/i], describe: /* @__PURE__ */ __name(function() {
          return { name: a32.OS_MAP.Linux };
        }, "describe") }, { test: [/CrOS/], describe: /* @__PURE__ */ __name(function() {
          return { name: a32.OS_MAP.ChromeOS };
        }, "describe") }, { test: [/PlayStation 4/], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = n10.default.getFirstMatch(/PlayStation 4[/\s](\d+(\.\d+)*)/i, e33);
          return { name: a32.OS_MAP.PlayStation4, version: t2 };
        }, "describe") }];
        t.default = o10, e32.exports = t.default;
      }, 94: function(e32, t, r32) {
        "use strict";
        t.__esModule = true, t.default = void 0;
        var i32, n10 = (i32 = r32(17)) && i32.__esModule ? i32 : { default: i32 }, a32 = r32(18);
        var o10 = [{ test: [/googlebot/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.bot, vendor: "Google" };
        }, "describe") }, { test: [/linespider/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.bot, vendor: "Line" };
        }, "describe") }, { test: [/amazonbot/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.bot, vendor: "Amazon" };
        }, "describe") }, { test: [/gptbot/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.bot, vendor: "OpenAI" };
        }, "describe") }, { test: [/chatgpt-user/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.bot, vendor: "OpenAI" };
        }, "describe") }, { test: [/oai-searchbot/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.bot, vendor: "OpenAI" };
        }, "describe") }, { test: [/baiduspider/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.bot, vendor: "Baidu" };
        }, "describe") }, { test: [/bingbot/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.bot, vendor: "Bing" };
        }, "describe") }, { test: [/duckduckbot/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.bot, vendor: "DuckDuckGo" };
        }, "describe") }, { test: [/claudebot/i, /claude-web/i, /claude-user/i, /claude-searchbot/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.bot, vendor: "Anthropic" };
        }, "describe") }, { test: [/omgilibot/i, /webzio-extended/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.bot, vendor: "Webz.io" };
        }, "describe") }, { test: [/diffbot/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.bot, vendor: "Diffbot" };
        }, "describe") }, { test: [/perplexitybot/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.bot, vendor: "Perplexity AI" };
        }, "describe") }, { test: [/perplexity-user/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.bot, vendor: "Perplexity AI" };
        }, "describe") }, { test: [/youbot/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.bot, vendor: "You.com" };
        }, "describe") }, { test: [/ia_archiver/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.bot, vendor: "Internet Archive" };
        }, "describe") }, { test: [/meta-webindexer/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.bot, vendor: "Meta" };
        }, "describe") }, { test: [/meta-externalads/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.bot, vendor: "Meta" };
        }, "describe") }, { test: [/meta-externalagent/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.bot, vendor: "Meta" };
        }, "describe") }, { test: [/meta-externalfetcher/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.bot, vendor: "Meta" };
        }, "describe") }, { test: [/facebookexternalhit/i, /facebookcatalog/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.bot, vendor: "Meta" };
        }, "describe") }, { test: [/slackbot/i, /slack-imgProxy/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.bot, vendor: "Slack" };
        }, "describe") }, { test: [/yahoo/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.bot, vendor: "Yahoo" };
        }, "describe") }, { test: [/yandexbot/i, /yandexmobilebot/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.bot, vendor: "Yandex" };
        }, "describe") }, { test: [/pingdom/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.bot, vendor: "Pingdom" };
        }, "describe") }, { test: [/huawei/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = n10.default.getFirstMatch(/(can-l01)/i, e33) && "Nova", r33 = { type: a32.PLATFORMS_MAP.mobile, vendor: "Huawei" };
          return t2 && (r33.model = t2), r33;
        }, "describe") }, { test: [/nexus\s*(?:7|8|9|10).*/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.tablet, vendor: "Nexus" };
        }, "describe") }, { test: [/ipad/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.tablet, vendor: "Apple", model: "iPad" };
        }, "describe") }, { test: [/Macintosh(.*?) FxiOS(.*?)\//], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.tablet, vendor: "Apple", model: "iPad" };
        }, "describe") }, { test: [/kftt build/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.tablet, vendor: "Amazon", model: "Kindle Fire HD 7" };
        }, "describe") }, { test: [/silk/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.tablet, vendor: "Amazon" };
        }, "describe") }, { test: [/tablet(?! pc)/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.tablet };
        }, "describe") }, { test: /* @__PURE__ */ __name(function(e33) {
          var t2 = e33.test(/ipod|iphone/i), r33 = e33.test(/like (ipod|iphone)/i);
          return t2 && !r33;
        }, "test"), describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = n10.default.getFirstMatch(/(ipod|iphone)/i, e33);
          return { type: a32.PLATFORMS_MAP.mobile, vendor: "Apple", model: t2 };
        }, "describe") }, { test: [/nexus\s*[0-6].*/i, /galaxy nexus/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.mobile, vendor: "Nexus" };
        }, "describe") }, { test: [/Nokia/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = n10.default.getFirstMatch(/Nokia\s+([0-9]+(\.[0-9]+)?)/i, e33), r33 = { type: a32.PLATFORMS_MAP.mobile, vendor: "Nokia" };
          return t2 && (r33.model = t2), r33;
        }, "describe") }, { test: [/[^-]mobi/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.mobile };
        }, "describe") }, { test: /* @__PURE__ */ __name(function(e33) {
          return "blackberry" === e33.getBrowserName(true);
        }, "test"), describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.mobile, vendor: "BlackBerry" };
        }, "describe") }, { test: /* @__PURE__ */ __name(function(e33) {
          return "bada" === e33.getBrowserName(true);
        }, "test"), describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.mobile };
        }, "describe") }, { test: /* @__PURE__ */ __name(function(e33) {
          return "windows phone" === e33.getBrowserName();
        }, "test"), describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.mobile, vendor: "Microsoft" };
        }, "describe") }, { test: /* @__PURE__ */ __name(function(e33) {
          var t2 = Number(String(e33.getOSVersion()).split(".")[0]);
          return "android" === e33.getOSName(true) && t2 >= 3;
        }, "test"), describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.tablet };
        }, "describe") }, { test: /* @__PURE__ */ __name(function(e33) {
          return "android" === e33.getOSName(true);
        }, "test"), describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.mobile };
        }, "describe") }, { test: [/smart-?tv|smarttv/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.tv };
        }, "describe") }, { test: [/netcast/i], describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.tv };
        }, "describe") }, { test: /* @__PURE__ */ __name(function(e33) {
          return "macos" === e33.getOSName(true);
        }, "test"), describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.desktop, vendor: "Apple" };
        }, "describe") }, { test: /* @__PURE__ */ __name(function(e33) {
          return "windows" === e33.getOSName(true);
        }, "test"), describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.desktop };
        }, "describe") }, { test: /* @__PURE__ */ __name(function(e33) {
          return "linux" === e33.getOSName(true);
        }, "test"), describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.desktop };
        }, "describe") }, { test: /* @__PURE__ */ __name(function(e33) {
          return "playstation 4" === e33.getOSName(true);
        }, "test"), describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.tv };
        }, "describe") }, { test: /* @__PURE__ */ __name(function(e33) {
          return "roku" === e33.getOSName(true);
        }, "test"), describe: /* @__PURE__ */ __name(function() {
          return { type: a32.PLATFORMS_MAP.tv };
        }, "describe") }];
        t.default = o10, e32.exports = t.default;
      }, 95: function(e32, t, r32) {
        "use strict";
        t.__esModule = true, t.default = void 0;
        var i32, n10 = (i32 = r32(17)) && i32.__esModule ? i32 : { default: i32 }, a32 = r32(18);
        var o10 = [{ test: /* @__PURE__ */ __name(function(e33) {
          return "microsoft edge" === e33.getBrowserName(true);
        }, "test"), describe: /* @__PURE__ */ __name(function(e33) {
          if (/\sedg\//i.test(e33)) return { name: a32.ENGINE_MAP.Blink };
          var t2 = n10.default.getFirstMatch(/edge\/(\d+(\.?_?\d+)+)/i, e33);
          return { name: a32.ENGINE_MAP.EdgeHTML, version: t2 };
        }, "describe") }, { test: [/trident/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: a32.ENGINE_MAP.Trident }, r33 = n10.default.getFirstMatch(/trident\/(\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: /* @__PURE__ */ __name(function(e33) {
          return e33.test(/presto/i);
        }, "test"), describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: a32.ENGINE_MAP.Presto }, r33 = n10.default.getFirstMatch(/presto\/(\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: /* @__PURE__ */ __name(function(e33) {
          var t2 = e33.test(/gecko/i), r33 = e33.test(/like gecko/i);
          return t2 && !r33;
        }, "test"), describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: a32.ENGINE_MAP.Gecko }, r33 = n10.default.getFirstMatch(/gecko\/(\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }, { test: [/(apple)?webkit\/537\.36/i], describe: /* @__PURE__ */ __name(function() {
          return { name: a32.ENGINE_MAP.Blink };
        }, "describe") }, { test: [/(apple)?webkit/i], describe: /* @__PURE__ */ __name(function(e33) {
          var t2 = { name: a32.ENGINE_MAP.WebKit }, r33 = n10.default.getFirstMatch(/webkit\/(\d+(\.?_?\d+)+)/i, e33);
          return r33 && (t2.version = r33), t2;
        }, "describe") }];
        t.default = o10, e32.exports = t.default;
      } });
    }));
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-user-agent-browser/createUserAgentStringParsingProvider.js
var createUserAgentStringParsingProvider;
var init_createUserAgentStringParsingProvider = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-user-agent-browser/createUserAgentStringParsingProvider.js"() {
    createUserAgentStringParsingProvider = /* @__PURE__ */ __name(({ serviceId, clientVersion }) => async (config2) => {
      const module2 = await Promise.resolve().then(() => __toESM(require_es5()));
      const parse2 = module2.parse ?? module2.default.parse ?? (() => "");
      const parsedUA = typeof window !== "undefined" && window?.navigator?.userAgent ? parse2(window.navigator.userAgent) : void 0;
      const sections = [
        ["aws-sdk-js", clientVersion],
        ["ua", "2.1"],
        [`os/${parsedUA?.os?.name || "other"}`, parsedUA?.os?.version],
        ["lang/js"],
        ["md/browser", `${parsedUA?.browser?.name ?? "unknown"}_${parsedUA?.browser?.version ?? "unknown"}`]
      ];
      if (serviceId) {
        sections.push([`api/${serviceId}`, clientVersion]);
      }
      const appId = await config2?.userAgentAppId?.();
      if (appId) {
        sections.push([`app/${appId}`]);
      }
      return sections;
    }, "createUserAgentStringParsingProvider");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-user-agent-browser/defaultUserAgent.js
var fallback;
var init_defaultUserAgent2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-user-agent-browser/defaultUserAgent.js"() {
    fallback = {
      os(ua) {
        if (/iPhone|iPad|iPod/.test(ua))
          return "iOS";
        if (/Macintosh|Mac OS X/.test(ua))
          return "macOS";
        if (/Windows NT/.test(ua))
          return "Windows";
        if (/Android/.test(ua))
          return "Android";
        if (/Linux/.test(ua))
          return "Linux";
        return void 0;
      },
      browser(ua) {
        if (/EdgiOS|EdgA|Edg\//.test(ua))
          return "Microsoft Edge";
        if (/Firefox\//.test(ua))
          return "Firefox";
        if (/Chrome\//.test(ua))
          return "Chrome";
        if (/Safari\//.test(ua))
          return "Safari";
        return void 0;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-endpoints/lib/isIpAddress.js
var init_isIpAddress3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-endpoints/lib/isIpAddress.js"() {
    init_endpoints3();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-endpoints/lib/aws/isVirtualHostableS3Bucket.js
var isVirtualHostableS3Bucket;
var init_isVirtualHostableS3Bucket = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-endpoints/lib/aws/isVirtualHostableS3Bucket.js"() {
    init_endpoints3();
    init_isIpAddress3();
    isVirtualHostableS3Bucket = /* @__PURE__ */ __name((value, allowSubDomains = false) => {
      if (allowSubDomains) {
        for (const label of value.split(".")) {
          if (!isVirtualHostableS3Bucket(label)) {
            return false;
          }
        }
        return true;
      }
      if (!isValidHostLabel2(value)) {
        return false;
      }
      if (value.length < 3 || value.length > 63) {
        return false;
      }
      if (value !== value.toLowerCase()) {
        return false;
      }
      if (isIpAddress2(value)) {
        return false;
      }
      return true;
    }, "isVirtualHostableS3Bucket");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-endpoints/lib/aws/parseArn.js
var ARN_DELIMITER, RESOURCE_DELIMITER, parseArn;
var init_parseArn = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-endpoints/lib/aws/parseArn.js"() {
    ARN_DELIMITER = ":";
    RESOURCE_DELIMITER = "/";
    parseArn = /* @__PURE__ */ __name((value) => {
      const segments = value.split(ARN_DELIMITER);
      if (segments.length < 6)
        return null;
      const [arn, partition4, service, region, accountId, ...resourcePath] = segments;
      if (arn !== "arn" || partition4 === "" || service === "" || resourcePath.join(ARN_DELIMITER) === "")
        return null;
      const resourceId = resourcePath.map((resource) => resource.split(RESOURCE_DELIMITER)).flat();
      return {
        partition: partition4,
        service,
        region,
        accountId,
        resourceId
      };
    }, "parseArn");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-endpoints/aws.js
var awsEndpointFunctions19;
var init_aws2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-endpoints/aws.js"() {
    init_endpoints3();
    init_isVirtualHostableS3Bucket();
    init_parseArn();
    init_partition();
    awsEndpointFunctions19 = {
      isVirtualHostableS3Bucket,
      parseArn,
      partition: partition2
    };
    customEndpointFunctions20.aws = awsEndpointFunctions19;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-endpoints/resolveEndpoint.js
var init_resolveEndpoint3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-endpoints/resolveEndpoint.js"() {
    init_endpoints3();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-endpoints/resolveDefaultAwsRegionalEndpointsConfig.js
var resolveDefaultAwsRegionalEndpointsConfig, toEndpointV14;
var init_resolveDefaultAwsRegionalEndpointsConfig = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-endpoints/resolveDefaultAwsRegionalEndpointsConfig.js"() {
    init_protocols11();
    resolveDefaultAwsRegionalEndpointsConfig = /* @__PURE__ */ __name((input) => {
      if (typeof input.endpointProvider !== "function") {
        throw new Error("@aws-sdk/util-endpoint - endpointProvider and endpoint missing in config for this client.");
      }
      const { endpoint } = input;
      if (endpoint === void 0) {
        input.endpoint = async () => {
          return toEndpointV14(input.endpointProvider({
            Region: typeof input.region === "function" ? await input.region() : input.region,
            UseDualStack: typeof input.useDualstackEndpoint === "function" ? await input.useDualstackEndpoint() : input.useDualstackEndpoint,
            UseFIPS: typeof input.useFipsEndpoint === "function" ? await input.useFipsEndpoint() : input.useFipsEndpoint,
            Endpoint: void 0
          }, { logger: input.logger }));
        };
      }
      return input;
    }, "resolveDefaultAwsRegionalEndpointsConfig");
    toEndpointV14 = /* @__PURE__ */ __name((endpoint) => parseUrl21(endpoint.url), "toEndpointV1");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-endpoints/types/EndpointError.js
var init_EndpointError3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/util-endpoints/types/EndpointError.js"() {
    init_endpoints3();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/region-config-resolver/awsRegionConfig.js
var init_awsRegionConfig = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/region-config-resolver/awsRegionConfig.js"() {
    init_config4();
    init_config4();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/region-config-resolver/stsRegionDefaultResolver.js
function stsRegionDefaultResolver6(loaderConfig = {}) {
  return loadConfig3({
    ...NODE_REGION_CONFIG_OPTIONS20,
    async default() {
      if (!warning.silence) {
        console.warn("@aws-sdk - WARN - default STS region of us-east-1 used. See @aws-sdk/credential-providers README and set a region explicitly.");
      }
      return "us-east-1";
    }
  }, { ...NODE_REGION_CONFIG_FILE_OPTIONS20, ...loaderConfig });
}
var warning;
var init_stsRegionDefaultResolver = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/region-config-resolver/stsRegionDefaultResolver.js"() {
    init_config4();
    __name(stsRegionDefaultResolver6, "stsRegionDefaultResolver");
    warning = {
      silence: false
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/region-config-resolver/extensions.js
var getAwsRegionExtensionConfiguration19, resolveAwsRegionExtensionConfiguration19;
var init_extensions = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/region-config-resolver/extensions.js"() {
    getAwsRegionExtensionConfiguration19 = /* @__PURE__ */ __name((runtimeConfig) => {
      return {
        setRegion(region) {
          runtimeConfig.region = region;
        },
        region() {
          return runtimeConfig.region;
        }
      };
    }, "getAwsRegionExtensionConfiguration");
    resolveAwsRegionExtensionConfiguration19 = /* @__PURE__ */ __name((awsRegionExtensionConfiguration) => {
      return {
        region: awsRegionExtensionConfiguration.region()
      };
    }, "resolveAwsRegionExtensionConfiguration");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/index.js
var client_exports10 = {};
__export(client_exports10, {
  DEFAULT_UA_APP_ID: () => DEFAULT_UA_APP_ID,
  EndpointError: () => EndpointError2,
  NODE_APP_ID_CONFIG_OPTIONS: () => NODE_APP_ID_CONFIG_OPTIONS19,
  NODE_REGION_CONFIG_FILE_OPTIONS: () => NODE_REGION_CONFIG_FILE_OPTIONS20,
  NODE_REGION_CONFIG_OPTIONS: () => NODE_REGION_CONFIG_OPTIONS20,
  REGION_ENV_NAME: () => REGION_ENV_NAME,
  REGION_INI_NAME: () => REGION_INI_NAME,
  UA_APP_ID_ENV_NAME: () => UA_APP_ID_ENV_NAME,
  UA_APP_ID_INI_NAME: () => UA_APP_ID_INI_NAME,
  awsEndpointFunctions: () => awsEndpointFunctions19,
  createDefaultUserAgentProvider: () => createDefaultUserAgentProvider19,
  createUserAgentStringParsingProvider: () => createUserAgentStringParsingProvider,
  crtAvailability: () => crtAvailability,
  defaultUserAgent: () => defaultUserAgent,
  emitWarningIfUnsupportedVersion: () => emitWarningIfUnsupportedVersion27,
  fallback: () => fallback,
  getAwsRegionExtensionConfiguration: () => getAwsRegionExtensionConfiguration19,
  getHostHeaderPlugin: () => getHostHeaderPlugin19,
  getLoggerPlugin: () => getLoggerPlugin19,
  getLongPollPlugin: () => getLongPollPlugin9,
  getRecursionDetectionPlugin: () => getRecursionDetectionPlugin19,
  getUserAgentMiddlewareOptions: () => getUserAgentMiddlewareOptions,
  getUserAgentPlugin: () => getUserAgentPlugin19,
  getUserAgentPrefix: () => getUserAgentPrefix,
  hostHeaderMiddleware: () => hostHeaderMiddleware,
  hostHeaderMiddlewareOptions: () => hostHeaderMiddlewareOptions,
  isIpAddress: () => isIpAddress2,
  isVirtualHostableS3Bucket: () => isVirtualHostableS3Bucket,
  loggerMiddleware: () => loggerMiddleware,
  loggerMiddlewareOptions: () => loggerMiddlewareOptions,
  parseArn: () => parseArn,
  partition: () => partition2,
  recursionDetectionMiddleware: () => recursionDetectionMiddleware,
  recursionDetectionMiddlewareOptions: () => recursionDetectionMiddlewareOptions,
  resolveAwsRegionExtensionConfiguration: () => resolveAwsRegionExtensionConfiguration19,
  resolveDefaultAwsRegionalEndpointsConfig: () => resolveDefaultAwsRegionalEndpointsConfig,
  resolveEndpoint: () => resolveEndpoint2,
  resolveHostHeaderConfig: () => resolveHostHeaderConfig19,
  resolveRegionConfig: () => resolveRegionConfig19,
  resolveUserAgentConfig: () => resolveUserAgentConfig19,
  setCredentialFeature: () => setCredentialFeature9,
  setFeature: () => setFeature12,
  setPartitionInfo: () => setPartitionInfo,
  setTokenFeature: () => setTokenFeature9,
  state: () => state9,
  stsRegionDefaultResolver: () => stsRegionDefaultResolver6,
  stsRegionWarning: () => warning,
  toEndpointV1: () => toEndpointV14,
  useDefaultPartitionInfo: () => useDefaultPartitionInfo,
  userAgentMiddleware: () => userAgentMiddleware
});
var init_client13 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/client/index.js"() {
    init_emitWarningIfUnsupportedVersion9();
    init_longPollMiddleware9();
    init_setCredentialFeature9();
    init_setFeature10();
    init_setTokenFeature9();
    init_hostHeaderMiddleware();
    init_loggerMiddleware();
    init_configuration();
    init_getRecursionDetectionPlugin();
    init_recursionDetectionMiddleware();
    init_configurations3();
    init_user_agent_middleware();
    init_defaultUserAgent();
    init_nodeAppIdConfigOptions();
    init_defaultUserAgent2();
    init_createUserAgentStringParsingProvider();
    init_aws2();
    init_resolveEndpoint3();
    init_resolveDefaultAwsRegionalEndpointsConfig();
    init_isIpAddress3();
    init_isVirtualHostableS3Bucket();
    init_parseArn();
    init_partition();
    init_EndpointError3();
    init_awsRegionConfig();
    init_stsRegionDefaultResolver();
    init_extensions();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getDateHeader.js
var getDateHeader7;
var init_getDateHeader7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getDateHeader.js"() {
    init_protocols11();
    getDateHeader7 = /* @__PURE__ */ __name((response) => HttpResponse11.isInstance(response) ? response.headers?.date ?? response.headers?.Date : void 0, "getDateHeader");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getSkewCorrectedDate.js
var getSkewCorrectedDate7;
var init_getSkewCorrectedDate7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getSkewCorrectedDate.js"() {
    getSkewCorrectedDate7 = /* @__PURE__ */ __name((systemClockOffset) => new Date(Date.now() + systemClockOffset), "getSkewCorrectedDate");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/isClockSkewed.js
var isClockSkewed7;
var init_isClockSkewed7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/isClockSkewed.js"() {
    init_getSkewCorrectedDate7();
    isClockSkewed7 = /* @__PURE__ */ __name((clockTime, systemClockOffset) => Math.abs(getSkewCorrectedDate7(systemClockOffset).getTime() - clockTime) >= 3e5, "isClockSkewed");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getUpdatedSystemClockOffset.js
var getUpdatedSystemClockOffset7;
var init_getUpdatedSystemClockOffset7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getUpdatedSystemClockOffset.js"() {
    init_isClockSkewed7();
    getUpdatedSystemClockOffset7 = /* @__PURE__ */ __name((clockTime, currentSystemClockOffset) => {
      const clockTimeInMs = Date.parse(clockTime);
      if (isClockSkewed7(clockTimeInMs, currentSystemClockOffset)) {
        return clockTimeInMs - Date.now();
      }
      return currentSystemClockOffset;
    }, "getUpdatedSystemClockOffset");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/index.js
var init_utils11 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/index.js"() {
    init_getDateHeader7();
    init_getSkewCorrectedDate7();
    init_getUpdatedSystemClockOffset7();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4Signer.js
var throwSigningPropertyError7, validateSigningProperties7, AwsSdkSigV4Signer7, AWSSDKSigV4Signer7;
var init_AwsSdkSigV4Signer7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4Signer.js"() {
    init_protocols11();
    init_utils11();
    throwSigningPropertyError7 = /* @__PURE__ */ __name((name, property) => {
      if (!property) {
        throw new Error(`Property \`${name}\` is not resolved for AWS SDK SigV4Auth`);
      }
      return property;
    }, "throwSigningPropertyError");
    validateSigningProperties7 = /* @__PURE__ */ __name(async (signingProperties) => {
      const context = throwSigningPropertyError7("context", signingProperties.context);
      const config2 = throwSigningPropertyError7("config", signingProperties.config);
      const authScheme = context.endpointV2?.properties?.authSchemes?.[0];
      const signerFunction = throwSigningPropertyError7("signer", config2.signer);
      const signer = await signerFunction(authScheme);
      const signingRegion = signingProperties?.signingRegion;
      const signingRegionSet = signingProperties?.signingRegionSet;
      const signingName = signingProperties?.signingName;
      return {
        config: config2,
        signer,
        signingRegion,
        signingRegionSet,
        signingName
      };
    }, "validateSigningProperties");
    AwsSdkSigV4Signer7 = class {
      static {
        __name(this, "AwsSdkSigV4Signer");
      }
      async sign(httpRequest, identity, signingProperties) {
        if (!HttpRequest22.isInstance(httpRequest)) {
          throw new Error("The request is not an instance of `HttpRequest` and cannot be signed");
        }
        const validatedProps = await validateSigningProperties7(signingProperties);
        const { config: config2, signer } = validatedProps;
        let { signingRegion, signingName } = validatedProps;
        const handlerExecutionContext = signingProperties.context;
        if (handlerExecutionContext?.authSchemes?.length ?? 0 > 1) {
          const [first, second] = handlerExecutionContext.authSchemes;
          if (first?.name === "sigv4a" && second?.name === "sigv4") {
            signingRegion = second?.signingRegion ?? signingRegion;
            signingName = second?.signingName ?? signingName;
          }
        }
        const signedRequest = await signer.sign(httpRequest, {
          signingDate: getSkewCorrectedDate7(config2.systemClockOffset),
          signingRegion,
          signingService: signingName
        });
        return signedRequest;
      }
      errorHandler(signingProperties) {
        return (error4) => {
          const serverTime = error4.ServerTime ?? getDateHeader7(error4.$response);
          if (serverTime) {
            const config2 = throwSigningPropertyError7("config", signingProperties.config);
            const initialSystemClockOffset = config2.systemClockOffset;
            config2.systemClockOffset = getUpdatedSystemClockOffset7(serverTime, config2.systemClockOffset);
            const clockSkewCorrected = config2.systemClockOffset !== initialSystemClockOffset;
            if (clockSkewCorrected && error4.$metadata) {
              error4.$metadata.clockSkewCorrected = true;
            }
          }
          throw error4;
        };
      }
      successHandler(httpResponse, signingProperties) {
        const dateHeader = getDateHeader7(httpResponse);
        if (dateHeader) {
          const config2 = throwSigningPropertyError7("config", signingProperties.config);
          config2.systemClockOffset = getUpdatedSystemClockOffset7(dateHeader, config2.systemClockOffset);
        }
      }
    };
    AWSSDKSigV4Signer7 = AwsSdkSigV4Signer7;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4ASigner.js
var AwsSdkSigV4ASigner7;
var init_AwsSdkSigV4ASigner7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4ASigner.js"() {
    init_protocols11();
    init_utils11();
    init_AwsSdkSigV4Signer7();
    AwsSdkSigV4ASigner7 = class extends AwsSdkSigV4Signer7 {
      static {
        __name(this, "AwsSdkSigV4ASigner");
      }
      async sign(httpRequest, identity, signingProperties) {
        if (!HttpRequest22.isInstance(httpRequest)) {
          throw new Error("The request is not an instance of `HttpRequest` and cannot be signed");
        }
        const { config: config2, signer, signingRegion, signingRegionSet, signingName } = await validateSigningProperties7(signingProperties);
        const configResolvedSigningRegionSet = await config2.sigv4aSigningRegionSet?.();
        const multiRegionOverride = (configResolvedSigningRegionSet ?? signingRegionSet ?? [signingRegion]).join(",");
        const signedRequest = await signer.sign(httpRequest, {
          signingDate: getSkewCorrectedDate7(config2.systemClockOffset),
          signingRegion: multiRegionOverride,
          signingService: signingName
        });
        return signedRequest;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getArrayForCommaSeparatedString.js
var getArrayForCommaSeparatedString7;
var init_getArrayForCommaSeparatedString7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getArrayForCommaSeparatedString.js"() {
    getArrayForCommaSeparatedString7 = /* @__PURE__ */ __name((str) => typeof str === "string" && str.length > 0 ? str.split(",").map((item) => item.trim()) : [], "getArrayForCommaSeparatedString");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getBearerTokenEnvKey.js
var getBearerTokenEnvKey7;
var init_getBearerTokenEnvKey7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getBearerTokenEnvKey.js"() {
    getBearerTokenEnvKey7 = /* @__PURE__ */ __name((signingName) => `AWS_BEARER_TOKEN_${signingName.replace(/[\s-]/g, "_").toUpperCase()}`, "getBearerTokenEnvKey");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/NODE_AUTH_SCHEME_PREFERENCE_OPTIONS.js
var NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY7, NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY7, NODE_AUTH_SCHEME_PREFERENCE_OPTIONS7;
var init_NODE_AUTH_SCHEME_PREFERENCE_OPTIONS7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/NODE_AUTH_SCHEME_PREFERENCE_OPTIONS.js"() {
    init_getArrayForCommaSeparatedString7();
    init_getBearerTokenEnvKey7();
    NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY7 = "AWS_AUTH_SCHEME_PREFERENCE";
    NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY7 = "auth_scheme_preference";
    NODE_AUTH_SCHEME_PREFERENCE_OPTIONS7 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3, options) => {
        if (options?.signingName) {
          const bearerTokenKey = getBearerTokenEnvKey7(options.signingName);
          if (bearerTokenKey in env3)
            return ["httpBearerAuth"];
        }
        if (!(NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY7 in env3))
          return void 0;
        return getArrayForCommaSeparatedString7(env3[NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY7]);
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => {
        if (!(NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY7 in profile))
          return void 0;
        return getArrayForCommaSeparatedString7(profile[NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY7]);
      }, "configFileSelector"),
      default: []
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4AConfig.js
var resolveAwsSdkSigV4AConfig7, NODE_SIGV4A_CONFIG_OPTIONS7;
var init_resolveAwsSdkSigV4AConfig7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4AConfig.js"() {
    init_dist_es2();
    init_config4();
    resolveAwsSdkSigV4AConfig7 = /* @__PURE__ */ __name((config2) => {
      config2.sigv4aSigningRegionSet = normalizeProvider23(config2.sigv4aSigningRegionSet);
      return config2;
    }, "resolveAwsSdkSigV4AConfig");
    NODE_SIGV4A_CONFIG_OPTIONS7 = {
      environmentVariableSelector(env3) {
        if (env3.AWS_SIGV4A_SIGNING_REGION_SET) {
          return env3.AWS_SIGV4A_SIGNING_REGION_SET.split(",").map((_) => _.trim());
        }
        throw new ProviderError8("AWS_SIGV4A_SIGNING_REGION_SET not set in env.", {
          tryNextLink: true
        });
      },
      configFileSelector(profile) {
        if (profile.sigv4a_signing_region_set) {
          return (profile.sigv4a_signing_region_set ?? "").split(",").map((_) => _.trim());
        }
        throw new ProviderError8("sigv4a_signing_region_set not set in profile.", {
          tryNextLink: true
        });
      },
      default: void 0
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/is-array-buffer/is-array-buffer.js
var isArrayBuffer4;
var init_is_array_buffer4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/is-array-buffer/is-array-buffer.js"() {
    isArrayBuffer4 = /* @__PURE__ */ __name((arg) => typeof ArrayBuffer === "function" && arg instanceof ArrayBuffer || Object.prototype.toString.call(arg) === "[object ArrayBuffer]", "isArrayBuffer");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-buffer-from/buffer-from.js
var fromArrayBuffer4, fromString4;
var init_buffer_from4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-buffer-from/buffer-from.js"() {
    init_is_array_buffer4();
    fromArrayBuffer4 = /* @__PURE__ */ __name((input, offset = 0, length = input.byteLength - offset) => {
      if (!isArrayBuffer4(input)) {
        throw new TypeError(`The "input" argument must be ArrayBuffer. Received type ${typeof input} (${input})`);
      }
      return Buffer.from(input, offset, length);
    }, "fromArrayBuffer");
    fromString4 = /* @__PURE__ */ __name((input, encoding) => {
      if (typeof input !== "string") {
        throw new TypeError(`The "input" argument must be of type string. Received type ${typeof input} (${input})`);
      }
      return encoding ? Buffer.from(input, encoding) : Buffer.from(input);
    }, "fromString");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/fromBase64.js
var BASE64_REGEX4, fromBase6438;
var init_fromBase644 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/fromBase64.js"() {
    init_buffer_from4();
    BASE64_REGEX4 = /^[A-Za-z0-9+/]*={0,2}$/;
    fromBase6438 = /* @__PURE__ */ __name((input) => {
      if (input.length * 3 % 4 !== 0) {
        throw new TypeError(`Incorrect padding on base64 string.`);
      }
      if (!BASE64_REGEX4.exec(input)) {
        throw new TypeError(`Invalid base64 string.`);
      }
      const buffer = fromString4(input, "base64");
      return new Uint8Array(buffer.buffer, buffer.byteOffset, buffer.byteLength);
    }, "fromBase64");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/fromUtf8.js
var fromUtf827;
var init_fromUtf84 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/fromUtf8.js"() {
    init_buffer_from4();
    fromUtf827 = /* @__PURE__ */ __name((input) => {
      const buf = fromString4(input, "utf8");
      return new Uint8Array(buf.buffer, buf.byteOffset, buf.byteLength / Uint8Array.BYTES_PER_ELEMENT);
    }, "fromUtf8");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/toBase64.js
var toBase6443;
var init_toBase644 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/toBase64.js"() {
    init_buffer_from4();
    init_fromUtf84();
    toBase6443 = /* @__PURE__ */ __name((_input) => {
      let input;
      if (typeof _input === "string") {
        input = fromUtf827(_input);
      } else {
        input = _input;
      }
      if (typeof input !== "object" || typeof input.byteOffset !== "number" || typeof input.byteLength !== "number") {
        throw new Error("@smithy/util-base64: toBase64 encoder function only accepts string | Uint8Array.");
      }
      return fromArrayBuffer4(input.buffer, input.byteOffset, input.byteLength).toString("base64");
    }, "toBase64");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/blob/Uint8ArrayBlobAdapter.js
function bindUint8ArrayBlobAdapter4(toUtf862, fromUtf842, toBase6467, fromBase6459) {
  return class Uint8ArrayBlobAdapter8 extends Uint8Array {
    static {
      __name(this, "Uint8ArrayBlobAdapter");
    }
    static fromString(source, encoding = "utf-8") {
      if (typeof source === "string") {
        if (encoding === "base64") {
          return Uint8ArrayBlobAdapter8.mutate(fromBase6459(source));
        }
        return Uint8ArrayBlobAdapter8.mutate(fromUtf842(source));
      }
      throw new Error(`Unsupported conversion from ${typeof source} to Uint8ArrayBlobAdapter.`);
    }
    static mutate(source) {
      Object.setPrototypeOf(source, Uint8ArrayBlobAdapter8.prototype);
      return source;
    }
    transformToString(encoding = "utf-8") {
      if (encoding === "base64") {
        return toBase6467(this);
      }
      return toUtf862(this);
    }
  };
}
var init_Uint8ArrayBlobAdapter4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/blob/Uint8ArrayBlobAdapter.js"() {
    __name(bindUint8ArrayBlobAdapter4, "bindUint8ArrayBlobAdapter");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/toUtf8.js
var toUtf841;
var init_toUtf84 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/toUtf8.js"() {
    init_buffer_from4();
    toUtf841 = /* @__PURE__ */ __name((input) => {
      if (typeof input === "string") {
        return input;
      }
      if (typeof input !== "object" || typeof input.byteOffset !== "number" || typeof input.byteLength !== "number") {
        throw new Error("@smithy/util-utf8: toUtf8 encoder function only accepts string | Uint8Array.");
      }
      return fromArrayBuffer4(input.buffer, input.byteOffset, input.byteLength).toString("utf8");
    }, "toUtf8");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/uuid/v4.js
function bindV44(getRandomValues7) {
  if (typeof crypto !== "undefined" && typeof crypto.randomUUID === "function") {
    return () => crypto.randomUUID();
  }
  return () => {
    const rnds = new Uint8Array(16);
    getRandomValues7(rnds);
    rnds[6] = rnds[6] & 15 | 64;
    rnds[8] = rnds[8] & 63 | 128;
    return decimalToHex4[rnds[0]] + decimalToHex4[rnds[1]] + decimalToHex4[rnds[2]] + decimalToHex4[rnds[3]] + "-" + decimalToHex4[rnds[4]] + decimalToHex4[rnds[5]] + "-" + decimalToHex4[rnds[6]] + decimalToHex4[rnds[7]] + "-" + decimalToHex4[rnds[8]] + decimalToHex4[rnds[9]] + "-" + decimalToHex4[rnds[10]] + decimalToHex4[rnds[11]] + decimalToHex4[rnds[12]] + decimalToHex4[rnds[13]] + decimalToHex4[rnds[14]] + decimalToHex4[rnds[15]];
  };
}
var decimalToHex4;
var init_v44 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/uuid/v4.js"() {
    decimalToHex4 = Array.from({ length: 256 }, (_, i32) => i32.toString(16).padStart(2, "0"));
    __name(bindV44, "bindV4");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/copyDocumentWithTransform.js
var copyDocumentWithTransform3;
var init_copyDocumentWithTransform3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/copyDocumentWithTransform.js"() {
    copyDocumentWithTransform3 = /* @__PURE__ */ __name((source, schemaRef, transform = (_) => _) => source, "copyDocumentWithTransform");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/parse-utils.js
var parseBoolean3, expectBoolean3, expectNumber4, MAX_FLOAT4, expectFloat324, expectLong4, expectInt3, expectInt323, expectShort4, expectByte4, expectSizedInt4, castInt4, expectNonNull3, expectObject3, expectString4, expectUnion8, strictParseDouble4, strictParseFloat3, strictParseFloat324, NUMBER_REGEX4, parseNumber4, limitedParseDouble3, handleFloat3, limitedParseFloat3, limitedParseFloat323, parseFloatString3, strictParseLong3, strictParseInt3, strictParseInt323, strictParseShort4, strictParseByte4, stackTraceWarning4, logger4;
var init_parse_utils4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/parse-utils.js"() {
    parseBoolean3 = /* @__PURE__ */ __name((value) => {
      switch (value) {
        case "true":
          return true;
        case "false":
          return false;
        default:
          throw new Error(`Unable to parse boolean value "${value}"`);
      }
    }, "parseBoolean");
    expectBoolean3 = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      if (typeof value === "number") {
        if (value === 0 || value === 1) {
          logger4.warn(stackTraceWarning4(`Expected boolean, got ${typeof value}: ${value}`));
        }
        if (value === 0) {
          return false;
        }
        if (value === 1) {
          return true;
        }
      }
      if (typeof value === "string") {
        const lower = value.toLowerCase();
        if (lower === "false" || lower === "true") {
          logger4.warn(stackTraceWarning4(`Expected boolean, got ${typeof value}: ${value}`));
        }
        if (lower === "false") {
          return false;
        }
        if (lower === "true") {
          return true;
        }
      }
      if (typeof value === "boolean") {
        return value;
      }
      throw new TypeError(`Expected boolean, got ${typeof value}: ${value}`);
    }, "expectBoolean");
    expectNumber4 = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      if (typeof value === "string") {
        const parsed = parseFloat(value);
        if (!Number.isNaN(parsed)) {
          if (String(parsed) !== String(value)) {
            logger4.warn(stackTraceWarning4(`Expected number but observed string: ${value}`));
          }
          return parsed;
        }
      }
      if (typeof value === "number") {
        return value;
      }
      throw new TypeError(`Expected number, got ${typeof value}: ${value}`);
    }, "expectNumber");
    MAX_FLOAT4 = Math.ceil(2 ** 127 * (2 - 2 ** -23));
    expectFloat324 = /* @__PURE__ */ __name((value) => {
      const expected = expectNumber4(value);
      if (expected !== void 0 && !Number.isNaN(expected) && expected !== Infinity && expected !== -Infinity) {
        if (Math.abs(expected) > MAX_FLOAT4) {
          throw new TypeError(`Expected 32-bit float, got ${value}`);
        }
      }
      return expected;
    }, "expectFloat32");
    expectLong4 = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      if (Number.isInteger(value) && !Number.isNaN(value)) {
        return value;
      }
      throw new TypeError(`Expected integer, got ${typeof value}: ${value}`);
    }, "expectLong");
    expectInt3 = expectLong4;
    expectInt323 = /* @__PURE__ */ __name((value) => expectSizedInt4(value, 32), "expectInt32");
    expectShort4 = /* @__PURE__ */ __name((value) => expectSizedInt4(value, 16), "expectShort");
    expectByte4 = /* @__PURE__ */ __name((value) => expectSizedInt4(value, 8), "expectByte");
    expectSizedInt4 = /* @__PURE__ */ __name((value, size) => {
      const expected = expectLong4(value);
      if (expected !== void 0 && castInt4(expected, size) !== expected) {
        throw new TypeError(`Expected ${size}-bit integer, got ${value}`);
      }
      return expected;
    }, "expectSizedInt");
    castInt4 = /* @__PURE__ */ __name((value, size) => {
      switch (size) {
        case 32:
          return Int32Array.of(value)[0];
        case 16:
          return Int16Array.of(value)[0];
        case 8:
          return Int8Array.of(value)[0];
      }
    }, "castInt");
    expectNonNull3 = /* @__PURE__ */ __name((value, location) => {
      if (value === null || value === void 0) {
        if (location) {
          throw new TypeError(`Expected a non-null value for ${location}`);
        }
        throw new TypeError("Expected a non-null value");
      }
      return value;
    }, "expectNonNull");
    expectObject3 = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      if (typeof value === "object" && !Array.isArray(value)) {
        return value;
      }
      const receivedType = Array.isArray(value) ? "array" : typeof value;
      throw new TypeError(`Expected object, got ${receivedType}: ${value}`);
    }, "expectObject");
    expectString4 = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      if (typeof value === "string") {
        return value;
      }
      if (["boolean", "number", "bigint"].includes(typeof value)) {
        logger4.warn(stackTraceWarning4(`Expected string, got ${typeof value}: ${value}`));
        return String(value);
      }
      throw new TypeError(`Expected string, got ${typeof value}: ${value}`);
    }, "expectString");
    expectUnion8 = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      const asObject = expectObject3(value);
      const setKeys = [];
      for (const k32 in asObject) {
        if (asObject[k32] != null) {
          setKeys.push(k32);
        }
      }
      if (setKeys.length === 0) {
        throw new TypeError(`Unions must have exactly one non-null member. None were found.`);
      }
      if (setKeys.length > 1) {
        throw new TypeError(`Unions must have exactly one non-null member. Keys ${setKeys} were not null.`);
      }
      return asObject;
    }, "expectUnion");
    strictParseDouble4 = /* @__PURE__ */ __name((value) => {
      if (typeof value == "string") {
        return expectNumber4(parseNumber4(value));
      }
      return expectNumber4(value);
    }, "strictParseDouble");
    strictParseFloat3 = strictParseDouble4;
    strictParseFloat324 = /* @__PURE__ */ __name((value) => {
      if (typeof value == "string") {
        return expectFloat324(parseNumber4(value));
      }
      return expectFloat324(value);
    }, "strictParseFloat32");
    NUMBER_REGEX4 = /(-?(?:0|[1-9]\d*)(?:\.\d+)?(?:[eE][+-]?\d+)?)|(-?Infinity)|(NaN)/g;
    parseNumber4 = /* @__PURE__ */ __name((value) => {
      const matches = value.match(NUMBER_REGEX4);
      if (matches === null || matches[0].length !== value.length) {
        throw new TypeError(`Expected real number, got implicit NaN`);
      }
      return parseFloat(value);
    }, "parseNumber");
    limitedParseDouble3 = /* @__PURE__ */ __name((value) => {
      if (typeof value == "string") {
        return parseFloatString3(value);
      }
      return expectNumber4(value);
    }, "limitedParseDouble");
    handleFloat3 = limitedParseDouble3;
    limitedParseFloat3 = limitedParseDouble3;
    limitedParseFloat323 = /* @__PURE__ */ __name((value) => {
      if (typeof value == "string") {
        return parseFloatString3(value);
      }
      return expectFloat324(value);
    }, "limitedParseFloat32");
    parseFloatString3 = /* @__PURE__ */ __name((value) => {
      switch (value) {
        case "NaN":
          return NaN;
        case "Infinity":
          return Infinity;
        case "-Infinity":
          return -Infinity;
        default:
          throw new Error(`Unable to parse float value: ${value}`);
      }
    }, "parseFloatString");
    strictParseLong3 = /* @__PURE__ */ __name((value) => {
      if (typeof value === "string") {
        return expectLong4(parseNumber4(value));
      }
      return expectLong4(value);
    }, "strictParseLong");
    strictParseInt3 = strictParseLong3;
    strictParseInt323 = /* @__PURE__ */ __name((value) => {
      if (typeof value === "string") {
        return expectInt323(parseNumber4(value));
      }
      return expectInt323(value);
    }, "strictParseInt32");
    strictParseShort4 = /* @__PURE__ */ __name((value) => {
      if (typeof value === "string") {
        return expectShort4(parseNumber4(value));
      }
      return expectShort4(value);
    }, "strictParseShort");
    strictParseByte4 = /* @__PURE__ */ __name((value) => {
      if (typeof value === "string") {
        return expectByte4(parseNumber4(value));
      }
      return expectByte4(value);
    }, "strictParseByte");
    stackTraceWarning4 = /* @__PURE__ */ __name((message2) => {
      return String(new TypeError(message2).stack || message2).split("\n").slice(0, 5).filter((s) => !s.includes("stackTraceWarning")).join("\n");
    }, "stackTraceWarning");
    logger4 = {
      warn: console.warn
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/date-utils.js
function dateToUtcString16(date7) {
  const year7 = date7.getUTCFullYear();
  const month = date7.getUTCMonth();
  const dayOfWeek = date7.getUTCDay();
  const dayOfMonthInt = date7.getUTCDate();
  const hoursInt = date7.getUTCHours();
  const minutesInt = date7.getUTCMinutes();
  const secondsInt = date7.getUTCSeconds();
  const dayOfMonthString = dayOfMonthInt < 10 ? `0${dayOfMonthInt}` : `${dayOfMonthInt}`;
  const hoursString = hoursInt < 10 ? `0${hoursInt}` : `${hoursInt}`;
  const minutesString = minutesInt < 10 ? `0${minutesInt}` : `${minutesInt}`;
  const secondsString = secondsInt < 10 ? `0${secondsInt}` : `${secondsInt}`;
  return `${DAYS4[dayOfWeek]}, ${dayOfMonthString} ${MONTHS5[month]} ${year7} ${hoursString}:${minutesString}:${secondsString} GMT`;
}
var DAYS4, MONTHS5, RFC33395, parseRfc3339DateTime5, RFC3339_WITH_OFFSET8, parseRfc3339DateTimeWithOffset5, IMF_FIXDATE8, RFC_850_DATE8, ASC_TIME8, parseRfc7231DateTime5, parseEpochTimestamp5, buildDate4, parseTwoDigitYear4, FIFTY_YEARS_IN_MILLIS5, adjustRfc850Year4, parseMonthByShortName4, DAYS_IN_MONTH4, validateDayOfMonth4, isLeapYear4, parseDateValue4, parseMilliseconds4, parseOffsetToMilliseconds3, stripLeadingZeroes4;
var init_date_utils5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/date-utils.js"() {
    init_parse_utils4();
    DAYS4 = ["Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"];
    MONTHS5 = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"];
    __name(dateToUtcString16, "dateToUtcString");
    RFC33395 = new RegExp(/^(\d{4})-(\d{2})-(\d{2})[tT](\d{2}):(\d{2}):(\d{2})(?:\.(\d+))?[zZ]$/);
    parseRfc3339DateTime5 = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      if (typeof value !== "string") {
        throw new TypeError("RFC-3339 date-times must be expressed as strings");
      }
      const match = RFC33395.exec(value);
      if (!match) {
        throw new TypeError("Invalid RFC-3339 date-time value");
      }
      const [_, yearStr, monthStr, dayStr, hours, minutes, seconds, fractionalMilliseconds] = match;
      const year7 = strictParseShort4(stripLeadingZeroes4(yearStr));
      const month = parseDateValue4(monthStr, "month", 1, 12);
      const day = parseDateValue4(dayStr, "day", 1, 31);
      return buildDate4(year7, month, day, { hours, minutes, seconds, fractionalMilliseconds });
    }, "parseRfc3339DateTime");
    RFC3339_WITH_OFFSET8 = new RegExp(/^(\d{4})-(\d{2})-(\d{2})[tT](\d{2}):(\d{2}):(\d{2})(?:\.(\d+))?(([-+]\d{2}\:\d{2})|[zZ])$/);
    parseRfc3339DateTimeWithOffset5 = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      if (typeof value !== "string") {
        throw new TypeError("RFC-3339 date-times must be expressed as strings");
      }
      const match = RFC3339_WITH_OFFSET8.exec(value);
      if (!match) {
        throw new TypeError("Invalid RFC-3339 date-time value");
      }
      const [_, yearStr, monthStr, dayStr, hours, minutes, seconds, fractionalMilliseconds, offsetStr] = match;
      const year7 = strictParseShort4(stripLeadingZeroes4(yearStr));
      const month = parseDateValue4(monthStr, "month", 1, 12);
      const day = parseDateValue4(dayStr, "day", 1, 31);
      const date7 = buildDate4(year7, month, day, { hours, minutes, seconds, fractionalMilliseconds });
      if (offsetStr.toUpperCase() != "Z") {
        date7.setTime(date7.getTime() - parseOffsetToMilliseconds3(offsetStr));
      }
      return date7;
    }, "parseRfc3339DateTimeWithOffset");
    IMF_FIXDATE8 = new RegExp(/^(?:Mon|Tue|Wed|Thu|Fri|Sat|Sun), (\d{2}) (Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec) (\d{4}) (\d{1,2}):(\d{2}):(\d{2})(?:\.(\d+))? GMT$/);
    RFC_850_DATE8 = new RegExp(/^(?:Monday|Tuesday|Wednesday|Thursday|Friday|Saturday|Sunday), (\d{2})-(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)-(\d{2}) (\d{1,2}):(\d{2}):(\d{2})(?:\.(\d+))? GMT$/);
    ASC_TIME8 = new RegExp(/^(?:Mon|Tue|Wed|Thu|Fri|Sat|Sun) (Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec) ( [1-9]|\d{2}) (\d{1,2}):(\d{2}):(\d{2})(?:\.(\d+))? (\d{4})$/);
    parseRfc7231DateTime5 = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      if (typeof value !== "string") {
        throw new TypeError("RFC-7231 date-times must be expressed as strings");
      }
      let match = IMF_FIXDATE8.exec(value);
      if (match) {
        const [_, dayStr, monthStr, yearStr, hours, minutes, seconds, fractionalMilliseconds] = match;
        return buildDate4(strictParseShort4(stripLeadingZeroes4(yearStr)), parseMonthByShortName4(monthStr), parseDateValue4(dayStr, "day", 1, 31), { hours, minutes, seconds, fractionalMilliseconds });
      }
      match = RFC_850_DATE8.exec(value);
      if (match) {
        const [_, dayStr, monthStr, yearStr, hours, minutes, seconds, fractionalMilliseconds] = match;
        return adjustRfc850Year4(buildDate4(parseTwoDigitYear4(yearStr), parseMonthByShortName4(monthStr), parseDateValue4(dayStr, "day", 1, 31), {
          hours,
          minutes,
          seconds,
          fractionalMilliseconds
        }));
      }
      match = ASC_TIME8.exec(value);
      if (match) {
        const [_, monthStr, dayStr, hours, minutes, seconds, fractionalMilliseconds, yearStr] = match;
        return buildDate4(strictParseShort4(stripLeadingZeroes4(yearStr)), parseMonthByShortName4(monthStr), parseDateValue4(dayStr.trimLeft(), "day", 1, 31), { hours, minutes, seconds, fractionalMilliseconds });
      }
      throw new TypeError("Invalid RFC-7231 date-time value");
    }, "parseRfc7231DateTime");
    parseEpochTimestamp5 = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return void 0;
      }
      let valueAsDouble;
      if (typeof value === "number") {
        valueAsDouble = value;
      } else if (typeof value === "string") {
        valueAsDouble = strictParseDouble4(value);
      } else if (typeof value === "object" && value.tag === 1) {
        valueAsDouble = value.value;
      } else {
        throw new TypeError("Epoch timestamps must be expressed as floating point numbers or their string representation");
      }
      if (Number.isNaN(valueAsDouble) || valueAsDouble === Infinity || valueAsDouble === -Infinity) {
        throw new TypeError("Epoch timestamps must be valid, non-Infinite, non-NaN numerics");
      }
      return new Date(Math.round(valueAsDouble * 1e3));
    }, "parseEpochTimestamp");
    buildDate4 = /* @__PURE__ */ __name((year7, month, day, time7) => {
      const adjustedMonth = month - 1;
      validateDayOfMonth4(year7, adjustedMonth, day);
      return new Date(Date.UTC(year7, adjustedMonth, day, parseDateValue4(time7.hours, "hour", 0, 23), parseDateValue4(time7.minutes, "minute", 0, 59), parseDateValue4(time7.seconds, "seconds", 0, 60), parseMilliseconds4(time7.fractionalMilliseconds)));
    }, "buildDate");
    parseTwoDigitYear4 = /* @__PURE__ */ __name((value) => {
      const thisYear = (/* @__PURE__ */ new Date()).getUTCFullYear();
      const valueInThisCentury = Math.floor(thisYear / 100) * 100 + strictParseShort4(stripLeadingZeroes4(value));
      if (valueInThisCentury < thisYear) {
        return valueInThisCentury + 100;
      }
      return valueInThisCentury;
    }, "parseTwoDigitYear");
    FIFTY_YEARS_IN_MILLIS5 = 50 * 365 * 24 * 60 * 60 * 1e3;
    adjustRfc850Year4 = /* @__PURE__ */ __name((input) => {
      if (input.getTime() - (/* @__PURE__ */ new Date()).getTime() > FIFTY_YEARS_IN_MILLIS5) {
        return new Date(Date.UTC(input.getUTCFullYear() - 100, input.getUTCMonth(), input.getUTCDate(), input.getUTCHours(), input.getUTCMinutes(), input.getUTCSeconds(), input.getUTCMilliseconds()));
      }
      return input;
    }, "adjustRfc850Year");
    parseMonthByShortName4 = /* @__PURE__ */ __name((value) => {
      const monthIdx = MONTHS5.indexOf(value);
      if (monthIdx < 0) {
        throw new TypeError(`Invalid month: ${value}`);
      }
      return monthIdx + 1;
    }, "parseMonthByShortName");
    DAYS_IN_MONTH4 = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];
    validateDayOfMonth4 = /* @__PURE__ */ __name((year7, month, day) => {
      let maxDays = DAYS_IN_MONTH4[month];
      if (month === 1 && isLeapYear4(year7)) {
        maxDays = 29;
      }
      if (day > maxDays) {
        throw new TypeError(`Invalid day for ${MONTHS5[month]} in ${year7}: ${day}`);
      }
    }, "validateDayOfMonth");
    isLeapYear4 = /* @__PURE__ */ __name((year7) => {
      return year7 % 4 === 0 && (year7 % 100 !== 0 || year7 % 400 === 0);
    }, "isLeapYear");
    parseDateValue4 = /* @__PURE__ */ __name((value, type, lower, upper) => {
      const dateVal = strictParseByte4(stripLeadingZeroes4(value));
      if (dateVal < lower || dateVal > upper) {
        throw new TypeError(`${type} must be between ${lower} and ${upper}, inclusive`);
      }
      return dateVal;
    }, "parseDateValue");
    parseMilliseconds4 = /* @__PURE__ */ __name((value) => {
      if (value === null || value === void 0) {
        return 0;
      }
      return strictParseFloat324("0." + value) * 1e3;
    }, "parseMilliseconds");
    parseOffsetToMilliseconds3 = /* @__PURE__ */ __name((value) => {
      const directionStr = value[0];
      let direction = 1;
      if (directionStr == "+") {
        direction = 1;
      } else if (directionStr == "-") {
        direction = -1;
      } else {
        throw new TypeError(`Offset direction, ${directionStr}, must be "+" or "-"`);
      }
      const hour = Number(value.substring(1, 3));
      const minute = Number(value.substring(4, 6));
      return direction * (hour * 60 + minute) * 60 * 1e3;
    }, "parseOffsetToMilliseconds");
    stripLeadingZeroes4 = /* @__PURE__ */ __name((value) => {
      let idx = 0;
      while (idx < value.length - 1 && value.charAt(idx) === "0") {
        idx++;
      }
      if (idx === 0) {
        return value;
      }
      return value.slice(idx);
    }, "stripLeadingZeroes");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/lazy-json.js
var LazyJsonString7;
var init_lazy_json4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/lazy-json.js"() {
    LazyJsonString7 = /* @__PURE__ */ __name(function LazyJsonString8(val) {
      const str = Object.assign(new String(val), {
        deserializeJSON() {
          return JSON.parse(String(val));
        },
        toString() {
          return String(val);
        },
        toJSON() {
          return String(val);
        }
      });
      return str;
    }, "LazyJsonString");
    LazyJsonString7.from = (object) => {
      if (object && typeof object === "object" && (object instanceof LazyJsonString7 || "deserializeJSON" in object)) {
        return object;
      } else if (typeof object === "string" || Object.getPrototypeOf(object) === String.prototype) {
        return LazyJsonString7(String(object));
      }
      return LazyJsonString7(JSON.stringify(object));
    };
    LazyJsonString7.fromObject = LazyJsonString7.from;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/quote-header.js
function quoteHeader4(part) {
  if (part.includes(",") || part.includes('"')) {
    part = `"${part.replace(/"/g, '\\"')}"`;
  }
  return part;
}
var init_quote_header4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/quote-header.js"() {
    __name(quoteHeader4, "quoteHeader");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/schema-serde-lib/schema-date-utils.js
function range4(v, min, max) {
  const _v = Number(v);
  if (_v < min || _v > max) {
    throw new Error(`Value ${_v} out of range [${min}, ${max}]`);
  }
}
var ddd4, mmm4, time4, date4, year4, RFC3339_WITH_OFFSET9, IMF_FIXDATE9, RFC_850_DATE9, ASC_TIME9, months4, _parseEpochTimestamp4, _parseRfc3339DateTimeWithOffset4, _parseRfc7231DateTime4;
var init_schema_date_utils4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/schema-serde-lib/schema-date-utils.js"() {
    ddd4 = `(?:Mon|Tue|Wed|Thu|Fri|Sat|Sun)(?:[ne|u?r]?s?day)?`;
    mmm4 = `(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)`;
    time4 = `(\\d?\\d):(\\d{2}):(\\d{2})(?:\\.(\\d+))?`;
    date4 = `(\\d?\\d)`;
    year4 = `(\\d{4})`;
    RFC3339_WITH_OFFSET9 = new RegExp(/^(\d{4})-(\d\d)-(\d\d)[tT](\d\d):(\d\d):(\d\d)(\.(\d+))?(([-+]\d\d:\d\d)|[zZ])$/);
    IMF_FIXDATE9 = new RegExp(`^${ddd4}, ${date4} ${mmm4} ${year4} ${time4} GMT$`);
    RFC_850_DATE9 = new RegExp(`^${ddd4}, ${date4}-${mmm4}-(\\d\\d) ${time4} GMT$`);
    ASC_TIME9 = new RegExp(`^${ddd4} ${mmm4} ( [1-9]|\\d\\d) ${time4} ${year4}$`);
    months4 = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"];
    _parseEpochTimestamp4 = /* @__PURE__ */ __name((value) => {
      if (value == null) {
        return void 0;
      }
      let num = NaN;
      if (typeof value === "number") {
        num = value;
      } else if (typeof value === "string") {
        if (!/^-?\d*\.?\d+$/.test(value)) {
          throw new TypeError(`parseEpochTimestamp - numeric string invalid.`);
        }
        num = Number.parseFloat(value);
      } else if (typeof value === "object" && value.tag === 1) {
        num = value.value;
      }
      if (isNaN(num) || Math.abs(num) === Infinity) {
        throw new TypeError("Epoch timestamps must be valid finite numbers.");
      }
      return new Date(Math.round(num * 1e3));
    }, "_parseEpochTimestamp");
    _parseRfc3339DateTimeWithOffset4 = /* @__PURE__ */ __name((value) => {
      if (value == null) {
        return void 0;
      }
      if (typeof value !== "string") {
        throw new TypeError("RFC3339 timestamps must be strings");
      }
      const matches = RFC3339_WITH_OFFSET9.exec(value);
      if (!matches) {
        throw new TypeError(`Invalid RFC3339 timestamp format ${value}`);
      }
      const [, yearStr, monthStr, dayStr, hours, minutes, seconds, , ms, offsetStr] = matches;
      range4(monthStr, 1, 12);
      range4(dayStr, 1, 31);
      range4(hours, 0, 23);
      range4(minutes, 0, 59);
      range4(seconds, 0, 60);
      const date7 = new Date(Date.UTC(Number(yearStr), Number(monthStr) - 1, Number(dayStr), Number(hours), Number(minutes), Number(seconds), Number(ms) ? Math.round(parseFloat(`0.${ms}`) * 1e3) : 0));
      date7.setUTCFullYear(Number(yearStr));
      if (offsetStr.toUpperCase() != "Z") {
        const [, sign, offsetH, offsetM] = /([+-])(\d\d):(\d\d)/.exec(offsetStr) || [void 0, "+", 0, 0];
        const scalar = sign === "-" ? 1 : -1;
        date7.setTime(date7.getTime() + scalar * (Number(offsetH) * 60 * 60 * 1e3 + Number(offsetM) * 60 * 1e3));
      }
      return date7;
    }, "_parseRfc3339DateTimeWithOffset");
    _parseRfc7231DateTime4 = /* @__PURE__ */ __name((value) => {
      if (value == null) {
        return void 0;
      }
      if (typeof value !== "string") {
        throw new TypeError("RFC7231 timestamps must be strings.");
      }
      let day;
      let month;
      let year7;
      let hour;
      let minute;
      let second;
      let fraction;
      let matches;
      if (matches = IMF_FIXDATE9.exec(value)) {
        [, day, month, year7, hour, minute, second, fraction] = matches;
      } else if (matches = RFC_850_DATE9.exec(value)) {
        [, day, month, year7, hour, minute, second, fraction] = matches;
        year7 = (Number(year7) + 1900).toString();
      } else if (matches = ASC_TIME9.exec(value)) {
        [, month, day, hour, minute, second, fraction, year7] = matches;
      }
      if (year7 && second) {
        const timestamp = Date.UTC(Number(year7), months4.indexOf(month), Number(day), Number(hour), Number(minute), Number(second), fraction ? Math.round(parseFloat(`0.${fraction}`) * 1e3) : 0);
        range4(day, 1, 31);
        range4(hour, 0, 23);
        range4(minute, 0, 59);
        range4(second, 0, 60);
        const date7 = new Date(timestamp);
        date7.setUTCFullYear(Number(year7));
        return date7;
      }
      throw new TypeError(`Invalid RFC7231 date-time value ${value}.`);
    }, "_parseRfc7231DateTime");
    __name(range4, "range");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/split-every.js
function splitEvery4(value, delimiter2, numDelimiters) {
  if (numDelimiters <= 0 || !Number.isInteger(numDelimiters)) {
    throw new Error("Invalid number of delimiters (" + numDelimiters + ") for splitEvery.");
  }
  const segments = value.split(delimiter2);
  if (numDelimiters === 1) {
    return segments;
  }
  const compoundSegments = [];
  let currentSegment = "";
  for (let i32 = 0; i32 < segments.length; i32++) {
    if (currentSegment === "") {
      currentSegment = segments[i32];
    } else {
      currentSegment += delimiter2 + segments[i32];
    }
    if ((i32 + 1) % numDelimiters === 0) {
      compoundSegments.push(currentSegment);
      currentSegment = "";
    }
  }
  if (currentSegment !== "") {
    compoundSegments.push(currentSegment);
  }
  return compoundSegments;
}
var init_split_every4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/split-every.js"() {
    __name(splitEvery4, "splitEvery");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/split-header.js
var splitHeader4;
var init_split_header4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/split-header.js"() {
    splitHeader4 = /* @__PURE__ */ __name((value) => {
      const z = value.length;
      const values = [];
      let withinQuotes = false;
      let prevChar = void 0;
      let anchor = 0;
      for (let i32 = 0; i32 < z; ++i32) {
        const char = value[i32];
        switch (char) {
          case `"`:
            if (prevChar !== "\\") {
              withinQuotes = !withinQuotes;
            }
            break;
          case ",":
            if (!withinQuotes) {
              values.push(value.slice(anchor, i32));
              anchor = i32 + 1;
            }
            break;
          default:
        }
        prevChar = char;
      }
      values.push(value.slice(anchor));
      return values.map((v) => {
        v = v.trim();
        const z2 = v.length;
        if (z2 < 2) {
          return v;
        }
        if (v[0] === `"` && v[z2 - 1] === `"`) {
          v = v.slice(1, z2 - 1);
        }
        return v.replace(/\\"/g, '"');
      });
    }, "splitHeader");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/value/NumericValue.js
function nv4(input) {
  return new NumericValue4(String(input), "bigDecimal");
}
var format14, NumericValue4;
var init_NumericValue4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/value/NumericValue.js"() {
    format14 = /^-?\d*(\.\d+)?$/;
    NumericValue4 = class _NumericValue {
      static {
        __name(this, "NumericValue");
      }
      string;
      type;
      constructor(string, type) {
        this.string = string;
        this.type = type;
        if (!format14.test(string)) {
          throw new Error(`@smithy/core/serde - NumericValue must only contain [0-9], at most one decimal point ".", and an optional negation prefix "-".`);
        }
      }
      toString() {
        return this.string;
      }
      static [Symbol.hasInstance](object) {
        if (!object || typeof object !== "object") {
          return false;
        }
        const _nv = object;
        return _NumericValue.prototype.isPrototypeOf(object) || _nv.type === "bigDecimal" && format14.test(_nv.string);
      }
    };
    __name(nv4, "nv");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-hex-encoding/hex-encoding.js
function fromHex3(encoded) {
  if (encoded.length % 2 !== 0) {
    throw new Error("Hex encoded strings must have an even number length");
  }
  const out = new Uint8Array(encoded.length / 2);
  for (let i32 = 0; i32 < encoded.length; i32 += 2) {
    const encodedByte = encoded.slice(i32, i32 + 2).toLowerCase();
    if (encodedByte in HEX_TO_SHORT3) {
      out[i32 / 2] = HEX_TO_SHORT3[encodedByte];
    } else {
      throw new Error(`Cannot decode unrecognized sequence ${encodedByte} as hexadecimal`);
    }
  }
  return out;
}
function toHex3(bytes) {
  let out = "";
  for (let i32 = 0; i32 < bytes.byteLength; i32++) {
    out += SHORT_TO_HEX3[bytes[i32]];
  }
  return out;
}
var SHORT_TO_HEX3, HEX_TO_SHORT3;
var init_hex_encoding3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-hex-encoding/hex-encoding.js"() {
    SHORT_TO_HEX3 = {};
    HEX_TO_SHORT3 = {};
    for (let i32 = 0; i32 < 256; i32++) {
      let encodedByte = i32.toString(16).toLowerCase();
      if (encodedByte.length === 1) {
        encodedByte = `0${encodedByte}`;
      }
      SHORT_TO_HEX3[i32] = encodedByte;
      HEX_TO_SHORT3[encodedByte] = i32;
    }
    __name(fromHex3, "fromHex");
    __name(toHex3, "toHex");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-body-length/calculateBodyLength.js
var import_node_fs2, calculateBodyLength20;
var init_calculateBodyLength2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-body-length/calculateBodyLength.js"() {
    import_node_fs2 = require("node:fs");
    calculateBodyLength20 = /* @__PURE__ */ __name((body) => {
      if (!body) {
        return 0;
      }
      if (typeof body === "string") {
        return Buffer.byteLength(body);
      } else if (typeof body.byteLength === "number") {
        return body.byteLength;
      } else if (typeof body.size === "number") {
        return body.size;
      } else if (typeof body.start === "number" && typeof body.end === "number") {
        return body.end + 1 - body.start;
      } else if (body instanceof import_node_fs2.ReadStream) {
        if (body.path != null) {
          return (0, import_node_fs2.lstatSync)(body.path).size;
        } else if (typeof body.fd === "number") {
          return (0, import_node_fs2.fstatSync)(body.fd).size;
        }
      }
      throw new Error(`Body Length computation failed for ${body}`);
    }, "calculateBodyLength");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/toUint8Array.js
var toUint8Array3;
var init_toUint8Array2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/toUint8Array.js"() {
    init_fromUtf84();
    toUint8Array3 = /* @__PURE__ */ __name((data3) => {
      if (typeof data3 === "string") {
        return fromUtf827(data3);
      }
      if (ArrayBuffer.isView(data3)) {
        return new Uint8Array(data3.buffer, data3.byteOffset, data3.byteLength / Uint8Array.BYTES_PER_ELEMENT);
      }
      return new Uint8Array(data3);
    }, "toUint8Array");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/collect-stream-body.js
var collectBody11;
var init_collect_stream_body5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/collect-stream-body.js"() {
    init_serde5();
    collectBody11 = /* @__PURE__ */ __name(async (streamBody = new Uint8Array(), context) => {
      if (streamBody instanceof Uint8Array) {
        return Uint8ArrayBlobAdapter5.mutate(streamBody);
      }
      if (!streamBody) {
        return Uint8ArrayBlobAdapter5.mutate(new Uint8Array());
      }
      const fromContext = context.streamCollector(streamBody);
      return Uint8ArrayBlobAdapter5.mutate(await fromContext);
    }, "collectBody");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/extended-encode-uri-component.js
function extendedEncodeURIComponent4(str) {
  return encodeURIComponent(str).replace(/[!'()*]/g, function(c32) {
    return "%" + c32.charCodeAt(0).toString(16).toUpperCase();
  });
}
var init_extended_encode_uri_component5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/extended-encode-uri-component.js"() {
    __name(extendedEncodeURIComponent4, "extendedEncodeURIComponent");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/deref.js
var deref4;
var init_deref4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/deref.js"() {
    deref4 = /* @__PURE__ */ __name((schemaRef) => {
      if (typeof schemaRef === "function") {
        return schemaRef();
      }
      return schemaRef;
    }, "deref");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/middleware-stack/MiddlewareStack.js
var getAllAliases2, getMiddlewareNameWithAliases2, constructStack2, stepWeights2, priorityWeights2;
var init_MiddlewareStack2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/middleware-stack/MiddlewareStack.js"() {
    getAllAliases2 = /* @__PURE__ */ __name((name, aliases) => {
      const _aliases = [];
      if (name) {
        _aliases.push(name);
      }
      if (aliases) {
        for (const alias of aliases) {
          _aliases.push(alias);
        }
      }
      return _aliases;
    }, "getAllAliases");
    getMiddlewareNameWithAliases2 = /* @__PURE__ */ __name((name, aliases) => {
      return `${name || "anonymous"}${aliases && aliases.length > 0 ? ` (a.k.a. ${aliases.join(",")})` : ""}`;
    }, "getMiddlewareNameWithAliases");
    constructStack2 = /* @__PURE__ */ __name(() => {
      let absoluteEntries = [];
      let relativeEntries = [];
      let identifyOnResolve = false;
      const entriesNameSet = /* @__PURE__ */ new Set();
      const sort = /* @__PURE__ */ __name((entries) => entries.sort((a32, b32) => stepWeights2[b32.step] - stepWeights2[a32.step] || priorityWeights2[b32.priority || "normal"] - priorityWeights2[a32.priority || "normal"]), "sort");
      const removeByName = /* @__PURE__ */ __name((toRemove) => {
        let isRemoved = false;
        const filterCb = /* @__PURE__ */ __name((entry) => {
          const aliases = getAllAliases2(entry.name, entry.aliases);
          if (aliases.includes(toRemove)) {
            isRemoved = true;
            for (const alias of aliases) {
              entriesNameSet.delete(alias);
            }
            return false;
          }
          return true;
        }, "filterCb");
        absoluteEntries = absoluteEntries.filter(filterCb);
        relativeEntries = relativeEntries.filter(filterCb);
        return isRemoved;
      }, "removeByName");
      const removeByReference = /* @__PURE__ */ __name((toRemove) => {
        let isRemoved = false;
        const filterCb = /* @__PURE__ */ __name((entry) => {
          if (entry.middleware === toRemove) {
            isRemoved = true;
            for (const alias of getAllAliases2(entry.name, entry.aliases)) {
              entriesNameSet.delete(alias);
            }
            return false;
          }
          return true;
        }, "filterCb");
        absoluteEntries = absoluteEntries.filter(filterCb);
        relativeEntries = relativeEntries.filter(filterCb);
        return isRemoved;
      }, "removeByReference");
      const cloneTo = /* @__PURE__ */ __name((toStack) => {
        absoluteEntries.forEach((entry) => {
          toStack.add(entry.middleware, { ...entry });
        });
        relativeEntries.forEach((entry) => {
          toStack.addRelativeTo(entry.middleware, { ...entry });
        });
        toStack.identifyOnResolve?.(stack.identifyOnResolve());
        return toStack;
      }, "cloneTo");
      const expandRelativeMiddlewareList = /* @__PURE__ */ __name((from) => {
        const expandedMiddlewareList = [];
        from.before.forEach((entry) => {
          if (entry.before.length === 0 && entry.after.length === 0) {
            expandedMiddlewareList.push(entry);
          } else {
            expandedMiddlewareList.push(...expandRelativeMiddlewareList(entry));
          }
        });
        expandedMiddlewareList.push(from);
        from.after.reverse().forEach((entry) => {
          if (entry.before.length === 0 && entry.after.length === 0) {
            expandedMiddlewareList.push(entry);
          } else {
            expandedMiddlewareList.push(...expandRelativeMiddlewareList(entry));
          }
        });
        return expandedMiddlewareList;
      }, "expandRelativeMiddlewareList");
      const getMiddlewareList = /* @__PURE__ */ __name((debug2 = false) => {
        const normalizedAbsoluteEntries = [];
        const normalizedRelativeEntries = [];
        const normalizedEntriesNameMap = {};
        absoluteEntries.forEach((entry) => {
          const normalizedEntry = {
            ...entry,
            before: [],
            after: []
          };
          for (const alias of getAllAliases2(normalizedEntry.name, normalizedEntry.aliases)) {
            normalizedEntriesNameMap[alias] = normalizedEntry;
          }
          normalizedAbsoluteEntries.push(normalizedEntry);
        });
        relativeEntries.forEach((entry) => {
          const normalizedEntry = {
            ...entry,
            before: [],
            after: []
          };
          for (const alias of getAllAliases2(normalizedEntry.name, normalizedEntry.aliases)) {
            normalizedEntriesNameMap[alias] = normalizedEntry;
          }
          normalizedRelativeEntries.push(normalizedEntry);
        });
        normalizedRelativeEntries.forEach((entry) => {
          if (entry.toMiddleware) {
            const toMiddleware = normalizedEntriesNameMap[entry.toMiddleware];
            if (toMiddleware === void 0) {
              if (debug2) {
                return;
              }
              throw new Error(`${entry.toMiddleware} is not found when adding ${getMiddlewareNameWithAliases2(entry.name, entry.aliases)} middleware ${entry.relation} ${entry.toMiddleware}`);
            }
            if (entry.relation === "after") {
              toMiddleware.after.push(entry);
            }
            if (entry.relation === "before") {
              toMiddleware.before.push(entry);
            }
          }
        });
        const mainChain = sort(normalizedAbsoluteEntries).map(expandRelativeMiddlewareList).reduce((wholeList, expandedMiddlewareList) => {
          wholeList.push(...expandedMiddlewareList);
          return wholeList;
        }, []);
        return mainChain;
      }, "getMiddlewareList");
      const stack = {
        add: /* @__PURE__ */ __name((middleware, options = {}) => {
          const { name, override, aliases: _aliases } = options;
          const entry = {
            step: "initialize",
            priority: "normal",
            middleware,
            ...options
          };
          const aliases = getAllAliases2(name, _aliases);
          if (aliases.length > 0) {
            if (aliases.some((alias) => entriesNameSet.has(alias))) {
              if (!override)
                throw new Error(`Duplicate middleware name '${getMiddlewareNameWithAliases2(name, _aliases)}'`);
              for (const alias of aliases) {
                const toOverrideIndex = absoluteEntries.findIndex((entry2) => entry2.name === alias || entry2.aliases?.some((a32) => a32 === alias));
                if (toOverrideIndex === -1) {
                  continue;
                }
                const toOverride = absoluteEntries[toOverrideIndex];
                if (toOverride.step !== entry.step || entry.priority !== toOverride.priority) {
                  throw new Error(`"${getMiddlewareNameWithAliases2(toOverride.name, toOverride.aliases)}" middleware with ${toOverride.priority} priority in ${toOverride.step} step cannot be overridden by "${getMiddlewareNameWithAliases2(name, _aliases)}" middleware with ${entry.priority} priority in ${entry.step} step.`);
                }
                absoluteEntries.splice(toOverrideIndex, 1);
              }
            }
            for (const alias of aliases) {
              entriesNameSet.add(alias);
            }
          }
          absoluteEntries.push(entry);
        }, "add"),
        addRelativeTo: /* @__PURE__ */ __name((middleware, options) => {
          const { name, override, aliases: _aliases } = options;
          const entry = {
            middleware,
            ...options
          };
          const aliases = getAllAliases2(name, _aliases);
          if (aliases.length > 0) {
            if (aliases.some((alias) => entriesNameSet.has(alias))) {
              if (!override)
                throw new Error(`Duplicate middleware name '${getMiddlewareNameWithAliases2(name, _aliases)}'`);
              for (const alias of aliases) {
                const toOverrideIndex = relativeEntries.findIndex((entry2) => entry2.name === alias || entry2.aliases?.some((a32) => a32 === alias));
                if (toOverrideIndex === -1) {
                  continue;
                }
                const toOverride = relativeEntries[toOverrideIndex];
                if (toOverride.toMiddleware !== entry.toMiddleware || toOverride.relation !== entry.relation) {
                  throw new Error(`"${getMiddlewareNameWithAliases2(toOverride.name, toOverride.aliases)}" middleware ${toOverride.relation} "${toOverride.toMiddleware}" middleware cannot be overridden by "${getMiddlewareNameWithAliases2(name, _aliases)}" middleware ${entry.relation} "${entry.toMiddleware}" middleware.`);
                }
                relativeEntries.splice(toOverrideIndex, 1);
              }
            }
            for (const alias of aliases) {
              entriesNameSet.add(alias);
            }
          }
          relativeEntries.push(entry);
        }, "addRelativeTo"),
        clone: /* @__PURE__ */ __name(() => cloneTo(constructStack2()), "clone"),
        use: /* @__PURE__ */ __name((plugin) => {
          plugin.applyToStack(stack);
        }, "use"),
        remove: /* @__PURE__ */ __name((toRemove) => {
          if (typeof toRemove === "string")
            return removeByName(toRemove);
          else
            return removeByReference(toRemove);
        }, "remove"),
        removeByTag: /* @__PURE__ */ __name((toRemove) => {
          let isRemoved = false;
          const filterCb = /* @__PURE__ */ __name((entry) => {
            const { tags, name, aliases: _aliases } = entry;
            if (tags && tags.includes(toRemove)) {
              const aliases = getAllAliases2(name, _aliases);
              for (const alias of aliases) {
                entriesNameSet.delete(alias);
              }
              isRemoved = true;
              return false;
            }
            return true;
          }, "filterCb");
          absoluteEntries = absoluteEntries.filter(filterCb);
          relativeEntries = relativeEntries.filter(filterCb);
          return isRemoved;
        }, "removeByTag"),
        concat: /* @__PURE__ */ __name((from) => {
          const cloned = cloneTo(constructStack2());
          cloned.use(from);
          cloned.identifyOnResolve(identifyOnResolve || cloned.identifyOnResolve() || (from.identifyOnResolve?.() ?? false));
          return cloned;
        }, "concat"),
        applyToStack: cloneTo,
        identify: /* @__PURE__ */ __name(() => {
          return getMiddlewareList(true).map((mw) => {
            const step = mw.step ?? mw.relation + " " + mw.toMiddleware;
            return getMiddlewareNameWithAliases2(mw.name, mw.aliases) + " - " + step;
          });
        }, "identify"),
        identifyOnResolve(toggle) {
          if (typeof toggle === "boolean")
            identifyOnResolve = toggle;
          return identifyOnResolve;
        },
        resolve: /* @__PURE__ */ __name((handler, context) => {
          for (const middleware of getMiddlewareList().map((entry) => entry.middleware).reverse()) {
            handler = middleware(handler, context);
          }
          if (identifyOnResolve) {
            console.log(stack.identify());
          }
          return handler;
        }, "resolve")
      };
      return stack;
    }, "constructStack");
    stepWeights2 = {
      initialize: 5,
      serialize: 4,
      build: 3,
      finalizeRequest: 2,
      deserialize: 1
    };
    priorityWeights2 = {
      high: 3,
      normal: 2,
      low: 1
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/util-middleware/getSmithyContext.js
var import_types45, getSmithyContext28;
var init_getSmithyContext5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/util-middleware/getSmithyContext.js"() {
    import_types45 = __toESM(require_dist_cjs());
    getSmithyContext28 = /* @__PURE__ */ __name((context) => context[import_types45.SMITHY_CONTEXT_KEY] || (context[import_types45.SMITHY_CONTEXT_KEY] = {}), "getSmithyContext");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/util-middleware/normalizeProvider.js
var normalizeProvider24;
var init_normalizeProvider6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/util-middleware/normalizeProvider.js"() {
    normalizeProvider24 = /* @__PURE__ */ __name((input) => {
      if (typeof input === "function")
        return input;
      const promisified = Promise.resolve(input);
      return () => promisified;
    }, "normalizeProvider");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/invalid-dependency/invalidFunction.js
var invalidFunction2;
var init_invalidFunction2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/invalid-dependency/invalidFunction.js"() {
    invalidFunction2 = /* @__PURE__ */ __name((message2) => () => {
      throw new Error(message2);
    }, "invalidFunction");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/invalid-dependency/invalidProvider.js
var invalidProvider2;
var init_invalidProvider2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/invalid-dependency/invalidProvider.js"() {
    invalidProvider2 = /* @__PURE__ */ __name((message2) => () => Promise.reject(message2), "invalidProvider");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/util-waiter/circularReplacer.js
var getCircularReplacer2;
var init_circularReplacer2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/util-waiter/circularReplacer.js"() {
    getCircularReplacer2 = /* @__PURE__ */ __name(() => {
      const seen = /* @__PURE__ */ new WeakSet();
      return (key, value) => {
        if (typeof value === "object" && value !== null) {
          if (seen.has(value)) {
            return "[Circular]";
          }
          seen.add(value);
        }
        return value;
      };
    }, "getCircularReplacer");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/util-waiter/utils/sleep.js
var sleep3;
var init_sleep2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/util-waiter/utils/sleep.js"() {
    sleep3 = /* @__PURE__ */ __name((seconds) => {
      return new Promise((resolve13) => setTimeout(resolve13, seconds * 1e3));
    }, "sleep");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/util-waiter/waiter.js
var waiterServiceDefaults2, WaiterState2, checkExceptions2;
var init_waiter2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/util-waiter/waiter.js"() {
    init_circularReplacer2();
    waiterServiceDefaults2 = {
      minDelay: 2,
      maxDelay: 120
    };
    (function(WaiterState3) {
      WaiterState3["ABORTED"] = "ABORTED";
      WaiterState3["FAILURE"] = "FAILURE";
      WaiterState3["SUCCESS"] = "SUCCESS";
      WaiterState3["RETRY"] = "RETRY";
      WaiterState3["TIMEOUT"] = "TIMEOUT";
    })(WaiterState2 || (WaiterState2 = {}));
    checkExceptions2 = /* @__PURE__ */ __name((result2) => {
      if (result2.state === WaiterState2.ABORTED) {
        const abortError = new Error(`${JSON.stringify({
          ...result2,
          reason: "Request was aborted"
        }, getCircularReplacer2())}`);
        abortError.name = "AbortError";
        throw abortError;
      } else if (result2.state === WaiterState2.TIMEOUT) {
        const timeoutError = new Error(`${JSON.stringify({
          ...result2,
          reason: "Waiter has timed out"
        }, getCircularReplacer2())}`);
        timeoutError.name = "TimeoutError";
        throw timeoutError;
      } else if (result2.state !== WaiterState2.SUCCESS) {
        throw new Error(`${JSON.stringify(result2, getCircularReplacer2())}`);
      }
      return result2;
    }, "checkExceptions");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/util-waiter/poller.js
var runPolling2, checkWarn4032, createMessageFromResponse2, exponentialBackoffWithJitter2, randomInRange2;
var init_poller2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/util-waiter/poller.js"() {
    init_circularReplacer2();
    init_sleep2();
    init_waiter2();
    runPolling2 = /* @__PURE__ */ __name(async ({ minDelay, maxDelay, maxWaitTime, abortController, client, abortSignal }, input, acceptorChecks) => {
      const observedResponses = {};
      const [minDelayMs, maxDelayMs] = [minDelay * 1e3, maxDelay * 1e3];
      let currentAttempt = 0;
      const waitUntil = Date.now() + maxWaitTime * 1e3;
      const warn403Time = Date.now() + 6e4;
      let didWarn403 = false;
      while (true) {
        if (currentAttempt > 0) {
          const delayMs = exponentialBackoffWithJitter2(minDelayMs, maxDelayMs, currentAttempt, waitUntil);
          if (abortController?.signal?.aborted || abortSignal?.aborted) {
            const message2 = "AbortController signal aborted.";
            observedResponses[message2] |= 0;
            observedResponses[message2] += 1;
            return { state: WaiterState2.ABORTED, observedResponses };
          }
          if (Date.now() + delayMs > waitUntil) {
            return { state: WaiterState2.TIMEOUT, observedResponses };
          }
          await sleep3(delayMs / 1e3);
        }
        const { state: state13, reason } = await acceptorChecks(client, input);
        if (reason) {
          const message2 = createMessageFromResponse2(reason);
          observedResponses[message2] |= 0;
          observedResponses[message2] += 1;
        }
        if (state13 !== WaiterState2.RETRY) {
          return { state: state13, reason, final: reason, observedResponses };
        }
        currentAttempt += 1;
        if (!didWarn403 && Date.now() >= warn403Time) {
          checkWarn4032(observedResponses, client);
          didWarn403 = true;
        }
      }
    }, "runPolling");
    checkWarn4032 = /* @__PURE__ */ __name((observedResponses = {}, client) => {
      const orderedErrors = Object.keys(observedResponses);
      let maxCount = 0;
      let count403 = 0;
      for (const response of orderedErrors) {
        const n10 = observedResponses[response] | 0;
        maxCount = Math.max(n10, maxCount);
        if (response.startsWith("403:")) {
          count403 += n10;
        }
      }
      const clientLogger = client?.config?.logger;
      const warningLogger = typeof clientLogger?.warn === "function" && !clientLogger.constructor?.name?.includes?.("NoOpLogger") ? clientLogger : console;
      if (count403 >= 3 || orderedErrors[orderedErrors.length - 1]?.startsWith("403:")) {
        warningLogger.warn(`@smithy/util-waiter WARN - 403 status code encountered during waiter polling.`);
      }
    }, "checkWarn403");
    createMessageFromResponse2 = /* @__PURE__ */ __name((reason) => {
      const status = reason?.$response?.statusCode ?? reason?.$metadata?.httpStatusCode;
      if (reason?.$responseBodyText) {
        return `${status ? status + ": " : ""}Deserialization error for body: ${reason.$responseBodyText}`;
      }
      if (status) {
        if (reason?.$response || reason?.message) {
          return `${status ?? "Unknown"}: ${reason?.message}`;
        }
        return `${status}: OK`;
      }
      return String(reason?.message ?? JSON.stringify(reason, getCircularReplacer2()) ?? "Unknown");
    }, "createMessageFromResponse");
    exponentialBackoffWithJitter2 = /* @__PURE__ */ __name((minDelayMs, maxDelayMs, attempt, waitUntil) => {
      const attemptCountCeiling = Math.log(maxDelayMs / minDelayMs) / Math.log(2) + 1;
      if (attempt > attemptCountCeiling) {
        return maxDelayMs;
      }
      const delay = minDelayMs * 2 ** (attempt - 1);
      const capped = Math.min(delay, maxDelayMs);
      const waitFor2 = randomInRange2(minDelayMs, capped);
      if (Date.now() + waitFor2 > waitUntil) {
        const timeRemaining = waitUntil - Date.now();
        return Math.max(0, timeRemaining - 500);
      }
      return waitFor2;
    }, "exponentialBackoffWithJitter");
    randomInRange2 = /* @__PURE__ */ __name((min, max) => min + Math.random() * (max - min), "randomInRange");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/util-waiter/utils/validate.js
var validateWaiterOptions2;
var init_validate2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/util-waiter/utils/validate.js"() {
    validateWaiterOptions2 = /* @__PURE__ */ __name((options) => {
      if (options.maxWaitTime <= 0) {
        throw new Error(`WaiterConfiguration.maxWaitTime must be greater than 0`);
      } else if (options.minDelay <= 0) {
        throw new Error(`WaiterConfiguration.minDelay must be greater than 0`);
      } else if (options.maxDelay <= 0) {
        throw new Error(`WaiterConfiguration.maxDelay must be greater than 0`);
      } else if (options.maxWaitTime <= options.minDelay) {
        throw new Error(`WaiterConfiguration.maxWaitTime [${options.maxWaitTime}] must be greater than WaiterConfiguration.minDelay [${options.minDelay}] for this waiter`);
      } else if (options.maxDelay < options.minDelay) {
        throw new Error(`WaiterConfiguration.maxDelay [${options.maxDelay}] must be greater than WaiterConfiguration.minDelay [${options.minDelay}] for this waiter`);
      }
    }, "validateWaiterOptions");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/util-waiter/createWaiter.js
var abortTimeout2, createWaiter2;
var init_createWaiter2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/util-waiter/createWaiter.js"() {
    init_poller2();
    init_validate2();
    init_waiter2();
    abortTimeout2 = /* @__PURE__ */ __name((abortSignal) => {
      let onAbort;
      const promise = new Promise((resolve13) => {
        onAbort = /* @__PURE__ */ __name(() => resolve13({ state: WaiterState2.ABORTED }), "onAbort");
        if (typeof abortSignal.addEventListener === "function") {
          abortSignal.addEventListener("abort", onAbort);
        } else {
          abortSignal.onabort = onAbort;
        }
      });
      return {
        clearListener() {
          if (typeof abortSignal.removeEventListener === "function") {
            abortSignal.removeEventListener("abort", onAbort);
          }
        },
        aborted: promise
      };
    }, "abortTimeout");
    createWaiter2 = /* @__PURE__ */ __name(async (options, input, acceptorChecks) => {
      const params = {
        ...waiterServiceDefaults2,
        ...options
      };
      validateWaiterOptions2(params);
      const exitConditions = [runPolling2(params, input, acceptorChecks)];
      const finalize = [];
      if (options.abortSignal) {
        const { aborted, clearListener } = abortTimeout2(options.abortSignal);
        finalize.push(clearListener);
        exitConditions.push(aborted);
      }
      if (options.abortController?.signal) {
        const { aborted, clearListener } = abortTimeout2(options.abortController.signal);
        finalize.push(clearListener);
        exitConditions.push(aborted);
      }
      return Promise.race(exitConditions).then((result2) => {
        for (const fn of finalize) {
          fn();
        }
        return result2;
      });
    }, "createWaiter");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/client.js
var Client2;
var init_client14 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/client.js"() {
    init_MiddlewareStack2();
    Client2 = class {
      static {
        __name(this, "Client");
      }
      config;
      middlewareStack = constructStack2();
      initConfig;
      handlers;
      constructor(config2) {
        this.config = config2;
        const { protocol, protocolSettings } = config2;
        if (protocolSettings) {
          if (typeof protocol === "function") {
            config2.protocol = new protocol(protocolSettings);
          }
        }
      }
      send(command, optionsOrCb, cb) {
        const options = typeof optionsOrCb !== "function" ? optionsOrCb : void 0;
        const callback = typeof optionsOrCb === "function" ? optionsOrCb : cb;
        const useHandlerCache = options === void 0 && this.config.cacheMiddleware === true;
        let handler;
        if (useHandlerCache) {
          if (!this.handlers) {
            this.handlers = /* @__PURE__ */ new WeakMap();
          }
          const handlers = this.handlers;
          if (handlers.has(command.constructor)) {
            handler = handlers.get(command.constructor);
          } else {
            handler = command.resolveMiddleware(this.middlewareStack, this.config, options);
            handlers.set(command.constructor, handler);
          }
        } else {
          delete this.handlers;
          handler = command.resolveMiddleware(this.middlewareStack, this.config, options);
        }
        if (callback) {
          handler(command).then((result2) => callback(null, result2.output), (err) => callback(err)).catch(() => {
          });
        } else {
          return handler(command).then((result2) => result2.output);
        }
      }
      destroy() {
        this.config?.requestHandler?.destroy?.();
        delete this.handlers;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/schemaLogFilter.js
function schemaLogFilter2(schema, data3) {
  if (data3 == null) {
    return data3;
  }
  const ns = NormalizedSchema4.of(schema);
  if (ns.getMergedTraits().sensitive) {
    return SENSITIVE_STRING3;
  }
  if (ns.isListSchema()) {
    const isSensitive = !!ns.getValueSchema().getMergedTraits().sensitive;
    if (isSensitive) {
      return SENSITIVE_STRING3;
    }
  } else if (ns.isMapSchema()) {
    const isSensitive = !!ns.getKeySchema().getMergedTraits().sensitive || !!ns.getValueSchema().getMergedTraits().sensitive;
    if (isSensitive) {
      return SENSITIVE_STRING3;
    }
  } else if (ns.isStructSchema() && typeof data3 === "object") {
    const object = data3;
    const newObject = {};
    for (const [member7, memberNs] of ns.structIterator()) {
      if (object[member7] != null) {
        newObject[member7] = schemaLogFilter2(memberNs, object[member7]);
      }
    }
    return newObject;
  }
  return data3;
}
var SENSITIVE_STRING3;
var init_schemaLogFilter2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/schemaLogFilter.js"() {
    init_schema7();
    SENSITIVE_STRING3 = "***SensitiveInformation***";
    __name(schemaLogFilter2, "schemaLogFilter");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/command.js
var import_types46, Command2, ClassBuilder2;
var init_command2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/command.js"() {
    import_types46 = __toESM(require_dist_cjs());
    init_MiddlewareStack2();
    init_schemaLogFilter2();
    Command2 = class {
      static {
        __name(this, "Command");
      }
      middlewareStack = constructStack2();
      schema;
      static classBuilder() {
        return new ClassBuilder2();
      }
      resolveMiddlewareWithContext(clientStack, configuration, options, { middlewareFn, clientName, commandName, inputFilterSensitiveLog, outputFilterSensitiveLog, smithyContext, additionalContext, CommandCtor }) {
        for (const mw of middlewareFn.bind(this)(CommandCtor, clientStack, configuration, options)) {
          this.middlewareStack.use(mw);
        }
        const stack = clientStack.concat(this.middlewareStack);
        const { logger: logger5 } = configuration;
        const handlerExecutionContext = {
          logger: logger5,
          clientName,
          commandName,
          inputFilterSensitiveLog,
          outputFilterSensitiveLog,
          [import_types46.SMITHY_CONTEXT_KEY]: {
            commandInstance: this,
            ...smithyContext
          },
          ...additionalContext
        };
        const { requestHandler } = configuration;
        let requestOptions = options ?? {};
        if (smithyContext.eventStream) {
          requestOptions = {
            isEventStream: true,
            ...requestOptions
          };
        }
        return stack.resolve((request4) => requestHandler.handle(request4.request, requestOptions), handlerExecutionContext);
      }
    };
    ClassBuilder2 = class {
      static {
        __name(this, "ClassBuilder");
      }
      _init = /* @__PURE__ */ __name(() => {
      }, "_init");
      _ep = {};
      _middlewareFn = /* @__PURE__ */ __name(() => [], "_middlewareFn");
      _commandName = "";
      _clientName = "";
      _additionalContext = {};
      _smithyContext = {};
      _inputFilterSensitiveLog = void 0;
      _outputFilterSensitiveLog = void 0;
      _serializer = null;
      _deserializer = null;
      _operationSchema;
      init(cb) {
        this._init = cb;
      }
      ep(endpointParameterInstructions) {
        this._ep = endpointParameterInstructions;
        return this;
      }
      m(middlewareSupplier) {
        this._middlewareFn = middlewareSupplier;
        return this;
      }
      s(service, operation3, smithyContext = {}) {
        this._smithyContext = {
          service,
          operation: operation3,
          ...smithyContext
        };
        return this;
      }
      c(additionalContext = {}) {
        this._additionalContext = additionalContext;
        return this;
      }
      n(clientName, commandName) {
        this._clientName = clientName;
        this._commandName = commandName;
        return this;
      }
      f(inputFilter = (_) => _, outputFilter = (_) => _) {
        this._inputFilterSensitiveLog = inputFilter;
        this._outputFilterSensitiveLog = outputFilter;
        return this;
      }
      ser(serializer) {
        this._serializer = serializer;
        return this;
      }
      de(deserializer) {
        this._deserializer = deserializer;
        return this;
      }
      sc(operation3) {
        this._operationSchema = operation3;
        this._smithyContext.operationSchema = operation3;
        return this;
      }
      build() {
        const closure = this;
        let CommandRef;
        return CommandRef = class extends Command2 {
          static {
            __name(this, "CommandRef");
          }
          input;
          static getEndpointParameterInstructions() {
            return closure._ep;
          }
          constructor(...[input]) {
            super();
            this.input = input ?? {};
            closure._init(this);
            this.schema = closure._operationSchema;
          }
          resolveMiddleware(stack, configuration, options) {
            const op3 = closure._operationSchema;
            const input = op3?.[4] ?? op3?.input;
            const output = op3?.[5] ?? op3?.output;
            return this.resolveMiddlewareWithContext(stack, configuration, options, {
              CommandCtor: CommandRef,
              middlewareFn: closure._middlewareFn,
              clientName: closure._clientName,
              commandName: closure._commandName,
              inputFilterSensitiveLog: closure._inputFilterSensitiveLog ?? (op3 ? schemaLogFilter2.bind(null, input) : (_) => _),
              outputFilterSensitiveLog: closure._outputFilterSensitiveLog ?? (op3 ? schemaLogFilter2.bind(null, output) : (_) => _),
              smithyContext: closure._smithyContext,
              additionalContext: closure._additionalContext
            });
          }
          serialize = closure._serializer;
          deserialize = closure._deserializer;
        };
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/constants.js
var SENSITIVE_STRING4;
var init_constants10 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/constants.js"() {
    SENSITIVE_STRING4 = "***SensitiveInformation***";
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/create-aggregated-client.js
var createAggregatedClient20;
var init_create_aggregated_client2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/create-aggregated-client.js"() {
    createAggregatedClient20 = /* @__PURE__ */ __name((commands32, Client3, options) => {
      for (const [command, CommandCtor] of Object.entries(commands32)) {
        const methodImpl = /* @__PURE__ */ __name(async function(args, optionsOrCb, cb) {
          const command2 = new CommandCtor(args);
          if (typeof optionsOrCb === "function") {
            this.send(command2, optionsOrCb);
          } else if (typeof cb === "function") {
            if (typeof optionsOrCb !== "object")
              throw new Error(`Expected http options but got ${typeof optionsOrCb}`);
            this.send(command2, optionsOrCb || {}, cb);
          } else {
            return this.send(command2, optionsOrCb);
          }
        }, "methodImpl");
        const methodName = (command[0].toLowerCase() + command.slice(1)).replace(/Command$/, "");
        Client3.prototype[methodName] = methodImpl;
      }
      const { paginators = {}, waiters = {} } = options ?? {};
      for (const [paginatorName, paginatorFn] of Object.entries(paginators)) {
        if (Client3.prototype[paginatorName] === void 0) {
          Client3.prototype[paginatorName] = function(commandInput = {}, paginationConfiguration, ...rest) {
            return paginatorFn({
              ...paginationConfiguration,
              client: this
            }, commandInput, ...rest);
          };
        }
      }
      for (const [waiterName, waiterFn] of Object.entries(waiters)) {
        if (Client3.prototype[waiterName] === void 0) {
          Client3.prototype[waiterName] = async function(commandInput = {}, waiterConfiguration, ...rest) {
            let config2 = waiterConfiguration;
            if (typeof waiterConfiguration === "number") {
              config2 = {
                maxWaitTime: waiterConfiguration
              };
            }
            return waiterFn({
              ...config2,
              client: this
            }, commandInput, ...rest);
          };
        }
      }
    }, "createAggregatedClient");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/exceptions.js
var ServiceException2, decorateServiceException9;
var init_exceptions2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/exceptions.js"() {
    ServiceException2 = class _ServiceException extends Error {
      static {
        __name(this, "ServiceException");
      }
      $fault;
      $response;
      $retryable;
      $metadata;
      constructor(options) {
        super(options.message);
        Object.setPrototypeOf(this, Object.getPrototypeOf(this).constructor.prototype);
        this.name = options.name;
        this.$fault = options.$fault;
        this.$metadata = options.$metadata;
      }
      static isInstance(value) {
        if (!value)
          return false;
        const candidate = value;
        return _ServiceException.prototype.isPrototypeOf(candidate) || Boolean(candidate.$fault) && Boolean(candidate.$metadata) && (candidate.$fault === "client" || candidate.$fault === "server");
      }
      static [Symbol.hasInstance](instance) {
        if (!instance)
          return false;
        const candidate = instance;
        if (this === _ServiceException) {
          return _ServiceException.isInstance(instance);
        }
        if (_ServiceException.isInstance(instance)) {
          if (candidate.name && this.name) {
            return this.prototype.isPrototypeOf(instance) || candidate.name === this.name;
          }
          return this.prototype.isPrototypeOf(instance);
        }
        return false;
      }
    };
    decorateServiceException9 = /* @__PURE__ */ __name((exception, additions = {}) => {
      Object.entries(additions).filter(([, v]) => v !== void 0).forEach(([k32, v]) => {
        if (exception[k32] == void 0 || exception[k32] === "") {
          exception[k32] = v;
        }
      });
      const message2 = exception.message || exception.Message || "UnknownError";
      exception.message = message2;
      delete exception.Message;
      return exception;
    }, "decorateServiceException");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/default-error-handler.js
var throwDefaultError2, withBaseException2, deserializeMetadata2;
var init_default_error_handler2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/default-error-handler.js"() {
    init_exceptions2();
    throwDefaultError2 = /* @__PURE__ */ __name(({ output, parsedBody, exceptionCtor, errorCode }) => {
      const $metadata = deserializeMetadata2(output);
      const statusCode = $metadata.httpStatusCode ? $metadata.httpStatusCode + "" : void 0;
      const response = new exceptionCtor({
        name: parsedBody?.code || parsedBody?.Code || errorCode || statusCode || "UnknownError",
        $fault: "client",
        $metadata
      });
      throw decorateServiceException9(response, parsedBody);
    }, "throwDefaultError");
    withBaseException2 = /* @__PURE__ */ __name((ExceptionCtor) => {
      return ({ output, parsedBody, errorCode }) => {
        throwDefaultError2({ output, parsedBody, exceptionCtor: ExceptionCtor, errorCode });
      };
    }, "withBaseException");
    deserializeMetadata2 = /* @__PURE__ */ __name((output) => ({
      httpStatusCode: output.statusCode,
      requestId: output.headers["x-amzn-requestid"] ?? output.headers["x-amzn-request-id"] ?? output.headers["x-amz-request-id"],
      extendedRequestId: output.headers["x-amz-id-2"],
      cfId: output.headers["x-amz-cf-id"]
    }), "deserializeMetadata");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/defaults-mode.js
var loadConfigsForDefaultMode20;
var init_defaults_mode2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/defaults-mode.js"() {
    loadConfigsForDefaultMode20 = /* @__PURE__ */ __name((mode) => {
      switch (mode) {
        case "standard":
          return {
            retryMode: "standard",
            connectionTimeout: 3100
          };
        case "in-region":
          return {
            retryMode: "standard",
            connectionTimeout: 1100
          };
        case "cross-region":
          return {
            retryMode: "standard",
            connectionTimeout: 3100
          };
        case "mobile":
          return {
            retryMode: "standard",
            connectionTimeout: 3e4
          };
        default:
          return {};
      }
    }, "loadConfigsForDefaultMode");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/emitWarningIfUnsupportedVersion.js
var warningEmitted2, emitWarningIfUnsupportedVersion29;
var init_emitWarningIfUnsupportedVersion11 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/emitWarningIfUnsupportedVersion.js"() {
    warningEmitted2 = false;
    emitWarningIfUnsupportedVersion29 = /* @__PURE__ */ __name((version) => {
      if (version && !warningEmitted2 && parseInt(version.substring(1, version.indexOf("."))) < 16) {
        warningEmitted2 = true;
      }
    }, "emitWarningIfUnsupportedVersion");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/extensions/checksum.js
var import_types47, knownAlgorithms2, getChecksumConfiguration2, resolveChecksumRuntimeConfig2;
var init_checksum2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/extensions/checksum.js"() {
    import_types47 = __toESM(require_dist_cjs());
    knownAlgorithms2 = Object.values(import_types47.AlgorithmId);
    getChecksumConfiguration2 = /* @__PURE__ */ __name((runtimeConfig) => {
      const checksumAlgorithms = [];
      for (const id in import_types47.AlgorithmId) {
        const algorithmId = import_types47.AlgorithmId[id];
        if (runtimeConfig[algorithmId] === void 0) {
          continue;
        }
        checksumAlgorithms.push({
          algorithmId: /* @__PURE__ */ __name(() => algorithmId, "algorithmId"),
          checksumConstructor: /* @__PURE__ */ __name(() => runtimeConfig[algorithmId], "checksumConstructor")
        });
      }
      for (const [id, ChecksumCtor] of Object.entries(runtimeConfig.checksumAlgorithms ?? {})) {
        checksumAlgorithms.push({
          algorithmId: /* @__PURE__ */ __name(() => id, "algorithmId"),
          checksumConstructor: /* @__PURE__ */ __name(() => ChecksumCtor, "checksumConstructor")
        });
      }
      return {
        addChecksumAlgorithm(algo) {
          runtimeConfig.checksumAlgorithms = runtimeConfig.checksumAlgorithms ?? {};
          const id = algo.algorithmId();
          const ctor = algo.checksumConstructor();
          if (knownAlgorithms2.includes(id)) {
            runtimeConfig.checksumAlgorithms[id.toUpperCase()] = ctor;
          } else {
            runtimeConfig.checksumAlgorithms[id] = ctor;
          }
          checksumAlgorithms.push(algo);
        },
        checksumAlgorithms() {
          return checksumAlgorithms;
        }
      };
    }, "getChecksumConfiguration");
    resolveChecksumRuntimeConfig2 = /* @__PURE__ */ __name((clientConfig) => {
      const runtimeConfig = {};
      clientConfig.checksumAlgorithms().forEach((checksumAlgorithm) => {
        const id = checksumAlgorithm.algorithmId();
        if (knownAlgorithms2.includes(id)) {
          runtimeConfig[id] = checksumAlgorithm.checksumConstructor();
        }
      });
      return runtimeConfig;
    }, "resolveChecksumRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/extensions/retry.js
var getRetryConfiguration2, resolveRetryRuntimeConfig2;
var init_retry4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/extensions/retry.js"() {
    getRetryConfiguration2 = /* @__PURE__ */ __name((runtimeConfig) => {
      return {
        setRetryStrategy(retryStrategy) {
          runtimeConfig.retryStrategy = retryStrategy;
        },
        retryStrategy() {
          return runtimeConfig.retryStrategy;
        }
      };
    }, "getRetryConfiguration");
    resolveRetryRuntimeConfig2 = /* @__PURE__ */ __name((retryStrategyConfiguration) => {
      const runtimeConfig = {};
      runtimeConfig.retryStrategy = retryStrategyConfiguration.retryStrategy();
      return runtimeConfig;
    }, "resolveRetryRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/extensions/defaultExtensionConfiguration.js
var getDefaultExtensionConfiguration20, getDefaultClientConfiguration2, resolveDefaultRuntimeConfig20;
var init_defaultExtensionConfiguration2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/extensions/defaultExtensionConfiguration.js"() {
    init_checksum2();
    init_retry4();
    getDefaultExtensionConfiguration20 = /* @__PURE__ */ __name((runtimeConfig) => {
      return Object.assign(getChecksumConfiguration2(runtimeConfig), getRetryConfiguration2(runtimeConfig));
    }, "getDefaultExtensionConfiguration");
    getDefaultClientConfiguration2 = getDefaultExtensionConfiguration20;
    resolveDefaultRuntimeConfig20 = /* @__PURE__ */ __name((config2) => {
      return Object.assign(resolveChecksumRuntimeConfig2(config2), resolveRetryRuntimeConfig2(config2));
    }, "resolveDefaultRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/get-array-if-single-item.js
var getArrayIfSingleItem2;
var init_get_array_if_single_item2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/get-array-if-single-item.js"() {
    getArrayIfSingleItem2 = /* @__PURE__ */ __name((mayBeArray) => Array.isArray(mayBeArray) ? mayBeArray : [mayBeArray], "getArrayIfSingleItem");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/get-value-from-text-node.js
var getValueFromTextNode13;
var init_get_value_from_text_node2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/get-value-from-text-node.js"() {
    getValueFromTextNode13 = /* @__PURE__ */ __name((obj) => {
      const textNodeName = "#text";
      for (const key in obj) {
        if (obj.hasOwnProperty(key) && obj[key][textNodeName] !== void 0) {
          obj[key] = obj[key][textNodeName];
        } else if (typeof obj[key] === "object" && obj[key] !== null) {
          obj[key] = getValueFromTextNode13(obj[key]);
        }
      }
      return obj;
    }, "getValueFromTextNode");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/is-serializable-header-value.js
var isSerializableHeaderValue2;
var init_is_serializable_header_value2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/is-serializable-header-value.js"() {
    isSerializableHeaderValue2 = /* @__PURE__ */ __name((value) => {
      return value != null;
    }, "isSerializableHeaderValue");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/NoOpLogger.js
var NoOpLogger21;
var init_NoOpLogger3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/NoOpLogger.js"() {
    NoOpLogger21 = class {
      static {
        __name(this, "NoOpLogger");
      }
      trace() {
      }
      debug() {
      }
      info() {
      }
      warn() {
      }
      error() {
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/object-mapping.js
function map4(arg0, arg1, arg2) {
  let target;
  let filter;
  let instructions;
  if (typeof arg1 === "undefined" && typeof arg2 === "undefined") {
    target = {};
    instructions = arg0;
  } else {
    target = arg0;
    if (typeof arg1 === "function") {
      filter = arg1;
      instructions = arg2;
      return mapWithFilter2(target, filter, instructions);
    } else {
      instructions = arg1;
    }
  }
  for (const key of Object.keys(instructions)) {
    if (!Array.isArray(instructions[key])) {
      target[key] = instructions[key];
      continue;
    }
    applyInstruction2(target, null, instructions, key);
  }
  return target;
}
var convertMap2, take2, mapWithFilter2, applyInstruction2, nonNullish2, pass2;
var init_object_mapping2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/object-mapping.js"() {
    __name(map4, "map");
    convertMap2 = /* @__PURE__ */ __name((target) => {
      const output = {};
      for (const [k32, v] of Object.entries(target || {})) {
        output[k32] = [, v];
      }
      return output;
    }, "convertMap");
    take2 = /* @__PURE__ */ __name((source, instructions) => {
      const out = {};
      for (const key in instructions) {
        applyInstruction2(out, source, instructions, key);
      }
      return out;
    }, "take");
    mapWithFilter2 = /* @__PURE__ */ __name((target, filter, instructions) => {
      return map4(target, Object.entries(instructions).reduce((_instructions, [key, value]) => {
        if (Array.isArray(value)) {
          _instructions[key] = value;
        } else {
          if (typeof value === "function") {
            _instructions[key] = [filter, value()];
          } else {
            _instructions[key] = [filter, value];
          }
        }
        return _instructions;
      }, {}));
    }, "mapWithFilter");
    applyInstruction2 = /* @__PURE__ */ __name((target, source, instructions, targetKey) => {
      if (source !== null) {
        let instruction = instructions[targetKey];
        if (typeof instruction === "function") {
          instruction = [, instruction];
        }
        const [filter2 = nonNullish2, valueFn = pass2, sourceKey = targetKey] = instruction;
        if (typeof filter2 === "function" && filter2(source[sourceKey]) || typeof filter2 !== "function" && !!filter2) {
          target[targetKey] = valueFn(source[sourceKey]);
        }
        return;
      }
      let [filter, value] = instructions[targetKey];
      if (typeof value === "function") {
        let _value;
        const defaultFilterPassed = filter === void 0 && (_value = value()) != null;
        const customFilterPassed = typeof filter === "function" && !!filter(void 0) || typeof filter !== "function" && !!filter;
        if (defaultFilterPassed) {
          target[targetKey] = _value;
        } else if (customFilterPassed) {
          target[targetKey] = value();
        }
      } else {
        const defaultFilterPassed = filter === void 0 && value != null;
        const customFilterPassed = typeof filter === "function" && !!filter(value) || typeof filter !== "function" && !!filter;
        if (defaultFilterPassed || customFilterPassed) {
          target[targetKey] = value;
        }
      }
    }, "applyInstruction");
    nonNullish2 = /* @__PURE__ */ __name((_) => _ != null, "nonNullish");
    pass2 = /* @__PURE__ */ __name((_) => _, "pass");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/ser-utils.js
var serializeFloat2, serializeDateTime2;
var init_ser_utils2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/ser-utils.js"() {
    serializeFloat2 = /* @__PURE__ */ __name((value) => {
      if (value !== value) {
        return "NaN";
      }
      switch (value) {
        case Infinity:
          return "Infinity";
        case -Infinity:
          return "-Infinity";
        default:
          return value;
      }
    }, "serializeFloat");
    serializeDateTime2 = /* @__PURE__ */ __name((date7) => date7.toISOString().replace(".000Z", "Z"), "serializeDateTime");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/serde-json.js
var _json2;
var init_serde_json2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/smithy-client/serde-json.js"() {
    _json2 = /* @__PURE__ */ __name((obj) => {
      if (obj == null) {
        return {};
      }
      if (Array.isArray(obj)) {
        return obj.filter((_) => _ != null).map(_json2);
      }
      if (typeof obj === "object") {
        const target = {};
        for (const key of Object.keys(obj)) {
          if (obj[key] == null) {
            continue;
          }
          target[key] = _json2(obj[key]);
        }
        return target;
      }
      return obj;
    }, "_json");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/index.js
var client_exports11 = {};
__export(client_exports11, {
  AlgorithmId: () => import_types47.AlgorithmId,
  Client: () => Client2,
  Command: () => Command2,
  NoOpLogger: () => NoOpLogger21,
  SENSITIVE_STRING: () => SENSITIVE_STRING4,
  ServiceException: () => ServiceException2,
  WaiterState: () => WaiterState2,
  _json: () => _json2,
  checkExceptions: () => checkExceptions2,
  constructStack: () => constructStack2,
  convertMap: () => convertMap2,
  createAggregatedClient: () => createAggregatedClient20,
  createWaiter: () => createWaiter2,
  decorateServiceException: () => decorateServiceException9,
  emitWarningIfUnsupportedVersion: () => emitWarningIfUnsupportedVersion29,
  getArrayIfSingleItem: () => getArrayIfSingleItem2,
  getChecksumConfiguration: () => getChecksumConfiguration2,
  getDefaultClientConfiguration: () => getDefaultClientConfiguration2,
  getDefaultExtensionConfiguration: () => getDefaultExtensionConfiguration20,
  getRetryConfiguration: () => getRetryConfiguration2,
  getSmithyContext: () => getSmithyContext28,
  getValueFromTextNode: () => getValueFromTextNode13,
  invalidFunction: () => invalidFunction2,
  invalidProvider: () => invalidProvider2,
  isSerializableHeaderValue: () => isSerializableHeaderValue2,
  loadConfigsForDefaultMode: () => loadConfigsForDefaultMode20,
  map: () => map4,
  normalizeProvider: () => normalizeProvider24,
  resolveChecksumRuntimeConfig: () => resolveChecksumRuntimeConfig2,
  resolveDefaultRuntimeConfig: () => resolveDefaultRuntimeConfig20,
  resolveRetryRuntimeConfig: () => resolveRetryRuntimeConfig2,
  schemaLogFilter: () => schemaLogFilter2,
  serializeDateTime: () => serializeDateTime2,
  serializeFloat: () => serializeFloat2,
  take: () => take2,
  throwDefaultError: () => throwDefaultError2,
  waiterServiceDefaults: () => waiterServiceDefaults2,
  withBaseException: () => withBaseException2
});
var init_client15 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/client/index.js"() {
    init_MiddlewareStack2();
    init_getSmithyContext5();
    init_normalizeProvider6();
    init_invalidFunction2();
    init_invalidProvider2();
    init_createWaiter2();
    init_waiter2();
    init_client14();
    init_command2();
    init_constants10();
    init_create_aggregated_client2();
    init_default_error_handler2();
    init_defaults_mode2();
    init_emitWarningIfUnsupportedVersion11();
    init_exceptions2();
    init_defaultExtensionConfiguration2();
    init_checksum2();
    init_retry4();
    init_get_array_if_single_item2();
    init_get_value_from_text_node2();
    init_is_serializable_header_value2();
    init_NoOpLogger3();
    init_object_mapping2();
    init_schemaLogFilter2();
    init_ser_utils2();
    init_serde_json2();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/schemas/operation.js
var init_operation4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/schemas/operation.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/property-provider/ProviderError.js
var ProviderError9;
var init_ProviderError3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/property-provider/ProviderError.js"() {
    ProviderError9 = class _ProviderError extends Error {
      static {
        __name(this, "ProviderError");
      }
      name = "ProviderError";
      tryNextLink;
      constructor(message2, options = true) {
        let logger5;
        let tryNextLink = true;
        if (typeof options === "boolean") {
          logger5 = void 0;
          tryNextLink = options;
        } else if (options != null && typeof options === "object") {
          logger5 = options.logger;
          tryNextLink = options.tryNextLink ?? true;
        }
        super(message2);
        this.tryNextLink = tryNextLink;
        Object.setPrototypeOf(this, _ProviderError.prototype);
        logger5?.debug?.(`@smithy/property-provider ${tryNextLink ? "->" : "(!)"} ${message2}`);
      }
      static from(error4, options = true) {
        return Object.assign(new this(error4.message, options), error4);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/property-provider/CredentialsProviderError.js
var CredentialsProviderError3;
var init_CredentialsProviderError3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/property-provider/CredentialsProviderError.js"() {
    init_ProviderError3();
    CredentialsProviderError3 = class _CredentialsProviderError extends ProviderError9 {
      static {
        __name(this, "CredentialsProviderError");
      }
      name = "CredentialsProviderError";
      constructor(message2, options = true) {
        super(message2, options);
        Object.setPrototypeOf(this, _CredentialsProviderError.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/property-provider/chain.js
var chain3;
var init_chain3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/property-provider/chain.js"() {
    init_ProviderError3();
    chain3 = /* @__PURE__ */ __name((...providers) => async () => {
      if (providers.length === 0) {
        throw new ProviderError9("No providers in chain");
      }
      let lastProviderError;
      for (const provider of providers) {
        try {
          const credentials = await provider();
          return credentials;
        } catch (err) {
          lastProviderError = err;
          if (err?.tryNextLink) {
            continue;
          }
          throw err;
        }
      }
      throw lastProviderError;
    }, "chain");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/property-provider/fromValue.js
var fromValue3;
var init_fromValue3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/property-provider/fromValue.js"() {
    fromValue3 = /* @__PURE__ */ __name((staticValue) => () => Promise.resolve(staticValue), "fromValue");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/property-provider/memoize.js
var memoize3;
var init_memoize3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/property-provider/memoize.js"() {
    memoize3 = /* @__PURE__ */ __name((provider, isExpired, requiresRefresh) => {
      let resolved;
      let pending;
      let hasResult;
      let isConstant = false;
      const coalesceProvider = /* @__PURE__ */ __name(async () => {
        if (!pending) {
          pending = provider();
        }
        try {
          resolved = await pending;
          hasResult = true;
          isConstant = false;
        } finally {
          pending = void 0;
        }
        return resolved;
      }, "coalesceProvider");
      if (isExpired === void 0) {
        return async (options) => {
          if (!hasResult || options?.forceRefresh) {
            resolved = await coalesceProvider();
          }
          return resolved;
        };
      }
      return async (options) => {
        if (!hasResult || options?.forceRefresh) {
          resolved = await coalesceProvider();
        }
        if (isConstant) {
          return resolved;
        }
        if (requiresRefresh && !requiresRefresh(resolved)) {
          isConstant = true;
          return resolved;
        }
        if (isExpired(resolved)) {
          await coalesceProvider();
          return resolved;
        }
        return resolved;
      };
    }, "memoize");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getHomeDir.js
var import_node_os4, import_node_path12, homeDirCache3, getHomeDirCacheKey3, getHomeDir3;
var init_getHomeDir3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getHomeDir.js"() {
    import_node_os4 = require("node:os");
    import_node_path12 = require("node:path");
    homeDirCache3 = {};
    getHomeDirCacheKey3 = /* @__PURE__ */ __name(() => {
      if (process && process.geteuid) {
        return `${process.geteuid()}`;
      }
      return "DEFAULT";
    }, "getHomeDirCacheKey");
    getHomeDir3 = /* @__PURE__ */ __name(() => {
      const { HOME, USERPROFILE, HOMEPATH, HOMEDRIVE = `C:${import_node_path12.sep}` } = process.env;
      if (HOME)
        return HOME;
      if (USERPROFILE)
        return USERPROFILE;
      if (HOMEPATH)
        return `${HOMEDRIVE}${HOMEPATH}`;
      const homeDirCacheKey = getHomeDirCacheKey3();
      if (!homeDirCache3[homeDirCacheKey])
        homeDirCache3[homeDirCacheKey] = (0, import_node_os4.homedir)();
      return homeDirCache3[homeDirCacheKey];
    }, "getHomeDir");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getProfileName.js
var ENV_PROFILE3, DEFAULT_PROFILE3, getProfileName3;
var init_getProfileName3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getProfileName.js"() {
    ENV_PROFILE3 = "AWS_PROFILE";
    DEFAULT_PROFILE3 = "default";
    getProfileName3 = /* @__PURE__ */ __name((init) => init.profile || process.env[ENV_PROFILE3] || DEFAULT_PROFILE3, "getProfileName");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/constants.js
var CONFIG_PREFIX_SEPARATOR3;
var init_constants11 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/constants.js"() {
    CONFIG_PREFIX_SEPARATOR3 = ".";
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getConfigData.js
var import_types48, getConfigData3;
var init_getConfigData3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getConfigData.js"() {
    import_types48 = __toESM(require_dist_cjs());
    init_constants11();
    getConfigData3 = /* @__PURE__ */ __name((data3) => Object.entries(data3).filter(([key]) => {
      const indexOfSeparator = key.indexOf(CONFIG_PREFIX_SEPARATOR3);
      if (indexOfSeparator === -1) {
        return false;
      }
      return Object.values(import_types48.IniSectionType).includes(key.substring(0, indexOfSeparator));
    }).reduce((acc, [key, value]) => {
      const indexOfSeparator = key.indexOf(CONFIG_PREFIX_SEPARATOR3);
      const updatedKey = key.substring(0, indexOfSeparator) === import_types48.IniSectionType.PROFILE ? key.substring(indexOfSeparator + 1) : key;
      acc[updatedKey] = value;
      return acc;
    }, {
      ...data3.default && { default: data3.default }
    }), "getConfigData");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getConfigFilepath.js
var import_node_path13, ENV_CONFIG_PATH3, getConfigFilepath3;
var init_getConfigFilepath3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getConfigFilepath.js"() {
    import_node_path13 = require("node:path");
    init_getHomeDir3();
    ENV_CONFIG_PATH3 = "AWS_CONFIG_FILE";
    getConfigFilepath3 = /* @__PURE__ */ __name(() => process.env[ENV_CONFIG_PATH3] || (0, import_node_path13.join)(getHomeDir3(), ".aws", "config"), "getConfigFilepath");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getCredentialsFilepath.js
var import_node_path14, ENV_CREDENTIALS_PATH3, getCredentialsFilepath3;
var init_getCredentialsFilepath3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getCredentialsFilepath.js"() {
    import_node_path14 = require("node:path");
    init_getHomeDir3();
    ENV_CREDENTIALS_PATH3 = "AWS_SHARED_CREDENTIALS_FILE";
    getCredentialsFilepath3 = /* @__PURE__ */ __name(() => process.env[ENV_CREDENTIALS_PATH3] || (0, import_node_path14.join)(getHomeDir3(), ".aws", "credentials"), "getCredentialsFilepath");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/parseIni.js
var import_types49, prefixKeyRegex3, profileNameBlockList3, parseIni3;
var init_parseIni3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/parseIni.js"() {
    import_types49 = __toESM(require_dist_cjs());
    init_constants11();
    prefixKeyRegex3 = /^([\w-]+)\s(["'])?([\w-@\+\.%:/]+)\2$/;
    profileNameBlockList3 = ["__proto__", "profile __proto__"];
    parseIni3 = /* @__PURE__ */ __name((iniData) => {
      const map5 = {};
      let currentSection;
      let currentSubSection;
      for (const iniLine of iniData.split(/\r?\n/)) {
        const trimmedLine = iniLine.split(/(^|\s)[;#]/)[0].trim();
        const isSection = trimmedLine[0] === "[" && trimmedLine[trimmedLine.length - 1] === "]";
        if (isSection) {
          currentSection = void 0;
          currentSubSection = void 0;
          const sectionName = trimmedLine.substring(1, trimmedLine.length - 1);
          const matches = prefixKeyRegex3.exec(sectionName);
          if (matches) {
            const [, prefix, , name] = matches;
            if (Object.values(import_types49.IniSectionType).includes(prefix)) {
              currentSection = [prefix, name].join(CONFIG_PREFIX_SEPARATOR3);
            }
          } else {
            currentSection = sectionName;
          }
          if (profileNameBlockList3.includes(sectionName)) {
            throw new Error(`Found invalid profile name "${sectionName}"`);
          }
        } else if (currentSection) {
          const indexOfEqualsSign = trimmedLine.indexOf("=");
          if (![0, -1].includes(indexOfEqualsSign)) {
            const [name, value] = [
              trimmedLine.substring(0, indexOfEqualsSign).trim(),
              trimmedLine.substring(indexOfEqualsSign + 1).trim()
            ];
            if (value === "") {
              currentSubSection = name;
            } else {
              if (currentSubSection && iniLine.trimStart() === iniLine) {
                currentSubSection = void 0;
              }
              map5[currentSection] = map5[currentSection] || {};
              const key = currentSubSection ? [currentSubSection, name].join(CONFIG_PREFIX_SEPARATOR3) : name;
              map5[currentSection][key] = value;
            }
          }
        }
      }
      return map5;
    }, "parseIni");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/readFile.js
var import_promises5, filePromises3, fileIntercept3, readFile7;
var init_readFile3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/readFile.js"() {
    import_promises5 = require("node:fs/promises");
    filePromises3 = {};
    fileIntercept3 = {};
    readFile7 = /* @__PURE__ */ __name((path47, options) => {
      if (fileIntercept3[path47] !== void 0) {
        return fileIntercept3[path47];
      }
      if (!filePromises3[path47] || options?.ignoreCache) {
        filePromises3[path47] = (0, import_promises5.readFile)(path47, "utf8");
      }
      return filePromises3[path47];
    }, "readFile");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/loadSharedConfigFiles.js
var import_node_path15, swallowError4, loadSharedConfigFiles3;
var init_loadSharedConfigFiles3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/loadSharedConfigFiles.js"() {
    import_node_path15 = require("node:path");
    init_getConfigData3();
    init_getConfigFilepath3();
    init_getCredentialsFilepath3();
    init_getHomeDir3();
    init_parseIni3();
    init_readFile3();
    swallowError4 = /* @__PURE__ */ __name(() => ({}), "swallowError");
    loadSharedConfigFiles3 = /* @__PURE__ */ __name(async (init = {}) => {
      const { filepath = getCredentialsFilepath3(), configFilepath = getConfigFilepath3() } = init;
      const homeDir = getHomeDir3();
      const relativeHomeDirPrefix = "~/";
      let resolvedFilepath = filepath;
      if (filepath.startsWith(relativeHomeDirPrefix)) {
        resolvedFilepath = (0, import_node_path15.join)(homeDir, filepath.slice(2));
      }
      let resolvedConfigFilepath = configFilepath;
      if (configFilepath.startsWith(relativeHomeDirPrefix)) {
        resolvedConfigFilepath = (0, import_node_path15.join)(homeDir, configFilepath.slice(2));
      }
      const parsedFiles = await Promise.all([
        readFile7(resolvedConfigFilepath, {
          ignoreCache: init.ignoreCache
        }).then(parseIni3).then(getConfigData3).catch(swallowError4),
        readFile7(resolvedFilepath, {
          ignoreCache: init.ignoreCache
        }).then(parseIni3).catch(swallowError4)
      ]);
      return {
        configFile: parsedFiles[0],
        credentialsFile: parsedFiles[1]
      };
    }, "loadSharedConfigFiles");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/getSelectorName.js
function getSelectorName3(functionString) {
  try {
    const constants3 = new Set(Array.from(functionString.match(/([A-Z_]){3,}/g) ?? []));
    constants3.delete("CONFIG");
    constants3.delete("CONFIG_PREFIX_SEPARATOR");
    constants3.delete("ENV");
    return [...constants3].join(", ");
  } catch (e32) {
    return functionString;
  }
}
var init_getSelectorName3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/getSelectorName.js"() {
    __name(getSelectorName3, "getSelectorName");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/fromEnv.js
var fromEnv3;
var init_fromEnv3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/fromEnv.js"() {
    init_CredentialsProviderError3();
    init_getSelectorName3();
    fromEnv3 = /* @__PURE__ */ __name((envVarSelector, options) => async () => {
      try {
        const config2 = envVarSelector(process.env, options);
        if (config2 === void 0) {
          throw new Error();
        }
        return config2;
      } catch (e32) {
        throw new CredentialsProviderError3(e32.message || `Not found in ENV: ${getSelectorName3(envVarSelector.toString())}`, { logger: options?.logger });
      }
    }, "fromEnv");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/fromSharedConfigFiles.js
var fromSharedConfigFiles3;
var init_fromSharedConfigFiles3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/fromSharedConfigFiles.js"() {
    init_CredentialsProviderError3();
    init_getProfileName3();
    init_loadSharedConfigFiles3();
    init_getSelectorName3();
    fromSharedConfigFiles3 = /* @__PURE__ */ __name((configSelector, { preferredFile = "config", ...init } = {}) => async () => {
      const profile = getProfileName3(init);
      const { configFile, credentialsFile } = await loadSharedConfigFiles3(init);
      const profileFromCredentials = credentialsFile[profile] || {};
      const profileFromConfig = configFile[profile] || {};
      const mergedProfile = preferredFile === "config" ? { ...profileFromCredentials, ...profileFromConfig } : { ...profileFromConfig, ...profileFromCredentials };
      try {
        const cfgFile = preferredFile === "config" ? configFile : credentialsFile;
        const configValue = configSelector(mergedProfile, cfgFile);
        if (configValue === void 0) {
          throw new Error();
        }
        return configValue;
      } catch (e32) {
        throw new CredentialsProviderError3(e32.message || `Not found in config files w/ profile [${profile}]: ${getSelectorName3(configSelector.toString())}`, { logger: init.logger });
      }
    }, "fromSharedConfigFiles");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/fromStatic.js
var isFunction3, fromStatic3;
var init_fromStatic3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/fromStatic.js"() {
    init_fromValue3();
    isFunction3 = /* @__PURE__ */ __name((func) => typeof func === "function", "isFunction");
    fromStatic3 = /* @__PURE__ */ __name((defaultValue2) => isFunction3(defaultValue2) ? async () => await defaultValue2() : fromValue3(defaultValue2), "fromStatic");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/configLoader.js
var loadConfig4;
var init_configLoader3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/configLoader.js"() {
    init_chain3();
    init_memoize3();
    init_fromEnv3();
    init_fromSharedConfigFiles3();
    init_fromStatic3();
    loadConfig4 = /* @__PURE__ */ __name(({ environmentVariableSelector, configFileSelector, default: defaultValue2 }, configuration = {}) => {
      const { signingName, logger: logger5 } = configuration;
      const envOptions = { signingName, logger: logger5 };
      return memoize3(chain3(fromEnv3(environmentVariableSelector, envOptions), fromSharedConfigFiles3(configFileSelector, configuration), fromStatic3(defaultValue2)));
    }, "loadConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/index.js
var init_config6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/config/index.js"() {
    init_constants11();
    init_configLoader3();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/getEndpointUrlConfig.js
var ENV_ENDPOINT_URL3, CONFIG_ENDPOINT_URL3, getEndpointUrlConfig3;
var init_getEndpointUrlConfig3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/getEndpointUrlConfig.js"() {
    init_config6();
    ENV_ENDPOINT_URL3 = "AWS_ENDPOINT_URL";
    CONFIG_ENDPOINT_URL3 = "endpoint_url";
    getEndpointUrlConfig3 = /* @__PURE__ */ __name((serviceId) => ({
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => {
        const serviceSuffixParts = serviceId.split(" ").map((w) => w.toUpperCase());
        const serviceEndpointUrl = env3[[ENV_ENDPOINT_URL3, ...serviceSuffixParts].join("_")];
        if (serviceEndpointUrl)
          return serviceEndpointUrl;
        const endpointUrl = env3[ENV_ENDPOINT_URL3];
        if (endpointUrl)
          return endpointUrl;
        return void 0;
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile, config2) => {
        if (config2 && profile.services) {
          const servicesSection = config2[["services", profile.services].join(CONFIG_PREFIX_SEPARATOR3)];
          if (servicesSection) {
            const servicePrefixParts = serviceId.split(" ").map((w) => w.toLowerCase());
            const endpointUrl2 = servicesSection[[servicePrefixParts.join("_"), CONFIG_ENDPOINT_URL3].join(CONFIG_PREFIX_SEPARATOR3)];
            if (endpointUrl2)
              return endpointUrl2;
          }
        }
        const endpointUrl = profile[CONFIG_ENDPOINT_URL3];
        if (endpointUrl)
          return endpointUrl;
        return void 0;
      }, "configFileSelector"),
      default: void 0
    }), "getEndpointUrlConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/getEndpointFromConfig.js
var getEndpointFromConfig3;
var init_getEndpointFromConfig3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/getEndpointFromConfig.js"() {
    init_config6();
    init_getEndpointUrlConfig3();
    getEndpointFromConfig3 = /* @__PURE__ */ __name(async (serviceId) => loadConfig4(getEndpointUrlConfig3(serviceId ?? ""))(), "getEndpointFromConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/service-customizations/s3.js
var resolveParamsForS33, DOMAIN_PATTERN3, IP_ADDRESS_PATTERN3, DOTS_PATTERN3, isDnsCompatibleBucketName3, isArnBucketName3;
var init_s33 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/service-customizations/s3.js"() {
    resolveParamsForS33 = /* @__PURE__ */ __name(async (endpointParams) => {
      const bucket = endpointParams?.Bucket || "";
      if (typeof endpointParams.Bucket === "string") {
        endpointParams.Bucket = bucket.replace(/#/g, encodeURIComponent("#")).replace(/\?/g, encodeURIComponent("?"));
      }
      if (isArnBucketName3(bucket)) {
        if (endpointParams.ForcePathStyle === true) {
          throw new Error("Path-style addressing cannot be used with ARN buckets");
        }
      } else if (!isDnsCompatibleBucketName3(bucket) || bucket.indexOf(".") !== -1 && !String(endpointParams.Endpoint).startsWith("http:") || bucket.toLowerCase() !== bucket || bucket.length < 3) {
        endpointParams.ForcePathStyle = true;
      }
      if (endpointParams.DisableMultiRegionAccessPoints) {
        endpointParams.disableMultiRegionAccessPoints = true;
        endpointParams.DisableMRAP = true;
      }
      return endpointParams;
    }, "resolveParamsForS3");
    DOMAIN_PATTERN3 = /^[a-z0-9][a-z0-9\.\-]{1,61}[a-z0-9]$/;
    IP_ADDRESS_PATTERN3 = /(\d+\.){3}\d+/;
    DOTS_PATTERN3 = /\.\./;
    isDnsCompatibleBucketName3 = /* @__PURE__ */ __name((bucketName) => DOMAIN_PATTERN3.test(bucketName) && !IP_ADDRESS_PATTERN3.test(bucketName) && !DOTS_PATTERN3.test(bucketName), "isDnsCompatibleBucketName");
    isArnBucketName3 = /* @__PURE__ */ __name((bucketName) => {
      const [arn, partition4, service, , , bucket] = bucketName.split(":");
      const isArn = arn === "arn" && bucketName.split(":").length >= 6;
      const isValidArn = Boolean(isArn && partition4 && service && bucket);
      if (isArn && !isValidArn) {
        throw new Error(`Invalid ARN: ${bucketName} was an invalid ARN.`);
      }
      return isValidArn;
    }, "isArnBucketName");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/service-customizations/index.js
var init_service_customizations3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/service-customizations/index.js"() {
    init_s33();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/createConfigValueProvider.js
var createConfigValueProvider3;
var init_createConfigValueProvider3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/createConfigValueProvider.js"() {
    createConfigValueProvider3 = /* @__PURE__ */ __name((configKey, canonicalEndpointParamKey, config2, isClientContextParam = false) => {
      const configProvider = /* @__PURE__ */ __name(async () => {
        let configValue;
        if (isClientContextParam) {
          const clientContextParams = config2.clientContextParams;
          const nestedValue = clientContextParams?.[configKey];
          configValue = nestedValue ?? config2[configKey] ?? config2[canonicalEndpointParamKey];
        } else {
          configValue = config2[configKey] ?? config2[canonicalEndpointParamKey];
        }
        if (typeof configValue === "function") {
          return configValue();
        }
        return configValue;
      }, "configProvider");
      if (configKey === "credentialScope" || canonicalEndpointParamKey === "CredentialScope") {
        return async () => {
          const credentials = typeof config2.credentials === "function" ? await config2.credentials() : config2.credentials;
          const configValue = credentials?.credentialScope ?? credentials?.CredentialScope;
          return configValue;
        };
      }
      if (configKey === "accountId" || canonicalEndpointParamKey === "AccountId") {
        return async () => {
          const credentials = typeof config2.credentials === "function" ? await config2.credentials() : config2.credentials;
          const configValue = credentials?.accountId ?? credentials?.AccountId;
          return configValue;
        };
      }
      if (configKey === "endpoint" || canonicalEndpointParamKey === "endpoint") {
        return async () => {
          if (config2.isCustomEndpoint === false) {
            return void 0;
          }
          const endpoint = await configProvider();
          if (endpoint && typeof endpoint === "object") {
            if ("url" in endpoint) {
              return endpoint.url.href;
            }
            if ("hostname" in endpoint) {
              const { protocol, hostname, port, path: path47 } = endpoint;
              return `${protocol}//${hostname}${port ? ":" + port : ""}${path47}`;
            }
          }
          return endpoint;
        };
      }
      return configProvider;
    }, "createConfigValueProvider");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/toEndpointV1.js
var toEndpointV15;
var init_toEndpointV16 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/toEndpointV1.js"() {
    init_protocols12();
    toEndpointV15 = /* @__PURE__ */ __name((endpoint) => {
      if (typeof endpoint === "object") {
        if ("url" in endpoint) {
          const v1Endpoint = parseUrl22(endpoint.url);
          if (endpoint.headers) {
            v1Endpoint.headers = {};
            for (const name in endpoint.headers) {
              v1Endpoint.headers[name.toLowerCase()] = endpoint.headers[name].join(", ");
            }
          }
          return v1Endpoint;
        }
        return endpoint;
      }
      return parseUrl22(endpoint);
    }, "toEndpointV1");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/toEndpointV1.js
var init_toEndpointV17 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/toEndpointV1.js"() {
    init_toEndpointV16();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/getEndpointFromInstructions.js
function bindGetEndpointFromInstructions3(getEndpointFromConfig5) {
  return async (commandInput, instructionsSupplier, clientConfig, context) => {
    if (!clientConfig.isCustomEndpoint) {
      let endpointFromConfig;
      if (clientConfig.serviceConfiguredEndpoint) {
        endpointFromConfig = await clientConfig.serviceConfiguredEndpoint();
      } else {
        endpointFromConfig = await getEndpointFromConfig5(clientConfig.serviceId);
      }
      if (endpointFromConfig) {
        clientConfig.endpoint = () => Promise.resolve(toEndpointV15(endpointFromConfig));
        clientConfig.isCustomEndpoint = true;
      }
    }
    const endpointParams = await resolveParams8(commandInput, instructionsSupplier, clientConfig);
    if (typeof clientConfig.endpointProvider !== "function") {
      throw new Error("config.endpointProvider is not set.");
    }
    const endpoint = clientConfig.endpointProvider(endpointParams, context);
    if (clientConfig.isCustomEndpoint && clientConfig.endpoint) {
      const customEndpoint = await clientConfig.endpoint();
      if (customEndpoint?.headers) {
        endpoint.headers ??= {};
        for (const [name, value] of Object.entries(customEndpoint.headers)) {
          endpoint.headers[name] = Array.isArray(value) ? value : [value];
        }
      }
    }
    return endpoint;
  };
}
var resolveParams8;
var init_getEndpointFromInstructions3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/getEndpointFromInstructions.js"() {
    init_service_customizations3();
    init_createConfigValueProvider3();
    init_toEndpointV17();
    __name(bindGetEndpointFromInstructions3, "bindGetEndpointFromInstructions");
    resolveParams8 = /* @__PURE__ */ __name(async (commandInput, instructionsSupplier, clientConfig) => {
      const endpointParams = {};
      const instructions = instructionsSupplier?.getEndpointParameterInstructions?.() || {};
      for (const [name, instruction] of Object.entries(instructions)) {
        switch (instruction.type) {
          case "staticContextParams":
            endpointParams[name] = instruction.value;
            break;
          case "contextParams":
            endpointParams[name] = commandInput[instruction.name];
            break;
          case "clientContextParams":
          case "builtInParams":
            endpointParams[name] = await createConfigValueProvider3(instruction.name, name, clientConfig, instruction.type !== "builtInParams")();
            break;
          case "operationContextParams":
            endpointParams[name] = instruction.get(commandInput);
            break;
          default:
            throw new Error("Unrecognized endpoint parameter instruction: " + JSON.stringify(instruction));
        }
      }
      if (Object.keys(instructions).length === 0) {
        Object.assign(endpointParams, clientConfig);
      }
      if (String(clientConfig.serviceId).toLowerCase() === "s3") {
        await resolveParamsForS33(endpointParams);
      }
      return endpointParams;
    }, "resolveParams");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/endpointMiddleware.js
function setFeature14(context, feature, value) {
  if (!context.__smithy_context) {
    context.__smithy_context = { features: {} };
  } else if (!context.__smithy_context.features) {
    context.__smithy_context.features = {};
  }
  context.__smithy_context.features[feature] = value;
}
function bindEndpointMiddleware3(getEndpointFromConfig5) {
  const getEndpointFromInstructions7 = bindGetEndpointFromInstructions3(getEndpointFromConfig5);
  return ({ config: config2, instructions }) => {
    return (next, context) => async (args) => {
      if (config2.isCustomEndpoint) {
        setFeature14(context, "ENDPOINT_OVERRIDE", "N");
      }
      const endpoint = await getEndpointFromInstructions7(args.input, {
        getEndpointParameterInstructions() {
          return instructions;
        }
      }, { ...config2 }, context);
      context.endpointV2 = endpoint;
      context.authSchemes = endpoint.properties?.authSchemes;
      const authScheme = context.authSchemes?.[0];
      if (authScheme) {
        context["signing_region"] = authScheme.signingRegion;
        context["signing_service"] = authScheme.signingName;
        const smithyContext = getSmithyContext28(context);
        const httpAuthOption = smithyContext?.selectedHttpAuthScheme?.httpAuthOption;
        if (httpAuthOption) {
          httpAuthOption.signingProperties = Object.assign(httpAuthOption.signingProperties || {}, {
            signing_region: authScheme.signingRegion,
            signingRegion: authScheme.signingRegion,
            signing_service: authScheme.signingName,
            signingName: authScheme.signingName,
            signingRegionSet: authScheme.signingRegionSet
          }, authScheme.properties);
        }
      }
      return next({
        ...args
      });
    };
  };
}
var init_endpointMiddleware3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/endpointMiddleware.js"() {
    init_client15();
    init_getEndpointFromInstructions3();
    __name(setFeature14, "setFeature");
    __name(bindEndpointMiddleware3, "bindEndpointMiddleware");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/getEndpointPlugin.js
function bindGetEndpointPlugin3(getEndpointFromConfig5) {
  const endpointMiddleware5 = bindEndpointMiddleware3(getEndpointFromConfig5);
  return (config2, instructions) => ({
    applyToStack: /* @__PURE__ */ __name((clientStack) => {
      clientStack.addRelativeTo(endpointMiddleware5({
        config: config2,
        instructions
      }), endpointMiddlewareOptions3);
    }, "applyToStack")
  });
}
var serializerMiddlewareOption6, endpointMiddlewareOptions3;
var init_getEndpointPlugin3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/getEndpointPlugin.js"() {
    init_endpointMiddleware3();
    serializerMiddlewareOption6 = {
      name: "serializerMiddleware",
      step: "serialize",
      tags: ["SERIALIZER"],
      override: true
    };
    endpointMiddlewareOptions3 = {
      step: "serialize",
      tags: ["ENDPOINT_PARAMETERS", "ENDPOINT_V2", "ENDPOINT"],
      name: "endpointV2Middleware",
      override: true,
      relation: "before",
      toMiddleware: serializerMiddlewareOption6.name
    };
    __name(bindGetEndpointPlugin3, "bindGetEndpointPlugin");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/resolveEndpointConfig.js
function bindResolveEndpointConfig3(getEndpointFromConfig5) {
  return (input) => {
    const tls = input.tls ?? true;
    const { endpoint, useDualstackEndpoint, useFipsEndpoint } = input;
    const customEndpointProvider = endpoint != null ? async () => toEndpointV15(await normalizeProvider24(endpoint)()) : void 0;
    const isCustomEndpoint = !!endpoint;
    const resolvedConfig = Object.assign(input, {
      endpoint: customEndpointProvider,
      tls,
      isCustomEndpoint,
      useDualstackEndpoint: normalizeProvider24(useDualstackEndpoint ?? false),
      useFipsEndpoint: normalizeProvider24(useFipsEndpoint ?? false)
    });
    let configuredEndpointPromise = void 0;
    resolvedConfig.serviceConfiguredEndpoint = async () => {
      if (input.serviceId && !configuredEndpointPromise) {
        configuredEndpointPromise = getEndpointFromConfig5(input.serviceId);
      }
      return configuredEndpointPromise;
    };
    return resolvedConfig;
  };
}
var init_resolveEndpointConfig3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/resolveEndpointConfig.js"() {
    init_client15();
    init_toEndpointV17();
    __name(bindResolveEndpointConfig3, "bindResolveEndpointConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/EndpointError.js
var init_EndpointError4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/EndpointError.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/EndpointFunctions.js
var init_EndpointFunctions3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/EndpointFunctions.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/EndpointRuleObject.js
var init_EndpointRuleObject3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/EndpointRuleObject.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/ErrorRuleObject.js
var init_ErrorRuleObject3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/ErrorRuleObject.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/RuleSetObject.js
var init_RuleSetObject3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/RuleSetObject.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/TreeRuleObject.js
var init_TreeRuleObject3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/TreeRuleObject.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/shared.js
var init_shared3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/shared.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/index.js
var init_types9 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/index.js"() {
    init_EndpointError4();
    init_EndpointFunctions3();
    init_EndpointRuleObject3();
    init_ErrorRuleObject3();
    init_RuleSetObject3();
    init_TreeRuleObject3();
    init_shared3();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/index.js
var getEndpointFromInstructions4, resolveEndpointConfig21, endpointMiddleware3, getEndpointPlugin27;
var init_endpoints4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/endpoints/index.js"() {
    init_getEndpointFromConfig3();
    init_getEndpointFromInstructions3();
    init_endpointMiddleware3();
    init_getEndpointPlugin3();
    init_resolveEndpointConfig3();
    init_toEndpointV16();
    init_types9();
    getEndpointFromInstructions4 = bindGetEndpointFromInstructions3(getEndpointFromConfig3);
    resolveEndpointConfig21 = bindResolveEndpointConfig3(getEndpointFromConfig3);
    endpointMiddleware3 = bindEndpointMiddleware3(getEndpointFromConfig3);
    getEndpointPlugin27 = bindGetEndpointPlugin3(getEndpointFromConfig3);
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/middleware/getSchemaSerdePlugin.js
var init_getSchemaSerdePlugin4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/middleware/getSchemaSerdePlugin.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/schemas/Schema.js
var init_Schema4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/schemas/Schema.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/schemas/ListSchema.js
var init_ListSchema4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/schemas/ListSchema.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/schemas/MapSchema.js
var init_MapSchema4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/schemas/MapSchema.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/schemas/OperationSchema.js
var init_OperationSchema4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/schemas/OperationSchema.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/schemas/StructureSchema.js
var init_StructureSchema4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/schemas/StructureSchema.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/schemas/ErrorSchema.js
var init_ErrorSchema4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/schemas/ErrorSchema.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/schemas/translateTraits.js
function translateTraits4(indicator) {
  if (typeof indicator === "object") {
    return indicator;
  }
  indicator = indicator | 0;
  if (traitsCache4[indicator]) {
    return traitsCache4[indicator];
  }
  const traits = {};
  let i32 = 0;
  for (const trait of [
    "httpLabel",
    "idempotent",
    "idempotencyToken",
    "sensitive",
    "httpPayload",
    "httpResponseCode",
    "httpQueryParams"
  ]) {
    if ((indicator >> i32++ & 1) === 1) {
      traits[trait] = 1;
    }
  }
  return traitsCache4[indicator] = traits;
}
var traitsCache4;
var init_translateTraits4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/schemas/translateTraits.js"() {
    traitsCache4 = [];
    __name(translateTraits4, "translateTraits");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/schemas/NormalizedSchema.js
function member4(memberSchema, memberName) {
  if (memberSchema instanceof NormalizedSchema4) {
    return Object.assign(memberSchema, {
      memberName,
      _isMemberSchema: true
    });
  }
  const internalCtorAccess = NormalizedSchema4;
  return new internalCtorAccess(memberSchema, memberName);
}
var anno4, simpleSchemaCacheN4, simpleSchemaCacheS4, NormalizedSchema4, isMemberSchema4, isStaticSchema4;
var init_NormalizedSchema4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/schemas/NormalizedSchema.js"() {
    init_deref4();
    init_translateTraits4();
    anno4 = {
      it: /* @__PURE__ */ Symbol.for("@smithy/nor-struct-it"),
      ns: /* @__PURE__ */ Symbol.for("@smithy/ns")
    };
    simpleSchemaCacheN4 = [];
    simpleSchemaCacheS4 = {};
    NormalizedSchema4 = class _NormalizedSchema {
      static {
        __name(this, "NormalizedSchema");
      }
      ref;
      memberName;
      static symbol = /* @__PURE__ */ Symbol.for("@smithy/nor");
      symbol = _NormalizedSchema.symbol;
      name;
      schema;
      _isMemberSchema;
      traits;
      memberTraits;
      normalizedTraits;
      constructor(ref, memberName) {
        this.ref = ref;
        this.memberName = memberName;
        const traitStack = [];
        let _ref = ref;
        let schema = ref;
        this._isMemberSchema = false;
        while (isMemberSchema4(_ref)) {
          traitStack.push(_ref[1]);
          _ref = _ref[0];
          schema = deref4(_ref);
          this._isMemberSchema = true;
        }
        if (traitStack.length > 0) {
          this.memberTraits = {};
          for (let i32 = traitStack.length - 1; i32 >= 0; --i32) {
            const traitSet = traitStack[i32];
            Object.assign(this.memberTraits, translateTraits4(traitSet));
          }
        } else {
          this.memberTraits = 0;
        }
        if (schema instanceof _NormalizedSchema) {
          const computedMemberTraits = this.memberTraits;
          Object.assign(this, schema);
          this.memberTraits = Object.assign({}, computedMemberTraits, schema.getMemberTraits(), this.getMemberTraits());
          this.normalizedTraits = void 0;
          this.memberName = memberName ?? schema.memberName;
          return;
        }
        this.schema = deref4(schema);
        if (isStaticSchema4(this.schema)) {
          this.name = `${this.schema[1]}#${this.schema[2]}`;
          this.traits = this.schema[3];
        } else {
          this.name = this.memberName ?? String(schema);
          this.traits = 0;
        }
        if (this._isMemberSchema && !memberName) {
          throw new Error(`@smithy/core/schema - NormalizedSchema member init ${this.getName(true)} missing member name.`);
        }
      }
      static [Symbol.hasInstance](lhs) {
        const isPrototype = this.prototype.isPrototypeOf(lhs);
        if (!isPrototype && typeof lhs === "object" && lhs !== null) {
          const ns = lhs;
          return ns.symbol === this.symbol;
        }
        return isPrototype;
      }
      static of(ref) {
        const keyAble = typeof ref === "function" || typeof ref === "object" && ref !== null;
        if (typeof ref === "number") {
          if (simpleSchemaCacheN4[ref]) {
            return simpleSchemaCacheN4[ref];
          }
        } else if (typeof ref === "string") {
          if (simpleSchemaCacheS4[ref]) {
            return simpleSchemaCacheS4[ref];
          }
        } else if (keyAble) {
          if (ref[anno4.ns]) {
            return ref[anno4.ns];
          }
        }
        const sc = deref4(ref);
        if (sc instanceof _NormalizedSchema) {
          return sc;
        }
        if (isMemberSchema4(sc)) {
          const [ns2, traits] = sc;
          if (ns2 instanceof _NormalizedSchema) {
            Object.assign(ns2.getMergedTraits(), translateTraits4(traits));
            return ns2;
          }
          throw new Error(`@smithy/core/schema - may not init unwrapped member schema=${JSON.stringify(ref, null, 2)}.`);
        }
        const ns = new _NormalizedSchema(sc);
        if (keyAble) {
          return ref[anno4.ns] = ns;
        }
        if (typeof sc === "string") {
          return simpleSchemaCacheS4[sc] = ns;
        }
        if (typeof sc === "number") {
          return simpleSchemaCacheN4[sc] = ns;
        }
        return ns;
      }
      getSchema() {
        const sc = this.schema;
        if (Array.isArray(sc) && sc[0] === 0) {
          return sc[4];
        }
        return sc;
      }
      getName(withNamespace = false) {
        const { name } = this;
        const short = !withNamespace && name && name.includes("#");
        return short ? name.split("#")[1] : name || void 0;
      }
      getMemberName() {
        return this.memberName;
      }
      isMemberSchema() {
        return this._isMemberSchema;
      }
      isListSchema() {
        const sc = this.getSchema();
        return typeof sc === "number" ? sc >= 64 && sc < 128 : sc[0] === 1;
      }
      isMapSchema() {
        const sc = this.getSchema();
        return typeof sc === "number" ? sc >= 128 && sc <= 255 : sc[0] === 2;
      }
      isStructSchema() {
        const sc = this.getSchema();
        if (typeof sc !== "object") {
          return false;
        }
        const id = sc[0];
        return id === 3 || id === -3 || id === 4;
      }
      isUnionSchema() {
        const sc = this.getSchema();
        if (typeof sc !== "object") {
          return false;
        }
        return sc[0] === 4;
      }
      isBlobSchema() {
        const sc = this.getSchema();
        return sc === 21 || sc === 42;
      }
      isTimestampSchema() {
        const sc = this.getSchema();
        return typeof sc === "number" && sc >= 4 && sc <= 7;
      }
      isUnitSchema() {
        return this.getSchema() === "unit";
      }
      isDocumentSchema() {
        return this.getSchema() === 15;
      }
      isStringSchema() {
        return this.getSchema() === 0;
      }
      isBooleanSchema() {
        return this.getSchema() === 2;
      }
      isNumericSchema() {
        return this.getSchema() === 1;
      }
      isBigIntegerSchema() {
        return this.getSchema() === 17;
      }
      isBigDecimalSchema() {
        return this.getSchema() === 19;
      }
      isStreaming() {
        const { streaming } = this.getMergedTraits();
        return !!streaming || this.getSchema() === 42;
      }
      isIdempotencyToken() {
        return !!this.getMergedTraits().idempotencyToken;
      }
      getMergedTraits() {
        return this.normalizedTraits ?? (this.normalizedTraits = {
          ...this.getOwnTraits(),
          ...this.getMemberTraits()
        });
      }
      getMemberTraits() {
        return translateTraits4(this.memberTraits);
      }
      getOwnTraits() {
        return translateTraits4(this.traits);
      }
      getKeySchema() {
        const [isDoc, isMap] = [this.isDocumentSchema(), this.isMapSchema()];
        if (!isDoc && !isMap) {
          throw new Error(`@smithy/core/schema - cannot get key for non-map: ${this.getName(true)}`);
        }
        const schema = this.getSchema();
        const memberSchema = isDoc ? 15 : schema[4] ?? 0;
        return member4([memberSchema, 0], "key");
      }
      getValueSchema() {
        const sc = this.getSchema();
        const [isDoc, isMap, isList] = [this.isDocumentSchema(), this.isMapSchema(), this.isListSchema()];
        const memberSchema = typeof sc === "number" ? 63 & sc : sc && typeof sc === "object" && (isMap || isList) ? sc[3 + sc[0]] : isDoc ? 15 : void 0;
        if (memberSchema != null) {
          return member4([memberSchema, 0], isMap ? "value" : "member");
        }
        throw new Error(`@smithy/core/schema - ${this.getName(true)} has no value member.`);
      }
      getMemberSchema(memberName) {
        const struct3 = this.getSchema();
        if (this.isStructSchema() && struct3[4].includes(memberName)) {
          const i32 = struct3[4].indexOf(memberName);
          const memberSchema = struct3[5][i32];
          return member4(isMemberSchema4(memberSchema) ? memberSchema : [memberSchema, 0], memberName);
        }
        if (this.isDocumentSchema()) {
          return member4([15, 0], memberName);
        }
        throw new Error(`@smithy/core/schema - ${this.getName(true)} has no member=${memberName}.`);
      }
      getMemberSchemas() {
        const buffer = {};
        try {
          for (const [k32, v] of this.structIterator()) {
            buffer[k32] = v;
          }
        } catch (ignored) {
        }
        return buffer;
      }
      getEventStreamMember() {
        if (this.isStructSchema()) {
          for (const [memberName, memberSchema] of this.structIterator()) {
            if (memberSchema.isStreaming() && memberSchema.isStructSchema()) {
              return memberName;
            }
          }
        }
        return "";
      }
      *structIterator() {
        if (this.isUnitSchema()) {
          return;
        }
        if (!this.isStructSchema()) {
          throw new Error("@smithy/core/schema - cannot iterate non-struct schema.");
        }
        const struct3 = this.getSchema();
        const z = struct3[4].length;
        let it = struct3[anno4.it];
        if (it && z === it.length) {
          yield* it;
          return;
        }
        it = Array(z);
        for (let i32 = 0; i32 < z; ++i32) {
          const k32 = struct3[4][i32];
          const v = member4([struct3[5][i32], 0], k32);
          yield it[i32] = [k32, v];
        }
        struct3[anno4.it] = it;
      }
    };
    __name(member4, "member");
    isMemberSchema4 = /* @__PURE__ */ __name((sc) => Array.isArray(sc) && sc.length === 2, "isMemberSchema");
    isStaticSchema4 = /* @__PURE__ */ __name((sc) => Array.isArray(sc) && sc.length >= 5, "isStaticSchema");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/schemas/SimpleSchema.js
var init_SimpleSchema4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/schemas/SimpleSchema.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/schemas/sentinels.js
var init_sentinels4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/schemas/sentinels.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/TypeRegistry.js
var TypeRegistry4;
var init_TypeRegistry4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/TypeRegistry.js"() {
    TypeRegistry4 = class _TypeRegistry {
      static {
        __name(this, "TypeRegistry");
      }
      namespace;
      schemas;
      exceptions;
      static registries = /* @__PURE__ */ new Map();
      constructor(namespace, schemas = /* @__PURE__ */ new Map(), exceptions = /* @__PURE__ */ new Map()) {
        this.namespace = namespace;
        this.schemas = schemas;
        this.exceptions = exceptions;
      }
      static for(namespace) {
        if (!_TypeRegistry.registries.has(namespace)) {
          _TypeRegistry.registries.set(namespace, new _TypeRegistry(namespace));
        }
        return _TypeRegistry.registries.get(namespace);
      }
      copyFrom(other) {
        const { schemas, exceptions } = this;
        for (const [k32, v] of other.schemas) {
          if (!schemas.has(k32)) {
            schemas.set(k32, v);
          }
        }
        for (const [k32, v] of other.exceptions) {
          if (!exceptions.has(k32)) {
            exceptions.set(k32, v);
          }
        }
      }
      register(shapeId, schema) {
        const qualifiedName = this.normalizeShapeId(shapeId);
        for (const r32 of [this, _TypeRegistry.for(qualifiedName.split("#")[0])]) {
          r32.schemas.set(qualifiedName, schema);
        }
      }
      getSchema(shapeId) {
        const id = this.normalizeShapeId(shapeId);
        if (!this.schemas.has(id)) {
          if (!shapeId.includes("#")) {
            const suffix = "#" + shapeId;
            const candidates = [];
            for (const [shapeId2, schema] of this.schemas.entries()) {
              if (shapeId2.endsWith(suffix)) {
                candidates.push(schema);
              }
            }
            if (candidates.length === 1) {
              return candidates[0];
            }
          }
          throw new Error(`@smithy/core/schema - schema not found for ${id}`);
        }
        return this.schemas.get(id);
      }
      registerError(es, ctor) {
        const $error = es;
        const ns = $error[1];
        for (const r32 of [this, _TypeRegistry.for(ns)]) {
          r32.schemas.set(ns + "#" + $error[2], $error);
          r32.exceptions.set($error, ctor);
        }
      }
      getErrorCtor(es) {
        const $error = es;
        if (this.exceptions.has($error)) {
          return this.exceptions.get($error);
        }
        const registry = _TypeRegistry.for($error[1]);
        return registry.exceptions.get($error);
      }
      getBaseException() {
        for (const exceptionKey of this.exceptions.keys()) {
          if (Array.isArray(exceptionKey)) {
            const [, ns, name] = exceptionKey;
            const id = ns + "#" + name;
            if (id.startsWith("smithy.ts.sdk.synthetic.") && id.endsWith("ServiceException")) {
              return exceptionKey;
            }
          }
        }
        return void 0;
      }
      find(predicate) {
        for (const schema of this.schemas.values()) {
          if (predicate(schema)) {
            return schema;
          }
        }
        return void 0;
      }
      clear() {
        this.schemas.clear();
        this.exceptions.clear();
      }
      normalizeShapeId(shapeId) {
        if (shapeId.includes("#")) {
          return shapeId;
        }
        return this.namespace + "#" + shapeId;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/index.js
var init_schema7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/schema/index.js"() {
    init_deref4();
    init_getSchemaSerdePlugin4();
    init_ListSchema4();
    init_MapSchema4();
    init_OperationSchema4();
    init_operation4();
    init_ErrorSchema4();
    init_NormalizedSchema4();
    init_Schema4();
    init_SimpleSchema4();
    init_StructureSchema4();
    init_sentinels4();
    init_translateTraits4();
    init_TypeRegistry4();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/SerdeContext.js
var SerdeContext4;
var init_SerdeContext5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/SerdeContext.js"() {
    SerdeContext4 = class {
      static {
        __name(this, "SerdeContext");
      }
      serdeContext;
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/httpRequest.js
function cloneQuery4(query) {
  return Object.keys(query).reduce((carry, paramName) => {
    const param = query[paramName];
    return {
      ...carry,
      [paramName]: Array.isArray(param) ? [...param] : param
    };
  }, {});
}
var HttpRequest23;
var init_httpRequest4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/httpRequest.js"() {
    HttpRequest23 = class _HttpRequest {
      static {
        __name(this, "HttpRequest");
      }
      method;
      protocol;
      hostname;
      port;
      path;
      query;
      headers;
      username;
      password;
      fragment;
      body;
      constructor(options) {
        this.method = options.method || "GET";
        this.hostname = options.hostname || "localhost";
        this.port = options.port;
        this.query = options.query || {};
        this.headers = options.headers || {};
        this.body = options.body;
        this.protocol = options.protocol ? options.protocol.slice(-1) !== ":" ? `${options.protocol}:` : options.protocol : "https:";
        this.path = options.path ? options.path.charAt(0) !== "/" ? `/${options.path}` : options.path : "/";
        this.username = options.username;
        this.password = options.password;
        this.fragment = options.fragment;
      }
      static clone(request4) {
        const cloned = new _HttpRequest({
          ...request4,
          headers: { ...request4.headers }
        });
        if (cloned.query) {
          cloned.query = cloneQuery4(cloned.query);
        }
        return cloned;
      }
      static isInstance(request4) {
        if (!request4) {
          return false;
        }
        const req = request4;
        return "method" in req && "protocol" in req && "hostname" in req && "path" in req && typeof req["query"] === "object" && typeof req["headers"] === "object";
      }
      clone() {
        return _HttpRequest.clone(this);
      }
    };
    __name(cloneQuery4, "cloneQuery");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/httpResponse.js
var HttpResponse12;
var init_httpResponse4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/httpResponse.js"() {
    HttpResponse12 = class {
      static {
        __name(this, "HttpResponse");
      }
      statusCode;
      reason;
      headers;
      body;
      constructor(options) {
        this.statusCode = options.statusCode;
        this.reason = options.reason;
        this.headers = options.headers || {};
        this.body = options.body;
      }
      static isInstance(response) {
        if (!response)
          return false;
        const resp = response;
        return typeof resp.statusCode === "number" && typeof resp.headers === "object";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/Int64.js
function negate3(bytes) {
  for (let i32 = 0; i32 < 8; i32++) {
    bytes[i32] ^= 255;
  }
  for (let i32 = 7; i32 > -1; i32--) {
    bytes[i32]++;
    if (bytes[i32] !== 0)
      break;
  }
}
var Int643;
var init_Int643 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/Int64.js"() {
    init_serde5();
    Int643 = class _Int64 {
      static {
        __name(this, "Int64");
      }
      bytes;
      constructor(bytes) {
        this.bytes = bytes;
        if (bytes.byteLength !== 8) {
          throw new Error("Int64 buffers must be exactly 8 bytes");
        }
      }
      static fromNumber(number) {
        if (number > 9223372036854776e3 || number < -9223372036854776e3) {
          throw new Error(`${number} is too large (or, if negative, too small) to represent as an Int64`);
        }
        const bytes = new Uint8Array(8);
        for (let i32 = 7, remaining = Math.abs(Math.round(number)); i32 > -1 && remaining > 0; i32--, remaining /= 256) {
          bytes[i32] = remaining;
        }
        if (number < 0) {
          negate3(bytes);
        }
        return new _Int64(bytes);
      }
      valueOf() {
        const bytes = this.bytes.slice(0);
        const negative = bytes[0] & 128;
        if (negative) {
          negate3(bytes);
        }
        return parseInt(toHex3(bytes), 16) * (negative ? -1 : 1);
      }
      toString() {
        return String(this.valueOf());
      }
    };
    __name(negate3, "negate");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/HeaderMarshaller.js
var HeaderMarshaller3, HEADER_VALUE_TYPE3, BOOLEAN_TAG3, BYTE_TAG3, SHORT_TAG3, INT_TAG3, LONG_TAG3, BINARY_TAG3, STRING_TAG3, TIMESTAMP_TAG3, UUID_TAG3, UUID_PATTERN3;
var init_HeaderMarshaller3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/HeaderMarshaller.js"() {
    init_serde5();
    init_Int643();
    HeaderMarshaller3 = class {
      static {
        __name(this, "HeaderMarshaller");
      }
      toUtf8;
      fromUtf8;
      constructor(toUtf862, fromUtf842) {
        this.toUtf8 = toUtf862;
        this.fromUtf8 = fromUtf842;
      }
      format(headers) {
        const chunks2 = [];
        for (const headerName of Object.keys(headers)) {
          const bytes = this.fromUtf8(headerName);
          chunks2.push(Uint8Array.from([bytes.byteLength]), bytes, this.formatHeaderValue(headers[headerName]));
        }
        const out = new Uint8Array(chunks2.reduce((carry, bytes) => carry + bytes.byteLength, 0));
        let position = 0;
        for (const chunk of chunks2) {
          out.set(chunk, position);
          position += chunk.byteLength;
        }
        return out;
      }
      formatHeaderValue(header) {
        switch (header.type) {
          case "boolean":
            return Uint8Array.from([header.value ? 0 : 1]);
          case "byte":
            return Uint8Array.from([2, header.value]);
          case "short":
            const shortView = new DataView(new ArrayBuffer(3));
            shortView.setUint8(0, 3);
            shortView.setInt16(1, header.value, false);
            return new Uint8Array(shortView.buffer);
          case "integer":
            const intView = new DataView(new ArrayBuffer(5));
            intView.setUint8(0, 4);
            intView.setInt32(1, header.value, false);
            return new Uint8Array(intView.buffer);
          case "long":
            const longBytes = new Uint8Array(9);
            longBytes[0] = 5;
            longBytes.set(header.value.bytes, 1);
            return longBytes;
          case "binary":
            const binView = new DataView(new ArrayBuffer(3 + header.value.byteLength));
            binView.setUint8(0, 6);
            binView.setUint16(1, header.value.byteLength, false);
            const binBytes = new Uint8Array(binView.buffer);
            binBytes.set(header.value, 3);
            return binBytes;
          case "string":
            const utf8Bytes = this.fromUtf8(header.value);
            const strView = new DataView(new ArrayBuffer(3 + utf8Bytes.byteLength));
            strView.setUint8(0, 7);
            strView.setUint16(1, utf8Bytes.byteLength, false);
            const strBytes = new Uint8Array(strView.buffer);
            strBytes.set(utf8Bytes, 3);
            return strBytes;
          case "timestamp":
            const tsBytes = new Uint8Array(9);
            tsBytes[0] = 8;
            tsBytes.set(Int643.fromNumber(header.value.valueOf()).bytes, 1);
            return tsBytes;
          case "uuid":
            if (!UUID_PATTERN3.test(header.value)) {
              throw new Error(`Invalid UUID received: ${header.value}`);
            }
            const uuidBytes = new Uint8Array(17);
            uuidBytes[0] = 9;
            uuidBytes.set(fromHex3(header.value.replace(/\-/g, "")), 1);
            return uuidBytes;
        }
      }
      parse(headers) {
        const out = {};
        let position = 0;
        while (position < headers.byteLength) {
          const nameLength = headers.getUint8(position++);
          const name = this.toUtf8(new Uint8Array(headers.buffer, headers.byteOffset + position, nameLength));
          position += nameLength;
          switch (headers.getUint8(position++)) {
            case 0:
              out[name] = {
                type: BOOLEAN_TAG3,
                value: true
              };
              break;
            case 1:
              out[name] = {
                type: BOOLEAN_TAG3,
                value: false
              };
              break;
            case 2:
              out[name] = {
                type: BYTE_TAG3,
                value: headers.getInt8(position++)
              };
              break;
            case 3:
              out[name] = {
                type: SHORT_TAG3,
                value: headers.getInt16(position, false)
              };
              position += 2;
              break;
            case 4:
              out[name] = {
                type: INT_TAG3,
                value: headers.getInt32(position, false)
              };
              position += 4;
              break;
            case 5:
              out[name] = {
                type: LONG_TAG3,
                value: new Int643(new Uint8Array(headers.buffer, headers.byteOffset + position, 8))
              };
              position += 8;
              break;
            case 6:
              const binaryLength = headers.getUint16(position, false);
              position += 2;
              out[name] = {
                type: BINARY_TAG3,
                value: new Uint8Array(headers.buffer, headers.byteOffset + position, binaryLength)
              };
              position += binaryLength;
              break;
            case 7:
              const stringLength = headers.getUint16(position, false);
              position += 2;
              out[name] = {
                type: STRING_TAG3,
                value: this.toUtf8(new Uint8Array(headers.buffer, headers.byteOffset + position, stringLength))
              };
              position += stringLength;
              break;
            case 8:
              out[name] = {
                type: TIMESTAMP_TAG3,
                value: new Date(new Int643(new Uint8Array(headers.buffer, headers.byteOffset + position, 8)).valueOf())
              };
              position += 8;
              break;
            case 9:
              const uuidBytes = new Uint8Array(headers.buffer, headers.byteOffset + position, 16);
              position += 16;
              out[name] = {
                type: UUID_TAG3,
                value: `${toHex3(uuidBytes.subarray(0, 4))}-${toHex3(uuidBytes.subarray(4, 6))}-${toHex3(uuidBytes.subarray(6, 8))}-${toHex3(uuidBytes.subarray(8, 10))}-${toHex3(uuidBytes.subarray(10))}`
              };
              break;
            default:
              throw new Error(`Unrecognized header type tag`);
          }
        }
        return out;
      }
    };
    (function(HEADER_VALUE_TYPE6) {
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["boolTrue"] = 0] = "boolTrue";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["boolFalse"] = 1] = "boolFalse";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["byte"] = 2] = "byte";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["short"] = 3] = "short";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["integer"] = 4] = "integer";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["long"] = 5] = "long";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["byteArray"] = 6] = "byteArray";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["string"] = 7] = "string";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["timestamp"] = 8] = "timestamp";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["uuid"] = 9] = "uuid";
    })(HEADER_VALUE_TYPE3 || (HEADER_VALUE_TYPE3 = {}));
    BOOLEAN_TAG3 = "boolean";
    BYTE_TAG3 = "byte";
    SHORT_TAG3 = "short";
    INT_TAG3 = "integer";
    LONG_TAG3 = "long";
    BINARY_TAG3 = "binary";
    STRING_TAG3 = "string";
    TIMESTAMP_TAG3 = "timestamp";
    UUID_TAG3 = "uuid";
    UUID_PATTERN3 = /^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$/;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/splitMessage.js
function splitMessage3({ byteLength, byteOffset, buffer }) {
  if (byteLength < MINIMUM_MESSAGE_LENGTH3) {
    throw new Error("Provided message too short to accommodate event stream message overhead");
  }
  const view = new DataView(buffer, byteOffset, byteLength);
  const messageLength = view.getUint32(0, false);
  if (byteLength !== messageLength) {
    throw new Error("Reported message length does not match received message length");
  }
  const headerLength = view.getUint32(PRELUDE_MEMBER_LENGTH3, false);
  const expectedPreludeChecksum = view.getUint32(PRELUDE_LENGTH3, false);
  const expectedMessageChecksum = view.getUint32(byteLength - CHECKSUM_LENGTH3, false);
  const checksummer = new import_crc325.Crc32().update(new Uint8Array(buffer, byteOffset, PRELUDE_LENGTH3));
  if (expectedPreludeChecksum !== checksummer.digest()) {
    throw new Error(`The prelude checksum specified in the message (${expectedPreludeChecksum}) does not match the calculated CRC32 checksum (${checksummer.digest()})`);
  }
  checksummer.update(new Uint8Array(buffer, byteOffset + PRELUDE_LENGTH3, byteLength - (PRELUDE_LENGTH3 + CHECKSUM_LENGTH3)));
  if (expectedMessageChecksum !== checksummer.digest()) {
    throw new Error(`The message checksum (${checksummer.digest()}) did not match the expected value of ${expectedMessageChecksum}`);
  }
  return {
    headers: new DataView(buffer, byteOffset + PRELUDE_LENGTH3 + CHECKSUM_LENGTH3, headerLength),
    body: new Uint8Array(buffer, byteOffset + PRELUDE_LENGTH3 + CHECKSUM_LENGTH3 + headerLength, messageLength - headerLength - (PRELUDE_LENGTH3 + CHECKSUM_LENGTH3 + CHECKSUM_LENGTH3))
  };
}
var import_crc325, PRELUDE_MEMBER_LENGTH3, PRELUDE_LENGTH3, CHECKSUM_LENGTH3, MINIMUM_MESSAGE_LENGTH3;
var init_splitMessage3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/splitMessage.js"() {
    import_crc325 = __toESM(require_main3());
    PRELUDE_MEMBER_LENGTH3 = 4;
    PRELUDE_LENGTH3 = PRELUDE_MEMBER_LENGTH3 * 2;
    CHECKSUM_LENGTH3 = 4;
    MINIMUM_MESSAGE_LENGTH3 = PRELUDE_LENGTH3 + CHECKSUM_LENGTH3 * 2;
    __name(splitMessage3, "splitMessage");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/EventStreamCodec.js
var import_crc326, EventStreamCodec3;
var init_EventStreamCodec3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/EventStreamCodec.js"() {
    import_crc326 = __toESM(require_main3());
    init_HeaderMarshaller3();
    init_splitMessage3();
    EventStreamCodec3 = class {
      static {
        __name(this, "EventStreamCodec");
      }
      headerMarshaller;
      messageBuffer;
      isEndOfStream;
      constructor(toUtf862, fromUtf842) {
        this.headerMarshaller = new HeaderMarshaller3(toUtf862, fromUtf842);
        this.messageBuffer = [];
        this.isEndOfStream = false;
      }
      feed(message2) {
        this.messageBuffer.push(this.decode(message2));
      }
      endOfStream() {
        this.isEndOfStream = true;
      }
      getMessage() {
        const message2 = this.messageBuffer.pop();
        const isEndOfStream = this.isEndOfStream;
        return {
          getMessage() {
            return message2;
          },
          isEndOfStream() {
            return isEndOfStream;
          }
        };
      }
      getAvailableMessages() {
        const messages = this.messageBuffer;
        this.messageBuffer = [];
        const isEndOfStream = this.isEndOfStream;
        return {
          getMessages() {
            return messages;
          },
          isEndOfStream() {
            return isEndOfStream;
          }
        };
      }
      encode({ headers: rawHeaders, body }) {
        const headers = this.headerMarshaller.format(rawHeaders);
        const length = headers.byteLength + body.byteLength + 16;
        const out = new Uint8Array(length);
        const view = new DataView(out.buffer, out.byteOffset, out.byteLength);
        const checksum = new import_crc326.Crc32();
        view.setUint32(0, length, false);
        view.setUint32(4, headers.byteLength, false);
        view.setUint32(8, checksum.update(out.subarray(0, 8)).digest(), false);
        out.set(headers, 12);
        out.set(body, headers.byteLength + 12);
        view.setUint32(length - 4, checksum.update(out.subarray(8, length - 4)).digest(), false);
        return out;
      }
      decode(message2) {
        const { headers, body } = splitMessage3(message2);
        return { headers: this.headerMarshaller.parse(headers), body };
      }
      formatHeaders(rawHeaders) {
        return this.headerMarshaller.format(rawHeaders);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/MessageDecoderStream.js
var MessageDecoderStream3;
var init_MessageDecoderStream3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/MessageDecoderStream.js"() {
    MessageDecoderStream3 = class {
      static {
        __name(this, "MessageDecoderStream");
      }
      options;
      constructor(options) {
        this.options = options;
      }
      [Symbol.asyncIterator]() {
        return this.asyncIterator();
      }
      async *asyncIterator() {
        for await (const bytes of this.options.inputStream) {
          const decoded = this.options.decoder.decode(bytes);
          yield decoded;
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/MessageEncoderStream.js
var MessageEncoderStream3;
var init_MessageEncoderStream3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/MessageEncoderStream.js"() {
    MessageEncoderStream3 = class {
      static {
        __name(this, "MessageEncoderStream");
      }
      options;
      constructor(options) {
        this.options = options;
      }
      [Symbol.asyncIterator]() {
        return this.asyncIterator();
      }
      async *asyncIterator() {
        for await (const msg of this.options.messageStream) {
          const encoded = this.options.encoder.encode(msg);
          yield encoded;
        }
        if (this.options.includeEndFrame) {
          yield new Uint8Array(0);
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/SmithyMessageDecoderStream.js
var SmithyMessageDecoderStream3;
var init_SmithyMessageDecoderStream3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/SmithyMessageDecoderStream.js"() {
    SmithyMessageDecoderStream3 = class {
      static {
        __name(this, "SmithyMessageDecoderStream");
      }
      options;
      constructor(options) {
        this.options = options;
      }
      [Symbol.asyncIterator]() {
        return this.asyncIterator();
      }
      async *asyncIterator() {
        for await (const message2 of this.options.messageStream) {
          const deserialized = await this.options.deserializer(message2);
          if (deserialized === void 0)
            continue;
          yield deserialized;
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/SmithyMessageEncoderStream.js
var SmithyMessageEncoderStream3;
var init_SmithyMessageEncoderStream3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/SmithyMessageEncoderStream.js"() {
    SmithyMessageEncoderStream3 = class {
      static {
        __name(this, "SmithyMessageEncoderStream");
      }
      options;
      constructor(options) {
        this.options = options;
      }
      [Symbol.asyncIterator]() {
        return this.asyncIterator();
      }
      async *asyncIterator() {
        for await (const chunk of this.options.inputStream) {
          const payloadBuf = this.options.serializer(chunk);
          yield payloadBuf;
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/getChunkedStream.js
function getChunkedStream3(source) {
  let currentMessageTotalLength = 0;
  let currentMessagePendingLength = 0;
  let currentMessage = null;
  let messageLengthBuffer = null;
  const allocateMessage = /* @__PURE__ */ __name((size) => {
    if (typeof size !== "number") {
      throw new Error("Attempted to allocate an event message where size was not a number: " + size);
    }
    currentMessageTotalLength = size;
    currentMessagePendingLength = 4;
    currentMessage = new Uint8Array(size);
    const currentMessageView = new DataView(currentMessage.buffer);
    currentMessageView.setUint32(0, size, false);
  }, "allocateMessage");
  const iterator = /* @__PURE__ */ __name(async function* () {
    const sourceIterator = source[Symbol.asyncIterator]();
    while (true) {
      const { value, done } = await sourceIterator.next();
      if (done) {
        if (!currentMessageTotalLength) {
          return;
        } else if (currentMessageTotalLength === currentMessagePendingLength) {
          yield currentMessage;
        } else {
          throw new Error("Truncated event message received.");
        }
        return;
      }
      const chunkLength = value.length;
      let currentOffset = 0;
      while (currentOffset < chunkLength) {
        if (!currentMessage) {
          const bytesRemaining = chunkLength - currentOffset;
          if (!messageLengthBuffer) {
            messageLengthBuffer = new Uint8Array(4);
          }
          const numBytesForTotal = Math.min(4 - currentMessagePendingLength, bytesRemaining);
          messageLengthBuffer.set(value.slice(currentOffset, currentOffset + numBytesForTotal), currentMessagePendingLength);
          currentMessagePendingLength += numBytesForTotal;
          currentOffset += numBytesForTotal;
          if (currentMessagePendingLength < 4) {
            break;
          }
          allocateMessage(new DataView(messageLengthBuffer.buffer).getUint32(0, false));
          messageLengthBuffer = null;
        }
        const numBytesToWrite = Math.min(currentMessageTotalLength - currentMessagePendingLength, chunkLength - currentOffset);
        currentMessage.set(value.slice(currentOffset, currentOffset + numBytesToWrite), currentMessagePendingLength);
        currentMessagePendingLength += numBytesToWrite;
        currentOffset += numBytesToWrite;
        if (currentMessageTotalLength && currentMessageTotalLength === currentMessagePendingLength) {
          yield currentMessage;
          currentMessage = null;
          currentMessageTotalLength = 0;
          currentMessagePendingLength = 0;
        }
      }
    }
  }, "iterator");
  return {
    [Symbol.asyncIterator]: iterator
  };
}
var init_getChunkedStream3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/getChunkedStream.js"() {
    __name(getChunkedStream3, "getChunkedStream");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/getUnmarshalledStream.js
function getUnmarshalledStream3(source, options) {
  const messageUnmarshaller = getMessageUnmarshaller3(options.deserializer, options.toUtf8);
  return {
    [Symbol.asyncIterator]: async function* () {
      for await (const chunk of source) {
        const message2 = options.eventStreamCodec.decode(chunk);
        const type = await messageUnmarshaller(message2);
        if (type === void 0)
          continue;
        yield type;
      }
    }
  };
}
function getMessageUnmarshaller3(deserializer, toUtf862) {
  return async function(message2) {
    const { value: messageType } = message2.headers[":message-type"];
    if (messageType === "error") {
      const unmodeledError = new Error(message2.headers[":error-message"].value || "UnknownError");
      unmodeledError.name = message2.headers[":error-code"].value;
      throw unmodeledError;
    } else if (messageType === "exception") {
      const code = message2.headers[":exception-type"].value;
      const exception = { [code]: message2 };
      const deserializedException = await deserializer(exception);
      if (deserializedException.$unknown) {
        const error4 = new Error(toUtf862(message2.body));
        error4.name = code;
        throw error4;
      }
      throw deserializedException[code];
    } else if (messageType === "event") {
      const event = {
        [message2.headers[":event-type"].value]: message2
      };
      const deserialized = await deserializer(event);
      if (deserialized.$unknown)
        return;
      return deserialized;
    } else {
      throw Error(`Unrecognizable event type: ${message2.headers[":event-type"].value}`);
    }
  };
}
var init_getUnmarshalledStream3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/getUnmarshalledStream.js"() {
    __name(getUnmarshalledStream3, "getUnmarshalledStream");
    __name(getMessageUnmarshaller3, "getMessageUnmarshaller");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/EventStreamMarshaller.js
var EventStreamMarshaller5, eventStreamSerdeProvider5;
var init_EventStreamMarshaller5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/EventStreamMarshaller.js"() {
    init_EventStreamCodec3();
    init_MessageDecoderStream3();
    init_MessageEncoderStream3();
    init_SmithyMessageDecoderStream3();
    init_SmithyMessageEncoderStream3();
    init_getChunkedStream3();
    init_getUnmarshalledStream3();
    EventStreamMarshaller5 = class {
      static {
        __name(this, "EventStreamMarshaller");
      }
      eventStreamCodec;
      utfEncoder;
      constructor({ utf8Encoder, utf8Decoder }) {
        this.eventStreamCodec = new EventStreamCodec3(utf8Encoder, utf8Decoder);
        this.utfEncoder = utf8Encoder;
      }
      deserialize(body, deserializer) {
        const inputStream = getChunkedStream3(body);
        return new SmithyMessageDecoderStream3({
          messageStream: new MessageDecoderStream3({ inputStream, decoder: this.eventStreamCodec }),
          deserializer: getMessageUnmarshaller3(deserializer, this.utfEncoder)
        });
      }
      serialize(inputStream, serializer) {
        return new MessageEncoderStream3({
          messageStream: new SmithyMessageEncoderStream3({ inputStream, serializer }),
          encoder: this.eventStreamCodec,
          includeEndFrame: true
        });
      }
    };
    eventStreamSerdeProvider5 = /* @__PURE__ */ __name((options) => new EventStreamMarshaller5(options), "eventStreamSerdeProvider");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde/EventStreamMarshaller.js
async function* readableToIterable3(readStream) {
  let streamEnded = false;
  let generationEnded = false;
  const records = new Array();
  readStream.on("error", (err) => {
    if (!streamEnded) {
      streamEnded = true;
    }
    if (err) {
      throw err;
    }
  });
  readStream.on("data", (data3) => {
    records.push(data3);
  });
  readStream.on("end", () => {
    streamEnded = true;
  });
  while (!generationEnded) {
    const value = await new Promise((resolve13) => setTimeout(() => resolve13(records.shift()), 0));
    if (value) {
      yield value;
    }
    generationEnded = streamEnded && records.length === 0;
  }
}
var import_node_stream14, EventStreamMarshaller6, eventStreamSerdeProvider6;
var init_EventStreamMarshaller6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde/EventStreamMarshaller.js"() {
    import_node_stream14 = require("node:stream");
    init_EventStreamMarshaller5();
    EventStreamMarshaller6 = class {
      static {
        __name(this, "EventStreamMarshaller");
      }
      universalMarshaller;
      constructor({ utf8Encoder, utf8Decoder }) {
        this.universalMarshaller = new EventStreamMarshaller5({
          utf8Decoder,
          utf8Encoder
        });
      }
      deserialize(body, deserializer) {
        const bodyIterable = typeof body[Symbol.asyncIterator] === "function" ? body : readableToIterable3(body);
        return this.universalMarshaller.deserialize(bodyIterable, deserializer);
      }
      serialize(input, serializer) {
        return import_node_stream14.Readable.from(this.universalMarshaller.serialize(input, serializer));
      }
    };
    eventStreamSerdeProvider6 = /* @__PURE__ */ __name((options) => new EventStreamMarshaller6(options), "eventStreamSerdeProvider");
    __name(readableToIterable3, "readableToIterable");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde/utils.js
var readableStreamToIterable3, iterableToReadableStream3;
var init_utils12 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde/utils.js"() {
    readableStreamToIterable3 = /* @__PURE__ */ __name((readableStream) => ({
      [Symbol.asyncIterator]: async function* () {
        const reader = readableStream.getReader();
        try {
          while (true) {
            const { done, value } = await reader.read();
            if (done)
              return;
            yield value;
          }
        } finally {
          reader.releaseLock();
        }
      }
    }), "readableStreamToIterable");
    iterableToReadableStream3 = /* @__PURE__ */ __name((asyncIterable) => {
      const iterator = asyncIterable[Symbol.asyncIterator]();
      return new ReadableStream({
        async pull(controller) {
          const { done, value } = await iterator.next();
          if (done) {
            return controller.close();
          }
          controller.enqueue(value);
        }
      });
    }, "iterableToReadableStream");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-config-resolver/EventStreamSerdeConfig.js
var resolveEventStreamSerdeConfig3;
var init_EventStreamSerdeConfig3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-config-resolver/EventStreamSerdeConfig.js"() {
    resolveEventStreamSerdeConfig3 = /* @__PURE__ */ __name((input) => Object.assign(input, {
      eventStreamMarshaller: input.eventStreamSerdeProvider(input)
    }), "resolveEventStreamSerdeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/EventStreamSerde.js
var EventStreamSerde4;
var init_EventStreamSerde4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/EventStreamSerde.js"() {
    init_serde5();
    EventStreamSerde4 = class {
      static {
        __name(this, "EventStreamSerde");
      }
      marshaller;
      serializer;
      deserializer;
      serdeContext;
      defaultContentType;
      constructor({ marshaller, serializer, deserializer, serdeContext, defaultContentType }) {
        this.marshaller = marshaller;
        this.serializer = serializer;
        this.deserializer = deserializer;
        this.serdeContext = serdeContext;
        this.defaultContentType = defaultContentType;
      }
      async serializeEventStream({ eventStream, requestSchema, initialRequest }) {
        const marshaller = this.marshaller;
        const eventStreamMember = requestSchema.getEventStreamMember();
        const unionSchema = requestSchema.getMemberSchema(eventStreamMember);
        const serializer = this.serializer;
        const defaultContentType = this.defaultContentType;
        const initialRequestMarker = /* @__PURE__ */ Symbol("initialRequestMarker");
        const eventStreamIterable = {
          async *[Symbol.asyncIterator]() {
            if (initialRequest) {
              const headers = {
                ":event-type": { type: "string", value: "initial-request" },
                ":message-type": { type: "string", value: "event" },
                ":content-type": { type: "string", value: defaultContentType }
              };
              serializer.write(requestSchema, initialRequest);
              const body = serializer.flush();
              yield {
                [initialRequestMarker]: true,
                headers,
                body
              };
            }
            for await (const page of eventStream) {
              yield page;
            }
          }
        };
        return marshaller.serialize(eventStreamIterable, (event) => {
          if (event[initialRequestMarker]) {
            return {
              headers: event.headers,
              body: event.body
            };
          }
          let unionMember = "";
          for (const key in event) {
            if (key !== "__type") {
              unionMember = key;
              break;
            }
          }
          const { additionalHeaders, body, eventType, explicitPayloadContentType } = this.writeEventBody(unionMember, unionSchema, event);
          const headers = {
            ":event-type": { type: "string", value: eventType },
            ":message-type": { type: "string", value: "event" },
            ":content-type": { type: "string", value: explicitPayloadContentType ?? defaultContentType },
            ...additionalHeaders
          };
          return {
            headers,
            body
          };
        });
      }
      async deserializeEventStream({ response, responseSchema, initialResponseContainer }) {
        const marshaller = this.marshaller;
        const eventStreamMember = responseSchema.getEventStreamMember();
        const unionSchema = responseSchema.getMemberSchema(eventStreamMember);
        const memberSchemas = unionSchema.getMemberSchemas();
        const initialResponseMarker = /* @__PURE__ */ Symbol("initialResponseMarker");
        const asyncIterable = marshaller.deserialize(response.body, async (event) => {
          let unionMember = "";
          for (const key in event) {
            if (key !== "__type") {
              unionMember = key;
              break;
            }
          }
          const body = event[unionMember].body;
          if (unionMember === "initial-response") {
            const dataObject = await this.deserializer.read(responseSchema, body);
            delete dataObject[eventStreamMember];
            return {
              [initialResponseMarker]: true,
              ...dataObject
            };
          } else if (unionMember in memberSchemas) {
            const eventStreamSchema = memberSchemas[unionMember];
            if (eventStreamSchema.isStructSchema()) {
              const out = {};
              let hasBindings = false;
              for (const [name, member7] of eventStreamSchema.structIterator()) {
                const { eventHeader, eventPayload } = member7.getMergedTraits();
                hasBindings = hasBindings || Boolean(eventHeader || eventPayload);
                if (eventPayload) {
                  if (member7.isBlobSchema()) {
                    out[name] = body;
                  } else if (member7.isStringSchema()) {
                    out[name] = (this.serdeContext?.utf8Encoder ?? toUtf841)(body);
                  } else if (member7.isStructSchema()) {
                    out[name] = await this.deserializer.read(member7, body);
                  }
                } else if (eventHeader) {
                  const value = event[unionMember].headers[name]?.value;
                  if (value != null) {
                    if (member7.isNumericSchema()) {
                      if (value && typeof value === "object" && "bytes" in value) {
                        out[name] = BigInt(value.toString());
                      } else {
                        out[name] = Number(value);
                      }
                    } else {
                      out[name] = value;
                    }
                  }
                }
              }
              if (hasBindings) {
                return {
                  [unionMember]: out
                };
              }
              if (body.byteLength === 0) {
                return {
                  [unionMember]: {}
                };
              }
            }
            return {
              [unionMember]: await this.deserializer.read(eventStreamSchema, body)
            };
          } else {
            return {
              $unknown: event
            };
          }
        });
        const asyncIterator = asyncIterable[Symbol.asyncIterator]();
        const firstEvent = await asyncIterator.next();
        if (firstEvent.done) {
          return asyncIterable;
        }
        if (firstEvent.value?.[initialResponseMarker]) {
          if (!responseSchema) {
            throw new Error("@smithy::core/protocols - initial-response event encountered in event stream but no response schema given.");
          }
          for (const key in firstEvent.value) {
            initialResponseContainer[key] = firstEvent.value[key];
          }
        }
        return {
          async *[Symbol.asyncIterator]() {
            if (!firstEvent?.value?.[initialResponseMarker]) {
              yield firstEvent.value;
            }
            while (true) {
              const { done, value } = await asyncIterator.next();
              if (done) {
                break;
              }
              yield value;
            }
          }
        };
      }
      writeEventBody(unionMember, unionSchema, event) {
        const serializer = this.serializer;
        let eventType = unionMember;
        let explicitPayloadMember = null;
        let explicitPayloadContentType;
        const isKnownSchema = (() => {
          const struct3 = unionSchema.getSchema();
          return struct3[4].includes(unionMember);
        })();
        const additionalHeaders = {};
        if (!isKnownSchema) {
          const [type, value] = event[unionMember];
          eventType = type;
          serializer.write(15, value);
        } else {
          const eventSchema = unionSchema.getMemberSchema(unionMember);
          if (eventSchema.isStructSchema()) {
            for (const [memberName, memberSchema] of eventSchema.structIterator()) {
              const { eventHeader, eventPayload } = memberSchema.getMergedTraits();
              if (eventPayload) {
                explicitPayloadMember = memberName;
              } else if (eventHeader) {
                const value = event[unionMember][memberName];
                let type = "binary";
                if (memberSchema.isNumericSchema()) {
                  if ((-2) ** 31 <= value && value <= 2 ** 31 - 1) {
                    type = "integer";
                  } else {
                    type = "long";
                  }
                } else if (memberSchema.isTimestampSchema()) {
                  type = "timestamp";
                } else if (memberSchema.isStringSchema()) {
                  type = "string";
                } else if (memberSchema.isBooleanSchema()) {
                  type = "boolean";
                }
                if (value != null) {
                  additionalHeaders[memberName] = {
                    type,
                    value
                  };
                  delete event[unionMember][memberName];
                }
              }
            }
            if (explicitPayloadMember !== null) {
              const payloadSchema = eventSchema.getMemberSchema(explicitPayloadMember);
              if (payloadSchema.isBlobSchema()) {
                explicitPayloadContentType = "application/octet-stream";
              } else if (payloadSchema.isStringSchema()) {
                explicitPayloadContentType = "text/plain";
              }
              serializer.write(payloadSchema, event[unionMember][explicitPayloadMember]);
            } else {
              serializer.write(eventSchema, event[unionMember]);
            }
          } else if (eventSchema.isUnitSchema()) {
            serializer.write(eventSchema, {});
          } else {
            throw new Error("@smithy/core/event-streams - non-struct member not supported in event stream union.");
          }
        }
        const messageSerialization = serializer.flush() ?? new Uint8Array();
        const body = typeof messageSerialization === "string" ? (this.serdeContext?.utf8Decoder ?? fromUtf827)(messageSerialization) : messageSerialization;
        return {
          body,
          eventType,
          explicitPayloadContentType,
          additionalHeaders
        };
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/index.js
var event_streams_exports4 = {};
__export(event_streams_exports4, {
  EventStreamCodec: () => EventStreamCodec3,
  EventStreamMarshaller: () => EventStreamMarshaller6,
  EventStreamSerde: () => EventStreamSerde4,
  HeaderMarshaller: () => HeaderMarshaller3,
  Int64: () => Int643,
  MessageDecoderStream: () => MessageDecoderStream3,
  MessageEncoderStream: () => MessageEncoderStream3,
  SmithyMessageDecoderStream: () => SmithyMessageDecoderStream3,
  SmithyMessageEncoderStream: () => SmithyMessageEncoderStream3,
  UniversalEventStreamMarshaller: () => EventStreamMarshaller5,
  eventStreamSerdeProvider: () => eventStreamSerdeProvider6,
  getChunkedStream: () => getChunkedStream3,
  getMessageUnmarshaller: () => getMessageUnmarshaller3,
  getUnmarshalledStream: () => getUnmarshalledStream3,
  iterableToReadableStream: () => iterableToReadableStream3,
  readableStreamToIterable: () => readableStreamToIterable3,
  resolveEventStreamSerdeConfig: () => resolveEventStreamSerdeConfig3,
  universalEventStreamSerdeProvider: () => eventStreamSerdeProvider5
});
var init_event_streams4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/event-streams/index.js"() {
    init_EventStreamCodec3();
    init_HeaderMarshaller3();
    init_Int643();
    init_MessageDecoderStream3();
    init_MessageEncoderStream3();
    init_SmithyMessageDecoderStream3();
    init_SmithyMessageEncoderStream3();
    init_EventStreamMarshaller6();
    init_utils12();
    init_EventStreamMarshaller5();
    init_getChunkedStream3();
    init_getUnmarshalledStream3();
    init_EventStreamSerdeConfig3();
    init_EventStreamSerde4();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/HttpProtocol.js
var HttpProtocol4;
var init_HttpProtocol5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/HttpProtocol.js"() {
    init_schema7();
    init_SerdeContext5();
    init_httpRequest4();
    init_httpResponse4();
    HttpProtocol4 = class extends SerdeContext4 {
      static {
        __name(this, "HttpProtocol");
      }
      options;
      compositeErrorRegistry;
      constructor(options) {
        super();
        this.options = options;
        this.compositeErrorRegistry = TypeRegistry4.for(options.defaultNamespace);
        for (const etr of options.errorTypeRegistries ?? []) {
          this.compositeErrorRegistry.copyFrom(etr);
        }
      }
      getRequestType() {
        return HttpRequest23;
      }
      getResponseType() {
        return HttpResponse12;
      }
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
        this.serializer.setSerdeContext(serdeContext);
        this.deserializer.setSerdeContext(serdeContext);
        if (this.getPayloadCodec()) {
          this.getPayloadCodec().setSerdeContext(serdeContext);
        }
      }
      updateServiceEndpoint(request4, endpoint) {
        if ("url" in endpoint) {
          request4.protocol = endpoint.url.protocol;
          request4.hostname = endpoint.url.hostname;
          request4.port = endpoint.url.port ? Number(endpoint.url.port) : void 0;
          request4.path = endpoint.url.pathname;
          request4.fragment = endpoint.url.hash || void 0;
          request4.username = endpoint.url.username || void 0;
          request4.password = endpoint.url.password || void 0;
          if (!request4.query) {
            request4.query = {};
          }
          for (const [k32, v] of endpoint.url.searchParams.entries()) {
            request4.query[k32] = v;
          }
          if (endpoint.headers) {
            for (const name in endpoint.headers) {
              request4.headers[name] = endpoint.headers[name].join(", ");
            }
          }
          return request4;
        } else {
          request4.protocol = endpoint.protocol;
          request4.hostname = endpoint.hostname;
          request4.port = endpoint.port ? Number(endpoint.port) : void 0;
          request4.path = endpoint.path;
          request4.query = {
            ...endpoint.query
          };
          if (endpoint.headers) {
            for (const name in endpoint.headers) {
              request4.headers[name] = endpoint.headers[name];
            }
          }
          return request4;
        }
      }
      setHostPrefix(request4, operationSchema, input) {
        if (this.serdeContext?.disableHostPrefix) {
          return;
        }
        const inputNs = NormalizedSchema4.of(operationSchema.input);
        const opTraits = translateTraits4(operationSchema.traits ?? {});
        if (opTraits.endpoint) {
          let hostPrefix = opTraits.endpoint?.[0];
          if (typeof hostPrefix === "string") {
            for (const [name, member7] of inputNs.structIterator()) {
              if (!member7.getMergedTraits().hostLabel) {
                continue;
              }
              const replacement = input[name];
              if (typeof replacement !== "string") {
                throw new Error(`@smithy/core/schema - ${name} in input must be a string as hostLabel.`);
              }
              hostPrefix = hostPrefix.replace(`{${name}}`, replacement);
            }
            request4.hostname = hostPrefix + request4.hostname;
          }
        }
      }
      deserializeMetadata(output) {
        return {
          httpStatusCode: output.statusCode,
          requestId: output.headers["x-amzn-requestid"] ?? output.headers["x-amzn-request-id"] ?? output.headers["x-amz-request-id"],
          extendedRequestId: output.headers["x-amz-id-2"],
          cfId: output.headers["x-amz-cf-id"]
        };
      }
      async serializeEventStream({ eventStream, requestSchema, initialRequest }) {
        const eventStreamSerde = await this.loadEventStreamCapability();
        return eventStreamSerde.serializeEventStream({
          eventStream,
          requestSchema,
          initialRequest
        });
      }
      async deserializeEventStream({ response, responseSchema, initialResponseContainer }) {
        const eventStreamSerde = await this.loadEventStreamCapability();
        return eventStreamSerde.deserializeEventStream({
          response,
          responseSchema,
          initialResponseContainer
        });
      }
      async loadEventStreamCapability() {
        const { EventStreamSerde: EventStreamSerde7 } = await Promise.resolve().then(() => (init_event_streams4(), event_streams_exports4));
        return new EventStreamSerde7({
          marshaller: this.getEventStreamMarshaller(),
          serializer: this.serializer,
          deserializer: this.deserializer,
          serdeContext: this.serdeContext,
          defaultContentType: this.getDefaultContentType()
        });
      }
      getDefaultContentType() {
        throw new Error(`@smithy/core/protocols - ${this.constructor.name} getDefaultContentType() implementation missing.`);
      }
      async deserializeHttpMessage(schema, context, response, arg4, arg5) {
        void schema;
        void context;
        void response;
        void arg4;
        void arg5;
        return [];
      }
      getEventStreamMarshaller() {
        const context = this.serdeContext;
        if (!context.eventStreamMarshaller) {
          throw new Error("@smithy/core - HttpProtocol: eventStreamMarshaller missing in serdeContext.");
        }
        return context.eventStreamMarshaller;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/HttpBindingProtocol.js
var HttpBindingProtocol4;
var init_HttpBindingProtocol5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/HttpBindingProtocol.js"() {
    init_schema7();
    init_serde5();
    init_HttpProtocol5();
    init_collect_stream_body5();
    init_extended_encode_uri_component5();
    init_httpRequest4();
    HttpBindingProtocol4 = class extends HttpProtocol4 {
      static {
        __name(this, "HttpBindingProtocol");
      }
      async serializeRequest(operationSchema, _input, context) {
        const input = _input && typeof _input === "object" ? _input : {};
        const serializer = this.serializer;
        const query = {};
        const headers = {};
        const endpoint = await context.endpoint();
        const ns = NormalizedSchema4.of(operationSchema?.input);
        const payloadMemberNames = [];
        const payloadMemberSchemas = [];
        let hasNonHttpBindingMember = false;
        let payload3;
        const request4 = new HttpRequest23({
          protocol: "",
          hostname: "",
          port: void 0,
          path: "",
          fragment: void 0,
          query,
          headers,
          body: void 0
        });
        if (endpoint) {
          this.updateServiceEndpoint(request4, endpoint);
          this.setHostPrefix(request4, operationSchema, input);
          const opTraits = translateTraits4(operationSchema.traits);
          if (opTraits.http) {
            request4.method = opTraits.http[0];
            const [path47, search] = opTraits.http[1].split("?");
            if (request4.path == "/") {
              request4.path = path47;
            } else {
              request4.path += path47;
            }
            const traitSearchParams = new URLSearchParams(search ?? "");
            for (const [key, value] of traitSearchParams) {
              query[key] = value;
            }
          }
        }
        for (const [memberName, memberNs] of ns.structIterator()) {
          const memberTraits = memberNs.getMergedTraits() ?? {};
          const inputMemberValue = input[memberName];
          if (inputMemberValue == null && !memberNs.isIdempotencyToken()) {
            if (memberTraits.httpLabel) {
              if (request4.path.includes(`{${memberName}+}`) || request4.path.includes(`{${memberName}}`)) {
                throw new Error(`No value provided for input HTTP label: ${memberName}.`);
              }
            }
            continue;
          }
          if (memberTraits.httpPayload) {
            const isStreaming = memberNs.isStreaming();
            if (isStreaming) {
              const isEventStream = memberNs.isStructSchema();
              if (isEventStream) {
                if (input[memberName]) {
                  payload3 = await this.serializeEventStream({
                    eventStream: input[memberName],
                    requestSchema: ns
                  });
                }
              } else {
                payload3 = inputMemberValue;
              }
            } else {
              serializer.write(memberNs, inputMemberValue);
              payload3 = serializer.flush();
            }
          } else if (memberTraits.httpLabel) {
            serializer.write(memberNs, inputMemberValue);
            const replacement = serializer.flush();
            if (request4.path.includes(`{${memberName}+}`)) {
              request4.path = request4.path.replace(`{${memberName}+}`, replacement.split("/").map(extendedEncodeURIComponent4).join("/"));
            } else if (request4.path.includes(`{${memberName}}`)) {
              request4.path = request4.path.replace(`{${memberName}}`, extendedEncodeURIComponent4(replacement));
            }
          } else if (memberTraits.httpHeader) {
            serializer.write(memberNs, inputMemberValue);
            headers[memberTraits.httpHeader.toLowerCase()] = String(serializer.flush());
          } else if (typeof memberTraits.httpPrefixHeaders === "string") {
            for (const key in inputMemberValue) {
              const val = inputMemberValue[key];
              const amalgam = memberTraits.httpPrefixHeaders + key;
              serializer.write([memberNs.getValueSchema(), { httpHeader: amalgam }], val);
              headers[amalgam.toLowerCase()] = serializer.flush();
            }
          } else if (memberTraits.httpQuery || memberTraits.httpQueryParams) {
            this.serializeQuery(memberNs, inputMemberValue, query);
          } else {
            hasNonHttpBindingMember = true;
            payloadMemberNames.push(memberName);
            payloadMemberSchemas.push(memberNs);
          }
        }
        if (hasNonHttpBindingMember && input) {
          const [namespace, name] = (ns.getName(true) ?? "#Unknown").split("#");
          const requiredMembers = ns.getSchema()[6];
          const payloadSchema = [
            3,
            namespace,
            name,
            ns.getMergedTraits(),
            payloadMemberNames,
            payloadMemberSchemas,
            void 0
          ];
          if (requiredMembers) {
            payloadSchema[6] = requiredMembers;
          } else {
            payloadSchema.pop();
          }
          serializer.write(payloadSchema, input);
          payload3 = serializer.flush();
        }
        request4.headers = headers;
        request4.query = query;
        request4.body = payload3;
        return request4;
      }
      serializeQuery(ns, data3, query) {
        const serializer = this.serializer;
        const traits = ns.getMergedTraits();
        if (traits.httpQueryParams) {
          for (const key in data3) {
            if (!(key in query)) {
              const val = data3[key];
              const valueSchema = ns.getValueSchema();
              Object.assign(valueSchema.getMergedTraits(), {
                ...traits,
                httpQuery: key,
                httpQueryParams: void 0
              });
              this.serializeQuery(valueSchema, val, query);
            }
          }
          return;
        }
        if (ns.isListSchema()) {
          const sparse = !!ns.getMergedTraits().sparse;
          const buffer = [];
          for (const item of data3) {
            serializer.write([ns.getValueSchema(), traits], item);
            const serializable = serializer.flush();
            if (sparse || serializable !== void 0) {
              buffer.push(serializable);
            }
          }
          query[traits.httpQuery] = buffer;
        } else {
          serializer.write([ns, traits], data3);
          query[traits.httpQuery] = serializer.flush();
        }
      }
      async deserializeResponse(operationSchema, context, response) {
        const deserializer = this.deserializer;
        const ns = NormalizedSchema4.of(operationSchema.output);
        const dataObject = {};
        if (response.statusCode >= 300) {
          const bytes = await collectBody11(response.body, context);
          if (bytes.byteLength > 0) {
            Object.assign(dataObject, await deserializer.read(15, bytes));
          }
          await this.handleError(operationSchema, context, response, dataObject, this.deserializeMetadata(response));
          throw new Error("@smithy/core/protocols - HTTP Protocol error handler failed to throw.");
        }
        for (const header in response.headers) {
          const value = response.headers[header];
          delete response.headers[header];
          response.headers[header.toLowerCase()] = value;
        }
        const nonHttpBindingMembers = await this.deserializeHttpMessage(ns, context, response, dataObject);
        if (nonHttpBindingMembers.length) {
          const bytes = await collectBody11(response.body, context);
          if (bytes.byteLength > 0) {
            const dataFromBody = await deserializer.read(ns, bytes);
            for (const member7 of nonHttpBindingMembers) {
              if (dataFromBody[member7] != null) {
                dataObject[member7] = dataFromBody[member7];
              }
            }
          }
        } else if (nonHttpBindingMembers.discardResponseBody) {
          await collectBody11(response.body, context);
        }
        dataObject.$metadata = this.deserializeMetadata(response);
        return dataObject;
      }
      async deserializeHttpMessage(schema, context, response, arg4, arg5) {
        let dataObject;
        if (arg4 instanceof Set) {
          dataObject = arg5;
        } else {
          dataObject = arg4;
        }
        let discardResponseBody = true;
        const deserializer = this.deserializer;
        const ns = NormalizedSchema4.of(schema);
        const nonHttpBindingMembers = [];
        for (const [memberName, memberSchema] of ns.structIterator()) {
          const memberTraits = memberSchema.getMemberTraits();
          if (memberTraits.httpPayload) {
            discardResponseBody = false;
            const isStreaming = memberSchema.isStreaming();
            if (isStreaming) {
              const isEventStream = memberSchema.isStructSchema();
              if (isEventStream) {
                dataObject[memberName] = await this.deserializeEventStream({
                  response,
                  responseSchema: ns
                });
              } else {
                dataObject[memberName] = sdkStreamMixin6(response.body);
              }
            } else if (response.body) {
              const bytes = await collectBody11(response.body, context);
              if (bytes.byteLength > 0) {
                dataObject[memberName] = await deserializer.read(memberSchema, bytes);
              }
            }
          } else if (memberTraits.httpHeader) {
            const key = String(memberTraits.httpHeader).toLowerCase();
            const value = response.headers[key];
            if (null != value) {
              if (memberSchema.isListSchema()) {
                const headerListValueSchema = memberSchema.getValueSchema();
                headerListValueSchema.getMergedTraits().httpHeader = key;
                let sections;
                if (headerListValueSchema.isTimestampSchema() && headerListValueSchema.getSchema() === 4) {
                  sections = splitEvery4(value, ",", 2);
                } else {
                  sections = splitHeader4(value);
                }
                const list3 = [];
                for (const section of sections) {
                  list3.push(await deserializer.read(headerListValueSchema, section.trim()));
                }
                dataObject[memberName] = list3;
              } else {
                dataObject[memberName] = await deserializer.read(memberSchema, value);
              }
            }
          } else if (memberTraits.httpPrefixHeaders !== void 0) {
            dataObject[memberName] = {};
            for (const header in response.headers) {
              if (header.startsWith(memberTraits.httpPrefixHeaders)) {
                const value = response.headers[header];
                const valueSchema = memberSchema.getValueSchema();
                valueSchema.getMergedTraits().httpHeader = header;
                dataObject[memberName][header.slice(memberTraits.httpPrefixHeaders.length)] = await deserializer.read(valueSchema, value);
              }
            }
          } else if (memberTraits.httpResponseCode) {
            dataObject[memberName] = response.statusCode;
          } else {
            nonHttpBindingMembers.push(memberName);
          }
        }
        nonHttpBindingMembers.discardResponseBody = discardResponseBody;
        return nonHttpBindingMembers;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/RpcProtocol.js
var RpcProtocol4;
var init_RpcProtocol5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/RpcProtocol.js"() {
    init_schema7();
    init_HttpProtocol5();
    init_collect_stream_body5();
    init_httpRequest4();
    RpcProtocol4 = class extends HttpProtocol4 {
      static {
        __name(this, "RpcProtocol");
      }
      async serializeRequest(operationSchema, _input, context) {
        const serializer = this.serializer;
        const query = {};
        const headers = {};
        const endpoint = await context.endpoint();
        const ns = NormalizedSchema4.of(operationSchema?.input);
        const schema = ns.getSchema();
        let payload3;
        const input = _input && typeof _input === "object" ? _input : {};
        const request4 = new HttpRequest23({
          protocol: "",
          hostname: "",
          port: void 0,
          path: "/",
          fragment: void 0,
          query,
          headers,
          body: void 0
        });
        if (endpoint) {
          this.updateServiceEndpoint(request4, endpoint);
          this.setHostPrefix(request4, operationSchema, input);
        }
        if (input) {
          const eventStreamMember = ns.getEventStreamMember();
          if (eventStreamMember) {
            if (input[eventStreamMember]) {
              const initialRequest = {};
              for (const [memberName, memberSchema] of ns.structIterator()) {
                if (memberName !== eventStreamMember && input[memberName]) {
                  serializer.write(memberSchema, input[memberName]);
                  initialRequest[memberName] = serializer.flush();
                }
              }
              payload3 = await this.serializeEventStream({
                eventStream: input[eventStreamMember],
                requestSchema: ns,
                initialRequest
              });
            }
          } else {
            serializer.write(schema, input);
            payload3 = serializer.flush();
          }
        }
        request4.headers = Object.assign(request4.headers, headers);
        request4.query = query;
        request4.body = payload3;
        request4.method = "POST";
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        const deserializer = this.deserializer;
        const ns = NormalizedSchema4.of(operationSchema.output);
        const dataObject = {};
        if (response.statusCode >= 300) {
          const bytes = await collectBody11(response.body, context);
          if (bytes.byteLength > 0) {
            Object.assign(dataObject, await deserializer.read(15, bytes));
          }
          await this.handleError(operationSchema, context, response, dataObject, this.deserializeMetadata(response));
          throw new Error("@smithy/core/protocols - RPC Protocol error handler failed to throw.");
        }
        for (const header in response.headers) {
          const value = response.headers[header];
          delete response.headers[header];
          response.headers[header.toLowerCase()] = value;
        }
        const eventStreamMember = ns.getEventStreamMember();
        if (eventStreamMember) {
          dataObject[eventStreamMember] = await this.deserializeEventStream({
            response,
            responseSchema: ns,
            initialResponseContainer: dataObject
          });
        } else {
          const bytes = await collectBody11(response.body, context);
          if (bytes.byteLength > 0) {
            Object.assign(dataObject, await deserializer.read(ns, bytes));
          }
        }
        dataObject.$metadata = this.deserializeMetadata(response);
        return dataObject;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/resolve-path.js
var resolvedPath4;
var init_resolve_path5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/resolve-path.js"() {
    init_extended_encode_uri_component5();
    resolvedPath4 = /* @__PURE__ */ __name((resolvedPath7, input, memberName, labelValueProvider, uriLabel, isGreedyLabel) => {
      if (input != null && input[memberName] !== void 0) {
        const labelValue = labelValueProvider();
        if (labelValue == null || labelValue.length <= 0) {
          throw new Error("Empty value provided for input HTTP label: " + memberName + ".");
        }
        resolvedPath7 = resolvedPath7.replace(uriLabel, isGreedyLabel ? labelValue.split("/").map((segment) => extendedEncodeURIComponent4(segment)).join("/") : extendedEncodeURIComponent4(labelValue));
      } else {
        throw new Error("No value provided for input HTTP label: " + memberName + ".");
      }
      return resolvedPath7;
    }, "resolvedPath");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/requestBuilder.js
function requestBuilder4(input, context) {
  return new RequestBuilder4(input, context);
}
var RequestBuilder4;
var init_requestBuilder7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/requestBuilder.js"() {
    init_httpRequest4();
    init_resolve_path5();
    __name(requestBuilder4, "requestBuilder");
    RequestBuilder4 = class {
      static {
        __name(this, "RequestBuilder");
      }
      input;
      context;
      query = {};
      method = "";
      headers = {};
      path = "";
      body = null;
      hostname = "";
      resolvePathStack = [];
      constructor(input, context) {
        this.input = input;
        this.context = context;
      }
      async build() {
        const { hostname, protocol = "https", port, path: basePath } = await this.context.endpoint();
        this.path = basePath;
        for (const resolvePath of this.resolvePathStack) {
          resolvePath(this.path);
        }
        return new HttpRequest23({
          protocol,
          hostname: this.hostname || hostname,
          port,
          method: this.method,
          path: this.path,
          query: this.query,
          body: this.body,
          headers: this.headers
        });
      }
      hn(hostname) {
        this.hostname = hostname;
        return this;
      }
      bp(uriLabel) {
        this.resolvePathStack.push((basePath) => {
          this.path = `${basePath?.endsWith("/") ? basePath.slice(0, -1) : basePath || ""}` + uriLabel;
        });
        return this;
      }
      p(memberName, labelValueProvider, uriLabel, isGreedyLabel) {
        this.resolvePathStack.push((path47) => {
          this.path = resolvedPath4(path47, this.input, memberName, labelValueProvider, uriLabel, isGreedyLabel);
        });
        return this;
      }
      h(headers) {
        this.headers = headers;
        return this;
      }
      q(query) {
        this.query = query;
        return this;
      }
      b(body) {
        this.body = body;
        return this;
      }
      m(method) {
        this.method = method;
        return this;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/serde/determineTimestampFormat.js
function determineTimestampFormat4(ns, settings) {
  if (settings.timestampFormat.useTrait) {
    if (ns.isTimestampSchema() && (ns.getSchema() === 5 || ns.getSchema() === 6 || ns.getSchema() === 7)) {
      return ns.getSchema();
    }
  }
  const { httpLabel, httpPrefixHeaders, httpHeader, httpQuery } = ns.getMergedTraits();
  const bindingFormat = settings.httpBindings ? typeof httpPrefixHeaders === "string" || Boolean(httpHeader) ? 6 : Boolean(httpQuery) || Boolean(httpLabel) ? 5 : void 0 : void 0;
  return bindingFormat ?? settings.timestampFormat.default;
}
var init_determineTimestampFormat5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/serde/determineTimestampFormat.js"() {
    __name(determineTimestampFormat4, "determineTimestampFormat");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/serde/FromStringShapeDeserializer.js
var FromStringShapeDeserializer4;
var init_FromStringShapeDeserializer5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/serde/FromStringShapeDeserializer.js"() {
    init_schema7();
    init_serde5();
    init_SerdeContext5();
    init_determineTimestampFormat5();
    FromStringShapeDeserializer4 = class extends SerdeContext4 {
      static {
        __name(this, "FromStringShapeDeserializer");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      read(_schema, data3) {
        const ns = NormalizedSchema4.of(_schema);
        if (ns.isListSchema()) {
          return splitHeader4(data3).map((item) => this.read(ns.getValueSchema(), item));
        }
        if (ns.isBlobSchema()) {
          return (this.serdeContext?.base64Decoder ?? fromBase6438)(data3);
        }
        if (ns.isTimestampSchema()) {
          const format32 = determineTimestampFormat4(ns, this.settings);
          switch (format32) {
            case 5:
              return _parseRfc3339DateTimeWithOffset4(data3);
            case 6:
              return _parseRfc7231DateTime4(data3);
            case 7:
              return _parseEpochTimestamp4(data3);
            default:
              console.warn("Missing timestamp format, parsing value with Date constructor:", data3);
              return new Date(data3);
          }
        }
        if (ns.isStringSchema()) {
          const mediaType = ns.getMergedTraits().mediaType;
          let intermediateValue = data3;
          if (mediaType) {
            if (ns.getMergedTraits().httpHeader) {
              intermediateValue = this.base64ToUtf8(intermediateValue);
            }
            const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
            if (isJson) {
              intermediateValue = LazyJsonString7.from(intermediateValue);
            }
            return intermediateValue;
          }
        }
        if (ns.isNumericSchema()) {
          return Number(data3);
        }
        if (ns.isBigIntegerSchema()) {
          return BigInt(data3);
        }
        if (ns.isBigDecimalSchema()) {
          return new NumericValue4(data3, "bigDecimal");
        }
        if (ns.isBooleanSchema()) {
          return String(data3).toLowerCase() === "true";
        }
        return data3;
      }
      base64ToUtf8(base64String) {
        return (this.serdeContext?.utf8Encoder ?? toUtf841)((this.serdeContext?.base64Decoder ?? fromBase6438)(base64String));
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/serde/HttpInterceptingShapeDeserializer.js
var HttpInterceptingShapeDeserializer4;
var init_HttpInterceptingShapeDeserializer5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/serde/HttpInterceptingShapeDeserializer.js"() {
    init_schema7();
    init_serde5();
    init_SerdeContext5();
    init_FromStringShapeDeserializer5();
    HttpInterceptingShapeDeserializer4 = class extends SerdeContext4 {
      static {
        __name(this, "HttpInterceptingShapeDeserializer");
      }
      codecDeserializer;
      stringDeserializer;
      constructor(codecDeserializer, codecSettings) {
        super();
        this.codecDeserializer = codecDeserializer;
        this.stringDeserializer = new FromStringShapeDeserializer4(codecSettings);
      }
      setSerdeContext(serdeContext) {
        this.stringDeserializer.setSerdeContext(serdeContext);
        this.codecDeserializer.setSerdeContext(serdeContext);
        this.serdeContext = serdeContext;
      }
      read(schema, data3) {
        const ns = NormalizedSchema4.of(schema);
        const traits = ns.getMergedTraits();
        const toString = this.serdeContext?.utf8Encoder ?? toUtf841;
        if (traits.httpHeader || traits.httpResponseCode) {
          return this.stringDeserializer.read(ns, toString(data3));
        }
        if (traits.httpPayload) {
          if (ns.isBlobSchema()) {
            const toBytes = this.serdeContext?.utf8Decoder ?? fromUtf827;
            if (typeof data3 === "string") {
              return toBytes(data3);
            }
            return data3;
          } else if (ns.isStringSchema()) {
            if ("byteLength" in data3) {
              return toString(data3);
            }
            return data3;
          }
        }
        return this.codecDeserializer.read(ns, data3);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/serde/ToStringShapeSerializer.js
var ToStringShapeSerializer4;
var init_ToStringShapeSerializer5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/serde/ToStringShapeSerializer.js"() {
    init_schema7();
    init_serde5();
    init_SerdeContext5();
    init_determineTimestampFormat5();
    ToStringShapeSerializer4 = class extends SerdeContext4 {
      static {
        __name(this, "ToStringShapeSerializer");
      }
      settings;
      stringBuffer = "";
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value) {
        const ns = NormalizedSchema4.of(schema);
        switch (typeof value) {
          case "object":
            if (value === null) {
              this.stringBuffer = "null";
              return;
            }
            if (ns.isTimestampSchema()) {
              if (!(value instanceof Date)) {
                throw new Error(`@smithy/core/protocols - received non-Date value ${value} when schema expected Date in ${ns.getName(true)}`);
              }
              const format32 = determineTimestampFormat4(ns, this.settings);
              switch (format32) {
                case 5:
                  this.stringBuffer = value.toISOString().replace(".000Z", "Z");
                  break;
                case 6:
                  this.stringBuffer = dateToUtcString16(value);
                  break;
                case 7:
                  this.stringBuffer = String(value.getTime() / 1e3);
                  break;
                default:
                  console.warn("Missing timestamp format, using epoch seconds", value);
                  this.stringBuffer = String(value.getTime() / 1e3);
              }
              return;
            }
            if (ns.isBlobSchema() && "byteLength" in value) {
              this.stringBuffer = (this.serdeContext?.base64Encoder ?? toBase6443)(value);
              return;
            }
            if (ns.isListSchema() && Array.isArray(value)) {
              let buffer = "";
              for (const item of value) {
                this.write([ns.getValueSchema(), ns.getMergedTraits()], item);
                const headerItem = this.flush();
                const serialized = ns.getValueSchema().isTimestampSchema() ? headerItem : quoteHeader4(headerItem);
                if (buffer !== "") {
                  buffer += ", ";
                }
                buffer += serialized;
              }
              this.stringBuffer = buffer;
              return;
            }
            this.stringBuffer = JSON.stringify(value, null, 2);
            break;
          case "string":
            const mediaType = ns.getMergedTraits().mediaType;
            let intermediateValue = value;
            if (mediaType) {
              const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
              if (isJson) {
                intermediateValue = LazyJsonString7.from(intermediateValue);
              }
              if (ns.getMergedTraits().httpHeader) {
                this.stringBuffer = (this.serdeContext?.base64Encoder ?? toBase6443)(intermediateValue.toString());
                return;
              }
            }
            this.stringBuffer = value;
            break;
          default:
            if (ns.isIdempotencyToken()) {
              this.stringBuffer = generateIdempotencyToken4();
            } else {
              this.stringBuffer = String(value);
            }
        }
      }
      flush() {
        const buffer = this.stringBuffer;
        this.stringBuffer = "";
        return buffer;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/serde/HttpInterceptingShapeSerializer.js
var HttpInterceptingShapeSerializer4;
var init_HttpInterceptingShapeSerializer5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/serde/HttpInterceptingShapeSerializer.js"() {
    init_schema7();
    init_ToStringShapeSerializer5();
    HttpInterceptingShapeSerializer4 = class {
      static {
        __name(this, "HttpInterceptingShapeSerializer");
      }
      codecSerializer;
      stringSerializer;
      buffer;
      constructor(codecSerializer, codecSettings, stringSerializer = new ToStringShapeSerializer4(codecSettings)) {
        this.codecSerializer = codecSerializer;
        this.stringSerializer = stringSerializer;
      }
      setSerdeContext(serdeContext) {
        this.codecSerializer.setSerdeContext(serdeContext);
        this.stringSerializer.setSerdeContext(serdeContext);
      }
      write(schema, value) {
        const ns = NormalizedSchema4.of(schema);
        const traits = ns.getMergedTraits();
        if (traits.httpHeader || traits.httpLabel || traits.httpQuery) {
          this.stringSerializer.write(ns, value);
          this.buffer = this.stringSerializer.flush();
          return;
        }
        return this.codecSerializer.write(ns, value);
      }
      flush() {
        if (this.buffer !== void 0) {
          const buffer = this.buffer;
          this.buffer = void 0;
          return buffer;
        }
        return this.codecSerializer.flush();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/Field.js
var import_types50, Field3;
var init_Field3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/Field.js"() {
    import_types50 = __toESM(require_dist_cjs());
    Field3 = class {
      static {
        __name(this, "Field");
      }
      name;
      kind;
      values;
      constructor({ name, kind = import_types50.FieldPosition.HEADER, values = [] }) {
        this.name = name;
        this.kind = kind;
        this.values = values;
      }
      add(value) {
        this.values.push(value);
      }
      set(values) {
        this.values = values;
      }
      remove(value) {
        this.values = this.values.filter((v) => v !== value);
      }
      toString() {
        return this.values.map((v) => v.includes(",") || v.includes(" ") ? `"${v}"` : v).join(", ");
      }
      get() {
        return this.values;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/Fields.js
var Fields3;
var init_Fields3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/Fields.js"() {
    Fields3 = class {
      static {
        __name(this, "Fields");
      }
      entries = {};
      encoding;
      constructor({ fields = [], encoding = "utf-8" }) {
        fields.forEach(this.setField.bind(this));
        this.encoding = encoding;
      }
      setField(field) {
        this.entries[field.name.toLowerCase()] = field;
      }
      getField(name) {
        return this.entries[name.toLowerCase()];
      }
      removeField(name) {
        delete this.entries[name.toLowerCase()];
      }
      getByType(kind) {
        return Object.values(this.entries).filter((field) => field.kind === kind);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/isValidHostname.js
function isValidHostname3(hostname) {
  const hostPattern = /^[a-z0-9][a-z0-9\.\-]*[a-z0-9]$/;
  return hostPattern.test(hostname);
}
var init_isValidHostname3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/isValidHostname.js"() {
    __name(isValidHostname3, "isValidHostname");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/extensions/httpExtensionConfiguration.js
var getHttpHandlerExtensionConfiguration21, resolveHttpHandlerRuntimeConfig21;
var init_httpExtensionConfiguration3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/extensions/httpExtensionConfiguration.js"() {
    getHttpHandlerExtensionConfiguration21 = /* @__PURE__ */ __name((runtimeConfig) => {
      return {
        setHttpHandler(handler) {
          runtimeConfig.httpHandler = handler;
        },
        httpHandler() {
          return runtimeConfig.httpHandler;
        },
        updateHttpClientConfig(key, value) {
          runtimeConfig.httpHandler?.updateHttpClientConfig(key, value);
        },
        httpHandlerConfigs() {
          return runtimeConfig.httpHandler.httpHandlerConfigs();
        }
      };
    }, "getHttpHandlerExtensionConfiguration");
    resolveHttpHandlerRuntimeConfig21 = /* @__PURE__ */ __name((httpHandlerExtensionConfiguration) => {
      return {
        httpHandler: httpHandlerExtensionConfiguration.httpHandler()
      };
    }, "resolveHttpHandlerRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/middleware-content-length/contentLengthMiddleware.js
function contentLengthMiddleware3(bodyLengthChecker) {
  return (next) => async (args) => {
    const request4 = args.request;
    if (HttpRequest23.isInstance(request4)) {
      const { body, headers } = request4;
      if (body && Object.keys(headers).map((str) => str.toLowerCase()).indexOf(CONTENT_LENGTH_HEADER3) === -1) {
        try {
          const length = bodyLengthChecker(body);
          request4.headers = {
            ...request4.headers,
            [CONTENT_LENGTH_HEADER3]: String(length)
          };
        } catch (error4) {
        }
      }
    }
    return next({
      ...args,
      request: request4
    });
  };
}
var CONTENT_LENGTH_HEADER3, contentLengthMiddlewareOptions3, getContentLengthPlugin21;
var init_contentLengthMiddleware3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/middleware-content-length/contentLengthMiddleware.js"() {
    init_httpRequest4();
    CONTENT_LENGTH_HEADER3 = "content-length";
    __name(contentLengthMiddleware3, "contentLengthMiddleware");
    contentLengthMiddlewareOptions3 = {
      step: "build",
      tags: ["SET_CONTENT_LENGTH", "CONTENT_LENGTH"],
      name: "contentLengthMiddleware",
      override: true
    };
    getContentLengthPlugin21 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(contentLengthMiddleware3(options.bodyLengthChecker), contentLengthMiddlewareOptions3);
      }, "applyToStack")
    }), "getContentLengthPlugin");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/util-uri-escape/escape-uri.js
var escapeUri3, hexEncode3;
var init_escape_uri3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/util-uri-escape/escape-uri.js"() {
    escapeUri3 = /* @__PURE__ */ __name((uri) => encodeURIComponent(uri).replace(/[!'()*]/g, hexEncode3), "escapeUri");
    hexEncode3 = /* @__PURE__ */ __name((c32) => `%${c32.charCodeAt(0).toString(16).toUpperCase()}`, "hexEncode");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/util-uri-escape/escape-uri-path.js
var escapeUriPath3;
var init_escape_uri_path3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/util-uri-escape/escape-uri-path.js"() {
    init_escape_uri3();
    escapeUriPath3 = /* @__PURE__ */ __name((uri) => uri.split("/").map(escapeUri3).join("/"), "escapeUriPath");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/querystring-builder/buildQueryString.js
function buildQueryString3(query) {
  const parts = [];
  for (let key of Object.keys(query).sort()) {
    const value = query[key];
    key = escapeUri3(key);
    if (Array.isArray(value)) {
      for (let i32 = 0, iLen = value.length; i32 < iLen; i32++) {
        parts.push(`${key}=${escapeUri3(value[i32])}`);
      }
    } else {
      let qsEntry = key;
      if (value || typeof value === "string") {
        qsEntry += `=${escapeUri3(value)}`;
      }
      parts.push(qsEntry);
    }
  }
  return parts.join("&");
}
var init_buildQueryString3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/querystring-builder/buildQueryString.js"() {
    init_escape_uri3();
    __name(buildQueryString3, "buildQueryString");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/querystring-parser/parseQueryString.js
function parseQueryString3(querystring) {
  const query = {};
  querystring = querystring.replace(/^\?/, "");
  if (querystring) {
    for (const pair of querystring.split("&")) {
      let [key, value = null] = pair.split("=");
      key = decodeURIComponent(key);
      if (value) {
        value = decodeURIComponent(value);
      }
      if (!(key in query)) {
        query[key] = value;
      } else if (Array.isArray(query[key])) {
        query[key].push(value);
      } else {
        query[key] = [query[key], value];
      }
    }
  }
  return query;
}
var init_parseQueryString3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/querystring-parser/parseQueryString.js"() {
    __name(parseQueryString3, "parseQueryString");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/url-parser/parseUrl.js
var parseUrl22;
var init_parseUrl3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/url-parser/parseUrl.js"() {
    init_parseQueryString3();
    parseUrl22 = /* @__PURE__ */ __name((url) => {
      if (typeof url === "string") {
        return parseUrl22(new URL(url));
      }
      const { hostname, pathname, port, protocol, search } = url;
      let query;
      if (search) {
        query = parseQueryString3(search);
      }
      return {
        hostname,
        port: port ? parseInt(port) : void 0,
        protocol,
        path: pathname,
        query
      };
    }, "parseUrl");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/index.js
var protocols_exports9 = {};
__export(protocols_exports9, {
  Field: () => Field3,
  Fields: () => Fields3,
  FromStringShapeDeserializer: () => FromStringShapeDeserializer4,
  HttpBindingProtocol: () => HttpBindingProtocol4,
  HttpInterceptingShapeDeserializer: () => HttpInterceptingShapeDeserializer4,
  HttpInterceptingShapeSerializer: () => HttpInterceptingShapeSerializer4,
  HttpProtocol: () => HttpProtocol4,
  HttpRequest: () => HttpRequest23,
  HttpResponse: () => HttpResponse12,
  RequestBuilder: () => RequestBuilder4,
  RpcProtocol: () => RpcProtocol4,
  SerdeContext: () => SerdeContext4,
  ToStringShapeSerializer: () => ToStringShapeSerializer4,
  buildQueryString: () => buildQueryString3,
  collectBody: () => collectBody11,
  contentLengthMiddleware: () => contentLengthMiddleware3,
  contentLengthMiddlewareOptions: () => contentLengthMiddlewareOptions3,
  determineTimestampFormat: () => determineTimestampFormat4,
  escapeUri: () => escapeUri3,
  escapeUriPath: () => escapeUriPath3,
  extendedEncodeURIComponent: () => extendedEncodeURIComponent4,
  getContentLengthPlugin: () => getContentLengthPlugin21,
  getHttpHandlerExtensionConfiguration: () => getHttpHandlerExtensionConfiguration21,
  isValidHostname: () => isValidHostname3,
  parseQueryString: () => parseQueryString3,
  parseUrl: () => parseUrl22,
  requestBuilder: () => requestBuilder4,
  resolveHttpHandlerRuntimeConfig: () => resolveHttpHandlerRuntimeConfig21,
  resolvedPath: () => resolvedPath4
});
var init_protocols12 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/protocols/index.js"() {
    init_collect_stream_body5();
    init_extended_encode_uri_component5();
    init_HttpBindingProtocol5();
    init_HttpProtocol5();
    init_RpcProtocol5();
    init_requestBuilder7();
    init_resolve_path5();
    init_FromStringShapeDeserializer5();
    init_HttpInterceptingShapeDeserializer5();
    init_HttpInterceptingShapeSerializer5();
    init_ToStringShapeSerializer5();
    init_determineTimestampFormat5();
    init_SerdeContext5();
    init_Field3();
    init_Fields3();
    init_httpRequest4();
    init_httpResponse4();
    init_isValidHostname3();
    init_httpExtensionConfiguration3();
    init_contentLengthMiddleware3();
    init_escape_uri3();
    init_escape_uri_path3();
    init_buildQueryString3();
    init_parseQueryString3();
    init_parseUrl3();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/middleware-serde/deserializerMiddleware.js
var deserializerMiddleware2, findHeader4;
var init_deserializerMiddleware2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/middleware-serde/deserializerMiddleware.js"() {
    init_protocols12();
    deserializerMiddleware2 = /* @__PURE__ */ __name((options, deserializer) => (next, context) => async (args) => {
      const { response } = await next(args);
      try {
        const parsed = await deserializer(response, options);
        return {
          response,
          output: parsed
        };
      } catch (error4) {
        Object.defineProperty(error4, "$response", {
          value: response,
          enumerable: false,
          writable: false,
          configurable: false
        });
        if (!("$metadata" in error4)) {
          const hint = `Deserialization error: to see the raw response, inspect the hidden field {error}.$response on this object.`;
          try {
            error4.message += "\n  " + hint;
          } catch (e32) {
            if (!context.logger || context.logger?.constructor?.name === "NoOpLogger") {
              console.warn(hint);
            } else {
              context.logger?.warn?.(hint);
            }
          }
          if (typeof error4.$responseBodyText !== "undefined") {
            if (error4.$response) {
              error4.$response.body = error4.$responseBodyText;
            }
          }
          try {
            if (HttpResponse12.isInstance(response)) {
              const { headers = {} } = response;
              const headerEntries = Object.entries(headers);
              error4.$metadata = {
                httpStatusCode: response.statusCode,
                requestId: findHeader4(/^x-[\w-]+-request-?id$/, headerEntries),
                extendedRequestId: findHeader4(/^x-[\w-]+-id-2$/, headerEntries),
                cfId: findHeader4(/^x-[\w-]+-cf-id$/, headerEntries)
              };
            }
          } catch (e32) {
          }
        }
        throw error4;
      }
    }, "deserializerMiddleware");
    findHeader4 = /* @__PURE__ */ __name((pattern, headers) => {
      return (headers.find(([k32]) => {
        return k32.match(pattern);
      }) || [void 0, void 0])[1];
    }, "findHeader");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/middleware-serde/serializerMiddleware.js
var serializerMiddleware2;
var init_serializerMiddleware2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/middleware-serde/serializerMiddleware.js"() {
    init_endpoints4();
    serializerMiddleware2 = /* @__PURE__ */ __name((options, serializer) => (next, context) => async (args) => {
      const endpointConfig = options;
      const endpoint = context.endpointV2 ? async () => toEndpointV15(context.endpointV2) : endpointConfig.endpoint;
      if (!endpoint) {
        throw new Error("No valid endpoint provider available.");
      }
      const request4 = await serializer(args.input, { ...options, endpoint });
      return next({
        ...args,
        request: request4
      });
    }, "serializerMiddleware");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/middleware-serde/serdePlugin.js
function getSerdePlugin2(config2, serializer, deserializer) {
  return {
    applyToStack: /* @__PURE__ */ __name((commandStack) => {
      commandStack.add(deserializerMiddleware2(config2, deserializer), deserializerMiddlewareOption4);
      commandStack.add(serializerMiddleware2(config2, serializer), serializerMiddlewareOption7);
    }, "applyToStack")
  };
}
var deserializerMiddlewareOption4, serializerMiddlewareOption7;
var init_serdePlugin2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/middleware-serde/serdePlugin.js"() {
    init_deserializerMiddleware2();
    init_serializerMiddleware2();
    deserializerMiddlewareOption4 = {
      name: "deserializerMiddleware",
      step: "deserialize",
      tags: ["DESERIALIZER"],
      override: true
    };
    serializerMiddlewareOption7 = {
      name: "serializerMiddleware",
      step: "serialize",
      tags: ["SERIALIZER"],
      override: true
    };
    __name(getSerdePlugin2, "getSerdePlugin");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/hash-node/hash-node.js
function castSourceData2(toCast, encoding) {
  if (Buffer.isBuffer(toCast)) {
    return toCast;
  }
  if (typeof toCast === "string") {
    return fromString4(toCast, encoding);
  }
  if (ArrayBuffer.isView(toCast)) {
    return fromArrayBuffer4(toCast.buffer, toCast.byteOffset, toCast.byteLength);
  }
  return fromArrayBuffer4(toCast);
}
var import_node_crypto11, Hash20;
var init_hash_node2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/hash-node/hash-node.js"() {
    import_node_crypto11 = require("node:crypto");
    init_buffer_from4();
    init_toUint8Array2();
    Hash20 = class {
      static {
        __name(this, "Hash");
      }
      algorithmIdentifier;
      secret;
      hash;
      constructor(algorithmIdentifier, secret) {
        this.algorithmIdentifier = algorithmIdentifier;
        this.secret = secret;
        this.reset();
      }
      update(toHash, encoding) {
        this.hash.update(toUint8Array3(castSourceData2(toHash, encoding)));
      }
      digest() {
        return Promise.resolve(this.hash.digest());
      }
      reset() {
        this.hash = this.secret ? (0, import_node_crypto11.createHmac)(this.algorithmIdentifier, castSourceData2(this.secret)) : (0, import_node_crypto11.createHash)(this.algorithmIdentifier);
      }
    };
    __name(castSourceData2, "castSourceData");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/checksum/ChecksumStream.js
var import_node_stream15, ChecksumStream3;
var init_ChecksumStream2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/checksum/ChecksumStream.js"() {
    import_node_stream15 = require("node:stream");
    init_toBase644();
    ChecksumStream3 = class extends import_node_stream15.Duplex {
      static {
        __name(this, "ChecksumStream");
      }
      expectedChecksum;
      checksumSourceLocation;
      checksum;
      source;
      base64Encoder;
      pendingCallback = null;
      constructor({ expectedChecksum, checksum, source, checksumSourceLocation, base64Encoder }) {
        super();
        if (typeof source.pipe === "function") {
          this.source = source;
        } else {
          throw new Error(`@smithy/util-stream: unsupported source type ${source?.constructor?.name ?? source} in ChecksumStream.`);
        }
        this.base64Encoder = base64Encoder ?? toBase6443;
        this.expectedChecksum = expectedChecksum;
        this.checksum = checksum;
        this.checksumSourceLocation = checksumSourceLocation;
        this.source.pipe(this);
      }
      _read(size) {
        if (this.pendingCallback) {
          const callback = this.pendingCallback;
          this.pendingCallback = null;
          callback();
        }
      }
      _write(chunk, encoding, callback) {
        try {
          this.checksum.update(chunk);
          const canPushMore = this.push(chunk);
          if (!canPushMore) {
            this.pendingCallback = callback;
            return;
          }
        } catch (e32) {
          return callback(e32);
        }
        return callback();
      }
      async _final(callback) {
        try {
          const digest = await this.checksum.digest();
          const received = this.base64Encoder(digest);
          if (this.expectedChecksum !== received) {
            return callback(new Error(`Checksum mismatch: expected "${this.expectedChecksum}" but received "${received}" in response header "${this.checksumSourceLocation}".`));
          }
        } catch (e32) {
          return callback(e32);
        }
        this.push(null);
        return callback();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-type-check.js
var isReadableStream3, isBlob2;
var init_stream_type_check3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-type-check.js"() {
    isReadableStream3 = /* @__PURE__ */ __name((stream) => typeof ReadableStream === "function" && (stream?.constructor?.name === ReadableStream.name || stream instanceof ReadableStream), "isReadableStream");
    isBlob2 = /* @__PURE__ */ __name((blob) => {
      return typeof Blob === "function" && (blob?.constructor?.name === Blob.name || blob instanceof Blob);
    }, "isBlob");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/fromUtf8.browser.js
var fromUtf828;
var init_fromUtf8_browser3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/fromUtf8.browser.js"() {
    fromUtf828 = /* @__PURE__ */ __name((input) => new TextEncoder().encode(input), "fromUtf8");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/constants-for-browser.js
var chars3, alphabetByEncoding3, alphabetByValue3, bitsPerLetter3, bitsPerByte3, maxLetterValue3;
var init_constants_for_browser3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/constants-for-browser.js"() {
    chars3 = `ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/`;
    alphabetByEncoding3 = Object.entries(chars3).reduce((acc, [i32, c32]) => {
      acc[c32] = Number(i32);
      return acc;
    }, {});
    alphabetByValue3 = chars3.split("");
    bitsPerLetter3 = 6;
    bitsPerByte3 = 8;
    maxLetterValue3 = 63;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/toBase64.browser.js
function toBase6444(_input) {
  let input;
  if (typeof _input === "string") {
    input = fromUtf828(_input);
  } else {
    input = _input;
  }
  const isArrayLike = typeof input === "object" && typeof input.length === "number";
  const isUint8Array = typeof input === "object" && typeof input.byteOffset === "number" && typeof input.byteLength === "number";
  if (!isArrayLike && !isUint8Array) {
    throw new Error("@smithy/util-base64: toBase64 encoder function only accepts string | Uint8Array.");
  }
  let str = "";
  for (let i32 = 0; i32 < input.length; i32 += 3) {
    let bits = 0;
    let bitLength = 0;
    for (let j32 = i32, limit = Math.min(i32 + 3, input.length); j32 < limit; j32++) {
      bits |= input[j32] << (limit - j32 - 1) * bitsPerByte3;
      bitLength += bitsPerByte3;
    }
    const bitClusterCount = Math.ceil(bitLength / bitsPerLetter3);
    bits <<= bitClusterCount * bitsPerLetter3 - bitLength;
    for (let k32 = 1; k32 <= bitClusterCount; k32++) {
      const offset = (bitClusterCount - k32) * bitsPerLetter3;
      str += alphabetByValue3[(bits & maxLetterValue3 << offset) >> offset];
    }
    str += "==".slice(0, 4 - bitClusterCount);
  }
  return str;
}
var init_toBase64_browser3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/toBase64.browser.js"() {
    init_fromUtf8_browser3();
    init_constants_for_browser3();
    __name(toBase6444, "toBase64");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/checksum/ChecksumStream.browser.js
var ReadableStreamRef2, ChecksumStream4;
var init_ChecksumStream_browser2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/checksum/ChecksumStream.browser.js"() {
    ReadableStreamRef2 = typeof ReadableStream === "function" ? ReadableStream : function() {
    };
    ChecksumStream4 = class extends ReadableStreamRef2 {
      static {
        __name(this, "ChecksumStream");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/checksum/createChecksumStream.browser.js
var createChecksumStream3;
var init_createChecksumStream_browser2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/checksum/createChecksumStream.browser.js"() {
    init_toBase64_browser3();
    init_stream_type_check3();
    init_ChecksumStream_browser2();
    createChecksumStream3 = /* @__PURE__ */ __name(({ expectedChecksum, checksum, source, checksumSourceLocation, base64Encoder }) => {
      if (!isReadableStream3(source)) {
        throw new Error(`@smithy/util-stream: unsupported source type ${source?.constructor?.name ?? source} in ChecksumStream.`);
      }
      const encoder = base64Encoder ?? toBase6444;
      if (typeof TransformStream !== "function") {
        throw new Error("@smithy/util-stream: unable to instantiate ChecksumStream because API unavailable: ReadableStream/TransformStream.");
      }
      const transform = new TransformStream({
        start() {
        },
        async transform(chunk, controller) {
          checksum.update(chunk);
          controller.enqueue(chunk);
        },
        async flush(controller) {
          const digest = await checksum.digest();
          const received = encoder(digest);
          if (expectedChecksum !== received) {
            const error4 = new Error(`Checksum mismatch: expected "${expectedChecksum}" but received "${received}" in response header "${checksumSourceLocation}".`);
            controller.error(error4);
          } else {
            controller.terminate();
          }
        }
      });
      source.pipeThrough(transform);
      const readable = transform.readable;
      Object.setPrototypeOf(readable, ChecksumStream4.prototype);
      return readable;
    }, "createChecksumStream");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/checksum/createChecksumStream.js
function createChecksumStream4(init) {
  if (typeof ReadableStream === "function" && isReadableStream3(init.source)) {
    return createChecksumStream3(init);
  }
  return new ChecksumStream3(init);
}
var init_createChecksumStream2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/checksum/createChecksumStream.js"() {
    init_stream_type_check3();
    init_ChecksumStream2();
    init_createChecksumStream_browser2();
    __name(createChecksumStream4, "createChecksumStream");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/ByteArrayCollector.js
var ByteArrayCollector2;
var init_ByteArrayCollector2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/ByteArrayCollector.js"() {
    ByteArrayCollector2 = class {
      static {
        __name(this, "ByteArrayCollector");
      }
      allocByteArray;
      byteLength = 0;
      byteArrays = [];
      constructor(allocByteArray) {
        this.allocByteArray = allocByteArray;
      }
      push(byteArray) {
        this.byteArrays.push(byteArray);
        this.byteLength += byteArray.byteLength;
      }
      flush() {
        if (this.byteArrays.length === 1) {
          const bytes = this.byteArrays[0];
          this.reset();
          return bytes;
        }
        const aggregation = this.allocByteArray(this.byteLength);
        let cursor3 = 0;
        for (let i32 = 0; i32 < this.byteArrays.length; ++i32) {
          const bytes = this.byteArrays[i32];
          aggregation.set(bytes, cursor3);
          cursor3 += bytes.byteLength;
        }
        this.reset();
        return aggregation;
      }
      reset() {
        this.byteArrays = [];
        this.byteLength = 0;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/createBufferedReadable.browser.js
function createBufferedReadableStream2(upstream, size, logger5) {
  const reader = upstream.getReader();
  let streamBufferingLoggedWarning = false;
  let bytesSeen = 0;
  const buffers = ["", new ByteArrayCollector2((size2) => new Uint8Array(size2))];
  let mode = -1;
  const pull = /* @__PURE__ */ __name(async (controller) => {
    const { value, done } = await reader.read();
    const chunk = value;
    if (done) {
      if (mode !== -1) {
        const remainder = flush2(buffers, mode);
        if (sizeOf2(remainder) > 0) {
          controller.enqueue(remainder);
        }
      }
      controller.close();
    } else {
      const chunkMode = modeOf2(chunk, false);
      if (mode !== chunkMode) {
        if (mode >= 0) {
          controller.enqueue(flush2(buffers, mode));
        }
        mode = chunkMode;
      }
      if (mode === -1) {
        controller.enqueue(chunk);
        return;
      }
      const chunkSize = sizeOf2(chunk);
      bytesSeen += chunkSize;
      const bufferSize = sizeOf2(buffers[mode]);
      if (chunkSize >= size && bufferSize === 0) {
        controller.enqueue(chunk);
      } else {
        const newSize = merge2(buffers, mode, chunk);
        if (!streamBufferingLoggedWarning && bytesSeen > size * 2) {
          streamBufferingLoggedWarning = true;
          logger5?.warn(`@smithy/util-stream - stream chunk size ${chunkSize} is below threshold of ${size}, automatically buffering.`);
        }
        if (newSize >= size) {
          controller.enqueue(flush2(buffers, mode));
        } else {
          await pull(controller);
        }
      }
    }
  }, "pull");
  return new ReadableStream({
    pull
  });
}
function merge2(buffers, mode, chunk) {
  switch (mode) {
    case 0:
      buffers[0] += chunk;
      return sizeOf2(buffers[0]);
    case 1:
    case 2:
      buffers[mode].push(chunk);
      return sizeOf2(buffers[mode]);
  }
}
function flush2(buffers, mode) {
  switch (mode) {
    case 0:
      const s = buffers[0];
      buffers[0] = "";
      return s;
    case 1:
    case 2:
      return buffers[mode].flush();
  }
  throw new Error(`@smithy/util-stream - invalid index ${mode} given to flush()`);
}
function sizeOf2(chunk) {
  return chunk?.byteLength ?? chunk?.length ?? 0;
}
function modeOf2(chunk, allowBuffer = true) {
  if (allowBuffer && typeof Buffer !== "undefined" && chunk instanceof Buffer) {
    return 2;
  }
  if (chunk instanceof Uint8Array) {
    return 1;
  }
  if (typeof chunk === "string") {
    return 0;
  }
  return -1;
}
var init_createBufferedReadable_browser2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/createBufferedReadable.browser.js"() {
    init_ByteArrayCollector2();
    __name(createBufferedReadableStream2, "createBufferedReadableStream");
    __name(merge2, "merge");
    __name(flush2, "flush");
    __name(sizeOf2, "sizeOf");
    __name(modeOf2, "modeOf");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/createBufferedReadable.js
function createBufferedReadable2(upstream, size, logger5) {
  if (isReadableStream3(upstream)) {
    return createBufferedReadableStream2(upstream, size, logger5);
  }
  const downstream = new import_node_stream16.Readable({ read() {
  } });
  let streamBufferingLoggedWarning = false;
  let bytesSeen = 0;
  const buffers = [
    "",
    new ByteArrayCollector2((size2) => new Uint8Array(size2)),
    new ByteArrayCollector2((size2) => Buffer.from(new Uint8Array(size2)))
  ];
  let mode = -1;
  upstream.on("data", (chunk) => {
    const chunkMode = modeOf2(chunk, true);
    if (mode !== chunkMode) {
      if (mode >= 0) {
        downstream.push(flush2(buffers, mode));
      }
      mode = chunkMode;
    }
    if (mode === -1) {
      downstream.push(chunk);
      return;
    }
    const chunkSize = sizeOf2(chunk);
    bytesSeen += chunkSize;
    const bufferSize = sizeOf2(buffers[mode]);
    if (chunkSize >= size && bufferSize === 0) {
      downstream.push(chunk);
    } else {
      const newSize = merge2(buffers, mode, chunk);
      if (!streamBufferingLoggedWarning && bytesSeen > size * 2) {
        streamBufferingLoggedWarning = true;
        logger5?.warn(`@smithy/util-stream - stream chunk size ${chunkSize} is below threshold of ${size}, automatically buffering.`);
      }
      if (newSize >= size) {
        downstream.push(flush2(buffers, mode));
      }
    }
  });
  upstream.on("end", () => {
    if (mode !== -1) {
      const remainder = flush2(buffers, mode);
      if (sizeOf2(remainder) > 0) {
        downstream.push(remainder);
      }
    }
    downstream.push(null);
  });
  return downstream;
}
var import_node_stream16;
var init_createBufferedReadable2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/createBufferedReadable.js"() {
    import_node_stream16 = require("node:stream");
    init_ByteArrayCollector2();
    init_createBufferedReadable_browser2();
    init_stream_type_check3();
    __name(createBufferedReadable2, "createBufferedReadable");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/getAwsChunkedEncodingStream.browser.js
var getAwsChunkedEncodingStream3;
var init_getAwsChunkedEncodingStream_browser2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/getAwsChunkedEncodingStream.browser.js"() {
    getAwsChunkedEncodingStream3 = /* @__PURE__ */ __name((readableStream, options) => {
      const { base64Encoder, bodyLengthChecker, checksumAlgorithmFn, checksumLocationName, streamHasher } = options;
      const checksumRequired = base64Encoder !== void 0 && bodyLengthChecker !== void 0 && checksumAlgorithmFn !== void 0 && checksumLocationName !== void 0 && streamHasher !== void 0;
      const digest = checksumRequired ? streamHasher(checksumAlgorithmFn, readableStream) : void 0;
      const reader = readableStream.getReader();
      return new ReadableStream({
        async pull(controller) {
          const { value, done } = await reader.read();
          if (done) {
            controller.enqueue(`0\r
`);
            if (checksumRequired) {
              const checksum = base64Encoder(await digest);
              controller.enqueue(`${checksumLocationName}:${checksum}\r
`);
              controller.enqueue(`\r
`);
            }
            controller.close();
          } else {
            controller.enqueue(`${(bodyLengthChecker(value) || 0).toString(16)}\r
${value}\r
`);
          }
        }
      });
    }, "getAwsChunkedEncodingStream");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/getAwsChunkedEncodingStream.js
function getAwsChunkedEncodingStream4(stream, options) {
  const readable = stream;
  const readableStream = stream;
  if (isReadableStream3(readableStream)) {
    return getAwsChunkedEncodingStream3(readableStream, options);
  }
  const { base64Encoder, bodyLengthChecker, checksumAlgorithmFn, checksumLocationName, streamHasher } = options;
  const checksumRequired = base64Encoder !== void 0 && checksumAlgorithmFn !== void 0 && checksumLocationName !== void 0 && streamHasher !== void 0;
  const digest = checksumRequired ? streamHasher(checksumAlgorithmFn, readable) : void 0;
  const awsChunkedEncodingStream = new import_node_stream17.Readable({
    read: /* @__PURE__ */ __name(() => {
    }, "read")
  });
  readable.on("data", (data3) => {
    const length = bodyLengthChecker(data3) || 0;
    if (length === 0) {
      return;
    }
    awsChunkedEncodingStream.push(`${length.toString(16)}\r
`);
    awsChunkedEncodingStream.push(data3);
    awsChunkedEncodingStream.push("\r\n");
  });
  readable.on("end", async () => {
    awsChunkedEncodingStream.push(`0\r
`);
    if (checksumRequired) {
      const checksum = base64Encoder(await digest);
      awsChunkedEncodingStream.push(`${checksumLocationName}:${checksum}\r
`);
      awsChunkedEncodingStream.push(`\r
`);
    }
    awsChunkedEncodingStream.push(null);
  });
  return awsChunkedEncodingStream;
}
var import_node_stream17;
var init_getAwsChunkedEncodingStream2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/getAwsChunkedEncodingStream.js"() {
    import_node_stream17 = require("node:stream");
    init_getAwsChunkedEncodingStream_browser2();
    init_stream_type_check3();
    __name(getAwsChunkedEncodingStream4, "getAwsChunkedEncodingStream");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/headStream.browser.js
async function headStream3(stream, bytes) {
  let byteLengthCounter = 0;
  const chunks2 = [];
  const reader = stream.getReader();
  let isDone = false;
  while (!isDone) {
    const { done, value } = await reader.read();
    if (value) {
      chunks2.push(value);
      byteLengthCounter += value?.byteLength ?? 0;
    }
    if (byteLengthCounter >= bytes) {
      break;
    }
    isDone = done;
  }
  reader.releaseLock();
  const collected = new Uint8Array(Math.min(bytes, byteLengthCounter));
  let offset = 0;
  for (const chunk of chunks2) {
    if (chunk.byteLength > collected.byteLength - offset) {
      collected.set(chunk.subarray(0, collected.byteLength - offset), offset);
      break;
    } else {
      collected.set(chunk, offset);
    }
    offset += chunk.length;
  }
  return collected;
}
var init_headStream_browser2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/headStream.browser.js"() {
    __name(headStream3, "headStream");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/headStream.js
var import_node_stream18, headStream4, Collector4;
var init_headStream2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/headStream.js"() {
    import_node_stream18 = require("node:stream");
    init_headStream_browser2();
    init_stream_type_check3();
    headStream4 = /* @__PURE__ */ __name((stream, bytes) => {
      if (isReadableStream3(stream)) {
        return headStream3(stream, bytes);
      }
      return new Promise((resolve13, reject) => {
        const collector = new Collector4();
        collector.limit = bytes;
        stream.pipe(collector);
        stream.on("error", (err) => {
          collector.end();
          reject(err);
        });
        collector.on("error", reject);
        collector.on("finish", function() {
          const bytes2 = new Uint8Array(Buffer.concat(this.buffers));
          resolve13(bytes2);
        });
      });
    }, "headStream");
    Collector4 = class extends import_node_stream18.Writable {
      static {
        __name(this, "Collector");
      }
      buffers = [];
      limit = Infinity;
      bytesBuffered = 0;
      _write(chunk, encoding, callback) {
        this.buffers.push(chunk);
        this.bytesBuffered += chunk.byteLength ?? 0;
        if (this.bytesBuffered >= this.limit) {
          const excess = this.bytesBuffered - this.limit;
          const tailBuffer = this.buffers[this.buffers.length - 1];
          this.buffers[this.buffers.length - 1] = tailBuffer.subarray(0, tailBuffer.byteLength - excess);
          this.emit("finish");
        }
        callback();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/toUtf8.browser.js
var toUtf842;
var init_toUtf8_browser3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/toUtf8.browser.js"() {
    toUtf842 = /* @__PURE__ */ __name((input) => {
      if (typeof input === "string") {
        return input;
      }
      if (typeof input !== "object" || typeof input.byteOffset !== "number" || typeof input.byteLength !== "number") {
        throw new Error("@smithy/util-utf8: toUtf8 encoder function only accepts string | Uint8Array.");
      }
      return new TextDecoder("utf-8").decode(input);
    }, "toUtf8");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/fromBase64.browser.js
var fromBase6439;
var init_fromBase64_browser3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/fromBase64.browser.js"() {
    init_constants_for_browser3();
    fromBase6439 = /* @__PURE__ */ __name((input) => {
      let totalByteLength = input.length / 4 * 3;
      if (input.slice(-2) === "==") {
        totalByteLength -= 2;
      } else if (input.slice(-1) === "=") {
        totalByteLength--;
      }
      const out = new ArrayBuffer(totalByteLength);
      const dataView5 = new DataView(out);
      for (let i32 = 0; i32 < input.length; i32 += 4) {
        let bits = 0;
        let bitLength = 0;
        for (let j32 = i32, limit = i32 + 3; j32 <= limit; j32++) {
          if (input[j32] !== "=") {
            if (!(input[j32] in alphabetByEncoding3)) {
              throw new TypeError(`Invalid character ${input[j32]} in base64 string.`);
            }
            bits |= alphabetByEncoding3[input[j32]] << (limit - j32) * bitsPerLetter3;
            bitLength += bitsPerLetter3;
          } else {
            bits >>= bitsPerLetter3;
          }
        }
        const chunkOffset = i32 / 4 * 3;
        bits >>= bitLength % bitsPerByte3;
        const byteLength = Math.floor(bitLength / bitsPerByte3);
        for (let k32 = 0; k32 < byteLength; k32++) {
          const offset = (byteLength - k32 - 1) * bitsPerByte3;
          dataView5.setUint8(chunkOffset + k32, (bits & 255 << offset) >> offset);
        }
      }
      return new Uint8Array(out);
    }, "fromBase64");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-collector.browser.js
async function collectBlob3(blob) {
  const base64 = await readToBase643(blob);
  const arrayBuffer = fromBase6439(base64);
  return new Uint8Array(arrayBuffer);
}
async function collectStream3(stream) {
  const chunks2 = [];
  const reader = stream.getReader();
  let isDone = false;
  let length = 0;
  while (!isDone) {
    const { done, value } = await reader.read();
    if (value) {
      chunks2.push(value);
      length += value.length;
    }
    isDone = done;
  }
  const collected = new Uint8Array(length);
  let offset = 0;
  for (const chunk of chunks2) {
    collected.set(chunk, offset);
    offset += chunk.length;
  }
  return collected;
}
function readToBase643(blob) {
  return new Promise((resolve13, reject) => {
    const reader = new FileReader();
    reader.onloadend = () => {
      if (reader.readyState !== 2) {
        return reject(new Error("Reader aborted too early"));
      }
      const result2 = reader.result ?? "";
      const commaIndex = result2.indexOf(",");
      const dataOffset = commaIndex > -1 ? commaIndex + 1 : result2.length;
      resolve13(result2.substring(dataOffset));
    };
    reader.onabort = () => reject(new Error("Read aborted"));
    reader.onerror = () => reject(reader.error);
    reader.readAsDataURL(blob);
  });
}
var streamCollector23;
var init_stream_collector_browser3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-collector.browser.js"() {
    init_fromBase64_browser3();
    streamCollector23 = /* @__PURE__ */ __name(async (stream) => {
      if (typeof Blob === "function" && stream instanceof Blob || stream.constructor?.name === "Blob") {
        if (Blob.prototype.arrayBuffer !== void 0) {
          return new Uint8Array(await stream.arrayBuffer());
        }
        return collectBlob3(stream);
      }
      return collectStream3(stream);
    }, "streamCollector");
    __name(collectBlob3, "collectBlob");
    __name(collectStream3, "collectStream");
    __name(readToBase643, "readToBase64");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/sdk-stream-mixin.browser.js
var ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED5, sdkStreamMixin7, isBlobInstance3;
var init_sdk_stream_mixin_browser3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/sdk-stream-mixin.browser.js"() {
    init_toBase64_browser3();
    init_hex_encoding3();
    init_toUtf8_browser3();
    init_stream_collector_browser3();
    init_stream_type_check3();
    ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED5 = "The stream has already been transformed.";
    sdkStreamMixin7 = /* @__PURE__ */ __name((stream) => {
      if (!isBlobInstance3(stream) && !isReadableStream3(stream)) {
        const name = stream?.__proto__?.constructor?.name || stream;
        throw new Error(`Unexpected stream implementation, expect Blob or ReadableStream, got ${name}`);
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED5);
        }
        transformed = true;
        return await streamCollector23(stream);
      }, "transformToByteArray");
      const blobToWebStream = /* @__PURE__ */ __name((blob) => {
        if (typeof blob.stream !== "function") {
          throw new Error("Cannot transform payload Blob to web stream. Please make sure the Blob.stream() is polyfilled.\nIf you are using React Native, this API is not yet supported, see: https://react-native.canny.io/feature-requests/p/fetch-streaming-body");
        }
        return blob.stream();
      }, "blobToWebStream");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === "base64") {
            return toBase6444(buf);
          } else if (encoding === "hex") {
            return toHex3(buf);
          } else if (encoding === void 0 || encoding === "utf8" || encoding === "utf-8") {
            return toUtf842(buf);
          } else if (typeof TextDecoder === "function") {
            return new TextDecoder(encoding).decode(buf);
          } else {
            throw new Error("TextDecoder is not available, please make sure polyfill is provided.");
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED5);
          }
          transformed = true;
          if (isBlobInstance3(stream)) {
            return blobToWebStream(stream);
          } else if (isReadableStream3(stream)) {
            return stream;
          } else {
            throw new Error(`Cannot transform payload to web stream, got ${stream}`);
          }
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
    isBlobInstance3 = /* @__PURE__ */ __name((stream) => typeof Blob === "function" && stream instanceof Blob, "isBlobInstance");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-collector.js
async function collectReadableStream3(stream) {
  const chunks2 = [];
  const reader = stream.getReader();
  let isDone = false;
  let length = 0;
  while (!isDone) {
    const { done, value } = await reader.read();
    if (value) {
      chunks2.push(value);
      length += value.length;
    }
    isDone = done;
  }
  const collected = new Uint8Array(length);
  let offset = 0;
  for (const chunk of chunks2) {
    collected.set(chunk, offset);
    offset += chunk.length;
  }
  return collected;
}
var import_node_stream19, Collector5, isReadableStreamInstance3, streamCollector24;
var init_stream_collector3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-collector.js"() {
    import_node_stream19 = require("node:stream");
    Collector5 = class extends import_node_stream19.Writable {
      static {
        __name(this, "Collector");
      }
      bufferedBytes = [];
      _write(chunk, encoding, callback) {
        this.bufferedBytes.push(chunk);
        callback();
      }
    };
    isReadableStreamInstance3 = /* @__PURE__ */ __name((stream) => typeof ReadableStream === "function" && stream instanceof ReadableStream, "isReadableStreamInstance");
    __name(collectReadableStream3, "collectReadableStream");
    streamCollector24 = /* @__PURE__ */ __name((stream) => {
      if (isReadableStreamInstance3(stream)) {
        return collectReadableStream3(stream);
      }
      return new Promise((resolve13, reject) => {
        const collector = new Collector5();
        stream.pipe(collector);
        stream.on("error", (err) => {
          collector.end();
          reject(err);
        });
        collector.on("error", reject);
        collector.on("finish", function() {
          const bytes = new Uint8Array(Buffer.concat(this.bufferedBytes));
          resolve13(bytes);
        });
      });
    }, "streamCollector");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/sdk-stream-mixin.js
var import_node_stream20, ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED6, sdkStreamMixin6;
var init_sdk_stream_mixin3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/sdk-stream-mixin.js"() {
    import_node_stream20 = require("node:stream");
    init_buffer_from4();
    init_sdk_stream_mixin_browser3();
    init_stream_collector3();
    ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED6 = "The stream has already been transformed.";
    sdkStreamMixin6 = /* @__PURE__ */ __name((stream) => {
      if (!(stream instanceof import_node_stream20.Readable)) {
        try {
          return sdkStreamMixin7(stream);
        } catch (e32) {
          const name = stream?.__proto__?.constructor?.name || stream;
          throw new Error(`Unexpected stream implementation, expect Stream.Readable instance, got ${name}`);
        }
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED6);
        }
        transformed = true;
        return await streamCollector24(stream);
      }, "transformToByteArray");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === void 0 || Buffer.isEncoding(encoding)) {
            return fromArrayBuffer4(buf.buffer, buf.byteOffset, buf.byteLength).toString(encoding);
          } else {
            const decoder = new TextDecoder(encoding);
            return decoder.decode(buf);
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED6);
          }
          if (stream.readableFlowing !== null) {
            throw new Error("The stream has been consumed by other callbacks.");
          }
          if (typeof import_node_stream20.Readable.toWeb !== "function") {
            throw new Error("Readable.toWeb() is not supported. Please ensure a polyfill is available.");
          }
          transformed = true;
          return import_node_stream20.Readable.toWeb(stream);
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/splitStream.browser.js
async function splitStream3(stream) {
  if (typeof stream.stream === "function") {
    stream = stream.stream();
  }
  const readableStream = stream;
  return readableStream.tee();
}
var init_splitStream_browser2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/splitStream.browser.js"() {
    __name(splitStream3, "splitStream");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/splitStream.js
async function splitStream4(stream) {
  if (isReadableStream3(stream) || isBlob2(stream)) {
    return splitStream3(stream);
  }
  const stream1 = new import_node_stream21.PassThrough();
  const stream2 = new import_node_stream21.PassThrough();
  stream.pipe(stream1);
  stream.pipe(stream2);
  return [stream1, stream2];
}
var import_node_stream21;
var init_splitStream2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/splitStream.js"() {
    import_node_stream21 = require("node:stream");
    init_splitStream_browser2();
    init_stream_type_check3();
    __name(splitStream4, "splitStream");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/index.js
var serde_exports3 = {};
__export(serde_exports3, {
  ChecksumStream: () => ChecksumStream3,
  Hash: () => Hash20,
  LazyJsonString: () => LazyJsonString7,
  NumericValue: () => NumericValue4,
  Uint8ArrayBlobAdapter: () => Uint8ArrayBlobAdapter5,
  _parseEpochTimestamp: () => _parseEpochTimestamp4,
  _parseRfc3339DateTimeWithOffset: () => _parseRfc3339DateTimeWithOffset4,
  _parseRfc7231DateTime: () => _parseRfc7231DateTime4,
  calculateBodyLength: () => calculateBodyLength20,
  copyDocumentWithTransform: () => copyDocumentWithTransform3,
  createBufferedReadable: () => createBufferedReadable2,
  createChecksumStream: () => createChecksumStream4,
  dateToUtcString: () => dateToUtcString16,
  deserializerMiddleware: () => deserializerMiddleware2,
  deserializerMiddlewareOption: () => deserializerMiddlewareOption4,
  expectBoolean: () => expectBoolean3,
  expectByte: () => expectByte4,
  expectFloat32: () => expectFloat324,
  expectInt: () => expectInt3,
  expectInt32: () => expectInt323,
  expectLong: () => expectLong4,
  expectNonNull: () => expectNonNull3,
  expectNumber: () => expectNumber4,
  expectObject: () => expectObject3,
  expectShort: () => expectShort4,
  expectString: () => expectString4,
  expectUnion: () => expectUnion8,
  fromArrayBuffer: () => fromArrayBuffer4,
  fromBase64: () => fromBase6438,
  fromHex: () => fromHex3,
  fromString: () => fromString4,
  fromUtf8: () => fromUtf827,
  generateIdempotencyToken: () => generateIdempotencyToken4,
  getAwsChunkedEncodingStream: () => getAwsChunkedEncodingStream4,
  getSerdePlugin: () => getSerdePlugin2,
  handleFloat: () => handleFloat3,
  headStream: () => headStream4,
  isArrayBuffer: () => isArrayBuffer4,
  isBlob: () => isBlob2,
  isReadableStream: () => isReadableStream3,
  limitedParseDouble: () => limitedParseDouble3,
  limitedParseFloat: () => limitedParseFloat3,
  limitedParseFloat32: () => limitedParseFloat323,
  logger: () => logger4,
  nv: () => nv4,
  parseBoolean: () => parseBoolean3,
  parseEpochTimestamp: () => parseEpochTimestamp5,
  parseRfc3339DateTime: () => parseRfc3339DateTime5,
  parseRfc3339DateTimeWithOffset: () => parseRfc3339DateTimeWithOffset5,
  parseRfc7231DateTime: () => parseRfc7231DateTime5,
  quoteHeader: () => quoteHeader4,
  sdkStreamMixin: () => sdkStreamMixin6,
  serializerMiddleware: () => serializerMiddleware2,
  serializerMiddlewareOption: () => serializerMiddlewareOption7,
  splitEvery: () => splitEvery4,
  splitHeader: () => splitHeader4,
  splitStream: () => splitStream4,
  strictParseByte: () => strictParseByte4,
  strictParseDouble: () => strictParseDouble4,
  strictParseFloat: () => strictParseFloat3,
  strictParseFloat32: () => strictParseFloat324,
  strictParseInt: () => strictParseInt3,
  strictParseInt32: () => strictParseInt323,
  strictParseLong: () => strictParseLong3,
  strictParseShort: () => strictParseShort4,
  toBase64: () => toBase6443,
  toHex: () => toHex3,
  toUint8Array: () => toUint8Array3,
  toUtf8: () => toUtf841,
  v4: () => v44
});
var import_node_crypto12, Uint8ArrayBlobAdapter5, _getRandomValues4, v44, generateIdempotencyToken4;
var init_serde5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/node_modules/@smithy/core/dist-es/submodules/serde/index.js"() {
    import_node_crypto12 = require("node:crypto");
    init_fromBase644();
    init_toBase644();
    init_Uint8ArrayBlobAdapter4();
    init_fromUtf84();
    init_toUtf84();
    init_v44();
    init_copyDocumentWithTransform3();
    init_date_utils5();
    init_lazy_json4();
    init_parse_utils4();
    init_quote_header4();
    init_schema_date_utils4();
    init_split_every4();
    init_split_header4();
    init_NumericValue4();
    init_hex_encoding3();
    init_calculateBodyLength2();
    init_toUint8Array2();
    init_buffer_from4();
    init_is_array_buffer4();
    init_deserializerMiddleware2();
    init_serdePlugin2();
    init_serializerMiddleware2();
    init_hash_node2();
    init_ChecksumStream2();
    init_createChecksumStream2();
    init_createBufferedReadable2();
    init_getAwsChunkedEncodingStream2();
    init_headStream2();
    init_sdk_stream_mixin3();
    init_splitStream2();
    init_stream_type_check3();
    Uint8ArrayBlobAdapter5 = class extends bindUint8ArrayBlobAdapter4(toUtf841, fromUtf827, toBase6443, fromBase6438) {
      static {
        __name(this, "Uint8ArrayBlobAdapter");
      }
    };
    _getRandomValues4 = import_node_crypto12.getRandomValues;
    v44 = bindV44(_getRandomValues4);
    generateIdempotencyToken4 = v44;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/dist-cjs/index.js
var require_dist_cjs141 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/signature-v4/dist-cjs/index.js"(exports2) {
    "use strict";
    var serde = (init_serde5(), __toCommonJS(serde_exports3));
    var client = (init_client15(), __toCommonJS(client_exports11));
    var protocols = (init_protocols12(), __toCommonJS(protocols_exports9));
    var HeaderFormatter = class {
      static {
        __name(this, "HeaderFormatter");
      }
      format(headers) {
        const chunks2 = [];
        for (const headerName of Object.keys(headers)) {
          const bytes = serde.fromUtf8(headerName);
          chunks2.push(Uint8Array.from([bytes.byteLength]), bytes, this.formatHeaderValue(headers[headerName]));
        }
        const out = new Uint8Array(chunks2.reduce((carry, bytes) => carry + bytes.byteLength, 0));
        let position = 0;
        for (const chunk of chunks2) {
          out.set(chunk, position);
          position += chunk.byteLength;
        }
        return out;
      }
      formatHeaderValue(header) {
        switch (header.type) {
          case "boolean":
            return Uint8Array.from([header.value ? 0 : 1]);
          case "byte":
            return Uint8Array.from([2, header.value]);
          case "short":
            const shortView = new DataView(new ArrayBuffer(3));
            shortView.setUint8(0, 3);
            shortView.setInt16(1, header.value, false);
            return new Uint8Array(shortView.buffer);
          case "integer":
            const intView = new DataView(new ArrayBuffer(5));
            intView.setUint8(0, 4);
            intView.setInt32(1, header.value, false);
            return new Uint8Array(intView.buffer);
          case "long":
            const longBytes = new Uint8Array(9);
            longBytes[0] = 5;
            longBytes.set(header.value.bytes, 1);
            return longBytes;
          case "binary":
            const binView = new DataView(new ArrayBuffer(3 + header.value.byteLength));
            binView.setUint8(0, 6);
            binView.setUint16(1, header.value.byteLength, false);
            const binBytes = new Uint8Array(binView.buffer);
            binBytes.set(header.value, 3);
            return binBytes;
          case "string":
            const utf8Bytes = serde.fromUtf8(header.value);
            const strView = new DataView(new ArrayBuffer(3 + utf8Bytes.byteLength));
            strView.setUint8(0, 7);
            strView.setUint16(1, utf8Bytes.byteLength, false);
            const strBytes = new Uint8Array(strView.buffer);
            strBytes.set(utf8Bytes, 3);
            return strBytes;
          case "timestamp":
            const tsBytes = new Uint8Array(9);
            tsBytes[0] = 8;
            tsBytes.set(Int646.fromNumber(header.value.valueOf()).bytes, 1);
            return tsBytes;
          case "uuid":
            if (!UUID_PATTERN6.test(header.value)) {
              throw new Error(`Invalid UUID received: ${header.value}`);
            }
            const uuidBytes = new Uint8Array(17);
            uuidBytes[0] = 9;
            uuidBytes.set(serde.fromHex(header.value.replace(/\-/g, "")), 1);
            return uuidBytes;
        }
      }
    };
    var HEADER_VALUE_TYPE6;
    (function(HEADER_VALUE_TYPE7) {
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["boolTrue"] = 0] = "boolTrue";
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["boolFalse"] = 1] = "boolFalse";
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["byte"] = 2] = "byte";
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["short"] = 3] = "short";
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["integer"] = 4] = "integer";
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["long"] = 5] = "long";
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["byteArray"] = 6] = "byteArray";
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["string"] = 7] = "string";
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["timestamp"] = 8] = "timestamp";
      HEADER_VALUE_TYPE7[HEADER_VALUE_TYPE7["uuid"] = 9] = "uuid";
    })(HEADER_VALUE_TYPE6 || (HEADER_VALUE_TYPE6 = {}));
    var UUID_PATTERN6 = /^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$/;
    var Int646 = class _Int64 {
      static {
        __name(this, "Int64");
      }
      bytes;
      constructor(bytes) {
        this.bytes = bytes;
        if (bytes.byteLength !== 8) {
          throw new Error("Int64 buffers must be exactly 8 bytes");
        }
      }
      static fromNumber(number) {
        if (number > 9223372036854776e3 || number < -9223372036854776e3) {
          throw new Error(`${number} is too large (or, if negative, too small) to represent as an Int64`);
        }
        const bytes = new Uint8Array(8);
        for (let i32 = 7, remaining = Math.abs(Math.round(number)); i32 > -1 && remaining > 0; i32--, remaining /= 256) {
          bytes[i32] = remaining;
        }
        if (number < 0) {
          negate6(bytes);
        }
        return new _Int64(bytes);
      }
      valueOf() {
        const bytes = this.bytes.slice(0);
        const negative = bytes[0] & 128;
        if (negative) {
          negate6(bytes);
        }
        return parseInt(serde.toHex(bytes), 16) * (negative ? -1 : 1);
      }
      toString() {
        return String(this.valueOf());
      }
    };
    function negate6(bytes) {
      for (let i32 = 0; i32 < 8; i32++) {
        bytes[i32] ^= 255;
      }
      for (let i32 = 7; i32 > -1; i32--) {
        bytes[i32]++;
        if (bytes[i32] !== 0)
          break;
      }
    }
    __name(negate6, "negate");
    var ALGORITHM_QUERY_PARAM = "X-Amz-Algorithm";
    var CREDENTIAL_QUERY_PARAM = "X-Amz-Credential";
    var AMZ_DATE_QUERY_PARAM = "X-Amz-Date";
    var SIGNED_HEADERS_QUERY_PARAM = "X-Amz-SignedHeaders";
    var EXPIRES_QUERY_PARAM = "X-Amz-Expires";
    var SIGNATURE_QUERY_PARAM = "X-Amz-Signature";
    var TOKEN_QUERY_PARAM = "X-Amz-Security-Token";
    var REGION_SET_PARAM = "X-Amz-Region-Set";
    var AUTH_HEADER = "authorization";
    var AMZ_DATE_HEADER = AMZ_DATE_QUERY_PARAM.toLowerCase();
    var DATE_HEADER = "date";
    var GENERATED_HEADERS = [AUTH_HEADER, AMZ_DATE_HEADER, DATE_HEADER];
    var SIGNATURE_HEADER = SIGNATURE_QUERY_PARAM.toLowerCase();
    var SHA256_HEADER = "x-amz-content-sha256";
    var TOKEN_HEADER = TOKEN_QUERY_PARAM.toLowerCase();
    var HOST_HEADER = "host";
    var ALWAYS_UNSIGNABLE_HEADERS = {
      authorization: true,
      "cache-control": true,
      connection: true,
      expect: true,
      from: true,
      "keep-alive": true,
      "max-forwards": true,
      pragma: true,
      referer: true,
      te: true,
      trailer: true,
      "transfer-encoding": true,
      upgrade: true,
      "user-agent": true,
      "x-amzn-trace-id": true
    };
    var PROXY_HEADER_PATTERN = /^proxy-/;
    var SEC_HEADER_PATTERN = /^sec-/;
    var UNSIGNABLE_PATTERNS = [/^proxy-/i, /^sec-/i];
    var ALGORITHM_IDENTIFIER = "AWS4-HMAC-SHA256";
    var ALGORITHM_IDENTIFIER_V4A = "AWS4-ECDSA-P256-SHA256";
    var EVENT_ALGORITHM_IDENTIFIER = "AWS4-HMAC-SHA256-PAYLOAD";
    var UNSIGNED_PAYLOAD = "UNSIGNED-PAYLOAD";
    var MAX_CACHE_SIZE = 50;
    var KEY_TYPE_IDENTIFIER = "aws4_request";
    var MAX_PRESIGNED_TTL = 60 * 60 * 24 * 7;
    var getCanonicalQuery = /* @__PURE__ */ __name(({ query = {} }) => {
      const keys = [];
      const serialized = {};
      for (const key of Object.keys(query)) {
        if (key.toLowerCase() === SIGNATURE_HEADER) {
          continue;
        }
        const encodedKey = protocols.escapeUri(key);
        keys.push(encodedKey);
        const value = query[key];
        if (typeof value === "string") {
          serialized[encodedKey] = `${encodedKey}=${protocols.escapeUri(value)}`;
        } else if (Array.isArray(value)) {
          serialized[encodedKey] = value.slice(0).reduce((encoded, value2) => encoded.concat([`${encodedKey}=${protocols.escapeUri(value2)}`]), []).sort().join("&");
        }
      }
      return keys.sort().map((key) => serialized[key]).filter((serialized2) => serialized2).join("&");
    }, "getCanonicalQuery");
    var iso8601 = /* @__PURE__ */ __name((time7) => toDate(time7).toISOString().replace(/\.\d{3}Z$/, "Z"), "iso8601");
    var toDate = /* @__PURE__ */ __name((time7) => {
      if (typeof time7 === "number") {
        return new Date(time7 * 1e3);
      }
      if (typeof time7 === "string") {
        if (Number(time7)) {
          return new Date(Number(time7) * 1e3);
        }
        return new Date(time7);
      }
      return time7;
    }, "toDate");
    var SignatureV4Base = class {
      static {
        __name(this, "SignatureV4Base");
      }
      service;
      regionProvider;
      credentialProvider;
      sha256;
      uriEscapePath;
      applyChecksum;
      constructor({ applyChecksum, credentials, region, service, sha256, uriEscapePath = true }) {
        this.service = service;
        this.sha256 = sha256;
        this.uriEscapePath = uriEscapePath;
        this.applyChecksum = typeof applyChecksum === "boolean" ? applyChecksum : true;
        this.regionProvider = client.normalizeProvider(region);
        this.credentialProvider = client.normalizeProvider(credentials);
      }
      createCanonicalRequest(request4, canonicalHeaders, payloadHash) {
        const sortedHeaders = Object.keys(canonicalHeaders).sort();
        return `${request4.method}
${this.getCanonicalPath(request4)}
${getCanonicalQuery(request4)}
${sortedHeaders.map((name) => `${name}:${canonicalHeaders[name]}`).join("\n")}

${sortedHeaders.join(";")}
${payloadHash}`;
      }
      async createStringToSign(longDate, credentialScope, canonicalRequest, algorithmIdentifier) {
        const hash = new this.sha256();
        hash.update(serde.toUint8Array(canonicalRequest));
        const hashedRequest = await hash.digest();
        return `${algorithmIdentifier}
${longDate}
${credentialScope}
${serde.toHex(hashedRequest)}`;
      }
      getCanonicalPath({ path: path47 }) {
        if (this.uriEscapePath) {
          const normalizedPathSegments = [];
          for (const pathSegment of path47.split("/")) {
            if (pathSegment?.length === 0)
              continue;
            if (pathSegment === ".")
              continue;
            if (pathSegment === "..") {
              normalizedPathSegments.pop();
            } else {
              normalizedPathSegments.push(pathSegment);
            }
          }
          const normalizedPath = `${path47?.startsWith("/") ? "/" : ""}${normalizedPathSegments.join("/")}${normalizedPathSegments.length > 0 && path47?.endsWith("/") ? "/" : ""}`;
          const doubleEncoded = protocols.escapeUri(normalizedPath);
          return doubleEncoded.replace(/%2F/g, "/");
        }
        return path47;
      }
      validateResolvedCredentials(credentials) {
        if (typeof credentials !== "object" || typeof credentials.accessKeyId !== "string" || typeof credentials.secretAccessKey !== "string") {
          throw new Error("Resolved credential object is not valid");
        }
      }
      formatDate(now) {
        const longDate = iso8601(now).replace(/[\-:]/g, "");
        return {
          longDate,
          shortDate: longDate.slice(0, 8)
        };
      }
      getCanonicalHeaderList(headers) {
        return Object.keys(headers).sort().join(";");
      }
    };
    var signingKeyCache = {};
    var cacheQueue = [];
    var createScope = /* @__PURE__ */ __name((shortDate, region, service) => `${shortDate}/${region}/${service}/${KEY_TYPE_IDENTIFIER}`, "createScope");
    var getSigningKey = /* @__PURE__ */ __name(async (sha256Constructor, credentials, shortDate, region, service) => {
      const credsHash = await hmac(sha256Constructor, credentials.secretAccessKey, credentials.accessKeyId);
      const cacheKey = `${shortDate}:${region}:${service}:${serde.toHex(credsHash)}:${credentials.sessionToken}`;
      if (cacheKey in signingKeyCache) {
        return signingKeyCache[cacheKey];
      }
      cacheQueue.push(cacheKey);
      while (cacheQueue.length > MAX_CACHE_SIZE) {
        delete signingKeyCache[cacheQueue.shift()];
      }
      let key = `AWS4${credentials.secretAccessKey}`;
      for (const signable of [shortDate, region, service, KEY_TYPE_IDENTIFIER]) {
        key = await hmac(sha256Constructor, key, signable);
      }
      return signingKeyCache[cacheKey] = key;
    }, "getSigningKey");
    var clearCredentialCache = /* @__PURE__ */ __name(() => {
      cacheQueue.length = 0;
      Object.keys(signingKeyCache).forEach((cacheKey) => {
        delete signingKeyCache[cacheKey];
      });
    }, "clearCredentialCache");
    var hmac = /* @__PURE__ */ __name((ctor, secret, data3) => {
      const hash = new ctor(secret);
      hash.update(serde.toUint8Array(data3));
      return hash.digest();
    }, "hmac");
    var getCanonicalHeaders = /* @__PURE__ */ __name(({ headers }, unsignableHeaders, signableHeaders) => {
      const canonical = {};
      for (const headerName of Object.keys(headers).sort()) {
        if (headers[headerName] == void 0) {
          continue;
        }
        const canonicalHeaderName = headerName.toLowerCase();
        if (canonicalHeaderName in ALWAYS_UNSIGNABLE_HEADERS || unsignableHeaders?.has(canonicalHeaderName) || PROXY_HEADER_PATTERN.test(canonicalHeaderName) || SEC_HEADER_PATTERN.test(canonicalHeaderName)) {
          if (!signableHeaders || signableHeaders && !signableHeaders.has(canonicalHeaderName)) {
            continue;
          }
        }
        canonical[canonicalHeaderName] = headers[headerName].trim().replace(/\s+/g, " ");
      }
      return canonical;
    }, "getCanonicalHeaders");
    var getPayloadHash = /* @__PURE__ */ __name(async ({ headers, body }, hashConstructor) => {
      for (const headerName of Object.keys(headers)) {
        if (headerName.toLowerCase() === SHA256_HEADER) {
          return headers[headerName];
        }
      }
      if (body == void 0) {
        return "e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855";
      } else if (typeof body === "string" || ArrayBuffer.isView(body) || serde.isArrayBuffer(body)) {
        const hashCtor = new hashConstructor();
        hashCtor.update(serde.toUint8Array(body));
        return serde.toHex(await hashCtor.digest());
      }
      return UNSIGNED_PAYLOAD;
    }, "getPayloadHash");
    var hasHeader = /* @__PURE__ */ __name((soughtHeader, headers) => {
      soughtHeader = soughtHeader.toLowerCase();
      for (const headerName of Object.keys(headers)) {
        if (soughtHeader === headerName.toLowerCase()) {
          return true;
        }
      }
      return false;
    }, "hasHeader");
    var moveHeadersToQuery = /* @__PURE__ */ __name((request4, options = {}) => {
      const { headers, query = {} } = protocols.HttpRequest.clone(request4);
      for (const name of Object.keys(headers)) {
        const lname = name.toLowerCase();
        if (lname.slice(0, 6) === "x-amz-" && !options.unhoistableHeaders?.has(lname) || options.hoistableHeaders?.has(lname)) {
          query[name] = headers[name];
          delete headers[name];
        }
      }
      return {
        ...request4,
        headers,
        query
      };
    }, "moveHeadersToQuery");
    var prepareRequest = /* @__PURE__ */ __name((request4) => {
      request4 = protocols.HttpRequest.clone(request4);
      for (const headerName of Object.keys(request4.headers)) {
        if (GENERATED_HEADERS.indexOf(headerName.toLowerCase()) > -1) {
          delete request4.headers[headerName];
        }
      }
      return request4;
    }, "prepareRequest");
    var SignatureV411 = class extends SignatureV4Base {
      static {
        __name(this, "SignatureV4");
      }
      headerFormatter = new HeaderFormatter();
      constructor({ applyChecksum, credentials, region, service, sha256, uriEscapePath = true }) {
        super({
          applyChecksum,
          credentials,
          region,
          service,
          sha256,
          uriEscapePath
        });
      }
      async presign(originalRequest, options = {}) {
        const { signingDate = /* @__PURE__ */ new Date(), expiresIn = 3600, unsignableHeaders, unhoistableHeaders, signableHeaders, hoistableHeaders, signingRegion, signingService } = options;
        const credentials = await this.credentialProvider();
        this.validateResolvedCredentials(credentials);
        const region = signingRegion ?? await this.regionProvider();
        const { longDate, shortDate } = this.formatDate(signingDate);
        if (expiresIn > MAX_PRESIGNED_TTL) {
          return Promise.reject("Signature version 4 presigned URLs must have an expiration date less than one week in the future");
        }
        const scope = createScope(shortDate, region, signingService ?? this.service);
        const request4 = moveHeadersToQuery(prepareRequest(originalRequest), { unhoistableHeaders, hoistableHeaders });
        if (credentials.sessionToken) {
          request4.query[TOKEN_QUERY_PARAM] = credentials.sessionToken;
        }
        request4.query[ALGORITHM_QUERY_PARAM] = ALGORITHM_IDENTIFIER;
        request4.query[CREDENTIAL_QUERY_PARAM] = `${credentials.accessKeyId}/${scope}`;
        request4.query[AMZ_DATE_QUERY_PARAM] = longDate;
        request4.query[EXPIRES_QUERY_PARAM] = expiresIn.toString(10);
        const canonicalHeaders = getCanonicalHeaders(request4, unsignableHeaders, signableHeaders);
        request4.query[SIGNED_HEADERS_QUERY_PARAM] = this.getCanonicalHeaderList(canonicalHeaders);
        request4.query[SIGNATURE_QUERY_PARAM] = await this.getSignature(longDate, scope, this.getSigningKey(credentials, region, shortDate, signingService), this.createCanonicalRequest(request4, canonicalHeaders, await getPayloadHash(originalRequest, this.sha256)));
        return request4;
      }
      async sign(toSign, options) {
        if (typeof toSign === "string") {
          return this.signString(toSign, options);
        } else if (toSign.headers && toSign.payload) {
          return this.signEvent(toSign, options);
        } else if (toSign.message) {
          return this.signMessage(toSign, options);
        } else {
          return this.signRequest(toSign, options);
        }
      }
      async signEvent({ headers, payload: payload3 }, { signingDate = /* @__PURE__ */ new Date(), priorSignature, signingRegion, signingService, eventStreamCredentials }) {
        const region = signingRegion ?? await this.regionProvider();
        const { shortDate, longDate } = this.formatDate(signingDate);
        const scope = createScope(shortDate, region, signingService ?? this.service);
        const hashedPayload = await getPayloadHash({ headers: {}, body: payload3 }, this.sha256);
        const hash = new this.sha256();
        hash.update(headers);
        const hashedHeaders = serde.toHex(await hash.digest());
        const stringToSign = [
          EVENT_ALGORITHM_IDENTIFIER,
          longDate,
          scope,
          priorSignature,
          hashedHeaders,
          hashedPayload
        ].join("\n");
        return this.signString(stringToSign, {
          signingDate,
          signingRegion: region,
          signingService,
          eventStreamCredentials
        });
      }
      async signMessage(signableMessage, { signingDate = /* @__PURE__ */ new Date(), signingRegion, signingService, eventStreamCredentials }) {
        const promise = this.signEvent({
          headers: this.headerFormatter.format(signableMessage.message.headers),
          payload: signableMessage.message.body
        }, {
          signingDate,
          signingRegion,
          signingService,
          priorSignature: signableMessage.priorSignature,
          eventStreamCredentials
        });
        return promise.then((signature) => {
          return { message: signableMessage.message, signature };
        });
      }
      async signString(stringToSign, { signingDate = /* @__PURE__ */ new Date(), signingRegion, signingService, eventStreamCredentials } = {}) {
        const credentials = eventStreamCredentials ?? await this.credentialProvider();
        this.validateResolvedCredentials(credentials);
        const region = signingRegion ?? await this.regionProvider();
        const { shortDate } = this.formatDate(signingDate);
        const hash = new this.sha256(await this.getSigningKey(credentials, region, shortDate, signingService));
        hash.update(serde.toUint8Array(stringToSign));
        return serde.toHex(await hash.digest());
      }
      async signRequest(requestToSign, { signingDate = /* @__PURE__ */ new Date(), signableHeaders, unsignableHeaders, signingRegion, signingService } = {}) {
        const credentials = await this.credentialProvider();
        this.validateResolvedCredentials(credentials);
        const region = signingRegion ?? await this.regionProvider();
        const request4 = prepareRequest(requestToSign);
        const { longDate, shortDate } = this.formatDate(signingDate);
        const scope = createScope(shortDate, region, signingService ?? this.service);
        request4.headers[AMZ_DATE_HEADER] = longDate;
        if (credentials.sessionToken) {
          request4.headers[TOKEN_HEADER] = credentials.sessionToken;
        }
        const payloadHash = await getPayloadHash(request4, this.sha256);
        if (!hasHeader(SHA256_HEADER, request4.headers) && this.applyChecksum) {
          request4.headers[SHA256_HEADER] = payloadHash;
        }
        const canonicalHeaders = getCanonicalHeaders(request4, unsignableHeaders, signableHeaders);
        const signature = await this.getSignature(longDate, scope, this.getSigningKey(credentials, region, shortDate, signingService), this.createCanonicalRequest(request4, canonicalHeaders, payloadHash));
        request4.headers[AUTH_HEADER] = `${ALGORITHM_IDENTIFIER} Credential=${credentials.accessKeyId}/${scope}, SignedHeaders=${this.getCanonicalHeaderList(canonicalHeaders)}, Signature=${signature}`;
        return request4;
      }
      async getSignature(longDate, credentialScope, keyPromise, canonicalRequest) {
        const stringToSign = await this.createStringToSign(longDate, credentialScope, canonicalRequest, ALGORITHM_IDENTIFIER);
        const hash = new this.sha256(await keyPromise);
        hash.update(serde.toUint8Array(stringToSign));
        return serde.toHex(await hash.digest());
      }
      getSigningKey(credentials, region, shortDate, service) {
        return getSigningKey(this.sha256, credentials, shortDate, region, service || this.service);
      }
    };
    var signatureV4aContainer = {
      SignatureV4a: null
    };
    exports2.ALGORITHM_IDENTIFIER = ALGORITHM_IDENTIFIER;
    exports2.ALGORITHM_IDENTIFIER_V4A = ALGORITHM_IDENTIFIER_V4A;
    exports2.ALGORITHM_QUERY_PARAM = ALGORITHM_QUERY_PARAM;
    exports2.ALWAYS_UNSIGNABLE_HEADERS = ALWAYS_UNSIGNABLE_HEADERS;
    exports2.AMZ_DATE_HEADER = AMZ_DATE_HEADER;
    exports2.AMZ_DATE_QUERY_PARAM = AMZ_DATE_QUERY_PARAM;
    exports2.AUTH_HEADER = AUTH_HEADER;
    exports2.CREDENTIAL_QUERY_PARAM = CREDENTIAL_QUERY_PARAM;
    exports2.DATE_HEADER = DATE_HEADER;
    exports2.EVENT_ALGORITHM_IDENTIFIER = EVENT_ALGORITHM_IDENTIFIER;
    exports2.EXPIRES_QUERY_PARAM = EXPIRES_QUERY_PARAM;
    exports2.GENERATED_HEADERS = GENERATED_HEADERS;
    exports2.HOST_HEADER = HOST_HEADER;
    exports2.KEY_TYPE_IDENTIFIER = KEY_TYPE_IDENTIFIER;
    exports2.MAX_CACHE_SIZE = MAX_CACHE_SIZE;
    exports2.MAX_PRESIGNED_TTL = MAX_PRESIGNED_TTL;
    exports2.PROXY_HEADER_PATTERN = PROXY_HEADER_PATTERN;
    exports2.REGION_SET_PARAM = REGION_SET_PARAM;
    exports2.SEC_HEADER_PATTERN = SEC_HEADER_PATTERN;
    exports2.SHA256_HEADER = SHA256_HEADER;
    exports2.SIGNATURE_HEADER = SIGNATURE_HEADER;
    exports2.SIGNATURE_QUERY_PARAM = SIGNATURE_QUERY_PARAM;
    exports2.SIGNED_HEADERS_QUERY_PARAM = SIGNED_HEADERS_QUERY_PARAM;
    exports2.SignatureV4 = SignatureV411;
    exports2.SignatureV4Base = SignatureV4Base;
    exports2.TOKEN_HEADER = TOKEN_HEADER;
    exports2.TOKEN_QUERY_PARAM = TOKEN_QUERY_PARAM;
    exports2.UNSIGNABLE_PATTERNS = UNSIGNABLE_PATTERNS;
    exports2.UNSIGNED_PAYLOAD = UNSIGNED_PAYLOAD;
    exports2.clearCredentialCache = clearCredentialCache;
    exports2.createScope = createScope;
    exports2.getCanonicalHeaders = getCanonicalHeaders;
    exports2.getCanonicalQuery = getCanonicalQuery;
    exports2.getPayloadHash = getPayloadHash;
    exports2.getSigningKey = getSigningKey;
    exports2.hasHeader = hasHeader;
    exports2.moveHeadersToQuery = moveHeadersToQuery;
    exports2.prepareRequest = prepareRequest;
    exports2.signatureV4aContainer = signatureV4aContainer;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4Config.js
function normalizeCredentialProvider7(config2, { credentials, credentialDefaultProvider }) {
  let credentialsProvider;
  if (credentials) {
    if (!credentials?.memoized) {
      credentialsProvider = memoizeIdentityProvider2(credentials, isIdentityExpired2, doesIdentityRequireRefresh2);
    } else {
      credentialsProvider = credentials;
    }
  } else {
    if (credentialDefaultProvider) {
      credentialsProvider = normalizeProvider23(credentialDefaultProvider(Object.assign({}, config2, {
        parentClientConfig: config2
      })));
    } else {
      credentialsProvider = /* @__PURE__ */ __name(async () => {
        throw new Error("@aws-sdk/core::resolveAwsSdkSigV4Config - `credentials` not provided and no credentialDefaultProvider was configured.");
      }, "credentialsProvider");
    }
  }
  credentialsProvider.memoized = true;
  return credentialsProvider;
}
function bindCallerConfig7(config2, credentialsProvider) {
  if (credentialsProvider.configBound) {
    return credentialsProvider;
  }
  const fn = /* @__PURE__ */ __name(async (options) => credentialsProvider({ ...options, callerClientConfig: config2 }), "fn");
  fn.memoized = credentialsProvider.memoized;
  fn.configBound = true;
  return fn;
}
var import_signature_v47, resolveAwsSdkSigV4Config7, resolveAWSSDKSigV4Config7;
var init_resolveAwsSdkSigV4Config7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4Config.js"() {
    init_client13();
    init_dist_es2();
    import_signature_v47 = __toESM(require_dist_cjs141());
    resolveAwsSdkSigV4Config7 = /* @__PURE__ */ __name((config2) => {
      let inputCredentials = config2.credentials;
      let isUserSupplied = !!config2.credentials;
      let resolvedCredentials = void 0;
      Object.defineProperty(config2, "credentials", {
        set(credentials) {
          if (credentials && credentials !== inputCredentials && credentials !== resolvedCredentials) {
            isUserSupplied = true;
          }
          inputCredentials = credentials;
          const memoizedProvider = normalizeCredentialProvider7(config2, {
            credentials: inputCredentials,
            credentialDefaultProvider: config2.credentialDefaultProvider
          });
          const boundProvider = bindCallerConfig7(config2, memoizedProvider);
          if (isUserSupplied && !boundProvider.attributed) {
            const isCredentialObject = typeof inputCredentials === "object" && inputCredentials !== null;
            resolvedCredentials = /* @__PURE__ */ __name(async (options) => {
              const creds = await boundProvider(options);
              const attributedCreds = creds;
              if (isCredentialObject && (!attributedCreds.$source || Object.keys(attributedCreds.$source).length === 0)) {
                return setCredentialFeature9(attributedCreds, "CREDENTIALS_CODE", "e");
              }
              return attributedCreds;
            }, "resolvedCredentials");
            resolvedCredentials.memoized = boundProvider.memoized;
            resolvedCredentials.configBound = boundProvider.configBound;
            resolvedCredentials.attributed = true;
          } else {
            resolvedCredentials = boundProvider;
          }
        },
        get() {
          return resolvedCredentials;
        },
        enumerable: true,
        configurable: true
      });
      config2.credentials = inputCredentials;
      const { signingEscapePath = true, systemClockOffset = config2.systemClockOffset || 0, sha256 } = config2;
      let signer;
      if (config2.signer) {
        signer = normalizeProvider23(config2.signer);
      } else if (config2.regionInfoProvider) {
        signer = /* @__PURE__ */ __name(() => normalizeProvider23(config2.region)().then(async (region) => [
          await config2.regionInfoProvider(region, {
            useFipsEndpoint: await config2.useFipsEndpoint(),
            useDualstackEndpoint: await config2.useDualstackEndpoint()
          }) || {},
          region
        ]).then(([regionInfo, region]) => {
          const { signingRegion, signingService } = regionInfo;
          config2.signingRegion = config2.signingRegion || signingRegion || region;
          config2.signingName = config2.signingName || signingService || config2.serviceId;
          const params = {
            ...config2,
            credentials: config2.credentials,
            region: config2.signingRegion,
            service: config2.signingName,
            sha256,
            uriEscapePath: signingEscapePath
          };
          const SignerCtor = config2.signerConstructor || import_signature_v47.SignatureV4;
          return new SignerCtor(params);
        }), "signer");
      } else {
        signer = /* @__PURE__ */ __name(async (authScheme) => {
          authScheme = Object.assign({}, {
            name: "sigv4",
            signingName: config2.signingName || config2.defaultSigningName,
            signingRegion: await normalizeProvider23(config2.region)(),
            properties: {}
          }, authScheme);
          const signingRegion = authScheme.signingRegion;
          const signingService = authScheme.signingName;
          config2.signingRegion = config2.signingRegion || signingRegion;
          config2.signingName = config2.signingName || signingService || config2.serviceId;
          const params = {
            ...config2,
            credentials: config2.credentials,
            region: config2.signingRegion,
            service: config2.signingName,
            sha256,
            uriEscapePath: signingEscapePath
          };
          const SignerCtor = config2.signerConstructor || import_signature_v47.SignatureV4;
          return new SignerCtor(params);
        }, "signer");
      }
      const resolvedConfig = Object.assign(config2, {
        systemClockOffset,
        signingEscapePath,
        signer
      });
      return resolvedConfig;
    }, "resolveAwsSdkSigV4Config");
    resolveAWSSDKSigV4Config7 = resolveAwsSdkSigV4Config7;
    __name(normalizeCredentialProvider7, "normalizeCredentialProvider");
    __name(bindCallerConfig7, "bindCallerConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/index.js
var init_aws_sdk7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/index.js"() {
    init_AwsSdkSigV4Signer7();
    init_AwsSdkSigV4ASigner7();
    init_NODE_AUTH_SCHEME_PREFERENCE_OPTIONS7();
    init_resolveAwsSdkSigV4AConfig7();
    init_resolveAwsSdkSigV4Config7();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/index.js
var httpAuthSchemes_exports7 = {};
__export(httpAuthSchemes_exports7, {
  AWSSDKSigV4Signer: () => AWSSDKSigV4Signer7,
  AwsSdkSigV4ASigner: () => AwsSdkSigV4ASigner7,
  AwsSdkSigV4Signer: () => AwsSdkSigV4Signer7,
  NODE_AUTH_SCHEME_PREFERENCE_OPTIONS: () => NODE_AUTH_SCHEME_PREFERENCE_OPTIONS7,
  NODE_SIGV4A_CONFIG_OPTIONS: () => NODE_SIGV4A_CONFIG_OPTIONS7,
  getBearerTokenEnvKey: () => getBearerTokenEnvKey7,
  resolveAWSSDKSigV4Config: () => resolveAWSSDKSigV4Config7,
  resolveAwsSdkSigV4AConfig: () => resolveAwsSdkSigV4AConfig7,
  resolveAwsSdkSigV4Config: () => resolveAwsSdkSigV4Config7,
  validateSigningProperties: () => validateSigningProperties7
});
var init_httpAuthSchemes9 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/index.js"() {
    init_aws_sdk7();
    init_getBearerTokenEnvKey7();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/dist-cjs/auth/httpAuthSchemeProvider.js
var require_httpAuthSchemeProvider6 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/dist-cjs/auth/httpAuthSchemeProvider.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.resolveHttpAuthSchemeConfig = exports2.defaultAppSyncHttpAuthSchemeProvider = exports2.defaultAppSyncHttpAuthSchemeParametersProvider = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes9(), __toCommonJS(httpAuthSchemes_exports7));
    var client_1 = (init_client12(), __toCommonJS(client_exports9));
    var defaultAppSyncHttpAuthSchemeParametersProvider = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, client_1.getSmithyContext)(context).operation,
        region: await (0, client_1.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultAppSyncHttpAuthSchemeParametersProvider");
    exports2.defaultAppSyncHttpAuthSchemeParametersProvider = defaultAppSyncHttpAuthSchemeParametersProvider;
    function createAwsAuthSigv4HttpAuthOption32(authParameters) {
      return {
        schemeId: "aws.auth#sigv4",
        signingProperties: {
          name: "appsync",
          region: authParameters.region
        },
        propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
          signingProperties: {
            config: config2,
            context
          }
        }), "propertiesExtractor")
      };
    }
    __name(createAwsAuthSigv4HttpAuthOption32, "createAwsAuthSigv4HttpAuthOption");
    var defaultAppSyncHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption32(authParameters));
        }
      }
      return options;
    }, "defaultAppSyncHttpAuthSchemeProvider");
    exports2.defaultAppSyncHttpAuthSchemeProvider = defaultAppSyncHttpAuthSchemeProvider;
    var resolveHttpAuthSchemeConfig32 = /* @__PURE__ */ __name((config2) => {
      const config_0 = (0, httpAuthSchemes_1.resolveAwsSdkSigV4Config)(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, client_1.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
    exports2.resolveHttpAuthSchemeConfig = resolveHttpAuthSchemeConfig32;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/package.json
var require_package6 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/package.json"(exports2, module2) {
    module2.exports = {
      name: "@aws-sdk/client-appsync",
      description: "AWS SDK for JavaScript Appsync Client for Node.js, Browser and React Native",
      version: "3.1048.0",
      scripts: {
        build: "concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline client-appsync",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        "extract:docs": "api-extractor run --local",
        "generate:client": "node ../../scripts/generate-clients/single-service --solo appsync",
        "test:index": "tsc --noEmit ./test/index-types.ts && node ./test/index-objects.spec.mjs"
      },
      main: "./dist-cjs/index.js",
      types: "./dist-types/index.d.ts",
      module: "./dist-es/index.js",
      sideEffects: false,
      dependencies: {
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.11",
        "@aws-sdk/credential-provider-node": "^3.972.42",
        "@aws-sdk/types": "^3.973.8",
        "@smithy/core": "^3.24.2",
        "@smithy/fetch-http-handler": "^5.4.2",
        "@smithy/node-http-handler": "^4.7.2",
        "@smithy/types": "^4.14.1",
        tslib: "^2.6.2"
      },
      devDependencies: {
        "@tsconfig/node20": "20.1.8",
        "@types/node": "^20.14.8",
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3"
      },
      engines: {
        node: ">=20.0.0"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "dist-*/**"
      ],
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      browser: {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.browser"
      },
      "react-native": {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.native"
      },
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/clients/client-appsync",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "clients/client-appsync"
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-env/dist-cjs/index.js
var require_dist_cjs142 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-env/dist-cjs/index.js"(exports2) {
    "use strict";
    var client = (init_client13(), __toCommonJS(client_exports10));
    var config2 = (init_config4(), __toCommonJS(config_exports));
    var ENV_KEY = "AWS_ACCESS_KEY_ID";
    var ENV_SECRET = "AWS_SECRET_ACCESS_KEY";
    var ENV_SESSION = "AWS_SESSION_TOKEN";
    var ENV_EXPIRATION = "AWS_CREDENTIAL_EXPIRATION";
    var ENV_CREDENTIAL_SCOPE = "AWS_CREDENTIAL_SCOPE";
    var ENV_ACCOUNT_ID = "AWS_ACCOUNT_ID";
    var fromEnv6 = /* @__PURE__ */ __name((init) => async () => {
      init?.logger?.debug("@aws-sdk/credential-provider-env - fromEnv");
      const accessKeyId = process.env[ENV_KEY];
      const secretAccessKey = process.env[ENV_SECRET];
      const sessionToken = process.env[ENV_SESSION];
      const expiry = process.env[ENV_EXPIRATION];
      const credentialScope = process.env[ENV_CREDENTIAL_SCOPE];
      const accountId = process.env[ENV_ACCOUNT_ID];
      if (accessKeyId && secretAccessKey) {
        const credentials = {
          accessKeyId,
          secretAccessKey,
          ...sessionToken && { sessionToken },
          ...expiry && { expiration: new Date(expiry) },
          ...credentialScope && { credentialScope },
          ...accountId && { accountId }
        };
        client.setCredentialFeature(credentials, "CREDENTIALS_ENV_VARS", "g");
        return credentials;
      }
      throw new config2.CredentialsProviderError("Unable to find environment variable credentials.", { logger: init?.logger });
    }, "fromEnv");
    exports2.ENV_ACCOUNT_ID = ENV_ACCOUNT_ID;
    exports2.ENV_CREDENTIAL_SCOPE = ENV_CREDENTIAL_SCOPE;
    exports2.ENV_EXPIRATION = ENV_EXPIRATION;
    exports2.ENV_KEY = ENV_KEY;
    exports2.ENV_SECRET = ENV_SECRET;
    exports2.ENV_SESSION = ENV_SESSION;
    exports2.fromEnv = fromEnv6;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/property-provider/ProviderError.js
var ProviderError10;
var init_ProviderError4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/property-provider/ProviderError.js"() {
    ProviderError10 = class _ProviderError extends Error {
      static {
        __name(this, "ProviderError");
      }
      name = "ProviderError";
      tryNextLink;
      constructor(message2, options = true) {
        let logger5;
        let tryNextLink = true;
        if (typeof options === "boolean") {
          logger5 = void 0;
          tryNextLink = options;
        } else if (options != null && typeof options === "object") {
          logger5 = options.logger;
          tryNextLink = options.tryNextLink ?? true;
        }
        super(message2);
        this.tryNextLink = tryNextLink;
        Object.setPrototypeOf(this, _ProviderError.prototype);
        logger5?.debug?.(`@smithy/property-provider ${tryNextLink ? "->" : "(!)"} ${message2}`);
      }
      static from(error4, options = true) {
        return Object.assign(new this(error4.message, options), error4);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/property-provider/CredentialsProviderError.js
var CredentialsProviderError4;
var init_CredentialsProviderError4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/property-provider/CredentialsProviderError.js"() {
    init_ProviderError4();
    CredentialsProviderError4 = class _CredentialsProviderError extends ProviderError10 {
      static {
        __name(this, "CredentialsProviderError");
      }
      name = "CredentialsProviderError";
      constructor(message2, options = true) {
        super(message2, options);
        Object.setPrototypeOf(this, _CredentialsProviderError.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/property-provider/TokenProviderError.js
var TokenProviderError2;
var init_TokenProviderError2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/property-provider/TokenProviderError.js"() {
    init_ProviderError4();
    TokenProviderError2 = class _TokenProviderError extends ProviderError10 {
      static {
        __name(this, "TokenProviderError");
      }
      name = "TokenProviderError";
      constructor(message2, options = true) {
        super(message2, options);
        Object.setPrototypeOf(this, _TokenProviderError.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/property-provider/chain.js
var chain4;
var init_chain4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/property-provider/chain.js"() {
    init_ProviderError4();
    chain4 = /* @__PURE__ */ __name((...providers) => async () => {
      if (providers.length === 0) {
        throw new ProviderError10("No providers in chain");
      }
      let lastProviderError;
      for (const provider of providers) {
        try {
          const credentials = await provider();
          return credentials;
        } catch (err) {
          lastProviderError = err;
          if (err?.tryNextLink) {
            continue;
          }
          throw err;
        }
      }
      throw lastProviderError;
    }, "chain");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/property-provider/fromValue.js
var fromValue4;
var init_fromValue4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/property-provider/fromValue.js"() {
    fromValue4 = /* @__PURE__ */ __name((staticValue) => () => Promise.resolve(staticValue), "fromValue");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/property-provider/memoize.js
var memoize4;
var init_memoize4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/property-provider/memoize.js"() {
    memoize4 = /* @__PURE__ */ __name((provider, isExpired, requiresRefresh) => {
      let resolved;
      let pending;
      let hasResult;
      let isConstant = false;
      const coalesceProvider = /* @__PURE__ */ __name(async () => {
        if (!pending) {
          pending = provider();
        }
        try {
          resolved = await pending;
          hasResult = true;
          isConstant = false;
        } finally {
          pending = void 0;
        }
        return resolved;
      }, "coalesceProvider");
      if (isExpired === void 0) {
        return async (options) => {
          if (!hasResult || options?.forceRefresh) {
            resolved = await coalesceProvider();
          }
          return resolved;
        };
      }
      return async (options) => {
        if (!hasResult || options?.forceRefresh) {
          resolved = await coalesceProvider();
        }
        if (isConstant) {
          return resolved;
        }
        if (requiresRefresh && !requiresRefresh(resolved)) {
          isConstant = true;
          return resolved;
        }
        if (isExpired(resolved)) {
          await coalesceProvider();
          return resolved;
        }
        return resolved;
      };
    }, "memoize");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/util-config-provider/booleanSelector.js
var booleanSelector2;
var init_booleanSelector2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/util-config-provider/booleanSelector.js"() {
    booleanSelector2 = /* @__PURE__ */ __name((obj, key, type) => {
      if (!(key in obj))
        return void 0;
      if (obj[key] === "true")
        return true;
      if (obj[key] === "false")
        return false;
      throw new Error(`Cannot load ${type} "${key}". Expected "true" or "false", got ${obj[key]}.`);
    }, "booleanSelector");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/util-config-provider/numberSelector.js
var numberSelector2;
var init_numberSelector2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/util-config-provider/numberSelector.js"() {
    numberSelector2 = /* @__PURE__ */ __name((obj, key, type) => {
      if (!(key in obj))
        return void 0;
      const numberValue = parseInt(obj[key], 10);
      if (Number.isNaN(numberValue)) {
        throw new TypeError(`Cannot load ${type} '${key}'. Expected number, got '${obj[key]}'.`);
      }
      return numberValue;
    }, "numberSelector");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/util-config-provider/types.js
var SelectorType2;
var init_types10 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/util-config-provider/types.js"() {
    (function(SelectorType3) {
      SelectorType3["ENV"] = "env";
      SelectorType3["CONFIG"] = "shared config entry";
    })(SelectorType2 || (SelectorType2 = {}));
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getHomeDir.js
var import_node_os5, import_node_path16, homeDirCache4, getHomeDirCacheKey4, getHomeDir4;
var init_getHomeDir4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getHomeDir.js"() {
    import_node_os5 = require("node:os");
    import_node_path16 = require("node:path");
    homeDirCache4 = {};
    getHomeDirCacheKey4 = /* @__PURE__ */ __name(() => {
      if (process && process.geteuid) {
        return `${process.geteuid()}`;
      }
      return "DEFAULT";
    }, "getHomeDirCacheKey");
    getHomeDir4 = /* @__PURE__ */ __name(() => {
      const { HOME, USERPROFILE, HOMEPATH, HOMEDRIVE = `C:${import_node_path16.sep}` } = process.env;
      if (HOME)
        return HOME;
      if (USERPROFILE)
        return USERPROFILE;
      if (HOMEPATH)
        return `${HOMEDRIVE}${HOMEPATH}`;
      const homeDirCacheKey = getHomeDirCacheKey4();
      if (!homeDirCache4[homeDirCacheKey])
        homeDirCache4[homeDirCacheKey] = (0, import_node_os5.homedir)();
      return homeDirCache4[homeDirCacheKey];
    }, "getHomeDir");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getProfileName.js
var ENV_PROFILE4, DEFAULT_PROFILE4, getProfileName4;
var init_getProfileName4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getProfileName.js"() {
    ENV_PROFILE4 = "AWS_PROFILE";
    DEFAULT_PROFILE4 = "default";
    getProfileName4 = /* @__PURE__ */ __name((init) => init.profile || process.env[ENV_PROFILE4] || DEFAULT_PROFILE4, "getProfileName");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getSSOTokenFilepath.js
var import_node_crypto13, import_node_path17, getSSOTokenFilepath2;
var init_getSSOTokenFilepath2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getSSOTokenFilepath.js"() {
    import_node_crypto13 = require("node:crypto");
    import_node_path17 = require("node:path");
    init_getHomeDir4();
    getSSOTokenFilepath2 = /* @__PURE__ */ __name((id) => {
      const hasher = (0, import_node_crypto13.createHash)("sha1");
      const cacheName = hasher.update(id).digest("hex");
      return (0, import_node_path17.join)(getHomeDir4(), ".aws", "sso", "cache", `${cacheName}.json`);
    }, "getSSOTokenFilepath");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getSSOTokenFromFile.js
var import_promises6, tokenIntercept2, getSSOTokenFromFile2;
var init_getSSOTokenFromFile2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getSSOTokenFromFile.js"() {
    import_promises6 = require("node:fs/promises");
    init_getSSOTokenFilepath2();
    tokenIntercept2 = {};
    getSSOTokenFromFile2 = /* @__PURE__ */ __name(async (id) => {
      if (tokenIntercept2[id]) {
        return tokenIntercept2[id];
      }
      const ssoTokenFilepath = getSSOTokenFilepath2(id);
      const ssoTokenText = await (0, import_promises6.readFile)(ssoTokenFilepath, "utf8");
      return JSON.parse(ssoTokenText);
    }, "getSSOTokenFromFile");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/constants.js
var CONFIG_PREFIX_SEPARATOR4;
var init_constants12 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/constants.js"() {
    CONFIG_PREFIX_SEPARATOR4 = ".";
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getConfigData.js
var import_types51, getConfigData4;
var init_getConfigData4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getConfigData.js"() {
    import_types51 = __toESM(require_dist_cjs());
    init_constants12();
    getConfigData4 = /* @__PURE__ */ __name((data3) => Object.entries(data3).filter(([key]) => {
      const indexOfSeparator = key.indexOf(CONFIG_PREFIX_SEPARATOR4);
      if (indexOfSeparator === -1) {
        return false;
      }
      return Object.values(import_types51.IniSectionType).includes(key.substring(0, indexOfSeparator));
    }).reduce((acc, [key, value]) => {
      const indexOfSeparator = key.indexOf(CONFIG_PREFIX_SEPARATOR4);
      const updatedKey = key.substring(0, indexOfSeparator) === import_types51.IniSectionType.PROFILE ? key.substring(indexOfSeparator + 1) : key;
      acc[updatedKey] = value;
      return acc;
    }, {
      ...data3.default && { default: data3.default }
    }), "getConfigData");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getConfigFilepath.js
var import_node_path18, ENV_CONFIG_PATH4, getConfigFilepath4;
var init_getConfigFilepath4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getConfigFilepath.js"() {
    import_node_path18 = require("node:path");
    init_getHomeDir4();
    ENV_CONFIG_PATH4 = "AWS_CONFIG_FILE";
    getConfigFilepath4 = /* @__PURE__ */ __name(() => process.env[ENV_CONFIG_PATH4] || (0, import_node_path18.join)(getHomeDir4(), ".aws", "config"), "getConfigFilepath");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getCredentialsFilepath.js
var import_node_path19, ENV_CREDENTIALS_PATH4, getCredentialsFilepath4;
var init_getCredentialsFilepath4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getCredentialsFilepath.js"() {
    import_node_path19 = require("node:path");
    init_getHomeDir4();
    ENV_CREDENTIALS_PATH4 = "AWS_SHARED_CREDENTIALS_FILE";
    getCredentialsFilepath4 = /* @__PURE__ */ __name(() => process.env[ENV_CREDENTIALS_PATH4] || (0, import_node_path19.join)(getHomeDir4(), ".aws", "credentials"), "getCredentialsFilepath");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/parseIni.js
var import_types52, prefixKeyRegex4, profileNameBlockList4, parseIni4;
var init_parseIni4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/parseIni.js"() {
    import_types52 = __toESM(require_dist_cjs());
    init_constants12();
    prefixKeyRegex4 = /^([\w-]+)\s(["'])?([\w-@\+\.%:/]+)\2$/;
    profileNameBlockList4 = ["__proto__", "profile __proto__"];
    parseIni4 = /* @__PURE__ */ __name((iniData) => {
      const map5 = {};
      let currentSection;
      let currentSubSection;
      for (const iniLine of iniData.split(/\r?\n/)) {
        const trimmedLine = iniLine.split(/(^|\s)[;#]/)[0].trim();
        const isSection = trimmedLine[0] === "[" && trimmedLine[trimmedLine.length - 1] === "]";
        if (isSection) {
          currentSection = void 0;
          currentSubSection = void 0;
          const sectionName = trimmedLine.substring(1, trimmedLine.length - 1);
          const matches = prefixKeyRegex4.exec(sectionName);
          if (matches) {
            const [, prefix, , name] = matches;
            if (Object.values(import_types52.IniSectionType).includes(prefix)) {
              currentSection = [prefix, name].join(CONFIG_PREFIX_SEPARATOR4);
            }
          } else {
            currentSection = sectionName;
          }
          if (profileNameBlockList4.includes(sectionName)) {
            throw new Error(`Found invalid profile name "${sectionName}"`);
          }
        } else if (currentSection) {
          const indexOfEqualsSign = trimmedLine.indexOf("=");
          if (![0, -1].includes(indexOfEqualsSign)) {
            const [name, value] = [
              trimmedLine.substring(0, indexOfEqualsSign).trim(),
              trimmedLine.substring(indexOfEqualsSign + 1).trim()
            ];
            if (value === "") {
              currentSubSection = name;
            } else {
              if (currentSubSection && iniLine.trimStart() === iniLine) {
                currentSubSection = void 0;
              }
              map5[currentSection] = map5[currentSection] || {};
              const key = currentSubSection ? [currentSubSection, name].join(CONFIG_PREFIX_SEPARATOR4) : name;
              map5[currentSection][key] = value;
            }
          }
        }
      }
      return map5;
    }, "parseIni");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/readFile.js
var import_promises7, filePromises4, fileIntercept4, readFile9;
var init_readFile4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/readFile.js"() {
    import_promises7 = require("node:fs/promises");
    filePromises4 = {};
    fileIntercept4 = {};
    readFile9 = /* @__PURE__ */ __name((path47, options) => {
      if (fileIntercept4[path47] !== void 0) {
        return fileIntercept4[path47];
      }
      if (!filePromises4[path47] || options?.ignoreCache) {
        filePromises4[path47] = (0, import_promises7.readFile)(path47, "utf8");
      }
      return filePromises4[path47];
    }, "readFile");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/loadSharedConfigFiles.js
var import_node_path20, swallowError5, loadSharedConfigFiles4;
var init_loadSharedConfigFiles4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/loadSharedConfigFiles.js"() {
    import_node_path20 = require("node:path");
    init_getConfigData4();
    init_getConfigFilepath4();
    init_getCredentialsFilepath4();
    init_getHomeDir4();
    init_parseIni4();
    init_readFile4();
    init_constants12();
    swallowError5 = /* @__PURE__ */ __name(() => ({}), "swallowError");
    loadSharedConfigFiles4 = /* @__PURE__ */ __name(async (init = {}) => {
      const { filepath = getCredentialsFilepath4(), configFilepath = getConfigFilepath4() } = init;
      const homeDir = getHomeDir4();
      const relativeHomeDirPrefix = "~/";
      let resolvedFilepath = filepath;
      if (filepath.startsWith(relativeHomeDirPrefix)) {
        resolvedFilepath = (0, import_node_path20.join)(homeDir, filepath.slice(2));
      }
      let resolvedConfigFilepath = configFilepath;
      if (configFilepath.startsWith(relativeHomeDirPrefix)) {
        resolvedConfigFilepath = (0, import_node_path20.join)(homeDir, configFilepath.slice(2));
      }
      const parsedFiles = await Promise.all([
        readFile9(resolvedConfigFilepath, {
          ignoreCache: init.ignoreCache
        }).then(parseIni4).then(getConfigData4).catch(swallowError5),
        readFile9(resolvedFilepath, {
          ignoreCache: init.ignoreCache
        }).then(parseIni4).catch(swallowError5)
      ]);
      return {
        configFile: parsedFiles[0],
        credentialsFile: parsedFiles[1]
      };
    }, "loadSharedConfigFiles");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getSsoSessionData.js
var import_types53, getSsoSessionData2;
var init_getSsoSessionData2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/getSsoSessionData.js"() {
    import_types53 = __toESM(require_dist_cjs());
    init_loadSharedConfigFiles4();
    getSsoSessionData2 = /* @__PURE__ */ __name((data3) => Object.entries(data3).filter(([key]) => key.startsWith(import_types53.IniSectionType.SSO_SESSION + CONFIG_PREFIX_SEPARATOR4)).reduce((acc, [key, value]) => ({ ...acc, [key.substring(key.indexOf(CONFIG_PREFIX_SEPARATOR4) + 1)]: value }), {}), "getSsoSessionData");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/loadSsoSessionData.js
var swallowError6, loadSsoSessionData2;
var init_loadSsoSessionData2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/loadSsoSessionData.js"() {
    init_getConfigFilepath4();
    init_getSsoSessionData2();
    init_parseIni4();
    init_readFile4();
    swallowError6 = /* @__PURE__ */ __name(() => ({}), "swallowError");
    loadSsoSessionData2 = /* @__PURE__ */ __name(async (init = {}) => readFile9(init.configFilepath ?? getConfigFilepath4()).then(parseIni4).then(getSsoSessionData2).catch(swallowError6), "loadSsoSessionData");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/mergeConfigFiles.js
var mergeConfigFiles2;
var init_mergeConfigFiles2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/mergeConfigFiles.js"() {
    mergeConfigFiles2 = /* @__PURE__ */ __name((...files) => {
      const merged = {};
      for (const file of files) {
        for (const [key, values] of Object.entries(file)) {
          if (merged[key] !== void 0) {
            Object.assign(merged[key], values);
          } else {
            merged[key] = values;
          }
        }
      }
      return merged;
    }, "mergeConfigFiles");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/parseKnownFiles.js
var parseKnownFiles2;
var init_parseKnownFiles2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/parseKnownFiles.js"() {
    init_loadSharedConfigFiles4();
    init_mergeConfigFiles2();
    parseKnownFiles2 = /* @__PURE__ */ __name(async (init) => {
      const parsedFiles = await loadSharedConfigFiles4(init);
      return mergeConfigFiles2(parsedFiles.configFile, parsedFiles.credentialsFile);
    }, "parseKnownFiles");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/externalDataInterceptor.js
var externalDataInterceptor2;
var init_externalDataInterceptor2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/shared-ini-file-loader/externalDataInterceptor.js"() {
    init_getSSOTokenFromFile2();
    init_readFile4();
    externalDataInterceptor2 = {
      getFileRecord() {
        return fileIntercept4;
      },
      interceptFile(path47, contents) {
        fileIntercept4[path47] = Promise.resolve(contents);
      },
      getTokenRecord() {
        return tokenIntercept2;
      },
      interceptToken(id, contents) {
        tokenIntercept2[id] = contents;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/getSelectorName.js
function getSelectorName4(functionString) {
  try {
    const constants3 = new Set(Array.from(functionString.match(/([A-Z_]){3,}/g) ?? []));
    constants3.delete("CONFIG");
    constants3.delete("CONFIG_PREFIX_SEPARATOR");
    constants3.delete("ENV");
    return [...constants3].join(", ");
  } catch (e32) {
    return functionString;
  }
}
var init_getSelectorName4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/getSelectorName.js"() {
    __name(getSelectorName4, "getSelectorName");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/fromEnv.js
var fromEnv4;
var init_fromEnv4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/fromEnv.js"() {
    init_CredentialsProviderError4();
    init_getSelectorName4();
    fromEnv4 = /* @__PURE__ */ __name((envVarSelector, options) => async () => {
      try {
        const config2 = envVarSelector(process.env, options);
        if (config2 === void 0) {
          throw new Error();
        }
        return config2;
      } catch (e32) {
        throw new CredentialsProviderError4(e32.message || `Not found in ENV: ${getSelectorName4(envVarSelector.toString())}`, { logger: options?.logger });
      }
    }, "fromEnv");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/fromSharedConfigFiles.js
var fromSharedConfigFiles4;
var init_fromSharedConfigFiles4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/fromSharedConfigFiles.js"() {
    init_CredentialsProviderError4();
    init_getProfileName4();
    init_loadSharedConfigFiles4();
    init_getSelectorName4();
    fromSharedConfigFiles4 = /* @__PURE__ */ __name((configSelector, { preferredFile = "config", ...init } = {}) => async () => {
      const profile = getProfileName4(init);
      const { configFile, credentialsFile } = await loadSharedConfigFiles4(init);
      const profileFromCredentials = credentialsFile[profile] || {};
      const profileFromConfig = configFile[profile] || {};
      const mergedProfile = preferredFile === "config" ? { ...profileFromCredentials, ...profileFromConfig } : { ...profileFromConfig, ...profileFromCredentials };
      try {
        const cfgFile = preferredFile === "config" ? configFile : credentialsFile;
        const configValue = configSelector(mergedProfile, cfgFile);
        if (configValue === void 0) {
          throw new Error();
        }
        return configValue;
      } catch (e32) {
        throw new CredentialsProviderError4(e32.message || `Not found in config files w/ profile [${profile}]: ${getSelectorName4(configSelector.toString())}`, { logger: init.logger });
      }
    }, "fromSharedConfigFiles");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/fromStatic.js
var isFunction4, fromStatic4;
var init_fromStatic4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/fromStatic.js"() {
    init_fromValue4();
    isFunction4 = /* @__PURE__ */ __name((func) => typeof func === "function", "isFunction");
    fromStatic4 = /* @__PURE__ */ __name((defaultValue2) => isFunction4(defaultValue2) ? async () => await defaultValue2() : fromValue4(defaultValue2), "fromStatic");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/configLoader.js
var loadConfig5;
var init_configLoader4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/node-config-provider/configLoader.js"() {
    init_chain4();
    init_memoize4();
    init_fromEnv4();
    init_fromSharedConfigFiles4();
    init_fromStatic4();
    loadConfig5 = /* @__PURE__ */ __name(({ environmentVariableSelector, configFileSelector, default: defaultValue2 }, configuration = {}) => {
      const { signingName, logger: logger5 } = configuration;
      const envOptions = { signingName, logger: logger5 };
      return memoize4(chain4(fromEnv4(environmentVariableSelector, envOptions), fromSharedConfigFiles4(configFileSelector, configuration), fromStatic4(defaultValue2)));
    }, "loadConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/endpointsConfig/NodeUseDualstackEndpointConfigOptions.js
var ENV_USE_DUALSTACK_ENDPOINT2, CONFIG_USE_DUALSTACK_ENDPOINT2, DEFAULT_USE_DUALSTACK_ENDPOINT2, NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS20, nodeDualstackConfigSelectors2;
var init_NodeUseDualstackEndpointConfigOptions2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/endpointsConfig/NodeUseDualstackEndpointConfigOptions.js"() {
    init_booleanSelector2();
    init_types10();
    ENV_USE_DUALSTACK_ENDPOINT2 = "AWS_USE_DUALSTACK_ENDPOINT";
    CONFIG_USE_DUALSTACK_ENDPOINT2 = "use_dualstack_endpoint";
    DEFAULT_USE_DUALSTACK_ENDPOINT2 = false;
    NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS20 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => booleanSelector2(env3, ENV_USE_DUALSTACK_ENDPOINT2, SelectorType2.ENV), "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => booleanSelector2(profile, CONFIG_USE_DUALSTACK_ENDPOINT2, SelectorType2.CONFIG), "configFileSelector"),
      default: false
    };
    nodeDualstackConfigSelectors2 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => booleanSelector2(env3, ENV_USE_DUALSTACK_ENDPOINT2, SelectorType2.ENV), "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => booleanSelector2(profile, CONFIG_USE_DUALSTACK_ENDPOINT2, SelectorType2.CONFIG), "configFileSelector"),
      default: void 0
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/endpointsConfig/NodeUseFipsEndpointConfigOptions.js
var ENV_USE_FIPS_ENDPOINT2, CONFIG_USE_FIPS_ENDPOINT2, DEFAULT_USE_FIPS_ENDPOINT2, NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS20, nodeFipsConfigSelectors2;
var init_NodeUseFipsEndpointConfigOptions2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/endpointsConfig/NodeUseFipsEndpointConfigOptions.js"() {
    init_booleanSelector2();
    init_types10();
    ENV_USE_FIPS_ENDPOINT2 = "AWS_USE_FIPS_ENDPOINT";
    CONFIG_USE_FIPS_ENDPOINT2 = "use_fips_endpoint";
    DEFAULT_USE_FIPS_ENDPOINT2 = false;
    NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS20 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => booleanSelector2(env3, ENV_USE_FIPS_ENDPOINT2, SelectorType2.ENV), "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => booleanSelector2(profile, CONFIG_USE_FIPS_ENDPOINT2, SelectorType2.CONFIG), "configFileSelector"),
      default: false
    };
    nodeFipsConfigSelectors2 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => booleanSelector2(env3, ENV_USE_FIPS_ENDPOINT2, SelectorType2.ENV), "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => booleanSelector2(profile, CONFIG_USE_FIPS_ENDPOINT2, SelectorType2.CONFIG), "configFileSelector"),
      default: void 0
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/client/util-middleware/getSmithyContext.js
var import_types56, getSmithyContext29;
var init_getSmithyContext6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/client/util-middleware/getSmithyContext.js"() {
    import_types56 = __toESM(require_dist_cjs());
    getSmithyContext29 = /* @__PURE__ */ __name((context) => context[import_types56.SMITHY_CONTEXT_KEY] || (context[import_types56.SMITHY_CONTEXT_KEY] = {}), "getSmithyContext");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/client/util-middleware/normalizeProvider.js
var normalizeProvider25;
var init_normalizeProvider7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/client/util-middleware/normalizeProvider.js"() {
    normalizeProvider25 = /* @__PURE__ */ __name((input) => {
      if (typeof input === "function")
        return input;
      const promisified = Promise.resolve(input);
      return () => promisified;
    }, "normalizeProvider");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/deref.js
var deref5;
var init_deref5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/deref.js"() {
    deref5 = /* @__PURE__ */ __name((schemaRef) => {
      if (typeof schemaRef === "function") {
        return schemaRef();
      }
      return schemaRef;
    }, "deref");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/is-array-buffer/is-array-buffer.js
var isArrayBuffer5;
var init_is_array_buffer5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/is-array-buffer/is-array-buffer.js"() {
    isArrayBuffer5 = /* @__PURE__ */ __name((arg) => typeof ArrayBuffer === "function" && arg instanceof ArrayBuffer || Object.prototype.toString.call(arg) === "[object ArrayBuffer]", "isArrayBuffer");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-buffer-from/buffer-from.js
var fromArrayBuffer5, fromString5;
var init_buffer_from5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-buffer-from/buffer-from.js"() {
    init_is_array_buffer5();
    fromArrayBuffer5 = /* @__PURE__ */ __name((input, offset = 0, length = input.byteLength - offset) => {
      if (!isArrayBuffer5(input)) {
        throw new TypeError(`The "input" argument must be ArrayBuffer. Received type ${typeof input} (${input})`);
      }
      return Buffer.from(input, offset, length);
    }, "fromArrayBuffer");
    fromString5 = /* @__PURE__ */ __name((input, encoding) => {
      if (typeof input !== "string") {
        throw new TypeError(`The "input" argument must be of type string. Received type ${typeof input} (${input})`);
      }
      return encoding ? Buffer.from(input, encoding) : Buffer.from(input);
    }, "fromString");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/fromBase64.js
var BASE64_REGEX5, fromBase6440;
var init_fromBase645 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/fromBase64.js"() {
    init_buffer_from5();
    BASE64_REGEX5 = /^[A-Za-z0-9+/]*={0,2}$/;
    fromBase6440 = /* @__PURE__ */ __name((input) => {
      if (input.length * 3 % 4 !== 0) {
        throw new TypeError(`Incorrect padding on base64 string.`);
      }
      if (!BASE64_REGEX5.exec(input)) {
        throw new TypeError(`Invalid base64 string.`);
      }
      const buffer = fromString5(input, "base64");
      return new Uint8Array(buffer.buffer, buffer.byteOffset, buffer.byteLength);
    }, "fromBase64");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/fromUtf8.js
var fromUtf829;
var init_fromUtf85 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/fromUtf8.js"() {
    init_buffer_from5();
    fromUtf829 = /* @__PURE__ */ __name((input) => {
      const buf = fromString5(input, "utf8");
      return new Uint8Array(buf.buffer, buf.byteOffset, buf.byteLength / Uint8Array.BYTES_PER_ELEMENT);
    }, "fromUtf8");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/toBase64.js
var toBase6445;
var init_toBase645 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/toBase64.js"() {
    init_buffer_from5();
    init_fromUtf85();
    toBase6445 = /* @__PURE__ */ __name((_input) => {
      let input;
      if (typeof _input === "string") {
        input = fromUtf829(_input);
      } else {
        input = _input;
      }
      if (typeof input !== "object" || typeof input.byteOffset !== "number" || typeof input.byteLength !== "number") {
        throw new Error("@smithy/util-base64: toBase64 encoder function only accepts string | Uint8Array.");
      }
      return fromArrayBuffer5(input.buffer, input.byteOffset, input.byteLength).toString("base64");
    }, "toBase64");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/blob/Uint8ArrayBlobAdapter.js
function bindUint8ArrayBlobAdapter5(toUtf862, fromUtf842, toBase6467, fromBase6459) {
  return class Uint8ArrayBlobAdapter8 extends Uint8Array {
    static {
      __name(this, "Uint8ArrayBlobAdapter");
    }
    static fromString(source, encoding = "utf-8") {
      if (typeof source === "string") {
        if (encoding === "base64") {
          return Uint8ArrayBlobAdapter8.mutate(fromBase6459(source));
        }
        return Uint8ArrayBlobAdapter8.mutate(fromUtf842(source));
      }
      throw new Error(`Unsupported conversion from ${typeof source} to Uint8ArrayBlobAdapter.`);
    }
    static mutate(source) {
      Object.setPrototypeOf(source, Uint8ArrayBlobAdapter8.prototype);
      return source;
    }
    transformToString(encoding = "utf-8") {
      if (encoding === "base64") {
        return toBase6467(this);
      }
      return toUtf862(this);
    }
  };
}
var init_Uint8ArrayBlobAdapter5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/blob/Uint8ArrayBlobAdapter.js"() {
    __name(bindUint8ArrayBlobAdapter5, "bindUint8ArrayBlobAdapter");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/toUtf8.js
var toUtf843;
var init_toUtf85 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/toUtf8.js"() {
    init_buffer_from5();
    toUtf843 = /* @__PURE__ */ __name((input) => {
      if (typeof input === "string") {
        return input;
      }
      if (typeof input !== "object" || typeof input.byteOffset !== "number" || typeof input.byteLength !== "number") {
        throw new Error("@smithy/util-utf8: toUtf8 encoder function only accepts string | Uint8Array.");
      }
      return fromArrayBuffer5(input.buffer, input.byteOffset, input.byteLength).toString("utf8");
    }, "toUtf8");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/uuid/v4.js
function bindV45(getRandomValues7) {
  if (typeof crypto !== "undefined" && typeof crypto.randomUUID === "function") {
    return () => crypto.randomUUID();
  }
  return () => {
    const rnds = new Uint8Array(16);
    getRandomValues7(rnds);
    rnds[6] = rnds[6] & 15 | 64;
    rnds[8] = rnds[8] & 63 | 128;
    return decimalToHex5[rnds[0]] + decimalToHex5[rnds[1]] + decimalToHex5[rnds[2]] + decimalToHex5[rnds[3]] + "-" + decimalToHex5[rnds[4]] + decimalToHex5[rnds[5]] + "-" + decimalToHex5[rnds[6]] + decimalToHex5[rnds[7]] + "-" + decimalToHex5[rnds[8]] + decimalToHex5[rnds[9]] + "-" + decimalToHex5[rnds[10]] + decimalToHex5[rnds[11]] + decimalToHex5[rnds[12]] + decimalToHex5[rnds[13]] + decimalToHex5[rnds[14]] + decimalToHex5[rnds[15]];
  };
}
var decimalToHex5;
var init_v45 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/uuid/v4.js"() {
    decimalToHex5 = Array.from({ length: 256 }, (_, i32) => i32.toString(16).padStart(2, "0"));
    __name(bindV45, "bindV4");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/date-utils.js
function dateToUtcString17(date7) {
  const year7 = date7.getUTCFullYear();
  const month = date7.getUTCMonth();
  const dayOfWeek = date7.getUTCDay();
  const dayOfMonthInt = date7.getUTCDate();
  const hoursInt = date7.getUTCHours();
  const minutesInt = date7.getUTCMinutes();
  const secondsInt = date7.getUTCSeconds();
  const dayOfMonthString = dayOfMonthInt < 10 ? `0${dayOfMonthInt}` : `${dayOfMonthInt}`;
  const hoursString = hoursInt < 10 ? `0${hoursInt}` : `${hoursInt}`;
  const minutesString = minutesInt < 10 ? `0${minutesInt}` : `${minutesInt}`;
  const secondsString = secondsInt < 10 ? `0${secondsInt}` : `${secondsInt}`;
  return `${DAYS5[dayOfWeek]}, ${dayOfMonthString} ${MONTHS6[month]} ${year7} ${hoursString}:${minutesString}:${secondsString} GMT`;
}
var DAYS5, MONTHS6, RFC33396, RFC3339_WITH_OFFSET10, IMF_FIXDATE10, RFC_850_DATE10, ASC_TIME10, FIFTY_YEARS_IN_MILLIS6;
var init_date_utils6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/date-utils.js"() {
    DAYS5 = ["Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"];
    MONTHS6 = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"];
    __name(dateToUtcString17, "dateToUtcString");
    RFC33396 = new RegExp(/^(\d{4})-(\d{2})-(\d{2})[tT](\d{2}):(\d{2}):(\d{2})(?:\.(\d+))?[zZ]$/);
    RFC3339_WITH_OFFSET10 = new RegExp(/^(\d{4})-(\d{2})-(\d{2})[tT](\d{2}):(\d{2}):(\d{2})(?:\.(\d+))?(([-+]\d{2}\:\d{2})|[zZ])$/);
    IMF_FIXDATE10 = new RegExp(/^(?:Mon|Tue|Wed|Thu|Fri|Sat|Sun), (\d{2}) (Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec) (\d{4}) (\d{1,2}):(\d{2}):(\d{2})(?:\.(\d+))? GMT$/);
    RFC_850_DATE10 = new RegExp(/^(?:Monday|Tuesday|Wednesday|Thursday|Friday|Saturday|Sunday), (\d{2})-(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)-(\d{2}) (\d{1,2}):(\d{2}):(\d{2})(?:\.(\d+))? GMT$/);
    ASC_TIME10 = new RegExp(/^(?:Mon|Tue|Wed|Thu|Fri|Sat|Sun) (Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec) ( [1-9]|\d{2}) (\d{1,2}):(\d{2}):(\d{2})(?:\.(\d+))? (\d{4})$/);
    FIFTY_YEARS_IN_MILLIS6 = 50 * 365 * 24 * 60 * 60 * 1e3;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/lazy-json.js
var LazyJsonString9;
var init_lazy_json5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/lazy-json.js"() {
    LazyJsonString9 = /* @__PURE__ */ __name(function LazyJsonString10(val) {
      const str = Object.assign(new String(val), {
        deserializeJSON() {
          return JSON.parse(String(val));
        },
        toString() {
          return String(val);
        },
        toJSON() {
          return String(val);
        }
      });
      return str;
    }, "LazyJsonString");
    LazyJsonString9.from = (object) => {
      if (object && typeof object === "object" && (object instanceof LazyJsonString9 || "deserializeJSON" in object)) {
        return object;
      } else if (typeof object === "string" || Object.getPrototypeOf(object) === String.prototype) {
        return LazyJsonString9(String(object));
      }
      return LazyJsonString9(JSON.stringify(object));
    };
    LazyJsonString9.fromObject = LazyJsonString9.from;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/quote-header.js
function quoteHeader5(part) {
  if (part.includes(",") || part.includes('"')) {
    part = `"${part.replace(/"/g, '\\"')}"`;
  }
  return part;
}
var init_quote_header5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/quote-header.js"() {
    __name(quoteHeader5, "quoteHeader");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/schema-serde-lib/schema-date-utils.js
function range5(v, min, max) {
  const _v = Number(v);
  if (_v < min || _v > max) {
    throw new Error(`Value ${_v} out of range [${min}, ${max}]`);
  }
}
var ddd5, mmm5, time5, date5, year5, RFC3339_WITH_OFFSET11, IMF_FIXDATE11, RFC_850_DATE11, ASC_TIME11, months5, _parseEpochTimestamp5, _parseRfc3339DateTimeWithOffset5, _parseRfc7231DateTime5;
var init_schema_date_utils5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/schema-serde-lib/schema-date-utils.js"() {
    ddd5 = `(?:Mon|Tue|Wed|Thu|Fri|Sat|Sun)(?:[ne|u?r]?s?day)?`;
    mmm5 = `(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)`;
    time5 = `(\\d?\\d):(\\d{2}):(\\d{2})(?:\\.(\\d+))?`;
    date5 = `(\\d?\\d)`;
    year5 = `(\\d{4})`;
    RFC3339_WITH_OFFSET11 = new RegExp(/^(\d{4})-(\d\d)-(\d\d)[tT](\d\d):(\d\d):(\d\d)(\.(\d+))?(([-+]\d\d:\d\d)|[zZ])$/);
    IMF_FIXDATE11 = new RegExp(`^${ddd5}, ${date5} ${mmm5} ${year5} ${time5} GMT$`);
    RFC_850_DATE11 = new RegExp(`^${ddd5}, ${date5}-${mmm5}-(\\d\\d) ${time5} GMT$`);
    ASC_TIME11 = new RegExp(`^${ddd5} ${mmm5} ( [1-9]|\\d\\d) ${time5} ${year5}$`);
    months5 = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"];
    _parseEpochTimestamp5 = /* @__PURE__ */ __name((value) => {
      if (value == null) {
        return void 0;
      }
      let num = NaN;
      if (typeof value === "number") {
        num = value;
      } else if (typeof value === "string") {
        if (!/^-?\d*\.?\d+$/.test(value)) {
          throw new TypeError(`parseEpochTimestamp - numeric string invalid.`);
        }
        num = Number.parseFloat(value);
      } else if (typeof value === "object" && value.tag === 1) {
        num = value.value;
      }
      if (isNaN(num) || Math.abs(num) === Infinity) {
        throw new TypeError("Epoch timestamps must be valid finite numbers.");
      }
      return new Date(Math.round(num * 1e3));
    }, "_parseEpochTimestamp");
    _parseRfc3339DateTimeWithOffset5 = /* @__PURE__ */ __name((value) => {
      if (value == null) {
        return void 0;
      }
      if (typeof value !== "string") {
        throw new TypeError("RFC3339 timestamps must be strings");
      }
      const matches = RFC3339_WITH_OFFSET11.exec(value);
      if (!matches) {
        throw new TypeError(`Invalid RFC3339 timestamp format ${value}`);
      }
      const [, yearStr, monthStr, dayStr, hours, minutes, seconds, , ms, offsetStr] = matches;
      range5(monthStr, 1, 12);
      range5(dayStr, 1, 31);
      range5(hours, 0, 23);
      range5(minutes, 0, 59);
      range5(seconds, 0, 60);
      const date7 = new Date(Date.UTC(Number(yearStr), Number(monthStr) - 1, Number(dayStr), Number(hours), Number(minutes), Number(seconds), Number(ms) ? Math.round(parseFloat(`0.${ms}`) * 1e3) : 0));
      date7.setUTCFullYear(Number(yearStr));
      if (offsetStr.toUpperCase() != "Z") {
        const [, sign, offsetH, offsetM] = /([+-])(\d\d):(\d\d)/.exec(offsetStr) || [void 0, "+", 0, 0];
        const scalar = sign === "-" ? 1 : -1;
        date7.setTime(date7.getTime() + scalar * (Number(offsetH) * 60 * 60 * 1e3 + Number(offsetM) * 60 * 1e3));
      }
      return date7;
    }, "_parseRfc3339DateTimeWithOffset");
    _parseRfc7231DateTime5 = /* @__PURE__ */ __name((value) => {
      if (value == null) {
        return void 0;
      }
      if (typeof value !== "string") {
        throw new TypeError("RFC7231 timestamps must be strings.");
      }
      let day;
      let month;
      let year7;
      let hour;
      let minute;
      let second;
      let fraction;
      let matches;
      if (matches = IMF_FIXDATE11.exec(value)) {
        [, day, month, year7, hour, minute, second, fraction] = matches;
      } else if (matches = RFC_850_DATE11.exec(value)) {
        [, day, month, year7, hour, minute, second, fraction] = matches;
        year7 = (Number(year7) + 1900).toString();
      } else if (matches = ASC_TIME11.exec(value)) {
        [, month, day, hour, minute, second, fraction, year7] = matches;
      }
      if (year7 && second) {
        const timestamp = Date.UTC(Number(year7), months5.indexOf(month), Number(day), Number(hour), Number(minute), Number(second), fraction ? Math.round(parseFloat(`0.${fraction}`) * 1e3) : 0);
        range5(day, 1, 31);
        range5(hour, 0, 23);
        range5(minute, 0, 59);
        range5(second, 0, 60);
        const date7 = new Date(timestamp);
        date7.setUTCFullYear(Number(year7));
        return date7;
      }
      throw new TypeError(`Invalid RFC7231 date-time value ${value}.`);
    }, "_parseRfc7231DateTime");
    __name(range5, "range");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/split-every.js
function splitEvery5(value, delimiter2, numDelimiters) {
  if (numDelimiters <= 0 || !Number.isInteger(numDelimiters)) {
    throw new Error("Invalid number of delimiters (" + numDelimiters + ") for splitEvery.");
  }
  const segments = value.split(delimiter2);
  if (numDelimiters === 1) {
    return segments;
  }
  const compoundSegments = [];
  let currentSegment = "";
  for (let i32 = 0; i32 < segments.length; i32++) {
    if (currentSegment === "") {
      currentSegment = segments[i32];
    } else {
      currentSegment += delimiter2 + segments[i32];
    }
    if ((i32 + 1) % numDelimiters === 0) {
      compoundSegments.push(currentSegment);
      currentSegment = "";
    }
  }
  if (currentSegment !== "") {
    compoundSegments.push(currentSegment);
  }
  return compoundSegments;
}
var init_split_every5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/split-every.js"() {
    __name(splitEvery5, "splitEvery");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/split-header.js
var splitHeader5;
var init_split_header5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/split-header.js"() {
    splitHeader5 = /* @__PURE__ */ __name((value) => {
      const z = value.length;
      const values = [];
      let withinQuotes = false;
      let prevChar = void 0;
      let anchor = 0;
      for (let i32 = 0; i32 < z; ++i32) {
        const char = value[i32];
        switch (char) {
          case `"`:
            if (prevChar !== "\\") {
              withinQuotes = !withinQuotes;
            }
            break;
          case ",":
            if (!withinQuotes) {
              values.push(value.slice(anchor, i32));
              anchor = i32 + 1;
            }
            break;
          default:
        }
        prevChar = char;
      }
      values.push(value.slice(anchor));
      return values.map((v) => {
        v = v.trim();
        const z2 = v.length;
        if (z2 < 2) {
          return v;
        }
        if (v[0] === `"` && v[z2 - 1] === `"`) {
          v = v.slice(1, z2 - 1);
        }
        return v.replace(/\\"/g, '"');
      });
    }, "splitHeader");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/value/NumericValue.js
var format15, NumericValue5;
var init_NumericValue5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/value/NumericValue.js"() {
    format15 = /^-?\d*(\.\d+)?$/;
    NumericValue5 = class _NumericValue {
      static {
        __name(this, "NumericValue");
      }
      string;
      type;
      constructor(string, type) {
        this.string = string;
        this.type = type;
        if (!format15.test(string)) {
          throw new Error(`@smithy/core/serde - NumericValue must only contain [0-9], at most one decimal point ".", and an optional negation prefix "-".`);
        }
      }
      toString() {
        return this.string;
      }
      static [Symbol.hasInstance](object) {
        if (!object || typeof object !== "object") {
          return false;
        }
        const _nv = object;
        return _NumericValue.prototype.isPrototypeOf(object) || _nv.type === "bigDecimal" && format15.test(_nv.string);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-hex-encoding/hex-encoding.js
function fromHex4(encoded) {
  if (encoded.length % 2 !== 0) {
    throw new Error("Hex encoded strings must have an even number length");
  }
  const out = new Uint8Array(encoded.length / 2);
  for (let i32 = 0; i32 < encoded.length; i32 += 2) {
    const encodedByte = encoded.slice(i32, i32 + 2).toLowerCase();
    if (encodedByte in HEX_TO_SHORT4) {
      out[i32 / 2] = HEX_TO_SHORT4[encodedByte];
    } else {
      throw new Error(`Cannot decode unrecognized sequence ${encodedByte} as hexadecimal`);
    }
  }
  return out;
}
function toHex4(bytes) {
  let out = "";
  for (let i32 = 0; i32 < bytes.byteLength; i32++) {
    out += SHORT_TO_HEX4[bytes[i32]];
  }
  return out;
}
var SHORT_TO_HEX4, HEX_TO_SHORT4;
var init_hex_encoding4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-hex-encoding/hex-encoding.js"() {
    SHORT_TO_HEX4 = {};
    HEX_TO_SHORT4 = {};
    for (let i32 = 0; i32 < 256; i32++) {
      let encodedByte = i32.toString(16).toLowerCase();
      if (encodedByte.length === 1) {
        encodedByte = `0${encodedByte}`;
      }
      SHORT_TO_HEX4[i32] = encodedByte;
      HEX_TO_SHORT4[encodedByte] = i32;
    }
    __name(fromHex4, "fromHex");
    __name(toHex4, "toHex");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/getEndpointUrlConfig.js
var ENV_ENDPOINT_URL4, CONFIG_ENDPOINT_URL4, getEndpointUrlConfig4;
var init_getEndpointUrlConfig4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/getEndpointUrlConfig.js"() {
    init_config8();
    ENV_ENDPOINT_URL4 = "AWS_ENDPOINT_URL";
    CONFIG_ENDPOINT_URL4 = "endpoint_url";
    getEndpointUrlConfig4 = /* @__PURE__ */ __name((serviceId) => ({
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => {
        const serviceSuffixParts = serviceId.split(" ").map((w) => w.toUpperCase());
        const serviceEndpointUrl = env3[[ENV_ENDPOINT_URL4, ...serviceSuffixParts].join("_")];
        if (serviceEndpointUrl)
          return serviceEndpointUrl;
        const endpointUrl = env3[ENV_ENDPOINT_URL4];
        if (endpointUrl)
          return endpointUrl;
        return void 0;
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile, config2) => {
        if (config2 && profile.services) {
          const servicesSection = config2[["services", profile.services].join(CONFIG_PREFIX_SEPARATOR4)];
          if (servicesSection) {
            const servicePrefixParts = serviceId.split(" ").map((w) => w.toLowerCase());
            const endpointUrl2 = servicesSection[[servicePrefixParts.join("_"), CONFIG_ENDPOINT_URL4].join(CONFIG_PREFIX_SEPARATOR4)];
            if (endpointUrl2)
              return endpointUrl2;
          }
        }
        const endpointUrl = profile[CONFIG_ENDPOINT_URL4];
        if (endpointUrl)
          return endpointUrl;
        return void 0;
      }, "configFileSelector"),
      default: void 0
    }), "getEndpointUrlConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/getEndpointFromConfig.js
var getEndpointFromConfig4;
var init_getEndpointFromConfig4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/getEndpointFromConfig.js"() {
    init_config8();
    init_getEndpointUrlConfig4();
    getEndpointFromConfig4 = /* @__PURE__ */ __name(async (serviceId) => loadConfig5(getEndpointUrlConfig4(serviceId ?? ""))(), "getEndpointFromConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/service-customizations/s3.js
var resolveParamsForS34, DOMAIN_PATTERN4, IP_ADDRESS_PATTERN4, DOTS_PATTERN4, isDnsCompatibleBucketName4, isArnBucketName4;
var init_s34 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/service-customizations/s3.js"() {
    resolveParamsForS34 = /* @__PURE__ */ __name(async (endpointParams) => {
      const bucket = endpointParams?.Bucket || "";
      if (typeof endpointParams.Bucket === "string") {
        endpointParams.Bucket = bucket.replace(/#/g, encodeURIComponent("#")).replace(/\?/g, encodeURIComponent("?"));
      }
      if (isArnBucketName4(bucket)) {
        if (endpointParams.ForcePathStyle === true) {
          throw new Error("Path-style addressing cannot be used with ARN buckets");
        }
      } else if (!isDnsCompatibleBucketName4(bucket) || bucket.indexOf(".") !== -1 && !String(endpointParams.Endpoint).startsWith("http:") || bucket.toLowerCase() !== bucket || bucket.length < 3) {
        endpointParams.ForcePathStyle = true;
      }
      if (endpointParams.DisableMultiRegionAccessPoints) {
        endpointParams.disableMultiRegionAccessPoints = true;
        endpointParams.DisableMRAP = true;
      }
      return endpointParams;
    }, "resolveParamsForS3");
    DOMAIN_PATTERN4 = /^[a-z0-9][a-z0-9\.\-]{1,61}[a-z0-9]$/;
    IP_ADDRESS_PATTERN4 = /(\d+\.){3}\d+/;
    DOTS_PATTERN4 = /\.\./;
    isDnsCompatibleBucketName4 = /* @__PURE__ */ __name((bucketName) => DOMAIN_PATTERN4.test(bucketName) && !IP_ADDRESS_PATTERN4.test(bucketName) && !DOTS_PATTERN4.test(bucketName), "isDnsCompatibleBucketName");
    isArnBucketName4 = /* @__PURE__ */ __name((bucketName) => {
      const [arn, partition4, service, , , bucket] = bucketName.split(":");
      const isArn = arn === "arn" && bucketName.split(":").length >= 6;
      const isValidArn = Boolean(isArn && partition4 && service && bucket);
      if (isArn && !isValidArn) {
        throw new Error(`Invalid ARN: ${bucketName} was an invalid ARN.`);
      }
      return isValidArn;
    }, "isArnBucketName");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/service-customizations/index.js
var init_service_customizations4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/service-customizations/index.js"() {
    init_s34();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/createConfigValueProvider.js
var createConfigValueProvider4;
var init_createConfigValueProvider4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/createConfigValueProvider.js"() {
    createConfigValueProvider4 = /* @__PURE__ */ __name((configKey, canonicalEndpointParamKey, config2, isClientContextParam = false) => {
      const configProvider = /* @__PURE__ */ __name(async () => {
        let configValue;
        if (isClientContextParam) {
          const clientContextParams = config2.clientContextParams;
          const nestedValue = clientContextParams?.[configKey];
          configValue = nestedValue ?? config2[configKey] ?? config2[canonicalEndpointParamKey];
        } else {
          configValue = config2[configKey] ?? config2[canonicalEndpointParamKey];
        }
        if (typeof configValue === "function") {
          return configValue();
        }
        return configValue;
      }, "configProvider");
      if (configKey === "credentialScope" || canonicalEndpointParamKey === "CredentialScope") {
        return async () => {
          const credentials = typeof config2.credentials === "function" ? await config2.credentials() : config2.credentials;
          const configValue = credentials?.credentialScope ?? credentials?.CredentialScope;
          return configValue;
        };
      }
      if (configKey === "accountId" || canonicalEndpointParamKey === "AccountId") {
        return async () => {
          const credentials = typeof config2.credentials === "function" ? await config2.credentials() : config2.credentials;
          const configValue = credentials?.accountId ?? credentials?.AccountId;
          return configValue;
        };
      }
      if (configKey === "endpoint" || canonicalEndpointParamKey === "endpoint") {
        return async () => {
          if (config2.isCustomEndpoint === false) {
            return void 0;
          }
          const endpoint = await configProvider();
          if (endpoint && typeof endpoint === "object") {
            if ("url" in endpoint) {
              return endpoint.url.href;
            }
            if ("hostname" in endpoint) {
              const { protocol, hostname, port, path: path47 } = endpoint;
              return `${protocol}//${hostname}${port ? ":" + port : ""}${path47}`;
            }
          }
          return endpoint;
        };
      }
      return configProvider;
    }, "createConfigValueProvider");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/toEndpointV1.js
var toEndpointV16;
var init_toEndpointV18 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/toEndpointV1.js"() {
    init_protocols13();
    toEndpointV16 = /* @__PURE__ */ __name((endpoint) => {
      if (typeof endpoint === "object") {
        if ("url" in endpoint) {
          const v1Endpoint = parseUrl23(endpoint.url);
          if (endpoint.headers) {
            v1Endpoint.headers = {};
            for (const name in endpoint.headers) {
              v1Endpoint.headers[name.toLowerCase()] = endpoint.headers[name].join(", ");
            }
          }
          return v1Endpoint;
        }
        return endpoint;
      }
      return parseUrl23(endpoint);
    }, "toEndpointV1");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/toEndpointV1.js
var init_toEndpointV19 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/toEndpointV1.js"() {
    init_toEndpointV18();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/getEndpointFromInstructions.js
function bindGetEndpointFromInstructions4(getEndpointFromConfig5) {
  return async (commandInput, instructionsSupplier, clientConfig, context) => {
    if (!clientConfig.isCustomEndpoint) {
      let endpointFromConfig;
      if (clientConfig.serviceConfiguredEndpoint) {
        endpointFromConfig = await clientConfig.serviceConfiguredEndpoint();
      } else {
        endpointFromConfig = await getEndpointFromConfig5(clientConfig.serviceId);
      }
      if (endpointFromConfig) {
        clientConfig.endpoint = () => Promise.resolve(toEndpointV16(endpointFromConfig));
        clientConfig.isCustomEndpoint = true;
      }
    }
    const endpointParams = await resolveParams9(commandInput, instructionsSupplier, clientConfig);
    if (typeof clientConfig.endpointProvider !== "function") {
      throw new Error("config.endpointProvider is not set.");
    }
    const endpoint = clientConfig.endpointProvider(endpointParams, context);
    if (clientConfig.isCustomEndpoint && clientConfig.endpoint) {
      const customEndpoint = await clientConfig.endpoint();
      if (customEndpoint?.headers) {
        endpoint.headers ??= {};
        for (const [name, value] of Object.entries(customEndpoint.headers)) {
          endpoint.headers[name] = Array.isArray(value) ? value : [value];
        }
      }
    }
    return endpoint;
  };
}
var resolveParams9;
var init_getEndpointFromInstructions4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/adaptors/getEndpointFromInstructions.js"() {
    init_service_customizations4();
    init_createConfigValueProvider4();
    init_toEndpointV19();
    __name(bindGetEndpointFromInstructions4, "bindGetEndpointFromInstructions");
    resolveParams9 = /* @__PURE__ */ __name(async (commandInput, instructionsSupplier, clientConfig) => {
      const endpointParams = {};
      const instructions = instructionsSupplier?.getEndpointParameterInstructions?.() || {};
      for (const [name, instruction] of Object.entries(instructions)) {
        switch (instruction.type) {
          case "staticContextParams":
            endpointParams[name] = instruction.value;
            break;
          case "contextParams":
            endpointParams[name] = commandInput[instruction.name];
            break;
          case "clientContextParams":
          case "builtInParams":
            endpointParams[name] = await createConfigValueProvider4(instruction.name, name, clientConfig, instruction.type !== "builtInParams")();
            break;
          case "operationContextParams":
            endpointParams[name] = instruction.get(commandInput);
            break;
          default:
            throw new Error("Unrecognized endpoint parameter instruction: " + JSON.stringify(instruction));
        }
      }
      if (Object.keys(instructions).length === 0) {
        Object.assign(endpointParams, clientConfig);
      }
      if (String(clientConfig.serviceId).toLowerCase() === "s3") {
        await resolveParamsForS34(endpointParams);
      }
      return endpointParams;
    }, "resolveParams");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/endpointMiddleware.js
function setFeature15(context, feature, value) {
  if (!context.__smithy_context) {
    context.__smithy_context = { features: {} };
  } else if (!context.__smithy_context.features) {
    context.__smithy_context.features = {};
  }
  context.__smithy_context.features[feature] = value;
}
function bindEndpointMiddleware4(getEndpointFromConfig5) {
  const getEndpointFromInstructions7 = bindGetEndpointFromInstructions4(getEndpointFromConfig5);
  return ({ config: config2, instructions }) => {
    return (next, context) => async (args) => {
      if (config2.isCustomEndpoint) {
        setFeature15(context, "ENDPOINT_OVERRIDE", "N");
      }
      const endpoint = await getEndpointFromInstructions7(args.input, {
        getEndpointParameterInstructions() {
          return instructions;
        }
      }, { ...config2 }, context);
      context.endpointV2 = endpoint;
      context.authSchemes = endpoint.properties?.authSchemes;
      const authScheme = context.authSchemes?.[0];
      if (authScheme) {
        context["signing_region"] = authScheme.signingRegion;
        context["signing_service"] = authScheme.signingName;
        const smithyContext = getSmithyContext29(context);
        const httpAuthOption = smithyContext?.selectedHttpAuthScheme?.httpAuthOption;
        if (httpAuthOption) {
          httpAuthOption.signingProperties = Object.assign(httpAuthOption.signingProperties || {}, {
            signing_region: authScheme.signingRegion,
            signingRegion: authScheme.signingRegion,
            signing_service: authScheme.signingName,
            signingName: authScheme.signingName,
            signingRegionSet: authScheme.signingRegionSet
          }, authScheme.properties);
        }
      }
      return next({
        ...args
      });
    };
  };
}
var init_endpointMiddleware4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/endpointMiddleware.js"() {
    init_client16();
    init_getEndpointFromInstructions4();
    __name(setFeature15, "setFeature");
    __name(bindEndpointMiddleware4, "bindEndpointMiddleware");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/getEndpointPlugin.js
function bindGetEndpointPlugin4(getEndpointFromConfig5) {
  const endpointMiddleware5 = bindEndpointMiddleware4(getEndpointFromConfig5);
  return (config2, instructions) => ({
    applyToStack: /* @__PURE__ */ __name((clientStack) => {
      clientStack.addRelativeTo(endpointMiddleware5({
        config: config2,
        instructions
      }), endpointMiddlewareOptions4);
    }, "applyToStack")
  });
}
var serializerMiddlewareOption8, endpointMiddlewareOptions4;
var init_getEndpointPlugin4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/getEndpointPlugin.js"() {
    init_endpointMiddleware4();
    serializerMiddlewareOption8 = {
      name: "serializerMiddleware",
      step: "serialize",
      tags: ["SERIALIZER"],
      override: true
    };
    endpointMiddlewareOptions4 = {
      step: "serialize",
      tags: ["ENDPOINT_PARAMETERS", "ENDPOINT_V2", "ENDPOINT"],
      name: "endpointV2Middleware",
      override: true,
      relation: "before",
      toMiddleware: serializerMiddlewareOption8.name
    };
    __name(bindGetEndpointPlugin4, "bindGetEndpointPlugin");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/resolveEndpointConfig.js
function bindResolveEndpointConfig4(getEndpointFromConfig5) {
  return (input) => {
    const tls = input.tls ?? true;
    const { endpoint, useDualstackEndpoint, useFipsEndpoint } = input;
    const customEndpointProvider = endpoint != null ? async () => toEndpointV16(await normalizeProvider25(endpoint)()) : void 0;
    const isCustomEndpoint = !!endpoint;
    const resolvedConfig = Object.assign(input, {
      endpoint: customEndpointProvider,
      tls,
      isCustomEndpoint,
      useDualstackEndpoint: normalizeProvider25(useDualstackEndpoint ?? false),
      useFipsEndpoint: normalizeProvider25(useFipsEndpoint ?? false)
    });
    let configuredEndpointPromise = void 0;
    resolvedConfig.serviceConfiguredEndpoint = async () => {
      if (input.serviceId && !configuredEndpointPromise) {
        configuredEndpointPromise = getEndpointFromConfig5(input.serviceId);
      }
      return configuredEndpointPromise;
    };
    return resolvedConfig;
  };
}
var init_resolveEndpointConfig4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/middleware-endpoint/resolveEndpointConfig.js"() {
    init_client16();
    init_toEndpointV19();
    __name(bindResolveEndpointConfig4, "bindResolveEndpointConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/EndpointError.js
var init_EndpointError5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/EndpointError.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/EndpointFunctions.js
var init_EndpointFunctions4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/EndpointFunctions.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/EndpointRuleObject.js
var init_EndpointRuleObject4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/EndpointRuleObject.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/ErrorRuleObject.js
var init_ErrorRuleObject4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/ErrorRuleObject.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/RuleSetObject.js
var init_RuleSetObject4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/RuleSetObject.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/TreeRuleObject.js
var init_TreeRuleObject4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/TreeRuleObject.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/shared.js
var init_shared4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/shared.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/index.js
var init_types11 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/types/index.js"() {
    init_EndpointError5();
    init_EndpointFunctions4();
    init_EndpointRuleObject4();
    init_ErrorRuleObject4();
    init_RuleSetObject4();
    init_TreeRuleObject4();
    init_shared4();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/isValidHostLabel.js
var VALID_HOST_LABEL_REGEX3, isValidHostLabel3;
var init_isValidHostLabel3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/util-endpoints/lib/isValidHostLabel.js"() {
    VALID_HOST_LABEL_REGEX3 = new RegExp(`^(?!.*-$)(?!-)[a-zA-Z0-9-]{1,63}$`);
    isValidHostLabel3 = /* @__PURE__ */ __name((value, allowSubDomains = false) => {
      if (!allowSubDomains) {
        return VALID_HOST_LABEL_REGEX3.test(value);
      }
      const labels = value.split(".");
      for (const label of labels) {
        if (!isValidHostLabel3(label)) {
          return false;
        }
      }
      return true;
    }, "isValidHostLabel");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/index.js
var getEndpointFromInstructions5, resolveEndpointConfig22, endpointMiddleware4, getEndpointPlugin28;
var init_endpoints5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/endpoints/index.js"() {
    init_getEndpointFromConfig4();
    init_getEndpointFromInstructions4();
    init_endpointMiddleware4();
    init_getEndpointPlugin4();
    init_resolveEndpointConfig4();
    init_toEndpointV18();
    init_isValidHostLabel3();
    init_types11();
    getEndpointFromInstructions5 = bindGetEndpointFromInstructions4(getEndpointFromConfig4);
    resolveEndpointConfig22 = bindResolveEndpointConfig4(getEndpointFromConfig4);
    endpointMiddleware4 = bindEndpointMiddleware4(getEndpointFromConfig4);
    getEndpointPlugin28 = bindGetEndpointPlugin4(getEndpointFromConfig4);
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-type-check.js
var isReadableStream4;
var init_stream_type_check4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-type-check.js"() {
    isReadableStream4 = /* @__PURE__ */ __name((stream) => typeof ReadableStream === "function" && (stream?.constructor?.name === ReadableStream.name || stream instanceof ReadableStream), "isReadableStream");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/fromUtf8.browser.js
var fromUtf830;
var init_fromUtf8_browser4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/fromUtf8.browser.js"() {
    fromUtf830 = /* @__PURE__ */ __name((input) => new TextEncoder().encode(input), "fromUtf8");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/constants-for-browser.js
var chars4, alphabetByEncoding4, alphabetByValue4, bitsPerLetter4, bitsPerByte4, maxLetterValue4;
var init_constants_for_browser4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/constants-for-browser.js"() {
    chars4 = `ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/`;
    alphabetByEncoding4 = Object.entries(chars4).reduce((acc, [i32, c32]) => {
      acc[c32] = Number(i32);
      return acc;
    }, {});
    alphabetByValue4 = chars4.split("");
    bitsPerLetter4 = 6;
    bitsPerByte4 = 8;
    maxLetterValue4 = 63;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/toBase64.browser.js
function toBase6446(_input) {
  let input;
  if (typeof _input === "string") {
    input = fromUtf830(_input);
  } else {
    input = _input;
  }
  const isArrayLike = typeof input === "object" && typeof input.length === "number";
  const isUint8Array = typeof input === "object" && typeof input.byteOffset === "number" && typeof input.byteLength === "number";
  if (!isArrayLike && !isUint8Array) {
    throw new Error("@smithy/util-base64: toBase64 encoder function only accepts string | Uint8Array.");
  }
  let str = "";
  for (let i32 = 0; i32 < input.length; i32 += 3) {
    let bits = 0;
    let bitLength = 0;
    for (let j32 = i32, limit = Math.min(i32 + 3, input.length); j32 < limit; j32++) {
      bits |= input[j32] << (limit - j32 - 1) * bitsPerByte4;
      bitLength += bitsPerByte4;
    }
    const bitClusterCount = Math.ceil(bitLength / bitsPerLetter4);
    bits <<= bitClusterCount * bitsPerLetter4 - bitLength;
    for (let k32 = 1; k32 <= bitClusterCount; k32++) {
      const offset = (bitClusterCount - k32) * bitsPerLetter4;
      str += alphabetByValue4[(bits & maxLetterValue4 << offset) >> offset];
    }
    str += "==".slice(0, 4 - bitClusterCount);
  }
  return str;
}
var init_toBase64_browser4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/toBase64.browser.js"() {
    init_fromUtf8_browser4();
    init_constants_for_browser4();
    __name(toBase6446, "toBase64");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/toUtf8.browser.js
var toUtf844;
var init_toUtf8_browser4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/toUtf8.browser.js"() {
    toUtf844 = /* @__PURE__ */ __name((input) => {
      if (typeof input === "string") {
        return input;
      }
      if (typeof input !== "object" || typeof input.byteOffset !== "number" || typeof input.byteLength !== "number") {
        throw new Error("@smithy/util-utf8: toUtf8 encoder function only accepts string | Uint8Array.");
      }
      return new TextDecoder("utf-8").decode(input);
    }, "toUtf8");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/fromBase64.browser.js
var fromBase6441;
var init_fromBase64_browser4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/fromBase64.browser.js"() {
    init_constants_for_browser4();
    fromBase6441 = /* @__PURE__ */ __name((input) => {
      let totalByteLength = input.length / 4 * 3;
      if (input.slice(-2) === "==") {
        totalByteLength -= 2;
      } else if (input.slice(-1) === "=") {
        totalByteLength--;
      }
      const out = new ArrayBuffer(totalByteLength);
      const dataView5 = new DataView(out);
      for (let i32 = 0; i32 < input.length; i32 += 4) {
        let bits = 0;
        let bitLength = 0;
        for (let j32 = i32, limit = i32 + 3; j32 <= limit; j32++) {
          if (input[j32] !== "=") {
            if (!(input[j32] in alphabetByEncoding4)) {
              throw new TypeError(`Invalid character ${input[j32]} in base64 string.`);
            }
            bits |= alphabetByEncoding4[input[j32]] << (limit - j32) * bitsPerLetter4;
            bitLength += bitsPerLetter4;
          } else {
            bits >>= bitsPerLetter4;
          }
        }
        const chunkOffset = i32 / 4 * 3;
        bits >>= bitLength % bitsPerByte4;
        const byteLength = Math.floor(bitLength / bitsPerByte4);
        for (let k32 = 0; k32 < byteLength; k32++) {
          const offset = (byteLength - k32 - 1) * bitsPerByte4;
          dataView5.setUint8(chunkOffset + k32, (bits & 255 << offset) >> offset);
        }
      }
      return new Uint8Array(out);
    }, "fromBase64");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-collector.browser.js
async function collectBlob4(blob) {
  const base64 = await readToBase644(blob);
  const arrayBuffer = fromBase6441(base64);
  return new Uint8Array(arrayBuffer);
}
async function collectStream4(stream) {
  const chunks2 = [];
  const reader = stream.getReader();
  let isDone = false;
  let length = 0;
  while (!isDone) {
    const { done, value } = await reader.read();
    if (value) {
      chunks2.push(value);
      length += value.length;
    }
    isDone = done;
  }
  const collected = new Uint8Array(length);
  let offset = 0;
  for (const chunk of chunks2) {
    collected.set(chunk, offset);
    offset += chunk.length;
  }
  return collected;
}
function readToBase644(blob) {
  return new Promise((resolve13, reject) => {
    const reader = new FileReader();
    reader.onloadend = () => {
      if (reader.readyState !== 2) {
        return reject(new Error("Reader aborted too early"));
      }
      const result2 = reader.result ?? "";
      const commaIndex = result2.indexOf(",");
      const dataOffset = commaIndex > -1 ? commaIndex + 1 : result2.length;
      resolve13(result2.substring(dataOffset));
    };
    reader.onabort = () => reject(new Error("Read aborted"));
    reader.onerror = () => reject(reader.error);
    reader.readAsDataURL(blob);
  });
}
var streamCollector25;
var init_stream_collector_browser4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-collector.browser.js"() {
    init_fromBase64_browser4();
    streamCollector25 = /* @__PURE__ */ __name(async (stream) => {
      if (typeof Blob === "function" && stream instanceof Blob || stream.constructor?.name === "Blob") {
        if (Blob.prototype.arrayBuffer !== void 0) {
          return new Uint8Array(await stream.arrayBuffer());
        }
        return collectBlob4(stream);
      }
      return collectStream4(stream);
    }, "streamCollector");
    __name(collectBlob4, "collectBlob");
    __name(collectStream4, "collectStream");
    __name(readToBase644, "readToBase64");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/sdk-stream-mixin.browser.js
var ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED7, sdkStreamMixin8, isBlobInstance4;
var init_sdk_stream_mixin_browser4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/sdk-stream-mixin.browser.js"() {
    init_toBase64_browser4();
    init_hex_encoding4();
    init_toUtf8_browser4();
    init_stream_collector_browser4();
    init_stream_type_check4();
    ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED7 = "The stream has already been transformed.";
    sdkStreamMixin8 = /* @__PURE__ */ __name((stream) => {
      if (!isBlobInstance4(stream) && !isReadableStream4(stream)) {
        const name = stream?.__proto__?.constructor?.name || stream;
        throw new Error(`Unexpected stream implementation, expect Blob or ReadableStream, got ${name}`);
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED7);
        }
        transformed = true;
        return await streamCollector25(stream);
      }, "transformToByteArray");
      const blobToWebStream = /* @__PURE__ */ __name((blob) => {
        if (typeof blob.stream !== "function") {
          throw new Error("Cannot transform payload Blob to web stream. Please make sure the Blob.stream() is polyfilled.\nIf you are using React Native, this API is not yet supported, see: https://react-native.canny.io/feature-requests/p/fetch-streaming-body");
        }
        return blob.stream();
      }, "blobToWebStream");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === "base64") {
            return toBase6446(buf);
          } else if (encoding === "hex") {
            return toHex4(buf);
          } else if (encoding === void 0 || encoding === "utf8" || encoding === "utf-8") {
            return toUtf844(buf);
          } else if (typeof TextDecoder === "function") {
            return new TextDecoder(encoding).decode(buf);
          } else {
            throw new Error("TextDecoder is not available, please make sure polyfill is provided.");
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED7);
          }
          transformed = true;
          if (isBlobInstance4(stream)) {
            return blobToWebStream(stream);
          } else if (isReadableStream4(stream)) {
            return stream;
          } else {
            throw new Error(`Cannot transform payload to web stream, got ${stream}`);
          }
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
    isBlobInstance4 = /* @__PURE__ */ __name((stream) => typeof Blob === "function" && stream instanceof Blob, "isBlobInstance");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-collector.js
async function collectReadableStream4(stream) {
  const chunks2 = [];
  const reader = stream.getReader();
  let isDone = false;
  let length = 0;
  while (!isDone) {
    const { done, value } = await reader.read();
    if (value) {
      chunks2.push(value);
      length += value.length;
    }
    isDone = done;
  }
  const collected = new Uint8Array(length);
  let offset = 0;
  for (const chunk of chunks2) {
    collected.set(chunk, offset);
    offset += chunk.length;
  }
  return collected;
}
var import_node_stream22, Collector6, isReadableStreamInstance4, streamCollector26;
var init_stream_collector4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-collector.js"() {
    import_node_stream22 = require("node:stream");
    Collector6 = class extends import_node_stream22.Writable {
      static {
        __name(this, "Collector");
      }
      bufferedBytes = [];
      _write(chunk, encoding, callback) {
        this.bufferedBytes.push(chunk);
        callback();
      }
    };
    isReadableStreamInstance4 = /* @__PURE__ */ __name((stream) => typeof ReadableStream === "function" && stream instanceof ReadableStream, "isReadableStreamInstance");
    __name(collectReadableStream4, "collectReadableStream");
    streamCollector26 = /* @__PURE__ */ __name((stream) => {
      if (isReadableStreamInstance4(stream)) {
        return collectReadableStream4(stream);
      }
      return new Promise((resolve13, reject) => {
        const collector = new Collector6();
        stream.pipe(collector);
        stream.on("error", (err) => {
          collector.end();
          reject(err);
        });
        collector.on("error", reject);
        collector.on("finish", function() {
          const bytes = new Uint8Array(Buffer.concat(this.bufferedBytes));
          resolve13(bytes);
        });
      });
    }, "streamCollector");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/sdk-stream-mixin.js
var import_node_stream23, ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED8, sdkStreamMixin9;
var init_sdk_stream_mixin4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/sdk-stream-mixin.js"() {
    import_node_stream23 = require("node:stream");
    init_buffer_from5();
    init_sdk_stream_mixin_browser4();
    init_stream_collector4();
    ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED8 = "The stream has already been transformed.";
    sdkStreamMixin9 = /* @__PURE__ */ __name((stream) => {
      if (!(stream instanceof import_node_stream23.Readable)) {
        try {
          return sdkStreamMixin8(stream);
        } catch (e32) {
          const name = stream?.__proto__?.constructor?.name || stream;
          throw new Error(`Unexpected stream implementation, expect Stream.Readable instance, got ${name}`);
        }
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED8);
        }
        transformed = true;
        return await streamCollector26(stream);
      }, "transformToByteArray");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === void 0 || Buffer.isEncoding(encoding)) {
            return fromArrayBuffer5(buf.buffer, buf.byteOffset, buf.byteLength).toString(encoding);
          } else {
            const decoder = new TextDecoder(encoding);
            return decoder.decode(buf);
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED8);
          }
          if (stream.readableFlowing !== null) {
            throw new Error("The stream has been consumed by other callbacks.");
          }
          if (typeof import_node_stream23.Readable.toWeb !== "function") {
            throw new Error("Readable.toWeb() is not supported. Please ensure a polyfill is available.");
          }
          transformed = true;
          return import_node_stream23.Readable.toWeb(stream);
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/index.js
var import_node_crypto14, Uint8ArrayBlobAdapter6, _getRandomValues5, v45, generateIdempotencyToken5;
var init_serde6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/serde/index.js"() {
    import_node_crypto14 = require("node:crypto");
    init_fromBase645();
    init_toBase645();
    init_Uint8ArrayBlobAdapter5();
    init_fromUtf85();
    init_toUtf85();
    init_v45();
    init_date_utils6();
    init_lazy_json5();
    init_quote_header5();
    init_schema_date_utils5();
    init_split_every5();
    init_split_header5();
    init_NumericValue5();
    init_hex_encoding4();
    init_sdk_stream_mixin4();
    Uint8ArrayBlobAdapter6 = class extends bindUint8ArrayBlobAdapter5(toUtf843, fromUtf829, toBase6445, fromBase6440) {
      static {
        __name(this, "Uint8ArrayBlobAdapter");
      }
    };
    _getRandomValues5 = import_node_crypto14.getRandomValues;
    v45 = bindV45(_getRandomValues5);
    generateIdempotencyToken5 = v45;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/collect-stream-body.js
var collectBody12;
var init_collect_stream_body6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/collect-stream-body.js"() {
    init_serde6();
    collectBody12 = /* @__PURE__ */ __name(async (streamBody = new Uint8Array(), context) => {
      if (streamBody instanceof Uint8Array) {
        return Uint8ArrayBlobAdapter6.mutate(streamBody);
      }
      if (!streamBody) {
        return Uint8ArrayBlobAdapter6.mutate(new Uint8Array());
      }
      const fromContext = context.streamCollector(streamBody);
      return Uint8ArrayBlobAdapter6.mutate(await fromContext);
    }, "collectBody");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/extended-encode-uri-component.js
function extendedEncodeURIComponent5(str) {
  return encodeURIComponent(str).replace(/[!'()*]/g, function(c32) {
    return "%" + c32.charCodeAt(0).toString(16).toUpperCase();
  });
}
var init_extended_encode_uri_component6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/extended-encode-uri-component.js"() {
    __name(extendedEncodeURIComponent5, "extendedEncodeURIComponent");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/SerdeContext.js
var SerdeContext5;
var init_SerdeContext6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/SerdeContext.js"() {
    SerdeContext5 = class {
      static {
        __name(this, "SerdeContext");
      }
      serdeContext;
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/httpRequest.js
function cloneQuery5(query) {
  return Object.keys(query).reduce((carry, paramName) => {
    const param = query[paramName];
    return {
      ...carry,
      [paramName]: Array.isArray(param) ? [...param] : param
    };
  }, {});
}
var HttpRequest24;
var init_httpRequest5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/httpRequest.js"() {
    HttpRequest24 = class _HttpRequest {
      static {
        __name(this, "HttpRequest");
      }
      method;
      protocol;
      hostname;
      port;
      path;
      query;
      headers;
      username;
      password;
      fragment;
      body;
      constructor(options) {
        this.method = options.method || "GET";
        this.hostname = options.hostname || "localhost";
        this.port = options.port;
        this.query = options.query || {};
        this.headers = options.headers || {};
        this.body = options.body;
        this.protocol = options.protocol ? options.protocol.slice(-1) !== ":" ? `${options.protocol}:` : options.protocol : "https:";
        this.path = options.path ? options.path.charAt(0) !== "/" ? `/${options.path}` : options.path : "/";
        this.username = options.username;
        this.password = options.password;
        this.fragment = options.fragment;
      }
      static clone(request4) {
        const cloned = new _HttpRequest({
          ...request4,
          headers: { ...request4.headers }
        });
        if (cloned.query) {
          cloned.query = cloneQuery5(cloned.query);
        }
        return cloned;
      }
      static isInstance(request4) {
        if (!request4) {
          return false;
        }
        const req = request4;
        return "method" in req && "protocol" in req && "hostname" in req && "path" in req && typeof req["query"] === "object" && typeof req["headers"] === "object";
      }
      clone() {
        return _HttpRequest.clone(this);
      }
    };
    __name(cloneQuery5, "cloneQuery");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/httpResponse.js
var HttpResponse13;
var init_httpResponse5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/httpResponse.js"() {
    HttpResponse13 = class {
      static {
        __name(this, "HttpResponse");
      }
      statusCode;
      reason;
      headers;
      body;
      constructor(options) {
        this.statusCode = options.statusCode;
        this.reason = options.reason;
        this.headers = options.headers || {};
        this.body = options.body;
      }
      static isInstance(response) {
        if (!response)
          return false;
        const resp = response;
        return typeof resp.statusCode === "number" && typeof resp.headers === "object";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/Int64.js
function negate4(bytes) {
  for (let i32 = 0; i32 < 8; i32++) {
    bytes[i32] ^= 255;
  }
  for (let i32 = 7; i32 > -1; i32--) {
    bytes[i32]++;
    if (bytes[i32] !== 0)
      break;
  }
}
var Int644;
var init_Int644 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/Int64.js"() {
    init_serde6();
    Int644 = class _Int64 {
      static {
        __name(this, "Int64");
      }
      bytes;
      constructor(bytes) {
        this.bytes = bytes;
        if (bytes.byteLength !== 8) {
          throw new Error("Int64 buffers must be exactly 8 bytes");
        }
      }
      static fromNumber(number) {
        if (number > 9223372036854776e3 || number < -9223372036854776e3) {
          throw new Error(`${number} is too large (or, if negative, too small) to represent as an Int64`);
        }
        const bytes = new Uint8Array(8);
        for (let i32 = 7, remaining = Math.abs(Math.round(number)); i32 > -1 && remaining > 0; i32--, remaining /= 256) {
          bytes[i32] = remaining;
        }
        if (number < 0) {
          negate4(bytes);
        }
        return new _Int64(bytes);
      }
      valueOf() {
        const bytes = this.bytes.slice(0);
        const negative = bytes[0] & 128;
        if (negative) {
          negate4(bytes);
        }
        return parseInt(toHex4(bytes), 16) * (negative ? -1 : 1);
      }
      toString() {
        return String(this.valueOf());
      }
    };
    __name(negate4, "negate");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/HeaderMarshaller.js
var HeaderMarshaller4, HEADER_VALUE_TYPE4, BOOLEAN_TAG4, BYTE_TAG4, SHORT_TAG4, INT_TAG4, LONG_TAG4, BINARY_TAG4, STRING_TAG4, TIMESTAMP_TAG4, UUID_TAG4, UUID_PATTERN4;
var init_HeaderMarshaller4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/HeaderMarshaller.js"() {
    init_serde6();
    init_Int644();
    HeaderMarshaller4 = class {
      static {
        __name(this, "HeaderMarshaller");
      }
      toUtf8;
      fromUtf8;
      constructor(toUtf862, fromUtf842) {
        this.toUtf8 = toUtf862;
        this.fromUtf8 = fromUtf842;
      }
      format(headers) {
        const chunks2 = [];
        for (const headerName of Object.keys(headers)) {
          const bytes = this.fromUtf8(headerName);
          chunks2.push(Uint8Array.from([bytes.byteLength]), bytes, this.formatHeaderValue(headers[headerName]));
        }
        const out = new Uint8Array(chunks2.reduce((carry, bytes) => carry + bytes.byteLength, 0));
        let position = 0;
        for (const chunk of chunks2) {
          out.set(chunk, position);
          position += chunk.byteLength;
        }
        return out;
      }
      formatHeaderValue(header) {
        switch (header.type) {
          case "boolean":
            return Uint8Array.from([header.value ? 0 : 1]);
          case "byte":
            return Uint8Array.from([2, header.value]);
          case "short":
            const shortView = new DataView(new ArrayBuffer(3));
            shortView.setUint8(0, 3);
            shortView.setInt16(1, header.value, false);
            return new Uint8Array(shortView.buffer);
          case "integer":
            const intView = new DataView(new ArrayBuffer(5));
            intView.setUint8(0, 4);
            intView.setInt32(1, header.value, false);
            return new Uint8Array(intView.buffer);
          case "long":
            const longBytes = new Uint8Array(9);
            longBytes[0] = 5;
            longBytes.set(header.value.bytes, 1);
            return longBytes;
          case "binary":
            const binView = new DataView(new ArrayBuffer(3 + header.value.byteLength));
            binView.setUint8(0, 6);
            binView.setUint16(1, header.value.byteLength, false);
            const binBytes = new Uint8Array(binView.buffer);
            binBytes.set(header.value, 3);
            return binBytes;
          case "string":
            const utf8Bytes = this.fromUtf8(header.value);
            const strView = new DataView(new ArrayBuffer(3 + utf8Bytes.byteLength));
            strView.setUint8(0, 7);
            strView.setUint16(1, utf8Bytes.byteLength, false);
            const strBytes = new Uint8Array(strView.buffer);
            strBytes.set(utf8Bytes, 3);
            return strBytes;
          case "timestamp":
            const tsBytes = new Uint8Array(9);
            tsBytes[0] = 8;
            tsBytes.set(Int644.fromNumber(header.value.valueOf()).bytes, 1);
            return tsBytes;
          case "uuid":
            if (!UUID_PATTERN4.test(header.value)) {
              throw new Error(`Invalid UUID received: ${header.value}`);
            }
            const uuidBytes = new Uint8Array(17);
            uuidBytes[0] = 9;
            uuidBytes.set(fromHex4(header.value.replace(/\-/g, "")), 1);
            return uuidBytes;
        }
      }
      parse(headers) {
        const out = {};
        let position = 0;
        while (position < headers.byteLength) {
          const nameLength = headers.getUint8(position++);
          const name = this.toUtf8(new Uint8Array(headers.buffer, headers.byteOffset + position, nameLength));
          position += nameLength;
          switch (headers.getUint8(position++)) {
            case 0:
              out[name] = {
                type: BOOLEAN_TAG4,
                value: true
              };
              break;
            case 1:
              out[name] = {
                type: BOOLEAN_TAG4,
                value: false
              };
              break;
            case 2:
              out[name] = {
                type: BYTE_TAG4,
                value: headers.getInt8(position++)
              };
              break;
            case 3:
              out[name] = {
                type: SHORT_TAG4,
                value: headers.getInt16(position, false)
              };
              position += 2;
              break;
            case 4:
              out[name] = {
                type: INT_TAG4,
                value: headers.getInt32(position, false)
              };
              position += 4;
              break;
            case 5:
              out[name] = {
                type: LONG_TAG4,
                value: new Int644(new Uint8Array(headers.buffer, headers.byteOffset + position, 8))
              };
              position += 8;
              break;
            case 6:
              const binaryLength = headers.getUint16(position, false);
              position += 2;
              out[name] = {
                type: BINARY_TAG4,
                value: new Uint8Array(headers.buffer, headers.byteOffset + position, binaryLength)
              };
              position += binaryLength;
              break;
            case 7:
              const stringLength = headers.getUint16(position, false);
              position += 2;
              out[name] = {
                type: STRING_TAG4,
                value: this.toUtf8(new Uint8Array(headers.buffer, headers.byteOffset + position, stringLength))
              };
              position += stringLength;
              break;
            case 8:
              out[name] = {
                type: TIMESTAMP_TAG4,
                value: new Date(new Int644(new Uint8Array(headers.buffer, headers.byteOffset + position, 8)).valueOf())
              };
              position += 8;
              break;
            case 9:
              const uuidBytes = new Uint8Array(headers.buffer, headers.byteOffset + position, 16);
              position += 16;
              out[name] = {
                type: UUID_TAG4,
                value: `${toHex4(uuidBytes.subarray(0, 4))}-${toHex4(uuidBytes.subarray(4, 6))}-${toHex4(uuidBytes.subarray(6, 8))}-${toHex4(uuidBytes.subarray(8, 10))}-${toHex4(uuidBytes.subarray(10))}`
              };
              break;
            default:
              throw new Error(`Unrecognized header type tag`);
          }
        }
        return out;
      }
    };
    (function(HEADER_VALUE_TYPE6) {
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["boolTrue"] = 0] = "boolTrue";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["boolFalse"] = 1] = "boolFalse";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["byte"] = 2] = "byte";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["short"] = 3] = "short";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["integer"] = 4] = "integer";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["long"] = 5] = "long";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["byteArray"] = 6] = "byteArray";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["string"] = 7] = "string";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["timestamp"] = 8] = "timestamp";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["uuid"] = 9] = "uuid";
    })(HEADER_VALUE_TYPE4 || (HEADER_VALUE_TYPE4 = {}));
    BOOLEAN_TAG4 = "boolean";
    BYTE_TAG4 = "byte";
    SHORT_TAG4 = "short";
    INT_TAG4 = "integer";
    LONG_TAG4 = "long";
    BINARY_TAG4 = "binary";
    STRING_TAG4 = "string";
    TIMESTAMP_TAG4 = "timestamp";
    UUID_TAG4 = "uuid";
    UUID_PATTERN4 = /^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$/;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/splitMessage.js
function splitMessage4({ byteLength, byteOffset, buffer }) {
  if (byteLength < MINIMUM_MESSAGE_LENGTH4) {
    throw new Error("Provided message too short to accommodate event stream message overhead");
  }
  const view = new DataView(buffer, byteOffset, byteLength);
  const messageLength = view.getUint32(0, false);
  if (byteLength !== messageLength) {
    throw new Error("Reported message length does not match received message length");
  }
  const headerLength = view.getUint32(PRELUDE_MEMBER_LENGTH4, false);
  const expectedPreludeChecksum = view.getUint32(PRELUDE_LENGTH4, false);
  const expectedMessageChecksum = view.getUint32(byteLength - CHECKSUM_LENGTH4, false);
  const checksummer = new import_crc327.Crc32().update(new Uint8Array(buffer, byteOffset, PRELUDE_LENGTH4));
  if (expectedPreludeChecksum !== checksummer.digest()) {
    throw new Error(`The prelude checksum specified in the message (${expectedPreludeChecksum}) does not match the calculated CRC32 checksum (${checksummer.digest()})`);
  }
  checksummer.update(new Uint8Array(buffer, byteOffset + PRELUDE_LENGTH4, byteLength - (PRELUDE_LENGTH4 + CHECKSUM_LENGTH4)));
  if (expectedMessageChecksum !== checksummer.digest()) {
    throw new Error(`The message checksum (${checksummer.digest()}) did not match the expected value of ${expectedMessageChecksum}`);
  }
  return {
    headers: new DataView(buffer, byteOffset + PRELUDE_LENGTH4 + CHECKSUM_LENGTH4, headerLength),
    body: new Uint8Array(buffer, byteOffset + PRELUDE_LENGTH4 + CHECKSUM_LENGTH4 + headerLength, messageLength - headerLength - (PRELUDE_LENGTH4 + CHECKSUM_LENGTH4 + CHECKSUM_LENGTH4))
  };
}
var import_crc327, PRELUDE_MEMBER_LENGTH4, PRELUDE_LENGTH4, CHECKSUM_LENGTH4, MINIMUM_MESSAGE_LENGTH4;
var init_splitMessage4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/splitMessage.js"() {
    import_crc327 = __toESM(require_main3());
    PRELUDE_MEMBER_LENGTH4 = 4;
    PRELUDE_LENGTH4 = PRELUDE_MEMBER_LENGTH4 * 2;
    CHECKSUM_LENGTH4 = 4;
    MINIMUM_MESSAGE_LENGTH4 = PRELUDE_LENGTH4 + CHECKSUM_LENGTH4 * 2;
    __name(splitMessage4, "splitMessage");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/EventStreamCodec.js
var import_crc328, EventStreamCodec4;
var init_EventStreamCodec4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/EventStreamCodec.js"() {
    import_crc328 = __toESM(require_main3());
    init_HeaderMarshaller4();
    init_splitMessage4();
    EventStreamCodec4 = class {
      static {
        __name(this, "EventStreamCodec");
      }
      headerMarshaller;
      messageBuffer;
      isEndOfStream;
      constructor(toUtf862, fromUtf842) {
        this.headerMarshaller = new HeaderMarshaller4(toUtf862, fromUtf842);
        this.messageBuffer = [];
        this.isEndOfStream = false;
      }
      feed(message2) {
        this.messageBuffer.push(this.decode(message2));
      }
      endOfStream() {
        this.isEndOfStream = true;
      }
      getMessage() {
        const message2 = this.messageBuffer.pop();
        const isEndOfStream = this.isEndOfStream;
        return {
          getMessage() {
            return message2;
          },
          isEndOfStream() {
            return isEndOfStream;
          }
        };
      }
      getAvailableMessages() {
        const messages = this.messageBuffer;
        this.messageBuffer = [];
        const isEndOfStream = this.isEndOfStream;
        return {
          getMessages() {
            return messages;
          },
          isEndOfStream() {
            return isEndOfStream;
          }
        };
      }
      encode({ headers: rawHeaders, body }) {
        const headers = this.headerMarshaller.format(rawHeaders);
        const length = headers.byteLength + body.byteLength + 16;
        const out = new Uint8Array(length);
        const view = new DataView(out.buffer, out.byteOffset, out.byteLength);
        const checksum = new import_crc328.Crc32();
        view.setUint32(0, length, false);
        view.setUint32(4, headers.byteLength, false);
        view.setUint32(8, checksum.update(out.subarray(0, 8)).digest(), false);
        out.set(headers, 12);
        out.set(body, headers.byteLength + 12);
        view.setUint32(length - 4, checksum.update(out.subarray(8, length - 4)).digest(), false);
        return out;
      }
      decode(message2) {
        const { headers, body } = splitMessage4(message2);
        return { headers: this.headerMarshaller.parse(headers), body };
      }
      formatHeaders(rawHeaders) {
        return this.headerMarshaller.format(rawHeaders);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/MessageDecoderStream.js
var MessageDecoderStream4;
var init_MessageDecoderStream4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/MessageDecoderStream.js"() {
    MessageDecoderStream4 = class {
      static {
        __name(this, "MessageDecoderStream");
      }
      options;
      constructor(options) {
        this.options = options;
      }
      [Symbol.asyncIterator]() {
        return this.asyncIterator();
      }
      async *asyncIterator() {
        for await (const bytes of this.options.inputStream) {
          const decoded = this.options.decoder.decode(bytes);
          yield decoded;
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/MessageEncoderStream.js
var MessageEncoderStream4;
var init_MessageEncoderStream4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/MessageEncoderStream.js"() {
    MessageEncoderStream4 = class {
      static {
        __name(this, "MessageEncoderStream");
      }
      options;
      constructor(options) {
        this.options = options;
      }
      [Symbol.asyncIterator]() {
        return this.asyncIterator();
      }
      async *asyncIterator() {
        for await (const msg of this.options.messageStream) {
          const encoded = this.options.encoder.encode(msg);
          yield encoded;
        }
        if (this.options.includeEndFrame) {
          yield new Uint8Array(0);
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/SmithyMessageDecoderStream.js
var SmithyMessageDecoderStream4;
var init_SmithyMessageDecoderStream4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/SmithyMessageDecoderStream.js"() {
    SmithyMessageDecoderStream4 = class {
      static {
        __name(this, "SmithyMessageDecoderStream");
      }
      options;
      constructor(options) {
        this.options = options;
      }
      [Symbol.asyncIterator]() {
        return this.asyncIterator();
      }
      async *asyncIterator() {
        for await (const message2 of this.options.messageStream) {
          const deserialized = await this.options.deserializer(message2);
          if (deserialized === void 0)
            continue;
          yield deserialized;
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/SmithyMessageEncoderStream.js
var SmithyMessageEncoderStream4;
var init_SmithyMessageEncoderStream4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/SmithyMessageEncoderStream.js"() {
    SmithyMessageEncoderStream4 = class {
      static {
        __name(this, "SmithyMessageEncoderStream");
      }
      options;
      constructor(options) {
        this.options = options;
      }
      [Symbol.asyncIterator]() {
        return this.asyncIterator();
      }
      async *asyncIterator() {
        for await (const chunk of this.options.inputStream) {
          const payloadBuf = this.options.serializer(chunk);
          yield payloadBuf;
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/getChunkedStream.js
function getChunkedStream4(source) {
  let currentMessageTotalLength = 0;
  let currentMessagePendingLength = 0;
  let currentMessage = null;
  let messageLengthBuffer = null;
  const allocateMessage = /* @__PURE__ */ __name((size) => {
    if (typeof size !== "number") {
      throw new Error("Attempted to allocate an event message where size was not a number: " + size);
    }
    currentMessageTotalLength = size;
    currentMessagePendingLength = 4;
    currentMessage = new Uint8Array(size);
    const currentMessageView = new DataView(currentMessage.buffer);
    currentMessageView.setUint32(0, size, false);
  }, "allocateMessage");
  const iterator = /* @__PURE__ */ __name(async function* () {
    const sourceIterator = source[Symbol.asyncIterator]();
    while (true) {
      const { value, done } = await sourceIterator.next();
      if (done) {
        if (!currentMessageTotalLength) {
          return;
        } else if (currentMessageTotalLength === currentMessagePendingLength) {
          yield currentMessage;
        } else {
          throw new Error("Truncated event message received.");
        }
        return;
      }
      const chunkLength = value.length;
      let currentOffset = 0;
      while (currentOffset < chunkLength) {
        if (!currentMessage) {
          const bytesRemaining = chunkLength - currentOffset;
          if (!messageLengthBuffer) {
            messageLengthBuffer = new Uint8Array(4);
          }
          const numBytesForTotal = Math.min(4 - currentMessagePendingLength, bytesRemaining);
          messageLengthBuffer.set(value.slice(currentOffset, currentOffset + numBytesForTotal), currentMessagePendingLength);
          currentMessagePendingLength += numBytesForTotal;
          currentOffset += numBytesForTotal;
          if (currentMessagePendingLength < 4) {
            break;
          }
          allocateMessage(new DataView(messageLengthBuffer.buffer).getUint32(0, false));
          messageLengthBuffer = null;
        }
        const numBytesToWrite = Math.min(currentMessageTotalLength - currentMessagePendingLength, chunkLength - currentOffset);
        currentMessage.set(value.slice(currentOffset, currentOffset + numBytesToWrite), currentMessagePendingLength);
        currentMessagePendingLength += numBytesToWrite;
        currentOffset += numBytesToWrite;
        if (currentMessageTotalLength && currentMessageTotalLength === currentMessagePendingLength) {
          yield currentMessage;
          currentMessage = null;
          currentMessageTotalLength = 0;
          currentMessagePendingLength = 0;
        }
      }
    }
  }, "iterator");
  return {
    [Symbol.asyncIterator]: iterator
  };
}
var init_getChunkedStream4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/getChunkedStream.js"() {
    __name(getChunkedStream4, "getChunkedStream");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/getUnmarshalledStream.js
function getUnmarshalledStream4(source, options) {
  const messageUnmarshaller = getMessageUnmarshaller4(options.deserializer, options.toUtf8);
  return {
    [Symbol.asyncIterator]: async function* () {
      for await (const chunk of source) {
        const message2 = options.eventStreamCodec.decode(chunk);
        const type = await messageUnmarshaller(message2);
        if (type === void 0)
          continue;
        yield type;
      }
    }
  };
}
function getMessageUnmarshaller4(deserializer, toUtf862) {
  return async function(message2) {
    const { value: messageType } = message2.headers[":message-type"];
    if (messageType === "error") {
      const unmodeledError = new Error(message2.headers[":error-message"].value || "UnknownError");
      unmodeledError.name = message2.headers[":error-code"].value;
      throw unmodeledError;
    } else if (messageType === "exception") {
      const code = message2.headers[":exception-type"].value;
      const exception = { [code]: message2 };
      const deserializedException = await deserializer(exception);
      if (deserializedException.$unknown) {
        const error4 = new Error(toUtf862(message2.body));
        error4.name = code;
        throw error4;
      }
      throw deserializedException[code];
    } else if (messageType === "event") {
      const event = {
        [message2.headers[":event-type"].value]: message2
      };
      const deserialized = await deserializer(event);
      if (deserialized.$unknown)
        return;
      return deserialized;
    } else {
      throw Error(`Unrecognizable event type: ${message2.headers[":event-type"].value}`);
    }
  };
}
var init_getUnmarshalledStream4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/getUnmarshalledStream.js"() {
    __name(getUnmarshalledStream4, "getUnmarshalledStream");
    __name(getMessageUnmarshaller4, "getMessageUnmarshaller");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/EventStreamMarshaller.js
var EventStreamMarshaller7, eventStreamSerdeProvider7;
var init_EventStreamMarshaller7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/EventStreamMarshaller.js"() {
    init_EventStreamCodec4();
    init_MessageDecoderStream4();
    init_MessageEncoderStream4();
    init_SmithyMessageDecoderStream4();
    init_SmithyMessageEncoderStream4();
    init_getChunkedStream4();
    init_getUnmarshalledStream4();
    EventStreamMarshaller7 = class {
      static {
        __name(this, "EventStreamMarshaller");
      }
      eventStreamCodec;
      utfEncoder;
      constructor({ utf8Encoder, utf8Decoder }) {
        this.eventStreamCodec = new EventStreamCodec4(utf8Encoder, utf8Decoder);
        this.utfEncoder = utf8Encoder;
      }
      deserialize(body, deserializer) {
        const inputStream = getChunkedStream4(body);
        return new SmithyMessageDecoderStream4({
          messageStream: new MessageDecoderStream4({ inputStream, decoder: this.eventStreamCodec }),
          deserializer: getMessageUnmarshaller4(deserializer, this.utfEncoder)
        });
      }
      serialize(inputStream, serializer) {
        return new MessageEncoderStream4({
          messageStream: new SmithyMessageEncoderStream4({ inputStream, serializer }),
          encoder: this.eventStreamCodec,
          includeEndFrame: true
        });
      }
    };
    eventStreamSerdeProvider7 = /* @__PURE__ */ __name((options) => new EventStreamMarshaller7(options), "eventStreamSerdeProvider");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde/EventStreamMarshaller.js
async function* readableToIterable4(readStream) {
  let streamEnded = false;
  let generationEnded = false;
  const records = new Array();
  readStream.on("error", (err) => {
    if (!streamEnded) {
      streamEnded = true;
    }
    if (err) {
      throw err;
    }
  });
  readStream.on("data", (data3) => {
    records.push(data3);
  });
  readStream.on("end", () => {
    streamEnded = true;
  });
  while (!generationEnded) {
    const value = await new Promise((resolve13) => setTimeout(() => resolve13(records.shift()), 0));
    if (value) {
      yield value;
    }
    generationEnded = streamEnded && records.length === 0;
  }
}
var import_node_stream24, EventStreamMarshaller8, eventStreamSerdeProvider8;
var init_EventStreamMarshaller8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde/EventStreamMarshaller.js"() {
    import_node_stream24 = require("node:stream");
    init_EventStreamMarshaller7();
    EventStreamMarshaller8 = class {
      static {
        __name(this, "EventStreamMarshaller");
      }
      universalMarshaller;
      constructor({ utf8Encoder, utf8Decoder }) {
        this.universalMarshaller = new EventStreamMarshaller7({
          utf8Decoder,
          utf8Encoder
        });
      }
      deserialize(body, deserializer) {
        const bodyIterable = typeof body[Symbol.asyncIterator] === "function" ? body : readableToIterable4(body);
        return this.universalMarshaller.deserialize(bodyIterable, deserializer);
      }
      serialize(input, serializer) {
        return import_node_stream24.Readable.from(this.universalMarshaller.serialize(input, serializer));
      }
    };
    eventStreamSerdeProvider8 = /* @__PURE__ */ __name((options) => new EventStreamMarshaller8(options), "eventStreamSerdeProvider");
    __name(readableToIterable4, "readableToIterable");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde/utils.js
var readableStreamToIterable4, iterableToReadableStream4;
var init_utils13 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde/utils.js"() {
    readableStreamToIterable4 = /* @__PURE__ */ __name((readableStream) => ({
      [Symbol.asyncIterator]: async function* () {
        const reader = readableStream.getReader();
        try {
          while (true) {
            const { done, value } = await reader.read();
            if (done)
              return;
            yield value;
          }
        } finally {
          reader.releaseLock();
        }
      }
    }), "readableStreamToIterable");
    iterableToReadableStream4 = /* @__PURE__ */ __name((asyncIterable) => {
      const iterator = asyncIterable[Symbol.asyncIterator]();
      return new ReadableStream({
        async pull(controller) {
          const { done, value } = await iterator.next();
          if (done) {
            return controller.close();
          }
          controller.enqueue(value);
        }
      });
    }, "iterableToReadableStream");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-config-resolver/EventStreamSerdeConfig.js
var resolveEventStreamSerdeConfig4;
var init_EventStreamSerdeConfig4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-config-resolver/EventStreamSerdeConfig.js"() {
    resolveEventStreamSerdeConfig4 = /* @__PURE__ */ __name((input) => Object.assign(input, {
      eventStreamMarshaller: input.eventStreamSerdeProvider(input)
    }), "resolveEventStreamSerdeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/EventStreamSerde.js
var EventStreamSerde5;
var init_EventStreamSerde5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/EventStreamSerde.js"() {
    init_serde6();
    EventStreamSerde5 = class {
      static {
        __name(this, "EventStreamSerde");
      }
      marshaller;
      serializer;
      deserializer;
      serdeContext;
      defaultContentType;
      constructor({ marshaller, serializer, deserializer, serdeContext, defaultContentType }) {
        this.marshaller = marshaller;
        this.serializer = serializer;
        this.deserializer = deserializer;
        this.serdeContext = serdeContext;
        this.defaultContentType = defaultContentType;
      }
      async serializeEventStream({ eventStream, requestSchema, initialRequest }) {
        const marshaller = this.marshaller;
        const eventStreamMember = requestSchema.getEventStreamMember();
        const unionSchema = requestSchema.getMemberSchema(eventStreamMember);
        const serializer = this.serializer;
        const defaultContentType = this.defaultContentType;
        const initialRequestMarker = /* @__PURE__ */ Symbol("initialRequestMarker");
        const eventStreamIterable = {
          async *[Symbol.asyncIterator]() {
            if (initialRequest) {
              const headers = {
                ":event-type": { type: "string", value: "initial-request" },
                ":message-type": { type: "string", value: "event" },
                ":content-type": { type: "string", value: defaultContentType }
              };
              serializer.write(requestSchema, initialRequest);
              const body = serializer.flush();
              yield {
                [initialRequestMarker]: true,
                headers,
                body
              };
            }
            for await (const page of eventStream) {
              yield page;
            }
          }
        };
        return marshaller.serialize(eventStreamIterable, (event) => {
          if (event[initialRequestMarker]) {
            return {
              headers: event.headers,
              body: event.body
            };
          }
          let unionMember = "";
          for (const key in event) {
            if (key !== "__type") {
              unionMember = key;
              break;
            }
          }
          const { additionalHeaders, body, eventType, explicitPayloadContentType } = this.writeEventBody(unionMember, unionSchema, event);
          const headers = {
            ":event-type": { type: "string", value: eventType },
            ":message-type": { type: "string", value: "event" },
            ":content-type": { type: "string", value: explicitPayloadContentType ?? defaultContentType },
            ...additionalHeaders
          };
          return {
            headers,
            body
          };
        });
      }
      async deserializeEventStream({ response, responseSchema, initialResponseContainer }) {
        const marshaller = this.marshaller;
        const eventStreamMember = responseSchema.getEventStreamMember();
        const unionSchema = responseSchema.getMemberSchema(eventStreamMember);
        const memberSchemas = unionSchema.getMemberSchemas();
        const initialResponseMarker = /* @__PURE__ */ Symbol("initialResponseMarker");
        const asyncIterable = marshaller.deserialize(response.body, async (event) => {
          let unionMember = "";
          for (const key in event) {
            if (key !== "__type") {
              unionMember = key;
              break;
            }
          }
          const body = event[unionMember].body;
          if (unionMember === "initial-response") {
            const dataObject = await this.deserializer.read(responseSchema, body);
            delete dataObject[eventStreamMember];
            return {
              [initialResponseMarker]: true,
              ...dataObject
            };
          } else if (unionMember in memberSchemas) {
            const eventStreamSchema = memberSchemas[unionMember];
            if (eventStreamSchema.isStructSchema()) {
              const out = {};
              let hasBindings = false;
              for (const [name, member7] of eventStreamSchema.structIterator()) {
                const { eventHeader, eventPayload } = member7.getMergedTraits();
                hasBindings = hasBindings || Boolean(eventHeader || eventPayload);
                if (eventPayload) {
                  if (member7.isBlobSchema()) {
                    out[name] = body;
                  } else if (member7.isStringSchema()) {
                    out[name] = (this.serdeContext?.utf8Encoder ?? toUtf843)(body);
                  } else if (member7.isStructSchema()) {
                    out[name] = await this.deserializer.read(member7, body);
                  }
                } else if (eventHeader) {
                  const value = event[unionMember].headers[name]?.value;
                  if (value != null) {
                    if (member7.isNumericSchema()) {
                      if (value && typeof value === "object" && "bytes" in value) {
                        out[name] = BigInt(value.toString());
                      } else {
                        out[name] = Number(value);
                      }
                    } else {
                      out[name] = value;
                    }
                  }
                }
              }
              if (hasBindings) {
                return {
                  [unionMember]: out
                };
              }
              if (body.byteLength === 0) {
                return {
                  [unionMember]: {}
                };
              }
            }
            return {
              [unionMember]: await this.deserializer.read(eventStreamSchema, body)
            };
          } else {
            return {
              $unknown: event
            };
          }
        });
        const asyncIterator = asyncIterable[Symbol.asyncIterator]();
        const firstEvent = await asyncIterator.next();
        if (firstEvent.done) {
          return asyncIterable;
        }
        if (firstEvent.value?.[initialResponseMarker]) {
          if (!responseSchema) {
            throw new Error("@smithy::core/protocols - initial-response event encountered in event stream but no response schema given.");
          }
          for (const key in firstEvent.value) {
            initialResponseContainer[key] = firstEvent.value[key];
          }
        }
        return {
          async *[Symbol.asyncIterator]() {
            if (!firstEvent?.value?.[initialResponseMarker]) {
              yield firstEvent.value;
            }
            while (true) {
              const { done, value } = await asyncIterator.next();
              if (done) {
                break;
              }
              yield value;
            }
          }
        };
      }
      writeEventBody(unionMember, unionSchema, event) {
        const serializer = this.serializer;
        let eventType = unionMember;
        let explicitPayloadMember = null;
        let explicitPayloadContentType;
        const isKnownSchema = (() => {
          const struct3 = unionSchema.getSchema();
          return struct3[4].includes(unionMember);
        })();
        const additionalHeaders = {};
        if (!isKnownSchema) {
          const [type, value] = event[unionMember];
          eventType = type;
          serializer.write(15, value);
        } else {
          const eventSchema = unionSchema.getMemberSchema(unionMember);
          if (eventSchema.isStructSchema()) {
            for (const [memberName, memberSchema] of eventSchema.structIterator()) {
              const { eventHeader, eventPayload } = memberSchema.getMergedTraits();
              if (eventPayload) {
                explicitPayloadMember = memberName;
              } else if (eventHeader) {
                const value = event[unionMember][memberName];
                let type = "binary";
                if (memberSchema.isNumericSchema()) {
                  if ((-2) ** 31 <= value && value <= 2 ** 31 - 1) {
                    type = "integer";
                  } else {
                    type = "long";
                  }
                } else if (memberSchema.isTimestampSchema()) {
                  type = "timestamp";
                } else if (memberSchema.isStringSchema()) {
                  type = "string";
                } else if (memberSchema.isBooleanSchema()) {
                  type = "boolean";
                }
                if (value != null) {
                  additionalHeaders[memberName] = {
                    type,
                    value
                  };
                  delete event[unionMember][memberName];
                }
              }
            }
            if (explicitPayloadMember !== null) {
              const payloadSchema = eventSchema.getMemberSchema(explicitPayloadMember);
              if (payloadSchema.isBlobSchema()) {
                explicitPayloadContentType = "application/octet-stream";
              } else if (payloadSchema.isStringSchema()) {
                explicitPayloadContentType = "text/plain";
              }
              serializer.write(payloadSchema, event[unionMember][explicitPayloadMember]);
            } else {
              serializer.write(eventSchema, event[unionMember]);
            }
          } else if (eventSchema.isUnitSchema()) {
            serializer.write(eventSchema, {});
          } else {
            throw new Error("@smithy/core/event-streams - non-struct member not supported in event stream union.");
          }
        }
        const messageSerialization = serializer.flush() ?? new Uint8Array();
        const body = typeof messageSerialization === "string" ? (this.serdeContext?.utf8Decoder ?? fromUtf829)(messageSerialization) : messageSerialization;
        return {
          body,
          eventType,
          explicitPayloadContentType,
          additionalHeaders
        };
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/index.js
var event_streams_exports5 = {};
__export(event_streams_exports5, {
  EventStreamCodec: () => EventStreamCodec4,
  EventStreamMarshaller: () => EventStreamMarshaller8,
  EventStreamSerde: () => EventStreamSerde5,
  HeaderMarshaller: () => HeaderMarshaller4,
  Int64: () => Int644,
  MessageDecoderStream: () => MessageDecoderStream4,
  MessageEncoderStream: () => MessageEncoderStream4,
  SmithyMessageDecoderStream: () => SmithyMessageDecoderStream4,
  SmithyMessageEncoderStream: () => SmithyMessageEncoderStream4,
  UniversalEventStreamMarshaller: () => EventStreamMarshaller7,
  eventStreamSerdeProvider: () => eventStreamSerdeProvider8,
  getChunkedStream: () => getChunkedStream4,
  getMessageUnmarshaller: () => getMessageUnmarshaller4,
  getUnmarshalledStream: () => getUnmarshalledStream4,
  iterableToReadableStream: () => iterableToReadableStream4,
  readableStreamToIterable: () => readableStreamToIterable4,
  resolveEventStreamSerdeConfig: () => resolveEventStreamSerdeConfig4,
  universalEventStreamSerdeProvider: () => eventStreamSerdeProvider7
});
var init_event_streams5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/event-streams/index.js"() {
    init_EventStreamCodec4();
    init_HeaderMarshaller4();
    init_Int644();
    init_MessageDecoderStream4();
    init_MessageEncoderStream4();
    init_SmithyMessageDecoderStream4();
    init_SmithyMessageEncoderStream4();
    init_EventStreamMarshaller8();
    init_utils13();
    init_EventStreamMarshaller7();
    init_getChunkedStream4();
    init_getUnmarshalledStream4();
    init_EventStreamSerdeConfig4();
    init_EventStreamSerde5();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/HttpProtocol.js
var HttpProtocol5;
var init_HttpProtocol6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/HttpProtocol.js"() {
    init_schema8();
    init_SerdeContext6();
    init_httpRequest5();
    init_httpResponse5();
    HttpProtocol5 = class extends SerdeContext5 {
      static {
        __name(this, "HttpProtocol");
      }
      options;
      compositeErrorRegistry;
      constructor(options) {
        super();
        this.options = options;
        this.compositeErrorRegistry = TypeRegistry5.for(options.defaultNamespace);
        for (const etr of options.errorTypeRegistries ?? []) {
          this.compositeErrorRegistry.copyFrom(etr);
        }
      }
      getRequestType() {
        return HttpRequest24;
      }
      getResponseType() {
        return HttpResponse13;
      }
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
        this.serializer.setSerdeContext(serdeContext);
        this.deserializer.setSerdeContext(serdeContext);
        if (this.getPayloadCodec()) {
          this.getPayloadCodec().setSerdeContext(serdeContext);
        }
      }
      updateServiceEndpoint(request4, endpoint) {
        if ("url" in endpoint) {
          request4.protocol = endpoint.url.protocol;
          request4.hostname = endpoint.url.hostname;
          request4.port = endpoint.url.port ? Number(endpoint.url.port) : void 0;
          request4.path = endpoint.url.pathname;
          request4.fragment = endpoint.url.hash || void 0;
          request4.username = endpoint.url.username || void 0;
          request4.password = endpoint.url.password || void 0;
          if (!request4.query) {
            request4.query = {};
          }
          for (const [k32, v] of endpoint.url.searchParams.entries()) {
            request4.query[k32] = v;
          }
          if (endpoint.headers) {
            for (const name in endpoint.headers) {
              request4.headers[name] = endpoint.headers[name].join(", ");
            }
          }
          return request4;
        } else {
          request4.protocol = endpoint.protocol;
          request4.hostname = endpoint.hostname;
          request4.port = endpoint.port ? Number(endpoint.port) : void 0;
          request4.path = endpoint.path;
          request4.query = {
            ...endpoint.query
          };
          if (endpoint.headers) {
            for (const name in endpoint.headers) {
              request4.headers[name] = endpoint.headers[name];
            }
          }
          return request4;
        }
      }
      setHostPrefix(request4, operationSchema, input) {
        if (this.serdeContext?.disableHostPrefix) {
          return;
        }
        const inputNs = NormalizedSchema5.of(operationSchema.input);
        const opTraits = translateTraits5(operationSchema.traits ?? {});
        if (opTraits.endpoint) {
          let hostPrefix = opTraits.endpoint?.[0];
          if (typeof hostPrefix === "string") {
            for (const [name, member7] of inputNs.structIterator()) {
              if (!member7.getMergedTraits().hostLabel) {
                continue;
              }
              const replacement = input[name];
              if (typeof replacement !== "string") {
                throw new Error(`@smithy/core/schema - ${name} in input must be a string as hostLabel.`);
              }
              hostPrefix = hostPrefix.replace(`{${name}}`, replacement);
            }
            request4.hostname = hostPrefix + request4.hostname;
          }
        }
      }
      deserializeMetadata(output) {
        return {
          httpStatusCode: output.statusCode,
          requestId: output.headers["x-amzn-requestid"] ?? output.headers["x-amzn-request-id"] ?? output.headers["x-amz-request-id"],
          extendedRequestId: output.headers["x-amz-id-2"],
          cfId: output.headers["x-amz-cf-id"]
        };
      }
      async serializeEventStream({ eventStream, requestSchema, initialRequest }) {
        const eventStreamSerde = await this.loadEventStreamCapability();
        return eventStreamSerde.serializeEventStream({
          eventStream,
          requestSchema,
          initialRequest
        });
      }
      async deserializeEventStream({ response, responseSchema, initialResponseContainer }) {
        const eventStreamSerde = await this.loadEventStreamCapability();
        return eventStreamSerde.deserializeEventStream({
          response,
          responseSchema,
          initialResponseContainer
        });
      }
      async loadEventStreamCapability() {
        const { EventStreamSerde: EventStreamSerde7 } = await Promise.resolve().then(() => (init_event_streams5(), event_streams_exports5));
        return new EventStreamSerde7({
          marshaller: this.getEventStreamMarshaller(),
          serializer: this.serializer,
          deserializer: this.deserializer,
          serdeContext: this.serdeContext,
          defaultContentType: this.getDefaultContentType()
        });
      }
      getDefaultContentType() {
        throw new Error(`@smithy/core/protocols - ${this.constructor.name} getDefaultContentType() implementation missing.`);
      }
      async deserializeHttpMessage(schema, context, response, arg4, arg5) {
        void schema;
        void context;
        void response;
        void arg4;
        void arg5;
        return [];
      }
      getEventStreamMarshaller() {
        const context = this.serdeContext;
        if (!context.eventStreamMarshaller) {
          throw new Error("@smithy/core - HttpProtocol: eventStreamMarshaller missing in serdeContext.");
        }
        return context.eventStreamMarshaller;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/HttpBindingProtocol.js
var HttpBindingProtocol5;
var init_HttpBindingProtocol6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/HttpBindingProtocol.js"() {
    init_schema8();
    init_serde6();
    init_HttpProtocol6();
    init_collect_stream_body6();
    init_extended_encode_uri_component6();
    init_httpRequest5();
    HttpBindingProtocol5 = class extends HttpProtocol5 {
      static {
        __name(this, "HttpBindingProtocol");
      }
      async serializeRequest(operationSchema, _input, context) {
        const input = _input && typeof _input === "object" ? _input : {};
        const serializer = this.serializer;
        const query = {};
        const headers = {};
        const endpoint = await context.endpoint();
        const ns = NormalizedSchema5.of(operationSchema?.input);
        const payloadMemberNames = [];
        const payloadMemberSchemas = [];
        let hasNonHttpBindingMember = false;
        let payload3;
        const request4 = new HttpRequest24({
          protocol: "",
          hostname: "",
          port: void 0,
          path: "",
          fragment: void 0,
          query,
          headers,
          body: void 0
        });
        if (endpoint) {
          this.updateServiceEndpoint(request4, endpoint);
          this.setHostPrefix(request4, operationSchema, input);
          const opTraits = translateTraits5(operationSchema.traits);
          if (opTraits.http) {
            request4.method = opTraits.http[0];
            const [path47, search] = opTraits.http[1].split("?");
            if (request4.path == "/") {
              request4.path = path47;
            } else {
              request4.path += path47;
            }
            const traitSearchParams = new URLSearchParams(search ?? "");
            for (const [key, value] of traitSearchParams) {
              query[key] = value;
            }
          }
        }
        for (const [memberName, memberNs] of ns.structIterator()) {
          const memberTraits = memberNs.getMergedTraits() ?? {};
          const inputMemberValue = input[memberName];
          if (inputMemberValue == null && !memberNs.isIdempotencyToken()) {
            if (memberTraits.httpLabel) {
              if (request4.path.includes(`{${memberName}+}`) || request4.path.includes(`{${memberName}}`)) {
                throw new Error(`No value provided for input HTTP label: ${memberName}.`);
              }
            }
            continue;
          }
          if (memberTraits.httpPayload) {
            const isStreaming = memberNs.isStreaming();
            if (isStreaming) {
              const isEventStream = memberNs.isStructSchema();
              if (isEventStream) {
                if (input[memberName]) {
                  payload3 = await this.serializeEventStream({
                    eventStream: input[memberName],
                    requestSchema: ns
                  });
                }
              } else {
                payload3 = inputMemberValue;
              }
            } else {
              serializer.write(memberNs, inputMemberValue);
              payload3 = serializer.flush();
            }
          } else if (memberTraits.httpLabel) {
            serializer.write(memberNs, inputMemberValue);
            const replacement = serializer.flush();
            if (request4.path.includes(`{${memberName}+}`)) {
              request4.path = request4.path.replace(`{${memberName}+}`, replacement.split("/").map(extendedEncodeURIComponent5).join("/"));
            } else if (request4.path.includes(`{${memberName}}`)) {
              request4.path = request4.path.replace(`{${memberName}}`, extendedEncodeURIComponent5(replacement));
            }
          } else if (memberTraits.httpHeader) {
            serializer.write(memberNs, inputMemberValue);
            headers[memberTraits.httpHeader.toLowerCase()] = String(serializer.flush());
          } else if (typeof memberTraits.httpPrefixHeaders === "string") {
            for (const key in inputMemberValue) {
              const val = inputMemberValue[key];
              const amalgam = memberTraits.httpPrefixHeaders + key;
              serializer.write([memberNs.getValueSchema(), { httpHeader: amalgam }], val);
              headers[amalgam.toLowerCase()] = serializer.flush();
            }
          } else if (memberTraits.httpQuery || memberTraits.httpQueryParams) {
            this.serializeQuery(memberNs, inputMemberValue, query);
          } else {
            hasNonHttpBindingMember = true;
            payloadMemberNames.push(memberName);
            payloadMemberSchemas.push(memberNs);
          }
        }
        if (hasNonHttpBindingMember && input) {
          const [namespace, name] = (ns.getName(true) ?? "#Unknown").split("#");
          const requiredMembers = ns.getSchema()[6];
          const payloadSchema = [
            3,
            namespace,
            name,
            ns.getMergedTraits(),
            payloadMemberNames,
            payloadMemberSchemas,
            void 0
          ];
          if (requiredMembers) {
            payloadSchema[6] = requiredMembers;
          } else {
            payloadSchema.pop();
          }
          serializer.write(payloadSchema, input);
          payload3 = serializer.flush();
        }
        request4.headers = headers;
        request4.query = query;
        request4.body = payload3;
        return request4;
      }
      serializeQuery(ns, data3, query) {
        const serializer = this.serializer;
        const traits = ns.getMergedTraits();
        if (traits.httpQueryParams) {
          for (const key in data3) {
            if (!(key in query)) {
              const val = data3[key];
              const valueSchema = ns.getValueSchema();
              Object.assign(valueSchema.getMergedTraits(), {
                ...traits,
                httpQuery: key,
                httpQueryParams: void 0
              });
              this.serializeQuery(valueSchema, val, query);
            }
          }
          return;
        }
        if (ns.isListSchema()) {
          const sparse = !!ns.getMergedTraits().sparse;
          const buffer = [];
          for (const item of data3) {
            serializer.write([ns.getValueSchema(), traits], item);
            const serializable = serializer.flush();
            if (sparse || serializable !== void 0) {
              buffer.push(serializable);
            }
          }
          query[traits.httpQuery] = buffer;
        } else {
          serializer.write([ns, traits], data3);
          query[traits.httpQuery] = serializer.flush();
        }
      }
      async deserializeResponse(operationSchema, context, response) {
        const deserializer = this.deserializer;
        const ns = NormalizedSchema5.of(operationSchema.output);
        const dataObject = {};
        if (response.statusCode >= 300) {
          const bytes = await collectBody12(response.body, context);
          if (bytes.byteLength > 0) {
            Object.assign(dataObject, await deserializer.read(15, bytes));
          }
          await this.handleError(operationSchema, context, response, dataObject, this.deserializeMetadata(response));
          throw new Error("@smithy/core/protocols - HTTP Protocol error handler failed to throw.");
        }
        for (const header in response.headers) {
          const value = response.headers[header];
          delete response.headers[header];
          response.headers[header.toLowerCase()] = value;
        }
        const nonHttpBindingMembers = await this.deserializeHttpMessage(ns, context, response, dataObject);
        if (nonHttpBindingMembers.length) {
          const bytes = await collectBody12(response.body, context);
          if (bytes.byteLength > 0) {
            const dataFromBody = await deserializer.read(ns, bytes);
            for (const member7 of nonHttpBindingMembers) {
              if (dataFromBody[member7] != null) {
                dataObject[member7] = dataFromBody[member7];
              }
            }
          }
        } else if (nonHttpBindingMembers.discardResponseBody) {
          await collectBody12(response.body, context);
        }
        dataObject.$metadata = this.deserializeMetadata(response);
        return dataObject;
      }
      async deserializeHttpMessage(schema, context, response, arg4, arg5) {
        let dataObject;
        if (arg4 instanceof Set) {
          dataObject = arg5;
        } else {
          dataObject = arg4;
        }
        let discardResponseBody = true;
        const deserializer = this.deserializer;
        const ns = NormalizedSchema5.of(schema);
        const nonHttpBindingMembers = [];
        for (const [memberName, memberSchema] of ns.structIterator()) {
          const memberTraits = memberSchema.getMemberTraits();
          if (memberTraits.httpPayload) {
            discardResponseBody = false;
            const isStreaming = memberSchema.isStreaming();
            if (isStreaming) {
              const isEventStream = memberSchema.isStructSchema();
              if (isEventStream) {
                dataObject[memberName] = await this.deserializeEventStream({
                  response,
                  responseSchema: ns
                });
              } else {
                dataObject[memberName] = sdkStreamMixin9(response.body);
              }
            } else if (response.body) {
              const bytes = await collectBody12(response.body, context);
              if (bytes.byteLength > 0) {
                dataObject[memberName] = await deserializer.read(memberSchema, bytes);
              }
            }
          } else if (memberTraits.httpHeader) {
            const key = String(memberTraits.httpHeader).toLowerCase();
            const value = response.headers[key];
            if (null != value) {
              if (memberSchema.isListSchema()) {
                const headerListValueSchema = memberSchema.getValueSchema();
                headerListValueSchema.getMergedTraits().httpHeader = key;
                let sections;
                if (headerListValueSchema.isTimestampSchema() && headerListValueSchema.getSchema() === 4) {
                  sections = splitEvery5(value, ",", 2);
                } else {
                  sections = splitHeader5(value);
                }
                const list3 = [];
                for (const section of sections) {
                  list3.push(await deserializer.read(headerListValueSchema, section.trim()));
                }
                dataObject[memberName] = list3;
              } else {
                dataObject[memberName] = await deserializer.read(memberSchema, value);
              }
            }
          } else if (memberTraits.httpPrefixHeaders !== void 0) {
            dataObject[memberName] = {};
            for (const header in response.headers) {
              if (header.startsWith(memberTraits.httpPrefixHeaders)) {
                const value = response.headers[header];
                const valueSchema = memberSchema.getValueSchema();
                valueSchema.getMergedTraits().httpHeader = header;
                dataObject[memberName][header.slice(memberTraits.httpPrefixHeaders.length)] = await deserializer.read(valueSchema, value);
              }
            }
          } else if (memberTraits.httpResponseCode) {
            dataObject[memberName] = response.statusCode;
          } else {
            nonHttpBindingMembers.push(memberName);
          }
        }
        nonHttpBindingMembers.discardResponseBody = discardResponseBody;
        return nonHttpBindingMembers;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/RpcProtocol.js
var RpcProtocol5;
var init_RpcProtocol6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/RpcProtocol.js"() {
    init_schema8();
    init_HttpProtocol6();
    init_collect_stream_body6();
    init_httpRequest5();
    RpcProtocol5 = class extends HttpProtocol5 {
      static {
        __name(this, "RpcProtocol");
      }
      async serializeRequest(operationSchema, _input, context) {
        const serializer = this.serializer;
        const query = {};
        const headers = {};
        const endpoint = await context.endpoint();
        const ns = NormalizedSchema5.of(operationSchema?.input);
        const schema = ns.getSchema();
        let payload3;
        const input = _input && typeof _input === "object" ? _input : {};
        const request4 = new HttpRequest24({
          protocol: "",
          hostname: "",
          port: void 0,
          path: "/",
          fragment: void 0,
          query,
          headers,
          body: void 0
        });
        if (endpoint) {
          this.updateServiceEndpoint(request4, endpoint);
          this.setHostPrefix(request4, operationSchema, input);
        }
        if (input) {
          const eventStreamMember = ns.getEventStreamMember();
          if (eventStreamMember) {
            if (input[eventStreamMember]) {
              const initialRequest = {};
              for (const [memberName, memberSchema] of ns.structIterator()) {
                if (memberName !== eventStreamMember && input[memberName]) {
                  serializer.write(memberSchema, input[memberName]);
                  initialRequest[memberName] = serializer.flush();
                }
              }
              payload3 = await this.serializeEventStream({
                eventStream: input[eventStreamMember],
                requestSchema: ns,
                initialRequest
              });
            }
          } else {
            serializer.write(schema, input);
            payload3 = serializer.flush();
          }
        }
        request4.headers = Object.assign(request4.headers, headers);
        request4.query = query;
        request4.body = payload3;
        request4.method = "POST";
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        const deserializer = this.deserializer;
        const ns = NormalizedSchema5.of(operationSchema.output);
        const dataObject = {};
        if (response.statusCode >= 300) {
          const bytes = await collectBody12(response.body, context);
          if (bytes.byteLength > 0) {
            Object.assign(dataObject, await deserializer.read(15, bytes));
          }
          await this.handleError(operationSchema, context, response, dataObject, this.deserializeMetadata(response));
          throw new Error("@smithy/core/protocols - RPC Protocol error handler failed to throw.");
        }
        for (const header in response.headers) {
          const value = response.headers[header];
          delete response.headers[header];
          response.headers[header.toLowerCase()] = value;
        }
        const eventStreamMember = ns.getEventStreamMember();
        if (eventStreamMember) {
          dataObject[eventStreamMember] = await this.deserializeEventStream({
            response,
            responseSchema: ns,
            initialResponseContainer: dataObject
          });
        } else {
          const bytes = await collectBody12(response.body, context);
          if (bytes.byteLength > 0) {
            Object.assign(dataObject, await deserializer.read(ns, bytes));
          }
        }
        dataObject.$metadata = this.deserializeMetadata(response);
        return dataObject;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/resolve-path.js
var resolvedPath5;
var init_resolve_path6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/resolve-path.js"() {
    init_extended_encode_uri_component6();
    resolvedPath5 = /* @__PURE__ */ __name((resolvedPath7, input, memberName, labelValueProvider, uriLabel, isGreedyLabel) => {
      if (input != null && input[memberName] !== void 0) {
        const labelValue = labelValueProvider();
        if (labelValue == null || labelValue.length <= 0) {
          throw new Error("Empty value provided for input HTTP label: " + memberName + ".");
        }
        resolvedPath7 = resolvedPath7.replace(uriLabel, isGreedyLabel ? labelValue.split("/").map((segment) => extendedEncodeURIComponent5(segment)).join("/") : extendedEncodeURIComponent5(labelValue));
      } else {
        throw new Error("No value provided for input HTTP label: " + memberName + ".");
      }
      return resolvedPath7;
    }, "resolvedPath");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/requestBuilder.js
function requestBuilder5(input, context) {
  return new RequestBuilder5(input, context);
}
var RequestBuilder5;
var init_requestBuilder8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/requestBuilder.js"() {
    init_httpRequest5();
    init_resolve_path6();
    __name(requestBuilder5, "requestBuilder");
    RequestBuilder5 = class {
      static {
        __name(this, "RequestBuilder");
      }
      input;
      context;
      query = {};
      method = "";
      headers = {};
      path = "";
      body = null;
      hostname = "";
      resolvePathStack = [];
      constructor(input, context) {
        this.input = input;
        this.context = context;
      }
      async build() {
        const { hostname, protocol = "https", port, path: basePath } = await this.context.endpoint();
        this.path = basePath;
        for (const resolvePath of this.resolvePathStack) {
          resolvePath(this.path);
        }
        return new HttpRequest24({
          protocol,
          hostname: this.hostname || hostname,
          port,
          method: this.method,
          path: this.path,
          query: this.query,
          body: this.body,
          headers: this.headers
        });
      }
      hn(hostname) {
        this.hostname = hostname;
        return this;
      }
      bp(uriLabel) {
        this.resolvePathStack.push((basePath) => {
          this.path = `${basePath?.endsWith("/") ? basePath.slice(0, -1) : basePath || ""}` + uriLabel;
        });
        return this;
      }
      p(memberName, labelValueProvider, uriLabel, isGreedyLabel) {
        this.resolvePathStack.push((path47) => {
          this.path = resolvedPath5(path47, this.input, memberName, labelValueProvider, uriLabel, isGreedyLabel);
        });
        return this;
      }
      h(headers) {
        this.headers = headers;
        return this;
      }
      q(query) {
        this.query = query;
        return this;
      }
      b(body) {
        this.body = body;
        return this;
      }
      m(method) {
        this.method = method;
        return this;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/serde/determineTimestampFormat.js
function determineTimestampFormat5(ns, settings) {
  if (settings.timestampFormat.useTrait) {
    if (ns.isTimestampSchema() && (ns.getSchema() === 5 || ns.getSchema() === 6 || ns.getSchema() === 7)) {
      return ns.getSchema();
    }
  }
  const { httpLabel, httpPrefixHeaders, httpHeader, httpQuery } = ns.getMergedTraits();
  const bindingFormat = settings.httpBindings ? typeof httpPrefixHeaders === "string" || Boolean(httpHeader) ? 6 : Boolean(httpQuery) || Boolean(httpLabel) ? 5 : void 0 : void 0;
  return bindingFormat ?? settings.timestampFormat.default;
}
var init_determineTimestampFormat6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/serde/determineTimestampFormat.js"() {
    __name(determineTimestampFormat5, "determineTimestampFormat");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/serde/FromStringShapeDeserializer.js
var FromStringShapeDeserializer5;
var init_FromStringShapeDeserializer6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/serde/FromStringShapeDeserializer.js"() {
    init_schema8();
    init_serde6();
    init_SerdeContext6();
    init_determineTimestampFormat6();
    FromStringShapeDeserializer5 = class extends SerdeContext5 {
      static {
        __name(this, "FromStringShapeDeserializer");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      read(_schema, data3) {
        const ns = NormalizedSchema5.of(_schema);
        if (ns.isListSchema()) {
          return splitHeader5(data3).map((item) => this.read(ns.getValueSchema(), item));
        }
        if (ns.isBlobSchema()) {
          return (this.serdeContext?.base64Decoder ?? fromBase6440)(data3);
        }
        if (ns.isTimestampSchema()) {
          const format32 = determineTimestampFormat5(ns, this.settings);
          switch (format32) {
            case 5:
              return _parseRfc3339DateTimeWithOffset5(data3);
            case 6:
              return _parseRfc7231DateTime5(data3);
            case 7:
              return _parseEpochTimestamp5(data3);
            default:
              console.warn("Missing timestamp format, parsing value with Date constructor:", data3);
              return new Date(data3);
          }
        }
        if (ns.isStringSchema()) {
          const mediaType = ns.getMergedTraits().mediaType;
          let intermediateValue = data3;
          if (mediaType) {
            if (ns.getMergedTraits().httpHeader) {
              intermediateValue = this.base64ToUtf8(intermediateValue);
            }
            const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
            if (isJson) {
              intermediateValue = LazyJsonString9.from(intermediateValue);
            }
            return intermediateValue;
          }
        }
        if (ns.isNumericSchema()) {
          return Number(data3);
        }
        if (ns.isBigIntegerSchema()) {
          return BigInt(data3);
        }
        if (ns.isBigDecimalSchema()) {
          return new NumericValue5(data3, "bigDecimal");
        }
        if (ns.isBooleanSchema()) {
          return String(data3).toLowerCase() === "true";
        }
        return data3;
      }
      base64ToUtf8(base64String) {
        return (this.serdeContext?.utf8Encoder ?? toUtf843)((this.serdeContext?.base64Decoder ?? fromBase6440)(base64String));
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/serde/HttpInterceptingShapeDeserializer.js
var HttpInterceptingShapeDeserializer5;
var init_HttpInterceptingShapeDeserializer6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/serde/HttpInterceptingShapeDeserializer.js"() {
    init_schema8();
    init_serde6();
    init_SerdeContext6();
    init_FromStringShapeDeserializer6();
    HttpInterceptingShapeDeserializer5 = class extends SerdeContext5 {
      static {
        __name(this, "HttpInterceptingShapeDeserializer");
      }
      codecDeserializer;
      stringDeserializer;
      constructor(codecDeserializer, codecSettings) {
        super();
        this.codecDeserializer = codecDeserializer;
        this.stringDeserializer = new FromStringShapeDeserializer5(codecSettings);
      }
      setSerdeContext(serdeContext) {
        this.stringDeserializer.setSerdeContext(serdeContext);
        this.codecDeserializer.setSerdeContext(serdeContext);
        this.serdeContext = serdeContext;
      }
      read(schema, data3) {
        const ns = NormalizedSchema5.of(schema);
        const traits = ns.getMergedTraits();
        const toString = this.serdeContext?.utf8Encoder ?? toUtf843;
        if (traits.httpHeader || traits.httpResponseCode) {
          return this.stringDeserializer.read(ns, toString(data3));
        }
        if (traits.httpPayload) {
          if (ns.isBlobSchema()) {
            const toBytes = this.serdeContext?.utf8Decoder ?? fromUtf829;
            if (typeof data3 === "string") {
              return toBytes(data3);
            }
            return data3;
          } else if (ns.isStringSchema()) {
            if ("byteLength" in data3) {
              return toString(data3);
            }
            return data3;
          }
        }
        return this.codecDeserializer.read(ns, data3);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/serde/ToStringShapeSerializer.js
var ToStringShapeSerializer5;
var init_ToStringShapeSerializer6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/serde/ToStringShapeSerializer.js"() {
    init_schema8();
    init_serde6();
    init_SerdeContext6();
    init_determineTimestampFormat6();
    ToStringShapeSerializer5 = class extends SerdeContext5 {
      static {
        __name(this, "ToStringShapeSerializer");
      }
      settings;
      stringBuffer = "";
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value) {
        const ns = NormalizedSchema5.of(schema);
        switch (typeof value) {
          case "object":
            if (value === null) {
              this.stringBuffer = "null";
              return;
            }
            if (ns.isTimestampSchema()) {
              if (!(value instanceof Date)) {
                throw new Error(`@smithy/core/protocols - received non-Date value ${value} when schema expected Date in ${ns.getName(true)}`);
              }
              const format32 = determineTimestampFormat5(ns, this.settings);
              switch (format32) {
                case 5:
                  this.stringBuffer = value.toISOString().replace(".000Z", "Z");
                  break;
                case 6:
                  this.stringBuffer = dateToUtcString17(value);
                  break;
                case 7:
                  this.stringBuffer = String(value.getTime() / 1e3);
                  break;
                default:
                  console.warn("Missing timestamp format, using epoch seconds", value);
                  this.stringBuffer = String(value.getTime() / 1e3);
              }
              return;
            }
            if (ns.isBlobSchema() && "byteLength" in value) {
              this.stringBuffer = (this.serdeContext?.base64Encoder ?? toBase6445)(value);
              return;
            }
            if (ns.isListSchema() && Array.isArray(value)) {
              let buffer = "";
              for (const item of value) {
                this.write([ns.getValueSchema(), ns.getMergedTraits()], item);
                const headerItem = this.flush();
                const serialized = ns.getValueSchema().isTimestampSchema() ? headerItem : quoteHeader5(headerItem);
                if (buffer !== "") {
                  buffer += ", ";
                }
                buffer += serialized;
              }
              this.stringBuffer = buffer;
              return;
            }
            this.stringBuffer = JSON.stringify(value, null, 2);
            break;
          case "string":
            const mediaType = ns.getMergedTraits().mediaType;
            let intermediateValue = value;
            if (mediaType) {
              const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
              if (isJson) {
                intermediateValue = LazyJsonString9.from(intermediateValue);
              }
              if (ns.getMergedTraits().httpHeader) {
                this.stringBuffer = (this.serdeContext?.base64Encoder ?? toBase6445)(intermediateValue.toString());
                return;
              }
            }
            this.stringBuffer = value;
            break;
          default:
            if (ns.isIdempotencyToken()) {
              this.stringBuffer = generateIdempotencyToken5();
            } else {
              this.stringBuffer = String(value);
            }
        }
      }
      flush() {
        const buffer = this.stringBuffer;
        this.stringBuffer = "";
        return buffer;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/serde/HttpInterceptingShapeSerializer.js
var HttpInterceptingShapeSerializer5;
var init_HttpInterceptingShapeSerializer6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/serde/HttpInterceptingShapeSerializer.js"() {
    init_schema8();
    init_ToStringShapeSerializer6();
    HttpInterceptingShapeSerializer5 = class {
      static {
        __name(this, "HttpInterceptingShapeSerializer");
      }
      codecSerializer;
      stringSerializer;
      buffer;
      constructor(codecSerializer, codecSettings, stringSerializer = new ToStringShapeSerializer5(codecSettings)) {
        this.codecSerializer = codecSerializer;
        this.stringSerializer = stringSerializer;
      }
      setSerdeContext(serdeContext) {
        this.codecSerializer.setSerdeContext(serdeContext);
        this.stringSerializer.setSerdeContext(serdeContext);
      }
      write(schema, value) {
        const ns = NormalizedSchema5.of(schema);
        const traits = ns.getMergedTraits();
        if (traits.httpHeader || traits.httpLabel || traits.httpQuery) {
          this.stringSerializer.write(ns, value);
          this.buffer = this.stringSerializer.flush();
          return;
        }
        return this.codecSerializer.write(ns, value);
      }
      flush() {
        if (this.buffer !== void 0) {
          const buffer = this.buffer;
          this.buffer = void 0;
          return buffer;
        }
        return this.codecSerializer.flush();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/Field.js
var import_types57, Field4;
var init_Field4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/Field.js"() {
    import_types57 = __toESM(require_dist_cjs());
    Field4 = class {
      static {
        __name(this, "Field");
      }
      name;
      kind;
      values;
      constructor({ name, kind = import_types57.FieldPosition.HEADER, values = [] }) {
        this.name = name;
        this.kind = kind;
        this.values = values;
      }
      add(value) {
        this.values.push(value);
      }
      set(values) {
        this.values = values;
      }
      remove(value) {
        this.values = this.values.filter((v) => v !== value);
      }
      toString() {
        return this.values.map((v) => v.includes(",") || v.includes(" ") ? `"${v}"` : v).join(", ");
      }
      get() {
        return this.values;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/Fields.js
var Fields4;
var init_Fields4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/Fields.js"() {
    Fields4 = class {
      static {
        __name(this, "Fields");
      }
      entries = {};
      encoding;
      constructor({ fields = [], encoding = "utf-8" }) {
        fields.forEach(this.setField.bind(this));
        this.encoding = encoding;
      }
      setField(field) {
        this.entries[field.name.toLowerCase()] = field;
      }
      getField(name) {
        return this.entries[name.toLowerCase()];
      }
      removeField(name) {
        delete this.entries[name.toLowerCase()];
      }
      getByType(kind) {
        return Object.values(this.entries).filter((field) => field.kind === kind);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/isValidHostname.js
function isValidHostname4(hostname) {
  const hostPattern = /^[a-z0-9][a-z0-9\.\-]*[a-z0-9]$/;
  return hostPattern.test(hostname);
}
var init_isValidHostname4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/isValidHostname.js"() {
    __name(isValidHostname4, "isValidHostname");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/extensions/httpExtensionConfiguration.js
var getHttpHandlerExtensionConfiguration22, resolveHttpHandlerRuntimeConfig22;
var init_httpExtensionConfiguration4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/extensions/httpExtensionConfiguration.js"() {
    getHttpHandlerExtensionConfiguration22 = /* @__PURE__ */ __name((runtimeConfig) => {
      return {
        setHttpHandler(handler) {
          runtimeConfig.httpHandler = handler;
        },
        httpHandler() {
          return runtimeConfig.httpHandler;
        },
        updateHttpClientConfig(key, value) {
          runtimeConfig.httpHandler?.updateHttpClientConfig(key, value);
        },
        httpHandlerConfigs() {
          return runtimeConfig.httpHandler.httpHandlerConfigs();
        }
      };
    }, "getHttpHandlerExtensionConfiguration");
    resolveHttpHandlerRuntimeConfig22 = /* @__PURE__ */ __name((httpHandlerExtensionConfiguration) => {
      return {
        httpHandler: httpHandlerExtensionConfiguration.httpHandler()
      };
    }, "resolveHttpHandlerRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/middleware-content-length/contentLengthMiddleware.js
function contentLengthMiddleware4(bodyLengthChecker) {
  return (next) => async (args) => {
    const request4 = args.request;
    if (HttpRequest24.isInstance(request4)) {
      const { body, headers } = request4;
      if (body && Object.keys(headers).map((str) => str.toLowerCase()).indexOf(CONTENT_LENGTH_HEADER4) === -1) {
        try {
          const length = bodyLengthChecker(body);
          request4.headers = {
            ...request4.headers,
            [CONTENT_LENGTH_HEADER4]: String(length)
          };
        } catch (error4) {
        }
      }
    }
    return next({
      ...args,
      request: request4
    });
  };
}
var CONTENT_LENGTH_HEADER4, contentLengthMiddlewareOptions4, getContentLengthPlugin22;
var init_contentLengthMiddleware4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/middleware-content-length/contentLengthMiddleware.js"() {
    init_httpRequest5();
    CONTENT_LENGTH_HEADER4 = "content-length";
    __name(contentLengthMiddleware4, "contentLengthMiddleware");
    contentLengthMiddlewareOptions4 = {
      step: "build",
      tags: ["SET_CONTENT_LENGTH", "CONTENT_LENGTH"],
      name: "contentLengthMiddleware",
      override: true
    };
    getContentLengthPlugin22 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(contentLengthMiddleware4(options.bodyLengthChecker), contentLengthMiddlewareOptions4);
      }, "applyToStack")
    }), "getContentLengthPlugin");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/util-uri-escape/escape-uri.js
var escapeUri4, hexEncode4;
var init_escape_uri4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/util-uri-escape/escape-uri.js"() {
    escapeUri4 = /* @__PURE__ */ __name((uri) => encodeURIComponent(uri).replace(/[!'()*]/g, hexEncode4), "escapeUri");
    hexEncode4 = /* @__PURE__ */ __name((c32) => `%${c32.charCodeAt(0).toString(16).toUpperCase()}`, "hexEncode");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/util-uri-escape/escape-uri-path.js
var escapeUriPath4;
var init_escape_uri_path4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/util-uri-escape/escape-uri-path.js"() {
    init_escape_uri4();
    escapeUriPath4 = /* @__PURE__ */ __name((uri) => uri.split("/").map(escapeUri4).join("/"), "escapeUriPath");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/querystring-builder/buildQueryString.js
function buildQueryString4(query) {
  const parts = [];
  for (let key of Object.keys(query).sort()) {
    const value = query[key];
    key = escapeUri4(key);
    if (Array.isArray(value)) {
      for (let i32 = 0, iLen = value.length; i32 < iLen; i32++) {
        parts.push(`${key}=${escapeUri4(value[i32])}`);
      }
    } else {
      let qsEntry = key;
      if (value || typeof value === "string") {
        qsEntry += `=${escapeUri4(value)}`;
      }
      parts.push(qsEntry);
    }
  }
  return parts.join("&");
}
var init_buildQueryString4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/querystring-builder/buildQueryString.js"() {
    init_escape_uri4();
    __name(buildQueryString4, "buildQueryString");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/querystring-parser/parseQueryString.js
function parseQueryString4(querystring) {
  const query = {};
  querystring = querystring.replace(/^\?/, "");
  if (querystring) {
    for (const pair of querystring.split("&")) {
      let [key, value = null] = pair.split("=");
      key = decodeURIComponent(key);
      if (value) {
        value = decodeURIComponent(value);
      }
      if (!(key in query)) {
        query[key] = value;
      } else if (Array.isArray(query[key])) {
        query[key].push(value);
      } else {
        query[key] = [query[key], value];
      }
    }
  }
  return query;
}
var init_parseQueryString4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/querystring-parser/parseQueryString.js"() {
    __name(parseQueryString4, "parseQueryString");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/url-parser/parseUrl.js
var parseUrl23;
var init_parseUrl4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/url-parser/parseUrl.js"() {
    init_parseQueryString4();
    parseUrl23 = /* @__PURE__ */ __name((url) => {
      if (typeof url === "string") {
        return parseUrl23(new URL(url));
      }
      const { hostname, pathname, port, protocol, search } = url;
      let query;
      if (search) {
        query = parseQueryString4(search);
      }
      return {
        hostname,
        port: port ? parseInt(port) : void 0,
        protocol,
        path: pathname,
        query
      };
    }, "parseUrl");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/index.js
var protocols_exports10 = {};
__export(protocols_exports10, {
  Field: () => Field4,
  Fields: () => Fields4,
  FromStringShapeDeserializer: () => FromStringShapeDeserializer5,
  HttpBindingProtocol: () => HttpBindingProtocol5,
  HttpInterceptingShapeDeserializer: () => HttpInterceptingShapeDeserializer5,
  HttpInterceptingShapeSerializer: () => HttpInterceptingShapeSerializer5,
  HttpProtocol: () => HttpProtocol5,
  HttpRequest: () => HttpRequest24,
  HttpResponse: () => HttpResponse13,
  RequestBuilder: () => RequestBuilder5,
  RpcProtocol: () => RpcProtocol5,
  SerdeContext: () => SerdeContext5,
  ToStringShapeSerializer: () => ToStringShapeSerializer5,
  buildQueryString: () => buildQueryString4,
  collectBody: () => collectBody12,
  contentLengthMiddleware: () => contentLengthMiddleware4,
  contentLengthMiddlewareOptions: () => contentLengthMiddlewareOptions4,
  determineTimestampFormat: () => determineTimestampFormat5,
  escapeUri: () => escapeUri4,
  escapeUriPath: () => escapeUriPath4,
  extendedEncodeURIComponent: () => extendedEncodeURIComponent5,
  getContentLengthPlugin: () => getContentLengthPlugin22,
  getHttpHandlerExtensionConfiguration: () => getHttpHandlerExtensionConfiguration22,
  isValidHostname: () => isValidHostname4,
  parseQueryString: () => parseQueryString4,
  parseUrl: () => parseUrl23,
  requestBuilder: () => requestBuilder5,
  resolveHttpHandlerRuntimeConfig: () => resolveHttpHandlerRuntimeConfig22,
  resolvedPath: () => resolvedPath5
});
var init_protocols13 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/protocols/index.js"() {
    init_collect_stream_body6();
    init_extended_encode_uri_component6();
    init_HttpBindingProtocol6();
    init_HttpProtocol6();
    init_RpcProtocol6();
    init_requestBuilder8();
    init_resolve_path6();
    init_FromStringShapeDeserializer6();
    init_HttpInterceptingShapeDeserializer6();
    init_HttpInterceptingShapeSerializer6();
    init_ToStringShapeSerializer6();
    init_determineTimestampFormat6();
    init_SerdeContext6();
    init_Field4();
    init_Fields4();
    init_httpRequest5();
    init_httpResponse5();
    init_isValidHostname4();
    init_httpExtensionConfiguration4();
    init_contentLengthMiddleware4();
    init_escape_uri4();
    init_escape_uri_path4();
    init_buildQueryString4();
    init_parseQueryString4();
    init_parseUrl4();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/schemas/operation.js
var init_operation5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/schemas/operation.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/middleware/getSchemaSerdePlugin.js
var init_getSchemaSerdePlugin5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/middleware/getSchemaSerdePlugin.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/schemas/Schema.js
var init_Schema5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/schemas/Schema.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/schemas/ListSchema.js
var init_ListSchema5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/schemas/ListSchema.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/schemas/MapSchema.js
var init_MapSchema5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/schemas/MapSchema.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/schemas/OperationSchema.js
var init_OperationSchema5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/schemas/OperationSchema.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/schemas/StructureSchema.js
var init_StructureSchema5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/schemas/StructureSchema.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/schemas/ErrorSchema.js
var init_ErrorSchema5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/schemas/ErrorSchema.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/schemas/translateTraits.js
function translateTraits5(indicator) {
  if (typeof indicator === "object") {
    return indicator;
  }
  indicator = indicator | 0;
  if (traitsCache5[indicator]) {
    return traitsCache5[indicator];
  }
  const traits = {};
  let i32 = 0;
  for (const trait of [
    "httpLabel",
    "idempotent",
    "idempotencyToken",
    "sensitive",
    "httpPayload",
    "httpResponseCode",
    "httpQueryParams"
  ]) {
    if ((indicator >> i32++ & 1) === 1) {
      traits[trait] = 1;
    }
  }
  return traitsCache5[indicator] = traits;
}
var traitsCache5;
var init_translateTraits5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/schemas/translateTraits.js"() {
    traitsCache5 = [];
    __name(translateTraits5, "translateTraits");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/schemas/NormalizedSchema.js
function member5(memberSchema, memberName) {
  if (memberSchema instanceof NormalizedSchema5) {
    return Object.assign(memberSchema, {
      memberName,
      _isMemberSchema: true
    });
  }
  const internalCtorAccess = NormalizedSchema5;
  return new internalCtorAccess(memberSchema, memberName);
}
var anno5, simpleSchemaCacheN5, simpleSchemaCacheS5, NormalizedSchema5, isMemberSchema5, isStaticSchema5;
var init_NormalizedSchema5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/schemas/NormalizedSchema.js"() {
    init_deref5();
    init_translateTraits5();
    anno5 = {
      it: /* @__PURE__ */ Symbol.for("@smithy/nor-struct-it"),
      ns: /* @__PURE__ */ Symbol.for("@smithy/ns")
    };
    simpleSchemaCacheN5 = [];
    simpleSchemaCacheS5 = {};
    NormalizedSchema5 = class _NormalizedSchema {
      static {
        __name(this, "NormalizedSchema");
      }
      ref;
      memberName;
      static symbol = /* @__PURE__ */ Symbol.for("@smithy/nor");
      symbol = _NormalizedSchema.symbol;
      name;
      schema;
      _isMemberSchema;
      traits;
      memberTraits;
      normalizedTraits;
      constructor(ref, memberName) {
        this.ref = ref;
        this.memberName = memberName;
        const traitStack = [];
        let _ref = ref;
        let schema = ref;
        this._isMemberSchema = false;
        while (isMemberSchema5(_ref)) {
          traitStack.push(_ref[1]);
          _ref = _ref[0];
          schema = deref5(_ref);
          this._isMemberSchema = true;
        }
        if (traitStack.length > 0) {
          this.memberTraits = {};
          for (let i32 = traitStack.length - 1; i32 >= 0; --i32) {
            const traitSet = traitStack[i32];
            Object.assign(this.memberTraits, translateTraits5(traitSet));
          }
        } else {
          this.memberTraits = 0;
        }
        if (schema instanceof _NormalizedSchema) {
          const computedMemberTraits = this.memberTraits;
          Object.assign(this, schema);
          this.memberTraits = Object.assign({}, computedMemberTraits, schema.getMemberTraits(), this.getMemberTraits());
          this.normalizedTraits = void 0;
          this.memberName = memberName ?? schema.memberName;
          return;
        }
        this.schema = deref5(schema);
        if (isStaticSchema5(this.schema)) {
          this.name = `${this.schema[1]}#${this.schema[2]}`;
          this.traits = this.schema[3];
        } else {
          this.name = this.memberName ?? String(schema);
          this.traits = 0;
        }
        if (this._isMemberSchema && !memberName) {
          throw new Error(`@smithy/core/schema - NormalizedSchema member init ${this.getName(true)} missing member name.`);
        }
      }
      static [Symbol.hasInstance](lhs) {
        const isPrototype = this.prototype.isPrototypeOf(lhs);
        if (!isPrototype && typeof lhs === "object" && lhs !== null) {
          const ns = lhs;
          return ns.symbol === this.symbol;
        }
        return isPrototype;
      }
      static of(ref) {
        const keyAble = typeof ref === "function" || typeof ref === "object" && ref !== null;
        if (typeof ref === "number") {
          if (simpleSchemaCacheN5[ref]) {
            return simpleSchemaCacheN5[ref];
          }
        } else if (typeof ref === "string") {
          if (simpleSchemaCacheS5[ref]) {
            return simpleSchemaCacheS5[ref];
          }
        } else if (keyAble) {
          if (ref[anno5.ns]) {
            return ref[anno5.ns];
          }
        }
        const sc = deref5(ref);
        if (sc instanceof _NormalizedSchema) {
          return sc;
        }
        if (isMemberSchema5(sc)) {
          const [ns2, traits] = sc;
          if (ns2 instanceof _NormalizedSchema) {
            Object.assign(ns2.getMergedTraits(), translateTraits5(traits));
            return ns2;
          }
          throw new Error(`@smithy/core/schema - may not init unwrapped member schema=${JSON.stringify(ref, null, 2)}.`);
        }
        const ns = new _NormalizedSchema(sc);
        if (keyAble) {
          return ref[anno5.ns] = ns;
        }
        if (typeof sc === "string") {
          return simpleSchemaCacheS5[sc] = ns;
        }
        if (typeof sc === "number") {
          return simpleSchemaCacheN5[sc] = ns;
        }
        return ns;
      }
      getSchema() {
        const sc = this.schema;
        if (Array.isArray(sc) && sc[0] === 0) {
          return sc[4];
        }
        return sc;
      }
      getName(withNamespace = false) {
        const { name } = this;
        const short = !withNamespace && name && name.includes("#");
        return short ? name.split("#")[1] : name || void 0;
      }
      getMemberName() {
        return this.memberName;
      }
      isMemberSchema() {
        return this._isMemberSchema;
      }
      isListSchema() {
        const sc = this.getSchema();
        return typeof sc === "number" ? sc >= 64 && sc < 128 : sc[0] === 1;
      }
      isMapSchema() {
        const sc = this.getSchema();
        return typeof sc === "number" ? sc >= 128 && sc <= 255 : sc[0] === 2;
      }
      isStructSchema() {
        const sc = this.getSchema();
        if (typeof sc !== "object") {
          return false;
        }
        const id = sc[0];
        return id === 3 || id === -3 || id === 4;
      }
      isUnionSchema() {
        const sc = this.getSchema();
        if (typeof sc !== "object") {
          return false;
        }
        return sc[0] === 4;
      }
      isBlobSchema() {
        const sc = this.getSchema();
        return sc === 21 || sc === 42;
      }
      isTimestampSchema() {
        const sc = this.getSchema();
        return typeof sc === "number" && sc >= 4 && sc <= 7;
      }
      isUnitSchema() {
        return this.getSchema() === "unit";
      }
      isDocumentSchema() {
        return this.getSchema() === 15;
      }
      isStringSchema() {
        return this.getSchema() === 0;
      }
      isBooleanSchema() {
        return this.getSchema() === 2;
      }
      isNumericSchema() {
        return this.getSchema() === 1;
      }
      isBigIntegerSchema() {
        return this.getSchema() === 17;
      }
      isBigDecimalSchema() {
        return this.getSchema() === 19;
      }
      isStreaming() {
        const { streaming } = this.getMergedTraits();
        return !!streaming || this.getSchema() === 42;
      }
      isIdempotencyToken() {
        return !!this.getMergedTraits().idempotencyToken;
      }
      getMergedTraits() {
        return this.normalizedTraits ?? (this.normalizedTraits = {
          ...this.getOwnTraits(),
          ...this.getMemberTraits()
        });
      }
      getMemberTraits() {
        return translateTraits5(this.memberTraits);
      }
      getOwnTraits() {
        return translateTraits5(this.traits);
      }
      getKeySchema() {
        const [isDoc, isMap] = [this.isDocumentSchema(), this.isMapSchema()];
        if (!isDoc && !isMap) {
          throw new Error(`@smithy/core/schema - cannot get key for non-map: ${this.getName(true)}`);
        }
        const schema = this.getSchema();
        const memberSchema = isDoc ? 15 : schema[4] ?? 0;
        return member5([memberSchema, 0], "key");
      }
      getValueSchema() {
        const sc = this.getSchema();
        const [isDoc, isMap, isList] = [this.isDocumentSchema(), this.isMapSchema(), this.isListSchema()];
        const memberSchema = typeof sc === "number" ? 63 & sc : sc && typeof sc === "object" && (isMap || isList) ? sc[3 + sc[0]] : isDoc ? 15 : void 0;
        if (memberSchema != null) {
          return member5([memberSchema, 0], isMap ? "value" : "member");
        }
        throw new Error(`@smithy/core/schema - ${this.getName(true)} has no value member.`);
      }
      getMemberSchema(memberName) {
        const struct3 = this.getSchema();
        if (this.isStructSchema() && struct3[4].includes(memberName)) {
          const i32 = struct3[4].indexOf(memberName);
          const memberSchema = struct3[5][i32];
          return member5(isMemberSchema5(memberSchema) ? memberSchema : [memberSchema, 0], memberName);
        }
        if (this.isDocumentSchema()) {
          return member5([15, 0], memberName);
        }
        throw new Error(`@smithy/core/schema - ${this.getName(true)} has no member=${memberName}.`);
      }
      getMemberSchemas() {
        const buffer = {};
        try {
          for (const [k32, v] of this.structIterator()) {
            buffer[k32] = v;
          }
        } catch (ignored) {
        }
        return buffer;
      }
      getEventStreamMember() {
        if (this.isStructSchema()) {
          for (const [memberName, memberSchema] of this.structIterator()) {
            if (memberSchema.isStreaming() && memberSchema.isStructSchema()) {
              return memberName;
            }
          }
        }
        return "";
      }
      *structIterator() {
        if (this.isUnitSchema()) {
          return;
        }
        if (!this.isStructSchema()) {
          throw new Error("@smithy/core/schema - cannot iterate non-struct schema.");
        }
        const struct3 = this.getSchema();
        const z = struct3[4].length;
        let it = struct3[anno5.it];
        if (it && z === it.length) {
          yield* it;
          return;
        }
        it = Array(z);
        for (let i32 = 0; i32 < z; ++i32) {
          const k32 = struct3[4][i32];
          const v = member5([struct3[5][i32], 0], k32);
          yield it[i32] = [k32, v];
        }
        struct3[anno5.it] = it;
      }
    };
    __name(member5, "member");
    isMemberSchema5 = /* @__PURE__ */ __name((sc) => Array.isArray(sc) && sc.length === 2, "isMemberSchema");
    isStaticSchema5 = /* @__PURE__ */ __name((sc) => Array.isArray(sc) && sc.length >= 5, "isStaticSchema");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/schemas/SimpleSchema.js
var init_SimpleSchema5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/schemas/SimpleSchema.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/schemas/sentinels.js
var init_sentinels5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/schemas/sentinels.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/TypeRegistry.js
var TypeRegistry5;
var init_TypeRegistry5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/TypeRegistry.js"() {
    TypeRegistry5 = class _TypeRegistry {
      static {
        __name(this, "TypeRegistry");
      }
      namespace;
      schemas;
      exceptions;
      static registries = /* @__PURE__ */ new Map();
      constructor(namespace, schemas = /* @__PURE__ */ new Map(), exceptions = /* @__PURE__ */ new Map()) {
        this.namespace = namespace;
        this.schemas = schemas;
        this.exceptions = exceptions;
      }
      static for(namespace) {
        if (!_TypeRegistry.registries.has(namespace)) {
          _TypeRegistry.registries.set(namespace, new _TypeRegistry(namespace));
        }
        return _TypeRegistry.registries.get(namespace);
      }
      copyFrom(other) {
        const { schemas, exceptions } = this;
        for (const [k32, v] of other.schemas) {
          if (!schemas.has(k32)) {
            schemas.set(k32, v);
          }
        }
        for (const [k32, v] of other.exceptions) {
          if (!exceptions.has(k32)) {
            exceptions.set(k32, v);
          }
        }
      }
      register(shapeId, schema) {
        const qualifiedName = this.normalizeShapeId(shapeId);
        for (const r32 of [this, _TypeRegistry.for(qualifiedName.split("#")[0])]) {
          r32.schemas.set(qualifiedName, schema);
        }
      }
      getSchema(shapeId) {
        const id = this.normalizeShapeId(shapeId);
        if (!this.schemas.has(id)) {
          if (!shapeId.includes("#")) {
            const suffix = "#" + shapeId;
            const candidates = [];
            for (const [shapeId2, schema] of this.schemas.entries()) {
              if (shapeId2.endsWith(suffix)) {
                candidates.push(schema);
              }
            }
            if (candidates.length === 1) {
              return candidates[0];
            }
          }
          throw new Error(`@smithy/core/schema - schema not found for ${id}`);
        }
        return this.schemas.get(id);
      }
      registerError(es, ctor) {
        const $error = es;
        const ns = $error[1];
        for (const r32 of [this, _TypeRegistry.for(ns)]) {
          r32.schemas.set(ns + "#" + $error[2], $error);
          r32.exceptions.set($error, ctor);
        }
      }
      getErrorCtor(es) {
        const $error = es;
        if (this.exceptions.has($error)) {
          return this.exceptions.get($error);
        }
        const registry = _TypeRegistry.for($error[1]);
        return registry.exceptions.get($error);
      }
      getBaseException() {
        for (const exceptionKey of this.exceptions.keys()) {
          if (Array.isArray(exceptionKey)) {
            const [, ns, name] = exceptionKey;
            const id = ns + "#" + name;
            if (id.startsWith("smithy.ts.sdk.synthetic.") && id.endsWith("ServiceException")) {
              return exceptionKey;
            }
          }
        }
        return void 0;
      }
      find(predicate) {
        for (const schema of this.schemas.values()) {
          if (predicate(schema)) {
            return schema;
          }
        }
        return void 0;
      }
      clear() {
        this.schemas.clear();
        this.exceptions.clear();
      }
      normalizeShapeId(shapeId) {
        if (shapeId.includes("#")) {
          return shapeId;
        }
        return this.namespace + "#" + shapeId;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/index.js
var init_schema8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/schema/index.js"() {
    init_deref5();
    init_getSchemaSerdePlugin5();
    init_ListSchema5();
    init_MapSchema5();
    init_OperationSchema5();
    init_operation5();
    init_ErrorSchema5();
    init_NormalizedSchema5();
    init_Schema5();
    init_SimpleSchema5();
    init_StructureSchema5();
    init_sentinels5();
    init_translateTraits5();
    init_TypeRegistry5();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/client/index.js
var init_client16 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/client/index.js"() {
    init_getSmithyContext6();
    init_normalizeProvider7();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/endpointsConfig/resolveCustomEndpointsConfig.js
var resolveCustomEndpointsConfig2;
var init_resolveCustomEndpointsConfig2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/endpointsConfig/resolveCustomEndpointsConfig.js"() {
    init_client16();
    resolveCustomEndpointsConfig2 = /* @__PURE__ */ __name((input) => {
      const { tls, endpoint, urlParser, useDualstackEndpoint } = input;
      return Object.assign(input, {
        tls: tls ?? true,
        endpoint: normalizeProvider25(typeof endpoint === "string" ? urlParser(endpoint) : endpoint),
        isCustomEndpoint: true,
        useDualstackEndpoint: normalizeProvider25(useDualstackEndpoint ?? false)
      });
    }, "resolveCustomEndpointsConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/endpointsConfig/utils/getEndpointFromRegion.js
var getEndpointFromRegion2;
var init_getEndpointFromRegion2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/endpointsConfig/utils/getEndpointFromRegion.js"() {
    getEndpointFromRegion2 = /* @__PURE__ */ __name(async (input) => {
      const { tls = true } = input;
      const region = await input.region();
      const dnsHostRegex = new RegExp(/^([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9-]{0,61}[a-zA-Z0-9])$/);
      if (!dnsHostRegex.test(region)) {
        throw new Error("Invalid region in client config");
      }
      const useDualstackEndpoint = await input.useDualstackEndpoint();
      const useFipsEndpoint = await input.useFipsEndpoint();
      const { hostname } = await input.regionInfoProvider(region, { useDualstackEndpoint, useFipsEndpoint }) ?? {};
      if (!hostname) {
        throw new Error("Cannot resolve hostname from client config");
      }
      return input.urlParser(`${tls ? "https:" : "http:"}//${hostname}`);
    }, "getEndpointFromRegion");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/endpointsConfig/resolveEndpointsConfig.js
var resolveEndpointsConfig2;
var init_resolveEndpointsConfig2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/endpointsConfig/resolveEndpointsConfig.js"() {
    init_client16();
    init_getEndpointFromRegion2();
    resolveEndpointsConfig2 = /* @__PURE__ */ __name((input) => {
      const useDualstackEndpoint = normalizeProvider25(input.useDualstackEndpoint ?? false);
      const { endpoint, useFipsEndpoint, urlParser, tls } = input;
      return Object.assign(input, {
        tls: tls ?? true,
        endpoint: endpoint ? normalizeProvider25(typeof endpoint === "string" ? urlParser(endpoint) : endpoint) : () => getEndpointFromRegion2({ ...input, useDualstackEndpoint, useFipsEndpoint }),
        isCustomEndpoint: !!endpoint,
        useDualstackEndpoint
      });
    }, "resolveEndpointsConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionConfig/config.js
var REGION_ENV_NAME2, REGION_INI_NAME2, NODE_REGION_CONFIG_OPTIONS21, NODE_REGION_CONFIG_FILE_OPTIONS21;
var init_config7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionConfig/config.js"() {
    REGION_ENV_NAME2 = "AWS_REGION";
    REGION_INI_NAME2 = "region";
    NODE_REGION_CONFIG_OPTIONS21 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[REGION_ENV_NAME2], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[REGION_INI_NAME2], "configFileSelector"),
      default: /* @__PURE__ */ __name(() => {
        throw new Error("Region is missing");
      }, "default")
    };
    NODE_REGION_CONFIG_FILE_OPTIONS21 = {
      preferredFile: "credentials"
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionConfig/checkRegion.js
var validRegions2, checkRegion2;
var init_checkRegion2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionConfig/checkRegion.js"() {
    init_endpoints5();
    validRegions2 = /* @__PURE__ */ new Set();
    checkRegion2 = /* @__PURE__ */ __name((region, check = isValidHostLabel3) => {
      if (!validRegions2.has(region) && !check(region)) {
        if (region === "*") {
          console.warn(`@smithy/config-resolver WARN - Please use the caller region instead of "*". See "sigv4a" in https://github.com/aws/aws-sdk-js-v3/blob/main/supplemental-docs/CLIENTS.md.`);
        } else {
          throw new Error(`Region not accepted: region="${region}" is not a valid hostname component.`);
        }
      } else {
        validRegions2.add(region);
      }
    }, "checkRegion");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionConfig/isFipsRegion.js
var isFipsRegion2;
var init_isFipsRegion2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionConfig/isFipsRegion.js"() {
    isFipsRegion2 = /* @__PURE__ */ __name((region) => typeof region === "string" && (region.startsWith("fips-") || region.endsWith("-fips")), "isFipsRegion");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionConfig/getRealRegion.js
var getRealRegion2;
var init_getRealRegion2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionConfig/getRealRegion.js"() {
    init_isFipsRegion2();
    getRealRegion2 = /* @__PURE__ */ __name((region) => isFipsRegion2(region) ? ["fips-aws-global", "aws-fips"].includes(region) ? "us-east-1" : region.replace(/fips-(dkr-|prod-)?|-fips/, "") : region, "getRealRegion");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionConfig/resolveRegionConfig.js
var resolveRegionConfig20;
var init_resolveRegionConfig2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionConfig/resolveRegionConfig.js"() {
    init_checkRegion2();
    init_getRealRegion2();
    init_isFipsRegion2();
    resolveRegionConfig20 = /* @__PURE__ */ __name((input) => {
      const { region, useFipsEndpoint } = input;
      if (!region) {
        throw new Error("Region is missing");
      }
      return Object.assign(input, {
        region: /* @__PURE__ */ __name(async () => {
          const providedRegion = typeof region === "function" ? await region() : region;
          const realRegion = getRealRegion2(providedRegion);
          checkRegion2(realRegion);
          return realRegion;
        }, "region"),
        useFipsEndpoint: /* @__PURE__ */ __name(async () => {
          const providedRegion = typeof region === "string" ? region : await region();
          if (isFipsRegion2(providedRegion)) {
            return true;
          }
          return typeof useFipsEndpoint !== "function" ? Promise.resolve(!!useFipsEndpoint) : useFipsEndpoint();
        }, "useFipsEndpoint")
      });
    }, "resolveRegionConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionInfo/getHostnameFromVariants.js
var getHostnameFromVariants2;
var init_getHostnameFromVariants2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionInfo/getHostnameFromVariants.js"() {
    getHostnameFromVariants2 = /* @__PURE__ */ __name((variants = [], { useFipsEndpoint, useDualstackEndpoint }) => variants.find(({ tags }) => useFipsEndpoint === tags.includes("fips") && useDualstackEndpoint === tags.includes("dualstack"))?.hostname, "getHostnameFromVariants");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionInfo/getResolvedHostname.js
var getResolvedHostname2;
var init_getResolvedHostname2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionInfo/getResolvedHostname.js"() {
    getResolvedHostname2 = /* @__PURE__ */ __name((resolvedRegion, { regionHostname, partitionHostname }) => regionHostname ? regionHostname : partitionHostname ? partitionHostname.replace("{region}", resolvedRegion) : void 0, "getResolvedHostname");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionInfo/getResolvedPartition.js
var getResolvedPartition2;
var init_getResolvedPartition2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionInfo/getResolvedPartition.js"() {
    getResolvedPartition2 = /* @__PURE__ */ __name((region, { partitionHash }) => Object.keys(partitionHash || {}).find((key) => partitionHash[key].regions.includes(region)) ?? "aws", "getResolvedPartition");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionInfo/getResolvedSigningRegion.js
var getResolvedSigningRegion2;
var init_getResolvedSigningRegion2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionInfo/getResolvedSigningRegion.js"() {
    getResolvedSigningRegion2 = /* @__PURE__ */ __name((hostname, { signingRegion, regionRegex, useFipsEndpoint }) => {
      if (signingRegion) {
        return signingRegion;
      } else if (useFipsEndpoint) {
        const regionRegexJs = regionRegex.replace("\\\\", "\\").replace(/^\^/g, "\\.").replace(/\$$/g, "\\.");
        const regionRegexmatchArray = hostname.match(regionRegexJs);
        if (regionRegexmatchArray) {
          return regionRegexmatchArray[0].slice(1, -1);
        }
      }
    }, "getResolvedSigningRegion");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionInfo/getRegionInfo.js
var getRegionInfo2;
var init_getRegionInfo2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/config-resolver/regionInfo/getRegionInfo.js"() {
    init_getHostnameFromVariants2();
    init_getResolvedHostname2();
    init_getResolvedPartition2();
    init_getResolvedSigningRegion2();
    getRegionInfo2 = /* @__PURE__ */ __name((region, { useFipsEndpoint = false, useDualstackEndpoint = false, signingService, regionHash, partitionHash }) => {
      const partition4 = getResolvedPartition2(region, { partitionHash });
      const resolvedRegion = region in regionHash ? region : partitionHash[partition4]?.endpoint ?? region;
      const hostnameOptions = { useFipsEndpoint, useDualstackEndpoint };
      const regionHostname = getHostnameFromVariants2(regionHash[resolvedRegion]?.variants, hostnameOptions);
      const partitionHostname = getHostnameFromVariants2(partitionHash[partition4]?.variants, hostnameOptions);
      const hostname = getResolvedHostname2(resolvedRegion, { regionHostname, partitionHostname });
      if (hostname === void 0) {
        throw new Error(`Endpoint resolution failed for: ${{ resolvedRegion, useFipsEndpoint, useDualstackEndpoint }}`);
      }
      const signingRegion = getResolvedSigningRegion2(hostname, {
        signingRegion: regionHash[resolvedRegion]?.signingRegion,
        regionRegex: partitionHash[partition4].regionRegex,
        useFipsEndpoint
      });
      return {
        partition: partition4,
        signingService,
        hostname,
        ...signingRegion && { signingRegion },
        ...regionHash[resolvedRegion]?.signingService && {
          signingService: regionHash[resolvedRegion].signingService
        }
      };
    }, "getRegionInfo");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/defaults-mode/constants.js
var AWS_EXECUTION_ENV2, AWS_REGION_ENV2, AWS_DEFAULT_REGION_ENV2, ENV_IMDS_DISABLED2, DEFAULTS_MODE_OPTIONS2, IMDS_REGION_PATH2;
var init_constants13 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/defaults-mode/constants.js"() {
    AWS_EXECUTION_ENV2 = "AWS_EXECUTION_ENV";
    AWS_REGION_ENV2 = "AWS_REGION";
    AWS_DEFAULT_REGION_ENV2 = "AWS_DEFAULT_REGION";
    ENV_IMDS_DISABLED2 = "AWS_EC2_METADATA_DISABLED";
    DEFAULTS_MODE_OPTIONS2 = ["in-region", "cross-region", "mobile", "standard", "legacy"];
    IMDS_REGION_PATH2 = "/latest/meta-data/placement/region";
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/defaults-mode/defaultsModeConfig.js
var AWS_DEFAULTS_MODE_ENV2, AWS_DEFAULTS_MODE_CONFIG2, NODE_DEFAULTS_MODE_CONFIG_OPTIONS2;
var init_defaultsModeConfig2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/defaults-mode/defaultsModeConfig.js"() {
    AWS_DEFAULTS_MODE_ENV2 = "AWS_DEFAULTS_MODE";
    AWS_DEFAULTS_MODE_CONFIG2 = "defaults_mode";
    NODE_DEFAULTS_MODE_CONFIG_OPTIONS2 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => {
        return env3[AWS_DEFAULTS_MODE_ENV2];
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => {
        return profile[AWS_DEFAULTS_MODE_CONFIG2];
      }, "configFileSelector"),
      default: "legacy"
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/defaults-mode/resolveDefaultsModeConfig.js
var resolveDefaultsModeConfig20, resolveNodeDefaultsModeAuto2, inferPhysicalRegion2, getImdsEndpoint2, imdsHttpGet2;
var init_resolveDefaultsModeConfig2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/defaults-mode/resolveDefaultsModeConfig.js"() {
    init_config7();
    init_configLoader4();
    init_memoize4();
    init_constants13();
    init_defaultsModeConfig2();
    resolveDefaultsModeConfig20 = /* @__PURE__ */ __name(({ region = loadConfig5(NODE_REGION_CONFIG_OPTIONS21), defaultsMode = loadConfig5(NODE_DEFAULTS_MODE_CONFIG_OPTIONS2) } = {}) => memoize4(async () => {
      const mode = typeof defaultsMode === "function" ? await defaultsMode() : defaultsMode;
      switch (mode?.toLowerCase()) {
        case "auto":
          return resolveNodeDefaultsModeAuto2(region);
        case "in-region":
        case "cross-region":
        case "mobile":
        case "standard":
        case "legacy":
          return Promise.resolve(mode?.toLocaleLowerCase());
        case void 0:
          return Promise.resolve("legacy");
        default:
          throw new Error(`Invalid parameter for "defaultsMode", expect ${DEFAULTS_MODE_OPTIONS2.join(", ")}, got ${mode}`);
      }
    }), "resolveDefaultsModeConfig");
    resolveNodeDefaultsModeAuto2 = /* @__PURE__ */ __name(async (clientRegion) => {
      if (clientRegion) {
        const resolvedRegion = typeof clientRegion === "function" ? await clientRegion() : clientRegion;
        const inferredRegion = await inferPhysicalRegion2();
        if (!inferredRegion) {
          return "standard";
        }
        if (resolvedRegion === inferredRegion) {
          return "in-region";
        } else {
          return "cross-region";
        }
      }
      return "standard";
    }, "resolveNodeDefaultsModeAuto");
    inferPhysicalRegion2 = /* @__PURE__ */ __name(async () => {
      if (process.env[AWS_EXECUTION_ENV2] && (process.env[AWS_REGION_ENV2] || process.env[AWS_DEFAULT_REGION_ENV2])) {
        return process.env[AWS_REGION_ENV2] ?? process.env[AWS_DEFAULT_REGION_ENV2];
      }
      if (!process.env[ENV_IMDS_DISABLED2]) {
        try {
          const endpoint = await getImdsEndpoint2();
          return (await imdsHttpGet2({ hostname: endpoint.hostname, path: IMDS_REGION_PATH2 })).toString();
        } catch (e32) {
        }
      }
    }, "inferPhysicalRegion");
    getImdsEndpoint2 = /* @__PURE__ */ __name(async () => {
      const envEndpoint = process.env.AWS_EC2_METADATA_SERVICE_ENDPOINT;
      if (envEndpoint) {
        const url = new URL(envEndpoint);
        return { hostname: url.hostname, path: url.pathname };
      }
      const envMode = process.env.AWS_EC2_METADATA_SERVICE_ENDPOINT_MODE;
      if (envMode === "IPv6") {
        return { hostname: "fd00:ec2::254", path: "/" };
      }
      return { hostname: "169.254.169.254", path: "/" };
    }, "getImdsEndpoint");
    imdsHttpGet2 = /* @__PURE__ */ __name(async ({ hostname, path: path47 }) => {
      const { request: request4 } = await import("node:http");
      return new Promise((resolve13, reject) => {
        const req = request4({
          method: "GET",
          hostname: hostname.replace(/^\[(.+)]$/, "$1"),
          path: path47,
          timeout: 1e3,
          signal: AbortSignal.timeout(1e3)
        });
        req.on("error", (err) => {
          reject(err);
          req.destroy();
        });
        req.on("timeout", () => {
          reject(new Error("TimeoutError from instance metadata service"));
          req.destroy();
        });
        req.on("response", (res) => {
          const { statusCode = 400 } = res;
          if (statusCode < 200 || 300 <= statusCode) {
            reject(Object.assign(new Error("Error response received from instance metadata service"), { statusCode }));
            req.destroy();
            return;
          }
          const chunks2 = [];
          res.on("data", (chunk) => chunks2.push(chunk));
          res.on("end", () => {
            resolve13(Buffer.concat(chunks2));
            req.destroy();
          });
        });
        req.end();
      });
    }, "imdsHttpGet");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/index.js
var config_exports2 = {};
__export(config_exports2, {
  CONFIG_PREFIX_SEPARATOR: () => CONFIG_PREFIX_SEPARATOR4,
  CONFIG_USE_DUALSTACK_ENDPOINT: () => CONFIG_USE_DUALSTACK_ENDPOINT2,
  CONFIG_USE_FIPS_ENDPOINT: () => CONFIG_USE_FIPS_ENDPOINT2,
  CredentialsProviderError: () => CredentialsProviderError4,
  DEFAULT_PROFILE: () => DEFAULT_PROFILE4,
  DEFAULT_USE_DUALSTACK_ENDPOINT: () => DEFAULT_USE_DUALSTACK_ENDPOINT2,
  DEFAULT_USE_FIPS_ENDPOINT: () => DEFAULT_USE_FIPS_ENDPOINT2,
  ENV_PROFILE: () => ENV_PROFILE4,
  ENV_USE_DUALSTACK_ENDPOINT: () => ENV_USE_DUALSTACK_ENDPOINT2,
  ENV_USE_FIPS_ENDPOINT: () => ENV_USE_FIPS_ENDPOINT2,
  NODE_REGION_CONFIG_FILE_OPTIONS: () => NODE_REGION_CONFIG_FILE_OPTIONS21,
  NODE_REGION_CONFIG_OPTIONS: () => NODE_REGION_CONFIG_OPTIONS21,
  NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS: () => NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS20,
  NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS: () => NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS20,
  ProviderError: () => ProviderError10,
  REGION_ENV_NAME: () => REGION_ENV_NAME2,
  REGION_INI_NAME: () => REGION_INI_NAME2,
  SelectorType: () => SelectorType2,
  TokenProviderError: () => TokenProviderError2,
  booleanSelector: () => booleanSelector2,
  chain: () => chain4,
  externalDataInterceptor: () => externalDataInterceptor2,
  fromStatic: () => fromStatic4,
  fromValue: () => fromValue4,
  getHomeDir: () => getHomeDir4,
  getProfileName: () => getProfileName4,
  getRegionInfo: () => getRegionInfo2,
  getSSOTokenFilepath: () => getSSOTokenFilepath2,
  getSSOTokenFromFile: () => getSSOTokenFromFile2,
  loadConfig: () => loadConfig5,
  loadSharedConfigFiles: () => loadSharedConfigFiles4,
  loadSsoSessionData: () => loadSsoSessionData2,
  memoize: () => memoize4,
  nodeDualstackConfigSelectors: () => nodeDualstackConfigSelectors2,
  nodeFipsConfigSelectors: () => nodeFipsConfigSelectors2,
  numberSelector: () => numberSelector2,
  parseKnownFiles: () => parseKnownFiles2,
  readFile: () => readFile9,
  resolveCustomEndpointsConfig: () => resolveCustomEndpointsConfig2,
  resolveDefaultsModeConfig: () => resolveDefaultsModeConfig20,
  resolveEndpointsConfig: () => resolveEndpointsConfig2,
  resolveRegionConfig: () => resolveRegionConfig20
});
var init_config8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/node_modules/@smithy/core/dist-es/submodules/config/index.js"() {
    init_ProviderError4();
    init_CredentialsProviderError4();
    init_TokenProviderError2();
    init_chain4();
    init_fromValue4();
    init_memoize4();
    init_booleanSelector2();
    init_numberSelector2();
    init_types10();
    init_getHomeDir4();
    init_getProfileName4();
    init_getSSOTokenFilepath2();
    init_getSSOTokenFromFile2();
    init_constants12();
    init_loadSharedConfigFiles4();
    init_loadSsoSessionData2();
    init_parseKnownFiles2();
    init_externalDataInterceptor2();
    init_readFile4();
    init_configLoader4();
    init_fromStatic4();
    init_NodeUseDualstackEndpointConfigOptions2();
    init_NodeUseFipsEndpointConfigOptions2();
    init_resolveCustomEndpointsConfig2();
    init_resolveEndpointsConfig2();
    init_config7();
    init_resolveRegionConfig2();
    init_getRegionInfo2();
    init_resolveDefaultsModeConfig2();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/dist-cjs/index.js
var require_dist_cjs143 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/credential-provider-imds/dist-cjs/index.js"(exports2) {
    "use strict";
    var node_url = require("node:url");
    var config2 = (init_config8(), __toCommonJS(config_exports2));
    var node_http = require("node:http");
    var protocols = (init_protocols13(), __toCommonJS(protocols_exports10));
    var isImdsCredentials = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.AccessKeyId === "string" && typeof arg.SecretAccessKey === "string" && typeof arg.Token === "string" && typeof arg.Expiration === "string", "isImdsCredentials");
    var fromImdsCredentials = /* @__PURE__ */ __name((creds) => ({
      accessKeyId: creds.AccessKeyId,
      secretAccessKey: creds.SecretAccessKey,
      sessionToken: creds.Token,
      expiration: new Date(creds.Expiration),
      ...creds.AccountId && { accountId: creds.AccountId }
    }), "fromImdsCredentials");
    var DEFAULT_TIMEOUT2 = 1e3;
    var DEFAULT_MAX_RETRIES = 0;
    var providerConfigFromInit = /* @__PURE__ */ __name(({ maxRetries = DEFAULT_MAX_RETRIES, timeout = DEFAULT_TIMEOUT2 }) => ({ maxRetries, timeout }), "providerConfigFromInit");
    function httpRequest(options) {
      return new Promise((resolve13, reject) => {
        const req = node_http.request({
          method: "GET",
          ...options,
          hostname: options.hostname?.replace(/^\[(.+)\]$/, "$1")
        });
        req.on("error", (err) => {
          reject(Object.assign(new config2.ProviderError("Unable to connect to instance metadata service"), err));
          req.destroy();
        });
        req.on("timeout", () => {
          reject(new config2.ProviderError("TimeoutError from instance metadata service"));
          req.destroy();
        });
        req.on("response", (res) => {
          const { statusCode = 400 } = res;
          if (statusCode < 200 || 300 <= statusCode) {
            reject(Object.assign(new config2.ProviderError("Error response received from instance metadata service"), { statusCode }));
            req.destroy();
          }
          const chunks2 = [];
          res.on("data", (chunk) => {
            chunks2.push(chunk);
          });
          res.on("end", () => {
            resolve13(Buffer.concat(chunks2));
            req.destroy();
          });
        });
        req.end();
      });
    }
    __name(httpRequest, "httpRequest");
    var retry = /* @__PURE__ */ __name((toRetry, maxRetries) => {
      let promise = toRetry();
      for (let i32 = 0; i32 < maxRetries; i32++) {
        promise = promise.catch(toRetry);
      }
      return promise;
    }, "retry");
    var ENV_CMDS_FULL_URI = "AWS_CONTAINER_CREDENTIALS_FULL_URI";
    var ENV_CMDS_RELATIVE_URI = "AWS_CONTAINER_CREDENTIALS_RELATIVE_URI";
    var ENV_CMDS_AUTH_TOKEN = "AWS_CONTAINER_AUTHORIZATION_TOKEN";
    var fromContainerMetadata = /* @__PURE__ */ __name((init = {}) => {
      const { timeout, maxRetries } = providerConfigFromInit(init);
      return () => retry(async () => {
        const requestOptions = await getCmdsUri({ logger: init.logger });
        const credsResponse = JSON.parse(await requestFromEcsImds(timeout, requestOptions));
        if (!isImdsCredentials(credsResponse)) {
          throw new config2.CredentialsProviderError("Invalid response received from instance metadata service.", {
            logger: init.logger
          });
        }
        return fromImdsCredentials(credsResponse);
      }, maxRetries);
    }, "fromContainerMetadata");
    var requestFromEcsImds = /* @__PURE__ */ __name(async (timeout, options) => {
      if (process.env[ENV_CMDS_AUTH_TOKEN]) {
        options.headers = {
          ...options.headers,
          Authorization: process.env[ENV_CMDS_AUTH_TOKEN]
        };
      }
      const buffer = await httpRequest({
        ...options,
        timeout
      });
      return buffer.toString();
    }, "requestFromEcsImds");
    var CMDS_IP = "169.254.170.2";
    var GREENGRASS_HOSTS = {
      localhost: true,
      "127.0.0.1": true
    };
    var GREENGRASS_PROTOCOLS = {
      "http:": true,
      "https:": true
    };
    var getCmdsUri = /* @__PURE__ */ __name(async ({ logger: logger5 }) => {
      if (process.env[ENV_CMDS_RELATIVE_URI]) {
        return {
          hostname: CMDS_IP,
          path: process.env[ENV_CMDS_RELATIVE_URI]
        };
      }
      if (process.env[ENV_CMDS_FULL_URI]) {
        const parsed = node_url.parse(process.env[ENV_CMDS_FULL_URI]);
        if (!parsed.hostname || !(parsed.hostname in GREENGRASS_HOSTS)) {
          throw new config2.CredentialsProviderError(`${parsed.hostname} is not a valid container metadata service hostname`, {
            tryNextLink: false,
            logger: logger5
          });
        }
        if (!parsed.protocol || !(parsed.protocol in GREENGRASS_PROTOCOLS)) {
          throw new config2.CredentialsProviderError(`${parsed.protocol} is not a valid container metadata service protocol`, {
            tryNextLink: false,
            logger: logger5
          });
        }
        return {
          ...parsed,
          port: parsed.port ? parseInt(parsed.port, 10) : void 0
        };
      }
      throw new config2.CredentialsProviderError(`The container metadata credential provider cannot be used unless the ${ENV_CMDS_RELATIVE_URI} or ${ENV_CMDS_FULL_URI} environment variable is set`, {
        tryNextLink: false,
        logger: logger5
      });
    }, "getCmdsUri");
    var InstanceMetadataV1FallbackError = class _InstanceMetadataV1FallbackError extends config2.CredentialsProviderError {
      static {
        __name(this, "InstanceMetadataV1FallbackError");
      }
      tryNextLink;
      name = "InstanceMetadataV1FallbackError";
      constructor(message2, tryNextLink = true) {
        super(message2, tryNextLink);
        this.tryNextLink = tryNextLink;
        Object.setPrototypeOf(this, _InstanceMetadataV1FallbackError.prototype);
      }
    };
    exports2.Endpoint = void 0;
    (function(Endpoint) {
      Endpoint["IPv4"] = "http://169.254.169.254";
      Endpoint["IPv6"] = "http://[fd00:ec2::254]";
    })(exports2.Endpoint || (exports2.Endpoint = {}));
    var ENV_ENDPOINT_NAME = "AWS_EC2_METADATA_SERVICE_ENDPOINT";
    var CONFIG_ENDPOINT_NAME = "ec2_metadata_service_endpoint";
    var ENDPOINT_CONFIG_OPTIONS = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[ENV_ENDPOINT_NAME], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[CONFIG_ENDPOINT_NAME], "configFileSelector"),
      default: void 0
    };
    var EndpointMode;
    (function(EndpointMode2) {
      EndpointMode2["IPv4"] = "IPv4";
      EndpointMode2["IPv6"] = "IPv6";
    })(EndpointMode || (EndpointMode = {}));
    var ENV_ENDPOINT_MODE_NAME = "AWS_EC2_METADATA_SERVICE_ENDPOINT_MODE";
    var CONFIG_ENDPOINT_MODE_NAME = "ec2_metadata_service_endpoint_mode";
    var ENDPOINT_MODE_CONFIG_OPTIONS = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[ENV_ENDPOINT_MODE_NAME], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[CONFIG_ENDPOINT_MODE_NAME], "configFileSelector"),
      default: EndpointMode.IPv4
    };
    var getInstanceMetadataEndpoint = /* @__PURE__ */ __name(async () => protocols.parseUrl(await getFromEndpointConfig() || await getFromEndpointModeConfig()), "getInstanceMetadataEndpoint");
    var getFromEndpointConfig = /* @__PURE__ */ __name(async () => config2.loadConfig(ENDPOINT_CONFIG_OPTIONS)(), "getFromEndpointConfig");
    var getFromEndpointModeConfig = /* @__PURE__ */ __name(async () => {
      const endpointMode = await config2.loadConfig(ENDPOINT_MODE_CONFIG_OPTIONS)();
      switch (endpointMode) {
        case EndpointMode.IPv4:
          return exports2.Endpoint.IPv4;
        case EndpointMode.IPv6:
          return exports2.Endpoint.IPv6;
        default:
          throw new Error(`Unsupported endpoint mode: ${endpointMode}. Select from ${Object.values(EndpointMode)}`);
      }
    }, "getFromEndpointModeConfig");
    var STATIC_STABILITY_REFRESH_INTERVAL_SECONDS = 5 * 60;
    var STATIC_STABILITY_REFRESH_INTERVAL_JITTER_WINDOW_SECONDS = 5 * 60;
    var STATIC_STABILITY_DOC_URL = "https://docs.aws.amazon.com/sdkref/latest/guide/feature-static-credentials.html";
    var getExtendedInstanceMetadataCredentials = /* @__PURE__ */ __name((credentials, logger5) => {
      const refreshInterval = STATIC_STABILITY_REFRESH_INTERVAL_SECONDS + Math.floor(Math.random() * STATIC_STABILITY_REFRESH_INTERVAL_JITTER_WINDOW_SECONDS);
      const newExpiration = new Date(Date.now() + refreshInterval * 1e3);
      logger5.warn(`Attempting credential expiration extension due to a credential service availability issue. A refresh of these credentials will be attempted after ${new Date(newExpiration)}.
For more information, please visit: ` + STATIC_STABILITY_DOC_URL);
      const originalExpiration = credentials.originalExpiration ?? credentials.expiration;
      return {
        ...credentials,
        ...originalExpiration ? { originalExpiration } : {},
        expiration: newExpiration
      };
    }, "getExtendedInstanceMetadataCredentials");
    var staticStabilityProvider = /* @__PURE__ */ __name((provider, options = {}) => {
      const logger5 = options?.logger || console;
      let pastCredentials;
      return async () => {
        let credentials;
        try {
          credentials = await provider();
          if (credentials.expiration && credentials.expiration.getTime() < Date.now()) {
            credentials = getExtendedInstanceMetadataCredentials(credentials, logger5);
          }
        } catch (e32) {
          if (pastCredentials) {
            logger5.warn("Credential renew failed: ", e32);
            credentials = getExtendedInstanceMetadataCredentials(pastCredentials, logger5);
          } else {
            throw e32;
          }
        }
        pastCredentials = credentials;
        return credentials;
      };
    }, "staticStabilityProvider");
    var IMDS_PATH = "/latest/meta-data/iam/security-credentials/";
    var IMDS_TOKEN_PATH = "/latest/api/token";
    var AWS_EC2_METADATA_V1_DISABLED = "AWS_EC2_METADATA_V1_DISABLED";
    var PROFILE_AWS_EC2_METADATA_V1_DISABLED = "ec2_metadata_v1_disabled";
    var X_AWS_EC2_METADATA_TOKEN = "x-aws-ec2-metadata-token";
    var fromInstanceMetadata = /* @__PURE__ */ __name((init = {}) => staticStabilityProvider(getInstanceMetadataProvider(init), { logger: init.logger }), "fromInstanceMetadata");
    var getInstanceMetadataProvider = /* @__PURE__ */ __name((init = {}) => {
      let disableFetchToken = false;
      const { logger: logger5, profile } = init;
      const { timeout, maxRetries } = providerConfigFromInit(init);
      const getCredentials = /* @__PURE__ */ __name(async (maxRetries2, options) => {
        const isImdsV1Fallback = disableFetchToken || options.headers?.[X_AWS_EC2_METADATA_TOKEN] == null;
        if (isImdsV1Fallback) {
          let fallbackBlockedFromProfile = false;
          let fallbackBlockedFromProcessEnv = false;
          const configValue = await config2.loadConfig({
            environmentVariableSelector: /* @__PURE__ */ __name((env3) => {
              const envValue = env3[AWS_EC2_METADATA_V1_DISABLED];
              fallbackBlockedFromProcessEnv = !!envValue && envValue !== "false";
              if (envValue === void 0) {
                throw new config2.CredentialsProviderError(`${AWS_EC2_METADATA_V1_DISABLED} not set in env, checking config file next.`, { logger: init.logger });
              }
              return fallbackBlockedFromProcessEnv;
            }, "environmentVariableSelector"),
            configFileSelector: /* @__PURE__ */ __name((profile2) => {
              const profileValue = profile2[PROFILE_AWS_EC2_METADATA_V1_DISABLED];
              fallbackBlockedFromProfile = !!profileValue && profileValue !== "false";
              return fallbackBlockedFromProfile;
            }, "configFileSelector"),
            default: false
          }, {
            profile
          })();
          if (init.ec2MetadataV1Disabled || configValue) {
            const causes = [];
            if (init.ec2MetadataV1Disabled)
              causes.push("credential provider initialization (runtime option ec2MetadataV1Disabled)");
            if (fallbackBlockedFromProfile)
              causes.push(`config file profile (${PROFILE_AWS_EC2_METADATA_V1_DISABLED})`);
            if (fallbackBlockedFromProcessEnv)
              causes.push(`process environment variable (${AWS_EC2_METADATA_V1_DISABLED})`);
            throw new InstanceMetadataV1FallbackError(`AWS EC2 Metadata v1 fallback has been blocked by AWS SDK configuration in the following: [${causes.join(", ")}].`);
          }
        }
        const imdsProfile = (await retry(async () => {
          let profile2;
          try {
            profile2 = await getProfile(options);
          } catch (err) {
            if (err.statusCode === 401) {
              disableFetchToken = false;
            }
            throw err;
          }
          return profile2;
        }, maxRetries2)).trim();
        return retry(async () => {
          let creds;
          try {
            creds = await getCredentialsFromProfile(imdsProfile, options, init);
          } catch (err) {
            if (err.statusCode === 401) {
              disableFetchToken = false;
            }
            throw err;
          }
          return creds;
        }, maxRetries2);
      }, "getCredentials");
      return async () => {
        const endpoint = await getInstanceMetadataEndpoint();
        if (disableFetchToken) {
          logger5?.debug("AWS SDK Instance Metadata", "using v1 fallback (no token fetch)");
          return getCredentials(maxRetries, { ...endpoint, timeout });
        } else {
          let token;
          try {
            token = (await getMetadataToken({ ...endpoint, timeout })).toString();
          } catch (error4) {
            if (error4?.statusCode === 400) {
              throw Object.assign(error4, {
                message: "EC2 Metadata token request returned error"
              });
            } else if (error4.message === "TimeoutError" || [403, 404, 405].includes(error4.statusCode)) {
              disableFetchToken = true;
            }
            logger5?.debug("AWS SDK Instance Metadata", "using v1 fallback (initial)");
            return getCredentials(maxRetries, { ...endpoint, timeout });
          }
          return getCredentials(maxRetries, {
            ...endpoint,
            headers: {
              [X_AWS_EC2_METADATA_TOKEN]: token
            },
            timeout
          });
        }
      };
    }, "getInstanceMetadataProvider");
    var getMetadataToken = /* @__PURE__ */ __name(async (options) => httpRequest({
      ...options,
      path: IMDS_TOKEN_PATH,
      method: "PUT",
      headers: {
        "x-aws-ec2-metadata-token-ttl-seconds": "21600"
      }
    }), "getMetadataToken");
    var getProfile = /* @__PURE__ */ __name(async (options) => (await httpRequest({ ...options, path: IMDS_PATH })).toString(), "getProfile");
    var getCredentialsFromProfile = /* @__PURE__ */ __name(async (profile, options, init) => {
      const credentialsResponse = JSON.parse((await httpRequest({
        ...options,
        path: IMDS_PATH + profile
      })).toString());
      if (!isImdsCredentials(credentialsResponse)) {
        throw new config2.CredentialsProviderError("Invalid response received from instance metadata service.", {
          logger: init.logger
        });
      }
      return fromImdsCredentials(credentialsResponse);
    }, "getCredentialsFromProfile");
    exports2.DEFAULT_MAX_RETRIES = DEFAULT_MAX_RETRIES;
    exports2.DEFAULT_TIMEOUT = DEFAULT_TIMEOUT2;
    exports2.ENV_CMDS_AUTH_TOKEN = ENV_CMDS_AUTH_TOKEN;
    exports2.ENV_CMDS_FULL_URI = ENV_CMDS_FULL_URI;
    exports2.ENV_CMDS_RELATIVE_URI = ENV_CMDS_RELATIVE_URI;
    exports2.fromContainerMetadata = fromContainerMetadata;
    exports2.fromInstanceMetadata = fromInstanceMetadata;
    exports2.getInstanceMetadataEndpoint = getInstanceMetadataEndpoint;
    exports2.httpRequest = httpRequest;
    exports2.providerConfigFromInit = providerConfigFromInit;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/is-array-buffer/is-array-buffer.js
var isArrayBuffer6;
var init_is_array_buffer6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/is-array-buffer/is-array-buffer.js"() {
    isArrayBuffer6 = /* @__PURE__ */ __name((arg) => typeof ArrayBuffer === "function" && arg instanceof ArrayBuffer || Object.prototype.toString.call(arg) === "[object ArrayBuffer]", "isArrayBuffer");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-buffer-from/buffer-from.js
var fromArrayBuffer6, fromString6;
var init_buffer_from6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-buffer-from/buffer-from.js"() {
    init_is_array_buffer6();
    fromArrayBuffer6 = /* @__PURE__ */ __name((input, offset = 0, length = input.byteLength - offset) => {
      if (!isArrayBuffer6(input)) {
        throw new TypeError(`The "input" argument must be ArrayBuffer. Received type ${typeof input} (${input})`);
      }
      return Buffer.from(input, offset, length);
    }, "fromArrayBuffer");
    fromString6 = /* @__PURE__ */ __name((input, encoding) => {
      if (typeof input !== "string") {
        throw new TypeError(`The "input" argument must be of type string. Received type ${typeof input} (${input})`);
      }
      return encoding ? Buffer.from(input, encoding) : Buffer.from(input);
    }, "fromString");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/fromBase64.js
var BASE64_REGEX6, fromBase6442;
var init_fromBase646 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/fromBase64.js"() {
    init_buffer_from6();
    BASE64_REGEX6 = /^[A-Za-z0-9+/]*={0,2}$/;
    fromBase6442 = /* @__PURE__ */ __name((input) => {
      if (input.length * 3 % 4 !== 0) {
        throw new TypeError(`Incorrect padding on base64 string.`);
      }
      if (!BASE64_REGEX6.exec(input)) {
        throw new TypeError(`Invalid base64 string.`);
      }
      const buffer = fromString6(input, "base64");
      return new Uint8Array(buffer.buffer, buffer.byteOffset, buffer.byteLength);
    }, "fromBase64");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/fromUtf8.js
var fromUtf831;
var init_fromUtf86 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/fromUtf8.js"() {
    init_buffer_from6();
    fromUtf831 = /* @__PURE__ */ __name((input) => {
      const buf = fromString6(input, "utf8");
      return new Uint8Array(buf.buffer, buf.byteOffset, buf.byteLength / Uint8Array.BYTES_PER_ELEMENT);
    }, "fromUtf8");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/toBase64.js
var toBase6447;
var init_toBase646 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/toBase64.js"() {
    init_buffer_from6();
    init_fromUtf86();
    toBase6447 = /* @__PURE__ */ __name((_input) => {
      let input;
      if (typeof _input === "string") {
        input = fromUtf831(_input);
      } else {
        input = _input;
      }
      if (typeof input !== "object" || typeof input.byteOffset !== "number" || typeof input.byteLength !== "number") {
        throw new Error("@smithy/util-base64: toBase64 encoder function only accepts string | Uint8Array.");
      }
      return fromArrayBuffer6(input.buffer, input.byteOffset, input.byteLength).toString("base64");
    }, "toBase64");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/blob/Uint8ArrayBlobAdapter.js
function bindUint8ArrayBlobAdapter6(toUtf862, fromUtf842, toBase6467, fromBase6459) {
  return class Uint8ArrayBlobAdapter8 extends Uint8Array {
    static {
      __name(this, "Uint8ArrayBlobAdapter");
    }
    static fromString(source, encoding = "utf-8") {
      if (typeof source === "string") {
        if (encoding === "base64") {
          return Uint8ArrayBlobAdapter8.mutate(fromBase6459(source));
        }
        return Uint8ArrayBlobAdapter8.mutate(fromUtf842(source));
      }
      throw new Error(`Unsupported conversion from ${typeof source} to Uint8ArrayBlobAdapter.`);
    }
    static mutate(source) {
      Object.setPrototypeOf(source, Uint8ArrayBlobAdapter8.prototype);
      return source;
    }
    transformToString(encoding = "utf-8") {
      if (encoding === "base64") {
        return toBase6467(this);
      }
      return toUtf862(this);
    }
  };
}
var init_Uint8ArrayBlobAdapter6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/blob/Uint8ArrayBlobAdapter.js"() {
    __name(bindUint8ArrayBlobAdapter6, "bindUint8ArrayBlobAdapter");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/toUtf8.js
var toUtf845;
var init_toUtf86 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/toUtf8.js"() {
    init_buffer_from6();
    toUtf845 = /* @__PURE__ */ __name((input) => {
      if (typeof input === "string") {
        return input;
      }
      if (typeof input !== "object" || typeof input.byteOffset !== "number" || typeof input.byteLength !== "number") {
        throw new Error("@smithy/util-utf8: toUtf8 encoder function only accepts string | Uint8Array.");
      }
      return fromArrayBuffer6(input.buffer, input.byteOffset, input.byteLength).toString("utf8");
    }, "toUtf8");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/uuid/v4.js
function bindV46(getRandomValues7) {
  if (typeof crypto !== "undefined" && typeof crypto.randomUUID === "function") {
    return () => crypto.randomUUID();
  }
  return () => {
    const rnds = new Uint8Array(16);
    getRandomValues7(rnds);
    rnds[6] = rnds[6] & 15 | 64;
    rnds[8] = rnds[8] & 63 | 128;
    return decimalToHex6[rnds[0]] + decimalToHex6[rnds[1]] + decimalToHex6[rnds[2]] + decimalToHex6[rnds[3]] + "-" + decimalToHex6[rnds[4]] + decimalToHex6[rnds[5]] + "-" + decimalToHex6[rnds[6]] + decimalToHex6[rnds[7]] + "-" + decimalToHex6[rnds[8]] + decimalToHex6[rnds[9]] + "-" + decimalToHex6[rnds[10]] + decimalToHex6[rnds[11]] + decimalToHex6[rnds[12]] + decimalToHex6[rnds[13]] + decimalToHex6[rnds[14]] + decimalToHex6[rnds[15]];
  };
}
var decimalToHex6;
var init_v46 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/uuid/v4.js"() {
    decimalToHex6 = Array.from({ length: 256 }, (_, i32) => i32.toString(16).padStart(2, "0"));
    __name(bindV46, "bindV4");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/date-utils.js
function dateToUtcString18(date7) {
  const year7 = date7.getUTCFullYear();
  const month = date7.getUTCMonth();
  const dayOfWeek = date7.getUTCDay();
  const dayOfMonthInt = date7.getUTCDate();
  const hoursInt = date7.getUTCHours();
  const minutesInt = date7.getUTCMinutes();
  const secondsInt = date7.getUTCSeconds();
  const dayOfMonthString = dayOfMonthInt < 10 ? `0${dayOfMonthInt}` : `${dayOfMonthInt}`;
  const hoursString = hoursInt < 10 ? `0${hoursInt}` : `${hoursInt}`;
  const minutesString = minutesInt < 10 ? `0${minutesInt}` : `${minutesInt}`;
  const secondsString = secondsInt < 10 ? `0${secondsInt}` : `${secondsInt}`;
  return `${DAYS6[dayOfWeek]}, ${dayOfMonthString} ${MONTHS7[month]} ${year7} ${hoursString}:${minutesString}:${secondsString} GMT`;
}
var DAYS6, MONTHS7, RFC33397, RFC3339_WITH_OFFSET12, IMF_FIXDATE12, RFC_850_DATE12, ASC_TIME12, FIFTY_YEARS_IN_MILLIS7;
var init_date_utils7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/date-utils.js"() {
    DAYS6 = ["Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"];
    MONTHS7 = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"];
    __name(dateToUtcString18, "dateToUtcString");
    RFC33397 = new RegExp(/^(\d{4})-(\d{2})-(\d{2})[tT](\d{2}):(\d{2}):(\d{2})(?:\.(\d+))?[zZ]$/);
    RFC3339_WITH_OFFSET12 = new RegExp(/^(\d{4})-(\d{2})-(\d{2})[tT](\d{2}):(\d{2}):(\d{2})(?:\.(\d+))?(([-+]\d{2}\:\d{2})|[zZ])$/);
    IMF_FIXDATE12 = new RegExp(/^(?:Mon|Tue|Wed|Thu|Fri|Sat|Sun), (\d{2}) (Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec) (\d{4}) (\d{1,2}):(\d{2}):(\d{2})(?:\.(\d+))? GMT$/);
    RFC_850_DATE12 = new RegExp(/^(?:Monday|Tuesday|Wednesday|Thursday|Friday|Saturday|Sunday), (\d{2})-(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)-(\d{2}) (\d{1,2}):(\d{2}):(\d{2})(?:\.(\d+))? GMT$/);
    ASC_TIME12 = new RegExp(/^(?:Mon|Tue|Wed|Thu|Fri|Sat|Sun) (Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec) ( [1-9]|\d{2}) (\d{1,2}):(\d{2}):(\d{2})(?:\.(\d+))? (\d{4})$/);
    FIFTY_YEARS_IN_MILLIS7 = 50 * 365 * 24 * 60 * 60 * 1e3;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/lazy-json.js
var LazyJsonString11;
var init_lazy_json6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/lazy-json.js"() {
    LazyJsonString11 = /* @__PURE__ */ __name(function LazyJsonString12(val) {
      const str = Object.assign(new String(val), {
        deserializeJSON() {
          return JSON.parse(String(val));
        },
        toString() {
          return String(val);
        },
        toJSON() {
          return String(val);
        }
      });
      return str;
    }, "LazyJsonString");
    LazyJsonString11.from = (object) => {
      if (object && typeof object === "object" && (object instanceof LazyJsonString11 || "deserializeJSON" in object)) {
        return object;
      } else if (typeof object === "string" || Object.getPrototypeOf(object) === String.prototype) {
        return LazyJsonString11(String(object));
      }
      return LazyJsonString11(JSON.stringify(object));
    };
    LazyJsonString11.fromObject = LazyJsonString11.from;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/quote-header.js
function quoteHeader6(part) {
  if (part.includes(",") || part.includes('"')) {
    part = `"${part.replace(/"/g, '\\"')}"`;
  }
  return part;
}
var init_quote_header6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/quote-header.js"() {
    __name(quoteHeader6, "quoteHeader");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/schema-serde-lib/schema-date-utils.js
function range6(v, min, max) {
  const _v = Number(v);
  if (_v < min || _v > max) {
    throw new Error(`Value ${_v} out of range [${min}, ${max}]`);
  }
}
var ddd6, mmm6, time6, date6, year6, RFC3339_WITH_OFFSET13, IMF_FIXDATE13, RFC_850_DATE13, ASC_TIME13, months6, _parseEpochTimestamp6, _parseRfc3339DateTimeWithOffset6, _parseRfc7231DateTime6;
var init_schema_date_utils6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/schema-serde-lib/schema-date-utils.js"() {
    ddd6 = `(?:Mon|Tue|Wed|Thu|Fri|Sat|Sun)(?:[ne|u?r]?s?day)?`;
    mmm6 = `(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)`;
    time6 = `(\\d?\\d):(\\d{2}):(\\d{2})(?:\\.(\\d+))?`;
    date6 = `(\\d?\\d)`;
    year6 = `(\\d{4})`;
    RFC3339_WITH_OFFSET13 = new RegExp(/^(\d{4})-(\d\d)-(\d\d)[tT](\d\d):(\d\d):(\d\d)(\.(\d+))?(([-+]\d\d:\d\d)|[zZ])$/);
    IMF_FIXDATE13 = new RegExp(`^${ddd6}, ${date6} ${mmm6} ${year6} ${time6} GMT$`);
    RFC_850_DATE13 = new RegExp(`^${ddd6}, ${date6}-${mmm6}-(\\d\\d) ${time6} GMT$`);
    ASC_TIME13 = new RegExp(`^${ddd6} ${mmm6} ( [1-9]|\\d\\d) ${time6} ${year6}$`);
    months6 = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"];
    _parseEpochTimestamp6 = /* @__PURE__ */ __name((value) => {
      if (value == null) {
        return void 0;
      }
      let num = NaN;
      if (typeof value === "number") {
        num = value;
      } else if (typeof value === "string") {
        if (!/^-?\d*\.?\d+$/.test(value)) {
          throw new TypeError(`parseEpochTimestamp - numeric string invalid.`);
        }
        num = Number.parseFloat(value);
      } else if (typeof value === "object" && value.tag === 1) {
        num = value.value;
      }
      if (isNaN(num) || Math.abs(num) === Infinity) {
        throw new TypeError("Epoch timestamps must be valid finite numbers.");
      }
      return new Date(Math.round(num * 1e3));
    }, "_parseEpochTimestamp");
    _parseRfc3339DateTimeWithOffset6 = /* @__PURE__ */ __name((value) => {
      if (value == null) {
        return void 0;
      }
      if (typeof value !== "string") {
        throw new TypeError("RFC3339 timestamps must be strings");
      }
      const matches = RFC3339_WITH_OFFSET13.exec(value);
      if (!matches) {
        throw new TypeError(`Invalid RFC3339 timestamp format ${value}`);
      }
      const [, yearStr, monthStr, dayStr, hours, minutes, seconds, , ms, offsetStr] = matches;
      range6(monthStr, 1, 12);
      range6(dayStr, 1, 31);
      range6(hours, 0, 23);
      range6(minutes, 0, 59);
      range6(seconds, 0, 60);
      const date7 = new Date(Date.UTC(Number(yearStr), Number(monthStr) - 1, Number(dayStr), Number(hours), Number(minutes), Number(seconds), Number(ms) ? Math.round(parseFloat(`0.${ms}`) * 1e3) : 0));
      date7.setUTCFullYear(Number(yearStr));
      if (offsetStr.toUpperCase() != "Z") {
        const [, sign, offsetH, offsetM] = /([+-])(\d\d):(\d\d)/.exec(offsetStr) || [void 0, "+", 0, 0];
        const scalar = sign === "-" ? 1 : -1;
        date7.setTime(date7.getTime() + scalar * (Number(offsetH) * 60 * 60 * 1e3 + Number(offsetM) * 60 * 1e3));
      }
      return date7;
    }, "_parseRfc3339DateTimeWithOffset");
    _parseRfc7231DateTime6 = /* @__PURE__ */ __name((value) => {
      if (value == null) {
        return void 0;
      }
      if (typeof value !== "string") {
        throw new TypeError("RFC7231 timestamps must be strings.");
      }
      let day;
      let month;
      let year7;
      let hour;
      let minute;
      let second;
      let fraction;
      let matches;
      if (matches = IMF_FIXDATE13.exec(value)) {
        [, day, month, year7, hour, minute, second, fraction] = matches;
      } else if (matches = RFC_850_DATE13.exec(value)) {
        [, day, month, year7, hour, minute, second, fraction] = matches;
        year7 = (Number(year7) + 1900).toString();
      } else if (matches = ASC_TIME13.exec(value)) {
        [, month, day, hour, minute, second, fraction, year7] = matches;
      }
      if (year7 && second) {
        const timestamp = Date.UTC(Number(year7), months6.indexOf(month), Number(day), Number(hour), Number(minute), Number(second), fraction ? Math.round(parseFloat(`0.${fraction}`) * 1e3) : 0);
        range6(day, 1, 31);
        range6(hour, 0, 23);
        range6(minute, 0, 59);
        range6(second, 0, 60);
        const date7 = new Date(timestamp);
        date7.setUTCFullYear(Number(year7));
        return date7;
      }
      throw new TypeError(`Invalid RFC7231 date-time value ${value}.`);
    }, "_parseRfc7231DateTime");
    __name(range6, "range");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/split-every.js
function splitEvery6(value, delimiter2, numDelimiters) {
  if (numDelimiters <= 0 || !Number.isInteger(numDelimiters)) {
    throw new Error("Invalid number of delimiters (" + numDelimiters + ") for splitEvery.");
  }
  const segments = value.split(delimiter2);
  if (numDelimiters === 1) {
    return segments;
  }
  const compoundSegments = [];
  let currentSegment = "";
  for (let i32 = 0; i32 < segments.length; i32++) {
    if (currentSegment === "") {
      currentSegment = segments[i32];
    } else {
      currentSegment += delimiter2 + segments[i32];
    }
    if ((i32 + 1) % numDelimiters === 0) {
      compoundSegments.push(currentSegment);
      currentSegment = "";
    }
  }
  if (currentSegment !== "") {
    compoundSegments.push(currentSegment);
  }
  return compoundSegments;
}
var init_split_every6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/split-every.js"() {
    __name(splitEvery6, "splitEvery");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/split-header.js
var splitHeader6;
var init_split_header6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/split-header.js"() {
    splitHeader6 = /* @__PURE__ */ __name((value) => {
      const z = value.length;
      const values = [];
      let withinQuotes = false;
      let prevChar = void 0;
      let anchor = 0;
      for (let i32 = 0; i32 < z; ++i32) {
        const char = value[i32];
        switch (char) {
          case `"`:
            if (prevChar !== "\\") {
              withinQuotes = !withinQuotes;
            }
            break;
          case ",":
            if (!withinQuotes) {
              values.push(value.slice(anchor, i32));
              anchor = i32 + 1;
            }
            break;
          default:
        }
        prevChar = char;
      }
      values.push(value.slice(anchor));
      return values.map((v) => {
        v = v.trim();
        const z2 = v.length;
        if (z2 < 2) {
          return v;
        }
        if (v[0] === `"` && v[z2 - 1] === `"`) {
          v = v.slice(1, z2 - 1);
        }
        return v.replace(/\\"/g, '"');
      });
    }, "splitHeader");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/value/NumericValue.js
var format16, NumericValue6;
var init_NumericValue6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/value/NumericValue.js"() {
    format16 = /^-?\d*(\.\d+)?$/;
    NumericValue6 = class _NumericValue {
      static {
        __name(this, "NumericValue");
      }
      string;
      type;
      constructor(string, type) {
        this.string = string;
        this.type = type;
        if (!format16.test(string)) {
          throw new Error(`@smithy/core/serde - NumericValue must only contain [0-9], at most one decimal point ".", and an optional negation prefix "-".`);
        }
      }
      toString() {
        return this.string;
      }
      static [Symbol.hasInstance](object) {
        if (!object || typeof object !== "object") {
          return false;
        }
        const _nv = object;
        return _NumericValue.prototype.isPrototypeOf(object) || _nv.type === "bigDecimal" && format16.test(_nv.string);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-hex-encoding/hex-encoding.js
function fromHex5(encoded) {
  if (encoded.length % 2 !== 0) {
    throw new Error("Hex encoded strings must have an even number length");
  }
  const out = new Uint8Array(encoded.length / 2);
  for (let i32 = 0; i32 < encoded.length; i32 += 2) {
    const encodedByte = encoded.slice(i32, i32 + 2).toLowerCase();
    if (encodedByte in HEX_TO_SHORT5) {
      out[i32 / 2] = HEX_TO_SHORT5[encodedByte];
    } else {
      throw new Error(`Cannot decode unrecognized sequence ${encodedByte} as hexadecimal`);
    }
  }
  return out;
}
function toHex5(bytes) {
  let out = "";
  for (let i32 = 0; i32 < bytes.byteLength; i32++) {
    out += SHORT_TO_HEX5[bytes[i32]];
  }
  return out;
}
var SHORT_TO_HEX5, HEX_TO_SHORT5;
var init_hex_encoding5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-hex-encoding/hex-encoding.js"() {
    SHORT_TO_HEX5 = {};
    HEX_TO_SHORT5 = {};
    for (let i32 = 0; i32 < 256; i32++) {
      let encodedByte = i32.toString(16).toLowerCase();
      if (encodedByte.length === 1) {
        encodedByte = `0${encodedByte}`;
      }
      SHORT_TO_HEX5[i32] = encodedByte;
      HEX_TO_SHORT5[encodedByte] = i32;
    }
    __name(fromHex5, "fromHex");
    __name(toHex5, "toHex");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/deref.js
var deref6;
var init_deref6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/deref.js"() {
    deref6 = /* @__PURE__ */ __name((schemaRef) => {
      if (typeof schemaRef === "function") {
        return schemaRef();
      }
      return schemaRef;
    }, "deref");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/schemas/operation.js
var init_operation6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/schemas/operation.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/middleware/getSchemaSerdePlugin.js
var init_getSchemaSerdePlugin6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/middleware/getSchemaSerdePlugin.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/schemas/Schema.js
var init_Schema6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/schemas/Schema.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/schemas/ListSchema.js
var init_ListSchema6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/schemas/ListSchema.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/schemas/MapSchema.js
var init_MapSchema6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/schemas/MapSchema.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/schemas/OperationSchema.js
var init_OperationSchema6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/schemas/OperationSchema.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/schemas/StructureSchema.js
var init_StructureSchema6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/schemas/StructureSchema.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/schemas/ErrorSchema.js
var init_ErrorSchema6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/schemas/ErrorSchema.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/schemas/translateTraits.js
function translateTraits6(indicator) {
  if (typeof indicator === "object") {
    return indicator;
  }
  indicator = indicator | 0;
  if (traitsCache6[indicator]) {
    return traitsCache6[indicator];
  }
  const traits = {};
  let i32 = 0;
  for (const trait of [
    "httpLabel",
    "idempotent",
    "idempotencyToken",
    "sensitive",
    "httpPayload",
    "httpResponseCode",
    "httpQueryParams"
  ]) {
    if ((indicator >> i32++ & 1) === 1) {
      traits[trait] = 1;
    }
  }
  return traitsCache6[indicator] = traits;
}
var traitsCache6;
var init_translateTraits6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/schemas/translateTraits.js"() {
    traitsCache6 = [];
    __name(translateTraits6, "translateTraits");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/schemas/NormalizedSchema.js
function member6(memberSchema, memberName) {
  if (memberSchema instanceof NormalizedSchema6) {
    return Object.assign(memberSchema, {
      memberName,
      _isMemberSchema: true
    });
  }
  const internalCtorAccess = NormalizedSchema6;
  return new internalCtorAccess(memberSchema, memberName);
}
var anno6, simpleSchemaCacheN6, simpleSchemaCacheS6, NormalizedSchema6, isMemberSchema6, isStaticSchema6;
var init_NormalizedSchema6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/schemas/NormalizedSchema.js"() {
    init_deref6();
    init_translateTraits6();
    anno6 = {
      it: /* @__PURE__ */ Symbol.for("@smithy/nor-struct-it"),
      ns: /* @__PURE__ */ Symbol.for("@smithy/ns")
    };
    simpleSchemaCacheN6 = [];
    simpleSchemaCacheS6 = {};
    NormalizedSchema6 = class _NormalizedSchema {
      static {
        __name(this, "NormalizedSchema");
      }
      ref;
      memberName;
      static symbol = /* @__PURE__ */ Symbol.for("@smithy/nor");
      symbol = _NormalizedSchema.symbol;
      name;
      schema;
      _isMemberSchema;
      traits;
      memberTraits;
      normalizedTraits;
      constructor(ref, memberName) {
        this.ref = ref;
        this.memberName = memberName;
        const traitStack = [];
        let _ref = ref;
        let schema = ref;
        this._isMemberSchema = false;
        while (isMemberSchema6(_ref)) {
          traitStack.push(_ref[1]);
          _ref = _ref[0];
          schema = deref6(_ref);
          this._isMemberSchema = true;
        }
        if (traitStack.length > 0) {
          this.memberTraits = {};
          for (let i32 = traitStack.length - 1; i32 >= 0; --i32) {
            const traitSet = traitStack[i32];
            Object.assign(this.memberTraits, translateTraits6(traitSet));
          }
        } else {
          this.memberTraits = 0;
        }
        if (schema instanceof _NormalizedSchema) {
          const computedMemberTraits = this.memberTraits;
          Object.assign(this, schema);
          this.memberTraits = Object.assign({}, computedMemberTraits, schema.getMemberTraits(), this.getMemberTraits());
          this.normalizedTraits = void 0;
          this.memberName = memberName ?? schema.memberName;
          return;
        }
        this.schema = deref6(schema);
        if (isStaticSchema6(this.schema)) {
          this.name = `${this.schema[1]}#${this.schema[2]}`;
          this.traits = this.schema[3];
        } else {
          this.name = this.memberName ?? String(schema);
          this.traits = 0;
        }
        if (this._isMemberSchema && !memberName) {
          throw new Error(`@smithy/core/schema - NormalizedSchema member init ${this.getName(true)} missing member name.`);
        }
      }
      static [Symbol.hasInstance](lhs) {
        const isPrototype = this.prototype.isPrototypeOf(lhs);
        if (!isPrototype && typeof lhs === "object" && lhs !== null) {
          const ns = lhs;
          return ns.symbol === this.symbol;
        }
        return isPrototype;
      }
      static of(ref) {
        const keyAble = typeof ref === "function" || typeof ref === "object" && ref !== null;
        if (typeof ref === "number") {
          if (simpleSchemaCacheN6[ref]) {
            return simpleSchemaCacheN6[ref];
          }
        } else if (typeof ref === "string") {
          if (simpleSchemaCacheS6[ref]) {
            return simpleSchemaCacheS6[ref];
          }
        } else if (keyAble) {
          if (ref[anno6.ns]) {
            return ref[anno6.ns];
          }
        }
        const sc = deref6(ref);
        if (sc instanceof _NormalizedSchema) {
          return sc;
        }
        if (isMemberSchema6(sc)) {
          const [ns2, traits] = sc;
          if (ns2 instanceof _NormalizedSchema) {
            Object.assign(ns2.getMergedTraits(), translateTraits6(traits));
            return ns2;
          }
          throw new Error(`@smithy/core/schema - may not init unwrapped member schema=${JSON.stringify(ref, null, 2)}.`);
        }
        const ns = new _NormalizedSchema(sc);
        if (keyAble) {
          return ref[anno6.ns] = ns;
        }
        if (typeof sc === "string") {
          return simpleSchemaCacheS6[sc] = ns;
        }
        if (typeof sc === "number") {
          return simpleSchemaCacheN6[sc] = ns;
        }
        return ns;
      }
      getSchema() {
        const sc = this.schema;
        if (Array.isArray(sc) && sc[0] === 0) {
          return sc[4];
        }
        return sc;
      }
      getName(withNamespace = false) {
        const { name } = this;
        const short = !withNamespace && name && name.includes("#");
        return short ? name.split("#")[1] : name || void 0;
      }
      getMemberName() {
        return this.memberName;
      }
      isMemberSchema() {
        return this._isMemberSchema;
      }
      isListSchema() {
        const sc = this.getSchema();
        return typeof sc === "number" ? sc >= 64 && sc < 128 : sc[0] === 1;
      }
      isMapSchema() {
        const sc = this.getSchema();
        return typeof sc === "number" ? sc >= 128 && sc <= 255 : sc[0] === 2;
      }
      isStructSchema() {
        const sc = this.getSchema();
        if (typeof sc !== "object") {
          return false;
        }
        const id = sc[0];
        return id === 3 || id === -3 || id === 4;
      }
      isUnionSchema() {
        const sc = this.getSchema();
        if (typeof sc !== "object") {
          return false;
        }
        return sc[0] === 4;
      }
      isBlobSchema() {
        const sc = this.getSchema();
        return sc === 21 || sc === 42;
      }
      isTimestampSchema() {
        const sc = this.getSchema();
        return typeof sc === "number" && sc >= 4 && sc <= 7;
      }
      isUnitSchema() {
        return this.getSchema() === "unit";
      }
      isDocumentSchema() {
        return this.getSchema() === 15;
      }
      isStringSchema() {
        return this.getSchema() === 0;
      }
      isBooleanSchema() {
        return this.getSchema() === 2;
      }
      isNumericSchema() {
        return this.getSchema() === 1;
      }
      isBigIntegerSchema() {
        return this.getSchema() === 17;
      }
      isBigDecimalSchema() {
        return this.getSchema() === 19;
      }
      isStreaming() {
        const { streaming } = this.getMergedTraits();
        return !!streaming || this.getSchema() === 42;
      }
      isIdempotencyToken() {
        return !!this.getMergedTraits().idempotencyToken;
      }
      getMergedTraits() {
        return this.normalizedTraits ?? (this.normalizedTraits = {
          ...this.getOwnTraits(),
          ...this.getMemberTraits()
        });
      }
      getMemberTraits() {
        return translateTraits6(this.memberTraits);
      }
      getOwnTraits() {
        return translateTraits6(this.traits);
      }
      getKeySchema() {
        const [isDoc, isMap] = [this.isDocumentSchema(), this.isMapSchema()];
        if (!isDoc && !isMap) {
          throw new Error(`@smithy/core/schema - cannot get key for non-map: ${this.getName(true)}`);
        }
        const schema = this.getSchema();
        const memberSchema = isDoc ? 15 : schema[4] ?? 0;
        return member6([memberSchema, 0], "key");
      }
      getValueSchema() {
        const sc = this.getSchema();
        const [isDoc, isMap, isList] = [this.isDocumentSchema(), this.isMapSchema(), this.isListSchema()];
        const memberSchema = typeof sc === "number" ? 63 & sc : sc && typeof sc === "object" && (isMap || isList) ? sc[3 + sc[0]] : isDoc ? 15 : void 0;
        if (memberSchema != null) {
          return member6([memberSchema, 0], isMap ? "value" : "member");
        }
        throw new Error(`@smithy/core/schema - ${this.getName(true)} has no value member.`);
      }
      getMemberSchema(memberName) {
        const struct3 = this.getSchema();
        if (this.isStructSchema() && struct3[4].includes(memberName)) {
          const i32 = struct3[4].indexOf(memberName);
          const memberSchema = struct3[5][i32];
          return member6(isMemberSchema6(memberSchema) ? memberSchema : [memberSchema, 0], memberName);
        }
        if (this.isDocumentSchema()) {
          return member6([15, 0], memberName);
        }
        throw new Error(`@smithy/core/schema - ${this.getName(true)} has no member=${memberName}.`);
      }
      getMemberSchemas() {
        const buffer = {};
        try {
          for (const [k32, v] of this.structIterator()) {
            buffer[k32] = v;
          }
        } catch (ignored) {
        }
        return buffer;
      }
      getEventStreamMember() {
        if (this.isStructSchema()) {
          for (const [memberName, memberSchema] of this.structIterator()) {
            if (memberSchema.isStreaming() && memberSchema.isStructSchema()) {
              return memberName;
            }
          }
        }
        return "";
      }
      *structIterator() {
        if (this.isUnitSchema()) {
          return;
        }
        if (!this.isStructSchema()) {
          throw new Error("@smithy/core/schema - cannot iterate non-struct schema.");
        }
        const struct3 = this.getSchema();
        const z = struct3[4].length;
        let it = struct3[anno6.it];
        if (it && z === it.length) {
          yield* it;
          return;
        }
        it = Array(z);
        for (let i32 = 0; i32 < z; ++i32) {
          const k32 = struct3[4][i32];
          const v = member6([struct3[5][i32], 0], k32);
          yield it[i32] = [k32, v];
        }
        struct3[anno6.it] = it;
      }
    };
    __name(member6, "member");
    isMemberSchema6 = /* @__PURE__ */ __name((sc) => Array.isArray(sc) && sc.length === 2, "isMemberSchema");
    isStaticSchema6 = /* @__PURE__ */ __name((sc) => Array.isArray(sc) && sc.length >= 5, "isStaticSchema");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/schemas/SimpleSchema.js
var init_SimpleSchema6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/schemas/SimpleSchema.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/schemas/sentinels.js
var init_sentinels6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/schemas/sentinels.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/TypeRegistry.js
var TypeRegistry6;
var init_TypeRegistry6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/TypeRegistry.js"() {
    TypeRegistry6 = class _TypeRegistry {
      static {
        __name(this, "TypeRegistry");
      }
      namespace;
      schemas;
      exceptions;
      static registries = /* @__PURE__ */ new Map();
      constructor(namespace, schemas = /* @__PURE__ */ new Map(), exceptions = /* @__PURE__ */ new Map()) {
        this.namespace = namespace;
        this.schemas = schemas;
        this.exceptions = exceptions;
      }
      static for(namespace) {
        if (!_TypeRegistry.registries.has(namespace)) {
          _TypeRegistry.registries.set(namespace, new _TypeRegistry(namespace));
        }
        return _TypeRegistry.registries.get(namespace);
      }
      copyFrom(other) {
        const { schemas, exceptions } = this;
        for (const [k32, v] of other.schemas) {
          if (!schemas.has(k32)) {
            schemas.set(k32, v);
          }
        }
        for (const [k32, v] of other.exceptions) {
          if (!exceptions.has(k32)) {
            exceptions.set(k32, v);
          }
        }
      }
      register(shapeId, schema) {
        const qualifiedName = this.normalizeShapeId(shapeId);
        for (const r32 of [this, _TypeRegistry.for(qualifiedName.split("#")[0])]) {
          r32.schemas.set(qualifiedName, schema);
        }
      }
      getSchema(shapeId) {
        const id = this.normalizeShapeId(shapeId);
        if (!this.schemas.has(id)) {
          if (!shapeId.includes("#")) {
            const suffix = "#" + shapeId;
            const candidates = [];
            for (const [shapeId2, schema] of this.schemas.entries()) {
              if (shapeId2.endsWith(suffix)) {
                candidates.push(schema);
              }
            }
            if (candidates.length === 1) {
              return candidates[0];
            }
          }
          throw new Error(`@smithy/core/schema - schema not found for ${id}`);
        }
        return this.schemas.get(id);
      }
      registerError(es, ctor) {
        const $error = es;
        const ns = $error[1];
        for (const r32 of [this, _TypeRegistry.for(ns)]) {
          r32.schemas.set(ns + "#" + $error[2], $error);
          r32.exceptions.set($error, ctor);
        }
      }
      getErrorCtor(es) {
        const $error = es;
        if (this.exceptions.has($error)) {
          return this.exceptions.get($error);
        }
        const registry = _TypeRegistry.for($error[1]);
        return registry.exceptions.get($error);
      }
      getBaseException() {
        for (const exceptionKey of this.exceptions.keys()) {
          if (Array.isArray(exceptionKey)) {
            const [, ns, name] = exceptionKey;
            const id = ns + "#" + name;
            if (id.startsWith("smithy.ts.sdk.synthetic.") && id.endsWith("ServiceException")) {
              return exceptionKey;
            }
          }
        }
        return void 0;
      }
      find(predicate) {
        for (const schema of this.schemas.values()) {
          if (predicate(schema)) {
            return schema;
          }
        }
        return void 0;
      }
      clear() {
        this.schemas.clear();
        this.exceptions.clear();
      }
      normalizeShapeId(shapeId) {
        if (shapeId.includes("#")) {
          return shapeId;
        }
        return this.namespace + "#" + shapeId;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/index.js
var init_schema9 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/schema/index.js"() {
    init_deref6();
    init_getSchemaSerdePlugin6();
    init_ListSchema6();
    init_MapSchema6();
    init_OperationSchema6();
    init_operation6();
    init_ErrorSchema6();
    init_NormalizedSchema6();
    init_Schema6();
    init_SimpleSchema6();
    init_StructureSchema6();
    init_sentinels6();
    init_translateTraits6();
    init_TypeRegistry6();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-type-check.js
var isReadableStream5;
var init_stream_type_check5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-type-check.js"() {
    isReadableStream5 = /* @__PURE__ */ __name((stream) => typeof ReadableStream === "function" && (stream?.constructor?.name === ReadableStream.name || stream instanceof ReadableStream), "isReadableStream");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/fromUtf8.browser.js
var fromUtf832;
var init_fromUtf8_browser5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/fromUtf8.browser.js"() {
    fromUtf832 = /* @__PURE__ */ __name((input) => new TextEncoder().encode(input), "fromUtf8");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/constants-for-browser.js
var chars5, alphabetByEncoding5, alphabetByValue5, bitsPerLetter5, bitsPerByte5, maxLetterValue5;
var init_constants_for_browser5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/constants-for-browser.js"() {
    chars5 = `ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/`;
    alphabetByEncoding5 = Object.entries(chars5).reduce((acc, [i32, c32]) => {
      acc[c32] = Number(i32);
      return acc;
    }, {});
    alphabetByValue5 = chars5.split("");
    bitsPerLetter5 = 6;
    bitsPerByte5 = 8;
    maxLetterValue5 = 63;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/toBase64.browser.js
function toBase6448(_input) {
  let input;
  if (typeof _input === "string") {
    input = fromUtf832(_input);
  } else {
    input = _input;
  }
  const isArrayLike = typeof input === "object" && typeof input.length === "number";
  const isUint8Array = typeof input === "object" && typeof input.byteOffset === "number" && typeof input.byteLength === "number";
  if (!isArrayLike && !isUint8Array) {
    throw new Error("@smithy/util-base64: toBase64 encoder function only accepts string | Uint8Array.");
  }
  let str = "";
  for (let i32 = 0; i32 < input.length; i32 += 3) {
    let bits = 0;
    let bitLength = 0;
    for (let j32 = i32, limit = Math.min(i32 + 3, input.length); j32 < limit; j32++) {
      bits |= input[j32] << (limit - j32 - 1) * bitsPerByte5;
      bitLength += bitsPerByte5;
    }
    const bitClusterCount = Math.ceil(bitLength / bitsPerLetter5);
    bits <<= bitClusterCount * bitsPerLetter5 - bitLength;
    for (let k32 = 1; k32 <= bitClusterCount; k32++) {
      const offset = (bitClusterCount - k32) * bitsPerLetter5;
      str += alphabetByValue5[(bits & maxLetterValue5 << offset) >> offset];
    }
    str += "==".slice(0, 4 - bitClusterCount);
  }
  return str;
}
var init_toBase64_browser5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/toBase64.browser.js"() {
    init_fromUtf8_browser5();
    init_constants_for_browser5();
    __name(toBase6448, "toBase64");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/toUtf8.browser.js
var toUtf846;
var init_toUtf8_browser5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-utf8/toUtf8.browser.js"() {
    toUtf846 = /* @__PURE__ */ __name((input) => {
      if (typeof input === "string") {
        return input;
      }
      if (typeof input !== "object" || typeof input.byteOffset !== "number" || typeof input.byteLength !== "number") {
        throw new Error("@smithy/util-utf8: toUtf8 encoder function only accepts string | Uint8Array.");
      }
      return new TextDecoder("utf-8").decode(input);
    }, "toUtf8");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/fromBase64.browser.js
var fromBase6443;
var init_fromBase64_browser5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-base64/fromBase64.browser.js"() {
    init_constants_for_browser5();
    fromBase6443 = /* @__PURE__ */ __name((input) => {
      let totalByteLength = input.length / 4 * 3;
      if (input.slice(-2) === "==") {
        totalByteLength -= 2;
      } else if (input.slice(-1) === "=") {
        totalByteLength--;
      }
      const out = new ArrayBuffer(totalByteLength);
      const dataView5 = new DataView(out);
      for (let i32 = 0; i32 < input.length; i32 += 4) {
        let bits = 0;
        let bitLength = 0;
        for (let j32 = i32, limit = i32 + 3; j32 <= limit; j32++) {
          if (input[j32] !== "=") {
            if (!(input[j32] in alphabetByEncoding5)) {
              throw new TypeError(`Invalid character ${input[j32]} in base64 string.`);
            }
            bits |= alphabetByEncoding5[input[j32]] << (limit - j32) * bitsPerLetter5;
            bitLength += bitsPerLetter5;
          } else {
            bits >>= bitsPerLetter5;
          }
        }
        const chunkOffset = i32 / 4 * 3;
        bits >>= bitLength % bitsPerByte5;
        const byteLength = Math.floor(bitLength / bitsPerByte5);
        for (let k32 = 0; k32 < byteLength; k32++) {
          const offset = (byteLength - k32 - 1) * bitsPerByte5;
          dataView5.setUint8(chunkOffset + k32, (bits & 255 << offset) >> offset);
        }
      }
      return new Uint8Array(out);
    }, "fromBase64");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-collector.browser.js
async function collectBlob5(blob) {
  const base64 = await readToBase645(blob);
  const arrayBuffer = fromBase6443(base64);
  return new Uint8Array(arrayBuffer);
}
async function collectStream5(stream) {
  const chunks2 = [];
  const reader = stream.getReader();
  let isDone = false;
  let length = 0;
  while (!isDone) {
    const { done, value } = await reader.read();
    if (value) {
      chunks2.push(value);
      length += value.length;
    }
    isDone = done;
  }
  const collected = new Uint8Array(length);
  let offset = 0;
  for (const chunk of chunks2) {
    collected.set(chunk, offset);
    offset += chunk.length;
  }
  return collected;
}
function readToBase645(blob) {
  return new Promise((resolve13, reject) => {
    const reader = new FileReader();
    reader.onloadend = () => {
      if (reader.readyState !== 2) {
        return reject(new Error("Reader aborted too early"));
      }
      const result2 = reader.result ?? "";
      const commaIndex = result2.indexOf(",");
      const dataOffset = commaIndex > -1 ? commaIndex + 1 : result2.length;
      resolve13(result2.substring(dataOffset));
    };
    reader.onabort = () => reject(new Error("Read aborted"));
    reader.onerror = () => reject(reader.error);
    reader.readAsDataURL(blob);
  });
}
var streamCollector27;
var init_stream_collector_browser5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-collector.browser.js"() {
    init_fromBase64_browser5();
    streamCollector27 = /* @__PURE__ */ __name(async (stream) => {
      if (typeof Blob === "function" && stream instanceof Blob || stream.constructor?.name === "Blob") {
        if (Blob.prototype.arrayBuffer !== void 0) {
          return new Uint8Array(await stream.arrayBuffer());
        }
        return collectBlob5(stream);
      }
      return collectStream5(stream);
    }, "streamCollector");
    __name(collectBlob5, "collectBlob");
    __name(collectStream5, "collectStream");
    __name(readToBase645, "readToBase64");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/sdk-stream-mixin.browser.js
var ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED9, sdkStreamMixin10, isBlobInstance5;
var init_sdk_stream_mixin_browser5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/sdk-stream-mixin.browser.js"() {
    init_toBase64_browser5();
    init_hex_encoding5();
    init_toUtf8_browser5();
    init_stream_collector_browser5();
    init_stream_type_check5();
    ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED9 = "The stream has already been transformed.";
    sdkStreamMixin10 = /* @__PURE__ */ __name((stream) => {
      if (!isBlobInstance5(stream) && !isReadableStream5(stream)) {
        const name = stream?.__proto__?.constructor?.name || stream;
        throw new Error(`Unexpected stream implementation, expect Blob or ReadableStream, got ${name}`);
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED9);
        }
        transformed = true;
        return await streamCollector27(stream);
      }, "transformToByteArray");
      const blobToWebStream = /* @__PURE__ */ __name((blob) => {
        if (typeof blob.stream !== "function") {
          throw new Error("Cannot transform payload Blob to web stream. Please make sure the Blob.stream() is polyfilled.\nIf you are using React Native, this API is not yet supported, see: https://react-native.canny.io/feature-requests/p/fetch-streaming-body");
        }
        return blob.stream();
      }, "blobToWebStream");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === "base64") {
            return toBase6448(buf);
          } else if (encoding === "hex") {
            return toHex5(buf);
          } else if (encoding === void 0 || encoding === "utf8" || encoding === "utf-8") {
            return toUtf846(buf);
          } else if (typeof TextDecoder === "function") {
            return new TextDecoder(encoding).decode(buf);
          } else {
            throw new Error("TextDecoder is not available, please make sure polyfill is provided.");
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED9);
          }
          transformed = true;
          if (isBlobInstance5(stream)) {
            return blobToWebStream(stream);
          } else if (isReadableStream5(stream)) {
            return stream;
          } else {
            throw new Error(`Cannot transform payload to web stream, got ${stream}`);
          }
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
    isBlobInstance5 = /* @__PURE__ */ __name((stream) => typeof Blob === "function" && stream instanceof Blob, "isBlobInstance");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-collector.js
async function collectReadableStream5(stream) {
  const chunks2 = [];
  const reader = stream.getReader();
  let isDone = false;
  let length = 0;
  while (!isDone) {
    const { done, value } = await reader.read();
    if (value) {
      chunks2.push(value);
      length += value.length;
    }
    isDone = done;
  }
  const collected = new Uint8Array(length);
  let offset = 0;
  for (const chunk of chunks2) {
    collected.set(chunk, offset);
    offset += chunk.length;
  }
  return collected;
}
var import_node_stream25, Collector7, isReadableStreamInstance5, streamCollector28;
var init_stream_collector5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/stream-collector.js"() {
    import_node_stream25 = require("node:stream");
    Collector7 = class extends import_node_stream25.Writable {
      static {
        __name(this, "Collector");
      }
      bufferedBytes = [];
      _write(chunk, encoding, callback) {
        this.bufferedBytes.push(chunk);
        callback();
      }
    };
    isReadableStreamInstance5 = /* @__PURE__ */ __name((stream) => typeof ReadableStream === "function" && stream instanceof ReadableStream, "isReadableStreamInstance");
    __name(collectReadableStream5, "collectReadableStream");
    streamCollector28 = /* @__PURE__ */ __name((stream) => {
      if (isReadableStreamInstance5(stream)) {
        return collectReadableStream5(stream);
      }
      return new Promise((resolve13, reject) => {
        const collector = new Collector7();
        stream.pipe(collector);
        stream.on("error", (err) => {
          collector.end();
          reject(err);
        });
        collector.on("error", reject);
        collector.on("finish", function() {
          const bytes = new Uint8Array(Buffer.concat(this.bufferedBytes));
          resolve13(bytes);
        });
      });
    }, "streamCollector");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/sdk-stream-mixin.js
var import_node_stream26, ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED10, sdkStreamMixin11;
var init_sdk_stream_mixin5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/util-stream/sdk-stream-mixin.js"() {
    import_node_stream26 = require("node:stream");
    init_buffer_from6();
    init_sdk_stream_mixin_browser5();
    init_stream_collector5();
    ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED10 = "The stream has already been transformed.";
    sdkStreamMixin11 = /* @__PURE__ */ __name((stream) => {
      if (!(stream instanceof import_node_stream26.Readable)) {
        try {
          return sdkStreamMixin10(stream);
        } catch (e32) {
          const name = stream?.__proto__?.constructor?.name || stream;
          throw new Error(`Unexpected stream implementation, expect Stream.Readable instance, got ${name}`);
        }
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED10);
        }
        transformed = true;
        return await streamCollector28(stream);
      }, "transformToByteArray");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === void 0 || Buffer.isEncoding(encoding)) {
            return fromArrayBuffer6(buf.buffer, buf.byteOffset, buf.byteLength).toString(encoding);
          } else {
            const decoder = new TextDecoder(encoding);
            return decoder.decode(buf);
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED10);
          }
          if (stream.readableFlowing !== null) {
            throw new Error("The stream has been consumed by other callbacks.");
          }
          if (typeof import_node_stream26.Readable.toWeb !== "function") {
            throw new Error("Readable.toWeb() is not supported. Please ensure a polyfill is available.");
          }
          transformed = true;
          return import_node_stream26.Readable.toWeb(stream);
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/index.js
var import_node_crypto15, Uint8ArrayBlobAdapter7, _getRandomValues6, v46, generateIdempotencyToken6;
var init_serde7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/serde/index.js"() {
    import_node_crypto15 = require("node:crypto");
    init_fromBase646();
    init_toBase646();
    init_Uint8ArrayBlobAdapter6();
    init_fromUtf86();
    init_toUtf86();
    init_v46();
    init_date_utils7();
    init_lazy_json6();
    init_quote_header6();
    init_schema_date_utils6();
    init_split_every6();
    init_split_header6();
    init_NumericValue6();
    init_hex_encoding5();
    init_sdk_stream_mixin5();
    Uint8ArrayBlobAdapter7 = class extends bindUint8ArrayBlobAdapter6(toUtf845, fromUtf831, toBase6447, fromBase6442) {
      static {
        __name(this, "Uint8ArrayBlobAdapter");
      }
    };
    _getRandomValues6 = import_node_crypto15.getRandomValues;
    v46 = bindV46(_getRandomValues6);
    generateIdempotencyToken6 = v46;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/collect-stream-body.js
var collectBody13;
var init_collect_stream_body7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/collect-stream-body.js"() {
    init_serde7();
    collectBody13 = /* @__PURE__ */ __name(async (streamBody = new Uint8Array(), context) => {
      if (streamBody instanceof Uint8Array) {
        return Uint8ArrayBlobAdapter7.mutate(streamBody);
      }
      if (!streamBody) {
        return Uint8ArrayBlobAdapter7.mutate(new Uint8Array());
      }
      const fromContext = context.streamCollector(streamBody);
      return Uint8ArrayBlobAdapter7.mutate(await fromContext);
    }, "collectBody");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/extended-encode-uri-component.js
function extendedEncodeURIComponent6(str) {
  return encodeURIComponent(str).replace(/[!'()*]/g, function(c32) {
    return "%" + c32.charCodeAt(0).toString(16).toUpperCase();
  });
}
var init_extended_encode_uri_component7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/extended-encode-uri-component.js"() {
    __name(extendedEncodeURIComponent6, "extendedEncodeURIComponent");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/SerdeContext.js
var SerdeContext6;
var init_SerdeContext7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/SerdeContext.js"() {
    SerdeContext6 = class {
      static {
        __name(this, "SerdeContext");
      }
      serdeContext;
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/httpRequest.js
function cloneQuery6(query) {
  return Object.keys(query).reduce((carry, paramName) => {
    const param = query[paramName];
    return {
      ...carry,
      [paramName]: Array.isArray(param) ? [...param] : param
    };
  }, {});
}
var HttpRequest25;
var init_httpRequest6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/httpRequest.js"() {
    HttpRequest25 = class _HttpRequest {
      static {
        __name(this, "HttpRequest");
      }
      method;
      protocol;
      hostname;
      port;
      path;
      query;
      headers;
      username;
      password;
      fragment;
      body;
      constructor(options) {
        this.method = options.method || "GET";
        this.hostname = options.hostname || "localhost";
        this.port = options.port;
        this.query = options.query || {};
        this.headers = options.headers || {};
        this.body = options.body;
        this.protocol = options.protocol ? options.protocol.slice(-1) !== ":" ? `${options.protocol}:` : options.protocol : "https:";
        this.path = options.path ? options.path.charAt(0) !== "/" ? `/${options.path}` : options.path : "/";
        this.username = options.username;
        this.password = options.password;
        this.fragment = options.fragment;
      }
      static clone(request4) {
        const cloned = new _HttpRequest({
          ...request4,
          headers: { ...request4.headers }
        });
        if (cloned.query) {
          cloned.query = cloneQuery6(cloned.query);
        }
        return cloned;
      }
      static isInstance(request4) {
        if (!request4) {
          return false;
        }
        const req = request4;
        return "method" in req && "protocol" in req && "hostname" in req && "path" in req && typeof req["query"] === "object" && typeof req["headers"] === "object";
      }
      clone() {
        return _HttpRequest.clone(this);
      }
    };
    __name(cloneQuery6, "cloneQuery");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/httpResponse.js
var HttpResponse14;
var init_httpResponse6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/httpResponse.js"() {
    HttpResponse14 = class {
      static {
        __name(this, "HttpResponse");
      }
      statusCode;
      reason;
      headers;
      body;
      constructor(options) {
        this.statusCode = options.statusCode;
        this.reason = options.reason;
        this.headers = options.headers || {};
        this.body = options.body;
      }
      static isInstance(response) {
        if (!response)
          return false;
        const resp = response;
        return typeof resp.statusCode === "number" && typeof resp.headers === "object";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/Int64.js
function negate5(bytes) {
  for (let i32 = 0; i32 < 8; i32++) {
    bytes[i32] ^= 255;
  }
  for (let i32 = 7; i32 > -1; i32--) {
    bytes[i32]++;
    if (bytes[i32] !== 0)
      break;
  }
}
var Int645;
var init_Int645 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/Int64.js"() {
    init_serde7();
    Int645 = class _Int64 {
      static {
        __name(this, "Int64");
      }
      bytes;
      constructor(bytes) {
        this.bytes = bytes;
        if (bytes.byteLength !== 8) {
          throw new Error("Int64 buffers must be exactly 8 bytes");
        }
      }
      static fromNumber(number) {
        if (number > 9223372036854776e3 || number < -9223372036854776e3) {
          throw new Error(`${number} is too large (or, if negative, too small) to represent as an Int64`);
        }
        const bytes = new Uint8Array(8);
        for (let i32 = 7, remaining = Math.abs(Math.round(number)); i32 > -1 && remaining > 0; i32--, remaining /= 256) {
          bytes[i32] = remaining;
        }
        if (number < 0) {
          negate5(bytes);
        }
        return new _Int64(bytes);
      }
      valueOf() {
        const bytes = this.bytes.slice(0);
        const negative = bytes[0] & 128;
        if (negative) {
          negate5(bytes);
        }
        return parseInt(toHex5(bytes), 16) * (negative ? -1 : 1);
      }
      toString() {
        return String(this.valueOf());
      }
    };
    __name(negate5, "negate");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/HeaderMarshaller.js
var HeaderMarshaller5, HEADER_VALUE_TYPE5, BOOLEAN_TAG5, BYTE_TAG5, SHORT_TAG5, INT_TAG5, LONG_TAG5, BINARY_TAG5, STRING_TAG5, TIMESTAMP_TAG5, UUID_TAG5, UUID_PATTERN5;
var init_HeaderMarshaller5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/HeaderMarshaller.js"() {
    init_serde7();
    init_Int645();
    HeaderMarshaller5 = class {
      static {
        __name(this, "HeaderMarshaller");
      }
      toUtf8;
      fromUtf8;
      constructor(toUtf862, fromUtf842) {
        this.toUtf8 = toUtf862;
        this.fromUtf8 = fromUtf842;
      }
      format(headers) {
        const chunks2 = [];
        for (const headerName of Object.keys(headers)) {
          const bytes = this.fromUtf8(headerName);
          chunks2.push(Uint8Array.from([bytes.byteLength]), bytes, this.formatHeaderValue(headers[headerName]));
        }
        const out = new Uint8Array(chunks2.reduce((carry, bytes) => carry + bytes.byteLength, 0));
        let position = 0;
        for (const chunk of chunks2) {
          out.set(chunk, position);
          position += chunk.byteLength;
        }
        return out;
      }
      formatHeaderValue(header) {
        switch (header.type) {
          case "boolean":
            return Uint8Array.from([header.value ? 0 : 1]);
          case "byte":
            return Uint8Array.from([2, header.value]);
          case "short":
            const shortView = new DataView(new ArrayBuffer(3));
            shortView.setUint8(0, 3);
            shortView.setInt16(1, header.value, false);
            return new Uint8Array(shortView.buffer);
          case "integer":
            const intView = new DataView(new ArrayBuffer(5));
            intView.setUint8(0, 4);
            intView.setInt32(1, header.value, false);
            return new Uint8Array(intView.buffer);
          case "long":
            const longBytes = new Uint8Array(9);
            longBytes[0] = 5;
            longBytes.set(header.value.bytes, 1);
            return longBytes;
          case "binary":
            const binView = new DataView(new ArrayBuffer(3 + header.value.byteLength));
            binView.setUint8(0, 6);
            binView.setUint16(1, header.value.byteLength, false);
            const binBytes = new Uint8Array(binView.buffer);
            binBytes.set(header.value, 3);
            return binBytes;
          case "string":
            const utf8Bytes = this.fromUtf8(header.value);
            const strView = new DataView(new ArrayBuffer(3 + utf8Bytes.byteLength));
            strView.setUint8(0, 7);
            strView.setUint16(1, utf8Bytes.byteLength, false);
            const strBytes = new Uint8Array(strView.buffer);
            strBytes.set(utf8Bytes, 3);
            return strBytes;
          case "timestamp":
            const tsBytes = new Uint8Array(9);
            tsBytes[0] = 8;
            tsBytes.set(Int645.fromNumber(header.value.valueOf()).bytes, 1);
            return tsBytes;
          case "uuid":
            if (!UUID_PATTERN5.test(header.value)) {
              throw new Error(`Invalid UUID received: ${header.value}`);
            }
            const uuidBytes = new Uint8Array(17);
            uuidBytes[0] = 9;
            uuidBytes.set(fromHex5(header.value.replace(/\-/g, "")), 1);
            return uuidBytes;
        }
      }
      parse(headers) {
        const out = {};
        let position = 0;
        while (position < headers.byteLength) {
          const nameLength = headers.getUint8(position++);
          const name = this.toUtf8(new Uint8Array(headers.buffer, headers.byteOffset + position, nameLength));
          position += nameLength;
          switch (headers.getUint8(position++)) {
            case 0:
              out[name] = {
                type: BOOLEAN_TAG5,
                value: true
              };
              break;
            case 1:
              out[name] = {
                type: BOOLEAN_TAG5,
                value: false
              };
              break;
            case 2:
              out[name] = {
                type: BYTE_TAG5,
                value: headers.getInt8(position++)
              };
              break;
            case 3:
              out[name] = {
                type: SHORT_TAG5,
                value: headers.getInt16(position, false)
              };
              position += 2;
              break;
            case 4:
              out[name] = {
                type: INT_TAG5,
                value: headers.getInt32(position, false)
              };
              position += 4;
              break;
            case 5:
              out[name] = {
                type: LONG_TAG5,
                value: new Int645(new Uint8Array(headers.buffer, headers.byteOffset + position, 8))
              };
              position += 8;
              break;
            case 6:
              const binaryLength = headers.getUint16(position, false);
              position += 2;
              out[name] = {
                type: BINARY_TAG5,
                value: new Uint8Array(headers.buffer, headers.byteOffset + position, binaryLength)
              };
              position += binaryLength;
              break;
            case 7:
              const stringLength = headers.getUint16(position, false);
              position += 2;
              out[name] = {
                type: STRING_TAG5,
                value: this.toUtf8(new Uint8Array(headers.buffer, headers.byteOffset + position, stringLength))
              };
              position += stringLength;
              break;
            case 8:
              out[name] = {
                type: TIMESTAMP_TAG5,
                value: new Date(new Int645(new Uint8Array(headers.buffer, headers.byteOffset + position, 8)).valueOf())
              };
              position += 8;
              break;
            case 9:
              const uuidBytes = new Uint8Array(headers.buffer, headers.byteOffset + position, 16);
              position += 16;
              out[name] = {
                type: UUID_TAG5,
                value: `${toHex5(uuidBytes.subarray(0, 4))}-${toHex5(uuidBytes.subarray(4, 6))}-${toHex5(uuidBytes.subarray(6, 8))}-${toHex5(uuidBytes.subarray(8, 10))}-${toHex5(uuidBytes.subarray(10))}`
              };
              break;
            default:
              throw new Error(`Unrecognized header type tag`);
          }
        }
        return out;
      }
    };
    (function(HEADER_VALUE_TYPE6) {
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["boolTrue"] = 0] = "boolTrue";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["boolFalse"] = 1] = "boolFalse";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["byte"] = 2] = "byte";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["short"] = 3] = "short";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["integer"] = 4] = "integer";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["long"] = 5] = "long";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["byteArray"] = 6] = "byteArray";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["string"] = 7] = "string";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["timestamp"] = 8] = "timestamp";
      HEADER_VALUE_TYPE6[HEADER_VALUE_TYPE6["uuid"] = 9] = "uuid";
    })(HEADER_VALUE_TYPE5 || (HEADER_VALUE_TYPE5 = {}));
    BOOLEAN_TAG5 = "boolean";
    BYTE_TAG5 = "byte";
    SHORT_TAG5 = "short";
    INT_TAG5 = "integer";
    LONG_TAG5 = "long";
    BINARY_TAG5 = "binary";
    STRING_TAG5 = "string";
    TIMESTAMP_TAG5 = "timestamp";
    UUID_TAG5 = "uuid";
    UUID_PATTERN5 = /^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$/;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/splitMessage.js
function splitMessage5({ byteLength, byteOffset, buffer }) {
  if (byteLength < MINIMUM_MESSAGE_LENGTH5) {
    throw new Error("Provided message too short to accommodate event stream message overhead");
  }
  const view = new DataView(buffer, byteOffset, byteLength);
  const messageLength = view.getUint32(0, false);
  if (byteLength !== messageLength) {
    throw new Error("Reported message length does not match received message length");
  }
  const headerLength = view.getUint32(PRELUDE_MEMBER_LENGTH5, false);
  const expectedPreludeChecksum = view.getUint32(PRELUDE_LENGTH5, false);
  const expectedMessageChecksum = view.getUint32(byteLength - CHECKSUM_LENGTH5, false);
  const checksummer = new import_crc329.Crc32().update(new Uint8Array(buffer, byteOffset, PRELUDE_LENGTH5));
  if (expectedPreludeChecksum !== checksummer.digest()) {
    throw new Error(`The prelude checksum specified in the message (${expectedPreludeChecksum}) does not match the calculated CRC32 checksum (${checksummer.digest()})`);
  }
  checksummer.update(new Uint8Array(buffer, byteOffset + PRELUDE_LENGTH5, byteLength - (PRELUDE_LENGTH5 + CHECKSUM_LENGTH5)));
  if (expectedMessageChecksum !== checksummer.digest()) {
    throw new Error(`The message checksum (${checksummer.digest()}) did not match the expected value of ${expectedMessageChecksum}`);
  }
  return {
    headers: new DataView(buffer, byteOffset + PRELUDE_LENGTH5 + CHECKSUM_LENGTH5, headerLength),
    body: new Uint8Array(buffer, byteOffset + PRELUDE_LENGTH5 + CHECKSUM_LENGTH5 + headerLength, messageLength - headerLength - (PRELUDE_LENGTH5 + CHECKSUM_LENGTH5 + CHECKSUM_LENGTH5))
  };
}
var import_crc329, PRELUDE_MEMBER_LENGTH5, PRELUDE_LENGTH5, CHECKSUM_LENGTH5, MINIMUM_MESSAGE_LENGTH5;
var init_splitMessage5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/splitMessage.js"() {
    import_crc329 = __toESM(require_main3());
    PRELUDE_MEMBER_LENGTH5 = 4;
    PRELUDE_LENGTH5 = PRELUDE_MEMBER_LENGTH5 * 2;
    CHECKSUM_LENGTH5 = 4;
    MINIMUM_MESSAGE_LENGTH5 = PRELUDE_LENGTH5 + CHECKSUM_LENGTH5 * 2;
    __name(splitMessage5, "splitMessage");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/EventStreamCodec.js
var import_crc3210, EventStreamCodec5;
var init_EventStreamCodec5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/EventStreamCodec.js"() {
    import_crc3210 = __toESM(require_main3());
    init_HeaderMarshaller5();
    init_splitMessage5();
    EventStreamCodec5 = class {
      static {
        __name(this, "EventStreamCodec");
      }
      headerMarshaller;
      messageBuffer;
      isEndOfStream;
      constructor(toUtf862, fromUtf842) {
        this.headerMarshaller = new HeaderMarshaller5(toUtf862, fromUtf842);
        this.messageBuffer = [];
        this.isEndOfStream = false;
      }
      feed(message2) {
        this.messageBuffer.push(this.decode(message2));
      }
      endOfStream() {
        this.isEndOfStream = true;
      }
      getMessage() {
        const message2 = this.messageBuffer.pop();
        const isEndOfStream = this.isEndOfStream;
        return {
          getMessage() {
            return message2;
          },
          isEndOfStream() {
            return isEndOfStream;
          }
        };
      }
      getAvailableMessages() {
        const messages = this.messageBuffer;
        this.messageBuffer = [];
        const isEndOfStream = this.isEndOfStream;
        return {
          getMessages() {
            return messages;
          },
          isEndOfStream() {
            return isEndOfStream;
          }
        };
      }
      encode({ headers: rawHeaders, body }) {
        const headers = this.headerMarshaller.format(rawHeaders);
        const length = headers.byteLength + body.byteLength + 16;
        const out = new Uint8Array(length);
        const view = new DataView(out.buffer, out.byteOffset, out.byteLength);
        const checksum = new import_crc3210.Crc32();
        view.setUint32(0, length, false);
        view.setUint32(4, headers.byteLength, false);
        view.setUint32(8, checksum.update(out.subarray(0, 8)).digest(), false);
        out.set(headers, 12);
        out.set(body, headers.byteLength + 12);
        view.setUint32(length - 4, checksum.update(out.subarray(8, length - 4)).digest(), false);
        return out;
      }
      decode(message2) {
        const { headers, body } = splitMessage5(message2);
        return { headers: this.headerMarshaller.parse(headers), body };
      }
      formatHeaders(rawHeaders) {
        return this.headerMarshaller.format(rawHeaders);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/MessageDecoderStream.js
var MessageDecoderStream5;
var init_MessageDecoderStream5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/MessageDecoderStream.js"() {
    MessageDecoderStream5 = class {
      static {
        __name(this, "MessageDecoderStream");
      }
      options;
      constructor(options) {
        this.options = options;
      }
      [Symbol.asyncIterator]() {
        return this.asyncIterator();
      }
      async *asyncIterator() {
        for await (const bytes of this.options.inputStream) {
          const decoded = this.options.decoder.decode(bytes);
          yield decoded;
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/MessageEncoderStream.js
var MessageEncoderStream5;
var init_MessageEncoderStream5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/MessageEncoderStream.js"() {
    MessageEncoderStream5 = class {
      static {
        __name(this, "MessageEncoderStream");
      }
      options;
      constructor(options) {
        this.options = options;
      }
      [Symbol.asyncIterator]() {
        return this.asyncIterator();
      }
      async *asyncIterator() {
        for await (const msg of this.options.messageStream) {
          const encoded = this.options.encoder.encode(msg);
          yield encoded;
        }
        if (this.options.includeEndFrame) {
          yield new Uint8Array(0);
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/SmithyMessageDecoderStream.js
var SmithyMessageDecoderStream5;
var init_SmithyMessageDecoderStream5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/SmithyMessageDecoderStream.js"() {
    SmithyMessageDecoderStream5 = class {
      static {
        __name(this, "SmithyMessageDecoderStream");
      }
      options;
      constructor(options) {
        this.options = options;
      }
      [Symbol.asyncIterator]() {
        return this.asyncIterator();
      }
      async *asyncIterator() {
        for await (const message2 of this.options.messageStream) {
          const deserialized = await this.options.deserializer(message2);
          if (deserialized === void 0)
            continue;
          yield deserialized;
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/SmithyMessageEncoderStream.js
var SmithyMessageEncoderStream5;
var init_SmithyMessageEncoderStream5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-codec/SmithyMessageEncoderStream.js"() {
    SmithyMessageEncoderStream5 = class {
      static {
        __name(this, "SmithyMessageEncoderStream");
      }
      options;
      constructor(options) {
        this.options = options;
      }
      [Symbol.asyncIterator]() {
        return this.asyncIterator();
      }
      async *asyncIterator() {
        for await (const chunk of this.options.inputStream) {
          const payloadBuf = this.options.serializer(chunk);
          yield payloadBuf;
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/getChunkedStream.js
function getChunkedStream5(source) {
  let currentMessageTotalLength = 0;
  let currentMessagePendingLength = 0;
  let currentMessage = null;
  let messageLengthBuffer = null;
  const allocateMessage = /* @__PURE__ */ __name((size) => {
    if (typeof size !== "number") {
      throw new Error("Attempted to allocate an event message where size was not a number: " + size);
    }
    currentMessageTotalLength = size;
    currentMessagePendingLength = 4;
    currentMessage = new Uint8Array(size);
    const currentMessageView = new DataView(currentMessage.buffer);
    currentMessageView.setUint32(0, size, false);
  }, "allocateMessage");
  const iterator = /* @__PURE__ */ __name(async function* () {
    const sourceIterator = source[Symbol.asyncIterator]();
    while (true) {
      const { value, done } = await sourceIterator.next();
      if (done) {
        if (!currentMessageTotalLength) {
          return;
        } else if (currentMessageTotalLength === currentMessagePendingLength) {
          yield currentMessage;
        } else {
          throw new Error("Truncated event message received.");
        }
        return;
      }
      const chunkLength = value.length;
      let currentOffset = 0;
      while (currentOffset < chunkLength) {
        if (!currentMessage) {
          const bytesRemaining = chunkLength - currentOffset;
          if (!messageLengthBuffer) {
            messageLengthBuffer = new Uint8Array(4);
          }
          const numBytesForTotal = Math.min(4 - currentMessagePendingLength, bytesRemaining);
          messageLengthBuffer.set(value.slice(currentOffset, currentOffset + numBytesForTotal), currentMessagePendingLength);
          currentMessagePendingLength += numBytesForTotal;
          currentOffset += numBytesForTotal;
          if (currentMessagePendingLength < 4) {
            break;
          }
          allocateMessage(new DataView(messageLengthBuffer.buffer).getUint32(0, false));
          messageLengthBuffer = null;
        }
        const numBytesToWrite = Math.min(currentMessageTotalLength - currentMessagePendingLength, chunkLength - currentOffset);
        currentMessage.set(value.slice(currentOffset, currentOffset + numBytesToWrite), currentMessagePendingLength);
        currentMessagePendingLength += numBytesToWrite;
        currentOffset += numBytesToWrite;
        if (currentMessageTotalLength && currentMessageTotalLength === currentMessagePendingLength) {
          yield currentMessage;
          currentMessage = null;
          currentMessageTotalLength = 0;
          currentMessagePendingLength = 0;
        }
      }
    }
  }, "iterator");
  return {
    [Symbol.asyncIterator]: iterator
  };
}
var init_getChunkedStream5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/getChunkedStream.js"() {
    __name(getChunkedStream5, "getChunkedStream");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/getUnmarshalledStream.js
function getUnmarshalledStream5(source, options) {
  const messageUnmarshaller = getMessageUnmarshaller5(options.deserializer, options.toUtf8);
  return {
    [Symbol.asyncIterator]: async function* () {
      for await (const chunk of source) {
        const message2 = options.eventStreamCodec.decode(chunk);
        const type = await messageUnmarshaller(message2);
        if (type === void 0)
          continue;
        yield type;
      }
    }
  };
}
function getMessageUnmarshaller5(deserializer, toUtf862) {
  return async function(message2) {
    const { value: messageType } = message2.headers[":message-type"];
    if (messageType === "error") {
      const unmodeledError = new Error(message2.headers[":error-message"].value || "UnknownError");
      unmodeledError.name = message2.headers[":error-code"].value;
      throw unmodeledError;
    } else if (messageType === "exception") {
      const code = message2.headers[":exception-type"].value;
      const exception = { [code]: message2 };
      const deserializedException = await deserializer(exception);
      if (deserializedException.$unknown) {
        const error4 = new Error(toUtf862(message2.body));
        error4.name = code;
        throw error4;
      }
      throw deserializedException[code];
    } else if (messageType === "event") {
      const event = {
        [message2.headers[":event-type"].value]: message2
      };
      const deserialized = await deserializer(event);
      if (deserialized.$unknown)
        return;
      return deserialized;
    } else {
      throw Error(`Unrecognizable event type: ${message2.headers[":event-type"].value}`);
    }
  };
}
var init_getUnmarshalledStream5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/getUnmarshalledStream.js"() {
    __name(getUnmarshalledStream5, "getUnmarshalledStream");
    __name(getMessageUnmarshaller5, "getMessageUnmarshaller");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/EventStreamMarshaller.js
var EventStreamMarshaller9, eventStreamSerdeProvider9;
var init_EventStreamMarshaller9 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-universal/EventStreamMarshaller.js"() {
    init_EventStreamCodec5();
    init_MessageDecoderStream5();
    init_MessageEncoderStream5();
    init_SmithyMessageDecoderStream5();
    init_SmithyMessageEncoderStream5();
    init_getChunkedStream5();
    init_getUnmarshalledStream5();
    EventStreamMarshaller9 = class {
      static {
        __name(this, "EventStreamMarshaller");
      }
      eventStreamCodec;
      utfEncoder;
      constructor({ utf8Encoder, utf8Decoder }) {
        this.eventStreamCodec = new EventStreamCodec5(utf8Encoder, utf8Decoder);
        this.utfEncoder = utf8Encoder;
      }
      deserialize(body, deserializer) {
        const inputStream = getChunkedStream5(body);
        return new SmithyMessageDecoderStream5({
          messageStream: new MessageDecoderStream5({ inputStream, decoder: this.eventStreamCodec }),
          deserializer: getMessageUnmarshaller5(deserializer, this.utfEncoder)
        });
      }
      serialize(inputStream, serializer) {
        return new MessageEncoderStream5({
          messageStream: new SmithyMessageEncoderStream5({ inputStream, serializer }),
          encoder: this.eventStreamCodec,
          includeEndFrame: true
        });
      }
    };
    eventStreamSerdeProvider9 = /* @__PURE__ */ __name((options) => new EventStreamMarshaller9(options), "eventStreamSerdeProvider");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde/EventStreamMarshaller.js
async function* readableToIterable5(readStream) {
  let streamEnded = false;
  let generationEnded = false;
  const records = new Array();
  readStream.on("error", (err) => {
    if (!streamEnded) {
      streamEnded = true;
    }
    if (err) {
      throw err;
    }
  });
  readStream.on("data", (data3) => {
    records.push(data3);
  });
  readStream.on("end", () => {
    streamEnded = true;
  });
  while (!generationEnded) {
    const value = await new Promise((resolve13) => setTimeout(() => resolve13(records.shift()), 0));
    if (value) {
      yield value;
    }
    generationEnded = streamEnded && records.length === 0;
  }
}
var import_node_stream27, EventStreamMarshaller10, eventStreamSerdeProvider10;
var init_EventStreamMarshaller10 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde/EventStreamMarshaller.js"() {
    import_node_stream27 = require("node:stream");
    init_EventStreamMarshaller9();
    EventStreamMarshaller10 = class {
      static {
        __name(this, "EventStreamMarshaller");
      }
      universalMarshaller;
      constructor({ utf8Encoder, utf8Decoder }) {
        this.universalMarshaller = new EventStreamMarshaller9({
          utf8Decoder,
          utf8Encoder
        });
      }
      deserialize(body, deserializer) {
        const bodyIterable = typeof body[Symbol.asyncIterator] === "function" ? body : readableToIterable5(body);
        return this.universalMarshaller.deserialize(bodyIterable, deserializer);
      }
      serialize(input, serializer) {
        return import_node_stream27.Readable.from(this.universalMarshaller.serialize(input, serializer));
      }
    };
    eventStreamSerdeProvider10 = /* @__PURE__ */ __name((options) => new EventStreamMarshaller10(options), "eventStreamSerdeProvider");
    __name(readableToIterable5, "readableToIterable");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde/utils.js
var readableStreamToIterable5, iterableToReadableStream5;
var init_utils14 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde/utils.js"() {
    readableStreamToIterable5 = /* @__PURE__ */ __name((readableStream) => ({
      [Symbol.asyncIterator]: async function* () {
        const reader = readableStream.getReader();
        try {
          while (true) {
            const { done, value } = await reader.read();
            if (done)
              return;
            yield value;
          }
        } finally {
          reader.releaseLock();
        }
      }
    }), "readableStreamToIterable");
    iterableToReadableStream5 = /* @__PURE__ */ __name((asyncIterable) => {
      const iterator = asyncIterable[Symbol.asyncIterator]();
      return new ReadableStream({
        async pull(controller) {
          const { done, value } = await iterator.next();
          if (done) {
            return controller.close();
          }
          controller.enqueue(value);
        }
      });
    }, "iterableToReadableStream");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-config-resolver/EventStreamSerdeConfig.js
var resolveEventStreamSerdeConfig5;
var init_EventStreamSerdeConfig5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/eventstream-serde-config-resolver/EventStreamSerdeConfig.js"() {
    resolveEventStreamSerdeConfig5 = /* @__PURE__ */ __name((input) => Object.assign(input, {
      eventStreamMarshaller: input.eventStreamSerdeProvider(input)
    }), "resolveEventStreamSerdeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/EventStreamSerde.js
var EventStreamSerde6;
var init_EventStreamSerde6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/EventStreamSerde.js"() {
    init_serde7();
    EventStreamSerde6 = class {
      static {
        __name(this, "EventStreamSerde");
      }
      marshaller;
      serializer;
      deserializer;
      serdeContext;
      defaultContentType;
      constructor({ marshaller, serializer, deserializer, serdeContext, defaultContentType }) {
        this.marshaller = marshaller;
        this.serializer = serializer;
        this.deserializer = deserializer;
        this.serdeContext = serdeContext;
        this.defaultContentType = defaultContentType;
      }
      async serializeEventStream({ eventStream, requestSchema, initialRequest }) {
        const marshaller = this.marshaller;
        const eventStreamMember = requestSchema.getEventStreamMember();
        const unionSchema = requestSchema.getMemberSchema(eventStreamMember);
        const serializer = this.serializer;
        const defaultContentType = this.defaultContentType;
        const initialRequestMarker = /* @__PURE__ */ Symbol("initialRequestMarker");
        const eventStreamIterable = {
          async *[Symbol.asyncIterator]() {
            if (initialRequest) {
              const headers = {
                ":event-type": { type: "string", value: "initial-request" },
                ":message-type": { type: "string", value: "event" },
                ":content-type": { type: "string", value: defaultContentType }
              };
              serializer.write(requestSchema, initialRequest);
              const body = serializer.flush();
              yield {
                [initialRequestMarker]: true,
                headers,
                body
              };
            }
            for await (const page of eventStream) {
              yield page;
            }
          }
        };
        return marshaller.serialize(eventStreamIterable, (event) => {
          if (event[initialRequestMarker]) {
            return {
              headers: event.headers,
              body: event.body
            };
          }
          let unionMember = "";
          for (const key in event) {
            if (key !== "__type") {
              unionMember = key;
              break;
            }
          }
          const { additionalHeaders, body, eventType, explicitPayloadContentType } = this.writeEventBody(unionMember, unionSchema, event);
          const headers = {
            ":event-type": { type: "string", value: eventType },
            ":message-type": { type: "string", value: "event" },
            ":content-type": { type: "string", value: explicitPayloadContentType ?? defaultContentType },
            ...additionalHeaders
          };
          return {
            headers,
            body
          };
        });
      }
      async deserializeEventStream({ response, responseSchema, initialResponseContainer }) {
        const marshaller = this.marshaller;
        const eventStreamMember = responseSchema.getEventStreamMember();
        const unionSchema = responseSchema.getMemberSchema(eventStreamMember);
        const memberSchemas = unionSchema.getMemberSchemas();
        const initialResponseMarker = /* @__PURE__ */ Symbol("initialResponseMarker");
        const asyncIterable = marshaller.deserialize(response.body, async (event) => {
          let unionMember = "";
          for (const key in event) {
            if (key !== "__type") {
              unionMember = key;
              break;
            }
          }
          const body = event[unionMember].body;
          if (unionMember === "initial-response") {
            const dataObject = await this.deserializer.read(responseSchema, body);
            delete dataObject[eventStreamMember];
            return {
              [initialResponseMarker]: true,
              ...dataObject
            };
          } else if (unionMember in memberSchemas) {
            const eventStreamSchema = memberSchemas[unionMember];
            if (eventStreamSchema.isStructSchema()) {
              const out = {};
              let hasBindings = false;
              for (const [name, member7] of eventStreamSchema.structIterator()) {
                const { eventHeader, eventPayload } = member7.getMergedTraits();
                hasBindings = hasBindings || Boolean(eventHeader || eventPayload);
                if (eventPayload) {
                  if (member7.isBlobSchema()) {
                    out[name] = body;
                  } else if (member7.isStringSchema()) {
                    out[name] = (this.serdeContext?.utf8Encoder ?? toUtf845)(body);
                  } else if (member7.isStructSchema()) {
                    out[name] = await this.deserializer.read(member7, body);
                  }
                } else if (eventHeader) {
                  const value = event[unionMember].headers[name]?.value;
                  if (value != null) {
                    if (member7.isNumericSchema()) {
                      if (value && typeof value === "object" && "bytes" in value) {
                        out[name] = BigInt(value.toString());
                      } else {
                        out[name] = Number(value);
                      }
                    } else {
                      out[name] = value;
                    }
                  }
                }
              }
              if (hasBindings) {
                return {
                  [unionMember]: out
                };
              }
              if (body.byteLength === 0) {
                return {
                  [unionMember]: {}
                };
              }
            }
            return {
              [unionMember]: await this.deserializer.read(eventStreamSchema, body)
            };
          } else {
            return {
              $unknown: event
            };
          }
        });
        const asyncIterator = asyncIterable[Symbol.asyncIterator]();
        const firstEvent = await asyncIterator.next();
        if (firstEvent.done) {
          return asyncIterable;
        }
        if (firstEvent.value?.[initialResponseMarker]) {
          if (!responseSchema) {
            throw new Error("@smithy::core/protocols - initial-response event encountered in event stream but no response schema given.");
          }
          for (const key in firstEvent.value) {
            initialResponseContainer[key] = firstEvent.value[key];
          }
        }
        return {
          async *[Symbol.asyncIterator]() {
            if (!firstEvent?.value?.[initialResponseMarker]) {
              yield firstEvent.value;
            }
            while (true) {
              const { done, value } = await asyncIterator.next();
              if (done) {
                break;
              }
              yield value;
            }
          }
        };
      }
      writeEventBody(unionMember, unionSchema, event) {
        const serializer = this.serializer;
        let eventType = unionMember;
        let explicitPayloadMember = null;
        let explicitPayloadContentType;
        const isKnownSchema = (() => {
          const struct3 = unionSchema.getSchema();
          return struct3[4].includes(unionMember);
        })();
        const additionalHeaders = {};
        if (!isKnownSchema) {
          const [type, value] = event[unionMember];
          eventType = type;
          serializer.write(15, value);
        } else {
          const eventSchema = unionSchema.getMemberSchema(unionMember);
          if (eventSchema.isStructSchema()) {
            for (const [memberName, memberSchema] of eventSchema.structIterator()) {
              const { eventHeader, eventPayload } = memberSchema.getMergedTraits();
              if (eventPayload) {
                explicitPayloadMember = memberName;
              } else if (eventHeader) {
                const value = event[unionMember][memberName];
                let type = "binary";
                if (memberSchema.isNumericSchema()) {
                  if ((-2) ** 31 <= value && value <= 2 ** 31 - 1) {
                    type = "integer";
                  } else {
                    type = "long";
                  }
                } else if (memberSchema.isTimestampSchema()) {
                  type = "timestamp";
                } else if (memberSchema.isStringSchema()) {
                  type = "string";
                } else if (memberSchema.isBooleanSchema()) {
                  type = "boolean";
                }
                if (value != null) {
                  additionalHeaders[memberName] = {
                    type,
                    value
                  };
                  delete event[unionMember][memberName];
                }
              }
            }
            if (explicitPayloadMember !== null) {
              const payloadSchema = eventSchema.getMemberSchema(explicitPayloadMember);
              if (payloadSchema.isBlobSchema()) {
                explicitPayloadContentType = "application/octet-stream";
              } else if (payloadSchema.isStringSchema()) {
                explicitPayloadContentType = "text/plain";
              }
              serializer.write(payloadSchema, event[unionMember][explicitPayloadMember]);
            } else {
              serializer.write(eventSchema, event[unionMember]);
            }
          } else if (eventSchema.isUnitSchema()) {
            serializer.write(eventSchema, {});
          } else {
            throw new Error("@smithy/core/event-streams - non-struct member not supported in event stream union.");
          }
        }
        const messageSerialization = serializer.flush() ?? new Uint8Array();
        const body = typeof messageSerialization === "string" ? (this.serdeContext?.utf8Decoder ?? fromUtf831)(messageSerialization) : messageSerialization;
        return {
          body,
          eventType,
          explicitPayloadContentType,
          additionalHeaders
        };
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/index.js
var event_streams_exports6 = {};
__export(event_streams_exports6, {
  EventStreamCodec: () => EventStreamCodec5,
  EventStreamMarshaller: () => EventStreamMarshaller10,
  EventStreamSerde: () => EventStreamSerde6,
  HeaderMarshaller: () => HeaderMarshaller5,
  Int64: () => Int645,
  MessageDecoderStream: () => MessageDecoderStream5,
  MessageEncoderStream: () => MessageEncoderStream5,
  SmithyMessageDecoderStream: () => SmithyMessageDecoderStream5,
  SmithyMessageEncoderStream: () => SmithyMessageEncoderStream5,
  UniversalEventStreamMarshaller: () => EventStreamMarshaller9,
  eventStreamSerdeProvider: () => eventStreamSerdeProvider10,
  getChunkedStream: () => getChunkedStream5,
  getMessageUnmarshaller: () => getMessageUnmarshaller5,
  getUnmarshalledStream: () => getUnmarshalledStream5,
  iterableToReadableStream: () => iterableToReadableStream5,
  readableStreamToIterable: () => readableStreamToIterable5,
  resolveEventStreamSerdeConfig: () => resolveEventStreamSerdeConfig5,
  universalEventStreamSerdeProvider: () => eventStreamSerdeProvider9
});
var init_event_streams6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/event-streams/index.js"() {
    init_EventStreamCodec5();
    init_HeaderMarshaller5();
    init_Int645();
    init_MessageDecoderStream5();
    init_MessageEncoderStream5();
    init_SmithyMessageDecoderStream5();
    init_SmithyMessageEncoderStream5();
    init_EventStreamMarshaller10();
    init_utils14();
    init_EventStreamMarshaller9();
    init_getChunkedStream5();
    init_getUnmarshalledStream5();
    init_EventStreamSerdeConfig5();
    init_EventStreamSerde6();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/HttpProtocol.js
var HttpProtocol6;
var init_HttpProtocol7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/HttpProtocol.js"() {
    init_schema9();
    init_SerdeContext7();
    init_httpRequest6();
    init_httpResponse6();
    HttpProtocol6 = class extends SerdeContext6 {
      static {
        __name(this, "HttpProtocol");
      }
      options;
      compositeErrorRegistry;
      constructor(options) {
        super();
        this.options = options;
        this.compositeErrorRegistry = TypeRegistry6.for(options.defaultNamespace);
        for (const etr of options.errorTypeRegistries ?? []) {
          this.compositeErrorRegistry.copyFrom(etr);
        }
      }
      getRequestType() {
        return HttpRequest25;
      }
      getResponseType() {
        return HttpResponse14;
      }
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
        this.serializer.setSerdeContext(serdeContext);
        this.deserializer.setSerdeContext(serdeContext);
        if (this.getPayloadCodec()) {
          this.getPayloadCodec().setSerdeContext(serdeContext);
        }
      }
      updateServiceEndpoint(request4, endpoint) {
        if ("url" in endpoint) {
          request4.protocol = endpoint.url.protocol;
          request4.hostname = endpoint.url.hostname;
          request4.port = endpoint.url.port ? Number(endpoint.url.port) : void 0;
          request4.path = endpoint.url.pathname;
          request4.fragment = endpoint.url.hash || void 0;
          request4.username = endpoint.url.username || void 0;
          request4.password = endpoint.url.password || void 0;
          if (!request4.query) {
            request4.query = {};
          }
          for (const [k32, v] of endpoint.url.searchParams.entries()) {
            request4.query[k32] = v;
          }
          if (endpoint.headers) {
            for (const name in endpoint.headers) {
              request4.headers[name] = endpoint.headers[name].join(", ");
            }
          }
          return request4;
        } else {
          request4.protocol = endpoint.protocol;
          request4.hostname = endpoint.hostname;
          request4.port = endpoint.port ? Number(endpoint.port) : void 0;
          request4.path = endpoint.path;
          request4.query = {
            ...endpoint.query
          };
          if (endpoint.headers) {
            for (const name in endpoint.headers) {
              request4.headers[name] = endpoint.headers[name];
            }
          }
          return request4;
        }
      }
      setHostPrefix(request4, operationSchema, input) {
        if (this.serdeContext?.disableHostPrefix) {
          return;
        }
        const inputNs = NormalizedSchema6.of(operationSchema.input);
        const opTraits = translateTraits6(operationSchema.traits ?? {});
        if (opTraits.endpoint) {
          let hostPrefix = opTraits.endpoint?.[0];
          if (typeof hostPrefix === "string") {
            for (const [name, member7] of inputNs.structIterator()) {
              if (!member7.getMergedTraits().hostLabel) {
                continue;
              }
              const replacement = input[name];
              if (typeof replacement !== "string") {
                throw new Error(`@smithy/core/schema - ${name} in input must be a string as hostLabel.`);
              }
              hostPrefix = hostPrefix.replace(`{${name}}`, replacement);
            }
            request4.hostname = hostPrefix + request4.hostname;
          }
        }
      }
      deserializeMetadata(output) {
        return {
          httpStatusCode: output.statusCode,
          requestId: output.headers["x-amzn-requestid"] ?? output.headers["x-amzn-request-id"] ?? output.headers["x-amz-request-id"],
          extendedRequestId: output.headers["x-amz-id-2"],
          cfId: output.headers["x-amz-cf-id"]
        };
      }
      async serializeEventStream({ eventStream, requestSchema, initialRequest }) {
        const eventStreamSerde = await this.loadEventStreamCapability();
        return eventStreamSerde.serializeEventStream({
          eventStream,
          requestSchema,
          initialRequest
        });
      }
      async deserializeEventStream({ response, responseSchema, initialResponseContainer }) {
        const eventStreamSerde = await this.loadEventStreamCapability();
        return eventStreamSerde.deserializeEventStream({
          response,
          responseSchema,
          initialResponseContainer
        });
      }
      async loadEventStreamCapability() {
        const { EventStreamSerde: EventStreamSerde7 } = await Promise.resolve().then(() => (init_event_streams6(), event_streams_exports6));
        return new EventStreamSerde7({
          marshaller: this.getEventStreamMarshaller(),
          serializer: this.serializer,
          deserializer: this.deserializer,
          serdeContext: this.serdeContext,
          defaultContentType: this.getDefaultContentType()
        });
      }
      getDefaultContentType() {
        throw new Error(`@smithy/core/protocols - ${this.constructor.name} getDefaultContentType() implementation missing.`);
      }
      async deserializeHttpMessage(schema, context, response, arg4, arg5) {
        void schema;
        void context;
        void response;
        void arg4;
        void arg5;
        return [];
      }
      getEventStreamMarshaller() {
        const context = this.serdeContext;
        if (!context.eventStreamMarshaller) {
          throw new Error("@smithy/core - HttpProtocol: eventStreamMarshaller missing in serdeContext.");
        }
        return context.eventStreamMarshaller;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/HttpBindingProtocol.js
var HttpBindingProtocol6;
var init_HttpBindingProtocol7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/HttpBindingProtocol.js"() {
    init_schema9();
    init_serde7();
    init_HttpProtocol7();
    init_collect_stream_body7();
    init_extended_encode_uri_component7();
    init_httpRequest6();
    HttpBindingProtocol6 = class extends HttpProtocol6 {
      static {
        __name(this, "HttpBindingProtocol");
      }
      async serializeRequest(operationSchema, _input, context) {
        const input = _input && typeof _input === "object" ? _input : {};
        const serializer = this.serializer;
        const query = {};
        const headers = {};
        const endpoint = await context.endpoint();
        const ns = NormalizedSchema6.of(operationSchema?.input);
        const payloadMemberNames = [];
        const payloadMemberSchemas = [];
        let hasNonHttpBindingMember = false;
        let payload3;
        const request4 = new HttpRequest25({
          protocol: "",
          hostname: "",
          port: void 0,
          path: "",
          fragment: void 0,
          query,
          headers,
          body: void 0
        });
        if (endpoint) {
          this.updateServiceEndpoint(request4, endpoint);
          this.setHostPrefix(request4, operationSchema, input);
          const opTraits = translateTraits6(operationSchema.traits);
          if (opTraits.http) {
            request4.method = opTraits.http[0];
            const [path47, search] = opTraits.http[1].split("?");
            if (request4.path == "/") {
              request4.path = path47;
            } else {
              request4.path += path47;
            }
            const traitSearchParams = new URLSearchParams(search ?? "");
            for (const [key, value] of traitSearchParams) {
              query[key] = value;
            }
          }
        }
        for (const [memberName, memberNs] of ns.structIterator()) {
          const memberTraits = memberNs.getMergedTraits() ?? {};
          const inputMemberValue = input[memberName];
          if (inputMemberValue == null && !memberNs.isIdempotencyToken()) {
            if (memberTraits.httpLabel) {
              if (request4.path.includes(`{${memberName}+}`) || request4.path.includes(`{${memberName}}`)) {
                throw new Error(`No value provided for input HTTP label: ${memberName}.`);
              }
            }
            continue;
          }
          if (memberTraits.httpPayload) {
            const isStreaming = memberNs.isStreaming();
            if (isStreaming) {
              const isEventStream = memberNs.isStructSchema();
              if (isEventStream) {
                if (input[memberName]) {
                  payload3 = await this.serializeEventStream({
                    eventStream: input[memberName],
                    requestSchema: ns
                  });
                }
              } else {
                payload3 = inputMemberValue;
              }
            } else {
              serializer.write(memberNs, inputMemberValue);
              payload3 = serializer.flush();
            }
          } else if (memberTraits.httpLabel) {
            serializer.write(memberNs, inputMemberValue);
            const replacement = serializer.flush();
            if (request4.path.includes(`{${memberName}+}`)) {
              request4.path = request4.path.replace(`{${memberName}+}`, replacement.split("/").map(extendedEncodeURIComponent6).join("/"));
            } else if (request4.path.includes(`{${memberName}}`)) {
              request4.path = request4.path.replace(`{${memberName}}`, extendedEncodeURIComponent6(replacement));
            }
          } else if (memberTraits.httpHeader) {
            serializer.write(memberNs, inputMemberValue);
            headers[memberTraits.httpHeader.toLowerCase()] = String(serializer.flush());
          } else if (typeof memberTraits.httpPrefixHeaders === "string") {
            for (const key in inputMemberValue) {
              const val = inputMemberValue[key];
              const amalgam = memberTraits.httpPrefixHeaders + key;
              serializer.write([memberNs.getValueSchema(), { httpHeader: amalgam }], val);
              headers[amalgam.toLowerCase()] = serializer.flush();
            }
          } else if (memberTraits.httpQuery || memberTraits.httpQueryParams) {
            this.serializeQuery(memberNs, inputMemberValue, query);
          } else {
            hasNonHttpBindingMember = true;
            payloadMemberNames.push(memberName);
            payloadMemberSchemas.push(memberNs);
          }
        }
        if (hasNonHttpBindingMember && input) {
          const [namespace, name] = (ns.getName(true) ?? "#Unknown").split("#");
          const requiredMembers = ns.getSchema()[6];
          const payloadSchema = [
            3,
            namespace,
            name,
            ns.getMergedTraits(),
            payloadMemberNames,
            payloadMemberSchemas,
            void 0
          ];
          if (requiredMembers) {
            payloadSchema[6] = requiredMembers;
          } else {
            payloadSchema.pop();
          }
          serializer.write(payloadSchema, input);
          payload3 = serializer.flush();
        }
        request4.headers = headers;
        request4.query = query;
        request4.body = payload3;
        return request4;
      }
      serializeQuery(ns, data3, query) {
        const serializer = this.serializer;
        const traits = ns.getMergedTraits();
        if (traits.httpQueryParams) {
          for (const key in data3) {
            if (!(key in query)) {
              const val = data3[key];
              const valueSchema = ns.getValueSchema();
              Object.assign(valueSchema.getMergedTraits(), {
                ...traits,
                httpQuery: key,
                httpQueryParams: void 0
              });
              this.serializeQuery(valueSchema, val, query);
            }
          }
          return;
        }
        if (ns.isListSchema()) {
          const sparse = !!ns.getMergedTraits().sparse;
          const buffer = [];
          for (const item of data3) {
            serializer.write([ns.getValueSchema(), traits], item);
            const serializable = serializer.flush();
            if (sparse || serializable !== void 0) {
              buffer.push(serializable);
            }
          }
          query[traits.httpQuery] = buffer;
        } else {
          serializer.write([ns, traits], data3);
          query[traits.httpQuery] = serializer.flush();
        }
      }
      async deserializeResponse(operationSchema, context, response) {
        const deserializer = this.deserializer;
        const ns = NormalizedSchema6.of(operationSchema.output);
        const dataObject = {};
        if (response.statusCode >= 300) {
          const bytes = await collectBody13(response.body, context);
          if (bytes.byteLength > 0) {
            Object.assign(dataObject, await deserializer.read(15, bytes));
          }
          await this.handleError(operationSchema, context, response, dataObject, this.deserializeMetadata(response));
          throw new Error("@smithy/core/protocols - HTTP Protocol error handler failed to throw.");
        }
        for (const header in response.headers) {
          const value = response.headers[header];
          delete response.headers[header];
          response.headers[header.toLowerCase()] = value;
        }
        const nonHttpBindingMembers = await this.deserializeHttpMessage(ns, context, response, dataObject);
        if (nonHttpBindingMembers.length) {
          const bytes = await collectBody13(response.body, context);
          if (bytes.byteLength > 0) {
            const dataFromBody = await deserializer.read(ns, bytes);
            for (const member7 of nonHttpBindingMembers) {
              if (dataFromBody[member7] != null) {
                dataObject[member7] = dataFromBody[member7];
              }
            }
          }
        } else if (nonHttpBindingMembers.discardResponseBody) {
          await collectBody13(response.body, context);
        }
        dataObject.$metadata = this.deserializeMetadata(response);
        return dataObject;
      }
      async deserializeHttpMessage(schema, context, response, arg4, arg5) {
        let dataObject;
        if (arg4 instanceof Set) {
          dataObject = arg5;
        } else {
          dataObject = arg4;
        }
        let discardResponseBody = true;
        const deserializer = this.deserializer;
        const ns = NormalizedSchema6.of(schema);
        const nonHttpBindingMembers = [];
        for (const [memberName, memberSchema] of ns.structIterator()) {
          const memberTraits = memberSchema.getMemberTraits();
          if (memberTraits.httpPayload) {
            discardResponseBody = false;
            const isStreaming = memberSchema.isStreaming();
            if (isStreaming) {
              const isEventStream = memberSchema.isStructSchema();
              if (isEventStream) {
                dataObject[memberName] = await this.deserializeEventStream({
                  response,
                  responseSchema: ns
                });
              } else {
                dataObject[memberName] = sdkStreamMixin11(response.body);
              }
            } else if (response.body) {
              const bytes = await collectBody13(response.body, context);
              if (bytes.byteLength > 0) {
                dataObject[memberName] = await deserializer.read(memberSchema, bytes);
              }
            }
          } else if (memberTraits.httpHeader) {
            const key = String(memberTraits.httpHeader).toLowerCase();
            const value = response.headers[key];
            if (null != value) {
              if (memberSchema.isListSchema()) {
                const headerListValueSchema = memberSchema.getValueSchema();
                headerListValueSchema.getMergedTraits().httpHeader = key;
                let sections;
                if (headerListValueSchema.isTimestampSchema() && headerListValueSchema.getSchema() === 4) {
                  sections = splitEvery6(value, ",", 2);
                } else {
                  sections = splitHeader6(value);
                }
                const list3 = [];
                for (const section of sections) {
                  list3.push(await deserializer.read(headerListValueSchema, section.trim()));
                }
                dataObject[memberName] = list3;
              } else {
                dataObject[memberName] = await deserializer.read(memberSchema, value);
              }
            }
          } else if (memberTraits.httpPrefixHeaders !== void 0) {
            dataObject[memberName] = {};
            for (const header in response.headers) {
              if (header.startsWith(memberTraits.httpPrefixHeaders)) {
                const value = response.headers[header];
                const valueSchema = memberSchema.getValueSchema();
                valueSchema.getMergedTraits().httpHeader = header;
                dataObject[memberName][header.slice(memberTraits.httpPrefixHeaders.length)] = await deserializer.read(valueSchema, value);
              }
            }
          } else if (memberTraits.httpResponseCode) {
            dataObject[memberName] = response.statusCode;
          } else {
            nonHttpBindingMembers.push(memberName);
          }
        }
        nonHttpBindingMembers.discardResponseBody = discardResponseBody;
        return nonHttpBindingMembers;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/RpcProtocol.js
var RpcProtocol6;
var init_RpcProtocol7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/RpcProtocol.js"() {
    init_schema9();
    init_HttpProtocol7();
    init_collect_stream_body7();
    init_httpRequest6();
    RpcProtocol6 = class extends HttpProtocol6 {
      static {
        __name(this, "RpcProtocol");
      }
      async serializeRequest(operationSchema, _input, context) {
        const serializer = this.serializer;
        const query = {};
        const headers = {};
        const endpoint = await context.endpoint();
        const ns = NormalizedSchema6.of(operationSchema?.input);
        const schema = ns.getSchema();
        let payload3;
        const input = _input && typeof _input === "object" ? _input : {};
        const request4 = new HttpRequest25({
          protocol: "",
          hostname: "",
          port: void 0,
          path: "/",
          fragment: void 0,
          query,
          headers,
          body: void 0
        });
        if (endpoint) {
          this.updateServiceEndpoint(request4, endpoint);
          this.setHostPrefix(request4, operationSchema, input);
        }
        if (input) {
          const eventStreamMember = ns.getEventStreamMember();
          if (eventStreamMember) {
            if (input[eventStreamMember]) {
              const initialRequest = {};
              for (const [memberName, memberSchema] of ns.structIterator()) {
                if (memberName !== eventStreamMember && input[memberName]) {
                  serializer.write(memberSchema, input[memberName]);
                  initialRequest[memberName] = serializer.flush();
                }
              }
              payload3 = await this.serializeEventStream({
                eventStream: input[eventStreamMember],
                requestSchema: ns,
                initialRequest
              });
            }
          } else {
            serializer.write(schema, input);
            payload3 = serializer.flush();
          }
        }
        request4.headers = Object.assign(request4.headers, headers);
        request4.query = query;
        request4.body = payload3;
        request4.method = "POST";
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        const deserializer = this.deserializer;
        const ns = NormalizedSchema6.of(operationSchema.output);
        const dataObject = {};
        if (response.statusCode >= 300) {
          const bytes = await collectBody13(response.body, context);
          if (bytes.byteLength > 0) {
            Object.assign(dataObject, await deserializer.read(15, bytes));
          }
          await this.handleError(operationSchema, context, response, dataObject, this.deserializeMetadata(response));
          throw new Error("@smithy/core/protocols - RPC Protocol error handler failed to throw.");
        }
        for (const header in response.headers) {
          const value = response.headers[header];
          delete response.headers[header];
          response.headers[header.toLowerCase()] = value;
        }
        const eventStreamMember = ns.getEventStreamMember();
        if (eventStreamMember) {
          dataObject[eventStreamMember] = await this.deserializeEventStream({
            response,
            responseSchema: ns,
            initialResponseContainer: dataObject
          });
        } else {
          const bytes = await collectBody13(response.body, context);
          if (bytes.byteLength > 0) {
            Object.assign(dataObject, await deserializer.read(ns, bytes));
          }
        }
        dataObject.$metadata = this.deserializeMetadata(response);
        return dataObject;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/resolve-path.js
var resolvedPath6;
var init_resolve_path7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/resolve-path.js"() {
    init_extended_encode_uri_component7();
    resolvedPath6 = /* @__PURE__ */ __name((resolvedPath7, input, memberName, labelValueProvider, uriLabel, isGreedyLabel) => {
      if (input != null && input[memberName] !== void 0) {
        const labelValue = labelValueProvider();
        if (labelValue == null || labelValue.length <= 0) {
          throw new Error("Empty value provided for input HTTP label: " + memberName + ".");
        }
        resolvedPath7 = resolvedPath7.replace(uriLabel, isGreedyLabel ? labelValue.split("/").map((segment) => extendedEncodeURIComponent6(segment)).join("/") : extendedEncodeURIComponent6(labelValue));
      } else {
        throw new Error("No value provided for input HTTP label: " + memberName + ".");
      }
      return resolvedPath7;
    }, "resolvedPath");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/requestBuilder.js
function requestBuilder6(input, context) {
  return new RequestBuilder6(input, context);
}
var RequestBuilder6;
var init_requestBuilder9 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/requestBuilder.js"() {
    init_httpRequest6();
    init_resolve_path7();
    __name(requestBuilder6, "requestBuilder");
    RequestBuilder6 = class {
      static {
        __name(this, "RequestBuilder");
      }
      input;
      context;
      query = {};
      method = "";
      headers = {};
      path = "";
      body = null;
      hostname = "";
      resolvePathStack = [];
      constructor(input, context) {
        this.input = input;
        this.context = context;
      }
      async build() {
        const { hostname, protocol = "https", port, path: basePath } = await this.context.endpoint();
        this.path = basePath;
        for (const resolvePath of this.resolvePathStack) {
          resolvePath(this.path);
        }
        return new HttpRequest25({
          protocol,
          hostname: this.hostname || hostname,
          port,
          method: this.method,
          path: this.path,
          query: this.query,
          body: this.body,
          headers: this.headers
        });
      }
      hn(hostname) {
        this.hostname = hostname;
        return this;
      }
      bp(uriLabel) {
        this.resolvePathStack.push((basePath) => {
          this.path = `${basePath?.endsWith("/") ? basePath.slice(0, -1) : basePath || ""}` + uriLabel;
        });
        return this;
      }
      p(memberName, labelValueProvider, uriLabel, isGreedyLabel) {
        this.resolvePathStack.push((path47) => {
          this.path = resolvedPath6(path47, this.input, memberName, labelValueProvider, uriLabel, isGreedyLabel);
        });
        return this;
      }
      h(headers) {
        this.headers = headers;
        return this;
      }
      q(query) {
        this.query = query;
        return this;
      }
      b(body) {
        this.body = body;
        return this;
      }
      m(method) {
        this.method = method;
        return this;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/serde/determineTimestampFormat.js
function determineTimestampFormat6(ns, settings) {
  if (settings.timestampFormat.useTrait) {
    if (ns.isTimestampSchema() && (ns.getSchema() === 5 || ns.getSchema() === 6 || ns.getSchema() === 7)) {
      return ns.getSchema();
    }
  }
  const { httpLabel, httpPrefixHeaders, httpHeader, httpQuery } = ns.getMergedTraits();
  const bindingFormat = settings.httpBindings ? typeof httpPrefixHeaders === "string" || Boolean(httpHeader) ? 6 : Boolean(httpQuery) || Boolean(httpLabel) ? 5 : void 0 : void 0;
  return bindingFormat ?? settings.timestampFormat.default;
}
var init_determineTimestampFormat7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/serde/determineTimestampFormat.js"() {
    __name(determineTimestampFormat6, "determineTimestampFormat");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/serde/FromStringShapeDeserializer.js
var FromStringShapeDeserializer6;
var init_FromStringShapeDeserializer7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/serde/FromStringShapeDeserializer.js"() {
    init_schema9();
    init_serde7();
    init_SerdeContext7();
    init_determineTimestampFormat7();
    FromStringShapeDeserializer6 = class extends SerdeContext6 {
      static {
        __name(this, "FromStringShapeDeserializer");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      read(_schema, data3) {
        const ns = NormalizedSchema6.of(_schema);
        if (ns.isListSchema()) {
          return splitHeader6(data3).map((item) => this.read(ns.getValueSchema(), item));
        }
        if (ns.isBlobSchema()) {
          return (this.serdeContext?.base64Decoder ?? fromBase6442)(data3);
        }
        if (ns.isTimestampSchema()) {
          const format32 = determineTimestampFormat6(ns, this.settings);
          switch (format32) {
            case 5:
              return _parseRfc3339DateTimeWithOffset6(data3);
            case 6:
              return _parseRfc7231DateTime6(data3);
            case 7:
              return _parseEpochTimestamp6(data3);
            default:
              console.warn("Missing timestamp format, parsing value with Date constructor:", data3);
              return new Date(data3);
          }
        }
        if (ns.isStringSchema()) {
          const mediaType = ns.getMergedTraits().mediaType;
          let intermediateValue = data3;
          if (mediaType) {
            if (ns.getMergedTraits().httpHeader) {
              intermediateValue = this.base64ToUtf8(intermediateValue);
            }
            const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
            if (isJson) {
              intermediateValue = LazyJsonString11.from(intermediateValue);
            }
            return intermediateValue;
          }
        }
        if (ns.isNumericSchema()) {
          return Number(data3);
        }
        if (ns.isBigIntegerSchema()) {
          return BigInt(data3);
        }
        if (ns.isBigDecimalSchema()) {
          return new NumericValue6(data3, "bigDecimal");
        }
        if (ns.isBooleanSchema()) {
          return String(data3).toLowerCase() === "true";
        }
        return data3;
      }
      base64ToUtf8(base64String) {
        return (this.serdeContext?.utf8Encoder ?? toUtf845)((this.serdeContext?.base64Decoder ?? fromBase6442)(base64String));
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/serde/HttpInterceptingShapeDeserializer.js
var HttpInterceptingShapeDeserializer6;
var init_HttpInterceptingShapeDeserializer7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/serde/HttpInterceptingShapeDeserializer.js"() {
    init_schema9();
    init_serde7();
    init_SerdeContext7();
    init_FromStringShapeDeserializer7();
    HttpInterceptingShapeDeserializer6 = class extends SerdeContext6 {
      static {
        __name(this, "HttpInterceptingShapeDeserializer");
      }
      codecDeserializer;
      stringDeserializer;
      constructor(codecDeserializer, codecSettings) {
        super();
        this.codecDeserializer = codecDeserializer;
        this.stringDeserializer = new FromStringShapeDeserializer6(codecSettings);
      }
      setSerdeContext(serdeContext) {
        this.stringDeserializer.setSerdeContext(serdeContext);
        this.codecDeserializer.setSerdeContext(serdeContext);
        this.serdeContext = serdeContext;
      }
      read(schema, data3) {
        const ns = NormalizedSchema6.of(schema);
        const traits = ns.getMergedTraits();
        const toString = this.serdeContext?.utf8Encoder ?? toUtf845;
        if (traits.httpHeader || traits.httpResponseCode) {
          return this.stringDeserializer.read(ns, toString(data3));
        }
        if (traits.httpPayload) {
          if (ns.isBlobSchema()) {
            const toBytes = this.serdeContext?.utf8Decoder ?? fromUtf831;
            if (typeof data3 === "string") {
              return toBytes(data3);
            }
            return data3;
          } else if (ns.isStringSchema()) {
            if ("byteLength" in data3) {
              return toString(data3);
            }
            return data3;
          }
        }
        return this.codecDeserializer.read(ns, data3);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/serde/ToStringShapeSerializer.js
var ToStringShapeSerializer6;
var init_ToStringShapeSerializer7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/serde/ToStringShapeSerializer.js"() {
    init_schema9();
    init_serde7();
    init_SerdeContext7();
    init_determineTimestampFormat7();
    ToStringShapeSerializer6 = class extends SerdeContext6 {
      static {
        __name(this, "ToStringShapeSerializer");
      }
      settings;
      stringBuffer = "";
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value) {
        const ns = NormalizedSchema6.of(schema);
        switch (typeof value) {
          case "object":
            if (value === null) {
              this.stringBuffer = "null";
              return;
            }
            if (ns.isTimestampSchema()) {
              if (!(value instanceof Date)) {
                throw new Error(`@smithy/core/protocols - received non-Date value ${value} when schema expected Date in ${ns.getName(true)}`);
              }
              const format32 = determineTimestampFormat6(ns, this.settings);
              switch (format32) {
                case 5:
                  this.stringBuffer = value.toISOString().replace(".000Z", "Z");
                  break;
                case 6:
                  this.stringBuffer = dateToUtcString18(value);
                  break;
                case 7:
                  this.stringBuffer = String(value.getTime() / 1e3);
                  break;
                default:
                  console.warn("Missing timestamp format, using epoch seconds", value);
                  this.stringBuffer = String(value.getTime() / 1e3);
              }
              return;
            }
            if (ns.isBlobSchema() && "byteLength" in value) {
              this.stringBuffer = (this.serdeContext?.base64Encoder ?? toBase6447)(value);
              return;
            }
            if (ns.isListSchema() && Array.isArray(value)) {
              let buffer = "";
              for (const item of value) {
                this.write([ns.getValueSchema(), ns.getMergedTraits()], item);
                const headerItem = this.flush();
                const serialized = ns.getValueSchema().isTimestampSchema() ? headerItem : quoteHeader6(headerItem);
                if (buffer !== "") {
                  buffer += ", ";
                }
                buffer += serialized;
              }
              this.stringBuffer = buffer;
              return;
            }
            this.stringBuffer = JSON.stringify(value, null, 2);
            break;
          case "string":
            const mediaType = ns.getMergedTraits().mediaType;
            let intermediateValue = value;
            if (mediaType) {
              const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
              if (isJson) {
                intermediateValue = LazyJsonString11.from(intermediateValue);
              }
              if (ns.getMergedTraits().httpHeader) {
                this.stringBuffer = (this.serdeContext?.base64Encoder ?? toBase6447)(intermediateValue.toString());
                return;
              }
            }
            this.stringBuffer = value;
            break;
          default:
            if (ns.isIdempotencyToken()) {
              this.stringBuffer = generateIdempotencyToken6();
            } else {
              this.stringBuffer = String(value);
            }
        }
      }
      flush() {
        const buffer = this.stringBuffer;
        this.stringBuffer = "";
        return buffer;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/serde/HttpInterceptingShapeSerializer.js
var HttpInterceptingShapeSerializer6;
var init_HttpInterceptingShapeSerializer7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/serde/HttpInterceptingShapeSerializer.js"() {
    init_schema9();
    init_ToStringShapeSerializer7();
    HttpInterceptingShapeSerializer6 = class {
      static {
        __name(this, "HttpInterceptingShapeSerializer");
      }
      codecSerializer;
      stringSerializer;
      buffer;
      constructor(codecSerializer, codecSettings, stringSerializer = new ToStringShapeSerializer6(codecSettings)) {
        this.codecSerializer = codecSerializer;
        this.stringSerializer = stringSerializer;
      }
      setSerdeContext(serdeContext) {
        this.codecSerializer.setSerdeContext(serdeContext);
        this.stringSerializer.setSerdeContext(serdeContext);
      }
      write(schema, value) {
        const ns = NormalizedSchema6.of(schema);
        const traits = ns.getMergedTraits();
        if (traits.httpHeader || traits.httpLabel || traits.httpQuery) {
          this.stringSerializer.write(ns, value);
          this.buffer = this.stringSerializer.flush();
          return;
        }
        return this.codecSerializer.write(ns, value);
      }
      flush() {
        if (this.buffer !== void 0) {
          const buffer = this.buffer;
          this.buffer = void 0;
          return buffer;
        }
        return this.codecSerializer.flush();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/Field.js
var import_types59, Field5;
var init_Field5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/Field.js"() {
    import_types59 = __toESM(require_dist_cjs());
    Field5 = class {
      static {
        __name(this, "Field");
      }
      name;
      kind;
      values;
      constructor({ name, kind = import_types59.FieldPosition.HEADER, values = [] }) {
        this.name = name;
        this.kind = kind;
        this.values = values;
      }
      add(value) {
        this.values.push(value);
      }
      set(values) {
        this.values = values;
      }
      remove(value) {
        this.values = this.values.filter((v) => v !== value);
      }
      toString() {
        return this.values.map((v) => v.includes(",") || v.includes(" ") ? `"${v}"` : v).join(", ");
      }
      get() {
        return this.values;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/Fields.js
var Fields5;
var init_Fields5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/Fields.js"() {
    Fields5 = class {
      static {
        __name(this, "Fields");
      }
      entries = {};
      encoding;
      constructor({ fields = [], encoding = "utf-8" }) {
        fields.forEach(this.setField.bind(this));
        this.encoding = encoding;
      }
      setField(field) {
        this.entries[field.name.toLowerCase()] = field;
      }
      getField(name) {
        return this.entries[name.toLowerCase()];
      }
      removeField(name) {
        delete this.entries[name.toLowerCase()];
      }
      getByType(kind) {
        return Object.values(this.entries).filter((field) => field.kind === kind);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/isValidHostname.js
function isValidHostname5(hostname) {
  const hostPattern = /^[a-z0-9][a-z0-9\.\-]*[a-z0-9]$/;
  return hostPattern.test(hostname);
}
var init_isValidHostname5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/isValidHostname.js"() {
    __name(isValidHostname5, "isValidHostname");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/extensions/httpExtensionConfiguration.js
var getHttpHandlerExtensionConfiguration23, resolveHttpHandlerRuntimeConfig23;
var init_httpExtensionConfiguration5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/protocol-http/extensions/httpExtensionConfiguration.js"() {
    getHttpHandlerExtensionConfiguration23 = /* @__PURE__ */ __name((runtimeConfig) => {
      return {
        setHttpHandler(handler) {
          runtimeConfig.httpHandler = handler;
        },
        httpHandler() {
          return runtimeConfig.httpHandler;
        },
        updateHttpClientConfig(key, value) {
          runtimeConfig.httpHandler?.updateHttpClientConfig(key, value);
        },
        httpHandlerConfigs() {
          return runtimeConfig.httpHandler.httpHandlerConfigs();
        }
      };
    }, "getHttpHandlerExtensionConfiguration");
    resolveHttpHandlerRuntimeConfig23 = /* @__PURE__ */ __name((httpHandlerExtensionConfiguration) => {
      return {
        httpHandler: httpHandlerExtensionConfiguration.httpHandler()
      };
    }, "resolveHttpHandlerRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/middleware-content-length/contentLengthMiddleware.js
function contentLengthMiddleware5(bodyLengthChecker) {
  return (next) => async (args) => {
    const request4 = args.request;
    if (HttpRequest25.isInstance(request4)) {
      const { body, headers } = request4;
      if (body && Object.keys(headers).map((str) => str.toLowerCase()).indexOf(CONTENT_LENGTH_HEADER5) === -1) {
        try {
          const length = bodyLengthChecker(body);
          request4.headers = {
            ...request4.headers,
            [CONTENT_LENGTH_HEADER5]: String(length)
          };
        } catch (error4) {
        }
      }
    }
    return next({
      ...args,
      request: request4
    });
  };
}
var CONTENT_LENGTH_HEADER5, contentLengthMiddlewareOptions5, getContentLengthPlugin23;
var init_contentLengthMiddleware5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/middleware-content-length/contentLengthMiddleware.js"() {
    init_httpRequest6();
    CONTENT_LENGTH_HEADER5 = "content-length";
    __name(contentLengthMiddleware5, "contentLengthMiddleware");
    contentLengthMiddlewareOptions5 = {
      step: "build",
      tags: ["SET_CONTENT_LENGTH", "CONTENT_LENGTH"],
      name: "contentLengthMiddleware",
      override: true
    };
    getContentLengthPlugin23 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(contentLengthMiddleware5(options.bodyLengthChecker), contentLengthMiddlewareOptions5);
      }, "applyToStack")
    }), "getContentLengthPlugin");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/util-uri-escape/escape-uri.js
var escapeUri5, hexEncode5;
var init_escape_uri5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/util-uri-escape/escape-uri.js"() {
    escapeUri5 = /* @__PURE__ */ __name((uri) => encodeURIComponent(uri).replace(/[!'()*]/g, hexEncode5), "escapeUri");
    hexEncode5 = /* @__PURE__ */ __name((c32) => `%${c32.charCodeAt(0).toString(16).toUpperCase()}`, "hexEncode");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/util-uri-escape/escape-uri-path.js
var escapeUriPath5;
var init_escape_uri_path5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/util-uri-escape/escape-uri-path.js"() {
    init_escape_uri5();
    escapeUriPath5 = /* @__PURE__ */ __name((uri) => uri.split("/").map(escapeUri5).join("/"), "escapeUriPath");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/querystring-builder/buildQueryString.js
function buildQueryString5(query) {
  const parts = [];
  for (let key of Object.keys(query).sort()) {
    const value = query[key];
    key = escapeUri5(key);
    if (Array.isArray(value)) {
      for (let i32 = 0, iLen = value.length; i32 < iLen; i32++) {
        parts.push(`${key}=${escapeUri5(value[i32])}`);
      }
    } else {
      let qsEntry = key;
      if (value || typeof value === "string") {
        qsEntry += `=${escapeUri5(value)}`;
      }
      parts.push(qsEntry);
    }
  }
  return parts.join("&");
}
var init_buildQueryString5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/querystring-builder/buildQueryString.js"() {
    init_escape_uri5();
    __name(buildQueryString5, "buildQueryString");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/querystring-parser/parseQueryString.js
function parseQueryString5(querystring) {
  const query = {};
  querystring = querystring.replace(/^\?/, "");
  if (querystring) {
    for (const pair of querystring.split("&")) {
      let [key, value = null] = pair.split("=");
      key = decodeURIComponent(key);
      if (value) {
        value = decodeURIComponent(value);
      }
      if (!(key in query)) {
        query[key] = value;
      } else if (Array.isArray(query[key])) {
        query[key].push(value);
      } else {
        query[key] = [query[key], value];
      }
    }
  }
  return query;
}
var init_parseQueryString5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/querystring-parser/parseQueryString.js"() {
    __name(parseQueryString5, "parseQueryString");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/url-parser/parseUrl.js
var parseUrl24;
var init_parseUrl5 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/url-parser/parseUrl.js"() {
    init_parseQueryString5();
    parseUrl24 = /* @__PURE__ */ __name((url) => {
      if (typeof url === "string") {
        return parseUrl24(new URL(url));
      }
      const { hostname, pathname, port, protocol, search } = url;
      let query;
      if (search) {
        query = parseQueryString5(search);
      }
      return {
        hostname,
        port: port ? parseInt(port) : void 0,
        protocol,
        path: pathname,
        query
      };
    }, "parseUrl");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/index.js
var protocols_exports11 = {};
__export(protocols_exports11, {
  Field: () => Field5,
  Fields: () => Fields5,
  FromStringShapeDeserializer: () => FromStringShapeDeserializer6,
  HttpBindingProtocol: () => HttpBindingProtocol6,
  HttpInterceptingShapeDeserializer: () => HttpInterceptingShapeDeserializer6,
  HttpInterceptingShapeSerializer: () => HttpInterceptingShapeSerializer6,
  HttpProtocol: () => HttpProtocol6,
  HttpRequest: () => HttpRequest25,
  HttpResponse: () => HttpResponse14,
  RequestBuilder: () => RequestBuilder6,
  RpcProtocol: () => RpcProtocol6,
  SerdeContext: () => SerdeContext6,
  ToStringShapeSerializer: () => ToStringShapeSerializer6,
  buildQueryString: () => buildQueryString5,
  collectBody: () => collectBody13,
  contentLengthMiddleware: () => contentLengthMiddleware5,
  contentLengthMiddlewareOptions: () => contentLengthMiddlewareOptions5,
  determineTimestampFormat: () => determineTimestampFormat6,
  escapeUri: () => escapeUri5,
  escapeUriPath: () => escapeUriPath5,
  extendedEncodeURIComponent: () => extendedEncodeURIComponent6,
  getContentLengthPlugin: () => getContentLengthPlugin23,
  getHttpHandlerExtensionConfiguration: () => getHttpHandlerExtensionConfiguration23,
  isValidHostname: () => isValidHostname5,
  parseQueryString: () => parseQueryString5,
  parseUrl: () => parseUrl24,
  requestBuilder: () => requestBuilder6,
  resolveHttpHandlerRuntimeConfig: () => resolveHttpHandlerRuntimeConfig23,
  resolvedPath: () => resolvedPath6
});
var init_protocols14 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/node_modules/@smithy/core/dist-es/submodules/protocols/index.js"() {
    init_collect_stream_body7();
    init_extended_encode_uri_component7();
    init_HttpBindingProtocol7();
    init_HttpProtocol7();
    init_RpcProtocol7();
    init_requestBuilder9();
    init_resolve_path7();
    init_FromStringShapeDeserializer7();
    init_HttpInterceptingShapeDeserializer7();
    init_HttpInterceptingShapeSerializer7();
    init_ToStringShapeSerializer7();
    init_determineTimestampFormat7();
    init_SerdeContext7();
    init_Field5();
    init_Fields5();
    init_httpRequest6();
    init_httpResponse6();
    init_isValidHostname5();
    init_httpExtensionConfiguration5();
    init_contentLengthMiddleware5();
    init_escape_uri5();
    init_escape_uri_path5();
    init_buildQueryString5();
    init_parseQueryString5();
    init_parseUrl5();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/dist-cjs/index.js
var require_dist_cjs144 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/node-http-handler/dist-cjs/index.js"(exports2) {
    "use strict";
    var node_https = require("node:https");
    var protocols = (init_protocols14(), __toCommonJS(protocols_exports11));
    var node_stream = require("node:stream");
    var http2 = require("node:http2");
    function buildAbortError(abortSignal) {
      const reason = abortSignal && typeof abortSignal === "object" && "reason" in abortSignal ? abortSignal.reason : void 0;
      if (reason) {
        if (reason instanceof Error) {
          const abortError3 = new Error("Request aborted");
          abortError3.name = "AbortError";
          abortError3.cause = reason;
          return abortError3;
        }
        const abortError2 = new Error(String(reason));
        abortError2.name = "AbortError";
        return abortError2;
      }
      const abortError = new Error("Request aborted");
      abortError.name = "AbortError";
      return abortError;
    }
    __name(buildAbortError, "buildAbortError");
    var NODEJS_TIMEOUT_ERROR_CODES3 = ["ECONNRESET", "EPIPE", "ETIMEDOUT"];
    var getTransformedHeaders = /* @__PURE__ */ __name((headers) => {
      const transformedHeaders = {};
      for (const name in headers) {
        const headerValues = headers[name];
        transformedHeaders[name] = Array.isArray(headerValues) ? headerValues.join(",") : headerValues;
      }
      return transformedHeaders;
    }, "getTransformedHeaders");
    var timing = {
      setTimeout: /* @__PURE__ */ __name((cb, ms) => setTimeout(cb, ms), "setTimeout"),
      clearTimeout: /* @__PURE__ */ __name((timeoutId) => clearTimeout(timeoutId), "clearTimeout")
    };
    var DEFER_EVENT_LISTENER_TIME$2 = 1e3;
    var setConnectionTimeout = /* @__PURE__ */ __name((request4, reject, timeoutInMs = 0) => {
      if (!timeoutInMs) {
        return -1;
      }
      const registerTimeout = /* @__PURE__ */ __name((offset) => {
        const timeoutId = timing.setTimeout(() => {
          request4.destroy();
          reject(Object.assign(new Error(`@smithy/node-http-handler - the request socket did not establish a connection with the server within the configured timeout of ${timeoutInMs} ms.`), {
            name: "TimeoutError"
          }));
        }, timeoutInMs - offset);
        const doWithSocket = /* @__PURE__ */ __name((socket) => {
          if (socket?.connecting) {
            socket.on("connect", () => {
              timing.clearTimeout(timeoutId);
            });
          } else {
            timing.clearTimeout(timeoutId);
          }
        }, "doWithSocket");
        if (request4.socket) {
          doWithSocket(request4.socket);
        } else {
          request4.on("socket", doWithSocket);
        }
      }, "registerTimeout");
      if (timeoutInMs < 2e3) {
        registerTimeout(0);
        return 0;
      }
      return timing.setTimeout(registerTimeout.bind(null, DEFER_EVENT_LISTENER_TIME$2), DEFER_EVENT_LISTENER_TIME$2);
    }, "setConnectionTimeout");
    var setRequestTimeout = /* @__PURE__ */ __name((req, reject, timeoutInMs = 0, throwOnRequestTimeout, logger5) => {
      if (timeoutInMs) {
        return timing.setTimeout(() => {
          let msg = `@smithy/node-http-handler - [${throwOnRequestTimeout ? "ERROR" : "WARN"}] a request has exceeded the configured ${timeoutInMs} ms requestTimeout.`;
          if (throwOnRequestTimeout) {
            const error4 = Object.assign(new Error(msg), {
              name: "TimeoutError",
              code: "ETIMEDOUT"
            });
            req.destroy(error4);
            reject(error4);
          } else {
            msg += ` Init client requestHandler with throwOnRequestTimeout=true to turn this into an error.`;
            logger5?.warn?.(msg);
          }
        }, timeoutInMs);
      }
      return -1;
    }, "setRequestTimeout");
    var DEFER_EVENT_LISTENER_TIME$1 = 3e3;
    var setSocketKeepAlive = /* @__PURE__ */ __name((request4, { keepAlive, keepAliveMsecs }, deferTimeMs = DEFER_EVENT_LISTENER_TIME$1) => {
      if (keepAlive !== true) {
        return -1;
      }
      const registerListener = /* @__PURE__ */ __name(() => {
        if (request4.socket) {
          request4.socket.setKeepAlive(keepAlive, keepAliveMsecs || 0);
        } else {
          request4.on("socket", (socket) => {
            socket.setKeepAlive(keepAlive, keepAliveMsecs || 0);
          });
        }
      }, "registerListener");
      if (deferTimeMs === 0) {
        registerListener();
        return 0;
      }
      return timing.setTimeout(registerListener, deferTimeMs);
    }, "setSocketKeepAlive");
    var DEFER_EVENT_LISTENER_TIME = 3e3;
    var setSocketTimeout = /* @__PURE__ */ __name((request4, reject, timeoutInMs = 0) => {
      const registerTimeout = /* @__PURE__ */ __name((offset) => {
        const timeout = timeoutInMs - offset;
        const onTimeout = /* @__PURE__ */ __name(() => {
          request4.destroy();
          reject(Object.assign(new Error(`@smithy/node-http-handler - the request socket timed out after ${timeoutInMs} ms of inactivity (configured by client requestHandler).`), { name: "TimeoutError" }));
        }, "onTimeout");
        if (request4.socket) {
          request4.socket.setTimeout(timeout, onTimeout);
          request4.on("close", () => request4.socket?.removeListener("timeout", onTimeout));
        } else {
          request4.setTimeout(timeout, onTimeout);
        }
      }, "registerTimeout");
      if (0 < timeoutInMs && timeoutInMs < 6e3) {
        registerTimeout(0);
        return 0;
      }
      return timing.setTimeout(registerTimeout.bind(null, timeoutInMs === 0 ? 0 : DEFER_EVENT_LISTENER_TIME), DEFER_EVENT_LISTENER_TIME);
    }, "setSocketTimeout");
    var MIN_WAIT_TIME = 6e3;
    async function writeRequestBody(httpRequest, request4, maxContinueTimeoutMs = MIN_WAIT_TIME, externalAgent = false) {
      const headers = request4.headers;
      const expect = headers ? headers.Expect || headers.expect : void 0;
      let timeoutId = -1;
      let sendBody = true;
      if (!externalAgent && expect === "100-continue") {
        sendBody = await Promise.race([
          new Promise((resolve13) => {
            timeoutId = Number(timing.setTimeout(() => resolve13(true), Math.max(MIN_WAIT_TIME, maxContinueTimeoutMs)));
          }),
          new Promise((resolve13) => {
            httpRequest.on("continue", () => {
              timing.clearTimeout(timeoutId);
              resolve13(true);
            });
            httpRequest.on("response", () => {
              timing.clearTimeout(timeoutId);
              resolve13(false);
            });
            httpRequest.on("error", () => {
              timing.clearTimeout(timeoutId);
              resolve13(false);
            });
          })
        ]);
      }
      if (sendBody) {
        writeBody(httpRequest, request4.body);
      }
    }
    __name(writeRequestBody, "writeRequestBody");
    function writeBody(httpRequest, body) {
      if (body instanceof node_stream.Readable) {
        body.pipe(httpRequest);
        return;
      }
      if (body) {
        const isBuffer = Buffer.isBuffer(body);
        const isString = typeof body === "string";
        if (isBuffer || isString) {
          if (isBuffer && body.byteLength === 0) {
            httpRequest.end();
          } else {
            httpRequest.end(body);
          }
          return;
        }
        const uint8 = body;
        if (typeof uint8 === "object" && uint8.buffer && typeof uint8.byteOffset === "number" && typeof uint8.byteLength === "number") {
          httpRequest.end(Buffer.from(uint8.buffer, uint8.byteOffset, uint8.byteLength));
          return;
        }
        httpRequest.end(Buffer.from(body));
        return;
      }
      httpRequest.end();
    }
    __name(writeBody, "writeBody");
    var DEFAULT_REQUEST_TIMEOUT = 0;
    var hAgent = void 0;
    var hRequest = void 0;
    var NodeHttpHandler = class _NodeHttpHandler {
      static {
        __name(this, "NodeHttpHandler");
      }
      config;
      configProvider;
      socketWarningTimestamp = 0;
      externalAgent = false;
      metadata = { handlerProtocol: "http/1.1" };
      static create(instanceOrOptions) {
        if (typeof instanceOrOptions?.handle === "function") {
          return instanceOrOptions;
        }
        return new _NodeHttpHandler(instanceOrOptions);
      }
      static checkSocketUsage(agent, socketWarningTimestamp, logger5 = console) {
        const { sockets, requests, maxSockets } = agent;
        if (typeof maxSockets !== "number" || maxSockets === Infinity) {
          return socketWarningTimestamp;
        }
        const interval = 15e3;
        if (Date.now() - interval < socketWarningTimestamp) {
          return socketWarningTimestamp;
        }
        if (sockets && requests) {
          for (const origin in sockets) {
            const socketsInUse = sockets[origin]?.length ?? 0;
            const requestsEnqueued = requests[origin]?.length ?? 0;
            if (socketsInUse >= maxSockets && requestsEnqueued >= 2 * maxSockets) {
              logger5?.warn?.(`@smithy/node-http-handler:WARN - socket usage at capacity=${socketsInUse} and ${requestsEnqueued} additional requests are enqueued.
See https://docs.aws.amazon.com/sdk-for-javascript/v3/developer-guide/node-configuring-maxsockets.html
or increase socketAcquisitionWarningTimeout=(millis) in the NodeHttpHandler config.`);
              return Date.now();
            }
          }
        }
        return socketWarningTimestamp;
      }
      constructor(options) {
        this.configProvider = new Promise((resolve13, reject) => {
          if (typeof options === "function") {
            options().then((_options) => {
              resolve13(this.resolveDefaultConfig(_options));
            }).catch(reject);
          } else {
            resolve13(this.resolveDefaultConfig(options));
          }
        });
      }
      destroy() {
        this.config?.httpAgent?.destroy();
        this.config?.httpsAgent?.destroy();
      }
      async handle(request4, { abortSignal, requestTimeout } = {}) {
        if (!this.config) {
          this.config = await this.configProvider;
        }
        const config2 = this.config;
        const isSSL = request4.protocol === "https:";
        if (!isSSL && !this.config.httpAgent) {
          this.config.httpAgent = await this.config.httpAgentProvider();
        }
        return new Promise((_resolve, _reject) => {
          let writeRequestBodyPromise = void 0;
          let socketWarningTimeoutId = -1;
          let connectionTimeoutId = -1;
          let requestTimeoutId = -1;
          let socketTimeoutId = -1;
          let keepAliveTimeoutId = -1;
          const clearTimeouts = /* @__PURE__ */ __name(() => {
            timing.clearTimeout(socketWarningTimeoutId);
            timing.clearTimeout(connectionTimeoutId);
            timing.clearTimeout(requestTimeoutId);
            timing.clearTimeout(socketTimeoutId);
            timing.clearTimeout(keepAliveTimeoutId);
          }, "clearTimeouts");
          const resolve13 = /* @__PURE__ */ __name(async (arg) => {
            await writeRequestBodyPromise;
            clearTimeouts();
            _resolve(arg);
          }, "resolve");
          const reject = /* @__PURE__ */ __name(async (arg) => {
            await writeRequestBodyPromise;
            clearTimeouts();
            _reject(arg);
          }, "reject");
          if (abortSignal?.aborted) {
            const abortError = buildAbortError(abortSignal);
            reject(abortError);
            return;
          }
          const headers = request4.headers;
          const expectContinue = headers ? (headers.Expect ?? headers.expect) === "100-continue" : false;
          let agent = isSSL ? config2.httpsAgent : config2.httpAgent;
          if (expectContinue && !this.externalAgent) {
            agent = new (isSSL ? node_https.Agent : hAgent)({
              keepAlive: false,
              maxSockets: Infinity
            });
          }
          socketWarningTimeoutId = timing.setTimeout(() => {
            this.socketWarningTimestamp = _NodeHttpHandler.checkSocketUsage(agent, this.socketWarningTimestamp, config2.logger);
          }, config2.socketAcquisitionWarningTimeout ?? (config2.requestTimeout ?? 2e3) + (config2.connectionTimeout ?? 1e3));
          const queryString = request4.query ? protocols.buildQueryString(request4.query) : "";
          let auth = void 0;
          if (request4.username != null || request4.password != null) {
            const username = request4.username ?? "";
            const password = request4.password ?? "";
            auth = `${username}:${password}`;
          }
          let path47 = request4.path;
          if (queryString) {
            path47 += `?${queryString}`;
          }
          if (request4.fragment) {
            path47 += `#${request4.fragment}`;
          }
          let hostname = request4.hostname ?? "";
          if (hostname[0] === "[" && hostname.endsWith("]")) {
            hostname = request4.hostname.slice(1, -1);
          } else {
            hostname = request4.hostname;
          }
          const nodeHttpsOptions = {
            headers: request4.headers,
            host: hostname,
            method: request4.method,
            path: path47,
            port: request4.port,
            agent,
            auth
          };
          const requestFunc = isSSL ? node_https.request : hRequest;
          const req = requestFunc(nodeHttpsOptions, (res) => {
            const httpResponse = new protocols.HttpResponse({
              statusCode: res.statusCode || -1,
              reason: res.statusMessage,
              headers: getTransformedHeaders(res.headers),
              body: res
            });
            resolve13({ response: httpResponse });
          });
          req.on("error", (err) => {
            if (NODEJS_TIMEOUT_ERROR_CODES3.includes(err.code)) {
              reject(Object.assign(err, { name: "TimeoutError" }));
            } else {
              reject(err);
            }
          });
          if (abortSignal) {
            const onAbort = /* @__PURE__ */ __name(() => {
              req.destroy();
              const abortError = buildAbortError(abortSignal);
              reject(abortError);
            }, "onAbort");
            if (typeof abortSignal.addEventListener === "function") {
              const signal = abortSignal;
              signal.addEventListener("abort", onAbort, { once: true });
              req.once("close", () => signal.removeEventListener("abort", onAbort));
            } else {
              abortSignal.onabort = onAbort;
            }
          }
          const effectiveRequestTimeout = requestTimeout ?? config2.requestTimeout;
          connectionTimeoutId = setConnectionTimeout(req, reject, config2.connectionTimeout);
          requestTimeoutId = setRequestTimeout(req, reject, effectiveRequestTimeout, config2.throwOnRequestTimeout, config2.logger ?? console);
          socketTimeoutId = setSocketTimeout(req, reject, config2.socketTimeout);
          const httpAgent = nodeHttpsOptions.agent;
          if (typeof httpAgent === "object" && "keepAlive" in httpAgent) {
            keepAliveTimeoutId = setSocketKeepAlive(req, {
              keepAlive: httpAgent.keepAlive,
              keepAliveMsecs: httpAgent.keepAliveMsecs
            });
          }
          writeRequestBodyPromise = writeRequestBody(req, request4, effectiveRequestTimeout, this.externalAgent).catch((e32) => {
            clearTimeouts();
            return _reject(e32);
          });
        });
      }
      updateHttpClientConfig(key, value) {
        this.config = void 0;
        this.configProvider = this.configProvider.then((config2) => {
          return {
            ...config2,
            [key]: value
          };
        });
      }
      httpHandlerConfigs() {
        return this.config ?? {};
      }
      resolveDefaultConfig(options) {
        const { requestTimeout, connectionTimeout, socketTimeout, socketAcquisitionWarningTimeout, httpAgent, httpsAgent, throwOnRequestTimeout, logger: logger5 } = options || {};
        const keepAlive = true;
        const maxSockets = 50;
        return {
          connectionTimeout,
          requestTimeout,
          socketTimeout,
          socketAcquisitionWarningTimeout,
          throwOnRequestTimeout,
          httpAgentProvider: /* @__PURE__ */ __name(async () => {
            const { Agent, request: request4 } = await import("node:http");
            hRequest = request4;
            hAgent = Agent;
            if (httpAgent instanceof hAgent || typeof httpAgent?.destroy === "function") {
              this.externalAgent = true;
              return httpAgent;
            }
            return new hAgent({ keepAlive, maxSockets, ...httpAgent });
          }, "httpAgentProvider"),
          httpsAgent: (() => {
            if (httpsAgent instanceof node_https.Agent || typeof httpsAgent?.destroy === "function") {
              this.externalAgent = true;
              return httpsAgent;
            }
            return new node_https.Agent({ keepAlive, maxSockets, ...httpsAgent });
          })(),
          logger: logger5
        };
      }
    };
    var ids = new Uint16Array(1);
    var ClientHttp2SessionRef = class {
      static {
        __name(this, "ClientHttp2SessionRef");
      }
      id = ids[0]++;
      total = 0;
      max = 0;
      session;
      refs = 0;
      constructor(session) {
        session.unref();
        this.session = session;
      }
      retain() {
        if (this.session.destroyed) {
          throw new Error("@smithy/node-http-handler - cannot acquire reference to destroyed session.");
        }
        this.refs += 1;
        this.total += 1;
        this.max = Math.max(this.refs, this.max);
        this.session.ref();
      }
      free() {
        if (this.session.destroyed) {
          return;
        }
        this.refs -= 1;
        if (this.refs === 0) {
          this.session.unref();
        }
        if (this.refs < 0) {
          throw new Error("@smithy/node-http-handler - ClientHttp2Session refcount at zero, cannot decrement.");
        }
      }
      deref() {
        return this.session;
      }
      close() {
        if (!this.session.closed) {
          this.session.close();
        }
      }
      destroy() {
        this.refs = 0;
        if (!this.session.destroyed) {
          this.session.destroy();
        }
      }
      useCount() {
        return this.refs;
      }
    };
    var NodeHttp2ConnectionPool = class {
      static {
        __name(this, "NodeHttp2ConnectionPool");
      }
      sessions = [];
      maxConcurrency = 0;
      constructor(sessions) {
        this.sessions = (sessions ?? []).map((session) => new ClientHttp2SessionRef(session));
      }
      poll() {
        let cleanup = false;
        for (const session of this.sessions) {
          if (session.deref().destroyed) {
            cleanup = true;
            continue;
          }
          if (!this.maxConcurrency || session.useCount() < this.maxConcurrency) {
            return session;
          }
        }
        if (cleanup) {
          for (const session of this.sessions) {
            if (session.deref().destroyed) {
              this.remove(session);
            }
          }
        }
      }
      offerLast(ref) {
        this.sessions.push(ref);
      }
      remove(ref) {
        const ix = this.sessions.indexOf(ref);
        if (ix > -1) {
          this.sessions.splice(ix, 1);
        }
      }
      [Symbol.iterator]() {
        return this.sessions[Symbol.iterator]();
      }
      setMaxConcurrency(maxConcurrency) {
        this.maxConcurrency = maxConcurrency;
      }
      destroy(ref) {
        this.remove(ref);
        ref.destroy();
      }
    };
    var NodeHttp2ConnectionManager = class {
      static {
        __name(this, "NodeHttp2ConnectionManager");
      }
      config;
      connectOptions;
      connectionPools = /* @__PURE__ */ new Map();
      constructor(config2) {
        this.config = config2;
        if (this.config.maxConcurrency && this.config.maxConcurrency <= 0) {
          throw new RangeError("maxConcurrency must be greater than zero.");
        }
      }
      lease(requestContext, connectionConfiguration) {
        const url = this.getUrlString(requestContext);
        const pool = this.getPool(url);
        if (!this.config.disableConcurrency && !connectionConfiguration.isEventStream) {
          const available = pool.poll();
          if (available) {
            available.retain();
            return available;
          }
        }
        const ref = new ClientHttp2SessionRef(this.connect(url));
        const session = ref.deref();
        if (this.config.maxConcurrency) {
          session.settings({ maxConcurrentStreams: this.config.maxConcurrency }, (err) => {
            if (err) {
              throw new Error("Fail to set maxConcurrentStreams to " + this.config.maxConcurrency + "when creating new session for " + requestContext.destination.toString());
            }
          });
        }
        const graceful = /* @__PURE__ */ __name(() => {
          this.removeFromPoolAndClose(url, ref);
        }, "graceful");
        const ensureDestroyed = /* @__PURE__ */ __name(() => {
          this.removeFromPoolAndCheckedDestroy(url, ref);
        }, "ensureDestroyed");
        session.on("goaway", graceful);
        session.on("error", ensureDestroyed);
        session.on("frameError", ensureDestroyed);
        session.on("close", ensureDestroyed);
        if (connectionConfiguration.requestTimeout) {
          session.setTimeout(connectionConfiguration.requestTimeout, ensureDestroyed);
        }
        pool.offerLast(ref);
        ref.retain();
        return ref;
      }
      release(_requestContext, ref) {
        ref.free();
      }
      createIsolatedSession(requestContext, connectionConfiguration) {
        const url = this.getUrlString(requestContext);
        const ref = new ClientHttp2SessionRef(this.connect(url));
        const session = ref.deref();
        session.settings({ maxConcurrentStreams: 1 });
        const ensureDestroyed = /* @__PURE__ */ __name(() => {
          ref.destroy();
        }, "ensureDestroyed");
        session.on("error", ensureDestroyed);
        session.on("frameError", ensureDestroyed);
        session.on("close", ensureDestroyed);
        if (connectionConfiguration.requestTimeout) {
          session.setTimeout(connectionConfiguration.requestTimeout, ensureDestroyed);
        }
        ref.retain();
        return ref;
      }
      destroy() {
        for (const [url, connectionPool] of this.connectionPools) {
          for (const session of [...connectionPool]) {
            session.destroy();
          }
          this.connectionPools.delete(url);
        }
      }
      setMaxConcurrentStreams(maxConcurrentStreams) {
        if (maxConcurrentStreams && maxConcurrentStreams <= 0) {
          throw new RangeError("maxConcurrentStreams must be greater than zero.");
        }
        this.config.maxConcurrency = maxConcurrentStreams;
        for (const pool of this.connectionPools.values()) {
          pool.setMaxConcurrency(maxConcurrentStreams);
        }
      }
      setDisableConcurrentStreams(disableConcurrentStreams) {
        this.config.disableConcurrency = disableConcurrentStreams;
      }
      setNodeHttp2ConnectOptions(nodeHttp2ConnectOptions) {
        this.connectOptions = nodeHttp2ConnectOptions;
      }
      debug() {
        const pools = {};
        for (const [url, pool] of this.connectionPools) {
          const sessions = [];
          for (const ref of pool) {
            sessions.push({
              id: ref.id,
              active: ref.useCount(),
              maxConcurrent: ref.max,
              totalRequests: ref.total
            });
          }
          pools[url] = { sessions };
        }
        return pools;
      }
      removeFromPoolAndClose(authority, ref) {
        this.connectionPools.get(authority)?.remove(ref);
        ref.close();
      }
      removeFromPoolAndCheckedDestroy(authority, ref) {
        this.connectionPools.get(authority)?.remove(ref);
        ref.destroy();
      }
      getPool(url) {
        if (!this.connectionPools.has(url)) {
          const pool = new NodeHttp2ConnectionPool();
          if (this.config.maxConcurrency) {
            pool.setMaxConcurrency(this.config.maxConcurrency);
          }
          this.connectionPools.set(url, pool);
        }
        return this.connectionPools.get(url);
      }
      getUrlString(request4) {
        return request4.destination.toString();
      }
      connect(url) {
        return this.connectOptions === void 0 ? http2.connect(url) : http2.connect(url, this.connectOptions);
      }
    };
    var NodeHttp2Handler = class _NodeHttp2Handler {
      static {
        __name(this, "NodeHttp2Handler");
      }
      config;
      configProvider;
      metadata = { handlerProtocol: "h2" };
      connectionManager = new NodeHttp2ConnectionManager({});
      static create(instanceOrOptions) {
        if (typeof instanceOrOptions?.handle === "function") {
          return instanceOrOptions;
        }
        return new _NodeHttp2Handler(instanceOrOptions);
      }
      constructor(options) {
        this.configProvider = new Promise((resolve13, reject) => {
          if (typeof options === "function") {
            options().then((opts) => {
              resolve13(opts || {});
            }).catch(reject);
          } else {
            resolve13(options || {});
          }
        });
      }
      destroy() {
        this.connectionManager.destroy();
      }
      async handle(request4, { abortSignal, requestTimeout, isEventStream } = {}) {
        if (!this.config) {
          this.config = await this.configProvider;
          const { disableConcurrentStreams: disableConcurrentStreams2, maxConcurrentStreams, nodeHttp2ConnectOptions } = this.config;
          this.connectionManager.setDisableConcurrentStreams(disableConcurrentStreams2 ?? false);
          if (maxConcurrentStreams) {
            this.connectionManager.setMaxConcurrentStreams(maxConcurrentStreams);
          }
          if (nodeHttp2ConnectOptions) {
            this.connectionManager.setNodeHttp2ConnectOptions(nodeHttp2ConnectOptions);
          }
        }
        const { requestTimeout: configRequestTimeout, disableConcurrentStreams } = this.config;
        const useIsolatedSession = disableConcurrentStreams || isEventStream;
        const effectiveRequestTimeout = requestTimeout ?? configRequestTimeout;
        return new Promise((_resolve, _reject) => {
          let fulfilled = false;
          let writeRequestBodyPromise = void 0;
          const resolve13 = /* @__PURE__ */ __name(async (arg) => {
            await writeRequestBodyPromise;
            _resolve(arg);
          }, "resolve");
          const reject = /* @__PURE__ */ __name(async (arg) => {
            await writeRequestBodyPromise;
            _reject(arg);
          }, "reject");
          if (abortSignal?.aborted) {
            fulfilled = true;
            const abortError = buildAbortError(abortSignal);
            reject(abortError);
            return;
          }
          const { hostname, method, port, protocol, query } = request4;
          let auth = "";
          if (request4.username != null || request4.password != null) {
            const username = request4.username ?? "";
            const password = request4.password ?? "";
            auth = `${username}:${password}@`;
          }
          const authority = `${protocol}//${auth}${hostname}${port ? `:${port}` : ""}`;
          const requestContext = { destination: new URL(authority) };
          const connectConfig = {
            requestTimeout: this.config?.sessionTimeout,
            isEventStream
          };
          const ref = useIsolatedSession ? this.connectionManager.createIsolatedSession(requestContext, connectConfig) : this.connectionManager.lease(requestContext, connectConfig);
          const session = ref.deref();
          const rejectWithDestroy = /* @__PURE__ */ __name((err) => {
            if (useIsolatedSession) {
              ref.destroy();
            }
            fulfilled = true;
            reject(err);
          }, "rejectWithDestroy");
          const queryString = query ? protocols.buildQueryString(query) : "";
          let path47 = request4.path;
          if (queryString) {
            path47 += `?${queryString}`;
          }
          if (request4.fragment) {
            path47 += `#${request4.fragment}`;
          }
          const clientHttp2Stream = session.request({
            ...request4.headers,
            [http2.constants.HTTP2_HEADER_PATH]: path47,
            [http2.constants.HTTP2_HEADER_METHOD]: method
          });
          if (effectiveRequestTimeout) {
            clientHttp2Stream.setTimeout(effectiveRequestTimeout, () => {
              clientHttp2Stream.close();
              const timeoutError = new Error(`Stream timed out because of no activity for ${effectiveRequestTimeout} ms`);
              timeoutError.name = "TimeoutError";
              rejectWithDestroy(timeoutError);
            });
          }
          if (abortSignal) {
            const onAbort = /* @__PURE__ */ __name(() => {
              clientHttp2Stream.close();
              const abortError = buildAbortError(abortSignal);
              rejectWithDestroy(abortError);
            }, "onAbort");
            if (typeof abortSignal.addEventListener === "function") {
              const signal = abortSignal;
              signal.addEventListener("abort", onAbort, { once: true });
              clientHttp2Stream.once("close", () => signal.removeEventListener("abort", onAbort));
            } else {
              abortSignal.onabort = onAbort;
            }
          }
          clientHttp2Stream.on("frameError", (type, code, id) => {
            rejectWithDestroy(new Error(`Frame type id ${type} in stream id ${id} has failed with code ${code}.`));
          });
          clientHttp2Stream.on("error", rejectWithDestroy);
          clientHttp2Stream.on("aborted", () => {
            rejectWithDestroy(new Error(`HTTP/2 stream is abnormally aborted in mid-communication with result code ${clientHttp2Stream.rstCode}.`));
          });
          clientHttp2Stream.on("response", (headers) => {
            const httpResponse = new protocols.HttpResponse({
              statusCode: headers[":status"] ?? -1,
              headers: getTransformedHeaders(headers),
              body: clientHttp2Stream
            });
            fulfilled = true;
            resolve13({ response: httpResponse });
            if (useIsolatedSession) {
              session.close();
            }
          });
          clientHttp2Stream.on("close", () => {
            if (useIsolatedSession) {
              ref.destroy();
            } else {
              this.connectionManager.release(requestContext, ref);
            }
            if (!fulfilled) {
              rejectWithDestroy(new Error("Unexpected error: http2 request did not get a response"));
            }
          });
          writeRequestBodyPromise = writeRequestBody(clientHttp2Stream, request4, effectiveRequestTimeout);
        });
      }
      updateHttpClientConfig(key, value) {
        this.config = void 0;
        this.configProvider = this.configProvider.then((config2) => {
          return {
            ...config2,
            [key]: value
          };
        });
      }
      httpHandlerConfigs() {
        return this.config ?? {};
      }
    };
    var Collector8 = class extends node_stream.Writable {
      static {
        __name(this, "Collector");
      }
      bufferedBytes = [];
      _write(chunk, encoding, callback) {
        this.bufferedBytes.push(chunk);
        callback();
      }
    };
    var streamCollector42 = /* @__PURE__ */ __name((stream) => {
      if (isReadableStreamInstance6(stream)) {
        return collectReadableStream6(stream);
      }
      return new Promise((resolve13, reject) => {
        const collector = new Collector8();
        stream.pipe(collector);
        stream.on("error", (err) => {
          collector.end();
          reject(err);
        });
        collector.on("error", reject);
        collector.on("finish", function() {
          const bytes = new Uint8Array(Buffer.concat(this.bufferedBytes));
          resolve13(bytes);
        });
      });
    }, "streamCollector");
    var isReadableStreamInstance6 = /* @__PURE__ */ __name((stream) => typeof ReadableStream === "function" && stream instanceof ReadableStream, "isReadableStreamInstance");
    async function collectReadableStream6(stream) {
      const chunks2 = [];
      const reader = stream.getReader();
      let isDone = false;
      let length = 0;
      while (!isDone) {
        const { done, value } = await reader.read();
        if (value) {
          chunks2.push(value);
          length += value.length;
        }
        isDone = done;
      }
      const collected = new Uint8Array(length);
      let offset = 0;
      for (const chunk of chunks2) {
        collected.set(chunk, offset);
        offset += chunk.length;
      }
      return collected;
    }
    __name(collectReadableStream6, "collectReadableStream");
    exports2.DEFAULT_REQUEST_TIMEOUT = DEFAULT_REQUEST_TIMEOUT;
    exports2.NodeHttp2Handler = NodeHttp2Handler;
    exports2.NodeHttpHandler = NodeHttpHandler;
    exports2.streamCollector = streamCollector42;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/checkUrl.js
var require_checkUrl6 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/checkUrl.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.checkUrl = void 0;
    var config_1 = (init_config4(), __toCommonJS(config_exports));
    var ECS_CONTAINER_HOST = "169.254.170.2";
    var EKS_CONTAINER_HOST_IPv4 = "169.254.170.23";
    var EKS_CONTAINER_HOST_IPv6 = "[fd00:ec2::23]";
    var checkUrl = /* @__PURE__ */ __name((url, logger5) => {
      if (url.protocol === "https:") {
        return;
      }
      if (url.hostname === ECS_CONTAINER_HOST || url.hostname === EKS_CONTAINER_HOST_IPv4 || url.hostname === EKS_CONTAINER_HOST_IPv6) {
        return;
      }
      if (url.hostname.includes("[")) {
        if (url.hostname === "[::1]" || url.hostname === "[0000:0000:0000:0000:0000:0000:0000:0001]") {
          return;
        }
      } else {
        if (url.hostname === "localhost") {
          return;
        }
        const ipComponents = url.hostname.split(".");
        const inRange = /* @__PURE__ */ __name((component) => {
          const num = parseInt(component, 10);
          return 0 <= num && num <= 255;
        }, "inRange");
        if (ipComponents[0] === "127" && inRange(ipComponents[1]) && inRange(ipComponents[2]) && inRange(ipComponents[3]) && ipComponents.length === 4) {
          return;
        }
      }
      throw new config_1.CredentialsProviderError(`URL not accepted. It must either be HTTPS or match one of the following:
  - loopback CIDR 127.0.0.0/8 or [::1/128]
  - ECS container host 169.254.170.2
  - EKS container host 169.254.170.23 or [fd00:ec2::23]`, { logger: logger5 });
    }, "checkUrl");
    exports2.checkUrl = checkUrl;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/requestHelpers.js
var require_requestHelpers6 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/requestHelpers.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createGetRequest = createGetRequest;
    exports2.getCredentials = getCredentials;
    var config_1 = (init_config4(), __toCommonJS(config_exports));
    var protocols_1 = (init_protocols11(), __toCommonJS(protocols_exports8));
    var serde_1 = (init_serde4(), __toCommonJS(serde_exports2));
    var serde_2 = (init_serde4(), __toCommonJS(serde_exports2));
    function createGetRequest(url) {
      return new protocols_1.HttpRequest({
        protocol: url.protocol,
        hostname: url.hostname,
        port: Number(url.port),
        path: url.pathname,
        query: Array.from(url.searchParams.entries()).reduce((acc, [k32, v]) => {
          acc[k32] = v;
          return acc;
        }, {}),
        fragment: url.hash
      });
    }
    __name(createGetRequest, "createGetRequest");
    async function getCredentials(response, logger5) {
      const stream = (0, serde_2.sdkStreamMixin)(response.body);
      const str = await stream.transformToString();
      if (response.statusCode === 200) {
        const parsed = JSON.parse(str);
        if (typeof parsed.AccessKeyId !== "string" || typeof parsed.SecretAccessKey !== "string" || typeof parsed.Token !== "string" || typeof parsed.Expiration !== "string") {
          throw new config_1.CredentialsProviderError("HTTP credential provider response not of the required format, an object matching: { AccessKeyId: string, SecretAccessKey: string, Token: string, Expiration: string(rfc3339) }", { logger: logger5 });
        }
        return {
          accessKeyId: parsed.AccessKeyId,
          secretAccessKey: parsed.SecretAccessKey,
          sessionToken: parsed.Token,
          expiration: (0, serde_1.parseRfc3339DateTime)(parsed.Expiration)
        };
      }
      if (response.statusCode >= 400 && response.statusCode < 500) {
        let parsedBody = {};
        try {
          parsedBody = JSON.parse(str);
        } catch (e32) {
        }
        throw Object.assign(new config_1.CredentialsProviderError(`Server responded with status: ${response.statusCode}`, { logger: logger5 }), {
          Code: parsedBody.Code,
          Message: parsedBody.Message
        });
      }
      throw new config_1.CredentialsProviderError(`Server responded with status: ${response.statusCode}`, { logger: logger5 });
    }
    __name(getCredentials, "getCredentials");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/retry-wrapper.js
var require_retry_wrapper6 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/retry-wrapper.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.retryWrapper = void 0;
    var retryWrapper = /* @__PURE__ */ __name((toRetry, maxRetries, delayMs) => {
      return async () => {
        for (let i32 = 0; i32 < maxRetries; ++i32) {
          try {
            return await toRetry();
          } catch (e32) {
            await new Promise((resolve13) => setTimeout(resolve13, delayMs));
          }
        }
        return await toRetry();
      };
    }, "retryWrapper");
    exports2.retryWrapper = retryWrapper;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/fromHttp.js
var require_fromHttp6 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/fromHttp.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromHttp = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var client_1 = (init_client13(), __toCommonJS(client_exports10));
    var config_1 = (init_config4(), __toCommonJS(config_exports));
    var node_http_handler_1 = require_dist_cjs144();
    var promises_1 = tslib_1.__importDefault(require("node:fs/promises"));
    var checkUrl_1 = require_checkUrl6();
    var requestHelpers_1 = require_requestHelpers6();
    var retry_wrapper_1 = require_retry_wrapper6();
    var AWS_CONTAINER_CREDENTIALS_RELATIVE_URI = "AWS_CONTAINER_CREDENTIALS_RELATIVE_URI";
    var DEFAULT_LINK_LOCAL_HOST = "http://169.254.170.2";
    var AWS_CONTAINER_CREDENTIALS_FULL_URI = "AWS_CONTAINER_CREDENTIALS_FULL_URI";
    var AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE = "AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE";
    var AWS_CONTAINER_AUTHORIZATION_TOKEN = "AWS_CONTAINER_AUTHORIZATION_TOKEN";
    var fromHttp = /* @__PURE__ */ __name((options = {}) => {
      options.logger?.debug("@aws-sdk/credential-provider-http - fromHttp");
      let host;
      const relative5 = options.awsContainerCredentialsRelativeUri ?? process.env[AWS_CONTAINER_CREDENTIALS_RELATIVE_URI];
      const full = options.awsContainerCredentialsFullUri ?? process.env[AWS_CONTAINER_CREDENTIALS_FULL_URI];
      const token = options.awsContainerAuthorizationToken ?? process.env[AWS_CONTAINER_AUTHORIZATION_TOKEN];
      const tokenFile = options.awsContainerAuthorizationTokenFile ?? process.env[AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE];
      const warn2 = options.logger?.constructor?.name === "NoOpLogger" || !options.logger?.warn ? console.warn : options.logger.warn.bind(options.logger);
      if (relative5 && full) {
        warn2("@aws-sdk/credential-provider-http: you have set both awsContainerCredentialsRelativeUri and awsContainerCredentialsFullUri.");
        warn2("awsContainerCredentialsFullUri will take precedence.");
      }
      if (token && tokenFile) {
        warn2("@aws-sdk/credential-provider-http: you have set both awsContainerAuthorizationToken and awsContainerAuthorizationTokenFile.");
        warn2("awsContainerAuthorizationToken will take precedence.");
      }
      if (full) {
        host = full;
      } else if (relative5) {
        host = `${DEFAULT_LINK_LOCAL_HOST}${relative5}`;
      } else {
        throw new config_1.CredentialsProviderError(`No HTTP credential provider host provided.
Set AWS_CONTAINER_CREDENTIALS_FULL_URI or AWS_CONTAINER_CREDENTIALS_RELATIVE_URI.`, { logger: options.logger });
      }
      const url = new URL(host);
      (0, checkUrl_1.checkUrl)(url, options.logger);
      const requestHandler = node_http_handler_1.NodeHttpHandler.create({
        requestTimeout: options.timeout ?? 1e3,
        connectionTimeout: options.timeout ?? 1e3
      });
      return (0, retry_wrapper_1.retryWrapper)(async () => {
        const request4 = (0, requestHelpers_1.createGetRequest)(url);
        if (token) {
          request4.headers.Authorization = token;
        } else if (tokenFile) {
          request4.headers.Authorization = (await promises_1.default.readFile(tokenFile)).toString();
        }
        try {
          const result2 = await requestHandler.handle(request4);
          return (0, requestHelpers_1.getCredentials)(result2.response).then((creds) => (0, client_1.setCredentialFeature)(creds, "CREDENTIALS_HTTP", "z"));
        } catch (e32) {
          throw new config_1.CredentialsProviderError(String(e32), { logger: options.logger });
        }
      }, options.maxRetries ?? 3, options.timeout ?? 1e3);
    }, "fromHttp");
    exports2.fromHttp = fromHttp;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-http/dist-cjs/index.js
var require_dist_cjs145 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-http/dist-cjs/index.js"(exports2) {
    "use strict";
    var fromHttp = require_fromHttp6();
    exports2.fromHttp = fromHttp.fromHttp;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption19(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "sso-oauth",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption19(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var defaultSSOOIDCHttpAuthSchemeParametersProvider3, defaultSSOOIDCHttpAuthSchemeProvider3, resolveHttpAuthSchemeConfig19;
var init_httpAuthSchemeProvider19 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes9();
    init_client12();
    defaultSSOOIDCHttpAuthSchemeParametersProvider3 = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: getSmithyContext26(context).operation,
        region: await normalizeProvider22(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultSSOOIDCHttpAuthSchemeParametersProvider");
    __name(createAwsAuthSigv4HttpAuthOption19, "createAwsAuthSigv4HttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption19, "createSmithyApiNoAuthHttpAuthOption");
    defaultSSOOIDCHttpAuthSchemeProvider3 = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "CreateToken": {
          options.push(createSmithyApiNoAuthHttpAuthOption19(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption19(authParameters));
        }
      }
      return options;
    }, "defaultSSOOIDCHttpAuthSchemeProvider");
    resolveHttpAuthSchemeConfig19 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveAwsSdkSigV4Config7(config2);
      return Object.assign(config_0, {
        authSchemePreference: normalizeProvider22(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/endpoint/EndpointParameters.js
var resolveClientEndpointParameters19, commonParams19;
var init_EndpointParameters19 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters19 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "sso-oauth"
      });
    }, "resolveClientEndpointParameters");
    commonParams19 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/package.json
var package_default7;
var init_package7 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/package.json"() {
    package_default7 = {
      name: "@aws-sdk/nested-clients",
      version: "3.997.9",
      description: "Nested clients for AWS SDK packages.",
      main: "./dist-cjs/index.js",
      module: "./dist-es/index.js",
      types: "./dist-types/index.d.ts",
      scripts: {
        build: "yarn lint && concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline nested-clients",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        lint: "node ../../scripts/validation/submodules-linter.js --pkg nested-clients",
        test: "yarn g:vitest run",
        "test:watch": "yarn g:vitest watch"
      },
      engines: {
        node: ">=20.0.0"
      },
      sideEffects: false,
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      dependencies: {
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.11",
        "@aws-sdk/signature-v4-multi-region": "^3.996.27",
        "@aws-sdk/types": "^3.973.8",
        "@smithy/core": "^3.24.2",
        "@smithy/fetch-http-handler": "^5.4.2",
        "@smithy/node-http-handler": "^4.7.2",
        "@smithy/types": "^4.14.1",
        tslib: "^2.6.2"
      },
      devDependencies: {
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "./cognito-identity.d.ts",
        "./cognito-identity.js",
        "./signin.d.ts",
        "./signin.js",
        "./sso-oidc.d.ts",
        "./sso-oidc.js",
        "./sso.d.ts",
        "./sso.js",
        "./sts.d.ts",
        "./sts.js",
        "dist-*/**"
      ],
      browser: {
        "./dist-es/submodules/cognito-identity/runtimeConfig": "./dist-es/submodules/cognito-identity/runtimeConfig.browser",
        "./dist-es/submodules/signin/runtimeConfig": "./dist-es/submodules/signin/runtimeConfig.browser",
        "./dist-es/submodules/sso-oidc/runtimeConfig": "./dist-es/submodules/sso-oidc/runtimeConfig.browser",
        "./dist-es/submodules/sso/runtimeConfig": "./dist-es/submodules/sso/runtimeConfig.browser",
        "./dist-es/submodules/sts/runtimeConfig": "./dist-es/submodules/sts/runtimeConfig.browser"
      },
      "react-native": {},
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/packages/nested-clients",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "packages/nested-clients"
      },
      exports: {
        "./package.json": "./package.json",
        "./sso-oidc": {
          types: "./dist-types/submodules/sso-oidc/index.d.ts",
          module: "./dist-es/submodules/sso-oidc/index.js",
          node: "./dist-cjs/submodules/sso-oidc/index.js",
          import: "./dist-es/submodules/sso-oidc/index.js",
          require: "./dist-cjs/submodules/sso-oidc/index.js"
        },
        "./sts": {
          types: "./dist-types/submodules/sts/index.d.ts",
          module: "./dist-es/submodules/sts/index.js",
          node: "./dist-cjs/submodules/sts/index.js",
          import: "./dist-es/submodules/sts/index.js",
          require: "./dist-cjs/submodules/sts/index.js"
        },
        "./signin": {
          types: "./dist-types/submodules/signin/index.d.ts",
          module: "./dist-es/submodules/signin/index.js",
          node: "./dist-cjs/submodules/signin/index.js",
          import: "./dist-es/submodules/signin/index.js",
          require: "./dist-cjs/submodules/signin/index.js"
        },
        "./cognito-identity": {
          types: "./dist-types/submodules/cognito-identity/index.d.ts",
          module: "./dist-es/submodules/cognito-identity/index.js",
          node: "./dist-cjs/submodules/cognito-identity/index.js",
          import: "./dist-es/submodules/cognito-identity/index.js",
          require: "./dist-cjs/submodules/cognito-identity/index.js"
        },
        "./sso": {
          types: "./dist-types/submodules/sso/index.d.ts",
          module: "./dist-es/submodules/sso/index.js",
          node: "./dist-cjs/submodules/sso/index.js",
          import: "./dist-es/submodules/sso/index.js",
          require: "./dist-cjs/submodules/sso/index.js"
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/cbor/cbor-types.js
function alloc2(size) {
  return typeof Buffer !== "undefined" ? Buffer.alloc(size) : new Uint8Array(size);
}
function tag2(data3) {
  data3[tagSymbol2] = true;
  return data3;
}
var majorUint642, majorNegativeInt642, majorUnstructuredByteString2, majorUtf8String2, majorList2, majorMap2, majorTag2, majorSpecial2, specialFalse2, specialTrue2, specialNull2, specialUndefined2, extendedOneByte2, extendedFloat162, extendedFloat322, extendedFloat642, minorIndefinite2, tagSymbol2;
var init_cbor_types2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/cbor/cbor-types.js"() {
    majorUint642 = 0;
    majorNegativeInt642 = 1;
    majorUnstructuredByteString2 = 2;
    majorUtf8String2 = 3;
    majorList2 = 4;
    majorMap2 = 5;
    majorTag2 = 6;
    majorSpecial2 = 7;
    specialFalse2 = 20;
    specialTrue2 = 21;
    specialNull2 = 22;
    specialUndefined2 = 23;
    extendedOneByte2 = 24;
    extendedFloat162 = 25;
    extendedFloat322 = 26;
    extendedFloat642 = 27;
    minorIndefinite2 = 31;
    __name(alloc2, "alloc");
    tagSymbol2 = /* @__PURE__ */ Symbol("@smithy/core/cbor::tagSymbol");
    __name(tag2, "tag");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/cbor/cbor-decode.js
function setPayload2(bytes) {
  payload2 = bytes;
  dataView3 = new DataView(payload2.buffer, payload2.byteOffset, payload2.byteLength);
}
function decode2(at, to) {
  if (at >= to) {
    throw new Error("unexpected end of (decode) payload.");
  }
  const major6 = (payload2[at] & 224) >> 5;
  const minor = payload2[at] & 31;
  switch (major6) {
    case majorUint642:
    case majorNegativeInt642:
    case majorTag2:
      let unsignedInt;
      let offset;
      if (minor < 24) {
        unsignedInt = minor;
        offset = 1;
      } else {
        switch (minor) {
          case extendedOneByte2:
          case extendedFloat162:
          case extendedFloat322:
          case extendedFloat642:
            const countLength = minorValueToArgumentLength2[minor];
            const countOffset = countLength + 1;
            offset = countOffset;
            if (to - at < countOffset) {
              throw new Error(`countLength ${countLength} greater than remaining buf len.`);
            }
            const countIndex = at + 1;
            if (countLength === 1) {
              unsignedInt = payload2[countIndex];
            } else if (countLength === 2) {
              unsignedInt = dataView3.getUint16(countIndex);
            } else if (countLength === 4) {
              unsignedInt = dataView3.getUint32(countIndex);
            } else {
              unsignedInt = dataView3.getBigUint64(countIndex);
            }
            break;
          default:
            throw new Error(`unexpected minor value ${minor}.`);
        }
      }
      if (major6 === majorUint642) {
        _offset2 = offset;
        return castBigInt2(unsignedInt);
      } else if (major6 === majorNegativeInt642) {
        let negativeInt;
        if (typeof unsignedInt === "bigint") {
          negativeInt = BigInt(-1) - unsignedInt;
        } else {
          negativeInt = -1 - unsignedInt;
        }
        _offset2 = offset;
        return castBigInt2(negativeInt);
      } else {
        if (minor === 2 || minor === 3) {
          const length = decodeCount2(at + offset, to);
          let b32 = BigInt(0);
          const start = at + offset + _offset2;
          for (let i32 = start; i32 < start + length; ++i32) {
            b32 = b32 << BigInt(8) | BigInt(payload2[i32]);
          }
          _offset2 = offset + _offset2 + length;
          return minor === 3 ? -b32 - BigInt(1) : b32;
        } else if (minor === 4) {
          const decimalFraction = decode2(at + offset, to);
          const [exponent, mantissa] = decimalFraction;
          const normalizer = mantissa < 0 ? -1 : 1;
          const mantissaStr = "0".repeat(Math.abs(exponent) + 1) + String(BigInt(normalizer) * BigInt(mantissa));
          let numericString;
          const sign = mantissa < 0 ? "-" : "";
          numericString = exponent === 0 ? mantissaStr : mantissaStr.slice(0, mantissaStr.length + exponent) + "." + mantissaStr.slice(exponent);
          numericString = numericString.replace(/^0+/g, "");
          if (numericString === "") {
            numericString = "0";
          }
          if (numericString[0] === ".") {
            numericString = "0" + numericString;
          }
          numericString = sign + numericString;
          _offset2 = offset + _offset2;
          return nv3(numericString);
        } else {
          const value = decode2(at + offset, to);
          const valueOffset = _offset2;
          _offset2 = offset + valueOffset;
          return tag2({ tag: castBigInt2(unsignedInt), value });
        }
      }
    case majorUtf8String2:
    case majorMap2:
    case majorList2:
    case majorUnstructuredByteString2:
      if (minor === minorIndefinite2) {
        switch (major6) {
          case majorUtf8String2:
            return decodeUtf8StringIndefinite2(at, to);
          case majorMap2:
            return decodeMapIndefinite2(at, to);
          case majorList2:
            return decodeListIndefinite2(at, to);
          case majorUnstructuredByteString2:
            return decodeUnstructuredByteStringIndefinite2(at, to);
        }
      } else {
        switch (major6) {
          case majorUtf8String2:
            return decodeUtf8String2(at, to);
          case majorMap2:
            return decodeMap2(at, to);
          case majorList2:
            return decodeList2(at, to);
          case majorUnstructuredByteString2:
            return decodeUnstructuredByteString2(at, to);
        }
      }
    default:
      return decodeSpecial2(at, to);
  }
}
function bytesToUtf82(bytes, at, to) {
  if (USE_BUFFER3 && bytes.constructor?.name === "Buffer") {
    return bytes.toString("utf-8", at, to);
  }
  if (textDecoder2) {
    return textDecoder2.decode(bytes.subarray(at, to));
  }
  return toUtf839(bytes.subarray(at, to));
}
function demote2(bigInteger) {
  const num = Number(bigInteger);
  if (num < Number.MIN_SAFE_INTEGER || Number.MAX_SAFE_INTEGER < num) {
    console.warn(new Error(`@smithy/core/cbor - truncating BigInt(${bigInteger}) to ${num} with loss of precision.`));
  }
  return num;
}
function bytesToFloat162(a32, b32) {
  const sign = a32 >> 7;
  const exponent = (a32 & 124) >> 2;
  const fraction = (a32 & 3) << 8 | b32;
  const scalar = sign === 0 ? 1 : -1;
  let exponentComponent;
  let summation;
  if (exponent === 0) {
    if (fraction === 0) {
      return 0;
    } else {
      exponentComponent = Math.pow(2, 1 - 15);
      summation = 0;
    }
  } else if (exponent === 31) {
    if (fraction === 0) {
      return scalar * Infinity;
    } else {
      return NaN;
    }
  } else {
    exponentComponent = Math.pow(2, exponent - 15);
    summation = 1;
  }
  summation += fraction / 1024;
  return scalar * (exponentComponent * summation);
}
function decodeCount2(at, to) {
  const minor = payload2[at] & 31;
  if (minor < 24) {
    _offset2 = 1;
    return minor;
  }
  if (minor === extendedOneByte2 || minor === extendedFloat162 || minor === extendedFloat322 || minor === extendedFloat642) {
    const countLength = minorValueToArgumentLength2[minor];
    _offset2 = countLength + 1;
    if (to - at < _offset2) {
      throw new Error(`countLength ${countLength} greater than remaining buf len.`);
    }
    const countIndex = at + 1;
    if (countLength === 1) {
      return payload2[countIndex];
    } else if (countLength === 2) {
      return dataView3.getUint16(countIndex);
    } else if (countLength === 4) {
      return dataView3.getUint32(countIndex);
    }
    return demote2(dataView3.getBigUint64(countIndex));
  }
  throw new Error(`unexpected minor value ${minor}.`);
}
function decodeUtf8String2(at, to) {
  const length = decodeCount2(at, to);
  const offset = _offset2;
  at += offset;
  if (to - at < length) {
    throw new Error(`string len ${length} greater than remaining buf len.`);
  }
  const value = bytesToUtf82(payload2, at, at + length);
  _offset2 = offset + length;
  return value;
}
function decodeUtf8StringIndefinite2(at, to) {
  at += 1;
  const vector = [];
  for (const base = at; at < to; ) {
    if (payload2[at] === 255) {
      const data3 = alloc2(vector.length);
      data3.set(vector, 0);
      _offset2 = at - base + 2;
      return bytesToUtf82(data3, 0, data3.length);
    }
    const major6 = (payload2[at] & 224) >> 5;
    const minor = payload2[at] & 31;
    if (major6 !== majorUtf8String2) {
      throw new Error(`unexpected major type ${major6} in indefinite string.`);
    }
    if (minor === minorIndefinite2) {
      throw new Error("nested indefinite string.");
    }
    const bytes = decodeUnstructuredByteString2(at, to);
    const length = _offset2;
    at += length;
    for (let i32 = 0; i32 < bytes.length; ++i32) {
      vector.push(bytes[i32]);
    }
  }
  throw new Error("expected break marker.");
}
function decodeUnstructuredByteString2(at, to) {
  const length = decodeCount2(at, to);
  const offset = _offset2;
  at += offset;
  if (to - at < length) {
    throw new Error(`unstructured byte string len ${length} greater than remaining buf len.`);
  }
  const value = payload2.subarray(at, at + length);
  _offset2 = offset + length;
  return value;
}
function decodeUnstructuredByteStringIndefinite2(at, to) {
  at += 1;
  const vector = [];
  for (const base = at; at < to; ) {
    if (payload2[at] === 255) {
      const data3 = alloc2(vector.length);
      data3.set(vector, 0);
      _offset2 = at - base + 2;
      return data3;
    }
    const major6 = (payload2[at] & 224) >> 5;
    const minor = payload2[at] & 31;
    if (major6 !== majorUnstructuredByteString2) {
      throw new Error(`unexpected major type ${major6} in indefinite string.`);
    }
    if (minor === minorIndefinite2) {
      throw new Error("nested indefinite string.");
    }
    const bytes = decodeUnstructuredByteString2(at, to);
    const length = _offset2;
    at += length;
    for (let i32 = 0; i32 < bytes.length; ++i32) {
      vector.push(bytes[i32]);
    }
  }
  throw new Error("expected break marker.");
}
function decodeList2(at, to) {
  const listDataLength = decodeCount2(at, to);
  const offset = _offset2;
  at += offset;
  const base = at;
  const list3 = Array(listDataLength);
  for (let i32 = 0; i32 < listDataLength; ++i32) {
    const item = decode2(at, to);
    const itemOffset = _offset2;
    list3[i32] = item;
    at += itemOffset;
  }
  _offset2 = offset + (at - base);
  return list3;
}
function decodeListIndefinite2(at, to) {
  at += 1;
  const list3 = [];
  for (const base = at; at < to; ) {
    if (payload2[at] === 255) {
      _offset2 = at - base + 2;
      return list3;
    }
    const item = decode2(at, to);
    const n10 = _offset2;
    at += n10;
    list3.push(item);
  }
  throw new Error("expected break marker.");
}
function decodeMap2(at, to) {
  const mapDataLength = decodeCount2(at, to);
  const offset = _offset2;
  at += offset;
  const base = at;
  const map5 = {};
  for (let i32 = 0; i32 < mapDataLength; ++i32) {
    if (at >= to) {
      throw new Error("unexpected end of map payload.");
    }
    const major6 = (payload2[at] & 224) >> 5;
    if (major6 !== majorUtf8String2) {
      throw new Error(`unexpected major type ${major6} for map key at index ${at}.`);
    }
    const key = decode2(at, to);
    at += _offset2;
    const value = decode2(at, to);
    at += _offset2;
    map5[key] = value;
  }
  _offset2 = offset + (at - base);
  return map5;
}
function decodeMapIndefinite2(at, to) {
  at += 1;
  const base = at;
  const map5 = {};
  for (; at < to; ) {
    if (at >= to) {
      throw new Error("unexpected end of map payload.");
    }
    if (payload2[at] === 255) {
      _offset2 = at - base + 2;
      return map5;
    }
    const major6 = (payload2[at] & 224) >> 5;
    if (major6 !== majorUtf8String2) {
      throw new Error(`unexpected major type ${major6} for map key.`);
    }
    const key = decode2(at, to);
    at += _offset2;
    const value = decode2(at, to);
    at += _offset2;
    map5[key] = value;
  }
  throw new Error("expected break marker.");
}
function decodeSpecial2(at, to) {
  const minor = payload2[at] & 31;
  switch (minor) {
    case specialTrue2:
    case specialFalse2:
      _offset2 = 1;
      return minor === specialTrue2;
    case specialNull2:
      _offset2 = 1;
      return null;
    case specialUndefined2:
      _offset2 = 1;
      return null;
    case extendedFloat162:
      if (to - at < 3) {
        throw new Error("incomplete float16 at end of buf.");
      }
      _offset2 = 3;
      return bytesToFloat162(payload2[at + 1], payload2[at + 2]);
    case extendedFloat322:
      if (to - at < 5) {
        throw new Error("incomplete float32 at end of buf.");
      }
      _offset2 = 5;
      return dataView3.getFloat32(at + 1);
    case extendedFloat642:
      if (to - at < 9) {
        throw new Error("incomplete float64 at end of buf.");
      }
      _offset2 = 9;
      return dataView3.getFloat64(at + 1);
    default:
      throw new Error(`unexpected minor value ${minor}.`);
  }
}
function castBigInt2(bigInt) {
  if (typeof bigInt === "number") {
    return bigInt;
  }
  const num = Number(bigInt);
  if (Number.MIN_SAFE_INTEGER <= num && num <= Number.MAX_SAFE_INTEGER) {
    return num;
  }
  return bigInt;
}
var USE_TEXT_DECODER2, USE_BUFFER3, payload2, dataView3, textDecoder2, _offset2, minorValueToArgumentLength2;
var init_cbor_decode2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/cbor/cbor-decode.js"() {
    init_serde4();
    init_cbor_types2();
    USE_TEXT_DECODER2 = typeof TextDecoder !== "undefined";
    USE_BUFFER3 = typeof Buffer !== "undefined";
    payload2 = alloc2(0);
    dataView3 = new DataView(payload2.buffer, payload2.byteOffset, payload2.byteLength);
    textDecoder2 = USE_TEXT_DECODER2 ? new TextDecoder() : null;
    _offset2 = 0;
    __name(setPayload2, "setPayload");
    __name(decode2, "decode");
    __name(bytesToUtf82, "bytesToUtf8");
    __name(demote2, "demote");
    minorValueToArgumentLength2 = {
      [extendedOneByte2]: 1,
      [extendedFloat162]: 2,
      [extendedFloat322]: 4,
      [extendedFloat642]: 8
    };
    __name(bytesToFloat162, "bytesToFloat16");
    __name(decodeCount2, "decodeCount");
    __name(decodeUtf8String2, "decodeUtf8String");
    __name(decodeUtf8StringIndefinite2, "decodeUtf8StringIndefinite");
    __name(decodeUnstructuredByteString2, "decodeUnstructuredByteString");
    __name(decodeUnstructuredByteStringIndefinite2, "decodeUnstructuredByteStringIndefinite");
    __name(decodeList2, "decodeList");
    __name(decodeListIndefinite2, "decodeListIndefinite");
    __name(decodeMap2, "decodeMap");
    __name(decodeMapIndefinite2, "decodeMapIndefinite");
    __name(decodeSpecial2, "decodeSpecial");
    __name(castBigInt2, "castBigInt");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/cbor/cbor-encode.js
function ensureSpace2(bytes) {
  const remaining = data2.byteLength - cursor2;
  if (remaining < bytes) {
    if (cursor2 < 16e6) {
      resize2(Math.max(data2.byteLength * 4, data2.byteLength + bytes));
    } else {
      resize2(data2.byteLength + bytes + 16e6);
    }
  }
}
function toUint8Array4() {
  const out = alloc2(cursor2);
  out.set(data2.subarray(0, cursor2), 0);
  cursor2 = 0;
  return out;
}
function resize2(size) {
  const old = data2;
  data2 = alloc2(size);
  if (old) {
    if (old.copy) {
      old.copy(data2, 0, 0, old.byteLength);
    } else {
      data2.set(old, 0);
    }
  }
  dataView4 = new DataView(data2.buffer, data2.byteOffset, data2.byteLength);
}
function encodeHeader2(major6, value) {
  if (value < 24) {
    data2[cursor2++] = major6 << 5 | value;
  } else if (value < 1 << 8) {
    data2[cursor2++] = major6 << 5 | 24;
    data2[cursor2++] = value;
  } else if (value < 1 << 16) {
    data2[cursor2++] = major6 << 5 | extendedFloat162;
    dataView4.setUint16(cursor2, value);
    cursor2 += 2;
  } else if (value < 2 ** 32) {
    data2[cursor2++] = major6 << 5 | extendedFloat322;
    dataView4.setUint32(cursor2, value);
    cursor2 += 4;
  } else {
    data2[cursor2++] = major6 << 5 | extendedFloat642;
    dataView4.setBigUint64(cursor2, typeof value === "bigint" ? value : BigInt(value));
    cursor2 += 8;
  }
}
function encode2(_input) {
  const encodeStack = [_input];
  while (encodeStack.length) {
    const input = encodeStack.pop();
    ensureSpace2(typeof input === "string" ? input.length * 4 : 64);
    if (typeof input === "string") {
      if (USE_BUFFER4) {
        encodeHeader2(majorUtf8String2, Buffer.byteLength(input));
        cursor2 += data2.write(input, cursor2);
      } else {
        const bytes = fromUtf825(input);
        encodeHeader2(majorUtf8String2, bytes.byteLength);
        data2.set(bytes, cursor2);
        cursor2 += bytes.byteLength;
      }
      continue;
    } else if (typeof input === "number") {
      if (Number.isInteger(input)) {
        const nonNegative = input >= 0;
        const major6 = nonNegative ? majorUint642 : majorNegativeInt642;
        const value = nonNegative ? input : -input - 1;
        if (value < 24) {
          data2[cursor2++] = major6 << 5 | value;
        } else if (value < 256) {
          data2[cursor2++] = major6 << 5 | 24;
          data2[cursor2++] = value;
        } else if (value < 65536) {
          data2[cursor2++] = major6 << 5 | extendedFloat162;
          data2[cursor2++] = value >> 8;
          data2[cursor2++] = value;
        } else if (value < 4294967296) {
          data2[cursor2++] = major6 << 5 | extendedFloat322;
          dataView4.setUint32(cursor2, value);
          cursor2 += 4;
        } else {
          data2[cursor2++] = major6 << 5 | extendedFloat642;
          dataView4.setBigUint64(cursor2, BigInt(value));
          cursor2 += 8;
        }
        continue;
      }
      data2[cursor2++] = majorSpecial2 << 5 | extendedFloat642;
      dataView4.setFloat64(cursor2, input);
      cursor2 += 8;
      continue;
    } else if (typeof input === "bigint") {
      const nonNegative = input >= 0;
      const major6 = nonNegative ? majorUint642 : majorNegativeInt642;
      const value = nonNegative ? input : -input - BigInt(1);
      const n10 = Number(value);
      if (n10 < 24) {
        data2[cursor2++] = major6 << 5 | n10;
      } else if (n10 < 256) {
        data2[cursor2++] = major6 << 5 | 24;
        data2[cursor2++] = n10;
      } else if (n10 < 65536) {
        data2[cursor2++] = major6 << 5 | extendedFloat162;
        data2[cursor2++] = n10 >> 8;
        data2[cursor2++] = n10 & 255;
      } else if (n10 < 4294967296) {
        data2[cursor2++] = major6 << 5 | extendedFloat322;
        dataView4.setUint32(cursor2, n10);
        cursor2 += 4;
      } else if (value < BigInt("18446744073709551616")) {
        data2[cursor2++] = major6 << 5 | extendedFloat642;
        dataView4.setBigUint64(cursor2, value);
        cursor2 += 8;
      } else {
        const binaryBigInt = value.toString(2);
        const bigIntBytes = new Uint8Array(Math.ceil(binaryBigInt.length / 8));
        let b32 = value;
        let i32 = 0;
        while (bigIntBytes.byteLength - ++i32 >= 0) {
          bigIntBytes[bigIntBytes.byteLength - i32] = Number(b32 & BigInt(255));
          b32 >>= BigInt(8);
        }
        ensureSpace2(bigIntBytes.byteLength * 2);
        data2[cursor2++] = nonNegative ? 194 : 195;
        if (USE_BUFFER4) {
          encodeHeader2(majorUnstructuredByteString2, Buffer.byteLength(bigIntBytes));
        } else {
          encodeHeader2(majorUnstructuredByteString2, bigIntBytes.byteLength);
        }
        data2.set(bigIntBytes, cursor2);
        cursor2 += bigIntBytes.byteLength;
      }
      continue;
    } else if (input === null) {
      data2[cursor2++] = majorSpecial2 << 5 | specialNull2;
      continue;
    } else if (typeof input === "boolean") {
      data2[cursor2++] = majorSpecial2 << 5 | (input ? specialTrue2 : specialFalse2);
      continue;
    } else if (typeof input === "undefined") {
      throw new Error("@smithy/core/cbor: client may not serialize undefined value.");
    } else if (Array.isArray(input)) {
      for (let i32 = input.length - 1; i32 >= 0; --i32) {
        encodeStack.push(input[i32]);
      }
      encodeHeader2(majorList2, input.length);
      continue;
    } else if (typeof input.byteLength === "number") {
      ensureSpace2(input.length * 2);
      encodeHeader2(majorUnstructuredByteString2, input.length);
      data2.set(input, cursor2);
      cursor2 += input.byteLength;
      continue;
    } else if (typeof input === "object") {
      if (input instanceof NumericValue3) {
        const decimalIndex = input.string.indexOf(".");
        const exponent = decimalIndex === -1 ? 0 : decimalIndex - input.string.length + 1;
        const mantissa = BigInt(input.string.replace(".", ""));
        data2[cursor2++] = 196;
        encodeStack.push(mantissa);
        encodeStack.push(exponent);
        encodeHeader2(majorList2, 2);
        continue;
      }
      if (input[tagSymbol2]) {
        if ("tag" in input && "value" in input) {
          encodeStack.push(input.value);
          encodeHeader2(majorTag2, input.tag);
          continue;
        } else {
          throw new Error("tag encountered with missing fields, need 'tag' and 'value', found: " + JSON.stringify(input));
        }
      }
      const keys = Object.keys(input);
      for (let i32 = keys.length - 1; i32 >= 0; --i32) {
        const key = keys[i32];
        encodeStack.push(input[key]);
        encodeStack.push(key);
      }
      encodeHeader2(majorMap2, keys.length);
      continue;
    }
    throw new Error(`data type ${input?.constructor?.name ?? typeof input} not compatible for encoding.`);
  }
}
var USE_BUFFER4, initialSize2, data2, dataView4, cursor2;
var init_cbor_encode2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/cbor/cbor-encode.js"() {
    init_serde4();
    init_cbor_types2();
    USE_BUFFER4 = typeof Buffer !== "undefined";
    initialSize2 = 2048;
    data2 = alloc2(initialSize2);
    dataView4 = new DataView(data2.buffer, data2.byteOffset, data2.byteLength);
    cursor2 = 0;
    __name(ensureSpace2, "ensureSpace");
    __name(toUint8Array4, "toUint8Array");
    __name(resize2, "resize");
    __name(encodeHeader2, "encodeHeader");
    __name(encode2, "encode");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/cbor/cbor.js
var cbor2;
var init_cbor3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/cbor/cbor.js"() {
    init_cbor_decode2();
    init_cbor_encode2();
    cbor2 = {
      deserialize(payload3) {
        setPayload2(payload3);
        return decode2(0, payload3.length);
      },
      serialize(input) {
        try {
          encode2(input);
          return toUint8Array4();
        } catch (e32) {
          toUint8Array4();
          throw e32;
        }
      },
      resizeEncodingBuffer(size) {
        resize2(size);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/cbor/parseCborBody.js
var dateToTag2, loadSmithyRpcV2CborErrorCode2;
var init_parseCborBody2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/cbor/parseCborBody.js"() {
    init_cbor_types2();
    dateToTag2 = /* @__PURE__ */ __name((date7) => {
      return tag2({
        tag: 1,
        value: date7.getTime() / 1e3
      });
    }, "dateToTag");
    loadSmithyRpcV2CborErrorCode2 = /* @__PURE__ */ __name((output, data3) => {
      const sanitizeErrorCode12 = /* @__PURE__ */ __name((rawValue) => {
        let cleanValue = rawValue;
        if (typeof cleanValue === "number") {
          cleanValue = cleanValue.toString();
        }
        if (cleanValue.indexOf(",") >= 0) {
          cleanValue = cleanValue.split(",")[0];
        }
        if (cleanValue.indexOf(":") >= 0) {
          cleanValue = cleanValue.split(":")[0];
        }
        if (cleanValue.indexOf("#") >= 0) {
          cleanValue = cleanValue.split("#")[1];
        }
        return cleanValue;
      }, "sanitizeErrorCode");
      if (data3["__type"] !== void 0) {
        return sanitizeErrorCode12(data3["__type"]);
      }
      let codeKey;
      for (const key in data3) {
        if (key.toLowerCase() === "code") {
          codeKey = key;
          break;
        }
      }
      if (codeKey && data3[codeKey] !== void 0) {
        return sanitizeErrorCode12(data3[codeKey]);
      }
    }, "loadSmithyRpcV2CborErrorCode");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/cbor/CborCodec.js
var CborCodec2, CborShapeSerializer2, CborShapeDeserializer2;
var init_CborCodec2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/cbor/CborCodec.js"() {
    init_protocols11();
    init_schema6();
    init_serde4();
    init_cbor3();
    init_parseCborBody2();
    CborCodec2 = class extends SerdeContext3 {
      static {
        __name(this, "CborCodec");
      }
      createSerializer() {
        const serializer = new CborShapeSerializer2();
        serializer.setSerdeContext(this.serdeContext);
        return serializer;
      }
      createDeserializer() {
        const deserializer = new CborShapeDeserializer2();
        deserializer.setSerdeContext(this.serdeContext);
        return deserializer;
      }
    };
    CborShapeSerializer2 = class extends SerdeContext3 {
      static {
        __name(this, "CborShapeSerializer");
      }
      value;
      write(schema, value) {
        this.value = this.serialize(schema, value);
      }
      serialize(schema, source) {
        const ns = NormalizedSchema3.of(schema);
        if (source == null) {
          if (ns.isIdempotencyToken()) {
            return generateIdempotencyToken3();
          }
          return source;
        }
        if (ns.isBlobSchema()) {
          if (typeof source === "string") {
            return (this.serdeContext?.base64Decoder ?? fromBase6436)(source);
          }
          return source;
        }
        if (ns.isTimestampSchema()) {
          if (typeof source === "number" || typeof source === "bigint") {
            return dateToTag2(new Date(Number(source) / 1e3 | 0));
          }
          return dateToTag2(source);
        }
        if (typeof source === "function" || typeof source === "object") {
          const sourceObject = source;
          if (ns.isListSchema() && Array.isArray(sourceObject)) {
            const sparse = !!ns.getMergedTraits().sparse;
            const newArray = [];
            let i32 = 0;
            for (const item of sourceObject) {
              const value = this.serialize(ns.getValueSchema(), item);
              if (value != null || sparse) {
                newArray[i32++] = value;
              }
            }
            return newArray;
          }
          if (sourceObject instanceof Date) {
            return dateToTag2(sourceObject);
          }
          const newObject = {};
          if (ns.isMapSchema()) {
            const sparse = !!ns.getMergedTraits().sparse;
            for (const key in sourceObject) {
              const value = this.serialize(ns.getValueSchema(), sourceObject[key]);
              if (value != null || sparse) {
                newObject[key] = value;
              }
            }
          } else if (ns.isStructSchema()) {
            for (const [key, memberSchema] of ns.structIterator()) {
              const value = this.serialize(memberSchema, sourceObject[key]);
              if (value != null) {
                newObject[key] = value;
              }
            }
            const isUnion = ns.isUnionSchema();
            if (isUnion && Array.isArray(sourceObject.$unknown)) {
              const [k32, v] = sourceObject.$unknown;
              newObject[k32] = v;
            } else if (typeof sourceObject.__type === "string") {
              for (const k32 in sourceObject) {
                if (!(k32 in newObject)) {
                  newObject[k32] = this.serialize(15, sourceObject[k32]);
                }
              }
            }
          } else if (ns.isDocumentSchema()) {
            for (const key in sourceObject) {
              newObject[key] = this.serialize(ns.getValueSchema(), sourceObject[key]);
            }
          } else if (ns.isBigDecimalSchema()) {
            return sourceObject;
          }
          return newObject;
        }
        return source;
      }
      flush() {
        const buffer = cbor2.serialize(this.value);
        this.value = void 0;
        return buffer;
      }
    };
    CborShapeDeserializer2 = class extends SerdeContext3 {
      static {
        __name(this, "CborShapeDeserializer");
      }
      read(schema, bytes) {
        const data3 = cbor2.deserialize(bytes);
        return this.readValue(schema, data3);
      }
      readValue(_schema, value) {
        const ns = NormalizedSchema3.of(_schema);
        if (ns.isTimestampSchema()) {
          if (typeof value === "number") {
            return _parseEpochTimestamp3(value);
          }
          if (typeof value === "object") {
            if (value.tag === 1 && "value" in value) {
              return _parseEpochTimestamp3(value.value);
            }
          }
        }
        if (ns.isBlobSchema()) {
          if (typeof value === "string") {
            return (this.serdeContext?.base64Decoder ?? fromBase6436)(value);
          }
          return value;
        }
        if (typeof value === "undefined" || typeof value === "boolean" || typeof value === "number" || typeof value === "string" || typeof value === "bigint" || typeof value === "symbol") {
          return value;
        } else if (typeof value === "object") {
          if (value === null) {
            return null;
          }
          if ("byteLength" in value) {
            return value;
          }
          if (value instanceof Date) {
            return value;
          }
          if (ns.isDocumentSchema()) {
            return value;
          }
          if (ns.isListSchema()) {
            const newArray = [];
            const memberSchema = ns.getValueSchema();
            for (const item of value) {
              const itemValue = this.readValue(memberSchema, item);
              newArray.push(itemValue);
            }
            return newArray;
          }
          const newObject = {};
          if (ns.isMapSchema()) {
            const targetSchema = ns.getValueSchema();
            for (const key in value) {
              const itemValue = this.readValue(targetSchema, value[key]);
              newObject[key] = itemValue;
            }
          } else if (ns.isStructSchema()) {
            const isUnion = ns.isUnionSchema();
            let keys;
            if (isUnion) {
              keys = /* @__PURE__ */ new Set();
              for (const k32 in value) {
                if (k32 !== "__type") {
                  keys.add(k32);
                }
              }
            }
            for (const [key, memberSchema] of ns.structIterator()) {
              if (isUnion) {
                keys.delete(key);
              }
              if (value[key] != null) {
                newObject[key] = this.readValue(memberSchema, value[key]);
              }
            }
            if (isUnion && keys?.size === 1) {
              let newObjectEmpty = true;
              for (const _ in newObject) {
                newObjectEmpty = false;
                break;
              }
              if (newObjectEmpty) {
                const k32 = keys.values().next().value;
                newObject.$unknown = [k32, value[k32]];
              }
            } else if (typeof value.__type === "string") {
              for (const k32 in value) {
                if (!(k32 in newObject)) {
                  newObject[k32] = value[k32];
                }
              }
            }
          } else if (value instanceof NumericValue3) {
            return value;
          }
          return newObject;
        } else {
          return value;
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/cbor/SmithyRpcV2CborProtocol.js
var SmithyRpcV2CborProtocol2;
var init_SmithyRpcV2CborProtocol2 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/cbor/SmithyRpcV2CborProtocol.js"() {
    init_client12();
    init_protocols11();
    init_schema6();
    init_CborCodec2();
    init_parseCborBody2();
    SmithyRpcV2CborProtocol2 = class extends RpcProtocol3 {
      static {
        __name(this, "SmithyRpcV2CborProtocol");
      }
      codec = new CborCodec2();
      serializer = this.codec.createSerializer();
      deserializer = this.codec.createDeserializer();
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32 }) {
        super({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32 });
      }
      getShapeId() {
        return "smithy.protocols#rpcv2Cbor";
      }
      getPayloadCodec() {
        return this.codec;
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        Object.assign(request4.headers, {
          "content-type": this.getDefaultContentType(),
          "smithy-protocol": "rpc-v2-cbor",
          accept: this.getDefaultContentType()
        });
        if (deref3(operationSchema.input) === "unit") {
          delete request4.body;
          delete request4.headers["content-type"];
        } else {
          if (!request4.body) {
            this.serializer.write(15, {});
            request4.body = this.serializer.flush();
          }
          try {
            request4.headers["content-length"] = String(request4.body.byteLength);
          } catch (e32) {
          }
        }
        const { service, operation: operation3 } = getSmithyContext26(context);
        const path47 = `/service/${service}/operation/${operation3}`;
        if (request4.path.endsWith("/")) {
          request4.path += path47.slice(1);
        } else {
          request4.path += path47;
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        return super.deserializeResponse(operationSchema, context, response);
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorName = loadSmithyRpcV2CborErrorCode2(response, dataObject) ?? "Unknown";
        const errorMetadata = {
          $metadata: metadata,
          $fault: response.statusCode <= 500 ? "client" : "server"
        };
        let namespace = this.options.defaultNamespace;
        if (errorName.includes("#")) {
          [namespace] = errorName.split("#");
        }
        const registry = this.compositeErrorRegistry;
        const nsRegistry = TypeRegistry3.for(namespace);
        registry.copyFrom(nsRegistry);
        let errorSchema;
        try {
          errorSchema = registry.getSchema(errorName);
        } catch (e32) {
          if (dataObject.Message) {
            dataObject.message = dataObject.Message;
          }
          const syntheticRegistry = TypeRegistry3.for("smithy.ts.sdk.synthetic." + namespace);
          registry.copyFrom(syntheticRegistry);
          const baseExceptionSchema = registry.getBaseException();
          if (baseExceptionSchema) {
            const ErrorCtor2 = registry.getErrorCtor(baseExceptionSchema);
            throw Object.assign(new ErrorCtor2({ name: errorName }), errorMetadata, dataObject);
          }
          throw Object.assign(new Error(errorName), errorMetadata, dataObject);
        }
        const ns = NormalizedSchema3.of(errorSchema);
        const ErrorCtor = registry.getErrorCtor(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "Unknown";
        const exception = new ErrorCtor({});
        const output = {};
        for (const [name, member7] of ns.structIterator()) {
          output[name] = this.deserializer.readValue(member7, dataObject[name]);
        }
        throw Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output);
      }
      getDefaultContentType() {
        return "application/cbor";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/cbor/index.js
var init_cbor4 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@smithy/core/dist-es/submodules/cbor/index.js"() {
    init_parseCborBody2();
    init_SmithyRpcV2CborProtocol2();
    init_CborCodec2();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ProtocolLib.js
var ProtocolLib8;
var init_ProtocolLib8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ProtocolLib.js"() {
    init_client12();
    init_schema6();
    ProtocolLib8 = class {
      static {
        __name(this, "ProtocolLib");
      }
      queryCompat;
      errorRegistry;
      constructor(queryCompat = false) {
        this.queryCompat = queryCompat;
      }
      resolveRestContentType(defaultContentType, inputSchema) {
        const members = inputSchema.getMemberSchemas();
        const httpPayloadMember = Object.values(members).find((m20) => {
          return !!m20.getMergedTraits().httpPayload;
        });
        if (httpPayloadMember) {
          const mediaType = httpPayloadMember.getMergedTraits().mediaType;
          if (mediaType) {
            return mediaType;
          } else if (httpPayloadMember.isStringSchema()) {
            return "text/plain";
          } else if (httpPayloadMember.isBlobSchema()) {
            return "application/octet-stream";
          } else {
            return defaultContentType;
          }
        } else if (!inputSchema.isUnitSchema()) {
          const hasBody = Object.values(members).find((m20) => {
            const { httpQuery, httpQueryParams, httpHeader, httpLabel, httpPrefixHeaders } = m20.getMergedTraits();
            const noPrefixHeaders = httpPrefixHeaders === void 0;
            return !httpQuery && !httpQueryParams && !httpHeader && !httpLabel && noPrefixHeaders;
          });
          if (hasBody) {
            return defaultContentType;
          }
        }
      }
      async getErrorSchemaOrThrowBaseException(errorIdentifier, defaultNamespace, response, dataObject, metadata, getErrorSchema) {
        let errorName = errorIdentifier;
        if (errorIdentifier.includes("#")) {
          [, errorName] = errorIdentifier.split("#");
        }
        const errorMetadata = {
          $metadata: metadata,
          $fault: response.statusCode < 500 ? "client" : "server"
        };
        if (!this.errorRegistry) {
          throw new Error("@aws-sdk/core/protocols - error handler not initialized.");
        }
        try {
          const errorSchema = getErrorSchema?.(this.errorRegistry, errorName) ?? this.errorRegistry.getSchema(errorIdentifier);
          return { errorSchema, errorMetadata };
        } catch (e32) {
          dataObject.message = dataObject.message ?? dataObject.Message ?? "UnknownError";
          const synthetic = this.errorRegistry;
          const baseExceptionSchema = synthetic.getBaseException();
          if (baseExceptionSchema) {
            const ErrorCtor = synthetic.getErrorCtor(baseExceptionSchema) ?? Error;
            throw this.decorateServiceException(Object.assign(new ErrorCtor({ name: errorName }), errorMetadata), dataObject);
          }
          const d32 = dataObject;
          const message2 = d32?.message ?? d32?.Message ?? d32?.Error?.Message ?? d32?.Error?.message;
          throw this.decorateServiceException(Object.assign(new Error(message2), {
            name: errorName
          }, errorMetadata), dataObject);
        }
      }
      compose(composite, errorIdentifier, defaultNamespace) {
        let namespace = defaultNamespace;
        if (errorIdentifier.includes("#")) {
          [namespace] = errorIdentifier.split("#");
        }
        const staticRegistry = TypeRegistry3.for(namespace);
        const defaultSyntheticRegistry = TypeRegistry3.for("smithy.ts.sdk.synthetic." + defaultNamespace);
        composite.copyFrom(staticRegistry);
        composite.copyFrom(defaultSyntheticRegistry);
        this.errorRegistry = composite;
      }
      decorateServiceException(exception, additions = {}) {
        if (this.queryCompat) {
          const msg = exception.Message ?? additions.Message;
          const error4 = decorateServiceException8(exception, additions);
          if (msg) {
            error4.message = msg;
          }
          const errorObj = error4.Error ?? {};
          errorObj.Type = error4.Error?.Type;
          errorObj.Code = error4.Error?.Code;
          errorObj.Message = error4.Error?.message ?? error4.Error?.Message ?? msg;
          error4.Error = errorObj;
          const reqId = error4.$metadata.requestId;
          if (reqId) {
            error4.RequestId = reqId;
          }
          return error4;
        }
        return decorateServiceException8(exception, additions);
      }
      setQueryCompatError(output, response) {
        const queryErrorHeader = response.headers?.["x-amzn-query-error"];
        if (output !== void 0 && queryErrorHeader != null) {
          const [Code, Type] = queryErrorHeader.split(";");
          const keys = Object.keys(output);
          const Error2 = {
            Code,
            Type
          };
          output.Code = Code;
          output.Type = Type;
          for (let i32 = 0; i32 < keys.length; i32++) {
            const k32 = keys[i32];
            Error2[k32 === "message" ? "Message" : k32] = output[k32];
          }
          delete Error2.__type;
          output.Error = Error2;
        }
      }
      queryCompatOutput(queryCompatErrorData, errorData) {
        if (queryCompatErrorData.Error) {
          errorData.Error = queryCompatErrorData.Error;
        }
        if (queryCompatErrorData.Type) {
          errorData.Type = queryCompatErrorData.Type;
        }
        if (queryCompatErrorData.Code) {
          errorData.Code = queryCompatErrorData.Code;
        }
      }
      findQueryCompatibleError(registry, errorName) {
        try {
          return registry.getSchema(errorName);
        } catch (e32) {
          return registry.find((schema) => NormalizedSchema3.of(schema).getMergedTraits().awsQueryError?.[0] === errorName);
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/cbor/AwsSmithyRpcV2CborProtocol.js
var AwsSmithyRpcV2CborProtocol6;
var init_AwsSmithyRpcV2CborProtocol8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/cbor/AwsSmithyRpcV2CborProtocol.js"() {
    init_cbor4();
    init_schema6();
    init_ProtocolLib8();
    AwsSmithyRpcV2CborProtocol6 = class extends SmithyRpcV2CborProtocol2 {
      static {
        __name(this, "AwsSmithyRpcV2CborProtocol");
      }
      awsQueryCompatible;
      mixin;
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, awsQueryCompatible }) {
        super({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32 });
        this.awsQueryCompatible = !!awsQueryCompatible;
        this.mixin = new ProtocolLib8(this.awsQueryCompatible);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        if (this.awsQueryCompatible) {
          request4.headers["x-amzn-query-mode"] = "true";
        }
        return request4;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        if (this.awsQueryCompatible) {
          this.mixin.setQueryCompatError(dataObject, response);
        }
        const errorName = (() => {
          const compatHeader = response.headers["x-amzn-query-error"];
          if (compatHeader && this.awsQueryCompatible) {
            return compatHeader.split(";")[0];
          }
          return loadSmithyRpcV2CborErrorCode2(response, dataObject) ?? "Unknown";
        })();
        this.mixin.compose(this.compositeErrorRegistry, errorName, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorName, this.options.defaultNamespace, response, dataObject, metadata, this.awsQueryCompatible ? this.mixin.findQueryCompatibleError : void 0);
        const ns = NormalizedSchema3.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor({});
        const output = {};
        for (const [name, member7] of ns.structIterator()) {
          if (dataObject[name] != null) {
            output[name] = this.deserializer.readValue(member7, dataObject[name]);
          }
        }
        if (this.awsQueryCompatible) {
          this.mixin.queryCompatOutput(dataObject, output);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/coercing-serializers.js
var _toStr6, _toBool6, _toNum6;
var init_coercing_serializers8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/coercing-serializers.js"() {
    _toStr6 = /* @__PURE__ */ __name((val) => {
      if (val == null) {
        return val;
      }
      if (typeof val === "number" || typeof val === "bigint") {
        const warning2 = new Error(`Received number ${val} where a string was expected.`);
        warning2.name = "Warning";
        console.warn(warning2);
        return String(val);
      }
      if (typeof val === "boolean") {
        const warning2 = new Error(`Received boolean ${val} where a string was expected.`);
        warning2.name = "Warning";
        console.warn(warning2);
        return String(val);
      }
      return val;
    }, "_toStr");
    _toBool6 = /* @__PURE__ */ __name((val) => {
      if (val == null) {
        return val;
      }
      if (typeof val === "number") {
      }
      if (typeof val === "string") {
        const lowercase = val.toLowerCase();
        if (val !== "" && lowercase !== "false" && lowercase !== "true") {
          const warning2 = new Error(`Received string "${val}" where a boolean was expected.`);
          warning2.name = "Warning";
          console.warn(warning2);
        }
        return val !== "" && lowercase !== "false";
      }
      return val;
    }, "_toBool");
    _toNum6 = /* @__PURE__ */ __name((val) => {
      if (val == null) {
        return val;
      }
      if (typeof val === "boolean") {
      }
      if (typeof val === "string") {
        const num = Number(val);
        if (num.toString() !== val) {
          const warning2 = new Error(`Received string "${val}" where a number was expected.`);
          warning2.name = "Warning";
          console.warn(warning2);
          return val;
        }
        return num;
      }
      return val;
    }, "_toNum");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ConfigurableSerdeContext.js
var SerdeContextConfig8;
var init_ConfigurableSerdeContext8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ConfigurableSerdeContext.js"() {
    SerdeContextConfig8 = class {
      static {
        __name(this, "SerdeContextConfig");
      }
      serdeContext;
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/UnionSerde.js
var UnionSerde8;
var init_UnionSerde8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/UnionSerde.js"() {
    UnionSerde8 = class {
      static {
        __name(this, "UnionSerde");
      }
      from;
      to;
      keys;
      constructor(from, to) {
        this.from = from;
        this.to = to;
        const keys = Object.keys(this.from);
        const set = new Set(keys);
        set.delete("__type");
        this.keys = set;
      }
      mark(key) {
        this.keys.delete(key);
      }
      hasUnknown() {
        return this.keys.size === 1 && Object.keys(this.to).length === 0;
      }
      writeUnknown() {
        if (this.hasUnknown()) {
          const k32 = this.keys.values().next().value;
          const v = this.from[k32];
          this.to.$unknown = [k32, v];
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReviver.js
function jsonReviver8(key, value, context) {
  if (context?.source) {
    const numericString = context.source;
    if (typeof value === "number") {
      if (value > Number.MAX_SAFE_INTEGER || value < Number.MIN_SAFE_INTEGER || numericString !== String(value)) {
        const isFractional = numericString.includes(".");
        if (isFractional) {
          return new NumericValue3(numericString, "bigDecimal");
        } else {
          return BigInt(numericString);
        }
      }
    }
  }
  return value;
}
var init_jsonReviver8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReviver.js"() {
    init_serde4();
    __name(jsonReviver8, "jsonReviver");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/common.js
var collectBodyString8;
var init_common10 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/common.js"() {
    init_protocols11();
    init_serde4();
    collectBodyString8 = /* @__PURE__ */ __name((streamBody, context) => collectBody10(streamBody, context).then((body) => (context?.utf8Encoder ?? toUtf839)(body)), "collectBodyString");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/parseJsonBody.js
var parseJsonBody8, parseJsonErrorBody6, findKey8, sanitizeErrorCode8, loadRestJsonErrorCode8, loadJsonRpcErrorCode, loadErrorCode;
var init_parseJsonBody8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/parseJsonBody.js"() {
    init_common10();
    parseJsonBody8 = /* @__PURE__ */ __name((streamBody, context) => collectBodyString8(streamBody, context).then((encoded) => {
      if (encoded.length) {
        try {
          return JSON.parse(encoded);
        } catch (e32) {
          if (e32?.name === "SyntaxError") {
            Object.defineProperty(e32, "$responseBodyText", {
              value: encoded
            });
          }
          throw e32;
        }
      }
      return {};
    }), "parseJsonBody");
    parseJsonErrorBody6 = /* @__PURE__ */ __name(async (errorBody, context) => {
      const value = await parseJsonBody8(errorBody, context);
      value.message = value.message ?? value.Message;
      return value;
    }, "parseJsonErrorBody");
    findKey8 = /* @__PURE__ */ __name((object, key) => Object.keys(object).find((k32) => k32.toLowerCase() === key.toLowerCase()), "findKey");
    sanitizeErrorCode8 = /* @__PURE__ */ __name((rawValue, removeNamespace = true) => {
      let cleanValue = rawValue;
      if (typeof cleanValue === "number") {
        cleanValue = cleanValue.toString();
      }
      if (cleanValue.indexOf(",") >= 0) {
        cleanValue = cleanValue.split(",")[0];
      }
      if (cleanValue.indexOf(":") >= 0) {
        cleanValue = cleanValue.split(":")[0];
      }
      if (removeNamespace && cleanValue.indexOf("#") >= 0) {
        cleanValue = cleanValue.split("#")[1];
      }
      return cleanValue;
    }, "sanitizeErrorCode");
    loadRestJsonErrorCode8 = /* @__PURE__ */ __name((output, data3) => {
      return loadErrorCode(output, data3, true, ["header", "code", "type"]);
    }, "loadRestJsonErrorCode");
    loadJsonRpcErrorCode = /* @__PURE__ */ __name((output, data3, removeNamespace, queryCompat = false) => {
      return loadErrorCode(output, data3, removeNamespace, queryCompat ? ["code", "header", "type"] : ["type", "code", "header"]);
    }, "loadJsonRpcErrorCode");
    loadErrorCode = /* @__PURE__ */ __name(({ headers }, data3, removeNamespace, order) => {
      while (order.length > 0) {
        const location = order.shift();
        switch (location) {
          case "header":
            const headerKey = findKey8(headers ?? {}, "x-amzn-errortype");
            if (headerKey !== void 0) {
              return sanitizeErrorCode8(headers[headerKey], removeNamespace);
            }
            break;
          case "code":
            const codeKey = findKey8(data3 ?? {}, "code");
            if (codeKey && data3[codeKey] !== void 0) {
              return sanitizeErrorCode8(data3[codeKey], removeNamespace);
            }
            break;
          case "type":
            if (data3?.__type !== void 0) {
              return sanitizeErrorCode8(data3.__type, removeNamespace);
            }
            break;
        }
      }
    }, "loadErrorCode");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeDeserializer.js
var JsonShapeDeserializer8;
var init_JsonShapeDeserializer8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeDeserializer.js"() {
    init_protocols11();
    init_schema6();
    init_serde4();
    init_serde4();
    init_ConfigurableSerdeContext8();
    init_UnionSerde8();
    init_jsonReviver8();
    init_parseJsonBody8();
    JsonShapeDeserializer8 = class extends SerdeContextConfig8 {
      static {
        __name(this, "JsonShapeDeserializer");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      async read(schema, data3) {
        return this._read(schema, typeof data3 === "string" ? JSON.parse(data3, jsonReviver8) : await parseJsonBody8(data3, this.serdeContext));
      }
      readObject(schema, data3) {
        return this._read(schema, data3);
      }
      _read(schema, value) {
        const isObject3 = value !== null && typeof value === "object";
        const ns = NormalizedSchema3.of(schema);
        if (isObject3) {
          if (ns.isStructSchema()) {
            const record = value;
            const union = ns.isUnionSchema();
            const out = {};
            let nameMap = void 0;
            const { jsonName } = this.settings;
            if (jsonName) {
              nameMap = {};
            }
            let unionSerde;
            if (union) {
              unionSerde = new UnionSerde8(record, out);
            }
            for (const [memberName, memberSchema] of ns.structIterator()) {
              let fromKey = memberName;
              if (jsonName) {
                fromKey = memberSchema.getMergedTraits().jsonName ?? fromKey;
                nameMap[fromKey] = memberName;
              }
              if (union) {
                unionSerde.mark(fromKey);
              }
              if (record[fromKey] != null) {
                out[memberName] = this._read(memberSchema, record[fromKey]);
              }
            }
            if (union) {
              unionSerde.writeUnknown();
            } else if (typeof record.__type === "string") {
              for (const k32 in record) {
                const v = record[k32];
                const t = jsonName ? nameMap[k32] ?? k32 : k32;
                if (!(t in out)) {
                  out[t] = v;
                }
              }
            }
            return out;
          }
          if (Array.isArray(value) && ns.isListSchema()) {
            const listMember = ns.getValueSchema();
            const out = [];
            for (const item of value) {
              out.push(this._read(listMember, item));
            }
            return out;
          }
          if (ns.isMapSchema()) {
            const mapMember = ns.getValueSchema();
            const out = {};
            for (const _k in value) {
              out[_k] = this._read(mapMember, value[_k]);
            }
            return out;
          }
        }
        if (ns.isBlobSchema() && typeof value === "string") {
          return fromBase6436(value);
        }
        const mediaType = ns.getMergedTraits().mediaType;
        if (ns.isStringSchema() && typeof value === "string" && mediaType) {
          const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
          if (isJson) {
            return LazyJsonString5.from(value);
          }
          return value;
        }
        if (ns.isTimestampSchema() && value != null) {
          const format32 = determineTimestampFormat3(ns, this.settings);
          switch (format32) {
            case 5:
              return parseRfc3339DateTimeWithOffset4(value);
            case 6:
              return parseRfc7231DateTime4(value);
            case 7:
              return parseEpochTimestamp4(value);
            default:
              console.warn("Missing timestamp format, parsing value with Date constructor:", value);
              return new Date(value);
          }
        }
        if (ns.isBigIntegerSchema() && (typeof value === "number" || typeof value === "string")) {
          return BigInt(value);
        }
        if (ns.isBigDecimalSchema() && value != void 0) {
          if (value instanceof NumericValue3) {
            return value;
          }
          const untyped = value;
          if (untyped.type === "bigDecimal" && "string" in untyped) {
            return new NumericValue3(untyped.string, untyped.type);
          }
          return new NumericValue3(String(value), "bigDecimal");
        }
        if (ns.isNumericSchema() && typeof value === "string") {
          switch (value) {
            case "Infinity":
              return Infinity;
            case "-Infinity":
              return -Infinity;
            case "NaN":
              return NaN;
          }
          return value;
        }
        if (ns.isDocumentSchema()) {
          if (isObject3) {
            const out = Array.isArray(value) ? [] : {};
            for (const k32 in value) {
              const v = value[k32];
              if (v instanceof NumericValue3) {
                out[k32] = v;
              } else {
                out[k32] = this._read(ns, v);
              }
            }
            return out;
          } else {
            return structuredClone(value);
          }
        }
        return value;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReplacer.js
var NUMERIC_CONTROL_CHAR8, JsonReplacer8;
var init_jsonReplacer8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReplacer.js"() {
    init_serde4();
    NUMERIC_CONTROL_CHAR8 = String.fromCharCode(925);
    JsonReplacer8 = class {
      static {
        __name(this, "JsonReplacer");
      }
      values = /* @__PURE__ */ new Map();
      counter = 0;
      stage = 0;
      createReplacer() {
        if (this.stage === 1) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer already created.");
        }
        if (this.stage === 2) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer exhausted.");
        }
        this.stage = 1;
        return (key, value) => {
          if (value instanceof NumericValue3) {
            const v = `${NUMERIC_CONTROL_CHAR8 + "nv" + this.counter++}_` + value.string;
            this.values.set(`"${v}"`, value.string);
            return v;
          }
          if (typeof value === "bigint") {
            const s = value.toString();
            const v = `${NUMERIC_CONTROL_CHAR8 + "b" + this.counter++}_` + s;
            this.values.set(`"${v}"`, s);
            return v;
          }
          return value;
        };
      }
      replaceInJson(json) {
        if (this.stage === 0) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer not created yet.");
        }
        if (this.stage === 2) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer exhausted.");
        }
        this.stage = 2;
        if (this.counter === 0) {
          return json;
        }
        for (const [key, value] of this.values) {
          json = json.replace(key, value);
        }
        return json;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeSerializer.js
var JsonShapeSerializer8;
var init_JsonShapeSerializer8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeSerializer.js"() {
    init_protocols11();
    init_schema6();
    init_serde4();
    init_ConfigurableSerdeContext8();
    init_jsonReplacer8();
    JsonShapeSerializer8 = class extends SerdeContextConfig8 {
      static {
        __name(this, "JsonShapeSerializer");
      }
      settings;
      buffer;
      useReplacer = false;
      rootSchema;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value) {
        this.rootSchema = NormalizedSchema3.of(schema);
        this.buffer = this._write(this.rootSchema, value);
      }
      flush() {
        const { rootSchema, useReplacer } = this;
        this.rootSchema = void 0;
        this.useReplacer = false;
        if (rootSchema?.isStructSchema() || rootSchema?.isDocumentSchema()) {
          if (!useReplacer) {
            return JSON.stringify(this.buffer);
          }
          const replacer = new JsonReplacer8();
          return replacer.replaceInJson(JSON.stringify(this.buffer, replacer.createReplacer(), 0));
        }
        return this.buffer;
      }
      writeDiscriminatedDocument(schema, value) {
        this.write(schema, value);
        if (typeof this.buffer === "object") {
          this.buffer.__type = NormalizedSchema3.of(schema).getName(true);
        }
      }
      _write(schema, value, container) {
        const isObject3 = value !== null && typeof value === "object";
        const ns = NormalizedSchema3.of(schema);
        if (isObject3) {
          if (ns.isStructSchema()) {
            const record = value;
            const out = {};
            const { jsonName } = this.settings;
            let nameMap = void 0;
            if (jsonName) {
              nameMap = {};
            }
            let outCount = 0;
            for (const [memberName, memberSchema] of ns.structIterator()) {
              const serializableValue = this._write(memberSchema, record[memberName], ns);
              if (serializableValue !== void 0) {
                let targetKey = memberName;
                if (jsonName) {
                  targetKey = memberSchema.getMergedTraits().jsonName ?? memberName;
                  nameMap[memberName] = targetKey;
                }
                out[targetKey] = serializableValue;
                outCount++;
              }
            }
            if (ns.isUnionSchema() && outCount === 0) {
              const { $unknown } = record;
              if (Array.isArray($unknown)) {
                const [k32, v] = $unknown;
                out[k32] = this._write(15, v);
              }
            } else if (typeof record.__type === "string") {
              for (const k32 in record) {
                const v = record[k32];
                const targetKey = jsonName ? nameMap[k32] ?? k32 : k32;
                if (!(targetKey in out)) {
                  out[targetKey] = this._write(15, v);
                }
              }
            }
            return out;
          }
          if (Array.isArray(value) && ns.isListSchema()) {
            const listMember = ns.getValueSchema();
            const out = [];
            const sparse = !!ns.getMergedTraits().sparse;
            for (const item of value) {
              if (sparse || item != null) {
                out.push(this._write(listMember, item));
              }
            }
            return out;
          }
          if (ns.isMapSchema()) {
            const mapMember = ns.getValueSchema();
            const out = {};
            const sparse = !!ns.getMergedTraits().sparse;
            for (const _k in value) {
              const _v = value[_k];
              if (sparse || _v != null) {
                out[_k] = this._write(mapMember, _v);
              }
            }
            return out;
          }
          if (value instanceof Uint8Array && (ns.isBlobSchema() || ns.isDocumentSchema())) {
            if (ns === this.rootSchema) {
              return value;
            }
            return (this.serdeContext?.base64Encoder ?? toBase6441)(value);
          }
          if (value instanceof Date && (ns.isTimestampSchema() || ns.isDocumentSchema())) {
            const format32 = determineTimestampFormat3(ns, this.settings);
            switch (format32) {
              case 5:
                return value.toISOString().replace(".000Z", "Z");
              case 6:
                return dateToUtcString15(value);
              case 7:
                return value.getTime() / 1e3;
              default:
                console.warn("Missing timestamp format, using epoch seconds", value);
                return value.getTime() / 1e3;
            }
          }
          if (value instanceof NumericValue3) {
            this.useReplacer = true;
          }
        }
        if (value === null && container?.isStructSchema()) {
          return void 0;
        }
        if (ns.isStringSchema()) {
          if (typeof value === "undefined" && ns.isIdempotencyToken()) {
            return generateIdempotencyToken3();
          }
          const mediaType = ns.getMergedTraits().mediaType;
          if (value != null && mediaType) {
            const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
            if (isJson) {
              return LazyJsonString5.from(value);
            }
          }
          return value;
        }
        if (typeof value === "number" && ns.isNumericSchema()) {
          if (Math.abs(value) === Infinity || isNaN(value)) {
            return String(value);
          }
          return value;
        }
        if (typeof value === "string" && ns.isBlobSchema()) {
          if (ns === this.rootSchema) {
            return value;
          }
          return (this.serdeContext?.base64Encoder ?? toBase6441)(value);
        }
        if (typeof value === "bigint") {
          this.useReplacer = true;
        }
        if (ns.isDocumentSchema()) {
          if (isObject3) {
            const out = Array.isArray(value) ? [] : {};
            for (const k32 in value) {
              const v = value[k32];
              if (v instanceof NumericValue3) {
                this.useReplacer = true;
                out[k32] = v;
              } else {
                out[k32] = this._write(ns, v);
              }
            }
            return out;
          } else {
            return structuredClone(value);
          }
        }
        return value;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonCodec.js
var JsonCodec8;
var init_JsonCodec8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonCodec.js"() {
    init_ConfigurableSerdeContext8();
    init_JsonShapeDeserializer8();
    init_JsonShapeSerializer8();
    JsonCodec8 = class extends SerdeContextConfig8 {
      static {
        __name(this, "JsonCodec");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      createSerializer() {
        const serializer = new JsonShapeSerializer8(this.settings);
        serializer.setSerdeContext(this.serdeContext);
        return serializer;
      }
      createDeserializer() {
        const deserializer = new JsonShapeDeserializer8(this.settings);
        deserializer.setSerdeContext(this.serdeContext);
        return deserializer;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJsonRpcProtocol.js
var AwsJsonRpcProtocol6;
var init_AwsJsonRpcProtocol8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJsonRpcProtocol.js"() {
    init_protocols11();
    init_schema6();
    init_ProtocolLib8();
    init_JsonCodec8();
    init_parseJsonBody8();
    AwsJsonRpcProtocol6 = class extends RpcProtocol3 {
      static {
        __name(this, "AwsJsonRpcProtocol");
      }
      serializer;
      deserializer;
      serviceTarget;
      codec;
      mixin;
      awsQueryCompatible;
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, serviceTarget, awsQueryCompatible, jsonCodec }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32
        });
        this.serviceTarget = serviceTarget;
        this.codec = jsonCodec ?? new JsonCodec8({
          timestampFormat: {
            useTrait: true,
            default: 7
          },
          jsonName: false
        });
        this.serializer = this.codec.createSerializer();
        this.deserializer = this.codec.createDeserializer();
        this.awsQueryCompatible = !!awsQueryCompatible;
        this.mixin = new ProtocolLib8(this.awsQueryCompatible);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        if (!request4.path.endsWith("/")) {
          request4.path += "/";
        }
        request4.headers["content-type"] = `application/x-amz-json-${this.getJsonRpcVersion()}`;
        request4.headers["x-amz-target"] = `${this.serviceTarget}.${operationSchema.name}`;
        if (this.awsQueryCompatible) {
          request4.headers["x-amzn-query-mode"] = "true";
        }
        if (deref3(operationSchema.input) === "unit" || !request4.body) {
          request4.body = "{}";
        }
        return request4;
      }
      getPayloadCodec() {
        return this.codec;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const { awsQueryCompatible } = this;
        if (awsQueryCompatible) {
          this.mixin.setQueryCompatError(dataObject, response);
        }
        const errorIdentifier = loadJsonRpcErrorCode(response, dataObject, this.getJsonRpcVersion() === "1.1", awsQueryCompatible) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata, awsQueryCompatible ? this.mixin.findQueryCompatibleError : void 0);
        const ns = NormalizedSchema3.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor({});
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          if (dataObject[name] != null) {
            output[name] = errorDeserializer.readObject(member7, dataObject[name]);
          }
        }
        if (awsQueryCompatible) {
          this.mixin.queryCompatOutput(dataObject, output);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_0Protocol.js
var AwsJson1_0Protocol6;
var init_AwsJson1_0Protocol8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_0Protocol.js"() {
    init_AwsJsonRpcProtocol8();
    AwsJson1_0Protocol6 = class extends AwsJsonRpcProtocol6 {
      static {
        __name(this, "AwsJson1_0Protocol");
      }
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, serviceTarget, awsQueryCompatible, jsonCodec }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32,
          serviceTarget,
          awsQueryCompatible,
          jsonCodec
        });
      }
      getShapeId() {
        return "aws.protocols#awsJson1_0";
      }
      getJsonRpcVersion() {
        return "1.0";
      }
      getDefaultContentType() {
        return "application/x-amz-json-1.0";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_1Protocol.js
var AwsJson1_1Protocol6;
var init_AwsJson1_1Protocol8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_1Protocol.js"() {
    init_AwsJsonRpcProtocol8();
    AwsJson1_1Protocol6 = class extends AwsJsonRpcProtocol6 {
      static {
        __name(this, "AwsJson1_1Protocol");
      }
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, serviceTarget, awsQueryCompatible, jsonCodec }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32,
          serviceTarget,
          awsQueryCompatible,
          jsonCodec
        });
      }
      getShapeId() {
        return "aws.protocols#awsJson1_1";
      }
      getJsonRpcVersion() {
        return "1.1";
      }
      getDefaultContentType() {
        return "application/x-amz-json-1.1";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsRestJsonProtocol.js
var AwsRestJsonProtocol8;
var init_AwsRestJsonProtocol8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsRestJsonProtocol.js"() {
    init_protocols11();
    init_schema6();
    init_ProtocolLib8();
    init_JsonCodec8();
    init_parseJsonBody8();
    AwsRestJsonProtocol8 = class extends HttpBindingProtocol3 {
      static {
        __name(this, "AwsRestJsonProtocol");
      }
      serializer;
      deserializer;
      codec;
      mixin = new ProtocolLib8();
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32 }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32
        });
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 7
          },
          httpBindings: true,
          jsonName: true
        };
        this.codec = new JsonCodec8(settings);
        this.serializer = new HttpInterceptingShapeSerializer3(this.codec.createSerializer(), settings);
        this.deserializer = new HttpInterceptingShapeDeserializer3(this.codec.createDeserializer(), settings);
      }
      getShapeId() {
        return "aws.protocols#restJson1";
      }
      getPayloadCodec() {
        return this.codec;
      }
      setSerdeContext(serdeContext) {
        this.codec.setSerdeContext(serdeContext);
        super.setSerdeContext(serdeContext);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        const inputSchema = NormalizedSchema3.of(operationSchema.input);
        if (!request4.headers["content-type"]) {
          const contentType = this.mixin.resolveRestContentType(this.getDefaultContentType(), inputSchema);
          if (contentType) {
            request4.headers["content-type"] = contentType;
          }
        }
        if (request4.body == null && request4.headers["content-type"] === this.getDefaultContentType()) {
          request4.body = "{}";
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        const output = await super.deserializeResponse(operationSchema, context, response);
        const outputSchema = NormalizedSchema3.of(operationSchema.output);
        for (const [name, member7] of outputSchema.structIterator()) {
          if (member7.getMemberTraits().httpPayload && !(name in output)) {
            output[name] = null;
          }
        }
        return output;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = loadRestJsonErrorCode8(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata);
        const ns = NormalizedSchema3.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor({});
        await this.deserializeHttpMessage(errorSchema, context, response, dataObject);
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().jsonName ?? name;
          output[name] = errorDeserializer.readObject(member7, dataObject[target]);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      getDefaultContentType() {
        return "application/json";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/awsExpectUnion.js
var awsExpectUnion6;
var init_awsExpectUnion8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/awsExpectUnion.js"() {
    init_serde4();
    awsExpectUnion6 = /* @__PURE__ */ __name((value) => {
      if (value == null) {
        return void 0;
      }
      if (typeof value === "object" && "__type" in value) {
        delete value.__type;
      }
      return expectUnion7(value);
    }, "awsExpectUnion");
  }
});

// ../../node_modules/fast-xml-parser/lib/fxp.cjs
var require_fxp3 = __commonJS({
  "../../node_modules/fast-xml-parser/lib/fxp.cjs"(exports2, module2) {
    (() => {
      "use strict";
      var t = { d: /* @__PURE__ */ __name((e33, n11) => {
        for (var i33 in n11) t.o(n11, i33) && !t.o(e33, i33) && Object.defineProperty(e33, i33, { enumerable: true, get: n11[i33] });
      }, "d"), o: /* @__PURE__ */ __name((t2, e33) => Object.prototype.hasOwnProperty.call(t2, e33), "o"), r: /* @__PURE__ */ __name((t2) => {
        "undefined" != typeof Symbol && Symbol.toStringTag && Object.defineProperty(t2, Symbol.toStringTag, { value: "Module" }), Object.defineProperty(t2, "__esModule", { value: true });
      }, "r") }, e32 = {};
      t.r(e32), t.d(e32, { XMLBuilder: /* @__PURE__ */ __name(() => Xt, "XMLBuilder"), XMLParser: /* @__PURE__ */ __name(() => Tt, "XMLParser"), XMLValidator: /* @__PURE__ */ __name(() => Yt, "XMLValidator") });
      const n10 = ":A-Za-z_\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD", i32 = new RegExp("^[" + n10 + "][" + n10 + "\\-.\\d\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$");
      function s(t2, e33) {
        const n11 = [];
        let i33 = e33.exec(t2);
        for (; i33; ) {
          const s2 = [];
          s2.startIndex = e33.lastIndex - i33[0].length;
          const r33 = i33.length;
          for (let t3 = 0; t3 < r33; t3++) s2.push(i33[t3]);
          n11.push(s2), i33 = e33.exec(t2);
        }
        return n11;
      }
      __name(s, "s");
      const r32 = /* @__PURE__ */ __name(function(t2) {
        return !(null == i32.exec(t2));
      }, "r"), o10 = ["hasOwnProperty", "toString", "valueOf", "__defineGetter__", "__defineSetter__", "__lookupGetter__", "__lookupSetter__"], a32 = ["__proto__", "constructor", "prototype"], h32 = { allowBooleanAttributes: false, unpairedTags: [] };
      function l20(t2, e33) {
        e33 = Object.assign({}, h32, e33);
        const n11 = [];
        let i33 = false, s2 = false;
        "\uFEFF" === t2[0] && (t2 = t2.substr(1));
        for (let r33 = 0; r33 < t2.length; r33++) if ("<" === t2[r33] && "?" === t2[r33 + 1]) {
          if (r33 += 2, r33 = p10(t2, r33), r33.err) return r33;
        } else {
          if ("<" !== t2[r33]) {
            if (u(t2[r33])) continue;
            return b32("InvalidChar", "char '" + t2[r33] + "' is not expected.", w(t2, r33));
          }
          {
            let o11 = r33;
            if (r33++, "!" === t2[r33]) {
              r33 = c32(t2, r33);
              continue;
            }
            {
              let a33 = false;
              "/" === t2[r33] && (a33 = true, r33++);
              let h33 = "";
              for (; r33 < t2.length && ">" !== t2[r33] && " " !== t2[r33] && "	" !== t2[r33] && "\n" !== t2[r33] && "\r" !== t2[r33]; r33++) h33 += t2[r33];
              if (h33 = h33.trim(), "/" === h33[h33.length - 1] && (h33 = h33.substring(0, h33.length - 1), r33--), !E(h33)) {
                let e34;
                return e34 = 0 === h33.trim().length ? "Invalid space after '<'." : "Tag '" + h33 + "' is an invalid name.", b32("InvalidTag", e34, w(t2, r33));
              }
              const l21 = g32(t2, r33);
              if (false === l21) return b32("InvalidAttr", "Attributes for '" + h33 + "' have open quote.", w(t2, r33));
              let d33 = l21.value;
              if (r33 = l21.index, "/" === d33[d33.length - 1]) {
                const n12 = r33 - d33.length;
                d33 = d33.substring(0, d33.length - 1);
                const s3 = x(d33, e33);
                if (true !== s3) return b32(s3.err.code, s3.err.msg, w(t2, n12 + s3.err.line));
                i33 = true;
              } else if (a33) {
                if (!l21.tagClosed) return b32("InvalidTag", "Closing tag '" + h33 + "' doesn't have proper closing.", w(t2, r33));
                if (d33.trim().length > 0) return b32("InvalidTag", "Closing tag '" + h33 + "' can't have attributes or invalid starting.", w(t2, o11));
                if (0 === n11.length) return b32("InvalidTag", "Closing tag '" + h33 + "' has not been opened.", w(t2, o11));
                {
                  const e34 = n11.pop();
                  if (h33 !== e34.tagName) {
                    let n12 = w(t2, e34.tagStartPos);
                    return b32("InvalidTag", "Expected closing tag '" + e34.tagName + "' (opened in line " + n12.line + ", col " + n12.col + ") instead of closing tag '" + h33 + "'.", w(t2, o11));
                  }
                  0 == n11.length && (s2 = true);
                }
              } else {
                const a34 = x(d33, e33);
                if (true !== a34) return b32(a34.err.code, a34.err.msg, w(t2, r33 - d33.length + a34.err.line));
                if (true === s2) return b32("InvalidXml", "Multiple possible root nodes found.", w(t2, r33));
                -1 !== e33.unpairedTags.indexOf(h33) || n11.push({ tagName: h33, tagStartPos: o11 }), i33 = true;
              }
              for (r33++; r33 < t2.length; r33++) if ("<" === t2[r33]) {
                if ("!" === t2[r33 + 1]) {
                  r33++, r33 = c32(t2, r33);
                  continue;
                }
                if ("?" !== t2[r33 + 1]) break;
                if (r33 = p10(t2, ++r33), r33.err) return r33;
              } else if ("&" === t2[r33]) {
                const e34 = N(t2, r33);
                if (-1 == e34) return b32("InvalidChar", "char '&' is not expected.", w(t2, r33));
                r33 = e34;
              } else if (true === s2 && !u(t2[r33])) return b32("InvalidXml", "Extra text at the end", w(t2, r33));
              "<" === t2[r33] && r33--;
            }
          }
        }
        return i33 ? 1 == n11.length ? b32("InvalidTag", "Unclosed tag '" + n11[0].tagName + "'.", w(t2, n11[0].tagStartPos)) : !(n11.length > 0) || b32("InvalidXml", "Invalid '" + JSON.stringify(n11.map((t3) => t3.tagName), null, 4).replace(/\r?\n/g, "") + "' found.", { line: 1, col: 1 }) : b32("InvalidXml", "Start tag expected.", 1);
      }
      __name(l20, "l");
      function u(t2) {
        return " " === t2 || "	" === t2 || "\n" === t2 || "\r" === t2;
      }
      __name(u, "u");
      function p10(t2, e33) {
        const n11 = e33;
        for (; e33 < t2.length; e33++) if ("?" == t2[e33] || " " == t2[e33]) {
          const i33 = t2.substr(n11, e33 - n11);
          if (e33 > 5 && "xml" === i33) return b32("InvalidXml", "XML declaration allowed only at the start of the document.", w(t2, e33));
          if ("?" == t2[e33] && ">" == t2[e33 + 1]) {
            e33++;
            break;
          }
          continue;
        }
        return e33;
      }
      __name(p10, "p");
      function c32(t2, e33) {
        if (t2.length > e33 + 5 && "-" === t2[e33 + 1] && "-" === t2[e33 + 2]) {
          for (e33 += 3; e33 < t2.length; e33++) if ("-" === t2[e33] && "-" === t2[e33 + 1] && ">" === t2[e33 + 2]) {
            e33 += 2;
            break;
          }
        } else if (t2.length > e33 + 8 && "D" === t2[e33 + 1] && "O" === t2[e33 + 2] && "C" === t2[e33 + 3] && "T" === t2[e33 + 4] && "Y" === t2[e33 + 5] && "P" === t2[e33 + 6] && "E" === t2[e33 + 7]) {
          let n11 = 1;
          for (e33 += 8; e33 < t2.length; e33++) if ("<" === t2[e33]) n11++;
          else if (">" === t2[e33] && (n11--, 0 === n11)) break;
        } else if (t2.length > e33 + 9 && "[" === t2[e33 + 1] && "C" === t2[e33 + 2] && "D" === t2[e33 + 3] && "A" === t2[e33 + 4] && "T" === t2[e33 + 5] && "A" === t2[e33 + 6] && "[" === t2[e33 + 7]) {
          for (e33 += 8; e33 < t2.length; e33++) if ("]" === t2[e33] && "]" === t2[e33 + 1] && ">" === t2[e33 + 2]) {
            e33 += 2;
            break;
          }
        }
        return e33;
      }
      __name(c32, "c");
      const d32 = '"', f32 = "'";
      function g32(t2, e33) {
        let n11 = "", i33 = "", s2 = false;
        for (; e33 < t2.length; e33++) {
          if (t2[e33] === d32 || t2[e33] === f32) "" === i33 ? i33 = t2[e33] : i33 !== t2[e33] || (i33 = "");
          else if (">" === t2[e33] && "" === i33) {
            s2 = true;
            break;
          }
          n11 += t2[e33];
        }
        return "" === i33 && { value: n11, index: e33, tagClosed: s2 };
      }
      __name(g32, "g");
      const m20 = new RegExp(`(\\s*)([^\\s=]+)(\\s*=)?(\\s*(['"])(([\\s\\S])*?)\\5)?`, "g");
      function x(t2, e33) {
        const n11 = s(t2, m20), i33 = {};
        for (let t3 = 0; t3 < n11.length; t3++) {
          if (0 === n11[t3][1].length) return b32("InvalidAttr", "Attribute '" + n11[t3][2] + "' has no space in starting.", v(n11[t3]));
          if (void 0 !== n11[t3][3] && void 0 === n11[t3][4]) return b32("InvalidAttr", "Attribute '" + n11[t3][2] + "' is without value.", v(n11[t3]));
          if (void 0 === n11[t3][3] && !e33.allowBooleanAttributes) return b32("InvalidAttr", "boolean attribute '" + n11[t3][2] + "' is not allowed.", v(n11[t3]));
          const s2 = n11[t3][2];
          if (!y(s2)) return b32("InvalidAttr", "Attribute '" + s2 + "' is an invalid name.", v(n11[t3]));
          if (Object.prototype.hasOwnProperty.call(i33, s2)) return b32("InvalidAttr", "Attribute '" + s2 + "' is repeated.", v(n11[t3]));
          i33[s2] = 1;
        }
        return true;
      }
      __name(x, "x");
      function N(t2, e33) {
        if (";" === t2[++e33]) return -1;
        if ("#" === t2[e33]) return (function(t3, e34) {
          let n12 = /\d/;
          for ("x" === t3[e34] && (e34++, n12 = /[\da-fA-F]/); e34 < t3.length; e34++) {
            if (";" === t3[e34]) return e34;
            if (!t3[e34].match(n12)) break;
          }
          return -1;
        })(t2, ++e33);
        let n11 = 0;
        for (; e33 < t2.length; e33++, n11++) if (!(t2[e33].match(/\w/) && n11 < 20)) {
          if (";" === t2[e33]) break;
          return -1;
        }
        return e33;
      }
      __name(N, "N");
      function b32(t2, e33, n11) {
        return { err: { code: t2, msg: e33, line: n11.line || n11, col: n11.col } };
      }
      __name(b32, "b");
      function y(t2) {
        return r32(t2);
      }
      __name(y, "y");
      function E(t2) {
        return r32(t2);
      }
      __name(E, "E");
      function w(t2, e33) {
        const n11 = t2.substring(0, e33).split(/\r?\n/);
        return { line: n11.length, col: n11[n11.length - 1].length + 1 };
      }
      __name(w, "w");
      function v(t2) {
        return t2.startIndex + t2[1].length;
      }
      __name(v, "v");
      const S = /* @__PURE__ */ __name((t2) => o10.includes(t2) ? "__" + t2 : t2, "S"), _ = { preserveOrder: false, attributeNamePrefix: "@_", attributesGroupName: false, textNodeName: "#text", ignoreAttributes: true, removeNSPrefix: false, allowBooleanAttributes: false, parseTagValue: true, parseAttributeValue: false, trimValues: true, cdataPropName: false, numberParseOptions: { hex: true, leadingZeros: true, eNotation: true }, tagValueProcessor: /* @__PURE__ */ __name(function(t2, e33) {
        return e33;
      }, "tagValueProcessor"), attributeValueProcessor: /* @__PURE__ */ __name(function(t2, e33) {
        return e33;
      }, "attributeValueProcessor"), stopNodes: [], alwaysCreateTextNode: false, isArray: /* @__PURE__ */ __name(() => false, "isArray"), commentPropName: false, unpairedTags: [], processEntities: true, htmlEntities: false, entityDecoder: null, ignoreDeclaration: false, ignorePiTags: false, transformTagName: false, transformAttributeName: false, updateTag: /* @__PURE__ */ __name(function(t2, e33, n11) {
        return t2;
      }, "updateTag"), captureMetaData: false, maxNestedTags: 100, strictReservedNames: true, jPath: true, onDangerousProperty: S };
      function A(t2, e33) {
        if ("string" != typeof t2) return;
        const n11 = t2.toLowerCase();
        if (o10.some((t3) => n11 === t3.toLowerCase())) throw new Error(`[SECURITY] Invalid ${e33}: "${t2}" is a reserved JavaScript keyword that could cause prototype pollution`);
        if (a32.some((t3) => n11 === t3.toLowerCase())) throw new Error(`[SECURITY] Invalid ${e33}: "${t2}" is a reserved JavaScript keyword that could cause prototype pollution`);
      }
      __name(A, "A");
      function T(t2, e33) {
        return "boolean" == typeof t2 ? { enabled: t2, maxEntitySize: 1e4, maxExpansionDepth: 1e4, maxTotalExpansions: 1 / 0, maxExpandedLength: 1e5, maxEntityCount: 1e3, allowedTags: null, tagFilter: null, appliesTo: "all" } : "object" == typeof t2 && null !== t2 ? { enabled: false !== t2.enabled, maxEntitySize: Math.max(1, t2.maxEntitySize ?? 1e4), maxExpansionDepth: Math.max(1, t2.maxExpansionDepth ?? 1e4), maxTotalExpansions: Math.max(1, t2.maxTotalExpansions ?? 1 / 0), maxExpandedLength: Math.max(1, t2.maxExpandedLength ?? 1e5), maxEntityCount: Math.max(1, t2.maxEntityCount ?? 1e3), allowedTags: t2.allowedTags ?? null, tagFilter: t2.tagFilter ?? null, appliesTo: t2.appliesTo ?? "all" } : T(true);
      }
      __name(T, "T");
      const C = /* @__PURE__ */ __name(function(t2) {
        const e33 = Object.assign({}, _, t2), n11 = [{ value: e33.attributeNamePrefix, name: "attributeNamePrefix" }, { value: e33.attributesGroupName, name: "attributesGroupName" }, { value: e33.textNodeName, name: "textNodeName" }, { value: e33.cdataPropName, name: "cdataPropName" }, { value: e33.commentPropName, name: "commentPropName" }];
        for (const { value: t3, name: e34 } of n11) t3 && A(t3, e34);
        return null === e33.onDangerousProperty && (e33.onDangerousProperty = S), e33.processEntities = T(e33.processEntities, e33.htmlEntities), e33.unpairedTagsSet = new Set(e33.unpairedTags), e33.stopNodes && Array.isArray(e33.stopNodes) && (e33.stopNodes = e33.stopNodes.map((t3) => "string" == typeof t3 && t3.startsWith("*.") ? ".." + t3.substring(2) : t3)), e33;
      }, "C");
      let P;
      P = "function" != typeof Symbol ? "@@xmlMetadata" : /* @__PURE__ */ Symbol("XML Node Metadata");
      class O {
        static {
          __name(this, "O");
        }
        constructor(t2) {
          this.tagname = t2, this.child = [], this[":@"] = /* @__PURE__ */ Object.create(null);
        }
        add(t2, e33) {
          "__proto__" === t2 && (t2 = "#__proto__"), this.child.push({ [t2]: e33 });
        }
        addChild(t2, e33) {
          "__proto__" === t2.tagname && (t2.tagname = "#__proto__"), t2[":@"] && Object.keys(t2[":@"]).length > 0 ? this.child.push({ [t2.tagname]: t2.child, ":@": t2[":@"] }) : this.child.push({ [t2.tagname]: t2.child }), void 0 !== e33 && (this.child[this.child.length - 1][P] = { startIndex: e33 });
        }
        static getMetaDataSymbol() {
          return P;
        }
      }
      class $ {
        static {
          __name(this, "$");
        }
        constructor(t2) {
          this.suppressValidationErr = !t2, this.options = t2;
        }
        readDocType(t2, e33) {
          const n11 = /* @__PURE__ */ Object.create(null);
          let i33 = 0;
          if ("O" !== t2[e33 + 3] || "C" !== t2[e33 + 4] || "T" !== t2[e33 + 5] || "Y" !== t2[e33 + 6] || "P" !== t2[e33 + 7] || "E" !== t2[e33 + 8]) throw new Error("Invalid Tag instead of DOCTYPE");
          {
            e33 += 9;
            let s2 = 1, r33 = false, o11 = false, a33 = "";
            for (; e33 < t2.length; e33++) if ("<" !== t2[e33] || o11) if (">" === t2[e33]) {
              if (o11 ? "-" === t2[e33 - 1] && "-" === t2[e33 - 2] && (o11 = false, s2--) : s2--, 0 === s2) break;
            } else "[" === t2[e33] ? r33 = true : a33 += t2[e33];
            else {
              if (r33 && D(t2, "!ENTITY", e33)) {
                let s3, r34;
                if (e33 += 7, [s3, r34, e33] = this.readEntityExp(t2, e33 + 1, this.suppressValidationErr), -1 === r34.indexOf("&")) {
                  if (false !== this.options.enabled && null != this.options.maxEntityCount && i33 >= this.options.maxEntityCount) throw new Error(`Entity count (${i33 + 1}) exceeds maximum allowed (${this.options.maxEntityCount})`);
                  n11[s3] = r34, i33++;
                }
              } else if (r33 && D(t2, "!ELEMENT", e33)) {
                e33 += 8;
                const { index: n12 } = this.readElementExp(t2, e33 + 1);
                e33 = n12;
              } else if (r33 && D(t2, "!ATTLIST", e33)) e33 += 8;
              else if (r33 && D(t2, "!NOTATION", e33)) {
                e33 += 9;
                const { index: n12 } = this.readNotationExp(t2, e33 + 1, this.suppressValidationErr);
                e33 = n12;
              } else {
                if (!D(t2, "!--", e33)) throw new Error("Invalid DOCTYPE");
                o11 = true;
              }
              s2++, a33 = "";
            }
            if (0 !== s2) throw new Error("Unclosed DOCTYPE");
          }
          return { entities: n11, i: e33 };
        }
        readEntityExp(t2, e33) {
          const n11 = e33 = I(t2, e33);
          for (; e33 < t2.length && !/\s/.test(t2[e33]) && '"' !== t2[e33] && "'" !== t2[e33]; ) e33++;
          let i33 = t2.substring(n11, e33);
          if (M(i33), e33 = I(t2, e33), !this.suppressValidationErr) {
            if ("SYSTEM" === t2.substring(e33, e33 + 6).toUpperCase()) throw new Error("External entities are not supported");
            if ("%" === t2[e33]) throw new Error("Parameter entities are not supported");
          }
          let s2 = "";
          if ([e33, s2] = this.readIdentifierVal(t2, e33, "entity"), false !== this.options.enabled && null != this.options.maxEntitySize && s2.length > this.options.maxEntitySize) throw new Error(`Entity "${i33}" size (${s2.length}) exceeds maximum allowed size (${this.options.maxEntitySize})`);
          return [i33, s2, --e33];
        }
        readNotationExp(t2, e33) {
          const n11 = e33 = I(t2, e33);
          for (; e33 < t2.length && !/\s/.test(t2[e33]); ) e33++;
          let i33 = t2.substring(n11, e33);
          !this.suppressValidationErr && M(i33), e33 = I(t2, e33);
          const s2 = t2.substring(e33, e33 + 6).toUpperCase();
          if (!this.suppressValidationErr && "SYSTEM" !== s2 && "PUBLIC" !== s2) throw new Error(`Expected SYSTEM or PUBLIC, found "${s2}"`);
          e33 += s2.length, e33 = I(t2, e33);
          let r33 = null, o11 = null;
          if ("PUBLIC" === s2) [e33, r33] = this.readIdentifierVal(t2, e33, "publicIdentifier"), '"' !== t2[e33 = I(t2, e33)] && "'" !== t2[e33] || ([e33, o11] = this.readIdentifierVal(t2, e33, "systemIdentifier"));
          else if ("SYSTEM" === s2 && ([e33, o11] = this.readIdentifierVal(t2, e33, "systemIdentifier"), !this.suppressValidationErr && !o11)) throw new Error("Missing mandatory system identifier for SYSTEM notation");
          return { notationName: i33, publicIdentifier: r33, systemIdentifier: o11, index: --e33 };
        }
        readIdentifierVal(t2, e33, n11) {
          let i33 = "";
          const s2 = t2[e33];
          if ('"' !== s2 && "'" !== s2) throw new Error(`Expected quoted string, found "${s2}"`);
          const r33 = ++e33;
          for (; e33 < t2.length && t2[e33] !== s2; ) e33++;
          if (i33 = t2.substring(r33, e33), t2[e33] !== s2) throw new Error(`Unterminated ${n11} value`);
          return [++e33, i33];
        }
        readElementExp(t2, e33) {
          const n11 = e33 = I(t2, e33);
          for (; e33 < t2.length && !/\s/.test(t2[e33]); ) e33++;
          let i33 = t2.substring(n11, e33);
          if (!this.suppressValidationErr && !r32(i33)) throw new Error(`Invalid element name: "${i33}"`);
          let s2 = "";
          if ("E" === t2[e33 = I(t2, e33)] && D(t2, "MPTY", e33)) e33 += 4;
          else if ("A" === t2[e33] && D(t2, "NY", e33)) e33 += 2;
          else if ("(" === t2[e33]) {
            const n12 = ++e33;
            for (; e33 < t2.length && ")" !== t2[e33]; ) e33++;
            if (s2 = t2.substring(n12, e33), ")" !== t2[e33]) throw new Error("Unterminated content model");
          } else if (!this.suppressValidationErr) throw new Error(`Invalid Element Expression, found "${t2[e33]}"`);
          return { elementName: i33, contentModel: s2.trim(), index: e33 };
        }
        readAttlistExp(t2, e33) {
          let n11 = e33 = I(t2, e33);
          for (; e33 < t2.length && !/\s/.test(t2[e33]); ) e33++;
          let i33 = t2.substring(n11, e33);
          for (M(i33), n11 = e33 = I(t2, e33); e33 < t2.length && !/\s/.test(t2[e33]); ) e33++;
          let s2 = t2.substring(n11, e33);
          if (!M(s2)) throw new Error(`Invalid attribute name: "${s2}"`);
          e33 = I(t2, e33);
          let r33 = "";
          if ("NOTATION" === t2.substring(e33, e33 + 8).toUpperCase()) {
            if (r33 = "NOTATION", "(" !== t2[e33 = I(t2, e33 += 8)]) throw new Error(`Expected '(', found "${t2[e33]}"`);
            e33++;
            let n12 = [];
            for (; e33 < t2.length && ")" !== t2[e33]; ) {
              const i34 = e33;
              for (; e33 < t2.length && "|" !== t2[e33] && ")" !== t2[e33]; ) e33++;
              let s3 = t2.substring(i34, e33);
              if (s3 = s3.trim(), !M(s3)) throw new Error(`Invalid notation name: "${s3}"`);
              n12.push(s3), "|" === t2[e33] && (e33++, e33 = I(t2, e33));
            }
            if (")" !== t2[e33]) throw new Error("Unterminated list of notations");
            e33++, r33 += " (" + n12.join("|") + ")";
          } else {
            const n12 = e33;
            for (; e33 < t2.length && !/\s/.test(t2[e33]); ) e33++;
            r33 += t2.substring(n12, e33);
            const i34 = ["CDATA", "ID", "IDREF", "IDREFS", "ENTITY", "ENTITIES", "NMTOKEN", "NMTOKENS"];
            if (!this.suppressValidationErr && !i34.includes(r33.toUpperCase())) throw new Error(`Invalid attribute type: "${r33}"`);
          }
          e33 = I(t2, e33);
          let o11 = "";
          return "#REQUIRED" === t2.substring(e33, e33 + 8).toUpperCase() ? (o11 = "#REQUIRED", e33 += 8) : "#IMPLIED" === t2.substring(e33, e33 + 7).toUpperCase() ? (o11 = "#IMPLIED", e33 += 7) : [e33, o11] = this.readIdentifierVal(t2, e33, "ATTLIST"), { elementName: i33, attributeName: s2, attributeType: r33, defaultValue: o11, index: e33 };
        }
      }
      const I = /* @__PURE__ */ __name((t2, e33) => {
        for (; e33 < t2.length && /\s/.test(t2[e33]); ) e33++;
        return e33;
      }, "I");
      function D(t2, e33, n11) {
        for (let i33 = 0; i33 < e33.length; i33++) if (e33[i33] !== t2[n11 + i33 + 1]) return false;
        return true;
      }
      __name(D, "D");
      function M(t2) {
        if (r32(t2)) return t2;
        throw new Error(`Invalid entity name ${t2}`);
      }
      __name(M, "M");
      const j32 = /^[-+]?0x[a-fA-F0-9]+$/, V = /^([\-\+])?(0*)([0-9]*(\.[0-9]*)?)$/, L = { hex: true, leadingZeros: true, decimalPoint: ".", eNotation: true, infinity: "original" };
      const k32 = /^([-+])?(0*)(\d*(\.\d*)?[eE][-\+]?\d+)$/;
      class F {
        static {
          __name(this, "F");
        }
        constructor(t2) {
          this._matcher = t2;
        }
        get separator() {
          return this._matcher.separator;
        }
        getCurrentTag() {
          const t2 = this._matcher.path;
          return t2.length > 0 ? t2[t2.length - 1].tag : void 0;
        }
        getCurrentNamespace() {
          const t2 = this._matcher.path;
          return t2.length > 0 ? t2[t2.length - 1].namespace : void 0;
        }
        getAttrValue(t2) {
          const e33 = this._matcher.path;
          if (0 !== e33.length) return e33[e33.length - 1].values?.[t2];
        }
        hasAttr(t2) {
          const e33 = this._matcher.path;
          if (0 === e33.length) return false;
          const n11 = e33[e33.length - 1];
          return void 0 !== n11.values && t2 in n11.values;
        }
        getPosition() {
          const t2 = this._matcher.path;
          return 0 === t2.length ? -1 : t2[t2.length - 1].position ?? 0;
        }
        getCounter() {
          const t2 = this._matcher.path;
          return 0 === t2.length ? -1 : t2[t2.length - 1].counter ?? 0;
        }
        getIndex() {
          return this.getPosition();
        }
        getDepth() {
          return this._matcher.path.length;
        }
        toString(t2, e33 = true) {
          return this._matcher.toString(t2, e33);
        }
        toArray() {
          return this._matcher.path.map((t2) => t2.tag);
        }
        matches(t2) {
          return this._matcher.matches(t2);
        }
        matchesAny(t2) {
          return t2.matchesAny(this._matcher);
        }
      }
      class R {
        static {
          __name(this, "R");
        }
        constructor(t2 = {}) {
          this.separator = t2.separator || ".", this.path = [], this.siblingStacks = [], this._pathStringCache = null, this._view = new F(this);
        }
        push(t2, e33 = null, n11 = null) {
          this._pathStringCache = null, this.path.length > 0 && (this.path[this.path.length - 1].values = void 0);
          const i33 = this.path.length;
          this.siblingStacks[i33] || (this.siblingStacks[i33] = /* @__PURE__ */ new Map());
          const s2 = this.siblingStacks[i33], r33 = n11 ? `${n11}:${t2}` : t2, o11 = s2.get(r33) || 0;
          let a33 = 0;
          for (const t3 of s2.values()) a33 += t3;
          s2.set(r33, o11 + 1);
          const h33 = { tag: t2, position: a33, counter: o11 };
          null != n11 && (h33.namespace = n11), null != e33 && (h33.values = e33), this.path.push(h33);
        }
        pop() {
          if (0 === this.path.length) return;
          this._pathStringCache = null;
          const t2 = this.path.pop();
          return this.siblingStacks.length > this.path.length + 1 && (this.siblingStacks.length = this.path.length + 1), t2;
        }
        updateCurrent(t2) {
          if (this.path.length > 0) {
            const e33 = this.path[this.path.length - 1];
            null != t2 && (e33.values = t2);
          }
        }
        getCurrentTag() {
          return this.path.length > 0 ? this.path[this.path.length - 1].tag : void 0;
        }
        getCurrentNamespace() {
          return this.path.length > 0 ? this.path[this.path.length - 1].namespace : void 0;
        }
        getAttrValue(t2) {
          if (0 !== this.path.length) return this.path[this.path.length - 1].values?.[t2];
        }
        hasAttr(t2) {
          if (0 === this.path.length) return false;
          const e33 = this.path[this.path.length - 1];
          return void 0 !== e33.values && t2 in e33.values;
        }
        getPosition() {
          return 0 === this.path.length ? -1 : this.path[this.path.length - 1].position ?? 0;
        }
        getCounter() {
          return 0 === this.path.length ? -1 : this.path[this.path.length - 1].counter ?? 0;
        }
        getIndex() {
          return this.getPosition();
        }
        getDepth() {
          return this.path.length;
        }
        toString(t2, e33 = true) {
          const n11 = t2 || this.separator;
          if (n11 === this.separator && true === e33) {
            if (null !== this._pathStringCache) return this._pathStringCache;
            const t3 = this.path.map((t4) => t4.namespace ? `${t4.namespace}:${t4.tag}` : t4.tag).join(n11);
            return this._pathStringCache = t3, t3;
          }
          return this.path.map((t3) => e33 && t3.namespace ? `${t3.namespace}:${t3.tag}` : t3.tag).join(n11);
        }
        toArray() {
          return this.path.map((t2) => t2.tag);
        }
        reset() {
          this._pathStringCache = null, this.path = [], this.siblingStacks = [];
        }
        matches(t2) {
          const e33 = t2.segments;
          return 0 !== e33.length && (t2.hasDeepWildcard() ? this._matchWithDeepWildcard(e33) : this._matchSimple(e33));
        }
        _matchSimple(t2) {
          if (this.path.length !== t2.length) return false;
          for (let e33 = 0; e33 < t2.length; e33++) if (!this._matchSegment(t2[e33], this.path[e33], e33 === this.path.length - 1)) return false;
          return true;
        }
        _matchWithDeepWildcard(t2) {
          let e33 = this.path.length - 1, n11 = t2.length - 1;
          for (; n11 >= 0 && e33 >= 0; ) {
            const i33 = t2[n11];
            if ("deep-wildcard" === i33.type) {
              if (n11--, n11 < 0) return true;
              const i34 = t2[n11];
              let s2 = false;
              for (let t3 = e33; t3 >= 0; t3--) if (this._matchSegment(i34, this.path[t3], t3 === this.path.length - 1)) {
                e33 = t3 - 1, n11--, s2 = true;
                break;
              }
              if (!s2) return false;
            } else {
              if (!this._matchSegment(i33, this.path[e33], e33 === this.path.length - 1)) return false;
              e33--, n11--;
            }
          }
          return n11 < 0;
        }
        _matchSegment(t2, e33, n11) {
          if ("*" !== t2.tag && t2.tag !== e33.tag) return false;
          if (void 0 !== t2.namespace && "*" !== t2.namespace && t2.namespace !== e33.namespace) return false;
          if (void 0 !== t2.attrName) {
            if (!n11) return false;
            if (!e33.values || !(t2.attrName in e33.values)) return false;
            if (void 0 !== t2.attrValue && String(e33.values[t2.attrName]) !== String(t2.attrValue)) return false;
          }
          if (void 0 !== t2.position) {
            if (!n11) return false;
            const i33 = e33.counter ?? 0;
            if ("first" === t2.position && 0 !== i33) return false;
            if ("odd" === t2.position && i33 % 2 != 1) return false;
            if ("even" === t2.position && i33 % 2 != 0) return false;
            if ("nth" === t2.position && i33 !== t2.positionValue) return false;
          }
          return true;
        }
        matchesAny(t2) {
          return t2.matchesAny(this);
        }
        snapshot() {
          return { path: this.path.map((t2) => ({ ...t2 })), siblingStacks: this.siblingStacks.map((t2) => new Map(t2)) };
        }
        restore(t2) {
          this._pathStringCache = null, this.path = t2.path.map((t3) => ({ ...t3 })), this.siblingStacks = t2.siblingStacks.map((t3) => new Map(t3));
        }
        readOnly() {
          return this._view;
        }
      }
      class G {
        static {
          __name(this, "G");
        }
        constructor(t2, e33 = {}, n11) {
          this.pattern = t2, this.separator = e33.separator || ".", this.segments = this._parse(t2), this.data = n11, this._hasDeepWildcard = this.segments.some((t3) => "deep-wildcard" === t3.type), this._hasAttributeCondition = this.segments.some((t3) => void 0 !== t3.attrName), this._hasPositionSelector = this.segments.some((t3) => void 0 !== t3.position);
        }
        _parse(t2) {
          const e33 = [];
          let n11 = 0, i33 = "";
          for (; n11 < t2.length; ) t2[n11] === this.separator ? n11 + 1 < t2.length && t2[n11 + 1] === this.separator ? (i33.trim() && (e33.push(this._parseSegment(i33.trim())), i33 = ""), e33.push({ type: "deep-wildcard" }), n11 += 2) : (i33.trim() && e33.push(this._parseSegment(i33.trim())), i33 = "", n11++) : (i33 += t2[n11], n11++);
          return i33.trim() && e33.push(this._parseSegment(i33.trim())), e33;
        }
        _parseSegment(t2) {
          const e33 = { type: "tag" };
          let n11 = null, i33 = t2;
          const s2 = t2.match(/^([^\[]+)(\[[^\]]*\])(.*)$/);
          if (s2 && (i33 = s2[1] + s2[3], s2[2])) {
            const t3 = s2[2].slice(1, -1);
            t3 && (n11 = t3);
          }
          let r33, o11, a33 = i33;
          if (i33.includes("::")) {
            const e34 = i33.indexOf("::");
            if (r33 = i33.substring(0, e34).trim(), a33 = i33.substring(e34 + 2).trim(), !r33) throw new Error(`Invalid namespace in pattern: ${t2}`);
          }
          let h33 = null;
          if (a33.includes(":")) {
            const t3 = a33.lastIndexOf(":"), e34 = a33.substring(0, t3).trim(), n12 = a33.substring(t3 + 1).trim();
            ["first", "last", "odd", "even"].includes(n12) || /^nth\(\d+\)$/.test(n12) ? (o11 = e34, h33 = n12) : o11 = a33;
          } else o11 = a33;
          if (!o11) throw new Error(`Invalid segment pattern: ${t2}`);
          if (e33.tag = o11, r33 && (e33.namespace = r33), n11) if (n11.includes("=")) {
            const t3 = n11.indexOf("=");
            e33.attrName = n11.substring(0, t3).trim(), e33.attrValue = n11.substring(t3 + 1).trim();
          } else e33.attrName = n11.trim();
          if (h33) {
            const t3 = h33.match(/^nth\((\d+)\)$/);
            t3 ? (e33.position = "nth", e33.positionValue = parseInt(t3[1], 10)) : e33.position = h33;
          }
          return e33;
        }
        get length() {
          return this.segments.length;
        }
        hasDeepWildcard() {
          return this._hasDeepWildcard;
        }
        hasAttributeCondition() {
          return this._hasAttributeCondition;
        }
        hasPositionSelector() {
          return this._hasPositionSelector;
        }
        toString() {
          return this.pattern;
        }
      }
      class B {
        static {
          __name(this, "B");
        }
        constructor() {
          this._byDepthAndTag = /* @__PURE__ */ new Map(), this._wildcardByDepth = /* @__PURE__ */ new Map(), this._deepWildcards = [], this._patterns = /* @__PURE__ */ new Set(), this._sealed = false;
        }
        add(t2) {
          if (this._sealed) throw new TypeError("ExpressionSet is sealed. Create a new ExpressionSet to add more expressions.");
          if (this._patterns.has(t2.pattern)) return this;
          if (this._patterns.add(t2.pattern), t2.hasDeepWildcard()) return this._deepWildcards.push(t2), this;
          const e33 = t2.length, n11 = t2.segments[t2.segments.length - 1], i33 = n11?.tag;
          if (i33 && "*" !== i33) {
            const n12 = `${e33}:${i33}`;
            this._byDepthAndTag.has(n12) || this._byDepthAndTag.set(n12, []), this._byDepthAndTag.get(n12).push(t2);
          } else this._wildcardByDepth.has(e33) || this._wildcardByDepth.set(e33, []), this._wildcardByDepth.get(e33).push(t2);
          return this;
        }
        addAll(t2) {
          for (const e33 of t2) this.add(e33);
          return this;
        }
        has(t2) {
          return this._patterns.has(t2.pattern);
        }
        get size() {
          return this._patterns.size;
        }
        seal() {
          return this._sealed = true, this;
        }
        get isSealed() {
          return this._sealed;
        }
        matchesAny(t2) {
          return null !== this.findMatch(t2);
        }
        findMatch(t2) {
          const e33 = t2.getDepth(), n11 = `${e33}:${t2.getCurrentTag()}`, i33 = this._byDepthAndTag.get(n11);
          if (i33) {
            for (let e34 = 0; e34 < i33.length; e34++) if (t2.matches(i33[e34])) return i33[e34];
          }
          const s2 = this._wildcardByDepth.get(e33);
          if (s2) {
            for (let e34 = 0; e34 < s2.length; e34++) if (t2.matches(s2[e34])) return s2[e34];
          }
          for (let e34 = 0; e34 < this._deepWildcards.length; e34++) if (t2.matches(this._deepWildcards[e34])) return this._deepWildcards[e34];
          return null;
        }
      }
      const U = { cent: "\xA2", pound: "\xA3", curren: "\xA4", yen: "\xA5", euro: "\u20AC", dollar: "$", euro: "\u20AC", fnof: "\u0192", inr: "\u20B9", af: "\u060B", birr: "\u1265\u122D", peso: "\u20B1", rub: "\u20BD", won: "\u20A9", yuan: "\xA5", cedil: "\xB8" }, W = { amp: "&", apos: "'", gt: ">", lt: "<", quot: '"' }, X = { nbsp: "\xA0", copy: "\xA9", reg: "\xAE", trade: "\u2122", mdash: "\u2014", ndash: "\u2013", hellip: "\u2026", laquo: "\xAB", raquo: "\xBB", lsquo: "\u2018", rsquo: "\u2019", ldquo: "\u201C", rdquo: "\u201D", bull: "\u2022", para: "\xB6", sect: "\xA7", deg: "\xB0", frac12: "\xBD", frac14: "\xBC", frac34: "\xBE" }, Y = new Set("!?\\\\/[]$%{}^&*()<>|+");
      function z(t2) {
        if ("#" === t2[0]) throw new Error(`[EntityReplacer] Invalid character '#' in entity name: "${t2}"`);
        for (const e33 of t2) if (Y.has(e33)) throw new Error(`[EntityReplacer] Invalid character '${e33}' in entity name: "${t2}"`);
        return t2;
      }
      __name(z, "z");
      function q10(...t2) {
        const e33 = /* @__PURE__ */ Object.create(null);
        for (const n11 of t2) if (n11) for (const t3 of Object.keys(n11)) {
          const i33 = n11[t3];
          if ("string" == typeof i33) e33[t3] = i33;
          else if (i33 && "object" == typeof i33 && void 0 !== i33.val) {
            const n12 = i33.val;
            "string" == typeof n12 && (e33[t3] = n12);
          }
        }
        return e33;
      }
      __name(q10, "q");
      const Z = "external", J = "base", K = "all", Q = Object.freeze({ allow: 0, leave: 1, remove: 2, throw: 3 }), H = /* @__PURE__ */ new Set([9, 10, 13]);
      class tt {
        static {
          __name(this, "tt");
        }
        constructor(t2 = {}) {
          var e33;
          this._limit = t2.limit || {}, this._maxTotalExpansions = this._limit.maxTotalExpansions || 0, this._maxExpandedLength = this._limit.maxExpandedLength || 0, this._postCheck = "function" == typeof t2.postCheck ? t2.postCheck : (t3) => t3, this._limitTiers = (e33 = this._limit.applyLimitsTo ?? Z) && e33 !== Z ? e33 === K ? /* @__PURE__ */ new Set([K]) : e33 === J ? /* @__PURE__ */ new Set([J]) : Array.isArray(e33) ? new Set(e33) : /* @__PURE__ */ new Set([Z]) : /* @__PURE__ */ new Set([Z]), this._numericAllowed = t2.numericAllowed ?? true, this._baseMap = q10(W, t2.namedEntities || null), this._externalMap = /* @__PURE__ */ Object.create(null), this._inputMap = /* @__PURE__ */ Object.create(null), this._totalExpansions = 0, this._expandedLength = 0, this._removeSet = new Set(t2.remove && Array.isArray(t2.remove) ? t2.remove : []), this._leaveSet = new Set(t2.leave && Array.isArray(t2.leave) ? t2.leave : []);
          const n11 = (function(t3) {
            if (!t3) return { xmlVersion: 1, onLevel: Q.allow, nullLevel: Q.remove };
            const e34 = 1.1 === t3.xmlVersion ? 1.1 : 1, n12 = Q[t3.onNCR] ?? Q.allow, i33 = Q[t3.nullNCR] ?? Q.remove;
            return { xmlVersion: e34, onLevel: n12, nullLevel: Math.max(i33, Q.remove) };
          })(t2.ncr);
          this._ncrXmlVersion = n11.xmlVersion, this._ncrOnLevel = n11.onLevel, this._ncrNullLevel = n11.nullLevel;
        }
        setExternalEntities(t2) {
          if (t2) for (const e33 of Object.keys(t2)) z(e33);
          this._externalMap = q10(t2);
        }
        addExternalEntity(t2, e33) {
          z(t2), "string" == typeof e33 && -1 === e33.indexOf("&") && (this._externalMap[t2] = e33);
        }
        addInputEntities(t2) {
          this._totalExpansions = 0, this._expandedLength = 0, this._inputMap = q10(t2);
        }
        reset() {
          return this._inputMap = /* @__PURE__ */ Object.create(null), this._totalExpansions = 0, this._expandedLength = 0, this;
        }
        setXmlVersion(t2) {
          this._ncrXmlVersion = 1.1 === t2 ? 1.1 : 1;
        }
        decode(t2) {
          if ("string" != typeof t2 || 0 === t2.length) return t2;
          const e33 = t2, n11 = [], i33 = t2.length;
          let s2 = 0, r33 = 0;
          const o11 = this._maxTotalExpansions > 0, a33 = this._maxExpandedLength > 0, h33 = o11 || a33;
          for (; r33 < i33; ) {
            if (38 !== t2.charCodeAt(r33)) {
              r33++;
              continue;
            }
            let e34 = r33 + 1;
            for (; e34 < i33 && 59 !== t2.charCodeAt(e34) && e34 - r33 <= 32; ) e34++;
            if (e34 >= i33 || 59 !== t2.charCodeAt(e34)) {
              r33++;
              continue;
            }
            const l22 = t2.slice(r33 + 1, e34);
            if (0 === l22.length) {
              r33++;
              continue;
            }
            let u2, p11;
            if (this._removeSet.has(l22)) u2 = "", void 0 === p11 && (p11 = Z);
            else {
              if (this._leaveSet.has(l22)) {
                r33++;
                continue;
              }
              if (35 === l22.charCodeAt(0)) {
                const t3 = this._resolveNCR(l22);
                if (void 0 === t3) {
                  r33++;
                  continue;
                }
                u2 = t3, p11 = J;
              } else {
                const t3 = this._resolveName(l22);
                u2 = t3?.value, p11 = t3?.tier;
              }
            }
            if (void 0 !== u2) {
              if (r33 > s2 && n11.push(t2.slice(s2, r33)), n11.push(u2), s2 = e34 + 1, r33 = s2, h33 && this._tierCounts(p11)) {
                if (o11 && (this._totalExpansions++, this._totalExpansions > this._maxTotalExpansions)) throw new Error(`[EntityReplacer] Entity expansion count limit exceeded: ${this._totalExpansions} > ${this._maxTotalExpansions}`);
                if (a33) {
                  const t3 = u2.length - (l22.length + 2);
                  if (t3 > 0 && (this._expandedLength += t3, this._expandedLength > this._maxExpandedLength)) throw new Error(`[EntityReplacer] Expanded content length limit exceeded: ${this._expandedLength} > ${this._maxExpandedLength}`);
                }
              }
            } else r33++;
          }
          s2 < i33 && n11.push(t2.slice(s2));
          const l21 = 0 === n11.length ? t2 : n11.join("");
          return this._postCheck(l21, e33);
        }
        _tierCounts(t2) {
          return !!this._limitTiers.has(K) || this._limitTiers.has(t2);
        }
        _resolveName(t2) {
          return t2 in this._inputMap ? { value: this._inputMap[t2], tier: Z } : t2 in this._externalMap ? { value: this._externalMap[t2], tier: Z } : t2 in this._baseMap ? { value: this._baseMap[t2], tier: J } : void 0;
        }
        _classifyNCR(t2) {
          return 0 === t2 ? this._ncrNullLevel : t2 >= 55296 && t2 <= 57343 || 1 === this._ncrXmlVersion && t2 >= 1 && t2 <= 31 && !H.has(t2) ? Q.remove : -1;
        }
        _applyNCRAction(t2, e33, n11) {
          switch (t2) {
            case Q.allow:
              return String.fromCodePoint(n11);
            case Q.remove:
              return "";
            case Q.leave:
              return;
            case Q.throw:
              throw new Error(`[EntityDecoder] Prohibited numeric character reference &${e33}; (U+${n11.toString(16).toUpperCase().padStart(4, "0")})`);
            default:
              return String.fromCodePoint(n11);
          }
        }
        _resolveNCR(t2) {
          const e33 = t2.charCodeAt(1);
          let n11;
          if (n11 = 120 === e33 || 88 === e33 ? parseInt(t2.slice(2), 16) : parseInt(t2.slice(1), 10), Number.isNaN(n11) || n11 < 0 || n11 > 1114111) return;
          const i33 = this._classifyNCR(n11);
          if (!this._numericAllowed && i33 < Q.remove) return;
          const s2 = -1 === i33 ? this._ncrOnLevel : Math.max(this._ncrOnLevel, i33);
          return this._applyNCRAction(s2, t2, n11);
        }
      }
      function et(t2, e33) {
        if (!t2) return {};
        const n11 = e33.attributesGroupName ? t2[e33.attributesGroupName] : t2;
        if (!n11) return {};
        const i33 = {};
        for (const t3 in n11) t3.startsWith(e33.attributeNamePrefix) ? i33[t3.substring(e33.attributeNamePrefix.length)] = n11[t3] : i33[t3] = n11[t3];
        return i33;
      }
      __name(et, "et");
      function nt(t2) {
        if (!t2 || "string" != typeof t2) return;
        const e33 = t2.indexOf(":");
        if (-1 !== e33 && e33 > 0) {
          const n11 = t2.substring(0, e33);
          if ("xmlns" !== n11) return n11;
        }
      }
      __name(nt, "nt");
      class it {
        static {
          __name(this, "it");
        }
        constructor(t2, e33) {
          var n11;
          this.options = t2, this.currentNode = null, this.tagsNodeStack = [], this.parseXml = ht, this.parseTextData = st, this.resolveNameSpace = rt, this.buildAttributesMap = at, this.isItStopNode = ct, this.replaceEntitiesValue = ut, this.readStopNodeData = mt, this.saveTextToParentTag = pt, this.addChild = lt, this.ignoreAttributesFn = "function" == typeof (n11 = this.options.ignoreAttributes) ? n11 : Array.isArray(n11) ? (t3) => {
            for (const e34 of n11) {
              if ("string" == typeof e34 && t3 === e34) return true;
              if (e34 instanceof RegExp && e34.test(t3)) return true;
            }
          } : () => false, this.entityExpansionCount = 0, this.currentExpandedLength = 0;
          let i33 = { ...W };
          this.options.entityDecoder ? this.entityDecoder = this.options.entityDecoder : ("object" == typeof this.options.htmlEntities ? i33 = this.options.htmlEntities : true === this.options.htmlEntities && (i33 = { ...X, ...U }), this.entityDecoder = new tt({ namedEntities: { ...i33, ...e33 }, numericAllowed: this.options.htmlEntities, limit: { maxTotalExpansions: this.options.processEntities.maxTotalExpansions, maxExpandedLength: this.options.processEntities.maxExpandedLength, applyLimitsTo: this.options.processEntities.appliesTo } })), this.matcher = new R(), this.readonlyMatcher = this.matcher.readOnly(), this.isCurrentNodeStopNode = false, this.stopNodeExpressionsSet = new B();
          const s2 = this.options.stopNodes;
          if (s2 && s2.length > 0) {
            for (let t3 = 0; t3 < s2.length; t3++) {
              const e34 = s2[t3];
              "string" == typeof e34 ? this.stopNodeExpressionsSet.add(new G(e34)) : e34 instanceof G && this.stopNodeExpressionsSet.add(e34);
            }
            this.stopNodeExpressionsSet.seal();
          }
        }
      }
      function st(t2, e33, n11, i33, s2, r33, o11) {
        const a33 = this.options;
        if (void 0 !== t2 && (a33.trimValues && !i33 && (t2 = t2.trim()), t2.length > 0)) {
          o11 || (t2 = this.replaceEntitiesValue(t2, e33, n11));
          const i34 = a33.jPath ? n11.toString() : n11, h33 = a33.tagValueProcessor(e33, t2, i34, s2, r33);
          return null == h33 ? t2 : typeof h33 != typeof t2 || h33 !== t2 ? h33 : a33.trimValues || t2.trim() === t2 ? xt(t2, a33.parseTagValue, a33.numberParseOptions) : t2;
        }
      }
      __name(st, "st");
      function rt(t2) {
        if (this.options.removeNSPrefix) {
          const e33 = t2.split(":"), n11 = "/" === t2.charAt(0) ? "/" : "";
          if ("xmlns" === e33[0]) return "";
          2 === e33.length && (t2 = n11 + e33[1]);
        }
        return t2;
      }
      __name(rt, "rt");
      const ot = new RegExp(`([^\\s=]+)\\s*(=\\s*(['"])([\\s\\S]*?)\\3)?`, "gm");
      function at(t2, e33, n11, i33 = false) {
        const r33 = this.options;
        if (true === i33 || true !== r33.ignoreAttributes && "string" == typeof t2) {
          const i34 = s(t2, ot), o11 = i34.length, a33 = {}, h33 = new Array(o11);
          let l21 = false;
          const u2 = {};
          for (let t3 = 0; t3 < o11; t3++) {
            const e34 = this.resolveNameSpace(i34[t3][1]), s2 = i34[t3][4];
            if (e34.length && void 0 !== s2) {
              let i35 = s2;
              r33.trimValues && (i35 = i35.trim()), i35 = this.replaceEntitiesValue(i35, n11, this.readonlyMatcher), h33[t3] = i35, u2[e34] = i35, l21 = true;
            }
          }
          l21 && "object" == typeof e33 && e33.updateCurrent && e33.updateCurrent(u2);
          const p11 = r33.jPath ? e33.toString() : this.readonlyMatcher;
          let c33 = false;
          for (let t3 = 0; t3 < o11; t3++) {
            const e34 = this.resolveNameSpace(i34[t3][1]);
            if (this.ignoreAttributesFn(e34, p11)) continue;
            let n12 = r33.attributeNamePrefix + e34;
            if (e34.length) if (r33.transformAttributeName && (n12 = r33.transformAttributeName(n12)), n12 = bt(n12, r33), void 0 !== i34[t3][4]) {
              const i35 = h33[t3], s2 = r33.attributeValueProcessor(e34, i35, p11);
              a33[n12] = null == s2 ? i35 : typeof s2 != typeof i35 || s2 !== i35 ? s2 : xt(i35, r33.parseAttributeValue, r33.numberParseOptions), c33 = true;
            } else r33.allowBooleanAttributes && (a33[n12] = true, c33 = true);
          }
          if (!c33) return;
          if (r33.attributesGroupName && !r33.preserveOrder) {
            const t3 = {};
            return t3[r33.attributesGroupName] = a33, t3;
          }
          return a33;
        }
      }
      __name(at, "at");
      const ht = /* @__PURE__ */ __name(function(t2) {
        t2 = t2.replace(/\r\n?/g, "\n");
        const e33 = new O("!xml");
        let n11 = e33, i33 = "";
        this.matcher.reset(), this.entityDecoder.reset(), this.entityExpansionCount = 0, this.currentExpandedLength = 0;
        const s2 = this.options, r33 = new $(s2.processEntities), o11 = t2.length;
        for (let a33 = 0; a33 < o11; a33++) if ("<" === t2[a33]) {
          const h33 = t2.charCodeAt(a33 + 1);
          if (47 === h33) {
            const e34 = dt(t2, ">", a33, "Closing Tag is not closed.");
            let r34 = t2.substring(a33 + 2, e34).trim();
            if (s2.removeNSPrefix) {
              const t3 = r34.indexOf(":");
              -1 !== t3 && (r34 = r34.substr(t3 + 1));
            }
            r34 = Nt(s2.transformTagName, r34, "", s2).tagName, n11 && (i33 = this.saveTextToParentTag(i33, n11, this.readonlyMatcher));
            const o12 = this.matcher.getCurrentTag();
            if (r34 && s2.unpairedTagsSet.has(r34)) throw new Error(`Unpaired tag can not be used as closing tag: </${r34}>`);
            o12 && s2.unpairedTagsSet.has(o12) && (this.matcher.pop(), this.tagsNodeStack.pop()), this.matcher.pop(), this.isCurrentNodeStopNode = false, n11 = this.tagsNodeStack.pop(), i33 = "", a33 = e34;
          } else if (63 === h33) {
            let e34 = gt(t2, a33, false, "?>");
            if (!e34) throw new Error("Pi Tag is not closed.");
            i33 = this.saveTextToParentTag(i33, n11, this.readonlyMatcher);
            const r34 = this.buildAttributesMap(e34.tagExp, this.matcher, e34.tagName, true);
            if (r34) {
              const t3 = r34[this.options.attributeNamePrefix + "version"];
              this.entityDecoder.setXmlVersion(Number(t3) || 1);
            }
            if (s2.ignoreDeclaration && "?xml" === e34.tagName || s2.ignorePiTags) ;
            else {
              const t3 = new O(e34.tagName);
              t3.add(s2.textNodeName, ""), e34.tagName !== e34.tagExp && e34.attrExpPresent && true !== s2.ignoreAttributes && (t3[":@"] = r34), this.addChild(n11, t3, this.readonlyMatcher, a33);
            }
            a33 = e34.closeIndex + 1;
          } else if (33 === h33 && 45 === t2.charCodeAt(a33 + 2) && 45 === t2.charCodeAt(a33 + 3)) {
            const e34 = dt(t2, "-->", a33 + 4, "Comment is not closed.");
            if (s2.commentPropName) {
              const r34 = t2.substring(a33 + 4, e34 - 2);
              i33 = this.saveTextToParentTag(i33, n11, this.readonlyMatcher), n11.add(s2.commentPropName, [{ [s2.textNodeName]: r34 }]);
            }
            a33 = e34;
          } else if (33 === h33 && 68 === t2.charCodeAt(a33 + 2)) {
            const e34 = r33.readDocType(t2, a33);
            this.entityDecoder.addInputEntities(e34.entities), a33 = e34.i;
          } else if (33 === h33 && 91 === t2.charCodeAt(a33 + 2)) {
            const e34 = dt(t2, "]]>", a33, "CDATA is not closed.") - 2, r34 = t2.substring(a33 + 9, e34);
            i33 = this.saveTextToParentTag(i33, n11, this.readonlyMatcher);
            let o12 = this.parseTextData(r34, n11.tagname, this.readonlyMatcher, true, false, true, true);
            null == o12 && (o12 = ""), s2.cdataPropName ? n11.add(s2.cdataPropName, [{ [s2.textNodeName]: r34 }]) : n11.add(s2.textNodeName, o12), a33 = e34 + 2;
          } else {
            let r34 = gt(t2, a33, s2.removeNSPrefix);
            if (!r34) {
              const e34 = t2.substring(Math.max(0, a33 - 50), Math.min(o11, a33 + 50));
              throw new Error(`readTagExp returned undefined at position ${a33}. Context: "${e34}"`);
            }
            let h34 = r34.tagName;
            const l21 = r34.rawTagName;
            let u2 = r34.tagExp, p11 = r34.attrExpPresent, c33 = r34.closeIndex;
            if ({ tagName: h34, tagExp: u2 } = Nt(s2.transformTagName, h34, u2, s2), s2.strictReservedNames && (h34 === s2.commentPropName || h34 === s2.cdataPropName || h34 === s2.textNodeName || h34 === s2.attributesGroupName)) throw new Error(`Invalid tag name: ${h34}`);
            n11 && i33 && "!xml" !== n11.tagname && (i33 = this.saveTextToParentTag(i33, n11, this.readonlyMatcher, false));
            const d33 = n11;
            d33 && s2.unpairedTagsSet.has(d33.tagname) && (n11 = this.tagsNodeStack.pop(), this.matcher.pop());
            let f33 = false;
            u2.length > 0 && u2.lastIndexOf("/") === u2.length - 1 && (f33 = true, "/" === h34[h34.length - 1] ? (h34 = h34.substr(0, h34.length - 1), u2 = h34) : u2 = u2.substr(0, u2.length - 1), p11 = h34 !== u2);
            let g33, m21 = null, x2 = {};
            g33 = nt(l21), h34 !== e33.tagname && this.matcher.push(h34, {}, g33), h34 !== u2 && p11 && (m21 = this.buildAttributesMap(u2, this.matcher, h34), m21 && (x2 = et(m21, s2))), h34 !== e33.tagname && (this.isCurrentNodeStopNode = this.isItStopNode());
            const N2 = a33;
            if (this.isCurrentNodeStopNode) {
              let e34 = "";
              if (f33) a33 = r34.closeIndex;
              else if (s2.unpairedTagsSet.has(h34)) a33 = r34.closeIndex;
              else {
                const n12 = this.readStopNodeData(t2, l21, c33 + 1);
                if (!n12) throw new Error(`Unexpected end of ${l21}`);
                a33 = n12.i, e34 = n12.tagContent;
              }
              const i34 = new O(h34);
              m21 && (i34[":@"] = m21), i34.add(s2.textNodeName, e34), this.matcher.pop(), this.isCurrentNodeStopNode = false, this.addChild(n11, i34, this.readonlyMatcher, N2);
            } else {
              if (f33) {
                ({ tagName: h34, tagExp: u2 } = Nt(s2.transformTagName, h34, u2, s2));
                const t3 = new O(h34);
                m21 && (t3[":@"] = m21), this.addChild(n11, t3, this.readonlyMatcher, N2), this.matcher.pop(), this.isCurrentNodeStopNode = false;
              } else {
                if (s2.unpairedTagsSet.has(h34)) {
                  const t3 = new O(h34);
                  m21 && (t3[":@"] = m21), this.addChild(n11, t3, this.readonlyMatcher, N2), this.matcher.pop(), this.isCurrentNodeStopNode = false, a33 = r34.closeIndex;
                  continue;
                }
                {
                  const t3 = new O(h34);
                  if (this.tagsNodeStack.length > s2.maxNestedTags) throw new Error("Maximum nested tags exceeded");
                  this.tagsNodeStack.push(n11), m21 && (t3[":@"] = m21), this.addChild(n11, t3, this.readonlyMatcher, N2), n11 = t3;
                }
              }
              i33 = "", a33 = c33;
            }
          }
        } else i33 += t2[a33];
        return e33.child;
      }, "ht");
      function lt(t2, e33, n11, i33) {
        this.options.captureMetaData || (i33 = void 0);
        const s2 = this.options.jPath ? n11.toString() : n11, r33 = this.options.updateTag(e33.tagname, s2, e33[":@"]);
        false === r33 || ("string" == typeof r33 ? (e33.tagname = r33, t2.addChild(e33, i33)) : t2.addChild(e33, i33));
      }
      __name(lt, "lt");
      function ut(t2, e33, n11) {
        const i33 = this.options.processEntities;
        if (!i33 || !i33.enabled) return t2;
        if (i33.allowedTags) {
          const s2 = this.options.jPath ? n11.toString() : n11;
          if (!(Array.isArray(i33.allowedTags) ? i33.allowedTags.includes(e33) : i33.allowedTags(e33, s2))) return t2;
        }
        if (i33.tagFilter) {
          const s2 = this.options.jPath ? n11.toString() : n11;
          if (!i33.tagFilter(e33, s2)) return t2;
        }
        return this.entityDecoder.decode(t2);
      }
      __name(ut, "ut");
      function pt(t2, e33, n11, i33) {
        return t2 && (void 0 === i33 && (i33 = 0 === e33.child.length), void 0 !== (t2 = this.parseTextData(t2, e33.tagname, n11, false, !!e33[":@"] && 0 !== Object.keys(e33[":@"]).length, i33)) && "" !== t2 && e33.add(this.options.textNodeName, t2), t2 = ""), t2;
      }
      __name(pt, "pt");
      function ct() {
        return 0 !== this.stopNodeExpressionsSet.size && this.matcher.matchesAny(this.stopNodeExpressionsSet);
      }
      __name(ct, "ct");
      function dt(t2, e33, n11, i33) {
        const s2 = t2.indexOf(e33, n11);
        if (-1 === s2) throw new Error(i33);
        return s2 + e33.length - 1;
      }
      __name(dt, "dt");
      function ft(t2, e33, n11, i33) {
        const s2 = t2.indexOf(e33, n11);
        if (-1 === s2) throw new Error(i33);
        return s2;
      }
      __name(ft, "ft");
      function gt(t2, e33, n11, i33 = ">") {
        const s2 = (function(t3, e34, n12 = ">") {
          let i34 = 0;
          const s3 = t3.length, r34 = n12.charCodeAt(0), o12 = n12.length > 1 ? n12.charCodeAt(1) : -1;
          let a34 = "", h34 = e34;
          for (let n13 = e34; n13 < s3; n13++) {
            const e35 = t3.charCodeAt(n13);
            if (i34) e35 === i34 && (i34 = 0);
            else if (34 === e35 || 39 === e35) i34 = e35;
            else if (e35 === r34) {
              if (-1 === o12) return a34 += t3.substring(h34, n13), { data: a34, index: n13 };
              if (t3.charCodeAt(n13 + 1) === o12) return a34 += t3.substring(h34, n13), { data: a34, index: n13 };
            } else 9 !== e35 || i34 || (a34 += t3.substring(h34, n13) + " ", h34 = n13 + 1);
          }
        })(t2, e33 + 1, i33);
        if (!s2) return;
        let r33 = s2.data;
        const o11 = s2.index, a33 = r33.search(/\s/);
        let h33 = r33, l21 = true;
        -1 !== a33 && (h33 = r33.substring(0, a33), r33 = r33.substring(a33 + 1).trimStart());
        const u2 = h33;
        if (n11) {
          const t3 = h33.indexOf(":");
          -1 !== t3 && (h33 = h33.substr(t3 + 1), l21 = h33 !== s2.data.substr(t3 + 1));
        }
        return { tagName: h33, tagExp: r33, closeIndex: o11, attrExpPresent: l21, rawTagName: u2 };
      }
      __name(gt, "gt");
      function mt(t2, e33, n11) {
        const i33 = n11;
        let s2 = 1;
        const r33 = t2.length;
        for (; n11 < r33; n11++) if ("<" === t2[n11]) {
          const r34 = t2.charCodeAt(n11 + 1);
          if (47 === r34) {
            const r35 = ft(t2, ">", n11, `${e33} is not closed`);
            if (t2.substring(n11 + 2, r35).trim() === e33 && (s2--, 0 === s2)) return { tagContent: t2.substring(i33, n11), i: r35 };
            n11 = r35;
          } else if (63 === r34) n11 = dt(t2, "?>", n11 + 1, "StopNode is not closed.");
          else if (33 === r34 && 45 === t2.charCodeAt(n11 + 2) && 45 === t2.charCodeAt(n11 + 3)) n11 = dt(t2, "-->", n11 + 3, "StopNode is not closed.");
          else if (33 === r34 && 91 === t2.charCodeAt(n11 + 2)) n11 = dt(t2, "]]>", n11, "StopNode is not closed.") - 2;
          else {
            const i34 = gt(t2, n11, false);
            i34 && ((i34 && i34.tagName) === e33 && "/" !== i34.tagExp[i34.tagExp.length - 1] && s2++, n11 = i34.closeIndex);
          }
        }
      }
      __name(mt, "mt");
      function xt(t2, e33, n11) {
        if (e33 && "string" == typeof t2) {
          const e34 = t2.trim();
          return "true" === e34 || "false" !== e34 && (function(t3, e35 = {}) {
            if (e35 = Object.assign({}, L, e35), !t3 || "string" != typeof t3) return t3;
            let n12 = t3.trim();
            if (0 === n12.length) return t3;
            if (void 0 !== e35.skipLike && e35.skipLike.test(n12)) return t3;
            if ("0" === n12) return 0;
            if (e35.hex && j32.test(n12)) return (function(t4) {
              if (parseInt) return parseInt(t4, 16);
              if (Number.parseInt) return Number.parseInt(t4, 16);
              if (window && window.parseInt) return window.parseInt(t4, 16);
              throw new Error("parseInt, Number.parseInt, window.parseInt are not supported");
            })(n12);
            if (isFinite(n12)) {
              if (n12.includes("e") || n12.includes("E")) return (function(t4, e36, n13) {
                if (!n13.eNotation) return t4;
                const i34 = e36.match(k32);
                if (i34) {
                  let s2 = i34[1] || "";
                  const r33 = -1 === i34[3].indexOf("e") ? "E" : "e", o11 = i34[2], a33 = s2 ? t4[o11.length + 1] === r33 : t4[o11.length] === r33;
                  return o11.length > 1 && a33 ? t4 : (1 !== o11.length || !i34[3].startsWith(`.${r33}`) && i34[3][0] !== r33) && o11.length > 0 ? n13.leadingZeros && !a33 ? (e36 = (i34[1] || "") + i34[3], Number(e36)) : t4 : Number(e36);
                }
                return t4;
              })(t3, n12, e35);
              {
                const s2 = V.exec(n12);
                if (s2) {
                  const r33 = s2[1] || "", o11 = s2[2];
                  let a33 = (i33 = s2[3]) && -1 !== i33.indexOf(".") ? ("." === (i33 = i33.replace(/0+$/, "")) ? i33 = "0" : "." === i33[0] ? i33 = "0" + i33 : "." === i33[i33.length - 1] && (i33 = i33.substring(0, i33.length - 1)), i33) : i33;
                  const h33 = r33 ? "." === t3[o11.length + 1] : "." === t3[o11.length];
                  if (!e35.leadingZeros && (o11.length > 1 || 1 === o11.length && !h33)) return t3;
                  {
                    const i34 = Number(n12), s3 = String(i34);
                    if (0 === i34) return i34;
                    if (-1 !== s3.search(/[eE]/)) return e35.eNotation ? i34 : t3;
                    if (-1 !== n12.indexOf(".")) return "0" === s3 || s3 === a33 || s3 === `${r33}${a33}` ? i34 : t3;
                    let h34 = o11 ? a33 : n12;
                    return o11 ? h34 === s3 || r33 + h34 === s3 ? i34 : t3 : h34 === s3 || h34 === r33 + s3 ? i34 : t3;
                  }
                }
                return t3;
              }
            }
            var i33;
            return (function(t4, e36, n13) {
              const i34 = e36 === 1 / 0;
              switch (n13.infinity.toLowerCase()) {
                case "null":
                  return null;
                case "infinity":
                  return e36;
                case "string":
                  return i34 ? "Infinity" : "-Infinity";
                default:
                  return t4;
              }
            })(t3, Number(n12), e35);
          })(t2, n11);
        }
        return void 0 !== t2 ? t2 : "";
      }
      __name(xt, "xt");
      function Nt(t2, e33, n11, i33) {
        if (t2) {
          const i34 = t2(e33);
          n11 === e33 && (n11 = i34), e33 = i34;
        }
        return { tagName: e33 = bt(e33, i33), tagExp: n11 };
      }
      __name(Nt, "Nt");
      function bt(t2, e33) {
        if (a32.includes(t2)) throw new Error(`[SECURITY] Invalid name: "${t2}" is a reserved JavaScript keyword that could cause prototype pollution`);
        return o10.includes(t2) ? e33.onDangerousProperty(t2) : t2;
      }
      __name(bt, "bt");
      const yt = O.getMetaDataSymbol();
      function Et(t2, e33) {
        if (!t2 || "object" != typeof t2) return {};
        if (!e33) return t2;
        const n11 = {};
        for (const i33 in t2) i33.startsWith(e33) ? n11[i33.substring(e33.length)] = t2[i33] : n11[i33] = t2[i33];
        return n11;
      }
      __name(Et, "Et");
      function wt(t2, e33, n11, i33) {
        return vt(t2, e33, n11, i33);
      }
      __name(wt, "wt");
      function vt(t2, e33, n11, i33) {
        let s2;
        const r33 = {};
        for (let o11 = 0; o11 < t2.length; o11++) {
          const a33 = t2[o11], h33 = St(a33);
          if (void 0 !== h33 && h33 !== e33.textNodeName) {
            const t3 = Et(a33[":@"] || {}, e33.attributeNamePrefix);
            n11.push(h33, t3);
          }
          if (h33 === e33.textNodeName) void 0 === s2 ? s2 = a33[h33] : s2 += "" + a33[h33];
          else {
            if (void 0 === h33) continue;
            if (a33[h33]) {
              let t3 = vt(a33[h33], e33, n11, i33);
              const s3 = At(t3, e33);
              if (0 === Object.keys(t3).length && e33.alwaysCreateTextNode && (t3[e33.textNodeName] = ""), a33[":@"] ? _t(t3, a33[":@"], i33, e33) : 1 !== Object.keys(t3).length || void 0 === t3[e33.textNodeName] || e33.alwaysCreateTextNode ? 0 === Object.keys(t3).length && (e33.alwaysCreateTextNode ? t3[e33.textNodeName] = "" : t3 = "") : t3 = t3[e33.textNodeName], void 0 !== a33[yt] && "object" == typeof t3 && null !== t3 && (t3[yt] = a33[yt]), void 0 !== r33[h33] && Object.prototype.hasOwnProperty.call(r33, h33)) Array.isArray(r33[h33]) || (r33[h33] = [r33[h33]]), r33[h33].push(t3);
              else {
                const n12 = e33.jPath ? i33.toString() : i33;
                e33.isArray(h33, n12, s3) ? r33[h33] = [t3] : r33[h33] = t3;
              }
              void 0 !== h33 && h33 !== e33.textNodeName && n11.pop();
            }
          }
        }
        return "string" == typeof s2 ? s2.length > 0 && (r33[e33.textNodeName] = s2) : void 0 !== s2 && (r33[e33.textNodeName] = s2), r33;
      }
      __name(vt, "vt");
      function St(t2) {
        const e33 = Object.keys(t2);
        for (let t3 = 0; t3 < e33.length; t3++) {
          const n11 = e33[t3];
          if (":@" !== n11) return n11;
        }
      }
      __name(St, "St");
      function _t(t2, e33, n11, i33) {
        if (e33) {
          const s2 = Object.keys(e33), r33 = s2.length;
          for (let o11 = 0; o11 < r33; o11++) {
            const r34 = s2[o11], a33 = r34.startsWith(i33.attributeNamePrefix) ? r34.substring(i33.attributeNamePrefix.length) : r34, h33 = i33.jPath ? n11.toString() + "." + a33 : n11;
            i33.isArray(r34, h33, true, true) ? t2[r34] = [e33[r34]] : t2[r34] = e33[r34];
          }
        }
      }
      __name(_t, "_t");
      function At(t2, e33) {
        const { textNodeName: n11 } = e33, i33 = Object.keys(t2).length;
        return 0 === i33 || !(1 !== i33 || !t2[n11] && "boolean" != typeof t2[n11] && 0 !== t2[n11]);
      }
      __name(At, "At");
      class Tt {
        static {
          __name(this, "Tt");
        }
        constructor(t2) {
          this.externalEntities = {}, this.options = C(t2);
        }
        parse(t2, e33) {
          if ("string" != typeof t2 && t2.toString) t2 = t2.toString();
          else if ("string" != typeof t2) throw new Error("XML data is accepted in String or Bytes[] form.");
          if (e33) {
            true === e33 && (e33 = {});
            const n12 = l20(t2, e33);
            if (true !== n12) throw Error(`${n12.err.msg}:${n12.err.line}:${n12.err.col}`);
          }
          const n11 = new it(this.options, this.externalEntities), i33 = n11.parseXml(t2);
          return this.options.preserveOrder || void 0 === i33 ? i33 : wt(i33, this.options, n11.matcher, n11.readonlyMatcher);
        }
        addEntity(t2, e33) {
          if (-1 !== e33.indexOf("&")) throw new Error("Entity value can't have '&'");
          if (-1 !== t2.indexOf("&") || -1 !== t2.indexOf(";")) throw new Error("An entity must be set without '&' and ';'. Eg. use '#xD' for '&#xD;'");
          if ("&" === e33) throw new Error("An entity with value '&' is not permitted");
          this.externalEntities[t2] = e33;
        }
        static getMetaDataSymbol() {
          return O.getMetaDataSymbol();
        }
      }
      function Ct(t2) {
        return String(t2).replace(/--/g, "- -").replace(/--/g, "- -").replace(/-$/, "- ");
      }
      __name(Ct, "Ct");
      function Pt(t2) {
        return String(t2).replace(/\]\]>/g, "]]]]><![CDATA[>");
      }
      __name(Pt, "Pt");
      function Ot(t2) {
        return String(t2).replace(/"/g, "&quot;").replace(/'/g, "&apos;");
      }
      __name(Ot, "Ot");
      function $t(t2, e33) {
        let n11 = "";
        e33.format && e33.indentBy.length > 0 && (n11 = "\n");
        const i33 = [];
        if (e33.stopNodes && Array.isArray(e33.stopNodes)) for (let t3 = 0; t3 < e33.stopNodes.length; t3++) {
          const n12 = e33.stopNodes[t3];
          "string" == typeof n12 ? i33.push(new G(n12)) : n12 instanceof G && i33.push(n12);
        }
        return It(t2, e33, n11, new R(), i33);
      }
      __name($t, "$t");
      function It(t2, e33, n11, i33, s2) {
        let r33 = "", o11 = false;
        if (e33.maxNestedTags && i33.getDepth() > e33.maxNestedTags) throw new Error("Maximum nested tags exceeded");
        if (!Array.isArray(t2)) {
          if (null != t2) {
            let n12 = t2.toString();
            return n12 = Ft(n12, e33), n12;
          }
          return "";
        }
        for (let a33 = 0; a33 < t2.length; a33++) {
          const h33 = t2[a33], l21 = Vt(h33);
          if (void 0 === l21) continue;
          const u2 = Dt(h33[":@"], e33);
          i33.push(l21, u2);
          const p11 = kt(i33, s2);
          if (l21 === e33.textNodeName) {
            let t3 = h33[l21];
            p11 || (t3 = e33.tagValueProcessor(l21, t3), t3 = Ft(t3, e33)), o11 && (r33 += n11), r33 += t3, o11 = false, i33.pop();
            continue;
          }
          if (l21 === e33.cdataPropName) {
            o11 && (r33 += n11), r33 += `<![CDATA[${Pt(h33[l21][0][e33.textNodeName])}]]>`, o11 = false, i33.pop();
            continue;
          }
          if (l21 === e33.commentPropName) {
            r33 += n11 + `<!--${Ct(h33[l21][0][e33.textNodeName])}-->`, o11 = true, i33.pop();
            continue;
          }
          if ("?" === l21[0]) {
            const t3 = Lt(h33[":@"], e33, p11), s3 = "?xml" === l21 ? "" : n11;
            let a34 = h33[l21][0][e33.textNodeName];
            a34 = 0 !== a34.length ? " " + a34 : "", r33 += s3 + `<${l21}${a34}${t3}?>`, o11 = true, i33.pop();
            continue;
          }
          let c33 = n11;
          "" !== c33 && (c33 += e33.indentBy);
          const d33 = n11 + `<${l21}${Lt(h33[":@"], e33, p11)}`;
          let f33;
          f33 = p11 ? Mt(h33[l21], e33) : It(h33[l21], e33, c33, i33, s2), -1 !== e33.unpairedTags.indexOf(l21) ? e33.suppressUnpairedNode ? r33 += d33 + ">" : r33 += d33 + "/>" : f33 && 0 !== f33.length || !e33.suppressEmptyNode ? f33 && f33.endsWith(">") ? r33 += d33 + `>${f33}${n11}</${l21}>` : (r33 += d33 + ">", f33 && "" !== n11 && (f33.includes("/>") || f33.includes("</")) ? r33 += n11 + e33.indentBy + f33 + n11 : r33 += f33, r33 += `</${l21}>`) : r33 += d33 + "/>", o11 = true, i33.pop();
        }
        return r33;
      }
      __name(It, "It");
      function Dt(t2, e33) {
        if (!t2 || e33.ignoreAttributes) return null;
        const n11 = {};
        let i33 = false;
        for (let s2 in t2) Object.prototype.hasOwnProperty.call(t2, s2) && (n11[s2.startsWith(e33.attributeNamePrefix) ? s2.substr(e33.attributeNamePrefix.length) : s2] = Ot(t2[s2]), i33 = true);
        return i33 ? n11 : null;
      }
      __name(Dt, "Dt");
      function Mt(t2, e33) {
        if (!Array.isArray(t2)) return null != t2 ? t2.toString() : "";
        let n11 = "";
        for (let i33 = 0; i33 < t2.length; i33++) {
          const s2 = t2[i33], r33 = Vt(s2);
          if (r33 === e33.textNodeName) n11 += s2[r33];
          else if (r33 === e33.cdataPropName) n11 += s2[r33][0][e33.textNodeName];
          else if (r33 === e33.commentPropName) n11 += s2[r33][0][e33.textNodeName];
          else {
            if (r33 && "?" === r33[0]) continue;
            if (r33) {
              const t3 = jt(s2[":@"], e33), i34 = Mt(s2[r33], e33);
              i34 && 0 !== i34.length ? n11 += `<${r33}${t3}>${i34}</${r33}>` : n11 += `<${r33}${t3}/>`;
            }
          }
        }
        return n11;
      }
      __name(Mt, "Mt");
      function jt(t2, e33) {
        let n11 = "";
        if (t2 && !e33.ignoreAttributes) for (let i33 in t2) {
          if (!Object.prototype.hasOwnProperty.call(t2, i33)) continue;
          let s2 = t2[i33];
          true === s2 && e33.suppressBooleanAttributes ? n11 += ` ${i33.substr(e33.attributeNamePrefix.length)}` : n11 += ` ${i33.substr(e33.attributeNamePrefix.length)}="${Ot(s2)}"`;
        }
        return n11;
      }
      __name(jt, "jt");
      function Vt(t2) {
        const e33 = Object.keys(t2);
        for (let n11 = 0; n11 < e33.length; n11++) {
          const i33 = e33[n11];
          if (Object.prototype.hasOwnProperty.call(t2, i33) && ":@" !== i33) return i33;
        }
      }
      __name(Vt, "Vt");
      function Lt(t2, e33, n11) {
        let i33 = "";
        if (t2 && !e33.ignoreAttributes) for (let s2 in t2) {
          if (!Object.prototype.hasOwnProperty.call(t2, s2)) continue;
          let r33;
          n11 ? r33 = t2[s2] : (r33 = e33.attributeValueProcessor(s2, t2[s2]), r33 = Ft(r33, e33)), true === r33 && e33.suppressBooleanAttributes ? i33 += ` ${s2.substr(e33.attributeNamePrefix.length)}` : i33 += ` ${s2.substr(e33.attributeNamePrefix.length)}="${Ot(r33)}"`;
        }
        return i33;
      }
      __name(Lt, "Lt");
      function kt(t2, e33) {
        if (!e33 || 0 === e33.length) return false;
        for (let n11 = 0; n11 < e33.length; n11++) if (t2.matches(e33[n11])) return true;
        return false;
      }
      __name(kt, "kt");
      function Ft(t2, e33) {
        if (t2 && t2.length > 0 && e33.processEntities) for (let n11 = 0; n11 < e33.entities.length; n11++) {
          const i33 = e33.entities[n11];
          t2 = t2.replace(i33.regex, i33.val);
        }
        return t2;
      }
      __name(Ft, "Ft");
      const Rt = { attributeNamePrefix: "@_", attributesGroupName: false, textNodeName: "#text", ignoreAttributes: true, cdataPropName: false, format: false, indentBy: "  ", suppressEmptyNode: false, suppressUnpairedNode: true, suppressBooleanAttributes: true, tagValueProcessor: /* @__PURE__ */ __name(function(t2, e33) {
        return e33;
      }, "tagValueProcessor"), attributeValueProcessor: /* @__PURE__ */ __name(function(t2, e33) {
        return e33;
      }, "attributeValueProcessor"), preserveOrder: false, commentPropName: false, unpairedTags: [], entities: [{ regex: new RegExp("&", "g"), val: "&amp;" }, { regex: new RegExp(">", "g"), val: "&gt;" }, { regex: new RegExp("<", "g"), val: "&lt;" }, { regex: new RegExp("'", "g"), val: "&apos;" }, { regex: new RegExp('"', "g"), val: "&quot;" }], processEntities: true, stopNodes: [], oneListGroup: false, maxNestedTags: 100, jPath: true };
      function Gt(t2) {
        if (this.options = Object.assign({}, Rt, t2), this.options.stopNodes && Array.isArray(this.options.stopNodes) && (this.options.stopNodes = this.options.stopNodes.map((t3) => "string" == typeof t3 && t3.startsWith("*.") ? ".." + t3.substring(2) : t3)), this.stopNodeExpressions = [], this.options.stopNodes && Array.isArray(this.options.stopNodes)) for (let t3 = 0; t3 < this.options.stopNodes.length; t3++) {
          const e34 = this.options.stopNodes[t3];
          "string" == typeof e34 ? this.stopNodeExpressions.push(new G(e34)) : e34 instanceof G && this.stopNodeExpressions.push(e34);
        }
        var e33;
        true === this.options.ignoreAttributes || this.options.attributesGroupName ? this.isAttribute = function() {
          return false;
        } : (this.ignoreAttributesFn = "function" == typeof (e33 = this.options.ignoreAttributes) ? e33 : Array.isArray(e33) ? (t3) => {
          for (const n11 of e33) {
            if ("string" == typeof n11 && t3 === n11) return true;
            if (n11 instanceof RegExp && n11.test(t3)) return true;
          }
        } : () => false, this.attrPrefixLen = this.options.attributeNamePrefix.length, this.isAttribute = Wt), this.processTextOrObjNode = Bt, this.options.format ? (this.indentate = Ut, this.tagEndChar = ">\n", this.newLine = "\n") : (this.indentate = function() {
          return "";
        }, this.tagEndChar = ">", this.newLine = "");
      }
      __name(Gt, "Gt");
      function Bt(t2, e33, n11, i33) {
        const s2 = this.extractAttributes(t2);
        if (i33.push(e33, s2), this.checkStopNode(i33)) {
          const s3 = this.buildRawContent(t2), r34 = this.buildAttributesForStopNode(t2);
          return i33.pop(), this.buildObjectNode(s3, e33, r34, n11);
        }
        const r33 = this.j2x(t2, n11 + 1, i33);
        return i33.pop(), void 0 !== t2[this.options.textNodeName] && 1 === Object.keys(t2).length ? this.buildTextValNode(t2[this.options.textNodeName], e33, r33.attrStr, n11, i33) : this.buildObjectNode(r33.val, e33, r33.attrStr, n11);
      }
      __name(Bt, "Bt");
      function Ut(t2) {
        return this.options.indentBy.repeat(t2);
      }
      __name(Ut, "Ut");
      function Wt(t2) {
        return !(!t2.startsWith(this.options.attributeNamePrefix) || t2 === this.options.textNodeName) && t2.substr(this.attrPrefixLen);
      }
      __name(Wt, "Wt");
      Gt.prototype.build = function(t2) {
        if (this.options.preserveOrder) return $t(t2, this.options);
        {
          Array.isArray(t2) && this.options.arrayNodeName && this.options.arrayNodeName.length > 1 && (t2 = { [this.options.arrayNodeName]: t2 });
          const e33 = new R();
          return this.j2x(t2, 0, e33).val;
        }
      }, Gt.prototype.j2x = function(t2, e33, n11) {
        let i33 = "", s2 = "";
        if (this.options.maxNestedTags && n11.getDepth() >= this.options.maxNestedTags) throw new Error("Maximum nested tags exceeded");
        const r33 = this.options.jPath ? n11.toString() : n11, o11 = this.checkStopNode(n11);
        for (let a33 in t2) if (Object.prototype.hasOwnProperty.call(t2, a33)) if (void 0 === t2[a33]) this.isAttribute(a33) && (s2 += "");
        else if (null === t2[a33]) this.isAttribute(a33) || a33 === this.options.cdataPropName || a33 === this.options.commentPropName ? s2 += "" : "?" === a33[0] ? s2 += this.indentate(e33) + "<" + a33 + "?" + this.tagEndChar : s2 += this.indentate(e33) + "<" + a33 + "/" + this.tagEndChar;
        else if (t2[a33] instanceof Date) s2 += this.buildTextValNode(t2[a33], a33, "", e33, n11);
        else if ("object" != typeof t2[a33]) {
          const h33 = this.isAttribute(a33);
          if (h33 && !this.ignoreAttributesFn(h33, r33)) i33 += this.buildAttrPairStr(h33, "" + t2[a33], o11);
          else if (!h33) if (a33 === this.options.textNodeName) {
            let e34 = this.options.tagValueProcessor(a33, "" + t2[a33]);
            s2 += this.replaceEntitiesValue(e34);
          } else {
            n11.push(a33);
            const i34 = this.checkStopNode(n11);
            if (n11.pop(), i34) {
              const n12 = "" + t2[a33];
              s2 += "" === n12 ? this.indentate(e33) + "<" + a33 + this.closeTag(a33) + this.tagEndChar : this.indentate(e33) + "<" + a33 + ">" + n12 + "</" + a33 + this.tagEndChar;
            } else s2 += this.buildTextValNode(t2[a33], a33, "", e33, n11);
          }
        } else if (Array.isArray(t2[a33])) {
          const i34 = t2[a33].length;
          let r34 = "", o12 = "";
          for (let h33 = 0; h33 < i34; h33++) {
            const i35 = t2[a33][h33];
            if (void 0 === i35) ;
            else if (null === i35) "?" === a33[0] ? s2 += this.indentate(e33) + "<" + a33 + "?" + this.tagEndChar : s2 += this.indentate(e33) + "<" + a33 + "/" + this.tagEndChar;
            else if ("object" == typeof i35) if (this.options.oneListGroup) {
              n11.push(a33);
              const t3 = this.j2x(i35, e33 + 1, n11);
              n11.pop(), r34 += t3.val, this.options.attributesGroupName && i35.hasOwnProperty(this.options.attributesGroupName) && (o12 += t3.attrStr);
            } else r34 += this.processTextOrObjNode(i35, a33, e33, n11);
            else if (this.options.oneListGroup) {
              let t3 = this.options.tagValueProcessor(a33, i35);
              t3 = this.replaceEntitiesValue(t3), r34 += t3;
            } else {
              n11.push(a33);
              const t3 = this.checkStopNode(n11);
              if (n11.pop(), t3) {
                const t4 = "" + i35;
                r34 += "" === t4 ? this.indentate(e33) + "<" + a33 + this.closeTag(a33) + this.tagEndChar : this.indentate(e33) + "<" + a33 + ">" + t4 + "</" + a33 + this.tagEndChar;
              } else r34 += this.buildTextValNode(i35, a33, "", e33, n11);
            }
          }
          this.options.oneListGroup && (r34 = this.buildObjectNode(r34, a33, o12, e33)), s2 += r34;
        } else if (this.options.attributesGroupName && a33 === this.options.attributesGroupName) {
          const e34 = Object.keys(t2[a33]), n12 = e34.length;
          for (let s3 = 0; s3 < n12; s3++) i33 += this.buildAttrPairStr(e34[s3], "" + t2[a33][e34[s3]], o11);
        } else s2 += this.processTextOrObjNode(t2[a33], a33, e33, n11);
        return { attrStr: i33, val: s2 };
      }, Gt.prototype.buildAttrPairStr = function(t2, e33, n11) {
        return n11 || (e33 = this.options.attributeValueProcessor(t2, "" + e33), e33 = this.replaceEntitiesValue(e33)), this.options.suppressBooleanAttributes && "true" === e33 ? " " + t2 : " " + t2 + '="' + Ot(e33) + '"';
      }, Gt.prototype.extractAttributes = function(t2) {
        if (!t2 || "object" != typeof t2) return null;
        const e33 = {};
        let n11 = false;
        if (this.options.attributesGroupName && t2[this.options.attributesGroupName]) {
          const i33 = t2[this.options.attributesGroupName];
          for (let t3 in i33) Object.prototype.hasOwnProperty.call(i33, t3) && (e33[t3.startsWith(this.options.attributeNamePrefix) ? t3.substring(this.options.attributeNamePrefix.length) : t3] = Ot(i33[t3]), n11 = true);
        } else for (let i33 in t2) {
          if (!Object.prototype.hasOwnProperty.call(t2, i33)) continue;
          const s2 = this.isAttribute(i33);
          s2 && (e33[s2] = Ot(t2[i33]), n11 = true);
        }
        return n11 ? e33 : null;
      }, Gt.prototype.buildRawContent = function(t2) {
        if ("string" == typeof t2) return t2;
        if ("object" != typeof t2 || null === t2) return String(t2);
        if (void 0 !== t2[this.options.textNodeName]) return t2[this.options.textNodeName];
        let e33 = "";
        for (let n11 in t2) {
          if (!Object.prototype.hasOwnProperty.call(t2, n11)) continue;
          if (this.isAttribute(n11)) continue;
          if (this.options.attributesGroupName && n11 === this.options.attributesGroupName) continue;
          const i33 = t2[n11];
          if (n11 === this.options.textNodeName) e33 += i33;
          else if (Array.isArray(i33)) {
            for (let t3 of i33) if ("string" == typeof t3 || "number" == typeof t3) e33 += `<${n11}>${t3}</${n11}>`;
            else if ("object" == typeof t3 && null !== t3) {
              const i34 = this.buildRawContent(t3), s2 = this.buildAttributesForStopNode(t3);
              e33 += "" === i34 ? `<${n11}${s2}/>` : `<${n11}${s2}>${i34}</${n11}>`;
            }
          } else if ("object" == typeof i33 && null !== i33) {
            const t3 = this.buildRawContent(i33), s2 = this.buildAttributesForStopNode(i33);
            e33 += "" === t3 ? `<${n11}${s2}/>` : `<${n11}${s2}>${t3}</${n11}>`;
          } else e33 += `<${n11}>${i33}</${n11}>`;
        }
        return e33;
      }, Gt.prototype.buildAttributesForStopNode = function(t2) {
        if (!t2 || "object" != typeof t2) return "";
        let e33 = "";
        if (this.options.attributesGroupName && t2[this.options.attributesGroupName]) {
          const n11 = t2[this.options.attributesGroupName];
          for (let t3 in n11) {
            if (!Object.prototype.hasOwnProperty.call(n11, t3)) continue;
            const i33 = t3.startsWith(this.options.attributeNamePrefix) ? t3.substring(this.options.attributeNamePrefix.length) : t3, s2 = n11[t3];
            true === s2 && this.options.suppressBooleanAttributes ? e33 += " " + i33 : e33 += " " + i33 + '="' + s2 + '"';
          }
        } else for (let n11 in t2) {
          if (!Object.prototype.hasOwnProperty.call(t2, n11)) continue;
          const i33 = this.isAttribute(n11);
          if (i33) {
            const s2 = t2[n11];
            true === s2 && this.options.suppressBooleanAttributes ? e33 += " " + i33 : e33 += " " + i33 + '="' + s2 + '"';
          }
        }
        return e33;
      }, Gt.prototype.buildObjectNode = function(t2, e33, n11, i33) {
        if ("" === t2) return "?" === e33[0] ? this.indentate(i33) + "<" + e33 + n11 + "?" + this.tagEndChar : this.indentate(i33) + "<" + e33 + n11 + this.closeTag(e33) + this.tagEndChar;
        {
          let s2 = "</" + e33 + this.tagEndChar, r33 = "";
          return "?" === e33[0] && (r33 = "?", s2 = ""), !n11 && "" !== n11 || -1 !== t2.indexOf("<") ? false !== this.options.commentPropName && e33 === this.options.commentPropName && 0 === r33.length ? this.indentate(i33) + `<!--${t2}-->` + this.newLine : this.indentate(i33) + "<" + e33 + n11 + r33 + this.tagEndChar + t2 + this.indentate(i33) + s2 : this.indentate(i33) + "<" + e33 + n11 + r33 + ">" + t2 + s2;
        }
      }, Gt.prototype.closeTag = function(t2) {
        let e33 = "";
        return -1 !== this.options.unpairedTags.indexOf(t2) ? this.options.suppressUnpairedNode || (e33 = "/") : e33 = this.options.suppressEmptyNode ? "/" : `></${t2}`, e33;
      }, Gt.prototype.checkStopNode = function(t2) {
        if (!this.stopNodeExpressions || 0 === this.stopNodeExpressions.length) return false;
        for (let e33 = 0; e33 < this.stopNodeExpressions.length; e33++) if (t2.matches(this.stopNodeExpressions[e33])) return true;
        return false;
      }, Gt.prototype.buildTextValNode = function(t2, e33, n11, i33, s2) {
        if (false !== this.options.cdataPropName && e33 === this.options.cdataPropName) {
          const e34 = Pt(t2);
          return this.indentate(i33) + `<![CDATA[${e34}]]>` + this.newLine;
        }
        if (false !== this.options.commentPropName && e33 === this.options.commentPropName) {
          const e34 = Ct(t2);
          return this.indentate(i33) + `<!--${e34}-->` + this.newLine;
        }
        if ("?" === e33[0]) return this.indentate(i33) + "<" + e33 + n11 + "?" + this.tagEndChar;
        {
          let s3 = this.options.tagValueProcessor(e33, t2);
          return s3 = this.replaceEntitiesValue(s3), "" === s3 ? this.indentate(i33) + "<" + e33 + n11 + this.closeTag(e33) + this.tagEndChar : this.indentate(i33) + "<" + e33 + n11 + ">" + s3 + "</" + e33 + this.tagEndChar;
        }
      }, Gt.prototype.replaceEntitiesValue = function(t2) {
        if (t2 && t2.length > 0 && this.options.processEntities) for (let e33 = 0; e33 < this.options.entities.length; e33++) {
          const n11 = this.options.entities[e33];
          t2 = t2.replace(n11.regex, n11.val);
        }
        return t2;
      };
      const Xt = Gt, Yt = { validate: l20 };
      module2.exports = e32;
    })();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/xml-builder/dist-cjs/xml-external/nodable_entities.js
var require_nodable_entities2 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/xml-builder/dist-cjs/xml-external/nodable_entities.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.EntityDecoderImpl = exports2.CURRENCY = exports2.COMMON_HTML = exports2.XML = void 0;
    exports2.XML = {
      amp: "&",
      apos: "'",
      gt: ">",
      lt: "<",
      quot: '"'
    };
    exports2.COMMON_HTML = {
      nbsp: "\xA0",
      copy: "\xA9",
      reg: "\xAE",
      trade: "\u2122",
      mdash: "\u2014",
      ndash: "\u2013",
      hellip: "\u2026",
      laquo: "\xAB",
      raquo: "\xBB",
      lsquo: "\u2018",
      rsquo: "\u2019",
      ldquo: "\u201C",
      rdquo: "\u201D",
      bull: "\u2022",
      para: "\xB6",
      sect: "\xA7",
      deg: "\xB0",
      frac12: "\xBD",
      frac14: "\xBC",
      frac34: "\xBE"
    };
    exports2.CURRENCY = {
      cent: "\xA2",
      pound: "\xA3",
      curren: "\xA4",
      yen: "\xA5",
      euro: "\u20AC",
      dollar: "$",
      fnof: "\u0192",
      inr: "\u20B9",
      af: "\u060B",
      birr: "\u1265\u122D",
      peso: "\u20B1",
      rub: "\u20BD",
      won: "\u20A9",
      yuan: "\xA5",
      cedil: "\xB8"
    };
    var SPECIAL_CHARS = new Set("!?\\/[]$%{}^&*()<>|+");
    function validateEntityName(name) {
      if (name[0] === "#") {
        throw new Error(`[EntityReplacer] Invalid character '#' in entity name: "${name}"`);
      }
      for (const ch of name) {
        if (SPECIAL_CHARS.has(ch)) {
          throw new Error(`[EntityReplacer] Invalid character '${ch}' in entity name: "${name}"`);
        }
      }
      return name;
    }
    __name(validateEntityName, "validateEntityName");
    function mergeEntityMaps(...maps) {
      const out = /* @__PURE__ */ Object.create(null);
      for (const map5 of maps) {
        if (!map5) {
          continue;
        }
        for (const key of Object.keys(map5)) {
          const raw = map5[key];
          if (typeof raw === "string") {
            out[key] = raw;
          } else if (raw && typeof raw === "object" && raw.val !== void 0) {
            const val = raw.val;
            if (typeof val === "string") {
              out[key] = val;
            }
          }
        }
      }
      return out;
    }
    __name(mergeEntityMaps, "mergeEntityMaps");
    var LIMIT_TIER_EXTERNAL = "external";
    var LIMIT_TIER_BASE = "base";
    var LIMIT_TIER_ALL = "all";
    function parseLimitTiers(raw) {
      if (!raw || raw === LIMIT_TIER_EXTERNAL) {
        return /* @__PURE__ */ new Set([LIMIT_TIER_EXTERNAL]);
      }
      if (raw === LIMIT_TIER_ALL) {
        return /* @__PURE__ */ new Set([LIMIT_TIER_ALL]);
      }
      if (raw === LIMIT_TIER_BASE) {
        return /* @__PURE__ */ new Set([LIMIT_TIER_BASE]);
      }
      if (Array.isArray(raw)) {
        return new Set(raw);
      }
      return /* @__PURE__ */ new Set([LIMIT_TIER_EXTERNAL]);
    }
    __name(parseLimitTiers, "parseLimitTiers");
    var NCR_LEVEL = Object.freeze({ allow: 0, leave: 1, remove: 2, throw: 3 });
    var XML10_ALLOWED_C0 = /* @__PURE__ */ new Set([9, 10, 13]);
    function parseNCRConfig(ncr) {
      if (!ncr) {
        return { xmlVersion: 1, onLevel: NCR_LEVEL.allow, nullLevel: NCR_LEVEL.remove };
      }
      const xmlVersion = ncr.xmlVersion === 1.1 ? 1.1 : 1;
      const onLevel = NCR_LEVEL[ncr.onNCR ?? "allow"] ?? NCR_LEVEL.allow;
      const nullLevel = NCR_LEVEL[ncr.nullNCR ?? "remove"] ?? NCR_LEVEL.remove;
      const clampedNull = Math.max(nullLevel, NCR_LEVEL.remove);
      return { xmlVersion, onLevel, nullLevel: clampedNull };
    }
    __name(parseNCRConfig, "parseNCRConfig");
    var EntityDecoderImpl = class EntityDecoderImpl {
      static {
        __name(this, "EntityDecoderImpl");
      }
      _limit;
      _maxTotalExpansions;
      _maxExpandedLength;
      _postCheck;
      _limitTiers;
      _numericAllowed;
      _baseMap;
      _externalMap;
      _inputMap;
      _totalExpansions;
      _expandedLength;
      _removeSet;
      _leaveSet;
      _ncrXmlVersion;
      _ncrOnLevel;
      _ncrNullLevel;
      constructor(options = {}) {
        this._limit = options.limit || {};
        this._maxTotalExpansions = this._limit.maxTotalExpansions || 0;
        this._maxExpandedLength = this._limit.maxExpandedLength || 0;
        this._postCheck = typeof options.postCheck === "function" ? options.postCheck : (r32) => r32;
        this._limitTiers = parseLimitTiers(this._limit.applyLimitsTo ?? LIMIT_TIER_EXTERNAL);
        this._numericAllowed = options.numericAllowed ?? true;
        this._baseMap = mergeEntityMaps(exports2.XML, options.namedEntities || null);
        this._externalMap = /* @__PURE__ */ Object.create(null);
        this._inputMap = /* @__PURE__ */ Object.create(null);
        this._totalExpansions = 0;
        this._expandedLength = 0;
        this._removeSet = new Set(options.remove && Array.isArray(options.remove) ? options.remove : []);
        this._leaveSet = new Set(options.leave && Array.isArray(options.leave) ? options.leave : []);
        const ncrCfg = parseNCRConfig(options.ncr);
        this._ncrXmlVersion = ncrCfg.xmlVersion;
        this._ncrOnLevel = ncrCfg.onLevel;
        this._ncrNullLevel = ncrCfg.nullLevel;
      }
      setExternalEntities(map5) {
        if (map5) {
          for (const key of Object.keys(map5)) {
            validateEntityName(key);
          }
        }
        this._externalMap = mergeEntityMaps(map5);
      }
      addExternalEntity(key, value) {
        validateEntityName(key);
        if (typeof value === "string" && value.indexOf("&") === -1) {
          this._externalMap[key] = value;
        }
      }
      addInputEntities(map5) {
        this._totalExpansions = 0;
        this._expandedLength = 0;
        this._inputMap = mergeEntityMaps(map5);
      }
      reset() {
        this._inputMap = /* @__PURE__ */ Object.create(null);
        this._totalExpansions = 0;
        this._expandedLength = 0;
        return this;
      }
      setXmlVersion(version) {
        this._ncrXmlVersion = version === "1.1" || version === 1.1 ? 1.1 : 1;
      }
      decode(str) {
        if (typeof str !== "string" || str.length === 0) {
          return str;
        }
        const original = str;
        const chunks2 = [];
        const len = str.length;
        let last = 0;
        let i32 = 0;
        const limitExpansions = this._maxTotalExpansions > 0;
        const limitLength = this._maxExpandedLength > 0;
        const checkLimits = limitExpansions || limitLength;
        while (i32 < len) {
          if (str.charCodeAt(i32) !== 38) {
            i32++;
            continue;
          }
          let j32 = i32 + 1;
          while (j32 < len && str.charCodeAt(j32) !== 59 && j32 - i32 <= 32) {
            j32++;
          }
          if (j32 >= len || str.charCodeAt(j32) !== 59) {
            i32++;
            continue;
          }
          const token = str.slice(i32 + 1, j32);
          if (token.length === 0) {
            i32++;
            continue;
          }
          let replacement;
          let tier;
          if (this._removeSet.has(token)) {
            replacement = "";
            if (tier === void 0) {
              tier = LIMIT_TIER_EXTERNAL;
            }
          } else if (this._leaveSet.has(token)) {
            i32++;
            continue;
          } else if (token.charCodeAt(0) === 35) {
            const ncrResult = this._resolveNCR(token);
            if (ncrResult === void 0) {
              i32++;
              continue;
            }
            replacement = ncrResult;
            tier = LIMIT_TIER_BASE;
          } else {
            const resolved = this._resolveName(token);
            replacement = resolved?.value;
            tier = resolved?.tier;
          }
          if (replacement === void 0) {
            i32++;
            continue;
          }
          if (i32 > last) {
            chunks2.push(str.slice(last, i32));
          }
          chunks2.push(replacement);
          last = j32 + 1;
          i32 = last;
          if (checkLimits && this._tierCounts(tier)) {
            if (limitExpansions) {
              this._totalExpansions++;
              if (this._totalExpansions > this._maxTotalExpansions) {
                throw new Error(`[EntityReplacer] Entity expansion count limit exceeded: ${this._totalExpansions} > ${this._maxTotalExpansions}`);
              }
            }
            if (limitLength) {
              const delta = replacement.length - (token.length + 2);
              if (delta > 0) {
                this._expandedLength += delta;
                if (this._expandedLength > this._maxExpandedLength) {
                  throw new Error(`[EntityReplacer] Expanded content length limit exceeded: ${this._expandedLength} > ${this._maxExpandedLength}`);
                }
              }
            }
          }
        }
        if (last < len) {
          chunks2.push(str.slice(last));
        }
        const result2 = chunks2.length === 0 ? str : chunks2.join("");
        return this._postCheck(result2, original);
      }
      _tierCounts(tier) {
        if (this._limitTiers.has(LIMIT_TIER_ALL)) {
          return true;
        }
        return this._limitTiers.has(tier);
      }
      _resolveName(name) {
        if (name in this._inputMap) {
          return { value: this._inputMap[name], tier: LIMIT_TIER_EXTERNAL };
        }
        if (name in this._externalMap) {
          return { value: this._externalMap[name], tier: LIMIT_TIER_EXTERNAL };
        }
        if (name in this._baseMap) {
          return { value: this._baseMap[name], tier: LIMIT_TIER_BASE };
        }
        return void 0;
      }
      _classifyNCR(cp) {
        if (cp === 0) {
          return this._ncrNullLevel;
        }
        if (cp >= 55296 && cp <= 57343) {
          return NCR_LEVEL.remove;
        }
        if (this._ncrXmlVersion === 1) {
          if (cp >= 1 && cp <= 31 && !XML10_ALLOWED_C0.has(cp)) {
            return NCR_LEVEL.remove;
          }
        }
        return -1;
      }
      _applyNCRAction(action, token, cp) {
        switch (action) {
          case NCR_LEVEL.allow:
            return String.fromCodePoint(cp);
          case NCR_LEVEL.remove:
            return "";
          case NCR_LEVEL.leave:
            return void 0;
          case NCR_LEVEL.throw:
            throw new Error(`[EntityDecoder] Prohibited numeric character reference &${token}; (U+${cp.toString(16).toUpperCase().padStart(4, "0")})`);
          default:
            return String.fromCodePoint(cp);
        }
      }
      _resolveNCR(token) {
        const second = token.charCodeAt(1);
        let cp;
        if (second === 120 || second === 88) {
          cp = parseInt(token.slice(2), 16);
        } else {
          cp = parseInt(token.slice(1), 10);
        }
        if (Number.isNaN(cp) || cp < 0 || cp > 1114111) {
          return void 0;
        }
        const minimum = this._classifyNCR(cp);
        if (!this._numericAllowed && minimum < NCR_LEVEL.remove) {
          return void 0;
        }
        const effective = minimum === -1 ? this._ncrOnLevel : Math.max(this._ncrOnLevel, minimum);
        return this._applyNCRAction(effective, token, cp);
      }
    };
    exports2.EntityDecoderImpl = EntityDecoderImpl;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/xml-builder/dist-cjs/xml-parser.js
var require_xml_parser3 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/xml-builder/dist-cjs/xml-parser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.parseXML = parseXML20;
    var fast_xml_parser_1 = require_fxp3();
    var nodable_entities_1 = require_nodable_entities2();
    var entityDecoder = new nodable_entities_1.EntityDecoderImpl({
      namedEntities: { ...nodable_entities_1.XML, ...nodable_entities_1.COMMON_HTML, ...nodable_entities_1.CURRENCY },
      numericAllowed: true,
      limit: {
        maxTotalExpansions: Infinity
      },
      ncr: {
        xmlVersion: 1.1
      }
    });
    var parser = new fast_xml_parser_1.XMLParser({
      attributeNamePrefix: "",
      processEntities: {
        enabled: true,
        maxTotalExpansions: Infinity
      },
      htmlEntities: true,
      entityDecoder: {
        setExternalEntities: /* @__PURE__ */ __name((entities) => {
          entityDecoder.setExternalEntities(entities);
        }, "setExternalEntities"),
        addInputEntities: /* @__PURE__ */ __name((entities) => {
          entityDecoder.addInputEntities(entities);
        }, "addInputEntities"),
        reset: /* @__PURE__ */ __name(() => {
          entityDecoder.reset();
        }, "reset"),
        decode: /* @__PURE__ */ __name((text) => {
          return entityDecoder.decode(text);
        }, "decode"),
        setXmlVersion: /* @__PURE__ */ __name((version) => void {}, "setXmlVersion")
      },
      ignoreAttributes: false,
      ignoreDeclaration: true,
      parseTagValue: false,
      trimValues: false,
      tagValueProcessor: /* @__PURE__ */ __name((_, val) => val.trim() === "" && val.includes("\n") ? "" : void 0, "tagValueProcessor"),
      maxNestedTags: Infinity
    });
    function parseXML20(xmlString) {
      return parser.parse(xmlString, true);
    }
    __name(parseXML20, "parseXML");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/xml-builder/dist-cjs/index.js
var require_dist_cjs146 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/xml-builder/dist-cjs/index.js"(exports2) {
    "use strict";
    var xmlParser = require_xml_parser3();
    var ATTR_ESCAPE_RE = /[&<>"]/g;
    var ATTR_ESCAPE_MAP = {
      "&": "&amp;",
      "<": "&lt;",
      ">": "&gt;",
      '"': "&quot;"
    };
    function escapeAttribute(value) {
      return value.replace(ATTR_ESCAPE_RE, (ch) => ATTR_ESCAPE_MAP[ch]);
    }
    __name(escapeAttribute, "escapeAttribute");
    var ELEMENT_ESCAPE_RE = /[&"'<>\r\n\u0085\u2028]/g;
    var ELEMENT_ESCAPE_MAP = {
      "&": "&amp;",
      '"': "&quot;",
      "'": "&apos;",
      "<": "&lt;",
      ">": "&gt;",
      "\r": "&#x0D;",
      "\n": "&#x0A;",
      "\x85": "&#x85;",
      "\u2028": "&#x2028;"
    };
    function escapeElement(value) {
      return value.replace(ELEMENT_ESCAPE_RE, (ch) => ELEMENT_ESCAPE_MAP[ch]);
    }
    __name(escapeElement, "escapeElement");
    var XmlText10 = class {
      static {
        __name(this, "XmlText");
      }
      value;
      constructor(value) {
        this.value = value;
      }
      toString() {
        return escapeElement("" + this.value);
      }
    };
    var XmlNode10 = class _XmlNode {
      static {
        __name(this, "XmlNode");
      }
      name;
      children;
      attributes = {};
      static of(name, childText, withName) {
        const node = new _XmlNode(name);
        if (childText !== void 0) {
          node.addChildNode(new XmlText10(childText));
        }
        if (withName !== void 0) {
          node.withName(withName);
        }
        return node;
      }
      constructor(name, children = []) {
        this.name = name;
        this.children = children;
      }
      withName(name) {
        this.name = name;
        return this;
      }
      addAttribute(name, value) {
        this.attributes[name] = value;
        return this;
      }
      addChildNode(child) {
        this.children.push(child);
        return this;
      }
      removeAttribute(name) {
        delete this.attributes[name];
        return this;
      }
      n(name) {
        this.name = name;
        return this;
      }
      c(child) {
        this.children.push(child);
        return this;
      }
      a(name, value) {
        if (value != null) {
          this.attributes[name] = value;
        }
        return this;
      }
      cc(input, field, withName = field) {
        if (input[field] != null) {
          const node = _XmlNode.of(field, input[field]).withName(withName);
          this.c(node);
        }
      }
      l(input, listName, memberName, valueProvider) {
        if (input[listName] != null) {
          const nodes32 = valueProvider();
          nodes32.map((node) => {
            node.withName(memberName);
            this.c(node);
          });
        }
      }
      lc(input, listName, memberName, valueProvider) {
        if (input[listName] != null) {
          const nodes32 = valueProvider();
          const containerNode = new _XmlNode(memberName);
          nodes32.map((node) => {
            containerNode.c(node);
          });
          this.c(containerNode);
        }
      }
      toString() {
        const hasChildren = Boolean(this.children.length);
        let xmlText = `<${this.name}`;
        const attributes = this.attributes;
        for (const attributeName of Object.keys(attributes)) {
          const attribute = attributes[attributeName];
          if (attribute != null) {
            xmlText += ` ${attributeName}="${escapeAttribute("" + attribute)}"`;
          }
        }
        return xmlText += !hasChildren ? "/>" : `>${this.children.map((c32) => c32.toString()).join("")}</${this.name}>`;
      }
    };
    exports2.parseXML = xmlParser.parseXML;
    exports2.XmlNode = XmlNode10;
    exports2.XmlText = XmlText10;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeDeserializer.js
var import_xml_builder17, XmlShapeDeserializer7;
var init_XmlShapeDeserializer8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeDeserializer.js"() {
    import_xml_builder17 = __toESM(require_dist_cjs146());
    init_client12();
    init_protocols11();
    init_schema6();
    init_serde4();
    init_ConfigurableSerdeContext8();
    init_UnionSerde8();
    XmlShapeDeserializer7 = class extends SerdeContextConfig8 {
      static {
        __name(this, "XmlShapeDeserializer");
      }
      settings;
      stringDeserializer;
      constructor(settings) {
        super();
        this.settings = settings;
        this.stringDeserializer = new FromStringShapeDeserializer3(settings);
      }
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
        this.stringDeserializer.setSerdeContext(serdeContext);
      }
      read(schema, bytes, key) {
        const ns = NormalizedSchema3.of(schema);
        const memberSchemas = ns.getMemberSchemas();
        const isEventPayload = ns.isStructSchema() && ns.isMemberSchema() && !!Object.values(memberSchemas).find((memberNs) => {
          return !!memberNs.getMemberTraits().eventPayload;
        });
        if (isEventPayload) {
          const output = {};
          const memberName = Object.keys(memberSchemas)[0];
          const eventMemberSchema = memberSchemas[memberName];
          if (eventMemberSchema.isBlobSchema()) {
            output[memberName] = bytes;
          } else {
            output[memberName] = this.read(memberSchemas[memberName], bytes);
          }
          return output;
        }
        const xmlString = (this.serdeContext?.utf8Encoder ?? toUtf839)(bytes);
        const parsedObject = this.parseXml(xmlString);
        return this.readSchema(schema, key ? parsedObject[key] : parsedObject);
      }
      readSchema(_schema, value) {
        const ns = NormalizedSchema3.of(_schema);
        if (ns.isUnitSchema()) {
          return;
        }
        const traits = ns.getMergedTraits();
        if (ns.isListSchema() && !Array.isArray(value)) {
          return this.readSchema(ns, [value]);
        }
        if (value == null) {
          return value;
        }
        if (typeof value === "object") {
          const flat = !!traits.xmlFlattened;
          if (ns.isListSchema()) {
            const listValue = ns.getValueSchema();
            const buffer2 = [];
            const sourceKey = listValue.getMergedTraits().xmlName ?? "member";
            const source = flat ? value : (value[0] ?? value)[sourceKey];
            if (source == null) {
              return buffer2;
            }
            const sourceArray = Array.isArray(source) ? source : [source];
            for (const v of sourceArray) {
              buffer2.push(this.readSchema(listValue, v));
            }
            return buffer2;
          }
          const buffer = {};
          if (ns.isMapSchema()) {
            const keyNs = ns.getKeySchema();
            const memberNs = ns.getValueSchema();
            let entries;
            if (flat) {
              entries = Array.isArray(value) ? value : [value];
            } else {
              entries = Array.isArray(value.entry) ? value.entry : [value.entry];
            }
            const keyProperty = keyNs.getMergedTraits().xmlName ?? "key";
            const valueProperty = memberNs.getMergedTraits().xmlName ?? "value";
            for (const entry of entries) {
              const key = entry[keyProperty];
              const value2 = entry[valueProperty];
              buffer[key] = this.readSchema(memberNs, value2);
            }
            return buffer;
          }
          if (ns.isStructSchema()) {
            const union = ns.isUnionSchema();
            let unionSerde;
            if (union) {
              unionSerde = new UnionSerde8(value, buffer);
            }
            for (const [memberName, memberSchema] of ns.structIterator()) {
              const memberTraits = memberSchema.getMergedTraits();
              const xmlObjectKey = !memberTraits.httpPayload ? memberSchema.getMemberTraits().xmlName ?? memberName : memberTraits.xmlName ?? memberSchema.getName();
              if (union) {
                unionSerde.mark(xmlObjectKey);
              }
              if (value[xmlObjectKey] != null) {
                buffer[memberName] = this.readSchema(memberSchema, value[xmlObjectKey]);
              }
            }
            if (union) {
              unionSerde.writeUnknown();
            }
            return buffer;
          }
          if (ns.isDocumentSchema()) {
            return value;
          }
          throw new Error(`@aws-sdk/core/protocols - xml deserializer unhandled schema type for ${ns.getName(true)}`);
        }
        if (ns.isListSchema()) {
          return [];
        }
        if (ns.isMapSchema() || ns.isStructSchema()) {
          return {};
        }
        return this.stringDeserializer.read(ns, value);
      }
      parseXml(xml) {
        if (xml.length) {
          let parsedObj;
          try {
            parsedObj = (0, import_xml_builder17.parseXML)(xml);
          } catch (e32) {
            if (e32 && typeof e32 === "object") {
              Object.defineProperty(e32, "$responseBodyText", {
                value: xml
              });
            }
            throw e32;
          }
          const textNodeName = "#text";
          const key = Object.keys(parsedObj)[0];
          const parsedObjToReturn = parsedObj[key];
          if (parsedObjToReturn[textNodeName]) {
            parsedObjToReturn[key] = parsedObjToReturn[textNodeName];
            delete parsedObjToReturn[textNodeName];
          }
          return getValueFromTextNode12(parsedObjToReturn);
        }
        return {};
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QueryShapeSerializer.js
var QueryShapeSerializer7;
var init_QueryShapeSerializer8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QueryShapeSerializer.js"() {
    init_protocols11();
    init_schema6();
    init_serde4();
    init_serde4();
    init_ConfigurableSerdeContext8();
    QueryShapeSerializer7 = class extends SerdeContextConfig8 {
      static {
        __name(this, "QueryShapeSerializer");
      }
      settings;
      buffer;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value, prefix = "") {
        if (this.buffer === void 0) {
          this.buffer = "";
        }
        const ns = NormalizedSchema3.of(schema);
        if (prefix && !prefix.endsWith(".")) {
          prefix += ".";
        }
        if (ns.isBlobSchema()) {
          if (typeof value === "string" || value instanceof Uint8Array) {
            this.writeKey(prefix);
            this.writeValue((this.serdeContext?.base64Encoder ?? toBase6441)(value));
          }
        } else if (ns.isBooleanSchema() || ns.isNumericSchema() || ns.isStringSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(String(value));
          } else if (ns.isIdempotencyToken()) {
            this.writeKey(prefix);
            this.writeValue(generateIdempotencyToken3());
          }
        } else if (ns.isBigIntegerSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(String(value));
          }
        } else if (ns.isBigDecimalSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(value instanceof NumericValue3 ? value.string : String(value));
          }
        } else if (ns.isTimestampSchema()) {
          if (value instanceof Date) {
            this.writeKey(prefix);
            const format32 = determineTimestampFormat3(ns, this.settings);
            switch (format32) {
              case 5:
                this.writeValue(value.toISOString().replace(".000Z", "Z"));
                break;
              case 6:
                this.writeValue(dateToUtcString15(value));
                break;
              case 7:
                this.writeValue(String(value.getTime() / 1e3));
                break;
            }
          }
        } else if (ns.isDocumentSchema()) {
          if (Array.isArray(value)) {
            this.write(64 | 15, value, prefix);
          } else if (value instanceof Date) {
            this.write(4, value, prefix);
          } else if (value instanceof Uint8Array) {
            this.write(21, value, prefix);
          } else if (value && typeof value === "object") {
            this.write(128 | 15, value, prefix);
          } else {
            this.writeKey(prefix);
            this.writeValue(String(value));
          }
        } else if (ns.isListSchema()) {
          if (Array.isArray(value)) {
            if (value.length === 0) {
              if (this.settings.serializeEmptyLists) {
                this.writeKey(prefix);
                this.writeValue("");
              }
            } else {
              const member7 = ns.getValueSchema();
              const flat = this.settings.flattenLists || ns.getMergedTraits().xmlFlattened;
              let i32 = 1;
              for (const item of value) {
                if (item == null) {
                  continue;
                }
                const traits = member7.getMergedTraits();
                const suffix = this.getKey("member", traits.xmlName, traits.ec2QueryName);
                const key = flat ? `${prefix}${i32}` : `${prefix}${suffix}.${i32}`;
                this.write(member7, item, key);
                ++i32;
              }
            }
          }
        } else if (ns.isMapSchema()) {
          if (value && typeof value === "object") {
            const keySchema = ns.getKeySchema();
            const memberSchema = ns.getValueSchema();
            const flat = ns.getMergedTraits().xmlFlattened;
            let i32 = 1;
            for (const k32 in value) {
              const v = value[k32];
              if (v == null) {
                continue;
              }
              const keyTraits = keySchema.getMergedTraits();
              const keySuffix = this.getKey("key", keyTraits.xmlName, keyTraits.ec2QueryName);
              const key = flat ? `${prefix}${i32}.${keySuffix}` : `${prefix}entry.${i32}.${keySuffix}`;
              const valTraits = memberSchema.getMergedTraits();
              const valueSuffix = this.getKey("value", valTraits.xmlName, valTraits.ec2QueryName);
              const valueKey = flat ? `${prefix}${i32}.${valueSuffix}` : `${prefix}entry.${i32}.${valueSuffix}`;
              this.write(keySchema, k32, key);
              this.write(memberSchema, v, valueKey);
              ++i32;
            }
          }
        } else if (ns.isStructSchema()) {
          if (value && typeof value === "object") {
            let didWriteMember = false;
            for (const [memberName, member7] of ns.structIterator()) {
              if (value[memberName] == null && !member7.isIdempotencyToken()) {
                continue;
              }
              const traits = member7.getMergedTraits();
              const suffix = this.getKey(memberName, traits.xmlName, traits.ec2QueryName, "struct");
              const key = `${prefix}${suffix}`;
              this.write(member7, value[memberName], key);
              didWriteMember = true;
            }
            if (!didWriteMember && ns.isUnionSchema()) {
              const { $unknown } = value;
              if (Array.isArray($unknown)) {
                const [k32, v] = $unknown;
                const key = `${prefix}${k32}`;
                this.write(15, v, key);
              }
            }
          }
        } else if (ns.isUnitSchema()) {
        } else {
          throw new Error(`@aws-sdk/core/protocols - QuerySerializer unrecognized schema type ${ns.getName(true)}`);
        }
      }
      flush() {
        if (this.buffer === void 0) {
          throw new Error("@aws-sdk/core/protocols - QuerySerializer cannot flush with nothing written to buffer.");
        }
        const str = this.buffer;
        delete this.buffer;
        return str;
      }
      getKey(memberName, xmlName, ec2QueryName, keySource) {
        const { ec2, capitalizeKeys } = this.settings;
        if (ec2 && ec2QueryName) {
          return ec2QueryName;
        }
        const key = xmlName ?? memberName;
        if (capitalizeKeys && keySource === "struct") {
          return key[0].toUpperCase() + key.slice(1);
        }
        return key;
      }
      writeKey(key) {
        if (key.endsWith(".")) {
          key = key.slice(0, key.length - 1);
        }
        this.buffer += `&${extendedEncodeURIComponent3(key)}=`;
      }
      writeValue(value) {
        this.buffer += extendedEncodeURIComponent3(value);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsQueryProtocol.js
var AwsQueryProtocol7;
var init_AwsQueryProtocol8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsQueryProtocol.js"() {
    init_protocols11();
    init_schema6();
    init_ProtocolLib8();
    init_XmlShapeDeserializer8();
    init_QueryShapeSerializer8();
    AwsQueryProtocol7 = class extends RpcProtocol3 {
      static {
        __name(this, "AwsQueryProtocol");
      }
      options;
      serializer;
      deserializer;
      mixin = new ProtocolLib8();
      constructor(options) {
        super({
          defaultNamespace: options.defaultNamespace,
          errorTypeRegistries: options.errorTypeRegistries
        });
        this.options = options;
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 5
          },
          httpBindings: false,
          xmlNamespace: options.xmlNamespace,
          serviceNamespace: options.defaultNamespace,
          serializeEmptyLists: true
        };
        this.serializer = new QueryShapeSerializer7(settings);
        this.deserializer = new XmlShapeDeserializer7(settings);
      }
      getShapeId() {
        return "aws.protocols#awsQuery";
      }
      setSerdeContext(serdeContext) {
        this.serializer.setSerdeContext(serdeContext);
        this.deserializer.setSerdeContext(serdeContext);
      }
      getPayloadCodec() {
        throw new Error("AWSQuery protocol has no payload codec.");
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        if (!request4.path.endsWith("/")) {
          request4.path += "/";
        }
        request4.headers["content-type"] = "application/x-www-form-urlencoded";
        if (deref3(operationSchema.input) === "unit" || !request4.body) {
          request4.body = "";
        }
        const action = operationSchema.name.split("#")[1] ?? operationSchema.name;
        request4.body = `Action=${action}&Version=${this.options.version}` + request4.body;
        if (request4.body.endsWith("&")) {
          request4.body = request4.body.slice(-1);
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        const deserializer = this.deserializer;
        const ns = NormalizedSchema3.of(operationSchema.output);
        const dataObject = {};
        if (response.statusCode >= 300) {
          const bytes2 = await collectBody10(response.body, context);
          if (bytes2.byteLength > 0) {
            Object.assign(dataObject, await deserializer.read(15, bytes2));
          }
          await this.handleError(operationSchema, context, response, dataObject, this.deserializeMetadata(response));
        }
        for (const header in response.headers) {
          const value = response.headers[header];
          delete response.headers[header];
          response.headers[header.toLowerCase()] = value;
        }
        const shortName = operationSchema.name.split("#")[1] ?? operationSchema.name;
        const awsQueryResultKey = ns.isStructSchema() && this.useNestedResult() ? shortName + "Result" : void 0;
        const bytes = await collectBody10(response.body, context);
        if (bytes.byteLength > 0) {
          Object.assign(dataObject, await deserializer.read(ns, bytes, awsQueryResultKey));
        }
        dataObject.$metadata = this.deserializeMetadata(response);
        return dataObject;
      }
      useNestedResult() {
        return true;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = this.loadQueryErrorCode(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const errorData = this.loadQueryError(dataObject) ?? {};
        const message2 = this.loadQueryErrorMessage(dataObject);
        errorData.message = message2;
        errorData.Error = {
          Type: errorData.Type,
          Code: errorData.Code,
          Message: message2
        };
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, errorData, metadata, this.mixin.findQueryCompatibleError);
        const ns = NormalizedSchema3.of(errorSchema);
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor({});
        const output = {
          Type: errorData.Error.Type,
          Code: errorData.Error.Code,
          Error: errorData.Error
        };
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().xmlName ?? name;
          const value = errorData[target] ?? dataObject[target];
          output[name] = this.deserializer.readSchema(member7, value);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      loadQueryErrorCode(output, data3) {
        const code = (data3.Errors?.[0]?.Error ?? data3.Errors?.Error ?? data3.Error)?.Code;
        if (code !== void 0) {
          return code;
        }
        if (output.statusCode == 404) {
          return "NotFound";
        }
      }
      loadQueryError(data3) {
        return data3.Errors?.[0]?.Error ?? data3.Errors?.Error ?? data3.Error;
      }
      loadQueryErrorMessage(data3) {
        const errorData = this.loadQueryError(data3);
        return errorData?.message ?? errorData?.Message ?? data3.message ?? data3.Message ?? "Unknown";
      }
      getDefaultContentType() {
        return "application/x-www-form-urlencoded";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsEc2QueryProtocol.js
var AwsEc2QueryProtocol6;
var init_AwsEc2QueryProtocol8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsEc2QueryProtocol.js"() {
    init_AwsQueryProtocol8();
    AwsEc2QueryProtocol6 = class extends AwsQueryProtocol7 {
      static {
        __name(this, "AwsEc2QueryProtocol");
      }
      options;
      constructor(options) {
        super(options);
        this.options = options;
        const ec2Settings = {
          capitalizeKeys: true,
          flattenLists: true,
          serializeEmptyLists: false,
          ec2: true
        };
        Object.assign(this.serializer.settings, ec2Settings);
      }
      getShapeId() {
        return "aws.protocols#ec2Query";
      }
      useNestedResult() {
        return false;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QuerySerializerSettings.js
var init_QuerySerializerSettings8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QuerySerializerSettings.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/parseXmlBody.js
var import_xml_builder18, parseXmlBody6, parseXmlErrorBody6, loadRestXmlErrorCode6;
var init_parseXmlBody8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/parseXmlBody.js"() {
    import_xml_builder18 = __toESM(require_dist_cjs146());
    init_client12();
    init_common10();
    parseXmlBody6 = /* @__PURE__ */ __name((streamBody, context) => collectBodyString8(streamBody, context).then((encoded) => {
      if (encoded.length) {
        let parsedObj;
        try {
          parsedObj = (0, import_xml_builder18.parseXML)(encoded);
        } catch (e32) {
          if (e32 && typeof e32 === "object") {
            Object.defineProperty(e32, "$responseBodyText", {
              value: encoded
            });
          }
          throw e32;
        }
        const textNodeName = "#text";
        const key = Object.keys(parsedObj)[0];
        const parsedObjToReturn = parsedObj[key];
        if (parsedObjToReturn[textNodeName]) {
          parsedObjToReturn[key] = parsedObjToReturn[textNodeName];
          delete parsedObjToReturn[textNodeName];
        }
        return getValueFromTextNode12(parsedObjToReturn);
      }
      return {};
    }), "parseXmlBody");
    parseXmlErrorBody6 = /* @__PURE__ */ __name(async (errorBody, context) => {
      const value = await parseXmlBody6(errorBody, context);
      if (value.Error) {
        value.Error.message = value.Error.message ?? value.Error.Message;
      }
      return value;
    }, "parseXmlErrorBody");
    loadRestXmlErrorCode6 = /* @__PURE__ */ __name((output, data3) => {
      if (data3?.Error?.Code !== void 0) {
        return data3.Error.Code;
      }
      if (data3?.Code !== void 0) {
        return data3.Code;
      }
      if (output.statusCode == 404) {
        return "NotFound";
      }
    }, "loadRestXmlErrorCode");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeSerializer.js
var import_xml_builder19, XmlShapeSerializer6;
var init_XmlShapeSerializer8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeSerializer.js"() {
    import_xml_builder19 = __toESM(require_dist_cjs146());
    init_protocols11();
    init_schema6();
    init_serde4();
    init_serde4();
    init_ConfigurableSerdeContext8();
    XmlShapeSerializer6 = class extends SerdeContextConfig8 {
      static {
        __name(this, "XmlShapeSerializer");
      }
      settings;
      stringBuffer;
      byteBuffer;
      buffer;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value) {
        const ns = NormalizedSchema3.of(schema);
        if (ns.isStringSchema() && typeof value === "string") {
          this.stringBuffer = value;
        } else if (ns.isBlobSchema()) {
          this.byteBuffer = "byteLength" in value ? value : (this.serdeContext?.base64Decoder ?? fromBase6436)(value);
        } else {
          this.buffer = this.writeStruct(ns, value, void 0);
          const traits = ns.getMergedTraits();
          if (traits.httpPayload && !traits.xmlName) {
            this.buffer.withName(ns.getName());
          }
        }
      }
      flush() {
        if (this.byteBuffer !== void 0) {
          const bytes = this.byteBuffer;
          delete this.byteBuffer;
          return bytes;
        }
        if (this.stringBuffer !== void 0) {
          const str = this.stringBuffer;
          delete this.stringBuffer;
          return str;
        }
        const buffer = this.buffer;
        if (this.settings.xmlNamespace) {
          if (!buffer?.attributes?.["xmlns"]) {
            buffer.addAttribute("xmlns", this.settings.xmlNamespace);
          }
        }
        delete this.buffer;
        return buffer.toString();
      }
      writeStruct(ns, value, parentXmlns) {
        const traits = ns.getMergedTraits();
        const name = ns.isMemberSchema() && !traits.httpPayload ? ns.getMemberTraits().xmlName ?? ns.getMemberName() : traits.xmlName ?? ns.getName();
        if (!name || !ns.isStructSchema()) {
          throw new Error(`@aws-sdk/core/protocols - xml serializer, cannot write struct with empty name or non-struct, schema=${ns.getName(true)}.`);
        }
        const structXmlNode = import_xml_builder19.XmlNode.of(name);
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(ns, parentXmlns);
        for (const [memberName, memberSchema] of ns.structIterator()) {
          const val = value[memberName];
          if (val != null || memberSchema.isIdempotencyToken()) {
            if (memberSchema.getMergedTraits().xmlAttribute) {
              structXmlNode.addAttribute(memberSchema.getMergedTraits().xmlName ?? memberName, this.writeSimple(memberSchema, val));
              continue;
            }
            if (memberSchema.isListSchema()) {
              this.writeList(memberSchema, val, structXmlNode, xmlns);
            } else if (memberSchema.isMapSchema()) {
              this.writeMap(memberSchema, val, structXmlNode, xmlns);
            } else if (memberSchema.isStructSchema()) {
              structXmlNode.addChildNode(this.writeStruct(memberSchema, val, xmlns));
            } else {
              const memberNode = import_xml_builder19.XmlNode.of(memberSchema.getMergedTraits().xmlName ?? memberSchema.getMemberName());
              this.writeSimpleInto(memberSchema, val, memberNode, xmlns);
              structXmlNode.addChildNode(memberNode);
            }
          }
        }
        const { $unknown } = value;
        if ($unknown && ns.isUnionSchema() && Array.isArray($unknown) && Object.keys(value).length === 1) {
          const [k32, v] = $unknown;
          const node = import_xml_builder19.XmlNode.of(k32);
          if (typeof v !== "string") {
            if (value instanceof import_xml_builder19.XmlNode || value instanceof import_xml_builder19.XmlText) {
              structXmlNode.addChildNode(value);
            } else {
              throw new Error(`@aws-sdk - $unknown union member in XML requires value of type string, @aws-sdk/xml-builder::XmlNode or XmlText.`);
            }
          }
          this.writeSimpleInto(0, v, node, xmlns);
          structXmlNode.addChildNode(node);
        }
        if (xmlns) {
          structXmlNode.addAttribute(xmlnsAttr, xmlns);
        }
        return structXmlNode;
      }
      writeList(listMember, array, container, parentXmlns) {
        if (!listMember.isMemberSchema()) {
          throw new Error(`@aws-sdk/core/protocols - xml serializer, cannot write non-member list: ${listMember.getName(true)}`);
        }
        const listTraits = listMember.getMergedTraits();
        const listValueSchema = listMember.getValueSchema();
        const listValueTraits = listValueSchema.getMergedTraits();
        const sparse = !!listValueTraits.sparse;
        const flat = !!listTraits.xmlFlattened;
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(listMember, parentXmlns);
        const writeItem = /* @__PURE__ */ __name((container2, value) => {
          if (listValueSchema.isListSchema()) {
            this.writeList(listValueSchema, Array.isArray(value) ? value : [value], container2, xmlns);
          } else if (listValueSchema.isMapSchema()) {
            this.writeMap(listValueSchema, value, container2, xmlns);
          } else if (listValueSchema.isStructSchema()) {
            const struct3 = this.writeStruct(listValueSchema, value, xmlns);
            container2.addChildNode(struct3.withName(flat ? listTraits.xmlName ?? listMember.getMemberName() : listValueTraits.xmlName ?? "member"));
          } else {
            const listItemNode = import_xml_builder19.XmlNode.of(flat ? listTraits.xmlName ?? listMember.getMemberName() : listValueTraits.xmlName ?? "member");
            this.writeSimpleInto(listValueSchema, value, listItemNode, xmlns);
            container2.addChildNode(listItemNode);
          }
        }, "writeItem");
        if (flat) {
          for (const value of array) {
            if (sparse || value != null) {
              writeItem(container, value);
            }
          }
        } else {
          const listNode = import_xml_builder19.XmlNode.of(listTraits.xmlName ?? listMember.getMemberName());
          if (xmlns) {
            listNode.addAttribute(xmlnsAttr, xmlns);
          }
          for (const value of array) {
            if (sparse || value != null) {
              writeItem(listNode, value);
            }
          }
          container.addChildNode(listNode);
        }
      }
      writeMap(mapMember, map5, container, parentXmlns, containerIsMap = false) {
        if (!mapMember.isMemberSchema()) {
          throw new Error(`@aws-sdk/core/protocols - xml serializer, cannot write non-member map: ${mapMember.getName(true)}`);
        }
        const mapTraits = mapMember.getMergedTraits();
        const mapKeySchema = mapMember.getKeySchema();
        const mapKeyTraits = mapKeySchema.getMergedTraits();
        const keyTag = mapKeyTraits.xmlName ?? "key";
        const mapValueSchema = mapMember.getValueSchema();
        const mapValueTraits = mapValueSchema.getMergedTraits();
        const valueTag = mapValueTraits.xmlName ?? "value";
        const sparse = !!mapValueTraits.sparse;
        const flat = !!mapTraits.xmlFlattened;
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(mapMember, parentXmlns);
        const addKeyValue = /* @__PURE__ */ __name((entry, key, val) => {
          const keyNode = import_xml_builder19.XmlNode.of(keyTag, key);
          const [keyXmlnsAttr, keyXmlns] = this.getXmlnsAttribute(mapKeySchema, xmlns);
          if (keyXmlns) {
            keyNode.addAttribute(keyXmlnsAttr, keyXmlns);
          }
          entry.addChildNode(keyNode);
          let valueNode = import_xml_builder19.XmlNode.of(valueTag);
          if (mapValueSchema.isListSchema()) {
            this.writeList(mapValueSchema, val, valueNode, xmlns);
          } else if (mapValueSchema.isMapSchema()) {
            this.writeMap(mapValueSchema, val, valueNode, xmlns, true);
          } else if (mapValueSchema.isStructSchema()) {
            valueNode = this.writeStruct(mapValueSchema, val, xmlns);
          } else {
            this.writeSimpleInto(mapValueSchema, val, valueNode, xmlns);
          }
          entry.addChildNode(valueNode);
        }, "addKeyValue");
        if (flat) {
          for (const key in map5) {
            const val = map5[key];
            if (sparse || val != null) {
              const entry = import_xml_builder19.XmlNode.of(mapTraits.xmlName ?? mapMember.getMemberName());
              addKeyValue(entry, key, val);
              container.addChildNode(entry);
            }
          }
        } else {
          let mapNode;
          if (!containerIsMap) {
            mapNode = import_xml_builder19.XmlNode.of(mapTraits.xmlName ?? mapMember.getMemberName());
            if (xmlns) {
              mapNode.addAttribute(xmlnsAttr, xmlns);
            }
            container.addChildNode(mapNode);
          }
          for (const key in map5) {
            const val = map5[key];
            if (sparse || val != null) {
              const entry = import_xml_builder19.XmlNode.of("entry");
              addKeyValue(entry, key, val);
              (containerIsMap ? container : mapNode).addChildNode(entry);
            }
          }
        }
      }
      writeSimple(_schema, value) {
        if (null === value) {
          throw new Error("@aws-sdk/core/protocols - (XML serializer) cannot write null value.");
        }
        const ns = NormalizedSchema3.of(_schema);
        let nodeContents = null;
        if (value && typeof value === "object") {
          if (ns.isBlobSchema()) {
            nodeContents = (this.serdeContext?.base64Encoder ?? toBase6441)(value);
          } else if (ns.isTimestampSchema() && value instanceof Date) {
            const format32 = determineTimestampFormat3(ns, this.settings);
            switch (format32) {
              case 5:
                nodeContents = value.toISOString().replace(".000Z", "Z");
                break;
              case 6:
                nodeContents = dateToUtcString15(value);
                break;
              case 7:
                nodeContents = String(value.getTime() / 1e3);
                break;
              default:
                console.warn("Missing timestamp format, using http date", value);
                nodeContents = dateToUtcString15(value);
                break;
            }
          } else if (ns.isBigDecimalSchema() && value) {
            if (value instanceof NumericValue3) {
              return value.string;
            }
            return String(value);
          } else if (ns.isMapSchema() || ns.isListSchema()) {
            throw new Error("@aws-sdk/core/protocols - xml serializer, cannot call _write() on List/Map schema, call writeList or writeMap() instead.");
          } else {
            throw new Error(`@aws-sdk/core/protocols - xml serializer, unhandled schema type for object value and schema: ${ns.getName(true)}`);
          }
        }
        if (ns.isBooleanSchema() || ns.isNumericSchema() || ns.isBigIntegerSchema() || ns.isBigDecimalSchema()) {
          nodeContents = String(value);
        }
        if (ns.isStringSchema()) {
          if (value === void 0 && ns.isIdempotencyToken()) {
            nodeContents = generateIdempotencyToken3();
          } else {
            nodeContents = String(value);
          }
        }
        if (nodeContents === null) {
          throw new Error(`Unhandled schema-value pair ${ns.getName(true)}=${value}`);
        }
        return nodeContents;
      }
      writeSimpleInto(_schema, value, into, parentXmlns) {
        const nodeContents = this.writeSimple(_schema, value);
        const ns = NormalizedSchema3.of(_schema);
        const content = new import_xml_builder19.XmlText(nodeContents);
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(ns, parentXmlns);
        if (xmlns) {
          into.addAttribute(xmlnsAttr, xmlns);
        }
        into.addChildNode(content);
      }
      getXmlnsAttribute(ns, parentXmlns) {
        const traits = ns.getMergedTraits();
        const [prefix, xmlns] = traits.xmlNamespace ?? [];
        if (xmlns && xmlns !== parentXmlns) {
          return [prefix ? `xmlns:${prefix}` : "xmlns", xmlns];
        }
        return [void 0, void 0];
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlCodec.js
var XmlCodec6;
var init_XmlCodec8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlCodec.js"() {
    init_ConfigurableSerdeContext8();
    init_XmlShapeDeserializer8();
    init_XmlShapeSerializer8();
    XmlCodec6 = class extends SerdeContextConfig8 {
      static {
        __name(this, "XmlCodec");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      createSerializer() {
        const serializer = new XmlShapeSerializer6(this.settings);
        serializer.setSerdeContext(this.serdeContext);
        return serializer;
      }
      createDeserializer() {
        const deserializer = new XmlShapeDeserializer7(this.settings);
        deserializer.setSerdeContext(this.serdeContext);
        return deserializer;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/AwsRestXmlProtocol.js
var AwsRestXmlProtocol6;
var init_AwsRestXmlProtocol8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/AwsRestXmlProtocol.js"() {
    init_protocols11();
    init_schema6();
    init_ProtocolLib8();
    init_parseXmlBody8();
    init_XmlCodec8();
    AwsRestXmlProtocol6 = class extends HttpBindingProtocol3 {
      static {
        __name(this, "AwsRestXmlProtocol");
      }
      codec;
      serializer;
      deserializer;
      mixin = new ProtocolLib8();
      constructor(options) {
        super(options);
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 5
          },
          httpBindings: true,
          xmlNamespace: options.xmlNamespace,
          serviceNamespace: options.defaultNamespace
        };
        this.codec = new XmlCodec6(settings);
        this.serializer = new HttpInterceptingShapeSerializer3(this.codec.createSerializer(), settings);
        this.deserializer = new HttpInterceptingShapeDeserializer3(this.codec.createDeserializer(), settings);
      }
      getPayloadCodec() {
        return this.codec;
      }
      getShapeId() {
        return "aws.protocols#restXml";
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        const inputSchema = NormalizedSchema3.of(operationSchema.input);
        if (!request4.headers["content-type"]) {
          const contentType = this.mixin.resolveRestContentType(this.getDefaultContentType(), inputSchema);
          if (contentType) {
            request4.headers["content-type"] = contentType;
          }
        }
        if (typeof request4.body === "string" && request4.headers["content-type"] === this.getDefaultContentType() && !request4.body.startsWith("<?xml ") && !this.hasUnstructuredPayloadBinding(inputSchema)) {
          request4.body = '<?xml version="1.0" encoding="UTF-8"?>' + request4.body;
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        return super.deserializeResponse(operationSchema, context, response);
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = loadRestXmlErrorCode6(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        if (dataObject.Error && typeof dataObject.Error === "object") {
          for (const key of Object.keys(dataObject.Error)) {
            dataObject[key] = dataObject.Error[key];
            if (key.toLowerCase() === "message") {
              dataObject.message = dataObject.Error[key];
            }
          }
        }
        if (dataObject.RequestId && !metadata.requestId) {
          metadata.requestId = dataObject.RequestId;
        }
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata);
        const ns = NormalizedSchema3.of(errorSchema);
        const message2 = dataObject.Error?.message ?? dataObject.Error?.Message ?? dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor({});
        await this.deserializeHttpMessage(errorSchema, context, response, dataObject);
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().xmlName ?? name;
          const value = dataObject.Error?.[target] ?? dataObject[target];
          output[name] = errorDeserializer.readSchema(member7, value);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      getDefaultContentType() {
        return "application/xml";
      }
      hasUnstructuredPayloadBinding(ns) {
        for (const [, member7] of ns.structIterator()) {
          if (member7.getMergedTraits().httpPayload) {
            return !(member7.isStructSchema() || member7.isMapSchema() || member7.isListSchema());
          }
        }
        return false;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/index.js
var protocols_exports12 = {};
__export(protocols_exports12, {
  AwsEc2QueryProtocol: () => AwsEc2QueryProtocol6,
  AwsJson1_0Protocol: () => AwsJson1_0Protocol6,
  AwsJson1_1Protocol: () => AwsJson1_1Protocol6,
  AwsJsonRpcProtocol: () => AwsJsonRpcProtocol6,
  AwsQueryProtocol: () => AwsQueryProtocol7,
  AwsRestJsonProtocol: () => AwsRestJsonProtocol8,
  AwsRestXmlProtocol: () => AwsRestXmlProtocol6,
  AwsSmithyRpcV2CborProtocol: () => AwsSmithyRpcV2CborProtocol6,
  JsonCodec: () => JsonCodec8,
  JsonShapeDeserializer: () => JsonShapeDeserializer8,
  JsonShapeSerializer: () => JsonShapeSerializer8,
  QueryShapeSerializer: () => QueryShapeSerializer7,
  XmlCodec: () => XmlCodec6,
  XmlShapeDeserializer: () => XmlShapeDeserializer7,
  XmlShapeSerializer: () => XmlShapeSerializer6,
  _toBool: () => _toBool6,
  _toNum: () => _toNum6,
  _toStr: () => _toStr6,
  awsExpectUnion: () => awsExpectUnion6,
  loadJsonRpcErrorCode: () => loadJsonRpcErrorCode,
  loadRestJsonErrorCode: () => loadRestJsonErrorCode8,
  loadRestXmlErrorCode: () => loadRestXmlErrorCode6,
  parseJsonBody: () => parseJsonBody8,
  parseJsonErrorBody: () => parseJsonErrorBody6,
  parseXmlBody: () => parseXmlBody6,
  parseXmlErrorBody: () => parseXmlErrorBody6
});
var init_protocols15 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/core/dist-es/submodules/protocols/index.js"() {
    init_AwsSmithyRpcV2CborProtocol8();
    init_coercing_serializers8();
    init_AwsJson1_0Protocol8();
    init_AwsJson1_1Protocol8();
    init_AwsJsonRpcProtocol8();
    init_AwsRestJsonProtocol8();
    init_JsonCodec8();
    init_JsonShapeDeserializer8();
    init_JsonShapeSerializer8();
    init_awsExpectUnion8();
    init_parseJsonBody8();
    init_AwsEc2QueryProtocol8();
    init_AwsQueryProtocol8();
    init_QuerySerializerSettings8();
    init_QueryShapeSerializer8();
    init_AwsRestXmlProtocol8();
    init_XmlCodec8();
    init_XmlShapeDeserializer8();
    init_XmlShapeSerializer8();
    init_parseXmlBody8();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/endpoint/bdd.js
var k19, a19, b19, c19, d19, e19, f19, g19, h19, i19, j19, _data19, root19, r19, nodes19, bdd19;
var init_bdd19 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/endpoint/bdd.js"() {
    init_endpoints3();
    k19 = "ref";
    a19 = -1;
    b19 = true;
    c19 = "isSet";
    d19 = "PartitionResult";
    e19 = "booleanEquals";
    f19 = "getAttr";
    g19 = { [k19]: "Endpoint" };
    h19 = { [k19]: d19 };
    i19 = {};
    j19 = [{ [k19]: "Region" }];
    _data19 = {
      conditions: [
        [c19, [g19]],
        [c19, j19],
        ["aws.partition", j19, d19],
        [e19, [{ [k19]: "UseFIPS" }, b19]],
        [e19, [{ [k19]: "UseDualStack" }, b19]],
        [e19, [{ fn: f19, argv: [h19, "supportsDualStack"] }, b19]],
        [e19, [{ fn: f19, argv: [h19, "supportsFIPS"] }, b19]],
        ["stringEquals", [{ fn: f19, argv: [h19, "name"] }, "aws-us-gov"]]
      ],
      results: [
        [a19],
        [a19, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a19, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [g19, i19],
        ["https://oidc-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", i19],
        [a19, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://oidc.{Region}.amazonaws.com", i19],
        ["https://oidc-fips.{Region}.{PartitionResult#dnsSuffix}", i19],
        [a19, "FIPS is enabled but this partition does not support FIPS"],
        ["https://oidc.{Region}.{PartitionResult#dualStackDnsSuffix}", i19],
        [a19, "DualStack is enabled but this partition does not support DualStack"],
        ["https://oidc.{Region}.{PartitionResult#dnsSuffix}", i19],
        [a19, "Invalid Configuration: Missing Region"]
      ]
    };
    root19 = 2;
    r19 = 1e8;
    nodes19 = new Int32Array([
      -1,
      1,
      -1,
      0,
      13,
      3,
      1,
      4,
      r19 + 12,
      2,
      5,
      r19 + 12,
      3,
      8,
      6,
      4,
      7,
      r19 + 11,
      5,
      r19 + 9,
      r19 + 10,
      4,
      11,
      9,
      6,
      10,
      r19 + 8,
      7,
      r19 + 6,
      r19 + 7,
      5,
      12,
      r19 + 5,
      6,
      r19 + 4,
      r19 + 5,
      3,
      r19 + 1,
      14,
      4,
      r19 + 2,
      r19 + 3
    ]);
    bdd19 = BinaryDecisionDiagram20.from(nodes19, root19, _data19.conditions, _data19.results);
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/endpoint/endpointResolver.js
var cache19, defaultEndpointResolver19;
var init_endpointResolver19 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/endpoint/endpointResolver.js"() {
    init_client13();
    init_endpoints3();
    init_bdd19();
    cache19 = new EndpointCache20({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    defaultEndpointResolver19 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache19.get(endpointParams, () => decideEndpoint20(bdd19, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    customEndpointFunctions20.aws = awsEndpointFunctions19;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/models/SSOOIDCServiceException.js
var SSOOIDCServiceException3;
var init_SSOOIDCServiceException3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/models/SSOOIDCServiceException.js"() {
    init_client12();
    SSOOIDCServiceException3 = class _SSOOIDCServiceException extends ServiceException {
      static {
        __name(this, "SSOOIDCServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _SSOOIDCServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/models/errors.js
var AccessDeniedException8, AuthorizationPendingException3, ExpiredTokenException8, InternalServerException8, InvalidClientException3, InvalidGrantException3, InvalidRequestException8, InvalidScopeException3, SlowDownException3, UnauthorizedClientException3, UnsupportedGrantTypeException3;
var init_errors19 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/models/errors.js"() {
    init_SSOOIDCServiceException3();
    AccessDeniedException8 = class _AccessDeniedException extends SSOOIDCServiceException3 {
      static {
        __name(this, "AccessDeniedException");
      }
      name = "AccessDeniedException";
      $fault = "client";
      error;
      reason;
      error_description;
      constructor(opts) {
        super({
          name: "AccessDeniedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AccessDeniedException.prototype);
        this.error = opts.error;
        this.reason = opts.reason;
        this.error_description = opts.error_description;
      }
    };
    AuthorizationPendingException3 = class _AuthorizationPendingException extends SSOOIDCServiceException3 {
      static {
        __name(this, "AuthorizationPendingException");
      }
      name = "AuthorizationPendingException";
      $fault = "client";
      error;
      error_description;
      constructor(opts) {
        super({
          name: "AuthorizationPendingException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AuthorizationPendingException.prototype);
        this.error = opts.error;
        this.error_description = opts.error_description;
      }
    };
    ExpiredTokenException8 = class _ExpiredTokenException extends SSOOIDCServiceException3 {
      static {
        __name(this, "ExpiredTokenException");
      }
      name = "ExpiredTokenException";
      $fault = "client";
      error;
      error_description;
      constructor(opts) {
        super({
          name: "ExpiredTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ExpiredTokenException.prototype);
        this.error = opts.error;
        this.error_description = opts.error_description;
      }
    };
    InternalServerException8 = class _InternalServerException extends SSOOIDCServiceException3 {
      static {
        __name(this, "InternalServerException");
      }
      name = "InternalServerException";
      $fault = "server";
      error;
      error_description;
      constructor(opts) {
        super({
          name: "InternalServerException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _InternalServerException.prototype);
        this.error = opts.error;
        this.error_description = opts.error_description;
      }
    };
    InvalidClientException3 = class _InvalidClientException extends SSOOIDCServiceException3 {
      static {
        __name(this, "InvalidClientException");
      }
      name = "InvalidClientException";
      $fault = "client";
      error;
      error_description;
      constructor(opts) {
        super({
          name: "InvalidClientException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidClientException.prototype);
        this.error = opts.error;
        this.error_description = opts.error_description;
      }
    };
    InvalidGrantException3 = class _InvalidGrantException extends SSOOIDCServiceException3 {
      static {
        __name(this, "InvalidGrantException");
      }
      name = "InvalidGrantException";
      $fault = "client";
      error;
      error_description;
      constructor(opts) {
        super({
          name: "InvalidGrantException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidGrantException.prototype);
        this.error = opts.error;
        this.error_description = opts.error_description;
      }
    };
    InvalidRequestException8 = class _InvalidRequestException extends SSOOIDCServiceException3 {
      static {
        __name(this, "InvalidRequestException");
      }
      name = "InvalidRequestException";
      $fault = "client";
      error;
      reason;
      error_description;
      constructor(opts) {
        super({
          name: "InvalidRequestException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidRequestException.prototype);
        this.error = opts.error;
        this.reason = opts.reason;
        this.error_description = opts.error_description;
      }
    };
    InvalidScopeException3 = class _InvalidScopeException extends SSOOIDCServiceException3 {
      static {
        __name(this, "InvalidScopeException");
      }
      name = "InvalidScopeException";
      $fault = "client";
      error;
      error_description;
      constructor(opts) {
        super({
          name: "InvalidScopeException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidScopeException.prototype);
        this.error = opts.error;
        this.error_description = opts.error_description;
      }
    };
    SlowDownException3 = class _SlowDownException extends SSOOIDCServiceException3 {
      static {
        __name(this, "SlowDownException");
      }
      name = "SlowDownException";
      $fault = "client";
      error;
      error_description;
      constructor(opts) {
        super({
          name: "SlowDownException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _SlowDownException.prototype);
        this.error = opts.error;
        this.error_description = opts.error_description;
      }
    };
    UnauthorizedClientException3 = class _UnauthorizedClientException extends SSOOIDCServiceException3 {
      static {
        __name(this, "UnauthorizedClientException");
      }
      name = "UnauthorizedClientException";
      $fault = "client";
      error;
      error_description;
      constructor(opts) {
        super({
          name: "UnauthorizedClientException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnauthorizedClientException.prototype);
        this.error = opts.error;
        this.error_description = opts.error_description;
      }
    };
    UnsupportedGrantTypeException3 = class _UnsupportedGrantTypeException extends SSOOIDCServiceException3 {
      static {
        __name(this, "UnsupportedGrantTypeException");
      }
      name = "UnsupportedGrantTypeException";
      $fault = "client";
      error;
      error_description;
      constructor(opts) {
        super({
          name: "UnsupportedGrantTypeException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnsupportedGrantTypeException.prototype);
        this.error = opts.error;
        this.error_description = opts.error_description;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/schemas/schemas_0.js
var _ADE8, _APE3, _AT8, _CS3, _CT3, _CTR3, _CTRr3, _CV3, _ETE8, _ICE3, _IGE3, _IRE8, _ISE8, _ISEn3, _IT3, _RT8, _SDE3, _UCE3, _UGTE3, _aT13, _c19, _cI8, _cS3, _cV8, _co8, _dC3, _e19, _eI8, _ed3, _gT8, _h13, _hE19, _iT8, _r3, _rT8, _rU8, _s19, _sc3, _se9, _tT8, n019, _s_registry19, SSOOIDCServiceException$3, n0_registry19, AccessDeniedException$8, AuthorizationPendingException$3, ExpiredTokenException$8, InternalServerException$8, InvalidClientException$3, InvalidGrantException$3, InvalidRequestException$8, InvalidScopeException$3, SlowDownException$3, UnauthorizedClientException$3, UnsupportedGrantTypeException$3, errorTypeRegistries19, AccessToken3, ClientSecret3, CodeVerifier3, IdToken3, RefreshToken8, CreateTokenRequest$3, CreateTokenResponse$3, Scopes3, CreateToken$3;
var init_schemas_019 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/schemas/schemas_0.js"() {
    init_schema6();
    init_errors19();
    init_SSOOIDCServiceException3();
    _ADE8 = "AccessDeniedException";
    _APE3 = "AuthorizationPendingException";
    _AT8 = "AccessToken";
    _CS3 = "ClientSecret";
    _CT3 = "CreateToken";
    _CTR3 = "CreateTokenRequest";
    _CTRr3 = "CreateTokenResponse";
    _CV3 = "CodeVerifier";
    _ETE8 = "ExpiredTokenException";
    _ICE3 = "InvalidClientException";
    _IGE3 = "InvalidGrantException";
    _IRE8 = "InvalidRequestException";
    _ISE8 = "InternalServerException";
    _ISEn3 = "InvalidScopeException";
    _IT3 = "IdToken";
    _RT8 = "RefreshToken";
    _SDE3 = "SlowDownException";
    _UCE3 = "UnauthorizedClientException";
    _UGTE3 = "UnsupportedGrantTypeException";
    _aT13 = "accessToken";
    _c19 = "client";
    _cI8 = "clientId";
    _cS3 = "clientSecret";
    _cV8 = "codeVerifier";
    _co8 = "code";
    _dC3 = "deviceCode";
    _e19 = "error";
    _eI8 = "expiresIn";
    _ed3 = "error_description";
    _gT8 = "grantType";
    _h13 = "http";
    _hE19 = "httpError";
    _iT8 = "idToken";
    _r3 = "reason";
    _rT8 = "refreshToken";
    _rU8 = "redirectUri";
    _s19 = "smithy.ts.sdk.synthetic.com.amazonaws.ssooidc";
    _sc3 = "scope";
    _se9 = "server";
    _tT8 = "tokenType";
    n019 = "com.amazonaws.ssooidc";
    _s_registry19 = TypeRegistry3.for(_s19);
    SSOOIDCServiceException$3 = [-3, _s19, "SSOOIDCServiceException", 0, [], []];
    _s_registry19.registerError(SSOOIDCServiceException$3, SSOOIDCServiceException3);
    n0_registry19 = TypeRegistry3.for(n019);
    AccessDeniedException$8 = [
      -3,
      n019,
      _ADE8,
      { [_e19]: _c19, [_hE19]: 400 },
      [_e19, _r3, _ed3],
      [0, 0, 0]
    ];
    n0_registry19.registerError(AccessDeniedException$8, AccessDeniedException8);
    AuthorizationPendingException$3 = [
      -3,
      n019,
      _APE3,
      { [_e19]: _c19, [_hE19]: 400 },
      [_e19, _ed3],
      [0, 0]
    ];
    n0_registry19.registerError(AuthorizationPendingException$3, AuthorizationPendingException3);
    ExpiredTokenException$8 = [-3, n019, _ETE8, { [_e19]: _c19, [_hE19]: 400 }, [_e19, _ed3], [0, 0]];
    n0_registry19.registerError(ExpiredTokenException$8, ExpiredTokenException8);
    InternalServerException$8 = [-3, n019, _ISE8, { [_e19]: _se9, [_hE19]: 500 }, [_e19, _ed3], [0, 0]];
    n0_registry19.registerError(InternalServerException$8, InternalServerException8);
    InvalidClientException$3 = [-3, n019, _ICE3, { [_e19]: _c19, [_hE19]: 401 }, [_e19, _ed3], [0, 0]];
    n0_registry19.registerError(InvalidClientException$3, InvalidClientException3);
    InvalidGrantException$3 = [-3, n019, _IGE3, { [_e19]: _c19, [_hE19]: 400 }, [_e19, _ed3], [0, 0]];
    n0_registry19.registerError(InvalidGrantException$3, InvalidGrantException3);
    InvalidRequestException$8 = [
      -3,
      n019,
      _IRE8,
      { [_e19]: _c19, [_hE19]: 400 },
      [_e19, _r3, _ed3],
      [0, 0, 0]
    ];
    n0_registry19.registerError(InvalidRequestException$8, InvalidRequestException8);
    InvalidScopeException$3 = [-3, n019, _ISEn3, { [_e19]: _c19, [_hE19]: 400 }, [_e19, _ed3], [0, 0]];
    n0_registry19.registerError(InvalidScopeException$3, InvalidScopeException3);
    SlowDownException$3 = [-3, n019, _SDE3, { [_e19]: _c19, [_hE19]: 400 }, [_e19, _ed3], [0, 0]];
    n0_registry19.registerError(SlowDownException$3, SlowDownException3);
    UnauthorizedClientException$3 = [
      -3,
      n019,
      _UCE3,
      { [_e19]: _c19, [_hE19]: 400 },
      [_e19, _ed3],
      [0, 0]
    ];
    n0_registry19.registerError(UnauthorizedClientException$3, UnauthorizedClientException3);
    UnsupportedGrantTypeException$3 = [
      -3,
      n019,
      _UGTE3,
      { [_e19]: _c19, [_hE19]: 400 },
      [_e19, _ed3],
      [0, 0]
    ];
    n0_registry19.registerError(UnsupportedGrantTypeException$3, UnsupportedGrantTypeException3);
    errorTypeRegistries19 = [_s_registry19, n0_registry19];
    AccessToken3 = [0, n019, _AT8, 8, 0];
    ClientSecret3 = [0, n019, _CS3, 8, 0];
    CodeVerifier3 = [0, n019, _CV3, 8, 0];
    IdToken3 = [0, n019, _IT3, 8, 0];
    RefreshToken8 = [0, n019, _RT8, 8, 0];
    CreateTokenRequest$3 = [
      3,
      n019,
      _CTR3,
      0,
      [_cI8, _cS3, _gT8, _dC3, _co8, _rT8, _sc3, _rU8, _cV8],
      [0, [() => ClientSecret3, 0], 0, 0, 0, [() => RefreshToken8, 0], 64 | 0, 0, [() => CodeVerifier3, 0]],
      3
    ];
    CreateTokenResponse$3 = [
      3,
      n019,
      _CTRr3,
      0,
      [_aT13, _tT8, _eI8, _rT8, _iT8],
      [[() => AccessToken3, 0], 0, 1, [() => RefreshToken8, 0], [() => IdToken3, 0]]
    ];
    Scopes3 = 64 | 0;
    CreateToken$3 = [
      9,
      n019,
      _CT3,
      { [_h13]: ["POST", "/token", 200] },
      () => CreateTokenRequest$3,
      () => CreateTokenResponse$3
    ];
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/runtimeConfig.shared.js
var getRuntimeConfig37;
var init_runtimeConfig_shared19 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/runtimeConfig.shared.js"() {
    init_httpAuthSchemes9();
    init_protocols15();
    init_dist_es2();
    init_client12();
    init_protocols11();
    init_serde4();
    init_httpAuthSchemeProvider19();
    init_endpointResolver19();
    init_schemas_019();
    getRuntimeConfig37 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2019-06-10",
        base64Decoder: config2?.base64Decoder ?? fromBase6436,
        base64Encoder: config2?.base64Encoder ?? toBase6441,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver19,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSSOOIDCHttpAuthSchemeProvider3,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer7()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner2()
          }
        ],
        logger: config2?.logger ?? new NoOpLogger20(),
        protocol: config2?.protocol ?? AwsRestJsonProtocol8,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.ssooidc",
          errorTypeRegistries: errorTypeRegistries19,
          version: "2019-06-10",
          serviceTarget: "AWSSSOOIDCService"
        },
        serviceId: config2?.serviceId ?? "SSO OIDC",
        urlParser: config2?.urlParser ?? parseUrl21,
        utf8Decoder: config2?.utf8Decoder ?? fromUtf825,
        utf8Encoder: config2?.utf8Encoder ?? toUtf839
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/runtimeConfig.js
var import_node_http_handler19, getRuntimeConfig38;
var init_runtimeConfig19 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/runtimeConfig.js"() {
    init_package7();
    init_client13();
    init_httpAuthSchemes9();
    init_client12();
    init_config4();
    init_retry3();
    init_serde4();
    import_node_http_handler19 = __toESM(require_dist_cjs144());
    init_runtimeConfig_shared19();
    getRuntimeConfig38 = /* @__PURE__ */ __name((config2) => {
      emitWarningIfUnsupportedVersion28(process.version);
      const defaultsMode = resolveDefaultsModeConfig19(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(loadConfigsForDefaultMode19), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig37(config2);
      emitWarningIfUnsupportedVersion27(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? loadConfig3(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS7, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? calculateBodyLength19,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? createDefaultUserAgentProvider19({ serviceId: clientSharedValues.serviceId, clientVersion: package_default7.version }),
        maxAttempts: config2?.maxAttempts ?? loadConfig3(NODE_MAX_ATTEMPT_CONFIG_OPTIONS20, config2),
        region: config2?.region ?? loadConfig3(NODE_REGION_CONFIG_OPTIONS20, { ...NODE_REGION_CONFIG_FILE_OPTIONS20, ...loaderConfig }),
        requestHandler: import_node_http_handler19.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? loadConfig3({
          ...NODE_RETRY_MODE_CONFIG_OPTIONS20,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || DEFAULT_RETRY_MODE20, "default")
        }, config2),
        sha256: config2?.sha256 ?? Hash19.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? import_node_http_handler19.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? loadConfig3(NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS19, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? loadConfig3(NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS19, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? loadConfig3(NODE_APP_ID_CONFIG_OPTIONS19, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration19, resolveHttpAuthRuntimeConfig19;
var init_httpAuthExtensionConfiguration19 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration19 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig19 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/runtimeExtensions.js
var resolveRuntimeExtensions19;
var init_runtimeExtensions19 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/runtimeExtensions.js"() {
    init_client13();
    init_client12();
    init_protocols11();
    init_httpAuthExtensionConfiguration19();
    resolveRuntimeExtensions19 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign(getAwsRegionExtensionConfiguration19(runtimeConfig), getDefaultExtensionConfiguration19(runtimeConfig), getHttpHandlerExtensionConfiguration20(runtimeConfig), getHttpAuthExtensionConfiguration19(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, resolveAwsRegionExtensionConfiguration19(extensionConfiguration), resolveDefaultRuntimeConfig19(extensionConfiguration), resolveHttpHandlerRuntimeConfig20(extensionConfiguration), resolveHttpAuthRuntimeConfig19(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/SSOOIDCClient.js
var SSOOIDCClient3;
var init_SSOOIDCClient3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/SSOOIDCClient.js"() {
    init_client13();
    init_dist_es2();
    init_client12();
    init_config4();
    init_endpoints3();
    init_protocols11();
    init_retry3();
    init_schema6();
    init_httpAuthSchemeProvider19();
    init_EndpointParameters19();
    init_runtimeConfig19();
    init_runtimeExtensions19();
    SSOOIDCClient3 = class extends Client {
      static {
        __name(this, "SSOOIDCClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig38(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters19(_config_0);
        const _config_2 = resolveUserAgentConfig19(_config_1);
        const _config_3 = resolveRetryConfig20(_config_2);
        const _config_4 = resolveRegionConfig19(_config_3);
        const _config_5 = resolveHostHeaderConfig19(_config_4);
        const _config_6 = resolveEndpointConfig20(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig19(_config_6);
        const _config_8 = resolveRuntimeExtensions19(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin2(this.config));
        this.middlewareStack.use(getUserAgentPlugin19(this.config));
        this.middlewareStack.use(getRetryPlugin20(this.config));
        this.middlewareStack.use(getContentLengthPlugin20(this.config));
        this.middlewareStack.use(getHostHeaderPlugin19(this.config));
        this.middlewareStack.use(getLoggerPlugin19(this.config));
        this.middlewareStack.use(getRecursionDetectionPlugin19(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin2(this.config, {
          httpAuthSchemeParametersProvider: defaultSSOOIDCHttpAuthSchemeParametersProvider3,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig2({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin2(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/commands/CreateTokenCommand.js
var CreateTokenCommand3;
var init_CreateTokenCommand3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/commands/CreateTokenCommand.js"() {
    init_client12();
    init_endpoints3();
    init_EndpointParameters19();
    init_schemas_019();
    CreateTokenCommand3 = class extends Command.classBuilder().ep(commonParams19).m(function(Command3, cs, config2, o10) {
      return [getEndpointPlugin26(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSSOOIDCService", "CreateToken", {}).n("SSOOIDCClient", "CreateTokenCommand").sc(CreateToken$3).build() {
      static {
        __name(this, "CreateTokenCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/SSOOIDC.js
var commands19, SSOOIDC3;
var init_SSOOIDC3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/SSOOIDC.js"() {
    init_client12();
    init_CreateTokenCommand3();
    init_SSOOIDCClient3();
    commands19 = {
      CreateTokenCommand: CreateTokenCommand3
    };
    SSOOIDC3 = class extends SSOOIDCClient3 {
      static {
        __name(this, "SSOOIDC");
      }
    };
    createAggregatedClient19(commands19, SSOOIDC3);
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/commands/index.js
var init_commands20 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/commands/index.js"() {
    init_CreateTokenCommand3();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/models/enums.js
var AccessDeniedExceptionReason3, InvalidRequestExceptionReason3;
var init_enums8 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/models/enums.js"() {
    AccessDeniedExceptionReason3 = {
      KMS_ACCESS_DENIED: "KMS_AccessDeniedException"
    };
    InvalidRequestExceptionReason3 = {
      KMS_DISABLED_KEY: "KMS_DisabledException",
      KMS_INVALID_KEY_USAGE: "KMS_InvalidKeyUsageException",
      KMS_INVALID_STATE: "KMS_InvalidStateException",
      KMS_KEY_NOT_FOUND: "KMS_NotFoundException"
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/models/models_0.js
var init_models_019 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/index.js
var sso_oidc_exports3 = {};
__export(sso_oidc_exports3, {
  $Command: () => Command,
  AccessDeniedException: () => AccessDeniedException8,
  AccessDeniedException$: () => AccessDeniedException$8,
  AccessDeniedExceptionReason: () => AccessDeniedExceptionReason3,
  AuthorizationPendingException: () => AuthorizationPendingException3,
  AuthorizationPendingException$: () => AuthorizationPendingException$3,
  CreateToken$: () => CreateToken$3,
  CreateTokenCommand: () => CreateTokenCommand3,
  CreateTokenRequest$: () => CreateTokenRequest$3,
  CreateTokenResponse$: () => CreateTokenResponse$3,
  ExpiredTokenException: () => ExpiredTokenException8,
  ExpiredTokenException$: () => ExpiredTokenException$8,
  InternalServerException: () => InternalServerException8,
  InternalServerException$: () => InternalServerException$8,
  InvalidClientException: () => InvalidClientException3,
  InvalidClientException$: () => InvalidClientException$3,
  InvalidGrantException: () => InvalidGrantException3,
  InvalidGrantException$: () => InvalidGrantException$3,
  InvalidRequestException: () => InvalidRequestException8,
  InvalidRequestException$: () => InvalidRequestException$8,
  InvalidRequestExceptionReason: () => InvalidRequestExceptionReason3,
  InvalidScopeException: () => InvalidScopeException3,
  InvalidScopeException$: () => InvalidScopeException$3,
  SSOOIDC: () => SSOOIDC3,
  SSOOIDCClient: () => SSOOIDCClient3,
  SSOOIDCServiceException: () => SSOOIDCServiceException3,
  SSOOIDCServiceException$: () => SSOOIDCServiceException$3,
  SlowDownException: () => SlowDownException3,
  SlowDownException$: () => SlowDownException$3,
  UnauthorizedClientException: () => UnauthorizedClientException3,
  UnauthorizedClientException$: () => UnauthorizedClientException$3,
  UnsupportedGrantTypeException: () => UnsupportedGrantTypeException3,
  UnsupportedGrantTypeException$: () => UnsupportedGrantTypeException$3,
  __Client: () => Client,
  errorTypeRegistries: () => errorTypeRegistries19
});
var init_sso_oidc3 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso-oidc/index.js"() {
    init_SSOOIDCClient3();
    init_SSOOIDC3();
    init_commands20();
    init_schemas_019();
    init_enums8();
    init_errors19();
    init_models_019();
    init_SSOOIDCServiceException3();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/token-providers/dist-cjs/index.js
var require_dist_cjs147 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/token-providers/dist-cjs/index.js"(exports2) {
    "use strict";
    var client = (init_client13(), __toCommonJS(client_exports10));
    var httpAuthSchemes = (init_httpAuthSchemes9(), __toCommonJS(httpAuthSchemes_exports7));
    var config2 = (init_config4(), __toCommonJS(config_exports));
    var node_fs = require("node:fs");
    var fromEnvSigningName = /* @__PURE__ */ __name(({ logger: logger5, signingName } = {}) => async () => {
      logger5?.debug?.("@aws-sdk/token-providers - fromEnvSigningName");
      if (!signingName) {
        throw new config2.TokenProviderError("Please pass 'signingName' to compute environment variable key", { logger: logger5 });
      }
      const bearerTokenKey = httpAuthSchemes.getBearerTokenEnvKey(signingName);
      if (!(bearerTokenKey in process.env)) {
        throw new config2.TokenProviderError(`Token not present in '${bearerTokenKey}' environment variable`, { logger: logger5 });
      }
      const token = { token: process.env[bearerTokenKey] };
      client.setTokenFeature(token, "BEARER_SERVICE_ENV_VARS", "3");
      return token;
    }, "fromEnvSigningName");
    var EXPIRE_WINDOW_MS = 5 * 60 * 1e3;
    var REFRESH_MESSAGE = `To refresh this SSO session run 'aws sso login' with the corresponding profile.`;
    var getSsoOidcClient = /* @__PURE__ */ __name(async (ssoRegion, init = {}, callerClientConfig) => {
      const { SSOOIDCClient: SSOOIDCClient4 } = await Promise.resolve().then(() => (init_sso_oidc3(), sso_oidc_exports3));
      const coalesce3 = /* @__PURE__ */ __name((prop) => init.clientConfig?.[prop] ?? init.parentClientConfig?.[prop] ?? callerClientConfig?.[prop], "coalesce");
      const ssoOidcClient = new SSOOIDCClient4(Object.assign({}, init.clientConfig ?? {}, {
        region: ssoRegion ?? init.clientConfig?.region,
        logger: coalesce3("logger"),
        userAgentAppId: coalesce3("userAgentAppId")
      }));
      return ssoOidcClient;
    }, "getSsoOidcClient");
    var getNewSsoOidcToken = /* @__PURE__ */ __name(async (ssoToken, ssoRegion, init = {}, callerClientConfig) => {
      const { CreateTokenCommand: CreateTokenCommand4 } = await Promise.resolve().then(() => (init_sso_oidc3(), sso_oidc_exports3));
      const ssoOidcClient = await getSsoOidcClient(ssoRegion, init, callerClientConfig);
      return ssoOidcClient.send(new CreateTokenCommand4({
        clientId: ssoToken.clientId,
        clientSecret: ssoToken.clientSecret,
        refreshToken: ssoToken.refreshToken,
        grantType: "refresh_token"
      }));
    }, "getNewSsoOidcToken");
    var validateTokenExpiry = /* @__PURE__ */ __name((token) => {
      if (token.expiration && token.expiration.getTime() < Date.now()) {
        throw new config2.TokenProviderError(`Token is expired. ${REFRESH_MESSAGE}`, false);
      }
    }, "validateTokenExpiry");
    var validateTokenKey = /* @__PURE__ */ __name((key, value, forRefresh = false) => {
      if (typeof value === "undefined") {
        throw new config2.TokenProviderError(`Value not present for '${key}' in SSO Token${forRefresh ? ". Cannot refresh" : ""}. ${REFRESH_MESSAGE}`, false);
      }
    }, "validateTokenKey");
    var { writeFile: writeFile6 } = node_fs.promises;
    var writeSSOTokenToFile = /* @__PURE__ */ __name((id, ssoToken) => {
      const tokenFilepath = config2.getSSOTokenFilepath(id);
      const tokenString = JSON.stringify(ssoToken, null, 2);
      return writeFile6(tokenFilepath, tokenString);
    }, "writeSSOTokenToFile");
    var lastRefreshAttemptTime = /* @__PURE__ */ new Date(0);
    var fromSso = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/token-providers - fromSso");
      const profiles = await config2.parseKnownFiles(init);
      const profileName = config2.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      });
      const profile = profiles[profileName];
      if (!profile) {
        throw new config2.TokenProviderError(`Profile '${profileName}' could not be found in shared credentials file.`, false);
      } else if (!profile["sso_session"]) {
        throw new config2.TokenProviderError(`Profile '${profileName}' is missing required property 'sso_session'.`);
      }
      const ssoSessionName = profile["sso_session"];
      const ssoSessions = await config2.loadSsoSessionData(init);
      const ssoSession = ssoSessions[ssoSessionName];
      if (!ssoSession) {
        throw new config2.TokenProviderError(`Sso session '${ssoSessionName}' could not be found in shared credentials file.`, false);
      }
      for (const ssoSessionRequiredKey of ["sso_start_url", "sso_region"]) {
        if (!ssoSession[ssoSessionRequiredKey]) {
          throw new config2.TokenProviderError(`Sso session '${ssoSessionName}' is missing required property '${ssoSessionRequiredKey}'.`, false);
        }
      }
      ssoSession["sso_start_url"];
      const ssoRegion = ssoSession["sso_region"];
      let ssoToken;
      try {
        ssoToken = await config2.getSSOTokenFromFile(ssoSessionName);
      } catch (e32) {
        throw new config2.TokenProviderError(`The SSO session token associated with profile=${profileName} was not found or is invalid. ${REFRESH_MESSAGE}`, false);
      }
      validateTokenKey("accessToken", ssoToken.accessToken);
      validateTokenKey("expiresAt", ssoToken.expiresAt);
      const { accessToken, expiresAt } = ssoToken;
      const existingToken = { token: accessToken, expiration: new Date(expiresAt) };
      if (existingToken.expiration.getTime() - Date.now() > EXPIRE_WINDOW_MS) {
        return existingToken;
      }
      if (Date.now() - lastRefreshAttemptTime.getTime() < 30 * 1e3) {
        validateTokenExpiry(existingToken);
        return existingToken;
      }
      validateTokenKey("clientId", ssoToken.clientId, true);
      validateTokenKey("clientSecret", ssoToken.clientSecret, true);
      validateTokenKey("refreshToken", ssoToken.refreshToken, true);
      try {
        lastRefreshAttemptTime.setTime(Date.now());
        const newSsoOidcToken = await getNewSsoOidcToken(ssoToken, ssoRegion, init, callerClientConfig);
        validateTokenKey("accessToken", newSsoOidcToken.accessToken);
        validateTokenKey("expiresIn", newSsoOidcToken.expiresIn);
        const newTokenExpiration = new Date(Date.now() + newSsoOidcToken.expiresIn * 1e3);
        try {
          await writeSSOTokenToFile(ssoSessionName, {
            ...ssoToken,
            accessToken: newSsoOidcToken.accessToken,
            expiresAt: newTokenExpiration.toISOString(),
            refreshToken: newSsoOidcToken.refreshToken
          });
        } catch (error4) {
        }
        return {
          token: newSsoOidcToken.accessToken,
          expiration: newTokenExpiration
        };
      } catch (error4) {
        validateTokenExpiry(existingToken);
        return existingToken;
      }
    }, "fromSso");
    var fromStatic5 = /* @__PURE__ */ __name(({ token, logger: logger5 }) => async () => {
      logger5?.debug("@aws-sdk/token-providers - fromStatic");
      if (!token || !token.token) {
        throw new config2.TokenProviderError(`Please pass a valid token to fromStatic`, false);
      }
      return token;
    }, "fromStatic");
    var nodeProvider = /* @__PURE__ */ __name((init = {}) => config2.memoize(config2.chain(fromSso(init), async () => {
      throw new config2.TokenProviderError("Could not load token from any providers", false);
    }), (token) => token.expiration !== void 0 && token.expiration.getTime() - Date.now() < 3e5, (token) => token.expiration !== void 0), "nodeProvider");
    exports2.fromEnvSigningName = fromEnvSigningName;
    exports2.fromSso = fromSso;
    exports2.fromStatic = fromStatic5;
    exports2.nodeProvider = nodeProvider;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption20(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "awsssoportal",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption20(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var defaultSSOHttpAuthSchemeParametersProvider6, defaultSSOHttpAuthSchemeProvider6, resolveHttpAuthSchemeConfig20;
var init_httpAuthSchemeProvider20 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes9();
    init_client12();
    defaultSSOHttpAuthSchemeParametersProvider6 = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: getSmithyContext26(context).operation,
        region: await normalizeProvider22(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultSSOHttpAuthSchemeParametersProvider");
    __name(createAwsAuthSigv4HttpAuthOption20, "createAwsAuthSigv4HttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption20, "createSmithyApiNoAuthHttpAuthOption");
    defaultSSOHttpAuthSchemeProvider6 = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "GetRoleCredentials": {
          options.push(createSmithyApiNoAuthHttpAuthOption20(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption20(authParameters));
        }
      }
      return options;
    }, "defaultSSOHttpAuthSchemeProvider");
    resolveHttpAuthSchemeConfig20 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveAwsSdkSigV4Config7(config2);
      return Object.assign(config_0, {
        authSchemePreference: normalizeProvider22(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/EndpointParameters.js
var resolveClientEndpointParameters20, commonParams20;
var init_EndpointParameters20 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters20 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "awsssoportal"
      });
    }, "resolveClientEndpointParameters");
    commonParams20 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/bdd.js
var k20, a20, b20, c20, d20, e20, f20, g20, h20, i20, j20, _data20, root20, r20, nodes20, bdd20;
var init_bdd20 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/bdd.js"() {
    init_endpoints3();
    k20 = "ref";
    a20 = -1;
    b20 = true;
    c20 = "isSet";
    d20 = "PartitionResult";
    e20 = "booleanEquals";
    f20 = "getAttr";
    g20 = { [k20]: "Endpoint" };
    h20 = { [k20]: d20 };
    i20 = {};
    j20 = [{ [k20]: "Region" }];
    _data20 = {
      conditions: [
        [c20, [g20]],
        [c20, j20],
        ["aws.partition", j20, d20],
        [e20, [{ [k20]: "UseFIPS" }, b20]],
        [e20, [{ [k20]: "UseDualStack" }, b20]],
        [e20, [{ fn: f20, argv: [h20, "supportsDualStack"] }, b20]],
        [e20, [{ fn: f20, argv: [h20, "supportsFIPS"] }, b20]],
        ["stringEquals", [{ fn: f20, argv: [h20, "name"] }, "aws-us-gov"]]
      ],
      results: [
        [a20],
        [a20, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a20, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [g20, i20],
        ["https://portal.sso-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", i20],
        [a20, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://portal.sso.{Region}.amazonaws.com", i20],
        ["https://portal.sso-fips.{Region}.{PartitionResult#dnsSuffix}", i20],
        [a20, "FIPS is enabled but this partition does not support FIPS"],
        ["https://portal.sso.{Region}.{PartitionResult#dualStackDnsSuffix}", i20],
        [a20, "DualStack is enabled but this partition does not support DualStack"],
        ["https://portal.sso.{Region}.{PartitionResult#dnsSuffix}", i20],
        [a20, "Invalid Configuration: Missing Region"]
      ]
    };
    root20 = 2;
    r20 = 1e8;
    nodes20 = new Int32Array([
      -1,
      1,
      -1,
      0,
      13,
      3,
      1,
      4,
      r20 + 12,
      2,
      5,
      r20 + 12,
      3,
      8,
      6,
      4,
      7,
      r20 + 11,
      5,
      r20 + 9,
      r20 + 10,
      4,
      11,
      9,
      6,
      10,
      r20 + 8,
      7,
      r20 + 6,
      r20 + 7,
      5,
      12,
      r20 + 5,
      6,
      r20 + 4,
      r20 + 5,
      3,
      r20 + 1,
      14,
      4,
      r20 + 2,
      r20 + 3
    ]);
    bdd20 = BinaryDecisionDiagram20.from(nodes20, root20, _data20.conditions, _data20.results);
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/endpointResolver.js
var cache20, defaultEndpointResolver20;
var init_endpointResolver20 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/endpointResolver.js"() {
    init_client13();
    init_endpoints3();
    init_bdd20();
    cache20 = new EndpointCache20({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    defaultEndpointResolver20 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache20.get(endpointParams, () => decideEndpoint20(bdd20, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    customEndpointFunctions20.aws = awsEndpointFunctions19;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/SSOServiceException.js
var SSOServiceException6;
var init_SSOServiceException6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/SSOServiceException.js"() {
    init_client12();
    SSOServiceException6 = class _SSOServiceException extends ServiceException {
      static {
        __name(this, "SSOServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _SSOServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/errors.js
var InvalidRequestException9, ResourceNotFoundException7, TooManyRequestsException7, UnauthorizedException6;
var init_errors20 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/errors.js"() {
    init_SSOServiceException6();
    InvalidRequestException9 = class _InvalidRequestException extends SSOServiceException6 {
      static {
        __name(this, "InvalidRequestException");
      }
      name = "InvalidRequestException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidRequestException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidRequestException.prototype);
      }
    };
    ResourceNotFoundException7 = class _ResourceNotFoundException extends SSOServiceException6 {
      static {
        __name(this, "ResourceNotFoundException");
      }
      name = "ResourceNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ResourceNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceNotFoundException.prototype);
      }
    };
    TooManyRequestsException7 = class _TooManyRequestsException extends SSOServiceException6 {
      static {
        __name(this, "TooManyRequestsException");
      }
      name = "TooManyRequestsException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TooManyRequestsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyRequestsException.prototype);
      }
    };
    UnauthorizedException6 = class _UnauthorizedException extends SSOServiceException6 {
      static {
        __name(this, "UnauthorizedException");
      }
      name = "UnauthorizedException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "UnauthorizedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnauthorizedException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/schemas/schemas_0.js
var _ATT6, _GRC6, _GRCR6, _GRCRe6, _IRE9, _RC6, _RNFE7, _SAKT6, _STT6, _TMRE12, _UE6, _aI6, _aKI11, _aT14, _ai6, _c20, _e20, _ex6, _h14, _hE20, _hH6, _hQ6, _m17, _rC6, _rN6, _rn6, _s20, _sAK11, _sT11, _xasbt6, n020, _s_registry20, SSOServiceException$6, n0_registry20, InvalidRequestException$9, ResourceNotFoundException$7, TooManyRequestsException$7, UnauthorizedException$6, errorTypeRegistries20, AccessTokenType6, SecretAccessKeyType6, SessionTokenType6, GetRoleCredentialsRequest$6, GetRoleCredentialsResponse$6, RoleCredentials$6, GetRoleCredentials$6;
var init_schemas_020 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/schemas/schemas_0.js"() {
    init_schema6();
    init_errors20();
    init_SSOServiceException6();
    _ATT6 = "AccessTokenType";
    _GRC6 = "GetRoleCredentials";
    _GRCR6 = "GetRoleCredentialsRequest";
    _GRCRe6 = "GetRoleCredentialsResponse";
    _IRE9 = "InvalidRequestException";
    _RC6 = "RoleCredentials";
    _RNFE7 = "ResourceNotFoundException";
    _SAKT6 = "SecretAccessKeyType";
    _STT6 = "SessionTokenType";
    _TMRE12 = "TooManyRequestsException";
    _UE6 = "UnauthorizedException";
    _aI6 = "accountId";
    _aKI11 = "accessKeyId";
    _aT14 = "accessToken";
    _ai6 = "account_id";
    _c20 = "client";
    _e20 = "error";
    _ex6 = "expiration";
    _h14 = "http";
    _hE20 = "httpError";
    _hH6 = "httpHeader";
    _hQ6 = "httpQuery";
    _m17 = "message";
    _rC6 = "roleCredentials";
    _rN6 = "roleName";
    _rn6 = "role_name";
    _s20 = "smithy.ts.sdk.synthetic.com.amazonaws.sso";
    _sAK11 = "secretAccessKey";
    _sT11 = "sessionToken";
    _xasbt6 = "x-amz-sso_bearer_token";
    n020 = "com.amazonaws.sso";
    _s_registry20 = TypeRegistry3.for(_s20);
    SSOServiceException$6 = [-3, _s20, "SSOServiceException", 0, [], []];
    _s_registry20.registerError(SSOServiceException$6, SSOServiceException6);
    n0_registry20 = TypeRegistry3.for(n020);
    InvalidRequestException$9 = [-3, n020, _IRE9, { [_e20]: _c20, [_hE20]: 400 }, [_m17], [0]];
    n0_registry20.registerError(InvalidRequestException$9, InvalidRequestException9);
    ResourceNotFoundException$7 = [-3, n020, _RNFE7, { [_e20]: _c20, [_hE20]: 404 }, [_m17], [0]];
    n0_registry20.registerError(ResourceNotFoundException$7, ResourceNotFoundException7);
    TooManyRequestsException$7 = [-3, n020, _TMRE12, { [_e20]: _c20, [_hE20]: 429 }, [_m17], [0]];
    n0_registry20.registerError(TooManyRequestsException$7, TooManyRequestsException7);
    UnauthorizedException$6 = [-3, n020, _UE6, { [_e20]: _c20, [_hE20]: 401 }, [_m17], [0]];
    n0_registry20.registerError(UnauthorizedException$6, UnauthorizedException6);
    errorTypeRegistries20 = [_s_registry20, n0_registry20];
    AccessTokenType6 = [0, n020, _ATT6, 8, 0];
    SecretAccessKeyType6 = [0, n020, _SAKT6, 8, 0];
    SessionTokenType6 = [0, n020, _STT6, 8, 0];
    GetRoleCredentialsRequest$6 = [
      3,
      n020,
      _GRCR6,
      0,
      [_rN6, _aI6, _aT14],
      [
        [0, { [_hQ6]: _rn6 }],
        [0, { [_hQ6]: _ai6 }],
        [() => AccessTokenType6, { [_hH6]: _xasbt6 }]
      ],
      3
    ];
    GetRoleCredentialsResponse$6 = [
      3,
      n020,
      _GRCRe6,
      0,
      [_rC6],
      [[() => RoleCredentials$6, 0]]
    ];
    RoleCredentials$6 = [
      3,
      n020,
      _RC6,
      0,
      [_aKI11, _sAK11, _sT11, _ex6],
      [0, [() => SecretAccessKeyType6, 0], [() => SessionTokenType6, 0], 1]
    ];
    GetRoleCredentials$6 = [
      9,
      n020,
      _GRC6,
      { [_h14]: ["GET", "/federation/credentials", 200] },
      () => GetRoleCredentialsRequest$6,
      () => GetRoleCredentialsResponse$6
    ];
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.shared.js
var getRuntimeConfig39;
var init_runtimeConfig_shared20 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.shared.js"() {
    init_httpAuthSchemes9();
    init_protocols15();
    init_dist_es2();
    init_client12();
    init_protocols11();
    init_serde4();
    init_httpAuthSchemeProvider20();
    init_endpointResolver20();
    init_schemas_020();
    getRuntimeConfig39 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2019-06-10",
        base64Decoder: config2?.base64Decoder ?? fromBase6436,
        base64Encoder: config2?.base64Encoder ?? toBase6441,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver20,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSSOHttpAuthSchemeProvider6,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer7()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner2()
          }
        ],
        logger: config2?.logger ?? new NoOpLogger20(),
        protocol: config2?.protocol ?? AwsRestJsonProtocol8,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.sso",
          errorTypeRegistries: errorTypeRegistries20,
          version: "2019-06-10",
          serviceTarget: "SWBPortalService"
        },
        serviceId: config2?.serviceId ?? "SSO",
        urlParser: config2?.urlParser ?? parseUrl21,
        utf8Decoder: config2?.utf8Decoder ?? fromUtf825,
        utf8Encoder: config2?.utf8Encoder ?? toUtf839
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.js
var import_node_http_handler20, getRuntimeConfig40;
var init_runtimeConfig20 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.js"() {
    init_package7();
    init_client13();
    init_httpAuthSchemes9();
    init_client12();
    init_config4();
    init_retry3();
    init_serde4();
    import_node_http_handler20 = __toESM(require_dist_cjs144());
    init_runtimeConfig_shared20();
    getRuntimeConfig40 = /* @__PURE__ */ __name((config2) => {
      emitWarningIfUnsupportedVersion28(process.version);
      const defaultsMode = resolveDefaultsModeConfig19(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(loadConfigsForDefaultMode19), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig39(config2);
      emitWarningIfUnsupportedVersion27(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? loadConfig3(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS7, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? calculateBodyLength19,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? createDefaultUserAgentProvider19({ serviceId: clientSharedValues.serviceId, clientVersion: package_default7.version }),
        maxAttempts: config2?.maxAttempts ?? loadConfig3(NODE_MAX_ATTEMPT_CONFIG_OPTIONS20, config2),
        region: config2?.region ?? loadConfig3(NODE_REGION_CONFIG_OPTIONS20, { ...NODE_REGION_CONFIG_FILE_OPTIONS20, ...loaderConfig }),
        requestHandler: import_node_http_handler20.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? loadConfig3({
          ...NODE_RETRY_MODE_CONFIG_OPTIONS20,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || DEFAULT_RETRY_MODE20, "default")
        }, config2),
        sha256: config2?.sha256 ?? Hash19.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? import_node_http_handler20.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? loadConfig3(NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS19, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? loadConfig3(NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS19, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? loadConfig3(NODE_APP_ID_CONFIG_OPTIONS19, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration20, resolveHttpAuthRuntimeConfig20;
var init_httpAuthExtensionConfiguration20 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration20 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig20 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeExtensions.js
var resolveRuntimeExtensions20;
var init_runtimeExtensions20 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeExtensions.js"() {
    init_client13();
    init_client12();
    init_protocols11();
    init_httpAuthExtensionConfiguration20();
    resolveRuntimeExtensions20 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign(getAwsRegionExtensionConfiguration19(runtimeConfig), getDefaultExtensionConfiguration19(runtimeConfig), getHttpHandlerExtensionConfiguration20(runtimeConfig), getHttpAuthExtensionConfiguration20(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, resolveAwsRegionExtensionConfiguration19(extensionConfiguration), resolveDefaultRuntimeConfig19(extensionConfiguration), resolveHttpHandlerRuntimeConfig20(extensionConfiguration), resolveHttpAuthRuntimeConfig20(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSOClient.js
var SSOClient6;
var init_SSOClient6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSOClient.js"() {
    init_client13();
    init_dist_es2();
    init_client12();
    init_config4();
    init_endpoints3();
    init_protocols11();
    init_retry3();
    init_schema6();
    init_httpAuthSchemeProvider20();
    init_EndpointParameters20();
    init_runtimeConfig20();
    init_runtimeExtensions20();
    SSOClient6 = class extends Client {
      static {
        __name(this, "SSOClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig40(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters20(_config_0);
        const _config_2 = resolveUserAgentConfig19(_config_1);
        const _config_3 = resolveRetryConfig20(_config_2);
        const _config_4 = resolveRegionConfig19(_config_3);
        const _config_5 = resolveHostHeaderConfig19(_config_4);
        const _config_6 = resolveEndpointConfig20(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig20(_config_6);
        const _config_8 = resolveRuntimeExtensions20(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin2(this.config));
        this.middlewareStack.use(getUserAgentPlugin19(this.config));
        this.middlewareStack.use(getRetryPlugin20(this.config));
        this.middlewareStack.use(getContentLengthPlugin20(this.config));
        this.middlewareStack.use(getHostHeaderPlugin19(this.config));
        this.middlewareStack.use(getLoggerPlugin19(this.config));
        this.middlewareStack.use(getRecursionDetectionPlugin19(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin2(this.config, {
          httpAuthSchemeParametersProvider: defaultSSOHttpAuthSchemeParametersProvider6,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig2({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin2(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/GetRoleCredentialsCommand.js
var GetRoleCredentialsCommand6;
var init_GetRoleCredentialsCommand6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/GetRoleCredentialsCommand.js"() {
    init_client12();
    init_endpoints3();
    init_EndpointParameters20();
    init_schemas_020();
    GetRoleCredentialsCommand6 = class extends Command.classBuilder().ep(commonParams20).m(function(Command3, cs, config2, o10) {
      return [getEndpointPlugin26(config2, Command3.getEndpointParameterInstructions())];
    }).s("SWBPortalService", "GetRoleCredentials", {}).n("SSOClient", "GetRoleCredentialsCommand").sc(GetRoleCredentials$6).build() {
      static {
        __name(this, "GetRoleCredentialsCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSO.js
var commands20, SSO6;
var init_SSO6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSO.js"() {
    init_client12();
    init_GetRoleCredentialsCommand6();
    init_SSOClient6();
    commands20 = {
      GetRoleCredentialsCommand: GetRoleCredentialsCommand6
    };
    SSO6 = class extends SSOClient6 {
      static {
        __name(this, "SSO");
      }
    };
    createAggregatedClient19(commands20, SSO6);
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/index.js
var init_commands21 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/index.js"() {
    init_GetRoleCredentialsCommand6();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/models_0.js
var init_models_020 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/index.js
var sso_exports6 = {};
__export(sso_exports6, {
  $Command: () => Command,
  GetRoleCredentials$: () => GetRoleCredentials$6,
  GetRoleCredentialsCommand: () => GetRoleCredentialsCommand6,
  GetRoleCredentialsRequest$: () => GetRoleCredentialsRequest$6,
  GetRoleCredentialsResponse$: () => GetRoleCredentialsResponse$6,
  InvalidRequestException: () => InvalidRequestException9,
  InvalidRequestException$: () => InvalidRequestException$9,
  ResourceNotFoundException: () => ResourceNotFoundException7,
  ResourceNotFoundException$: () => ResourceNotFoundException$7,
  RoleCredentials$: () => RoleCredentials$6,
  SSO: () => SSO6,
  SSOClient: () => SSOClient6,
  SSOServiceException: () => SSOServiceException6,
  SSOServiceException$: () => SSOServiceException$6,
  TooManyRequestsException: () => TooManyRequestsException7,
  TooManyRequestsException$: () => TooManyRequestsException$7,
  UnauthorizedException: () => UnauthorizedException6,
  UnauthorizedException$: () => UnauthorizedException$6,
  __Client: () => Client,
  errorTypeRegistries: () => errorTypeRegistries20
});
var init_sso6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/index.js"() {
    init_SSOClient6();
    init_SSO6();
    init_commands21();
    init_schemas_020();
    init_errors20();
    init_models_020();
    init_SSOServiceException6();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/loadSso-BKDNrsal.js
var require_loadSso_BKDNrsal6 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/loadSso-BKDNrsal.js"(exports2) {
    "use strict";
    var sso = (init_sso6(), __toCommonJS(sso_exports6));
    exports2.GetRoleCredentialsCommand = sso.GetRoleCredentialsCommand;
    exports2.SSOClient = sso.SSOClient;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/index.js
var require_dist_cjs148 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/index.js"(exports2) {
    "use strict";
    var config2 = (init_config4(), __toCommonJS(config_exports));
    var client = (init_client13(), __toCommonJS(client_exports10));
    var tokenProviders = require_dist_cjs147();
    var isSsoProfile = /* @__PURE__ */ __name((arg) => arg && (typeof arg.sso_start_url === "string" || typeof arg.sso_account_id === "string" || typeof arg.sso_session === "string" || typeof arg.sso_region === "string" || typeof arg.sso_role_name === "string"), "isSsoProfile");
    var SHOULD_FAIL_CREDENTIAL_CHAIN = false;
    var resolveSSOCredentials = /* @__PURE__ */ __name(async ({ ssoStartUrl, ssoSession, ssoAccountId, ssoRegion, ssoRoleName, ssoClient, clientConfig, parentClientConfig, callerClientConfig, profile, filepath, configFilepath, ignoreCache, logger: logger5 }) => {
      let token;
      const refreshMessage = `To refresh this SSO session run aws sso login with the corresponding profile.`;
      if (ssoSession) {
        try {
          const _token = await tokenProviders.fromSso({
            profile,
            filepath,
            configFilepath,
            ignoreCache
          })();
          token = {
            accessToken: _token.token,
            expiresAt: new Date(_token.expiration).toISOString()
          };
        } catch (e32) {
          throw new config2.CredentialsProviderError(e32.message, {
            tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
            logger: logger5
          });
        }
      } else {
        try {
          token = await config2.getSSOTokenFromFile(ssoStartUrl);
        } catch (e32) {
          throw new config2.CredentialsProviderError(`The SSO session associated with this profile is invalid. ${refreshMessage}`, {
            tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
            logger: logger5
          });
        }
      }
      if (new Date(token.expiresAt).getTime() - Date.now() <= 0) {
        throw new config2.CredentialsProviderError(`The SSO session associated with this profile has expired. ${refreshMessage}`, {
          tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
          logger: logger5
        });
      }
      const { accessToken } = token;
      const { SSOClient: SSOClient10, GetRoleCredentialsCommand: GetRoleCredentialsCommand10 } = await Promise.resolve().then(function() {
        return require_loadSso_BKDNrsal6();
      });
      const sso = ssoClient || new SSOClient10(Object.assign({}, clientConfig ?? {}, {
        logger: clientConfig?.logger ?? callerClientConfig?.logger ?? parentClientConfig?.logger,
        region: clientConfig?.region ?? ssoRegion,
        userAgentAppId: clientConfig?.userAgentAppId ?? callerClientConfig?.userAgentAppId ?? parentClientConfig?.userAgentAppId
      }));
      let ssoResp;
      try {
        ssoResp = await sso.send(new GetRoleCredentialsCommand10({
          accountId: ssoAccountId,
          roleName: ssoRoleName,
          accessToken
        }));
      } catch (e32) {
        throw new config2.CredentialsProviderError(e32, {
          tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
          logger: logger5
        });
      }
      const { roleCredentials: { accessKeyId, secretAccessKey, sessionToken, expiration, credentialScope, accountId } = {} } = ssoResp;
      if (!accessKeyId || !secretAccessKey || !sessionToken || !expiration) {
        throw new config2.CredentialsProviderError("SSO returns an invalid temporary credential.", {
          tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
          logger: logger5
        });
      }
      const credentials = {
        accessKeyId,
        secretAccessKey,
        sessionToken,
        expiration: new Date(expiration),
        ...credentialScope && { credentialScope },
        ...accountId && { accountId }
      };
      if (ssoSession) {
        client.setCredentialFeature(credentials, "CREDENTIALS_SSO", "s");
      } else {
        client.setCredentialFeature(credentials, "CREDENTIALS_SSO_LEGACY", "u");
      }
      return credentials;
    }, "resolveSSOCredentials");
    var validateSsoProfile = /* @__PURE__ */ __name((profile, logger5) => {
      const { sso_start_url, sso_account_id, sso_region, sso_role_name } = profile;
      if (!sso_start_url || !sso_account_id || !sso_region || !sso_role_name) {
        throw new config2.CredentialsProviderError(`Profile is configured with invalid SSO credentials. Required parameters "sso_account_id", "sso_region", "sso_role_name", "sso_start_url". Got ${Object.keys(profile).join(", ")}
Reference: https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-sso.html`, { tryNextLink: false, logger: logger5 });
      }
      return profile;
    }, "validateSsoProfile");
    var fromSSO = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/credential-provider-sso - fromSSO");
      const { ssoStartUrl, ssoAccountId, ssoRegion, ssoRoleName, ssoSession } = init;
      const { ssoClient } = init;
      const profileName = config2.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      });
      if (!ssoStartUrl && !ssoAccountId && !ssoRegion && !ssoRoleName && !ssoSession) {
        const profiles = await config2.parseKnownFiles(init);
        const profile = profiles[profileName];
        if (!profile) {
          throw new config2.CredentialsProviderError(`Profile ${profileName} was not found.`, { logger: init.logger });
        }
        if (!isSsoProfile(profile)) {
          throw new config2.CredentialsProviderError(`Profile ${profileName} is not configured with SSO credentials.`, {
            logger: init.logger
          });
        }
        if (profile?.sso_session) {
          const ssoSessions = await config2.loadSsoSessionData(init);
          const session = ssoSessions[profile.sso_session];
          const conflictMsg = ` configurations in profile ${profileName} and sso-session ${profile.sso_session}`;
          if (ssoRegion && ssoRegion !== session.sso_region) {
            throw new config2.CredentialsProviderError(`Conflicting SSO region` + conflictMsg, {
              tryNextLink: false,
              logger: init.logger
            });
          }
          if (ssoStartUrl && ssoStartUrl !== session.sso_start_url) {
            throw new config2.CredentialsProviderError(`Conflicting SSO start_url` + conflictMsg, {
              tryNextLink: false,
              logger: init.logger
            });
          }
          profile.sso_region = session.sso_region;
          profile.sso_start_url = session.sso_start_url;
        }
        const { sso_start_url, sso_account_id, sso_region, sso_role_name, sso_session } = validateSsoProfile(profile, init.logger);
        return resolveSSOCredentials({
          ssoStartUrl: sso_start_url,
          ssoSession: sso_session,
          ssoAccountId: sso_account_id,
          ssoRegion: sso_region,
          ssoRoleName: sso_role_name,
          ssoClient,
          clientConfig: init.clientConfig,
          parentClientConfig: init.parentClientConfig,
          callerClientConfig: init.callerClientConfig,
          profile: profileName,
          filepath: init.filepath,
          configFilepath: init.configFilepath,
          ignoreCache: init.ignoreCache,
          logger: init.logger
        });
      } else if (!ssoStartUrl || !ssoAccountId || !ssoRegion || !ssoRoleName) {
        throw new config2.CredentialsProviderError('Incomplete configuration. The fromSSO() argument hash must include "ssoStartUrl", "ssoAccountId", "ssoRegion", "ssoRoleName"', { tryNextLink: false, logger: init.logger });
      } else {
        return resolveSSOCredentials({
          ssoStartUrl,
          ssoSession,
          ssoAccountId,
          ssoRegion,
          ssoRoleName,
          ssoClient,
          clientConfig: init.clientConfig,
          parentClientConfig: init.parentClientConfig,
          callerClientConfig: init.callerClientConfig,
          profile: profileName,
          filepath: init.filepath,
          configFilepath: init.configFilepath,
          ignoreCache: init.ignoreCache,
          logger: init.logger
        });
      }
    }, "fromSSO");
    exports2.fromSSO = fromSSO;
    exports2.isSsoProfile = isSsoProfile;
    exports2.validateSsoProfile = validateSsoProfile;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption21(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "signin",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption21(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var defaultSigninHttpAuthSchemeParametersProvider6, defaultSigninHttpAuthSchemeProvider6, resolveHttpAuthSchemeConfig21;
var init_httpAuthSchemeProvider21 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes9();
    init_client12();
    defaultSigninHttpAuthSchemeParametersProvider6 = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: getSmithyContext26(context).operation,
        region: await normalizeProvider22(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultSigninHttpAuthSchemeParametersProvider");
    __name(createAwsAuthSigv4HttpAuthOption21, "createAwsAuthSigv4HttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption21, "createSmithyApiNoAuthHttpAuthOption");
    defaultSigninHttpAuthSchemeProvider6 = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "CreateOAuth2Token": {
          options.push(createSmithyApiNoAuthHttpAuthOption21(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption21(authParameters));
        }
      }
      return options;
    }, "defaultSigninHttpAuthSchemeProvider");
    resolveHttpAuthSchemeConfig21 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveAwsSdkSigV4Config7(config2);
      return Object.assign(config_0, {
        authSchemePreference: normalizeProvider22(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/EndpointParameters.js
var resolveClientEndpointParameters21, commonParams21;
var init_EndpointParameters21 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters21 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "signin"
      });
    }, "resolveClientEndpointParameters");
    commonParams21 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/bdd.js
var m12, a21, b21, c21, d21, e21, f21, g21, h21, i21, j21, k21, l12, _data21, root21, r21, nodes21, bdd21;
var init_bdd21 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/bdd.js"() {
    init_endpoints3();
    m12 = "ref";
    a21 = -1;
    b21 = true;
    c21 = "isSet";
    d21 = "PartitionResult";
    e21 = "booleanEquals";
    f21 = "getAttr";
    g21 = "stringEquals";
    h21 = { [m12]: "Endpoint" };
    i21 = { [m12]: d21 };
    j21 = { fn: f21, argv: [i21, "name"] };
    k21 = {};
    l12 = [{ [m12]: "Region" }];
    _data21 = {
      conditions: [
        [c21, [h21]],
        [c21, l12],
        ["aws.partition", l12, d21],
        [e21, [{ [m12]: "UseFIPS" }, b21]],
        [e21, [{ [m12]: "UseDualStack" }, b21]],
        [e21, [{ fn: f21, argv: [i21, "supportsDualStack"] }, b21]],
        [e21, [{ fn: f21, argv: [i21, "supportsFIPS"] }, b21]],
        [g21, [j21, "aws"]],
        [g21, [j21, "aws-cn"]],
        [g21, [j21, "aws-us-gov"]]
      ],
      results: [
        [a21],
        [a21, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a21, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [h21, k21],
        ["https://{Region}.signin.aws.amazon.com", k21],
        ["https://{Region}.signin.amazonaws.cn", k21],
        ["https://{Region}.signin.amazonaws-us-gov.com", k21],
        ["https://signin-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", k21],
        [a21, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://signin-fips.{Region}.{PartitionResult#dnsSuffix}", k21],
        [a21, "FIPS is enabled but this partition does not support FIPS"],
        ["https://signin.{Region}.{PartitionResult#dualStackDnsSuffix}", k21],
        [a21, "DualStack is enabled but this partition does not support DualStack"],
        ["https://signin.{Region}.{PartitionResult#dnsSuffix}", k21],
        [a21, "Invalid Configuration: Missing Region"]
      ]
    };
    root21 = 2;
    r21 = 1e8;
    nodes21 = new Int32Array([
      -1,
      1,
      -1,
      0,
      15,
      3,
      1,
      4,
      r21 + 14,
      2,
      5,
      r21 + 14,
      3,
      11,
      6,
      4,
      10,
      7,
      7,
      r21 + 4,
      8,
      8,
      r21 + 5,
      9,
      9,
      r21 + 6,
      r21 + 13,
      5,
      r21 + 11,
      r21 + 12,
      4,
      13,
      12,
      6,
      r21 + 9,
      r21 + 10,
      5,
      14,
      r21 + 8,
      6,
      r21 + 7,
      r21 + 8,
      3,
      r21 + 1,
      16,
      4,
      r21 + 2,
      r21 + 3
    ]);
    bdd21 = BinaryDecisionDiagram20.from(nodes21, root21, _data21.conditions, _data21.results);
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/endpointResolver.js
var cache21, defaultEndpointResolver21;
var init_endpointResolver21 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/endpointResolver.js"() {
    init_client13();
    init_endpoints3();
    init_bdd21();
    cache21 = new EndpointCache20({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    defaultEndpointResolver21 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache21.get(endpointParams, () => decideEndpoint20(bdd21, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    customEndpointFunctions20.aws = awsEndpointFunctions19;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/SigninServiceException.js
var SigninServiceException6;
var init_SigninServiceException6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/SigninServiceException.js"() {
    init_client12();
    SigninServiceException6 = class _SigninServiceException extends ServiceException {
      static {
        __name(this, "SigninServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _SigninServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/errors.js
var AccessDeniedException9, InternalServerException9, TooManyRequestsError6, ValidationException6;
var init_errors21 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/errors.js"() {
    init_SigninServiceException6();
    AccessDeniedException9 = class _AccessDeniedException extends SigninServiceException6 {
      static {
        __name(this, "AccessDeniedException");
      }
      name = "AccessDeniedException";
      $fault = "client";
      error;
      constructor(opts) {
        super({
          name: "AccessDeniedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AccessDeniedException.prototype);
        this.error = opts.error;
      }
    };
    InternalServerException9 = class _InternalServerException extends SigninServiceException6 {
      static {
        __name(this, "InternalServerException");
      }
      name = "InternalServerException";
      $fault = "server";
      error;
      constructor(opts) {
        super({
          name: "InternalServerException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _InternalServerException.prototype);
        this.error = opts.error;
      }
    };
    TooManyRequestsError6 = class _TooManyRequestsError extends SigninServiceException6 {
      static {
        __name(this, "TooManyRequestsError");
      }
      name = "TooManyRequestsError";
      $fault = "client";
      error;
      constructor(opts) {
        super({
          name: "TooManyRequestsError",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyRequestsError.prototype);
        this.error = opts.error;
      }
    };
    ValidationException6 = class _ValidationException extends SigninServiceException6 {
      static {
        __name(this, "ValidationException");
      }
      name = "ValidationException";
      $fault = "client";
      error;
      constructor(opts) {
        super({
          name: "ValidationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ValidationException.prototype);
        this.error = opts.error;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/schemas/schemas_0.js
var _ADE9, _AT9, _COAT6, _COATR6, _COATRB6, _COATRBr6, _COATRr6, _ISE9, _RT9, _TMRE13, _VE6, _aKI12, _aT15, _c21, _cI9, _cV9, _co9, _e21, _eI9, _gT9, _h15, _hE21, _iT9, _jN6, _m18, _rT9, _rU9, _s21, _sAK12, _sT12, _se10, _tI6, _tO6, _tT9, n021, _s_registry21, SigninServiceException$6, n0_registry21, AccessDeniedException$9, InternalServerException$9, TooManyRequestsError$6, ValidationException$6, errorTypeRegistries21, RefreshToken9, AccessToken$6, CreateOAuth2TokenRequest$6, CreateOAuth2TokenRequestBody$6, CreateOAuth2TokenResponse$6, CreateOAuth2TokenResponseBody$6, CreateOAuth2Token$6;
var init_schemas_021 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/schemas/schemas_0.js"() {
    init_schema6();
    init_errors21();
    init_SigninServiceException6();
    _ADE9 = "AccessDeniedException";
    _AT9 = "AccessToken";
    _COAT6 = "CreateOAuth2Token";
    _COATR6 = "CreateOAuth2TokenRequest";
    _COATRB6 = "CreateOAuth2TokenRequestBody";
    _COATRBr6 = "CreateOAuth2TokenResponseBody";
    _COATRr6 = "CreateOAuth2TokenResponse";
    _ISE9 = "InternalServerException";
    _RT9 = "RefreshToken";
    _TMRE13 = "TooManyRequestsError";
    _VE6 = "ValidationException";
    _aKI12 = "accessKeyId";
    _aT15 = "accessToken";
    _c21 = "client";
    _cI9 = "clientId";
    _cV9 = "codeVerifier";
    _co9 = "code";
    _e21 = "error";
    _eI9 = "expiresIn";
    _gT9 = "grantType";
    _h15 = "http";
    _hE21 = "httpError";
    _iT9 = "idToken";
    _jN6 = "jsonName";
    _m18 = "message";
    _rT9 = "refreshToken";
    _rU9 = "redirectUri";
    _s21 = "smithy.ts.sdk.synthetic.com.amazonaws.signin";
    _sAK12 = "secretAccessKey";
    _sT12 = "sessionToken";
    _se10 = "server";
    _tI6 = "tokenInput";
    _tO6 = "tokenOutput";
    _tT9 = "tokenType";
    n021 = "com.amazonaws.signin";
    _s_registry21 = TypeRegistry3.for(_s21);
    SigninServiceException$6 = [-3, _s21, "SigninServiceException", 0, [], []];
    _s_registry21.registerError(SigninServiceException$6, SigninServiceException6);
    n0_registry21 = TypeRegistry3.for(n021);
    AccessDeniedException$9 = [-3, n021, _ADE9, { [_e21]: _c21 }, [_e21, _m18], [0, 0], 2];
    n0_registry21.registerError(AccessDeniedException$9, AccessDeniedException9);
    InternalServerException$9 = [-3, n021, _ISE9, { [_e21]: _se10, [_hE21]: 500 }, [_e21, _m18], [0, 0], 2];
    n0_registry21.registerError(InternalServerException$9, InternalServerException9);
    TooManyRequestsError$6 = [-3, n021, _TMRE13, { [_e21]: _c21, [_hE21]: 429 }, [_e21, _m18], [0, 0], 2];
    n0_registry21.registerError(TooManyRequestsError$6, TooManyRequestsError6);
    ValidationException$6 = [-3, n021, _VE6, { [_e21]: _c21, [_hE21]: 400 }, [_e21, _m18], [0, 0], 2];
    n0_registry21.registerError(ValidationException$6, ValidationException6);
    errorTypeRegistries21 = [_s_registry21, n0_registry21];
    RefreshToken9 = [0, n021, _RT9, 8, 0];
    AccessToken$6 = [
      3,
      n021,
      _AT9,
      8,
      [_aKI12, _sAK12, _sT12],
      [
        [0, { [_jN6]: _aKI12 }],
        [0, { [_jN6]: _sAK12 }],
        [0, { [_jN6]: _sT12 }]
      ],
      3
    ];
    CreateOAuth2TokenRequest$6 = [
      3,
      n021,
      _COATR6,
      0,
      [_tI6],
      [[() => CreateOAuth2TokenRequestBody$6, 16]],
      1
    ];
    CreateOAuth2TokenRequestBody$6 = [
      3,
      n021,
      _COATRB6,
      0,
      [_cI9, _gT9, _co9, _rU9, _cV9, _rT9],
      [
        [0, { [_jN6]: _cI9 }],
        [0, { [_jN6]: _gT9 }],
        0,
        [0, { [_jN6]: _rU9 }],
        [0, { [_jN6]: _cV9 }],
        [() => RefreshToken9, { [_jN6]: _rT9 }]
      ],
      2
    ];
    CreateOAuth2TokenResponse$6 = [
      3,
      n021,
      _COATRr6,
      0,
      [_tO6],
      [[() => CreateOAuth2TokenResponseBody$6, 16]],
      1
    ];
    CreateOAuth2TokenResponseBody$6 = [
      3,
      n021,
      _COATRBr6,
      0,
      [_aT15, _tT9, _eI9, _rT9, _iT9],
      [
        [() => AccessToken$6, { [_jN6]: _aT15 }],
        [0, { [_jN6]: _tT9 }],
        [1, { [_jN6]: _eI9 }],
        [() => RefreshToken9, { [_jN6]: _rT9 }],
        [0, { [_jN6]: _iT9 }]
      ],
      4
    ];
    CreateOAuth2Token$6 = [
      9,
      n021,
      _COAT6,
      { [_h15]: ["POST", "/v1/token", 200] },
      () => CreateOAuth2TokenRequest$6,
      () => CreateOAuth2TokenResponse$6
    ];
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.shared.js
var getRuntimeConfig41;
var init_runtimeConfig_shared21 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.shared.js"() {
    init_httpAuthSchemes9();
    init_protocols15();
    init_dist_es2();
    init_client12();
    init_protocols11();
    init_serde4();
    init_httpAuthSchemeProvider21();
    init_endpointResolver21();
    init_schemas_021();
    getRuntimeConfig41 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2023-01-01",
        base64Decoder: config2?.base64Decoder ?? fromBase6436,
        base64Encoder: config2?.base64Encoder ?? toBase6441,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver21,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSigninHttpAuthSchemeProvider6,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer7()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner2()
          }
        ],
        logger: config2?.logger ?? new NoOpLogger20(),
        protocol: config2?.protocol ?? AwsRestJsonProtocol8,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.signin",
          errorTypeRegistries: errorTypeRegistries21,
          version: "2023-01-01",
          serviceTarget: "Signin"
        },
        serviceId: config2?.serviceId ?? "Signin",
        urlParser: config2?.urlParser ?? parseUrl21,
        utf8Decoder: config2?.utf8Decoder ?? fromUtf825,
        utf8Encoder: config2?.utf8Encoder ?? toUtf839
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.js
var import_node_http_handler21, getRuntimeConfig42;
var init_runtimeConfig21 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.js"() {
    init_package7();
    init_client13();
    init_httpAuthSchemes9();
    init_client12();
    init_config4();
    init_retry3();
    init_serde4();
    import_node_http_handler21 = __toESM(require_dist_cjs144());
    init_runtimeConfig_shared21();
    getRuntimeConfig42 = /* @__PURE__ */ __name((config2) => {
      emitWarningIfUnsupportedVersion28(process.version);
      const defaultsMode = resolveDefaultsModeConfig19(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(loadConfigsForDefaultMode19), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig41(config2);
      emitWarningIfUnsupportedVersion27(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? loadConfig3(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS7, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? calculateBodyLength19,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? createDefaultUserAgentProvider19({ serviceId: clientSharedValues.serviceId, clientVersion: package_default7.version }),
        maxAttempts: config2?.maxAttempts ?? loadConfig3(NODE_MAX_ATTEMPT_CONFIG_OPTIONS20, config2),
        region: config2?.region ?? loadConfig3(NODE_REGION_CONFIG_OPTIONS20, { ...NODE_REGION_CONFIG_FILE_OPTIONS20, ...loaderConfig }),
        requestHandler: import_node_http_handler21.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? loadConfig3({
          ...NODE_RETRY_MODE_CONFIG_OPTIONS20,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || DEFAULT_RETRY_MODE20, "default")
        }, config2),
        sha256: config2?.sha256 ?? Hash19.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? import_node_http_handler21.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? loadConfig3(NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS19, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? loadConfig3(NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS19, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? loadConfig3(NODE_APP_ID_CONFIG_OPTIONS19, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration21, resolveHttpAuthRuntimeConfig21;
var init_httpAuthExtensionConfiguration21 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration21 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig21 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeExtensions.js
var resolveRuntimeExtensions21;
var init_runtimeExtensions21 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeExtensions.js"() {
    init_client13();
    init_client12();
    init_protocols11();
    init_httpAuthExtensionConfiguration21();
    resolveRuntimeExtensions21 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign(getAwsRegionExtensionConfiguration19(runtimeConfig), getDefaultExtensionConfiguration19(runtimeConfig), getHttpHandlerExtensionConfiguration20(runtimeConfig), getHttpAuthExtensionConfiguration21(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, resolveAwsRegionExtensionConfiguration19(extensionConfiguration), resolveDefaultRuntimeConfig19(extensionConfiguration), resolveHttpHandlerRuntimeConfig20(extensionConfiguration), resolveHttpAuthRuntimeConfig21(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/SigninClient.js
var SigninClient6;
var init_SigninClient6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/SigninClient.js"() {
    init_client13();
    init_dist_es2();
    init_client12();
    init_config4();
    init_endpoints3();
    init_protocols11();
    init_retry3();
    init_schema6();
    init_httpAuthSchemeProvider21();
    init_EndpointParameters21();
    init_runtimeConfig21();
    init_runtimeExtensions21();
    SigninClient6 = class extends Client {
      static {
        __name(this, "SigninClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig42(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters21(_config_0);
        const _config_2 = resolveUserAgentConfig19(_config_1);
        const _config_3 = resolveRetryConfig20(_config_2);
        const _config_4 = resolveRegionConfig19(_config_3);
        const _config_5 = resolveHostHeaderConfig19(_config_4);
        const _config_6 = resolveEndpointConfig20(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig21(_config_6);
        const _config_8 = resolveRuntimeExtensions21(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin2(this.config));
        this.middlewareStack.use(getUserAgentPlugin19(this.config));
        this.middlewareStack.use(getRetryPlugin20(this.config));
        this.middlewareStack.use(getContentLengthPlugin20(this.config));
        this.middlewareStack.use(getHostHeaderPlugin19(this.config));
        this.middlewareStack.use(getLoggerPlugin19(this.config));
        this.middlewareStack.use(getRecursionDetectionPlugin19(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin2(this.config, {
          httpAuthSchemeParametersProvider: defaultSigninHttpAuthSchemeParametersProvider6,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig2({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin2(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/CreateOAuth2TokenCommand.js
var CreateOAuth2TokenCommand6;
var init_CreateOAuth2TokenCommand6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/CreateOAuth2TokenCommand.js"() {
    init_client12();
    init_endpoints3();
    init_EndpointParameters21();
    init_schemas_021();
    CreateOAuth2TokenCommand6 = class extends Command.classBuilder().ep(commonParams21).m(function(Command3, cs, config2, o10) {
      return [getEndpointPlugin26(config2, Command3.getEndpointParameterInstructions())];
    }).s("Signin", "CreateOAuth2Token", {}).n("SigninClient", "CreateOAuth2TokenCommand").sc(CreateOAuth2Token$6).build() {
      static {
        __name(this, "CreateOAuth2TokenCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/Signin.js
var commands21, Signin6;
var init_Signin6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/Signin.js"() {
    init_client12();
    init_CreateOAuth2TokenCommand6();
    init_SigninClient6();
    commands21 = {
      CreateOAuth2TokenCommand: CreateOAuth2TokenCommand6
    };
    Signin6 = class extends SigninClient6 {
      static {
        __name(this, "Signin");
      }
    };
    createAggregatedClient19(commands21, Signin6);
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/index.js
var init_commands22 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/index.js"() {
    init_CreateOAuth2TokenCommand6();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/enums.js
var OAuth2ErrorCode6;
var init_enums9 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/enums.js"() {
    OAuth2ErrorCode6 = {
      AUTHCODE_EXPIRED: "AUTHCODE_EXPIRED",
      INSUFFICIENT_PERMISSIONS: "INSUFFICIENT_PERMISSIONS",
      INVALID_REQUEST: "INVALID_REQUEST",
      SERVER_ERROR: "server_error",
      TOKEN_EXPIRED: "TOKEN_EXPIRED",
      USER_CREDENTIALS_CHANGED: "USER_CREDENTIALS_CHANGED"
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/models_0.js
var init_models_021 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/index.js
var signin_exports6 = {};
__export(signin_exports6, {
  $Command: () => Command,
  AccessDeniedException: () => AccessDeniedException9,
  AccessDeniedException$: () => AccessDeniedException$9,
  AccessToken$: () => AccessToken$6,
  CreateOAuth2Token$: () => CreateOAuth2Token$6,
  CreateOAuth2TokenCommand: () => CreateOAuth2TokenCommand6,
  CreateOAuth2TokenRequest$: () => CreateOAuth2TokenRequest$6,
  CreateOAuth2TokenRequestBody$: () => CreateOAuth2TokenRequestBody$6,
  CreateOAuth2TokenResponse$: () => CreateOAuth2TokenResponse$6,
  CreateOAuth2TokenResponseBody$: () => CreateOAuth2TokenResponseBody$6,
  InternalServerException: () => InternalServerException9,
  InternalServerException$: () => InternalServerException$9,
  OAuth2ErrorCode: () => OAuth2ErrorCode6,
  Signin: () => Signin6,
  SigninClient: () => SigninClient6,
  SigninServiceException: () => SigninServiceException6,
  SigninServiceException$: () => SigninServiceException$6,
  TooManyRequestsError: () => TooManyRequestsError6,
  TooManyRequestsError$: () => TooManyRequestsError$6,
  ValidationException: () => ValidationException6,
  ValidationException$: () => ValidationException$6,
  __Client: () => Client,
  errorTypeRegistries: () => errorTypeRegistries21
});
var init_signin6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/index.js"() {
    init_SigninClient6();
    init_Signin6();
    init_commands22();
    init_schemas_021();
    init_enums9();
    init_errors21();
    init_models_021();
    init_SigninServiceException6();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-login/dist-cjs/index.js
var require_dist_cjs149 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-login/dist-cjs/index.js"(exports2) {
    "use strict";
    var client = (init_client13(), __toCommonJS(client_exports10));
    var config2 = (init_config4(), __toCommonJS(config_exports));
    var protocols = (init_protocols11(), __toCommonJS(protocols_exports8));
    var node_crypto = require("node:crypto");
    var node_fs = require("node:fs");
    var node_os = require("node:os");
    var node_path = require("node:path");
    var LoginCredentialsFetcher = class _LoginCredentialsFetcher {
      static {
        __name(this, "LoginCredentialsFetcher");
      }
      profileData;
      init;
      callerClientConfig;
      static REFRESH_THRESHOLD = 5 * 60 * 1e3;
      constructor(profileData, init, callerClientConfig) {
        this.profileData = profileData;
        this.init = init;
        this.callerClientConfig = callerClientConfig;
      }
      async loadCredentials() {
        const token = await this.loadToken();
        if (!token) {
          throw new config2.CredentialsProviderError(`Failed to load a token for session ${this.loginSession}, please re-authenticate using aws login`, { tryNextLink: false, logger: this.logger });
        }
        const accessToken = token.accessToken;
        const now = Date.now();
        const expiryTime = new Date(accessToken.expiresAt).getTime();
        const timeUntilExpiry = expiryTime - now;
        if (timeUntilExpiry <= _LoginCredentialsFetcher.REFRESH_THRESHOLD) {
          return this.refresh(token);
        }
        return {
          accessKeyId: accessToken.accessKeyId,
          secretAccessKey: accessToken.secretAccessKey,
          sessionToken: accessToken.sessionToken,
          accountId: accessToken.accountId,
          expiration: new Date(accessToken.expiresAt)
        };
      }
      get logger() {
        return this.init?.logger;
      }
      get loginSession() {
        return this.profileData.login_session;
      }
      async refresh(token) {
        const { SigninClient: SigninClient10, CreateOAuth2TokenCommand: CreateOAuth2TokenCommand10 } = await Promise.resolve().then(() => (init_signin6(), signin_exports6));
        const { logger: logger5, userAgentAppId } = this.callerClientConfig ?? {};
        const isH210 = /* @__PURE__ */ __name((requestHandler2) => {
          return requestHandler2?.metadata?.handlerProtocol === "h2";
        }, "isH2");
        const requestHandler = isH210(this.callerClientConfig?.requestHandler) ? void 0 : this.callerClientConfig?.requestHandler;
        const region = this.profileData.region ?? await this.callerClientConfig?.region?.() ?? process.env.AWS_REGION;
        const client2 = new SigninClient10({
          credentials: {
            accessKeyId: "",
            secretAccessKey: ""
          },
          region,
          requestHandler,
          logger: logger5,
          userAgentAppId,
          ...this.init?.clientConfig
        });
        this.createDPoPInterceptor(client2.middlewareStack);
        const commandInput = {
          tokenInput: {
            clientId: token.clientId,
            refreshToken: token.refreshToken,
            grantType: "refresh_token"
          }
        };
        try {
          const response = await client2.send(new CreateOAuth2TokenCommand10(commandInput));
          const { accessKeyId, secretAccessKey, sessionToken } = response.tokenOutput?.accessToken ?? {};
          const { refreshToken, expiresIn } = response.tokenOutput ?? {};
          if (!accessKeyId || !secretAccessKey || !sessionToken || !refreshToken) {
            throw new config2.CredentialsProviderError("Token refresh response missing required fields", {
              logger: this.logger,
              tryNextLink: false
            });
          }
          const expiresInMs = (expiresIn ?? 900) * 1e3;
          const expiration = new Date(Date.now() + expiresInMs);
          const updatedToken = {
            ...token,
            accessToken: {
              ...token.accessToken,
              accessKeyId,
              secretAccessKey,
              sessionToken,
              expiresAt: expiration.toISOString()
            },
            refreshToken
          };
          await this.saveToken(updatedToken);
          const newAccessToken = updatedToken.accessToken;
          return {
            accessKeyId: newAccessToken.accessKeyId,
            secretAccessKey: newAccessToken.secretAccessKey,
            sessionToken: newAccessToken.sessionToken,
            accountId: newAccessToken.accountId,
            expiration
          };
        } catch (error4) {
          if (error4.name === "AccessDeniedException") {
            const errorType = error4.error;
            let message2;
            switch (errorType) {
              case "TOKEN_EXPIRED":
                message2 = "Your session has expired. Please reauthenticate.";
                break;
              case "USER_CREDENTIALS_CHANGED":
                message2 = "Unable to refresh credentials because of a change in your password. Please reauthenticate with your new password.";
                break;
              case "INSUFFICIENT_PERMISSIONS":
                message2 = "Unable to refresh credentials due to insufficient permissions. You may be missing permission for the 'CreateOAuth2Token' action.";
                break;
              default:
                message2 = `Failed to refresh token: ${String(error4)}. Please re-authenticate using \`aws login\``;
            }
            throw new config2.CredentialsProviderError(message2, { logger: this.logger, tryNextLink: false });
          }
          throw new config2.CredentialsProviderError(`Failed to refresh token: ${String(error4)}. Please re-authenticate using aws login`, { logger: this.logger });
        }
      }
      async loadToken() {
        const tokenFilePath = this.getTokenFilePath();
        try {
          let tokenData;
          try {
            tokenData = await config2.readFile(tokenFilePath, { ignoreCache: this.init?.ignoreCache });
          } catch {
            tokenData = await node_fs.promises.readFile(tokenFilePath, "utf8");
          }
          const token = JSON.parse(tokenData);
          const missingFields = ["accessToken", "clientId", "refreshToken", "dpopKey"].filter((k32) => !token[k32]);
          if (!token.accessToken?.accountId) {
            missingFields.push("accountId");
          }
          if (missingFields.length > 0) {
            throw new config2.CredentialsProviderError(`Token validation failed, missing fields: ${missingFields.join(", ")}`, {
              logger: this.logger,
              tryNextLink: false
            });
          }
          return token;
        } catch (error4) {
          throw new config2.CredentialsProviderError(`Failed to load token from ${tokenFilePath}: ${String(error4)}`, {
            logger: this.logger,
            tryNextLink: false
          });
        }
      }
      async saveToken(token) {
        const tokenFilePath = this.getTokenFilePath();
        const directory = node_path.dirname(tokenFilePath);
        try {
          await node_fs.promises.mkdir(directory, { recursive: true });
        } catch (error4) {
        }
        await node_fs.promises.writeFile(tokenFilePath, JSON.stringify(token, null, 2), "utf8");
      }
      getTokenFilePath() {
        const directory = process.env.AWS_LOGIN_CACHE_DIRECTORY ?? node_path.join(node_os.homedir(), ".aws", "login", "cache");
        const loginSessionBytes = Buffer.from(this.loginSession, "utf8");
        const loginSessionSha256 = node_crypto.createHash("sha256").update(loginSessionBytes).digest("hex");
        return node_path.join(directory, `${loginSessionSha256}.json`);
      }
      derToRawSignature(derSignature) {
        let offset = 2;
        if (derSignature[offset] !== 2) {
          throw new Error("Invalid DER signature");
        }
        offset++;
        const rLength = derSignature[offset++];
        let r32 = derSignature.subarray(offset, offset + rLength);
        offset += rLength;
        if (derSignature[offset] !== 2) {
          throw new Error("Invalid DER signature");
        }
        offset++;
        const sLength = derSignature[offset++];
        let s = derSignature.subarray(offset, offset + sLength);
        r32 = r32[0] === 0 ? r32.subarray(1) : r32;
        s = s[0] === 0 ? s.subarray(1) : s;
        const rPadded = Buffer.concat([Buffer.alloc(32 - r32.length), r32]);
        const sPadded = Buffer.concat([Buffer.alloc(32 - s.length), s]);
        return Buffer.concat([rPadded, sPadded]);
      }
      createDPoPInterceptor(middlewareStack) {
        middlewareStack.add((next) => async (args) => {
          if (protocols.HttpRequest.isInstance(args.request)) {
            const request4 = args.request;
            const actualEndpoint = `${request4.protocol}//${request4.hostname}${request4.port ? `:${request4.port}` : ""}${request4.path}`;
            const dpop = await this.generateDpop(request4.method, actualEndpoint);
            request4.headers = {
              ...request4.headers,
              DPoP: dpop
            };
          }
          return next(args);
        }, {
          step: "finalizeRequest",
          name: "dpopInterceptor",
          override: true
        });
      }
      async generateDpop(method = "POST", endpoint) {
        const token = await this.loadToken();
        try {
          const privateKey = node_crypto.createPrivateKey({
            key: token.dpopKey,
            format: "pem",
            type: "sec1"
          });
          const publicKey = node_crypto.createPublicKey(privateKey);
          const publicDer = publicKey.export({ format: "der", type: "spki" });
          let pointStart = -1;
          for (let i32 = 0; i32 < publicDer.length; i32++) {
            if (publicDer[i32] === 4) {
              pointStart = i32;
              break;
            }
          }
          const x = publicDer.slice(pointStart + 1, pointStart + 33);
          const y = publicDer.slice(pointStart + 33, pointStart + 65);
          const header = {
            alg: "ES256",
            typ: "dpop+jwt",
            jwk: {
              kty: "EC",
              crv: "P-256",
              x: x.toString("base64url"),
              y: y.toString("base64url")
            }
          };
          const payload3 = {
            jti: crypto.randomUUID(),
            htm: method,
            htu: endpoint,
            iat: Math.floor(Date.now() / 1e3)
          };
          const headerB64 = Buffer.from(JSON.stringify(header)).toString("base64url");
          const payloadB64 = Buffer.from(JSON.stringify(payload3)).toString("base64url");
          const message2 = `${headerB64}.${payloadB64}`;
          const asn1Signature = node_crypto.sign("sha256", Buffer.from(message2), privateKey);
          const rawSignature = this.derToRawSignature(asn1Signature);
          const signatureB64 = rawSignature.toString("base64url");
          return `${message2}.${signatureB64}`;
        } catch (error4) {
          throw new config2.CredentialsProviderError(`Failed to generate Dpop proof: ${error4 instanceof Error ? error4.message : String(error4)}`, { logger: this.logger, tryNextLink: false });
        }
      }
    };
    var fromLoginCredentials = /* @__PURE__ */ __name((init) => async ({ callerClientConfig } = {}) => {
      init?.logger?.debug?.("@aws-sdk/credential-providers - fromLoginCredentials");
      const profiles = await config2.parseKnownFiles(init || {});
      const profileName = config2.getProfileName({
        profile: init?.profile ?? callerClientConfig?.profile
      });
      const profile = profiles[profileName];
      if (!profile?.login_session) {
        throw new config2.CredentialsProviderError(`Profile ${profileName} does not contain login_session.`, {
          tryNextLink: true,
          logger: init?.logger
        });
      }
      const fetcher = new LoginCredentialsFetcher(profile, init, callerClientConfig);
      const credentials = await fetcher.loadCredentials();
      return client.setCredentialFeature(credentials, "CREDENTIALS_LOGIN", "AD");
    }, "fromLoginCredentials");
    exports2.fromLoginCredentials = fromLoginCredentials;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/signature-v4-multi-region/dist-cjs/index.js
var require_dist_cjs150 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/signature-v4-multi-region/dist-cjs/index.js"(exports2) {
    "use strict";
    var signatureV4 = require_dist_cjs141();
    var signatureV4CrtContainer = {
      CrtSignerV4: null
    };
    var SESSION_TOKEN_QUERY_PARAM = "X-Amz-S3session-Token";
    var SESSION_TOKEN_HEADER = SESSION_TOKEN_QUERY_PARAM.toLowerCase();
    var SignatureV4SignWithCredentials = class extends signatureV4.SignatureV4 {
      static {
        __name(this, "SignatureV4SignWithCredentials");
      }
      async signWithCredentials(requestToSign, credentials, options) {
        const credentialsWithoutSessionToken = getCredentialsWithoutSessionToken(credentials);
        requestToSign.headers[SESSION_TOKEN_HEADER] = credentials.sessionToken;
        const privateAccess = this;
        setSingleOverride(privateAccess, credentialsWithoutSessionToken);
        return privateAccess.signRequest(requestToSign, options ?? {});
      }
      async presignWithCredentials(requestToSign, credentials, options) {
        const credentialsWithoutSessionToken = getCredentialsWithoutSessionToken(credentials);
        delete requestToSign.headers[SESSION_TOKEN_HEADER];
        requestToSign.headers[SESSION_TOKEN_QUERY_PARAM] = credentials.sessionToken;
        requestToSign.query = requestToSign.query ?? {};
        requestToSign.query[SESSION_TOKEN_QUERY_PARAM] = credentials.sessionToken;
        const privateAccess = this;
        setSingleOverride(privateAccess, credentialsWithoutSessionToken);
        return this.presign(requestToSign, options);
      }
    };
    function getCredentialsWithoutSessionToken(credentials) {
      return {
        accessKeyId: credentials.accessKeyId,
        secretAccessKey: credentials.secretAccessKey,
        expiration: credentials.expiration
      };
    }
    __name(getCredentialsWithoutSessionToken, "getCredentialsWithoutSessionToken");
    function setSingleOverride(privateAccess, credentialsWithoutSessionToken) {
      const currentCredentialProvider = privateAccess.credentialProvider;
      privateAccess.credentialProvider = () => {
        privateAccess.credentialProvider = currentCredentialProvider;
        return Promise.resolve(credentialsWithoutSessionToken);
      };
    }
    __name(setSingleOverride, "setSingleOverride");
    var SignatureV4MultiRegion19 = class {
      static {
        __name(this, "SignatureV4MultiRegion");
      }
      sigv4aSigner;
      sigv4Signer;
      signerOptions;
      static sigv4aDependency() {
        if (typeof signatureV4CrtContainer.CrtSignerV4 === "function") {
          return "crt";
        } else if (typeof signatureV4.signatureV4aContainer.SignatureV4a === "function") {
          return "js";
        }
        return "none";
      }
      constructor(options) {
        this.sigv4Signer = new SignatureV4SignWithCredentials(options);
        this.signerOptions = options;
      }
      async sign(requestToSign, options = {}) {
        if (options.signingRegion === "*") {
          return this.getSigv4aSigner().sign(requestToSign, options);
        }
        return this.sigv4Signer.sign(requestToSign, options);
      }
      async signWithCredentials(requestToSign, credentials, options = {}) {
        if (options.signingRegion === "*") {
          const signer = this.getSigv4aSigner();
          const CrtSignerV4 = signatureV4CrtContainer.CrtSignerV4;
          if (CrtSignerV4 && signer instanceof CrtSignerV4) {
            return signer.signWithCredentials(requestToSign, credentials, options);
          } else {
            throw new Error(`signWithCredentials with signingRegion '*' is only supported when using the CRT dependency @aws-sdk/signature-v4-crt. Please check whether you have installed the "@aws-sdk/signature-v4-crt" package explicitly. You must also register the package by calling [require("@aws-sdk/signature-v4-crt");] or an ESM equivalent such as [import "@aws-sdk/signature-v4-crt";]. For more information please go to https://github.com/aws/aws-sdk-js-v3#functionality-requiring-aws-common-runtime-crt`);
          }
        }
        return this.sigv4Signer.signWithCredentials(requestToSign, credentials, options);
      }
      async presign(originalRequest, options = {}) {
        if (options.signingRegion === "*") {
          const signer = this.getSigv4aSigner();
          const CrtSignerV4 = signatureV4CrtContainer.CrtSignerV4;
          if (CrtSignerV4 && signer instanceof CrtSignerV4) {
            return signer.presign(originalRequest, options);
          } else {
            throw new Error(`presign with signingRegion '*' is only supported when using the CRT dependency @aws-sdk/signature-v4-crt. Please check whether you have installed the "@aws-sdk/signature-v4-crt" package explicitly. You must also register the package by calling [require("@aws-sdk/signature-v4-crt");] or an ESM equivalent such as [import "@aws-sdk/signature-v4-crt";]. For more information please go to https://github.com/aws/aws-sdk-js-v3#functionality-requiring-aws-common-runtime-crt`);
          }
        }
        return this.sigv4Signer.presign(originalRequest, options);
      }
      async presignWithCredentials(originalRequest, credentials, options = {}) {
        if (options.signingRegion === "*") {
          throw new Error("Method presignWithCredentials is not supported for [signingRegion=*].");
        }
        return this.sigv4Signer.presignWithCredentials(originalRequest, credentials, options);
      }
      getSigv4aSigner() {
        if (!this.sigv4aSigner) {
          const CrtSignerV4 = signatureV4CrtContainer.CrtSignerV4;
          const JsSigV4aSigner = signatureV4.signatureV4aContainer.SignatureV4a;
          if (this.signerOptions.runtime === "node") {
            if (!CrtSignerV4 && !JsSigV4aSigner) {
              throw new Error("Neither CRT nor JS SigV4a implementation is available. Please load either @aws-sdk/signature-v4-crt or @aws-sdk/signature-v4a. For more information please go to https://github.com/aws/aws-sdk-js-v3#functionality-requiring-aws-common-runtime-crt");
            }
            if (CrtSignerV4 && typeof CrtSignerV4 === "function") {
              this.sigv4aSigner = new CrtSignerV4({
                ...this.signerOptions,
                signingAlgorithm: 1
              });
            } else if (JsSigV4aSigner && typeof JsSigV4aSigner === "function") {
              this.sigv4aSigner = new JsSigV4aSigner({
                ...this.signerOptions
              });
            } else {
              throw new Error("Available SigV4a implementation is not a valid constructor. Please ensure you've properly imported @aws-sdk/signature-v4-crt or @aws-sdk/signature-v4a.For more information please go to https://github.com/aws/aws-sdk-js-v3#functionality-requiring-aws-common-runtime-crt");
            }
          } else {
            if (!JsSigV4aSigner || typeof JsSigV4aSigner !== "function") {
              throw new Error("JS SigV4a implementation is not available or not a valid constructor. Please check whether you have installed the @aws-sdk/signature-v4a package explicitly. The CRT implementation is not available for browsers. You must also register the package by calling [require('@aws-sdk/signature-v4a');] or an ESM equivalent such as [import '@aws-sdk/signature-v4a';]. For more information please go to https://github.com/aws/aws-sdk-js-v3#using-javascript-non-crt-implementation-of-sigv4a");
            }
            this.sigv4aSigner = new JsSigV4aSigner({
              ...this.signerOptions
            });
          }
        }
        return this.sigv4aSigner;
      }
    };
    exports2.SignatureV4MultiRegion = SignatureV4MultiRegion19;
    exports2.SignatureV4SignWithCredentials = SignatureV4SignWithCredentials;
    exports2.signatureV4CrtContainer = signatureV4CrtContainer;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/bdd.js
var q6, a22, b22, c22, d22, e22, f22, g22, h22, i22, j22, k22, l13, m13, n6, o6, p6, _data22, root22, r22, nodes22, bdd22;
var init_bdd22 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/bdd.js"() {
    init_endpoints3();
    q6 = "ref";
    a22 = -1;
    b22 = true;
    c22 = "isSet";
    d22 = "PartitionResult";
    e22 = "booleanEquals";
    f22 = "stringEquals";
    g22 = "getAttr";
    h22 = "us-east-1";
    i22 = "sigv4";
    j22 = "sts";
    k22 = "https://sts.{Region}.{PartitionResult#dnsSuffix}";
    l13 = { [q6]: "Endpoint" };
    m13 = { [q6]: "Region" };
    n6 = { [q6]: d22 };
    o6 = {};
    p6 = [m13];
    _data22 = {
      conditions: [
        [c22, [l13]],
        [c22, p6],
        ["aws.partition", p6, d22],
        [e22, [{ [q6]: "UseFIPS" }, b22]],
        [e22, [{ [q6]: "UseDualStack" }, b22]],
        [f22, [m13, "aws-global"]],
        [e22, [{ [q6]: "UseGlobalEndpoint" }, b22]],
        [f22, [m13, "eu-central-1"]],
        [e22, [{ fn: g22, argv: [n6, "supportsDualStack"] }, b22]],
        [e22, [{ fn: g22, argv: [n6, "supportsFIPS"] }, b22]],
        [f22, [m13, "ap-south-1"]],
        [f22, [m13, "eu-north-1"]],
        [f22, [m13, "eu-west-1"]],
        [f22, [m13, "eu-west-2"]],
        [f22, [m13, "eu-west-3"]],
        [f22, [m13, "sa-east-1"]],
        [f22, [m13, h22]],
        [f22, [m13, "us-east-2"]],
        [f22, [m13, "us-west-2"]],
        [f22, [m13, "us-west-1"]],
        [f22, [m13, "ca-central-1"]],
        [f22, [m13, "ap-southeast-1"]],
        [f22, [m13, "ap-northeast-1"]],
        [f22, [m13, "ap-southeast-2"]],
        [f22, [{ fn: g22, argv: [n6, "name"] }, "aws-us-gov"]]
      ],
      results: [
        [a22],
        ["https://sts.amazonaws.com", { authSchemes: [{ name: i22, signingName: j22, signingRegion: h22 }] }],
        [k22, { authSchemes: [{ name: i22, signingName: j22, signingRegion: "{Region}" }] }],
        [a22, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a22, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [l13, o6],
        ["https://sts-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", o6],
        [a22, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://sts.{Region}.amazonaws.com", o6],
        ["https://sts-fips.{Region}.{PartitionResult#dnsSuffix}", o6],
        [a22, "FIPS is enabled but this partition does not support FIPS"],
        ["https://sts.{Region}.{PartitionResult#dualStackDnsSuffix}", o6],
        [a22, "DualStack is enabled but this partition does not support DualStack"],
        [k22, o6],
        [a22, "Invalid Configuration: Missing Region"]
      ]
    };
    root22 = 2;
    r22 = 1e8;
    nodes22 = new Int32Array([
      -1,
      1,
      -1,
      0,
      30,
      3,
      1,
      4,
      r22 + 14,
      2,
      5,
      r22 + 14,
      3,
      25,
      6,
      4,
      24,
      7,
      5,
      r22 + 1,
      8,
      6,
      9,
      r22 + 13,
      7,
      r22 + 1,
      10,
      10,
      r22 + 1,
      11,
      11,
      r22 + 1,
      12,
      12,
      r22 + 1,
      13,
      13,
      r22 + 1,
      14,
      14,
      r22 + 1,
      15,
      15,
      r22 + 1,
      16,
      16,
      r22 + 1,
      17,
      17,
      r22 + 1,
      18,
      18,
      r22 + 1,
      19,
      19,
      r22 + 1,
      20,
      20,
      r22 + 1,
      21,
      21,
      r22 + 1,
      22,
      22,
      r22 + 1,
      23,
      23,
      r22 + 1,
      r22 + 2,
      8,
      r22 + 11,
      r22 + 12,
      4,
      28,
      26,
      9,
      27,
      r22 + 10,
      24,
      r22 + 8,
      r22 + 9,
      8,
      29,
      r22 + 7,
      9,
      r22 + 6,
      r22 + 7,
      3,
      r22 + 3,
      31,
      4,
      r22 + 4,
      r22 + 5
    ]);
    bdd22 = BinaryDecisionDiagram20.from(nodes22, root22, _data22.conditions, _data22.results);
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/endpointResolver.js
var cache22, defaultEndpointResolver22;
var init_endpointResolver22 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/endpointResolver.js"() {
    init_client13();
    init_endpoints3();
    init_bdd22();
    cache22 = new EndpointCache20({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS", "UseGlobalEndpoint"]
    });
    defaultEndpointResolver22 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache22.get(endpointParams, () => decideEndpoint20(bdd22, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    customEndpointFunctions20.aws = awsEndpointFunctions19;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption22(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "sts",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createAwsAuthSigv4aHttpAuthOption6(authParameters) {
  return {
    schemeId: "aws.auth#sigv4a",
    signingProperties: {
      name: "sts",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption22(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var import_signature_v4_multi_region11, createEndpointRuleSetHttpAuthSchemeParametersProvider6, _defaultSTSHttpAuthSchemeParametersProvider6, defaultSTSHttpAuthSchemeParametersProvider6, createEndpointRuleSetHttpAuthSchemeProvider6, _defaultSTSHttpAuthSchemeProvider6, defaultSTSHttpAuthSchemeProvider6, resolveHttpAuthSchemeConfig22;
var init_httpAuthSchemeProvider22 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes9();
    import_signature_v4_multi_region11 = __toESM(require_dist_cjs150());
    init_client12();
    init_endpoints3();
    init_endpointResolver22();
    createEndpointRuleSetHttpAuthSchemeParametersProvider6 = /* @__PURE__ */ __name((defaultHttpAuthSchemeParametersProvider) => async (config2, context, input) => {
      if (!input) {
        throw new Error("Could not find `input` for `defaultEndpointRuleSetHttpAuthSchemeParametersProvider`");
      }
      const defaultParameters = await defaultHttpAuthSchemeParametersProvider(config2, context, input);
      const instructionsFn = getSmithyContext26(context)?.commandInstance?.constructor?.getEndpointParameterInstructions;
      if (!instructionsFn) {
        throw new Error(`getEndpointParameterInstructions() is not defined on '${context.commandName}'`);
      }
      const endpointParameters = await resolveParams7(input, { getEndpointParameterInstructions: instructionsFn }, config2);
      return Object.assign(defaultParameters, endpointParameters);
    }, "createEndpointRuleSetHttpAuthSchemeParametersProvider");
    _defaultSTSHttpAuthSchemeParametersProvider6 = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: getSmithyContext26(context).operation,
        region: await normalizeProvider22(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "_defaultSTSHttpAuthSchemeParametersProvider");
    defaultSTSHttpAuthSchemeParametersProvider6 = createEndpointRuleSetHttpAuthSchemeParametersProvider6(_defaultSTSHttpAuthSchemeParametersProvider6);
    __name(createAwsAuthSigv4HttpAuthOption22, "createAwsAuthSigv4HttpAuthOption");
    __name(createAwsAuthSigv4aHttpAuthOption6, "createAwsAuthSigv4aHttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption22, "createSmithyApiNoAuthHttpAuthOption");
    createEndpointRuleSetHttpAuthSchemeProvider6 = /* @__PURE__ */ __name((defaultEndpointResolver32, defaultHttpAuthSchemeResolver, createHttpAuthOptionFunctions) => {
      const endpointRuleSetHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
        const endpoint = defaultEndpointResolver32(authParameters);
        const authSchemes = endpoint.properties?.authSchemes;
        if (!authSchemes) {
          return defaultHttpAuthSchemeResolver(authParameters);
        }
        const options = [];
        for (const scheme of authSchemes) {
          const { name: resolvedName, properties = {}, ...rest } = scheme;
          const name = resolvedName.toLowerCase();
          if (resolvedName !== name) {
            console.warn(`HttpAuthScheme has been normalized with lowercasing: '${resolvedName}' to '${name}'`);
          }
          let schemeId;
          if (name === "sigv4a") {
            schemeId = "aws.auth#sigv4a";
            const sigv4Present = authSchemes.find((s) => {
              const name2 = s.name.toLowerCase();
              return name2 !== "sigv4a" && name2.startsWith("sigv4");
            });
            if (import_signature_v4_multi_region11.SignatureV4MultiRegion.sigv4aDependency() === "none" && sigv4Present) {
              continue;
            }
          } else if (name.startsWith("sigv4")) {
            schemeId = "aws.auth#sigv4";
          } else {
            throw new Error(`Unknown HttpAuthScheme found in '@smithy.rules#endpointRuleSet': '${name}'`);
          }
          const createOption = createHttpAuthOptionFunctions[schemeId];
          if (!createOption) {
            throw new Error(`Could not find HttpAuthOption create function for '${schemeId}'`);
          }
          const option = createOption(authParameters);
          option.schemeId = schemeId;
          option.signingProperties = { ...option.signingProperties || {}, ...rest, ...properties };
          options.push(option);
        }
        return options;
      }, "endpointRuleSetHttpAuthSchemeProvider");
      return endpointRuleSetHttpAuthSchemeProvider;
    }, "createEndpointRuleSetHttpAuthSchemeProvider");
    _defaultSTSHttpAuthSchemeProvider6 = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "AssumeRoleWithWebIdentity": {
          options.push(createSmithyApiNoAuthHttpAuthOption22(authParameters));
          options.push(createAwsAuthSigv4aHttpAuthOption6(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption22(authParameters));
          options.push(createAwsAuthSigv4aHttpAuthOption6(authParameters));
        }
      }
      return options;
    }, "_defaultSTSHttpAuthSchemeProvider");
    defaultSTSHttpAuthSchemeProvider6 = createEndpointRuleSetHttpAuthSchemeProvider6(defaultEndpointResolver22, _defaultSTSHttpAuthSchemeProvider6, {
      "aws.auth#sigv4": createAwsAuthSigv4HttpAuthOption22,
      "aws.auth#sigv4a": createAwsAuthSigv4aHttpAuthOption6,
      "smithy.api#noAuth": createSmithyApiNoAuthHttpAuthOption22
    });
    resolveHttpAuthSchemeConfig22 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveAwsSdkSigV4Config7(config2);
      const config_1 = resolveAwsSdkSigV4AConfig7(config_0);
      return Object.assign(config_1, {
        authSchemePreference: normalizeProvider22(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/EndpointParameters.js
var resolveClientEndpointParameters22, commonParams22;
var init_EndpointParameters22 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters22 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        useGlobalEndpoint: options.useGlobalEndpoint ?? false,
        defaultSigningName: "sts"
      });
    }, "resolveClientEndpointParameters");
    commonParams22 = {
      UseGlobalEndpoint: { type: "builtInParams", name: "useGlobalEndpoint" },
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/STSServiceException.js
var STSServiceException6;
var init_STSServiceException6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/STSServiceException.js"() {
    init_client12();
    STSServiceException6 = class _STSServiceException extends ServiceException {
      static {
        __name(this, "STSServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _STSServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/errors.js
var ExpiredTokenException9, MalformedPolicyDocumentException6, PackedPolicyTooLargeException6, RegionDisabledException6, IDPRejectedClaimException6, InvalidIdentityTokenException6, IDPCommunicationErrorException6;
var init_errors22 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/errors.js"() {
    init_STSServiceException6();
    ExpiredTokenException9 = class _ExpiredTokenException extends STSServiceException6 {
      static {
        __name(this, "ExpiredTokenException");
      }
      name = "ExpiredTokenException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ExpiredTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ExpiredTokenException.prototype);
      }
    };
    MalformedPolicyDocumentException6 = class _MalformedPolicyDocumentException extends STSServiceException6 {
      static {
        __name(this, "MalformedPolicyDocumentException");
      }
      name = "MalformedPolicyDocumentException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "MalformedPolicyDocumentException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _MalformedPolicyDocumentException.prototype);
      }
    };
    PackedPolicyTooLargeException6 = class _PackedPolicyTooLargeException extends STSServiceException6 {
      static {
        __name(this, "PackedPolicyTooLargeException");
      }
      name = "PackedPolicyTooLargeException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "PackedPolicyTooLargeException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _PackedPolicyTooLargeException.prototype);
      }
    };
    RegionDisabledException6 = class _RegionDisabledException extends STSServiceException6 {
      static {
        __name(this, "RegionDisabledException");
      }
      name = "RegionDisabledException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "RegionDisabledException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _RegionDisabledException.prototype);
      }
    };
    IDPRejectedClaimException6 = class _IDPRejectedClaimException extends STSServiceException6 {
      static {
        __name(this, "IDPRejectedClaimException");
      }
      name = "IDPRejectedClaimException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "IDPRejectedClaimException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _IDPRejectedClaimException.prototype);
      }
    };
    InvalidIdentityTokenException6 = class _InvalidIdentityTokenException extends STSServiceException6 {
      static {
        __name(this, "InvalidIdentityTokenException");
      }
      name = "InvalidIdentityTokenException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidIdentityTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidIdentityTokenException.prototype);
      }
    };
    IDPCommunicationErrorException6 = class _IDPCommunicationErrorException extends STSServiceException6 {
      static {
        __name(this, "IDPCommunicationErrorException");
      }
      name = "IDPCommunicationErrorException";
      $fault = "client";
      $retryable = {};
      constructor(opts) {
        super({
          name: "IDPCommunicationErrorException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _IDPCommunicationErrorException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/schemas/schemas_0.js
var _A6, _AKI7, _AR6, _ARI6, _ARR6, _ARRs6, _ARU6, _ARWWI6, _ARWWIR6, _ARWWIRs6, _Au6, _C7, _CA6, _DS6, _E7, _EI6, _ETE9, _IDPCEE6, _IDPRCE6, _IITE6, _K6, _MPDE6, _P6, _PA6, _PAr6, _PC6, _PCLT6, _PCr6, _PDT6, _PI6, _PPS6, _PPTLE6, _Pr6, _RA6, _RDE6, _RSN6, _SAK6, _SFWIT6, _SI6, _SN6, _ST7, _T6, _TC6, _TTK6, _Ta6, _V6, _WIT6, _a6, _aKST6, _aQE6, _c22, _cTT6, _e22, _hE22, _m19, _pDLT6, _s22, _tLT6, n022, _s_registry22, STSServiceException$6, n0_registry22, ExpiredTokenException$9, IDPCommunicationErrorException$6, IDPRejectedClaimException$6, InvalidIdentityTokenException$6, MalformedPolicyDocumentException$6, PackedPolicyTooLargeException$6, RegionDisabledException$6, errorTypeRegistries22, accessKeySecretType6, clientTokenType6, AssumedRoleUser$6, AssumeRoleRequest$6, AssumeRoleResponse$6, AssumeRoleWithWebIdentityRequest$6, AssumeRoleWithWebIdentityResponse$6, Credentials$7, PolicyDescriptorType$6, ProvidedContext$6, Tag$6, policyDescriptorListType6, ProvidedContextsListType6, tagKeyListType6, tagListType6, AssumeRole$6, AssumeRoleWithWebIdentity$6;
var init_schemas_022 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/schemas/schemas_0.js"() {
    init_schema6();
    init_errors22();
    init_STSServiceException6();
    _A6 = "Arn";
    _AKI7 = "AccessKeyId";
    _AR6 = "AssumeRole";
    _ARI6 = "AssumedRoleId";
    _ARR6 = "AssumeRoleRequest";
    _ARRs6 = "AssumeRoleResponse";
    _ARU6 = "AssumedRoleUser";
    _ARWWI6 = "AssumeRoleWithWebIdentity";
    _ARWWIR6 = "AssumeRoleWithWebIdentityRequest";
    _ARWWIRs6 = "AssumeRoleWithWebIdentityResponse";
    _Au6 = "Audience";
    _C7 = "Credentials";
    _CA6 = "ContextAssertion";
    _DS6 = "DurationSeconds";
    _E7 = "Expiration";
    _EI6 = "ExternalId";
    _ETE9 = "ExpiredTokenException";
    _IDPCEE6 = "IDPCommunicationErrorException";
    _IDPRCE6 = "IDPRejectedClaimException";
    _IITE6 = "InvalidIdentityTokenException";
    _K6 = "Key";
    _MPDE6 = "MalformedPolicyDocumentException";
    _P6 = "Policy";
    _PA6 = "PolicyArns";
    _PAr6 = "ProviderArn";
    _PC6 = "ProvidedContexts";
    _PCLT6 = "ProvidedContextsListType";
    _PCr6 = "ProvidedContext";
    _PDT6 = "PolicyDescriptorType";
    _PI6 = "ProviderId";
    _PPS6 = "PackedPolicySize";
    _PPTLE6 = "PackedPolicyTooLargeException";
    _Pr6 = "Provider";
    _RA6 = "RoleArn";
    _RDE6 = "RegionDisabledException";
    _RSN6 = "RoleSessionName";
    _SAK6 = "SecretAccessKey";
    _SFWIT6 = "SubjectFromWebIdentityToken";
    _SI6 = "SourceIdentity";
    _SN6 = "SerialNumber";
    _ST7 = "SessionToken";
    _T6 = "Tags";
    _TC6 = "TokenCode";
    _TTK6 = "TransitiveTagKeys";
    _Ta6 = "Tag";
    _V6 = "Value";
    _WIT6 = "WebIdentityToken";
    _a6 = "arn";
    _aKST6 = "accessKeySecretType";
    _aQE6 = "awsQueryError";
    _c22 = "client";
    _cTT6 = "clientTokenType";
    _e22 = "error";
    _hE22 = "httpError";
    _m19 = "message";
    _pDLT6 = "policyDescriptorListType";
    _s22 = "smithy.ts.sdk.synthetic.com.amazonaws.sts";
    _tLT6 = "tagListType";
    n022 = "com.amazonaws.sts";
    _s_registry22 = TypeRegistry3.for(_s22);
    STSServiceException$6 = [-3, _s22, "STSServiceException", 0, [], []];
    _s_registry22.registerError(STSServiceException$6, STSServiceException6);
    n0_registry22 = TypeRegistry3.for(n022);
    ExpiredTokenException$9 = [
      -3,
      n022,
      _ETE9,
      { [_aQE6]: [`ExpiredTokenException`, 400], [_e22]: _c22, [_hE22]: 400 },
      [_m19],
      [0]
    ];
    n0_registry22.registerError(ExpiredTokenException$9, ExpiredTokenException9);
    IDPCommunicationErrorException$6 = [
      -3,
      n022,
      _IDPCEE6,
      { [_aQE6]: [`IDPCommunicationError`, 400], [_e22]: _c22, [_hE22]: 400 },
      [_m19],
      [0]
    ];
    n0_registry22.registerError(IDPCommunicationErrorException$6, IDPCommunicationErrorException6);
    IDPRejectedClaimException$6 = [
      -3,
      n022,
      _IDPRCE6,
      { [_aQE6]: [`IDPRejectedClaim`, 403], [_e22]: _c22, [_hE22]: 403 },
      [_m19],
      [0]
    ];
    n0_registry22.registerError(IDPRejectedClaimException$6, IDPRejectedClaimException6);
    InvalidIdentityTokenException$6 = [
      -3,
      n022,
      _IITE6,
      { [_aQE6]: [`InvalidIdentityToken`, 400], [_e22]: _c22, [_hE22]: 400 },
      [_m19],
      [0]
    ];
    n0_registry22.registerError(InvalidIdentityTokenException$6, InvalidIdentityTokenException6);
    MalformedPolicyDocumentException$6 = [
      -3,
      n022,
      _MPDE6,
      { [_aQE6]: [`MalformedPolicyDocument`, 400], [_e22]: _c22, [_hE22]: 400 },
      [_m19],
      [0]
    ];
    n0_registry22.registerError(MalformedPolicyDocumentException$6, MalformedPolicyDocumentException6);
    PackedPolicyTooLargeException$6 = [
      -3,
      n022,
      _PPTLE6,
      { [_aQE6]: [`PackedPolicyTooLarge`, 400], [_e22]: _c22, [_hE22]: 400 },
      [_m19],
      [0]
    ];
    n0_registry22.registerError(PackedPolicyTooLargeException$6, PackedPolicyTooLargeException6);
    RegionDisabledException$6 = [
      -3,
      n022,
      _RDE6,
      { [_aQE6]: [`RegionDisabledException`, 403], [_e22]: _c22, [_hE22]: 403 },
      [_m19],
      [0]
    ];
    n0_registry22.registerError(RegionDisabledException$6, RegionDisabledException6);
    errorTypeRegistries22 = [_s_registry22, n0_registry22];
    accessKeySecretType6 = [0, n022, _aKST6, 8, 0];
    clientTokenType6 = [0, n022, _cTT6, 8, 0];
    AssumedRoleUser$6 = [3, n022, _ARU6, 0, [_ARI6, _A6], [0, 0], 2];
    AssumeRoleRequest$6 = [
      3,
      n022,
      _ARR6,
      0,
      [_RA6, _RSN6, _PA6, _P6, _DS6, _T6, _TTK6, _EI6, _SN6, _TC6, _SI6, _PC6],
      [0, 0, () => policyDescriptorListType6, 0, 1, () => tagListType6, 64 | 0, 0, 0, 0, 0, () => ProvidedContextsListType6],
      2
    ];
    AssumeRoleResponse$6 = [
      3,
      n022,
      _ARRs6,
      0,
      [_C7, _ARU6, _PPS6, _SI6],
      [[() => Credentials$7, 0], () => AssumedRoleUser$6, 1, 0]
    ];
    AssumeRoleWithWebIdentityRequest$6 = [
      3,
      n022,
      _ARWWIR6,
      0,
      [_RA6, _RSN6, _WIT6, _PI6, _PA6, _P6, _DS6],
      [0, 0, [() => clientTokenType6, 0], 0, () => policyDescriptorListType6, 0, 1],
      3
    ];
    AssumeRoleWithWebIdentityResponse$6 = [
      3,
      n022,
      _ARWWIRs6,
      0,
      [_C7, _SFWIT6, _ARU6, _PPS6, _Pr6, _Au6, _SI6],
      [[() => Credentials$7, 0], 0, () => AssumedRoleUser$6, 1, 0, 0, 0]
    ];
    Credentials$7 = [
      3,
      n022,
      _C7,
      0,
      [_AKI7, _SAK6, _ST7, _E7],
      [0, [() => accessKeySecretType6, 0], 0, 4],
      4
    ];
    PolicyDescriptorType$6 = [3, n022, _PDT6, 0, [_a6], [0]];
    ProvidedContext$6 = [3, n022, _PCr6, 0, [_PAr6, _CA6], [0, 0]];
    Tag$6 = [3, n022, _Ta6, 0, [_K6, _V6], [0, 0], 2];
    policyDescriptorListType6 = [1, n022, _pDLT6, 0, () => PolicyDescriptorType$6];
    ProvidedContextsListType6 = [1, n022, _PCLT6, 0, () => ProvidedContext$6];
    tagKeyListType6 = 64 | 0;
    tagListType6 = [1, n022, _tLT6, 0, () => Tag$6];
    AssumeRole$6 = [9, n022, _AR6, 0, () => AssumeRoleRequest$6, () => AssumeRoleResponse$6];
    AssumeRoleWithWebIdentity$6 = [
      9,
      n022,
      _ARWWI6,
      0,
      () => AssumeRoleWithWebIdentityRequest$6,
      () => AssumeRoleWithWebIdentityResponse$6
    ];
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.shared.js
var import_signature_v4_multi_region12, getRuntimeConfig43;
var init_runtimeConfig_shared22 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.shared.js"() {
    init_httpAuthSchemes9();
    init_protocols15();
    import_signature_v4_multi_region12 = __toESM(require_dist_cjs150());
    init_dist_es2();
    init_client12();
    init_protocols11();
    init_serde4();
    init_httpAuthSchemeProvider22();
    init_endpointResolver22();
    init_schemas_022();
    getRuntimeConfig43 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2011-06-15",
        base64Decoder: config2?.base64Decoder ?? fromBase6436,
        base64Encoder: config2?.base64Encoder ?? toBase6441,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver22,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSTSHttpAuthSchemeProvider6,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer7()
          },
          {
            schemeId: "aws.auth#sigv4a",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4a"), "identityProvider"),
            signer: new AwsSdkSigV4ASigner7()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner2()
          }
        ],
        logger: config2?.logger ?? new NoOpLogger20(),
        protocol: config2?.protocol ?? AwsQueryProtocol7,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.sts",
          errorTypeRegistries: errorTypeRegistries22,
          xmlNamespace: "https://sts.amazonaws.com/doc/2011-06-15/",
          version: "2011-06-15",
          serviceTarget: "AWSSecurityTokenServiceV20110615"
        },
        serviceId: config2?.serviceId ?? "STS",
        signerConstructor: config2?.signerConstructor ?? import_signature_v4_multi_region12.SignatureV4MultiRegion,
        urlParser: config2?.urlParser ?? parseUrl21,
        utf8Decoder: config2?.utf8Decoder ?? fromUtf825,
        utf8Encoder: config2?.utf8Encoder ?? toUtf839
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.js
var import_node_http_handler22, getRuntimeConfig44;
var init_runtimeConfig22 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.js"() {
    init_package7();
    init_client13();
    init_httpAuthSchemes9();
    init_dist_es2();
    init_client12();
    init_config4();
    init_retry3();
    init_serde4();
    import_node_http_handler22 = __toESM(require_dist_cjs144());
    init_runtimeConfig_shared22();
    getRuntimeConfig44 = /* @__PURE__ */ __name((config2) => {
      emitWarningIfUnsupportedVersion28(process.version);
      const defaultsMode = resolveDefaultsModeConfig19(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(loadConfigsForDefaultMode19), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig43(config2);
      emitWarningIfUnsupportedVersion27(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? loadConfig3(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS7, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? calculateBodyLength19,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? createDefaultUserAgentProvider19({ serviceId: clientSharedValues.serviceId, clientVersion: package_default7.version }),
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4") || (async (idProps) => await config2.credentialDefaultProvider(idProps?.__config || {})()), "identityProvider"),
            signer: new AwsSdkSigV4Signer7()
          },
          {
            schemeId: "aws.auth#sigv4a",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4a"), "identityProvider"),
            signer: new AwsSdkSigV4ASigner7()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner2()
          }
        ],
        maxAttempts: config2?.maxAttempts ?? loadConfig3(NODE_MAX_ATTEMPT_CONFIG_OPTIONS20, config2),
        region: config2?.region ?? loadConfig3(NODE_REGION_CONFIG_OPTIONS20, { ...NODE_REGION_CONFIG_FILE_OPTIONS20, ...loaderConfig }),
        requestHandler: import_node_http_handler22.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? loadConfig3({
          ...NODE_RETRY_MODE_CONFIG_OPTIONS20,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || DEFAULT_RETRY_MODE20, "default")
        }, config2),
        sha256: config2?.sha256 ?? Hash19.bind(null, "sha256"),
        sigv4aSigningRegionSet: config2?.sigv4aSigningRegionSet ?? loadConfig3(NODE_SIGV4A_CONFIG_OPTIONS7, loaderConfig),
        streamCollector: config2?.streamCollector ?? import_node_http_handler22.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? loadConfig3(NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS19, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? loadConfig3(NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS19, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? loadConfig3(NODE_APP_ID_CONFIG_OPTIONS19, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration22, resolveHttpAuthRuntimeConfig22;
var init_httpAuthExtensionConfiguration22 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration22 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig22 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeExtensions.js
var resolveRuntimeExtensions22;
var init_runtimeExtensions22 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeExtensions.js"() {
    init_client13();
    init_client12();
    init_protocols11();
    init_httpAuthExtensionConfiguration22();
    resolveRuntimeExtensions22 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign(getAwsRegionExtensionConfiguration19(runtimeConfig), getDefaultExtensionConfiguration19(runtimeConfig), getHttpHandlerExtensionConfiguration20(runtimeConfig), getHttpAuthExtensionConfiguration22(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, resolveAwsRegionExtensionConfiguration19(extensionConfiguration), resolveDefaultRuntimeConfig19(extensionConfiguration), resolveHttpHandlerRuntimeConfig20(extensionConfiguration), resolveHttpAuthRuntimeConfig22(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STSClient.js
var STSClient7;
var init_STSClient6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STSClient.js"() {
    init_client13();
    init_dist_es2();
    init_client12();
    init_config4();
    init_endpoints3();
    init_protocols11();
    init_retry3();
    init_schema6();
    init_httpAuthSchemeProvider22();
    init_EndpointParameters22();
    init_runtimeConfig22();
    init_runtimeExtensions22();
    STSClient7 = class extends Client {
      static {
        __name(this, "STSClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig44(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters22(_config_0);
        const _config_2 = resolveUserAgentConfig19(_config_1);
        const _config_3 = resolveRetryConfig20(_config_2);
        const _config_4 = resolveRegionConfig19(_config_3);
        const _config_5 = resolveHostHeaderConfig19(_config_4);
        const _config_6 = resolveEndpointConfig20(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig22(_config_6);
        const _config_8 = resolveRuntimeExtensions22(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin2(this.config));
        this.middlewareStack.use(getUserAgentPlugin19(this.config));
        this.middlewareStack.use(getRetryPlugin20(this.config));
        this.middlewareStack.use(getContentLengthPlugin20(this.config));
        this.middlewareStack.use(getHostHeaderPlugin19(this.config));
        this.middlewareStack.use(getLoggerPlugin19(this.config));
        this.middlewareStack.use(getRecursionDetectionPlugin19(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin2(this.config, {
          httpAuthSchemeParametersProvider: defaultSTSHttpAuthSchemeParametersProvider6,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig2({
            "aws.auth#sigv4": config2.credentials,
            "aws.auth#sigv4a": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin2(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleCommand.js
var AssumeRoleCommand6;
var init_AssumeRoleCommand6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleCommand.js"() {
    init_client12();
    init_endpoints3();
    init_EndpointParameters22();
    init_schemas_022();
    AssumeRoleCommand6 = class extends Command.classBuilder().ep(commonParams22).m(function(Command3, cs, config2, o10) {
      return [getEndpointPlugin26(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "AssumeRole", {}).n("STSClient", "AssumeRoleCommand").sc(AssumeRole$6).build() {
      static {
        __name(this, "AssumeRoleCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleWithWebIdentityCommand.js
var AssumeRoleWithWebIdentityCommand6;
var init_AssumeRoleWithWebIdentityCommand6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleWithWebIdentityCommand.js"() {
    init_client12();
    init_endpoints3();
    init_EndpointParameters22();
    init_schemas_022();
    AssumeRoleWithWebIdentityCommand6 = class extends Command.classBuilder().ep(commonParams22).m(function(Command3, cs, config2, o10) {
      return [getEndpointPlugin26(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "AssumeRoleWithWebIdentity", {}).n("STSClient", "AssumeRoleWithWebIdentityCommand").sc(AssumeRoleWithWebIdentity$6).build() {
      static {
        __name(this, "AssumeRoleWithWebIdentityCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STS.js
var commands22, STS6;
var init_STS6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STS.js"() {
    init_client12();
    init_AssumeRoleCommand6();
    init_AssumeRoleWithWebIdentityCommand6();
    init_STSClient6();
    commands22 = {
      AssumeRoleCommand: AssumeRoleCommand6,
      AssumeRoleWithWebIdentityCommand: AssumeRoleWithWebIdentityCommand6
    };
    STS6 = class extends STSClient7 {
      static {
        __name(this, "STS");
      }
    };
    createAggregatedClient19(commands22, STS6);
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/index.js
var init_commands23 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/index.js"() {
    init_AssumeRoleCommand6();
    init_AssumeRoleWithWebIdentityCommand6();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/models_0.js
var init_models_022 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultStsRoleAssumers.js
var getAccountIdFromAssumedRoleUser6, resolveRegion6, getDefaultRoleAssumer11, getDefaultRoleAssumerWithWebIdentity11, isH26;
var init_defaultStsRoleAssumers6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultStsRoleAssumers.js"() {
    init_client13();
    init_AssumeRoleCommand6();
    init_AssumeRoleWithWebIdentityCommand6();
    getAccountIdFromAssumedRoleUser6 = /* @__PURE__ */ __name((assumedRoleUser) => {
      if (typeof assumedRoleUser?.Arn === "string") {
        const arnComponents = assumedRoleUser.Arn.split(":");
        if (arnComponents.length > 4 && arnComponents[4] !== "") {
          return arnComponents[4];
        }
      }
      return void 0;
    }, "getAccountIdFromAssumedRoleUser");
    resolveRegion6 = /* @__PURE__ */ __name(async (_region, _parentRegion, credentialProviderLogger, loaderConfig = {}) => {
      const region = typeof _region === "function" ? await _region() : _region;
      const parentRegion = typeof _parentRegion === "function" ? await _parentRegion() : _parentRegion;
      let stsDefaultRegion = "";
      const resolvedRegion = region ?? parentRegion ?? (stsDefaultRegion = await stsRegionDefaultResolver6(loaderConfig)());
      credentialProviderLogger?.debug?.("@aws-sdk/client-sts::resolveRegion", "accepting first of:", `${region} (credential provider clientConfig)`, `${parentRegion} (contextual client)`, `${stsDefaultRegion} (STS default: AWS_REGION, profile region, or us-east-1)`);
      return resolvedRegion;
    }, "resolveRegion");
    getDefaultRoleAssumer11 = /* @__PURE__ */ __name((stsOptions, STSClient12) => {
      let stsClient;
      let closureSourceCreds;
      return async (sourceCreds, params) => {
        closureSourceCreds = sourceCreds;
        if (!stsClient) {
          const { logger: logger5 = stsOptions?.parentClientConfig?.logger, profile = stsOptions?.parentClientConfig?.profile, region, requestHandler = stsOptions?.parentClientConfig?.requestHandler, credentialProviderLogger, userAgentAppId = stsOptions?.parentClientConfig?.userAgentAppId } = stsOptions;
          const resolvedRegion = await resolveRegion6(region, stsOptions?.parentClientConfig?.region, credentialProviderLogger, {
            logger: logger5,
            profile
          });
          const isCompatibleRequestHandler = !isH26(requestHandler);
          stsClient = new STSClient12({
            ...stsOptions,
            userAgentAppId,
            profile,
            credentialDefaultProvider: /* @__PURE__ */ __name(() => async () => closureSourceCreds, "credentialDefaultProvider"),
            region: resolvedRegion,
            requestHandler: isCompatibleRequestHandler ? requestHandler : void 0,
            logger: logger5
          });
        }
        const { Credentials, AssumedRoleUser } = await stsClient.send(new AssumeRoleCommand6(params));
        if (!Credentials || !Credentials.AccessKeyId || !Credentials.SecretAccessKey) {
          throw new Error(`Invalid response from STS.assumeRole call with role ${params.RoleArn}`);
        }
        const accountId = getAccountIdFromAssumedRoleUser6(AssumedRoleUser);
        const credentials = {
          accessKeyId: Credentials.AccessKeyId,
          secretAccessKey: Credentials.SecretAccessKey,
          sessionToken: Credentials.SessionToken,
          expiration: Credentials.Expiration,
          ...Credentials.CredentialScope && { credentialScope: Credentials.CredentialScope },
          ...accountId && { accountId }
        };
        setCredentialFeature9(credentials, "CREDENTIALS_STS_ASSUME_ROLE", "i");
        return credentials;
      };
    }, "getDefaultRoleAssumer");
    getDefaultRoleAssumerWithWebIdentity11 = /* @__PURE__ */ __name((stsOptions, STSClient12) => {
      let stsClient;
      return async (params) => {
        if (!stsClient) {
          const { logger: logger5 = stsOptions?.parentClientConfig?.logger, profile = stsOptions?.parentClientConfig?.profile, region, requestHandler = stsOptions?.parentClientConfig?.requestHandler, credentialProviderLogger, userAgentAppId = stsOptions?.parentClientConfig?.userAgentAppId } = stsOptions;
          const resolvedRegion = await resolveRegion6(region, stsOptions?.parentClientConfig?.region, credentialProviderLogger, {
            logger: logger5,
            profile
          });
          const isCompatibleRequestHandler = !isH26(requestHandler);
          stsClient = new STSClient12({
            ...stsOptions,
            userAgentAppId,
            profile,
            region: resolvedRegion,
            requestHandler: isCompatibleRequestHandler ? requestHandler : void 0,
            logger: logger5
          });
        }
        const { Credentials, AssumedRoleUser } = await stsClient.send(new AssumeRoleWithWebIdentityCommand6(params));
        if (!Credentials || !Credentials.AccessKeyId || !Credentials.SecretAccessKey) {
          throw new Error(`Invalid response from STS.assumeRoleWithWebIdentity call with role ${params.RoleArn}`);
        }
        const accountId = getAccountIdFromAssumedRoleUser6(AssumedRoleUser);
        const credentials = {
          accessKeyId: Credentials.AccessKeyId,
          secretAccessKey: Credentials.SecretAccessKey,
          sessionToken: Credentials.SessionToken,
          expiration: Credentials.Expiration,
          ...Credentials.CredentialScope && { credentialScope: Credentials.CredentialScope },
          ...accountId && { accountId }
        };
        if (accountId) {
          setCredentialFeature9(credentials, "RESOLVED_ACCOUNT_ID", "T");
        }
        setCredentialFeature9(credentials, "CREDENTIALS_STS_ASSUME_ROLE_WEB_ID", "k");
        return credentials;
      };
    }, "getDefaultRoleAssumerWithWebIdentity");
    isH26 = /* @__PURE__ */ __name((requestHandler) => {
      return requestHandler?.metadata?.handlerProtocol === "h2";
    }, "isH2");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultRoleAssumers.js
var getCustomizableStsClientCtor6, getDefaultRoleAssumer12, getDefaultRoleAssumerWithWebIdentity12, decorateDefaultCredentialProvider6;
var init_defaultRoleAssumers6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultRoleAssumers.js"() {
    init_defaultStsRoleAssumers6();
    init_STSClient6();
    getCustomizableStsClientCtor6 = /* @__PURE__ */ __name((baseCtor, customizations) => {
      if (!customizations)
        return baseCtor;
      else
        return class CustomizableSTSClient extends baseCtor {
          static {
            __name(this, "CustomizableSTSClient");
          }
          constructor(config2) {
            super(config2);
            for (const customization of customizations) {
              this.middlewareStack.use(customization);
            }
          }
        };
    }, "getCustomizableStsClientCtor");
    getDefaultRoleAssumer12 = /* @__PURE__ */ __name((stsOptions = {}, stsPlugins) => getDefaultRoleAssumer11(stsOptions, getCustomizableStsClientCtor6(STSClient7, stsPlugins)), "getDefaultRoleAssumer");
    getDefaultRoleAssumerWithWebIdentity12 = /* @__PURE__ */ __name((stsOptions = {}, stsPlugins) => getDefaultRoleAssumerWithWebIdentity11(stsOptions, getCustomizableStsClientCtor6(STSClient7, stsPlugins)), "getDefaultRoleAssumerWithWebIdentity");
    decorateDefaultCredentialProvider6 = /* @__PURE__ */ __name((provider) => (input) => provider({
      roleAssumer: getDefaultRoleAssumer12(input),
      roleAssumerWithWebIdentity: getDefaultRoleAssumerWithWebIdentity12(input),
      ...input
    }), "decorateDefaultCredentialProvider");
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/index.js
var sts_exports6 = {};
__export(sts_exports6, {
  $Command: () => Command,
  AssumeRole$: () => AssumeRole$6,
  AssumeRoleCommand: () => AssumeRoleCommand6,
  AssumeRoleRequest$: () => AssumeRoleRequest$6,
  AssumeRoleResponse$: () => AssumeRoleResponse$6,
  AssumeRoleWithWebIdentity$: () => AssumeRoleWithWebIdentity$6,
  AssumeRoleWithWebIdentityCommand: () => AssumeRoleWithWebIdentityCommand6,
  AssumeRoleWithWebIdentityRequest$: () => AssumeRoleWithWebIdentityRequest$6,
  AssumeRoleWithWebIdentityResponse$: () => AssumeRoleWithWebIdentityResponse$6,
  AssumedRoleUser$: () => AssumedRoleUser$6,
  Credentials$: () => Credentials$7,
  ExpiredTokenException: () => ExpiredTokenException9,
  ExpiredTokenException$: () => ExpiredTokenException$9,
  IDPCommunicationErrorException: () => IDPCommunicationErrorException6,
  IDPCommunicationErrorException$: () => IDPCommunicationErrorException$6,
  IDPRejectedClaimException: () => IDPRejectedClaimException6,
  IDPRejectedClaimException$: () => IDPRejectedClaimException$6,
  InvalidIdentityTokenException: () => InvalidIdentityTokenException6,
  InvalidIdentityTokenException$: () => InvalidIdentityTokenException$6,
  MalformedPolicyDocumentException: () => MalformedPolicyDocumentException6,
  MalformedPolicyDocumentException$: () => MalformedPolicyDocumentException$6,
  PackedPolicyTooLargeException: () => PackedPolicyTooLargeException6,
  PackedPolicyTooLargeException$: () => PackedPolicyTooLargeException$6,
  PolicyDescriptorType$: () => PolicyDescriptorType$6,
  ProvidedContext$: () => ProvidedContext$6,
  RegionDisabledException: () => RegionDisabledException6,
  RegionDisabledException$: () => RegionDisabledException$6,
  STS: () => STS6,
  STSClient: () => STSClient7,
  STSServiceException: () => STSServiceException6,
  STSServiceException$: () => STSServiceException$6,
  Tag$: () => Tag$6,
  __Client: () => Client,
  decorateDefaultCredentialProvider: () => decorateDefaultCredentialProvider6,
  errorTypeRegistries: () => errorTypeRegistries22,
  getDefaultRoleAssumer: () => getDefaultRoleAssumer12,
  getDefaultRoleAssumerWithWebIdentity: () => getDefaultRoleAssumerWithWebIdentity12
});
var init_sts6 = __esm({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/index.js"() {
    init_STSClient6();
    init_STS6();
    init_commands23();
    init_schemas_022();
    init_errors22();
    init_models_022();
    init_defaultRoleAssumers6();
    init_STSServiceException6();
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-process/dist-cjs/index.js
var require_dist_cjs151 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-process/dist-cjs/index.js"(exports2) {
    "use strict";
    var config2 = (init_config4(), __toCommonJS(config_exports));
    var node_child_process = require("node:child_process");
    var node_util = require("node:util");
    var client = (init_client13(), __toCommonJS(client_exports10));
    var getValidatedProcessCredentials = /* @__PURE__ */ __name((profileName, data3, profiles) => {
      if (data3.Version !== 1) {
        throw Error(`Profile ${profileName} credential_process did not return Version 1.`);
      }
      if (data3.AccessKeyId === void 0 || data3.SecretAccessKey === void 0) {
        throw Error(`Profile ${profileName} credential_process returned invalid credentials.`);
      }
      if (data3.Expiration) {
        const currentTime = /* @__PURE__ */ new Date();
        const expireTime = new Date(data3.Expiration);
        if (expireTime < currentTime) {
          throw Error(`Profile ${profileName} credential_process returned expired credentials.`);
        }
      }
      let accountId = data3.AccountId;
      if (!accountId && profiles?.[profileName]?.aws_account_id) {
        accountId = profiles[profileName].aws_account_id;
      }
      const credentials = {
        accessKeyId: data3.AccessKeyId,
        secretAccessKey: data3.SecretAccessKey,
        ...data3.SessionToken && { sessionToken: data3.SessionToken },
        ...data3.Expiration && { expiration: new Date(data3.Expiration) },
        ...data3.CredentialScope && { credentialScope: data3.CredentialScope },
        ...accountId && { accountId }
      };
      client.setCredentialFeature(credentials, "CREDENTIALS_PROCESS", "w");
      return credentials;
    }, "getValidatedProcessCredentials");
    var resolveProcessCredentials = /* @__PURE__ */ __name(async (profileName, profiles, logger5) => {
      const profile = profiles[profileName];
      if (profiles[profileName]) {
        const credentialProcess = profile["credential_process"];
        if (credentialProcess !== void 0) {
          const execPromise = node_util.promisify(config2.externalDataInterceptor?.getTokenRecord?.().exec ?? node_child_process.exec);
          try {
            const { stdout } = await execPromise(credentialProcess);
            let data3;
            try {
              data3 = JSON.parse(stdout.trim());
            } catch {
              throw Error(`Profile ${profileName} credential_process returned invalid JSON.`);
            }
            return getValidatedProcessCredentials(profileName, data3, profiles);
          } catch (error4) {
            throw new config2.CredentialsProviderError(error4.message, { logger: logger5 });
          }
        } else {
          throw new config2.CredentialsProviderError(`Profile ${profileName} did not contain credential_process.`, { logger: logger5 });
        }
      } else {
        throw new config2.CredentialsProviderError(`Profile ${profileName} could not be found in shared credentials file.`, {
          logger: logger5
        });
      }
    }, "resolveProcessCredentials");
    var fromProcess = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/credential-provider-process - fromProcess");
      const profiles = await config2.parseKnownFiles(init);
      return resolveProcessCredentials(config2.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      }), profiles, init.logger);
    }, "fromProcess");
    exports2.fromProcess = fromProcess;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromWebToken.js
var require_fromWebToken7 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromWebToken.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromWebToken = void 0;
    var fromWebToken = /* @__PURE__ */ __name((init) => async (awsIdentityProperties) => {
      init.logger?.debug("@aws-sdk/credential-provider-web-identity - fromWebToken");
      const { roleArn, roleSessionName, webIdentityToken, providerId, policyArns, policy, durationSeconds } = init;
      let { roleAssumerWithWebIdentity } = init;
      if (!roleAssumerWithWebIdentity) {
        const { getDefaultRoleAssumerWithWebIdentity: getDefaultRoleAssumerWithWebIdentity19 } = await Promise.resolve().then(() => (init_sts6(), sts_exports6));
        roleAssumerWithWebIdentity = getDefaultRoleAssumerWithWebIdentity19({
          ...init.clientConfig,
          credentialProviderLogger: init.logger,
          parentClientConfig: {
            ...awsIdentityProperties?.callerClientConfig,
            ...init.parentClientConfig
          }
        }, init.clientPlugins);
      }
      return roleAssumerWithWebIdentity({
        RoleArn: roleArn,
        RoleSessionName: roleSessionName ?? `aws-sdk-js-session-${Date.now()}`,
        WebIdentityToken: webIdentityToken,
        ProviderId: providerId,
        PolicyArns: policyArns,
        Policy: policy,
        DurationSeconds: durationSeconds
      });
    }, "fromWebToken");
    exports2.fromWebToken = fromWebToken;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromTokenFile.js
var require_fromTokenFile7 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromTokenFile.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromTokenFile = void 0;
    var client_1 = (init_client13(), __toCommonJS(client_exports10));
    var config_1 = (init_config4(), __toCommonJS(config_exports));
    var node_fs_1 = require("node:fs");
    var fromWebToken_1 = require_fromWebToken7();
    var ENV_TOKEN_FILE = "AWS_WEB_IDENTITY_TOKEN_FILE";
    var ENV_ROLE_ARN = "AWS_ROLE_ARN";
    var ENV_ROLE_SESSION_NAME = "AWS_ROLE_SESSION_NAME";
    var fromTokenFile = /* @__PURE__ */ __name((init = {}) => async (awsIdentityProperties) => {
      init.logger?.debug("@aws-sdk/credential-provider-web-identity - fromTokenFile");
      const webIdentityTokenFile = init?.webIdentityTokenFile ?? process.env[ENV_TOKEN_FILE];
      const roleArn = init?.roleArn ?? process.env[ENV_ROLE_ARN];
      const roleSessionName = init?.roleSessionName ?? process.env[ENV_ROLE_SESSION_NAME];
      if (!webIdentityTokenFile || !roleArn) {
        throw new config_1.CredentialsProviderError("Web identity configuration not specified", {
          logger: init.logger
        });
      }
      const credentials = await (0, fromWebToken_1.fromWebToken)({
        ...init,
        webIdentityToken: config_1.externalDataInterceptor?.getTokenRecord?.()[webIdentityTokenFile] ?? (0, node_fs_1.readFileSync)(webIdentityTokenFile, { encoding: "ascii" }),
        roleArn,
        roleSessionName
      })(awsIdentityProperties);
      if (webIdentityTokenFile === process.env[ENV_TOKEN_FILE]) {
        (0, client_1.setCredentialFeature)(credentials, "CREDENTIALS_ENV_VARS_STS_WEB_ID_TOKEN", "h");
      }
      return credentials;
    }, "fromTokenFile");
    exports2.fromTokenFile = fromTokenFile;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/index.js
var require_dist_cjs152 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/index.js"(exports2) {
    "use strict";
    var fromTokenFile = require_fromTokenFile7();
    var fromWebToken = require_fromWebToken7();
    Object.prototype.hasOwnProperty.call(fromTokenFile, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: fromTokenFile["__proto__"]
    });
    Object.keys(fromTokenFile).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = fromTokenFile[k32];
    });
    Object.prototype.hasOwnProperty.call(fromWebToken, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: fromWebToken["__proto__"]
    });
    Object.keys(fromWebToken).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = fromWebToken[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-ini/dist-cjs/index.js
var require_dist_cjs153 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-ini/dist-cjs/index.js"(exports2) {
    "use strict";
    var config2 = (init_config4(), __toCommonJS(config_exports));
    var client = (init_client13(), __toCommonJS(client_exports10));
    var credentialProviderLogin = require_dist_cjs149();
    var resolveCredentialSource = /* @__PURE__ */ __name((credentialSource, profileName, logger5) => {
      const sourceProvidersMap = {
        EcsContainer: /* @__PURE__ */ __name(async (options) => {
          const { fromHttp } = await Promise.resolve().then(() => __toESM(require_dist_cjs145()));
          const { fromContainerMetadata } = await Promise.resolve().then(() => __toESM(require_dist_cjs143()));
          logger5?.debug("@aws-sdk/credential-provider-ini - credential_source is EcsContainer");
          return async () => config2.chain(fromHttp(options ?? {}), fromContainerMetadata(options))().then(setNamedProvider);
        }, "EcsContainer"),
        Ec2InstanceMetadata: /* @__PURE__ */ __name(async (options) => {
          logger5?.debug("@aws-sdk/credential-provider-ini - credential_source is Ec2InstanceMetadata");
          const { fromInstanceMetadata } = await Promise.resolve().then(() => __toESM(require_dist_cjs143()));
          return async () => fromInstanceMetadata(options)().then(setNamedProvider);
        }, "Ec2InstanceMetadata"),
        Environment: /* @__PURE__ */ __name(async (options) => {
          logger5?.debug("@aws-sdk/credential-provider-ini - credential_source is Environment");
          const { fromEnv: fromEnv6 } = await Promise.resolve().then(() => __toESM(require_dist_cjs142()));
          return async () => fromEnv6(options)().then(setNamedProvider);
        }, "Environment")
      };
      if (credentialSource in sourceProvidersMap) {
        return sourceProvidersMap[credentialSource];
      } else {
        throw new config2.CredentialsProviderError(`Unsupported credential source in profile ${profileName}. Got ${credentialSource}, expected EcsContainer or Ec2InstanceMetadata or Environment.`, { logger: logger5 });
      }
    }, "resolveCredentialSource");
    var setNamedProvider = /* @__PURE__ */ __name((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_NAMED_PROVIDER", "p"), "setNamedProvider");
    var isAssumeRoleProfile = /* @__PURE__ */ __name((arg, { profile = "default", logger: logger5 } = {}) => {
      return Boolean(arg) && typeof arg === "object" && typeof arg.role_arn === "string" && ["undefined", "string"].indexOf(typeof arg.role_session_name) > -1 && ["undefined", "string"].indexOf(typeof arg.external_id) > -1 && ["undefined", "string"].indexOf(typeof arg.mfa_serial) > -1 && (isAssumeRoleWithSourceProfile(arg, { profile, logger: logger5 }) || isCredentialSourceProfile(arg, { profile, logger: logger5 }));
    }, "isAssumeRoleProfile");
    var isAssumeRoleWithSourceProfile = /* @__PURE__ */ __name((arg, { profile, logger: logger5 }) => {
      const withSourceProfile = typeof arg.source_profile === "string" && typeof arg.credential_source === "undefined";
      if (withSourceProfile) {
        logger5?.debug?.(`    ${profile} isAssumeRoleWithSourceProfile source_profile=${arg.source_profile}`);
      }
      return withSourceProfile;
    }, "isAssumeRoleWithSourceProfile");
    var isCredentialSourceProfile = /* @__PURE__ */ __name((arg, { profile, logger: logger5 }) => {
      const withProviderProfile = typeof arg.credential_source === "string" && typeof arg.source_profile === "undefined";
      if (withProviderProfile) {
        logger5?.debug?.(`    ${profile} isCredentialSourceProfile credential_source=${arg.credential_source}`);
      }
      return withProviderProfile;
    }, "isCredentialSourceProfile");
    var resolveAssumeRoleCredentials = /* @__PURE__ */ __name(async (profileName, profiles, options, callerClientConfig, visitedProfiles = {}, resolveProfileData2) => {
      options.logger?.debug("@aws-sdk/credential-provider-ini - resolveAssumeRoleCredentials (STS)");
      const profileData = profiles[profileName];
      const { source_profile, region } = profileData;
      if (!options.roleAssumer) {
        const { getDefaultRoleAssumer: getDefaultRoleAssumer19 } = await Promise.resolve().then(() => (init_sts6(), sts_exports6));
        options.roleAssumer = getDefaultRoleAssumer19({
          ...options.clientConfig,
          credentialProviderLogger: options.logger,
          parentClientConfig: {
            ...callerClientConfig,
            ...options?.parentClientConfig,
            region: region ?? options?.parentClientConfig?.region ?? callerClientConfig?.region
          }
        }, options.clientPlugins);
      }
      if (source_profile && source_profile in visitedProfiles) {
        throw new config2.CredentialsProviderError(`Detected a cycle attempting to resolve credentials for profile ${config2.getProfileName(options)}. Profiles visited: ` + Object.keys(visitedProfiles).join(", "), { logger: options.logger });
      }
      options.logger?.debug(`@aws-sdk/credential-provider-ini - finding credential resolver using ${source_profile ? `source_profile=[${source_profile}]` : `profile=[${profileName}]`}`);
      const sourceCredsProvider = source_profile ? resolveProfileData2(source_profile, profiles, options, callerClientConfig, {
        ...visitedProfiles,
        [source_profile]: true
      }, isCredentialSourceWithoutRoleArn(profiles[source_profile] ?? {})) : (await resolveCredentialSource(profileData.credential_source, profileName, options.logger)(options))();
      if (isCredentialSourceWithoutRoleArn(profileData)) {
        return sourceCredsProvider.then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SOURCE_PROFILE", "o"));
      } else {
        const params = {
          RoleArn: profileData.role_arn,
          RoleSessionName: profileData.role_session_name || `aws-sdk-js-${Date.now()}`,
          ExternalId: profileData.external_id,
          DurationSeconds: parseInt(profileData.duration_seconds || "3600", 10)
        };
        const { mfa_serial } = profileData;
        if (mfa_serial) {
          if (!options.mfaCodeProvider) {
            throw new config2.CredentialsProviderError(`Profile ${profileName} requires multi-factor authentication, but no MFA code callback was provided.`, { logger: options.logger, tryNextLink: false });
          }
          params.SerialNumber = mfa_serial;
          params.TokenCode = await options.mfaCodeProvider(mfa_serial);
        }
        const sourceCreds = await sourceCredsProvider;
        return options.roleAssumer(sourceCreds, params).then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SOURCE_PROFILE", "o"));
      }
    }, "resolveAssumeRoleCredentials");
    var isCredentialSourceWithoutRoleArn = /* @__PURE__ */ __name((section) => {
      return !section.role_arn && !!section.credential_source;
    }, "isCredentialSourceWithoutRoleArn");
    var isLoginProfile = /* @__PURE__ */ __name((data3) => {
      return Boolean(data3 && data3.login_session);
    }, "isLoginProfile");
    var resolveLoginCredentials = /* @__PURE__ */ __name(async (profileName, options, callerClientConfig) => {
      const credentials = await credentialProviderLogin.fromLoginCredentials({
        ...options,
        profile: profileName
      })({ callerClientConfig });
      return client.setCredentialFeature(credentials, "CREDENTIALS_PROFILE_LOGIN", "AC");
    }, "resolveLoginCredentials");
    var isProcessProfile = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.credential_process === "string", "isProcessProfile");
    var resolveProcessCredentials = /* @__PURE__ */ __name(async (options, profile) => Promise.resolve().then(() => __toESM(require_dist_cjs151())).then(({ fromProcess }) => fromProcess({
      ...options,
      profile
    })().then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_PROCESS", "v"))), "resolveProcessCredentials");
    var resolveSsoCredentials = /* @__PURE__ */ __name(async (profile, profileData, options = {}, callerClientConfig) => {
      const { fromSSO } = await Promise.resolve().then(() => __toESM(require_dist_cjs148()));
      return fromSSO({
        profile,
        logger: options.logger,
        parentClientConfig: options.parentClientConfig,
        clientConfig: options.clientConfig
      })({
        callerClientConfig
      }).then((creds) => {
        if (profileData.sso_session) {
          return client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SSO", "r");
        } else {
          return client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SSO_LEGACY", "t");
        }
      });
    }, "resolveSsoCredentials");
    var isSsoProfile = /* @__PURE__ */ __name((arg) => arg && (typeof arg.sso_start_url === "string" || typeof arg.sso_account_id === "string" || typeof arg.sso_session === "string" || typeof arg.sso_region === "string" || typeof arg.sso_role_name === "string"), "isSsoProfile");
    var isStaticCredsProfile = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.aws_access_key_id === "string" && typeof arg.aws_secret_access_key === "string" && ["undefined", "string"].indexOf(typeof arg.aws_session_token) > -1 && ["undefined", "string"].indexOf(typeof arg.aws_account_id) > -1, "isStaticCredsProfile");
    var resolveStaticCredentials = /* @__PURE__ */ __name(async (profile, options) => {
      options?.logger?.debug("@aws-sdk/credential-provider-ini - resolveStaticCredentials");
      const credentials = {
        accessKeyId: profile.aws_access_key_id,
        secretAccessKey: profile.aws_secret_access_key,
        sessionToken: profile.aws_session_token,
        ...profile.aws_credential_scope && { credentialScope: profile.aws_credential_scope },
        ...profile.aws_account_id && { accountId: profile.aws_account_id }
      };
      return client.setCredentialFeature(credentials, "CREDENTIALS_PROFILE", "n");
    }, "resolveStaticCredentials");
    var isWebIdentityProfile = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.web_identity_token_file === "string" && typeof arg.role_arn === "string" && ["undefined", "string"].indexOf(typeof arg.role_session_name) > -1, "isWebIdentityProfile");
    var resolveWebIdentityCredentials = /* @__PURE__ */ __name(async (profile, options, callerClientConfig) => Promise.resolve().then(() => __toESM(require_dist_cjs152())).then(({ fromTokenFile }) => fromTokenFile({
      webIdentityTokenFile: profile.web_identity_token_file,
      roleArn: profile.role_arn,
      roleSessionName: profile.role_session_name,
      roleAssumerWithWebIdentity: options.roleAssumerWithWebIdentity,
      logger: options.logger,
      parentClientConfig: options.parentClientConfig
    })({
      callerClientConfig
    }).then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_STS_WEB_ID_TOKEN", "q"))), "resolveWebIdentityCredentials");
    var resolveProfileData = /* @__PURE__ */ __name(async (profileName, profiles, options, callerClientConfig, visitedProfiles = {}, isAssumeRoleRecursiveCall = false) => {
      const data3 = profiles[profileName];
      if (Object.keys(visitedProfiles).length > 0 && isStaticCredsProfile(data3)) {
        return resolveStaticCredentials(data3, options);
      }
      if (isAssumeRoleRecursiveCall || isAssumeRoleProfile(data3, { profile: profileName, logger: options.logger })) {
        return resolveAssumeRoleCredentials(profileName, profiles, options, callerClientConfig, visitedProfiles, resolveProfileData);
      }
      if (isStaticCredsProfile(data3)) {
        return resolveStaticCredentials(data3, options);
      }
      if (isWebIdentityProfile(data3)) {
        return resolveWebIdentityCredentials(data3, options, callerClientConfig);
      }
      if (isProcessProfile(data3)) {
        return resolveProcessCredentials(options, profileName);
      }
      if (isSsoProfile(data3)) {
        return await resolveSsoCredentials(profileName, data3, options, callerClientConfig);
      }
      if (isLoginProfile(data3)) {
        return resolveLoginCredentials(profileName, options, callerClientConfig);
      }
      throw new config2.CredentialsProviderError(`Could not resolve credentials using profile: [${profileName}] in configuration/credentials file(s).`, { logger: options.logger });
    }, "resolveProfileData");
    var fromIni2 = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/credential-provider-ini - fromIni");
      const profiles = await config2.parseKnownFiles(init);
      return resolveProfileData(config2.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      }), profiles, init, callerClientConfig);
    }, "fromIni");
    exports2.fromIni = fromIni2;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-node/dist-cjs/index.js
var require_dist_cjs154 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/node_modules/@aws-sdk/credential-provider-node/dist-cjs/index.js"(exports2) {
    "use strict";
    var credentialProviderEnv = require_dist_cjs142();
    var config2 = (init_config4(), __toCommonJS(config_exports));
    var ENV_IMDS_DISABLED3 = "AWS_EC2_METADATA_DISABLED";
    var remoteProvider = /* @__PURE__ */ __name(async (init) => {
      const { ENV_CMDS_FULL_URI, ENV_CMDS_RELATIVE_URI, fromContainerMetadata, fromInstanceMetadata } = await Promise.resolve().then(() => __toESM(require_dist_cjs143()));
      if (process.env[ENV_CMDS_RELATIVE_URI] || process.env[ENV_CMDS_FULL_URI]) {
        init.logger?.debug("@aws-sdk/credential-provider-node - remoteProvider::fromHttp/fromContainerMetadata");
        const { fromHttp } = await Promise.resolve().then(() => __toESM(require_dist_cjs145()));
        return config2.chain(fromHttp(init), fromContainerMetadata(init));
      }
      if (process.env[ENV_IMDS_DISABLED3] && process.env[ENV_IMDS_DISABLED3] !== "false") {
        return async () => {
          throw new config2.CredentialsProviderError("EC2 Instance Metadata Service access disabled", { logger: init.logger });
        };
      }
      init.logger?.debug("@aws-sdk/credential-provider-node - remoteProvider::fromInstanceMetadata");
      return fromInstanceMetadata(init);
    }, "remoteProvider");
    function memoizeChain(providers, treatAsExpired) {
      const chain5 = internalCreateChain(providers);
      let activeLock;
      let passiveLock;
      let credentials;
      const provider = /* @__PURE__ */ __name(async (options) => {
        if (options?.forceRefresh) {
          return await chain5(options);
        }
        if (credentials?.expiration) {
          if (credentials?.expiration?.getTime() < Date.now()) {
            credentials = void 0;
          }
        }
        if (activeLock) {
          await activeLock;
        } else if (!credentials || treatAsExpired?.(credentials)) {
          if (credentials) {
            if (!passiveLock) {
              passiveLock = chain5(options).then((c32) => {
                credentials = c32;
              }).finally(() => {
                passiveLock = void 0;
              });
            }
          } else {
            activeLock = chain5(options).then((c32) => {
              credentials = c32;
            }).finally(() => {
              activeLock = void 0;
            });
            return provider(options);
          }
        }
        return credentials;
      }, "provider");
      return provider;
    }
    __name(memoizeChain, "memoizeChain");
    var internalCreateChain = /* @__PURE__ */ __name((providers) => async (awsIdentityProperties) => {
      let lastProviderError;
      for (const provider of providers) {
        try {
          return await provider(awsIdentityProperties);
        } catch (err) {
          lastProviderError = err;
          if (err?.tryNextLink) {
            continue;
          }
          throw err;
        }
      }
      throw lastProviderError;
    }, "internalCreateChain");
    var multipleCredentialSourceWarningEmitted = false;
    var defaultProvider = /* @__PURE__ */ __name((init = {}) => memoizeChain([
      async () => {
        const profile = init.profile ?? process.env[config2.ENV_PROFILE];
        if (profile) {
          const envStaticCredentialsAreSet = process.env[credentialProviderEnv.ENV_KEY] && process.env[credentialProviderEnv.ENV_SECRET];
          if (envStaticCredentialsAreSet) {
            if (!multipleCredentialSourceWarningEmitted) {
              const warnFn = init.logger?.warn && init.logger?.constructor?.name !== "NoOpLogger" ? init.logger.warn.bind(init.logger) : console.warn;
              warnFn(`@aws-sdk/credential-provider-node - defaultProvider::fromEnv WARNING:
    Multiple credential sources detected: 
    Both AWS_PROFILE and the pair AWS_ACCESS_KEY_ID/AWS_SECRET_ACCESS_KEY static credentials are set.
    This SDK will proceed with the AWS_PROFILE value.
    
    However, a future version may change this behavior to prefer the ENV static credentials.
    Please ensure that your environment only sets either the AWS_PROFILE or the
    AWS_ACCESS_KEY_ID/AWS_SECRET_ACCESS_KEY pair.
`);
              multipleCredentialSourceWarningEmitted = true;
            }
          }
          throw new config2.CredentialsProviderError("AWS_PROFILE is set, skipping fromEnv provider.", {
            logger: init.logger,
            tryNextLink: true
          });
        }
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromEnv");
        return credentialProviderEnv.fromEnv(init)();
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromSSO");
        const { ssoStartUrl, ssoAccountId, ssoRegion, ssoRoleName, ssoSession } = init;
        if (!ssoStartUrl && !ssoAccountId && !ssoRegion && !ssoRoleName && !ssoSession) {
          throw new config2.CredentialsProviderError("Skipping SSO provider in default chain (inputs do not include SSO fields).", { logger: init.logger });
        }
        const { fromSSO } = await Promise.resolve().then(() => __toESM(require_dist_cjs148()));
        return fromSSO(init)(awsIdentityProperties);
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromIni");
        const { fromIni: fromIni2 } = await Promise.resolve().then(() => __toESM(require_dist_cjs153()));
        return fromIni2(init)(awsIdentityProperties);
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromProcess");
        const { fromProcess } = await Promise.resolve().then(() => __toESM(require_dist_cjs151()));
        return fromProcess(init)(awsIdentityProperties);
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromTokenFile");
        const { fromTokenFile } = await Promise.resolve().then(() => __toESM(require_dist_cjs152()));
        return fromTokenFile(init)(awsIdentityProperties);
      },
      async () => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::remoteProvider");
        return (await remoteProvider(init))();
      },
      async () => {
        throw new config2.CredentialsProviderError("Could not load credentials from any providers", {
          tryNextLink: false,
          logger: init.logger
        });
      }
    ], credentialsTreatedAsExpired), "defaultProvider");
    var credentialsWillNeedRefresh = /* @__PURE__ */ __name((credentials) => credentials?.expiration !== void 0, "credentialsWillNeedRefresh");
    var credentialsTreatedAsExpired = /* @__PURE__ */ __name((credentials) => credentials?.expiration !== void 0 && credentials.expiration.getTime() - Date.now() < 3e5, "credentialsTreatedAsExpired");
    exports2.credentialsTreatedAsExpired = credentialsTreatedAsExpired;
    exports2.credentialsWillNeedRefresh = credentialsWillNeedRefresh;
    exports2.defaultProvider = defaultProvider;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/dist-cjs/endpoint/bdd.js
var require_bdd6 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/dist-cjs/endpoint/bdd.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.bdd = void 0;
    var endpoints_1 = (init_endpoints3(), __toCommonJS(endpoints_exports3));
    var k32 = "ref";
    var a32 = -1;
    var b32 = true;
    var c32 = "isSet";
    var d32 = "PartitionResult";
    var e32 = "booleanEquals";
    var f32 = "getAttr";
    var g32 = { [k32]: "Endpoint" };
    var h32 = { [k32]: d32 };
    var i32 = {};
    var j32 = [{ [k32]: "Region" }];
    var _data32 = {
      conditions: [
        [c32, [g32]],
        [c32, j32],
        ["aws.partition", j32, d32],
        [e32, [{ [k32]: "UseFIPS" }, b32]],
        [e32, [{ [k32]: "UseDualStack" }, b32]],
        [e32, [{ fn: f32, argv: [h32, "supportsDualStack"] }, b32]],
        [e32, [{ fn: f32, argv: [h32, "supportsFIPS"] }, b32]]
      ],
      results: [
        [a32],
        [a32, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a32, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [g32, i32],
        ["https://appsync-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", i32],
        [a32, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://appsync-fips.{Region}.{PartitionResult#dnsSuffix}", i32],
        [a32, "FIPS is enabled but this partition does not support FIPS"],
        ["https://appsync.{Region}.{PartitionResult#dualStackDnsSuffix}", i32],
        [a32, "DualStack is enabled but this partition does not support DualStack"],
        ["https://appsync.{Region}.{PartitionResult#dnsSuffix}", i32],
        [a32, "Invalid Configuration: Missing Region"]
      ]
    };
    var root32 = 2;
    var r32 = 1e8;
    var nodes32 = new Int32Array([
      -1,
      1,
      -1,
      0,
      12,
      3,
      1,
      4,
      r32 + 11,
      2,
      5,
      r32 + 11,
      3,
      8,
      6,
      4,
      7,
      r32 + 10,
      5,
      r32 + 8,
      r32 + 9,
      4,
      10,
      9,
      6,
      r32 + 6,
      r32 + 7,
      5,
      11,
      r32 + 5,
      6,
      r32 + 4,
      r32 + 5,
      3,
      r32 + 1,
      13,
      4,
      r32 + 2,
      r32 + 3
    ]);
    exports2.bdd = endpoints_1.BinaryDecisionDiagram.from(nodes32, root32, _data32.conditions, _data32.results);
  }
});

// ../../node_modules/@aws-sdk/client-appsync/dist-cjs/endpoint/endpointResolver.js
var require_endpointResolver6 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/dist-cjs/endpoint/endpointResolver.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.defaultEndpointResolver = void 0;
    var client_1 = (init_client13(), __toCommonJS(client_exports10));
    var endpoints_1 = (init_endpoints3(), __toCommonJS(endpoints_exports3));
    var bdd_1 = require_bdd6();
    var cache32 = new endpoints_1.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    var defaultEndpointResolver32 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache32.get(endpointParams, () => (0, endpoints_1.decideEndpoint)(bdd_1.bdd, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    exports2.defaultEndpointResolver = defaultEndpointResolver32;
    endpoints_1.customEndpointFunctions.aws = client_1.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/dist-cjs/models/AppSyncServiceException.js
var require_AppSyncServiceException = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/dist-cjs/models/AppSyncServiceException.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.AppSyncServiceException = exports2.__ServiceException = void 0;
    var client_1 = (init_client12(), __toCommonJS(client_exports9));
    Object.defineProperty(exports2, "__ServiceException", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return client_1.ServiceException;
    }, "get") });
    var AppSyncServiceException = class _AppSyncServiceException extends client_1.ServiceException {
      static {
        __name(this, "AppSyncServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _AppSyncServiceException.prototype);
      }
    };
    exports2.AppSyncServiceException = AppSyncServiceException;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/dist-cjs/models/errors.js
var require_errors6 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/dist-cjs/models/errors.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.GraphQLSchemaException = exports2.ConflictException = exports2.ServiceQuotaExceededException = exports2.UnauthorizedException = exports2.LimitExceededException = exports2.ConcurrentModificationException = exports2.NotFoundException = exports2.InternalFailureException = exports2.BadRequestException = exports2.ApiLimitExceededException = exports2.ApiKeyValidityOutOfBoundsException = exports2.ApiKeyLimitExceededException = exports2.AccessDeniedException = void 0;
    var AppSyncServiceException_1 = require_AppSyncServiceException();
    var AccessDeniedException13 = class _AccessDeniedException extends AppSyncServiceException_1.AppSyncServiceException {
      static {
        __name(this, "AccessDeniedException");
      }
      name = "AccessDeniedException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "AccessDeniedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AccessDeniedException.prototype);
      }
    };
    exports2.AccessDeniedException = AccessDeniedException13;
    var ApiKeyLimitExceededException = class _ApiKeyLimitExceededException extends AppSyncServiceException_1.AppSyncServiceException {
      static {
        __name(this, "ApiKeyLimitExceededException");
      }
      name = "ApiKeyLimitExceededException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ApiKeyLimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ApiKeyLimitExceededException.prototype);
      }
    };
    exports2.ApiKeyLimitExceededException = ApiKeyLimitExceededException;
    var ApiKeyValidityOutOfBoundsException = class _ApiKeyValidityOutOfBoundsException extends AppSyncServiceException_1.AppSyncServiceException {
      static {
        __name(this, "ApiKeyValidityOutOfBoundsException");
      }
      name = "ApiKeyValidityOutOfBoundsException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ApiKeyValidityOutOfBoundsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ApiKeyValidityOutOfBoundsException.prototype);
      }
    };
    exports2.ApiKeyValidityOutOfBoundsException = ApiKeyValidityOutOfBoundsException;
    var ApiLimitExceededException = class _ApiLimitExceededException extends AppSyncServiceException_1.AppSyncServiceException {
      static {
        __name(this, "ApiLimitExceededException");
      }
      name = "ApiLimitExceededException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ApiLimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ApiLimitExceededException.prototype);
      }
    };
    exports2.ApiLimitExceededException = ApiLimitExceededException;
    var BadRequestException = class _BadRequestException extends AppSyncServiceException_1.AppSyncServiceException {
      static {
        __name(this, "BadRequestException");
      }
      name = "BadRequestException";
      $fault = "client";
      reason;
      detail;
      constructor(opts) {
        super({
          name: "BadRequestException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _BadRequestException.prototype);
        this.reason = opts.reason;
        this.detail = opts.detail;
      }
    };
    exports2.BadRequestException = BadRequestException;
    var InternalFailureException = class _InternalFailureException extends AppSyncServiceException_1.AppSyncServiceException {
      static {
        __name(this, "InternalFailureException");
      }
      name = "InternalFailureException";
      $fault = "server";
      constructor(opts) {
        super({
          name: "InternalFailureException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _InternalFailureException.prototype);
      }
    };
    exports2.InternalFailureException = InternalFailureException;
    var NotFoundException = class _NotFoundException extends AppSyncServiceException_1.AppSyncServiceException {
      static {
        __name(this, "NotFoundException");
      }
      name = "NotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "NotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _NotFoundException.prototype);
      }
    };
    exports2.NotFoundException = NotFoundException;
    var ConcurrentModificationException = class _ConcurrentModificationException extends AppSyncServiceException_1.AppSyncServiceException {
      static {
        __name(this, "ConcurrentModificationException");
      }
      name = "ConcurrentModificationException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ConcurrentModificationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ConcurrentModificationException.prototype);
      }
    };
    exports2.ConcurrentModificationException = ConcurrentModificationException;
    var LimitExceededException2 = class _LimitExceededException extends AppSyncServiceException_1.AppSyncServiceException {
      static {
        __name(this, "LimitExceededException");
      }
      name = "LimitExceededException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "LimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _LimitExceededException.prototype);
      }
    };
    exports2.LimitExceededException = LimitExceededException2;
    var UnauthorizedException10 = class _UnauthorizedException extends AppSyncServiceException_1.AppSyncServiceException {
      static {
        __name(this, "UnauthorizedException");
      }
      name = "UnauthorizedException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "UnauthorizedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnauthorizedException.prototype);
      }
    };
    exports2.UnauthorizedException = UnauthorizedException10;
    var ServiceQuotaExceededException = class _ServiceQuotaExceededException extends AppSyncServiceException_1.AppSyncServiceException {
      static {
        __name(this, "ServiceQuotaExceededException");
      }
      name = "ServiceQuotaExceededException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ServiceQuotaExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ServiceQuotaExceededException.prototype);
      }
    };
    exports2.ServiceQuotaExceededException = ServiceQuotaExceededException;
    var ConflictException = class _ConflictException extends AppSyncServiceException_1.AppSyncServiceException {
      static {
        __name(this, "ConflictException");
      }
      name = "ConflictException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ConflictException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ConflictException.prototype);
      }
    };
    exports2.ConflictException = ConflictException;
    var GraphQLSchemaException = class _GraphQLSchemaException extends AppSyncServiceException_1.AppSyncServiceException {
      static {
        __name(this, "GraphQLSchemaException");
      }
      name = "GraphQLSchemaException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "GraphQLSchemaException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _GraphQLSchemaException.prototype);
      }
    };
    exports2.GraphQLSchemaException = GraphQLSchemaException;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/dist-cjs/schemas/schemas_0.js
var require_schemas_06 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/dist-cjs/schemas/schemas_0.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.CreateDomainNameResponse$ = exports2.CreateDomainNameRequest$ = exports2.CreateDataSourceResponse$ = exports2.CreateDataSourceRequest$ = exports2.CreateChannelNamespaceResponse$ = exports2.CreateChannelNamespaceRequest$ = exports2.CreateApiResponse$ = exports2.CreateApiRequest$ = exports2.CreateApiKeyResponse$ = exports2.CreateApiKeyRequest$ = exports2.CreateApiCacheResponse$ = exports2.CreateApiCacheRequest$ = exports2.CognitoUserPoolConfig$ = exports2.CognitoConfig$ = exports2.CodeErrorLocation$ = exports2.CodeError$ = exports2.ChannelNamespace$ = exports2.CachingConfig$ = exports2.BadRequestDetail$ = exports2.AwsIamConfig$ = exports2.AuthProvider$ = exports2.AuthorizationConfig$ = exports2.AuthMode$ = exports2.AssociateSourceGraphqlApiResponse$ = exports2.AssociateSourceGraphqlApiRequest$ = exports2.AssociateMergedGraphqlApiResponse$ = exports2.AssociateMergedGraphqlApiRequest$ = exports2.AssociateApiResponse$ = exports2.AssociateApiRequest$ = exports2.AppSyncRuntime$ = exports2.ApiKey$ = exports2.ApiCache$ = exports2.ApiAssociation$ = exports2.Api$ = exports2.AdditionalAuthenticationProvider$ = exports2.errorTypeRegistries = exports2.UnauthorizedException$ = exports2.ServiceQuotaExceededException$ = exports2.NotFoundException$ = exports2.LimitExceededException$ = exports2.InternalFailureException$ = exports2.GraphQLSchemaException$ = exports2.ConflictException$ = exports2.ConcurrentModificationException$ = exports2.BadRequestException$ = exports2.ApiLimitExceededException$ = exports2.ApiKeyValidityOutOfBoundsException$ = exports2.ApiKeyLimitExceededException$ = exports2.AccessDeniedException$ = exports2.AppSyncServiceException$ = void 0;
    exports2.EvaluateMappingTemplateRequest$ = exports2.EvaluateCodeResponse$ = exports2.EvaluateCodeRequest$ = exports2.EvaluateCodeErrorDetail$ = exports2.ErrorDetail$ = exports2.EnhancedMetricsConfig$ = exports2.ElasticsearchDataSourceConfig$ = exports2.DynamodbDataSourceConfig$ = exports2.DomainNameConfig$ = exports2.DisassociateSourceGraphqlApiResponse$ = exports2.DisassociateSourceGraphqlApiRequest$ = exports2.DisassociateMergedGraphqlApiResponse$ = exports2.DisassociateMergedGraphqlApiRequest$ = exports2.DisassociateApiResponse$ = exports2.DisassociateApiRequest$ = exports2.DeltaSyncConfig$ = exports2.DeleteTypeResponse$ = exports2.DeleteTypeRequest$ = exports2.DeleteResolverResponse$ = exports2.DeleteResolverRequest$ = exports2.DeleteGraphqlApiResponse$ = exports2.DeleteGraphqlApiRequest$ = exports2.DeleteFunctionResponse$ = exports2.DeleteFunctionRequest$ = exports2.DeleteDomainNameResponse$ = exports2.DeleteDomainNameRequest$ = exports2.DeleteDataSourceResponse$ = exports2.DeleteDataSourceRequest$ = exports2.DeleteChannelNamespaceResponse$ = exports2.DeleteChannelNamespaceRequest$ = exports2.DeleteApiResponse$ = exports2.DeleteApiRequest$ = exports2.DeleteApiKeyResponse$ = exports2.DeleteApiKeyRequest$ = exports2.DeleteApiCacheResponse$ = exports2.DeleteApiCacheRequest$ = exports2.DataSourceIntrospectionResult$ = exports2.DataSourceIntrospectionModelIndex$ = exports2.DataSourceIntrospectionModelFieldType$ = exports2.DataSourceIntrospectionModelField$ = exports2.DataSourceIntrospectionModel$ = exports2.DataSource$ = exports2.CreateTypeResponse$ = exports2.CreateTypeRequest$ = exports2.CreateResolverResponse$ = exports2.CreateResolverRequest$ = exports2.CreateGraphqlApiResponse$ = exports2.CreateGraphqlApiRequest$ = exports2.CreateFunctionResponse$ = exports2.CreateFunctionRequest$ = void 0;
    exports2.ListApisResponse$ = exports2.ListApisRequest$ = exports2.ListApiKeysResponse$ = exports2.ListApiKeysRequest$ = exports2.LambdaDataSourceConfig$ = exports2.LambdaConflictHandlerConfig$ = exports2.LambdaConfig$ = exports2.LambdaAuthorizerConfig$ = exports2.Integration$ = exports2.HttpDataSourceConfig$ = exports2.HandlerConfigs$ = exports2.HandlerConfig$ = exports2.GraphqlApi$ = exports2.GetTypeResponse$ = exports2.GetTypeRequest$ = exports2.GetSourceApiAssociationResponse$ = exports2.GetSourceApiAssociationRequest$ = exports2.GetSchemaCreationStatusResponse$ = exports2.GetSchemaCreationStatusRequest$ = exports2.GetResolverResponse$ = exports2.GetResolverRequest$ = exports2.GetIntrospectionSchemaResponse$ = exports2.GetIntrospectionSchemaRequest$ = exports2.GetGraphqlApiResponse$ = exports2.GetGraphqlApiRequest$ = exports2.GetGraphqlApiEnvironmentVariablesResponse$ = exports2.GetGraphqlApiEnvironmentVariablesRequest$ = exports2.GetFunctionResponse$ = exports2.GetFunctionRequest$ = exports2.GetDomainNameResponse$ = exports2.GetDomainNameRequest$ = exports2.GetDataSourceResponse$ = exports2.GetDataSourceRequest$ = exports2.GetDataSourceIntrospectionResponse$ = exports2.GetDataSourceIntrospectionRequest$ = exports2.GetChannelNamespaceResponse$ = exports2.GetChannelNamespaceRequest$ = exports2.GetApiResponse$ = exports2.GetApiRequest$ = exports2.GetApiCacheResponse$ = exports2.GetApiCacheRequest$ = exports2.GetApiAssociationResponse$ = exports2.GetApiAssociationRequest$ = exports2.FunctionConfiguration$ = exports2.FlushApiCacheResponse$ = exports2.FlushApiCacheRequest$ = exports2.EventLogConfig$ = exports2.EventConfig$ = exports2.EventBridgeDataSourceConfig$ = exports2.EvaluateMappingTemplateResponse$ = void 0;
    exports2.UpdateApiKeyRequest$ = exports2.UpdateApiCacheResponse$ = exports2.UpdateApiCacheRequest$ = exports2.UntagResourceResponse$ = exports2.UntagResourceRequest$ = exports2.Type$ = exports2.TagResourceResponse$ = exports2.TagResourceRequest$ = exports2.SyncConfig$ = exports2.StartSchemaMergeResponse$ = exports2.StartSchemaMergeRequest$ = exports2.StartSchemaCreationResponse$ = exports2.StartSchemaCreationRequest$ = exports2.StartDataSourceIntrospectionResponse$ = exports2.StartDataSourceIntrospectionRequest$ = exports2.SourceApiAssociationSummary$ = exports2.SourceApiAssociationConfig$ = exports2.SourceApiAssociation$ = exports2.Resolver$ = exports2.RelationalDatabaseDataSourceConfig$ = exports2.RdsHttpEndpointConfig$ = exports2.RdsDataApiConfig$ = exports2.PutGraphqlApiEnvironmentVariablesResponse$ = exports2.PutGraphqlApiEnvironmentVariablesRequest$ = exports2.PipelineConfig$ = exports2.OpenSearchServiceDataSourceConfig$ = exports2.OpenIDConnectConfig$ = exports2.LogConfig$ = exports2.ListTypesResponse$ = exports2.ListTypesRequest$ = exports2.ListTypesByAssociationResponse$ = exports2.ListTypesByAssociationRequest$ = exports2.ListTagsForResourceResponse$ = exports2.ListTagsForResourceRequest$ = exports2.ListSourceApiAssociationsResponse$ = exports2.ListSourceApiAssociationsRequest$ = exports2.ListResolversResponse$ = exports2.ListResolversRequest$ = exports2.ListResolversByFunctionResponse$ = exports2.ListResolversByFunctionRequest$ = exports2.ListGraphqlApisResponse$ = exports2.ListGraphqlApisRequest$ = exports2.ListFunctionsResponse$ = exports2.ListFunctionsRequest$ = exports2.ListDomainNamesResponse$ = exports2.ListDomainNamesRequest$ = exports2.ListDataSourcesResponse$ = exports2.ListDataSourcesRequest$ = exports2.ListChannelNamespacesResponse$ = exports2.ListChannelNamespacesRequest$ = void 0;
    exports2.GetApi$ = exports2.FlushApiCache$ = exports2.EvaluateMappingTemplate$ = exports2.EvaluateCode$ = exports2.DisassociateSourceGraphqlApi$ = exports2.DisassociateMergedGraphqlApi$ = exports2.DisassociateApi$ = exports2.DeleteType$ = exports2.DeleteResolver$ = exports2.DeleteGraphqlApi$ = exports2.DeleteFunction$ = exports2.DeleteDomainName$ = exports2.DeleteDataSource$ = exports2.DeleteChannelNamespace$ = exports2.DeleteApiKey$ = exports2.DeleteApiCache$ = exports2.DeleteApi$ = exports2.CreateType$ = exports2.CreateResolver$ = exports2.CreateGraphqlApi$ = exports2.CreateFunction$ = exports2.CreateDomainName$ = exports2.CreateDataSource$ = exports2.CreateChannelNamespace$ = exports2.CreateApiKey$ = exports2.CreateApiCache$ = exports2.CreateApi$ = exports2.AssociateSourceGraphqlApi$ = exports2.AssociateMergedGraphqlApi$ = exports2.AssociateApi$ = exports2.UserPoolConfig$ = exports2.UpdateTypeResponse$ = exports2.UpdateTypeRequest$ = exports2.UpdateSourceApiAssociationResponse$ = exports2.UpdateSourceApiAssociationRequest$ = exports2.UpdateResolverResponse$ = exports2.UpdateResolverRequest$ = exports2.UpdateGraphqlApiResponse$ = exports2.UpdateGraphqlApiRequest$ = exports2.UpdateFunctionResponse$ = exports2.UpdateFunctionRequest$ = exports2.UpdateDomainNameResponse$ = exports2.UpdateDomainNameRequest$ = exports2.UpdateDataSourceResponse$ = exports2.UpdateDataSourceRequest$ = exports2.UpdateChannelNamespaceResponse$ = exports2.UpdateChannelNamespaceRequest$ = exports2.UpdateApiResponse$ = exports2.UpdateApiRequest$ = exports2.UpdateApiKeyResponse$ = void 0;
    exports2.UpdateType$ = exports2.UpdateSourceApiAssociation$ = exports2.UpdateResolver$ = exports2.UpdateGraphqlApi$ = exports2.UpdateFunction$ = exports2.UpdateDomainName$ = exports2.UpdateDataSource$ = exports2.UpdateChannelNamespace$ = exports2.UpdateApiKey$ = exports2.UpdateApiCache$ = exports2.UpdateApi$ = exports2.UntagResource$ = exports2.TagResource$ = exports2.StartSchemaMerge$ = exports2.StartSchemaCreation$ = exports2.StartDataSourceIntrospection$ = exports2.PutGraphqlApiEnvironmentVariables$ = exports2.ListTypesByAssociation$ = exports2.ListTypes$ = exports2.ListTagsForResource$ = exports2.ListSourceApiAssociations$ = exports2.ListResolversByFunction$ = exports2.ListResolvers$ = exports2.ListGraphqlApis$ = exports2.ListFunctions$ = exports2.ListDomainNames$ = exports2.ListDataSources$ = exports2.ListChannelNamespaces$ = exports2.ListApis$ = exports2.ListApiKeys$ = exports2.GetType$ = exports2.GetSourceApiAssociation$ = exports2.GetSchemaCreationStatus$ = exports2.GetResolver$ = exports2.GetIntrospectionSchema$ = exports2.GetGraphqlApiEnvironmentVariables$ = exports2.GetGraphqlApi$ = exports2.GetFunction$ = exports2.GetDomainName$ = exports2.GetDataSourceIntrospection$ = exports2.GetDataSource$ = exports2.GetChannelNamespace$ = exports2.GetApiCache$ = exports2.GetApiAssociation$ = void 0;
    var _A10 = "Api";
    var _AA = "ApiAssociation";
    var _AAP = "AdditionalAuthenticationProvider";
    var _AAPd = "AdditionalAuthenticationProviders";
    var _AAR = "AssociateApiRequest";
    var _AARs = "AssociateApiResponse";
    var _AAs = "AssociateApi";
    var _AC = "ApiCache";
    var _ACu = "AuthorizationConfig";
    var _ADE13 = "AccessDeniedException";
    var _AIC = "AwsIamConfig";
    var _AK = "ApiKey";
    var _AKLEE = "ApiKeyLimitExceededException";
    var _AKVOOBE = "ApiKeyValidityOutOfBoundsException";
    var _AKp = "ApiKeys";
    var _ALEE = "ApiLimitExceededException";
    var _AM = "AuthMode";
    var _AMGA = "AssociateMergedGraphqlApi";
    var _AMGAR = "AssociateMergedGraphqlApiRequest";
    var _AMGARs = "AssociateMergedGraphqlApiResponse";
    var _AMu = "AuthModes";
    var _AP = "AuthProvider";
    var _APu = "AuthProviders";
    var _ASGA = "AssociateSourceGraphqlApi";
    var _ASGAR = "AssociateSourceGraphqlApiRequest";
    var _ASGARs = "AssociateSourceGraphqlApiResponse";
    var _ASR = "AppSyncRuntime";
    var _Ap = "Apis";
    var _BRD = "BadRequestDetail";
    var _BRE = "BadRequestException";
    var _CA10 = "CreateApi";
    var _CAC = "CreateApiCache";
    var _CACR = "CreateApiCacheRequest";
    var _CACRr = "CreateApiCacheResponse";
    var _CAK = "CreateApiKey";
    var _CAKR = "CreateApiKeyRequest";
    var _CAKRr = "CreateApiKeyResponse";
    var _CAR = "CreateApiRequest";
    var _CARr = "CreateApiResponse";
    var _CC = "CachingConfig";
    var _CCN = "CreateChannelNamespace";
    var _CCNR = "CreateChannelNamespaceRequest";
    var _CCNRr = "CreateChannelNamespaceResponse";
    var _CCo = "CognitoConfig";
    var _CDN = "CreateDomainName";
    var _CDNR = "CreateDomainNameRequest";
    var _CDNRr = "CreateDomainNameResponse";
    var _CDS = "CreateDataSource";
    var _CDSR = "CreateDataSourceRequest";
    var _CDSRr = "CreateDataSourceResponse";
    var _CE = "ConflictException";
    var _CEL = "CodeErrorLocation";
    var _CEo = "CodeError";
    var _CEod = "CodeErrors";
    var _CF = "CreateFunction";
    var _CFR = "CreateFunctionRequest";
    var _CFRr = "CreateFunctionResponse";
    var _CGA = "CreateGraphqlApi";
    var _CGAR = "CreateGraphqlApiRequest";
    var _CGARr = "CreateGraphqlApiResponse";
    var _CME = "ConcurrentModificationException";
    var _CN = "ChannelNamespace";
    var _CNh = "ChannelNamespaces";
    var _CR = "CreateResolver";
    var _CRR = "CreateResolverRequest";
    var _CRRr = "CreateResolverResponse";
    var _CT4 = "CreateType";
    var _CTR4 = "CreateTypeRequest";
    var _CTRr4 = "CreateTypeResponse";
    var _CUPC = "CognitoUserPoolConfig";
    var _DA = "DeleteApi";
    var _DAC = "DeleteApiCache";
    var _DACR = "DeleteApiCacheRequest";
    var _DACRe = "DeleteApiCacheResponse";
    var _DAK = "DeleteApiKey";
    var _DAKR = "DeleteApiKeyRequest";
    var _DAKRe = "DeleteApiKeyResponse";
    var _DAR = "DeleteApiRequest";
    var _DARe = "DeleteApiResponse";
    var _DARi = "DisassociateApiRequest";
    var _DARis = "DisassociateApiResponse";
    var _DAi = "DisassociateApi";
    var _DCN = "DeleteChannelNamespace";
    var _DCNR = "DeleteChannelNamespaceRequest";
    var _DCNRe = "DeleteChannelNamespaceResponse";
    var _DDN = "DeleteDomainName";
    var _DDNR = "DeleteDomainNameRequest";
    var _DDNRe = "DeleteDomainNameResponse";
    var _DDS = "DeleteDataSource";
    var _DDSC = "DynamodbDataSourceConfig";
    var _DDSR = "DeleteDataSourceRequest";
    var _DDSRe = "DeleteDataSourceResponse";
    var _DF = "DeleteFunction";
    var _DFR = "DeleteFunctionRequest";
    var _DFRe = "DeleteFunctionResponse";
    var _DGA = "DeleteGraphqlApi";
    var _DGAR = "DeleteGraphqlApiRequest";
    var _DGARe = "DeleteGraphqlApiResponse";
    var _DMGA = "DisassociateMergedGraphqlApi";
    var _DMGAR = "DisassociateMergedGraphqlApiRequest";
    var _DMGARi = "DisassociateMergedGraphqlApiResponse";
    var _DNC = "DomainNameConfig";
    var _DNCo = "DomainNameConfigs";
    var _DR = "DeleteResolver";
    var _DRR = "DeleteResolverRequest";
    var _DRRe = "DeleteResolverResponse";
    var _DS10 = "DataSource";
    var _DSC = "DeltaSyncConfig";
    var _DSGA = "DisassociateSourceGraphqlApi";
    var _DSGAR = "DisassociateSourceGraphqlApiRequest";
    var _DSGARi = "DisassociateSourceGraphqlApiResponse";
    var _DSIM = "DataSourceIntrospectionModel";
    var _DSIMF = "DataSourceIntrospectionModelField";
    var _DSIMFT = "DataSourceIntrospectionModelFieldType";
    var _DSIMFa = "DataSourceIntrospectionModelFields";
    var _DSIMI = "DataSourceIntrospectionModelIndex";
    var _DSIMIa = "DataSourceIntrospectionModelIndexes";
    var _DSIMa = "DataSourceIntrospectionModels";
    var _DSIR = "DataSourceIntrospectionResult";
    var _DSa = "DataSources";
    var _DT = "DeleteType";
    var _DTR = "DeleteTypeRequest";
    var _DTRe = "DeleteTypeResponse";
    var _EBDSC = "EventBridgeDataSourceConfig";
    var _EC = "EventConfig";
    var _ECED = "EvaluateCodeErrorDetail";
    var _ECR = "EvaluateCodeRequest";
    var _ECRv = "EvaluateCodeResponse";
    var _ECv = "EvaluateCode";
    var _ED = "ErrorDetail";
    var _EDSC = "ElasticsearchDataSourceConfig";
    var _ELC = "EventLogConfig";
    var _EMC = "EnhancedMetricsConfig";
    var _EMT = "EvaluateMappingTemplate";
    var _EMTR = "EvaluateMappingTemplateRequest";
    var _EMTRv = "EvaluateMappingTemplateResponse";
    var _F = "Functions";
    var _FAC = "FlushApiCache";
    var _FACR = "FlushApiCacheRequest";
    var _FACRl = "FlushApiCacheResponse";
    var _FC = "FunctionConfiguration";
    var _GA = "GraphqlApi";
    var _GAA = "GetApiAssociation";
    var _GAAR = "GetApiAssociationRequest";
    var _GAARe = "GetApiAssociationResponse";
    var _GAC = "GetApiCache";
    var _GACR = "GetApiCacheRequest";
    var _GACRe = "GetApiCacheResponse";
    var _GAR = "GetApiRequest";
    var _GARe = "GetApiResponse";
    var _GAe = "GetApi";
    var _GAr = "GraphqlApis";
    var _GCN = "GetChannelNamespace";
    var _GCNR = "GetChannelNamespaceRequest";
    var _GCNRe = "GetChannelNamespaceResponse";
    var _GDN = "GetDomainName";
    var _GDNR = "GetDomainNameRequest";
    var _GDNRe = "GetDomainNameResponse";
    var _GDS = "GetDataSource";
    var _GDSI = "GetDataSourceIntrospection";
    var _GDSIR = "GetDataSourceIntrospectionRequest";
    var _GDSIRe = "GetDataSourceIntrospectionResponse";
    var _GDSR = "GetDataSourceRequest";
    var _GDSRe = "GetDataSourceResponse";
    var _GF = "GetFunction";
    var _GFR = "GetFunctionRequest";
    var _GFRe = "GetFunctionResponse";
    var _GGA = "GetGraphqlApi";
    var _GGAEV = "GetGraphqlApiEnvironmentVariables";
    var _GGAEVR = "GetGraphqlApiEnvironmentVariablesRequest";
    var _GGAEVRe = "GetGraphqlApiEnvironmentVariablesResponse";
    var _GGAR = "GetGraphqlApiRequest";
    var _GGARe = "GetGraphqlApiResponse";
    var _GIS = "GetIntrospectionSchema";
    var _GISR = "GetIntrospectionSchemaRequest";
    var _GISRe = "GetIntrospectionSchemaResponse";
    var _GQLSE = "GraphQLSchemaException";
    var _GR = "GetResolver";
    var _GRR = "GetResolverRequest";
    var _GRRe = "GetResolverResponse";
    var _GSAA = "GetSourceApiAssociation";
    var _GSAAR = "GetSourceApiAssociationRequest";
    var _GSAARe = "GetSourceApiAssociationResponse";
    var _GSCS = "GetSchemaCreationStatus";
    var _GSCSR = "GetSchemaCreationStatusRequest";
    var _GSCSRe = "GetSchemaCreationStatusResponse";
    var _GT = "GetType";
    var _GTR = "GetTypeRequest";
    var _GTRe = "GetTypeResponse";
    var _HC = "HandlerConfig";
    var _HCa = "HandlerConfigs";
    var _HDSC = "HttpDataSourceConfig";
    var _I = "Integration";
    var _IFE = "InternalFailureException";
    var _LA = "ListApis";
    var _LAC = "LambdaAuthorizerConfig";
    var _LAK = "ListApiKeys";
    var _LAKR = "ListApiKeysRequest";
    var _LAKRi = "ListApiKeysResponse";
    var _LAR = "ListApisRequest";
    var _LARi = "ListApisResponse";
    var _LC = "LambdaConfig";
    var _LCHC = "LambdaConflictHandlerConfig";
    var _LCN = "ListChannelNamespaces";
    var _LCNR = "ListChannelNamespacesRequest";
    var _LCNRi = "ListChannelNamespacesResponse";
    var _LCo = "LogConfig";
    var _LDN = "ListDomainNames";
    var _LDNR = "ListDomainNamesRequest";
    var _LDNRi = "ListDomainNamesResponse";
    var _LDS = "ListDataSources";
    var _LDSC = "LambdaDataSourceConfig";
    var _LDSR = "ListDataSourcesRequest";
    var _LDSRi = "ListDataSourcesResponse";
    var _LEE2 = "LimitExceededException";
    var _LF = "ListFunctions";
    var _LFR = "ListFunctionsRequest";
    var _LFRi = "ListFunctionsResponse";
    var _LGA = "ListGraphqlApis";
    var _LGAR = "ListGraphqlApisRequest";
    var _LGARi = "ListGraphqlApisResponse";
    var _LR = "ListResolvers";
    var _LRBF = "ListResolversByFunction";
    var _LRBFR = "ListResolversByFunctionRequest";
    var _LRBFRi = "ListResolversByFunctionResponse";
    var _LRR = "ListResolversRequest";
    var _LRRi = "ListResolversResponse";
    var _LSAA = "ListSourceApiAssociations";
    var _LSAAR = "ListSourceApiAssociationsRequest";
    var _LSAARi = "ListSourceApiAssociationsResponse";
    var _LT = "ListTypes";
    var _LTBA = "ListTypesByAssociation";
    var _LTBAR = "ListTypesByAssociationRequest";
    var _LTBARi = "ListTypesByAssociationResponse";
    var _LTFR = "ListTagsForResource";
    var _LTFRR = "ListTagsForResourceRequest";
    var _LTFRRi = "ListTagsForResourceResponse";
    var _LTR = "ListTypesRequest";
    var _LTRi = "ListTypesResponse";
    var _NFE = "NotFoundException";
    var _OIDCC = "OpenIDConnectConfig";
    var _OSSDSC = "OpenSearchServiceDataSourceConfig";
    var _PC10 = "PipelineConfig";
    var _PGAEV = "PutGraphqlApiEnvironmentVariables";
    var _PGAEVR = "PutGraphqlApiEnvironmentVariablesRequest";
    var _PGAEVRu = "PutGraphqlApiEnvironmentVariablesResponse";
    var _R = "Resolver";
    var _RDAC = "RdsDataApiConfig";
    var _RDDSC = "RelationalDatabaseDataSourceConfig";
    var _RHEC = "RdsHttpEndpointConfig";
    var _Re = "Resolvers";
    var _SAA = "SourceApiAssociation";
    var _SAAC = "SourceApiAssociationConfig";
    var _SAAS = "SourceApiAssociationSummary";
    var _SAASL = "SourceApiAssociationSummaryList";
    var _SC = "SyncConfig";
    var _SDSI = "StartDataSourceIntrospection";
    var _SDSIR = "StartDataSourceIntrospectionRequest";
    var _SDSIRt = "StartDataSourceIntrospectionResponse";
    var _SQEE = "ServiceQuotaExceededException";
    var _SSC = "StartSchemaCreation";
    var _SSCR = "StartSchemaCreationRequest";
    var _SSCRt = "StartSchemaCreationResponse";
    var _SSM = "StartSchemaMerge";
    var _SSMR = "StartSchemaMergeRequest";
    var _SSMRt = "StartSchemaMergeResponse";
    var _T10 = "Type";
    var _TL = "TypeList";
    var _TR = "TagResource";
    var _TRR = "TagResourceRequest";
    var _TRRa = "TagResourceResponse";
    var _UA = "UpdateApi";
    var _UAC = "UpdateApiCache";
    var _UACR = "UpdateApiCacheRequest";
    var _UACRp = "UpdateApiCacheResponse";
    var _UAK = "UpdateApiKey";
    var _UAKR = "UpdateApiKeyRequest";
    var _UAKRp = "UpdateApiKeyResponse";
    var _UAR = "UpdateApiRequest";
    var _UARp = "UpdateApiResponse";
    var _UCN = "UpdateChannelNamespace";
    var _UCNR = "UpdateChannelNamespaceRequest";
    var _UCNRp = "UpdateChannelNamespaceResponse";
    var _UDN = "UpdateDomainName";
    var _UDNR = "UpdateDomainNameRequest";
    var _UDNRp = "UpdateDomainNameResponse";
    var _UDS = "UpdateDataSource";
    var _UDSR = "UpdateDataSourceRequest";
    var _UDSRp = "UpdateDataSourceResponse";
    var _UE10 = "UnauthorizedException";
    var _UF = "UpdateFunction";
    var _UFR = "UpdateFunctionRequest";
    var _UFRp = "UpdateFunctionResponse";
    var _UGA = "UpdateGraphqlApi";
    var _UGAR = "UpdateGraphqlApiRequest";
    var _UGARp = "UpdateGraphqlApiResponse";
    var _UPC = "UserPoolConfig";
    var _UR = "UntagResource";
    var _URR = "UntagResourceRequest";
    var _URRn = "UntagResourceResponse";
    var _URRp = "UpdateResolverRequest";
    var _URRpd = "UpdateResolverResponse";
    var _URp = "UpdateResolver";
    var _USAA = "UpdateSourceApiAssociation";
    var _USAAR = "UpdateSourceApiAssociationRequest";
    var _USAARp = "UpdateSourceApiAssociationResponse";
    var _UT = "UpdateType";
    var _UTR = "UpdateTypeRequest";
    var _UTRp = "UpdateTypeResponse";
    var _a10 = "api";
    var _aA = "apiArn";
    var _aAP = "additionalAuthenticationProviders";
    var _aAp = "apiAssociation";
    var _aAs = "associationArn";
    var _aC = "apiCache";
    var _aCB = "apiCachingBehavior";
    var _aCu = "authorizationConfig";
    var _aDN = "appsyncDomainName";
    var _aI10 = "apiId";
    var _aIC = "awsIamConfig";
    var _aICR = "appIdClientRegex";
    var _aIs = "associationId";
    var _aK = "apiKey";
    var _aKp = "apiKeys";
    var _aP = "authProviders";
    var _aR = "awsRegion";
    var _aREE = "atRestEncryptionEnabled";
    var _aRTIS = "authorizerResultTtlInSeconds";
    var _aS = "associationStatus";
    var _aSSA = "awsSecretStoreArn";
    var _aT22 = "authenticationType";
    var _aTTL = "authTTL";
    var _aTp = "apiType";
    var _aTu = "authType";
    var _aTut = "authorizationType";
    var _aU = "authorizerUri";
    var _ap = "apis";
    var _ar = "arn";
    var _b = "behavior";
    var _bTTTL = "baseTableTTL";
    var _c32 = "client";
    var _cA = "certificateArn";
    var _cAM = "connectionAuthModes";
    var _cC = "cognitoConfig";
    var _cCa = "cachingConfig";
    var _cD = "conflictDetection";
    var _cE = "codeErrors";
    var _cH = "codeHandlers";
    var _cHo = "conflictHandler";
    var _cI13 = "clientId";
    var _cK = "cachingKeys";
    var _cN = "channelNamespace";
    var _cNA = "channelNamespaceArn";
    var _cNh = "channelNamespaces";
    var _cWLRA = "cloudWatchLogsRoleArn";
    var _co13 = "column";
    var _cod = "code";
    var _con = "context";
    var _cr = "created";
    var _d = "detail";
    var _dA = "defaultAction";
    var _dC4 = "dynamodbConfig";
    var _dCI = "dbClusterIdentifier";
    var _dD = "deploymentDetail";
    var _dN = "domainName";
    var _dNA = "domainNameArn";
    var _dNC = "domainNameConfig";
    var _dNCo = "domainNameConfigs";
    var _dNa = "databaseName";
    var _dPAM = "defaultPublishAuthModes";
    var _dS = "dataSource";
    var _dSA = "dataSourceArn";
    var _dSAM = "defaultSubscribeAuthModes";
    var _dSC = "deltaSyncConfig";
    var _dSLMB = "dataSourceLevelMetricsBehavior";
    var _dSN = "dataSourceName";
    var _dSTN = "deltaSyncTableName";
    var _dSTTTL = "deltaSyncTableTTL";
    var _dSa = "dataSources";
    var _de = "description";
    var _def = "definition";
    var _del = "deletes";
    var _det = "details";
    var _dn = "dns";
    var _e32 = "error";
    var _eBA = "eventBusArn";
    var _eBC = "eventBridgeConfig";
    var _eC = "eventConfig";
    var _eCl = "elasticsearchConfig";
    var _eMC = "enhancedMetricsConfig";
    var _eR = "evaluationResult";
    var _eT = "errorType";
    var _eV = "environmentVariables";
    var _eVC = "excludeVerboseContent";
    var _en = "endpoint";
    var _ex10 = "expires";
    var _f = "format";
    var _fA = "functionArn";
    var _fC = "functionConfiguration";
    var _fI = "functionId";
    var _fLL = "fieldLogLevel";
    var _fN = "fieldName";
    var _fV = "functionVersion";
    var _fi = "fields";
    var _fu = "function";
    var _fun = "functions";
    var _gA = "graphqlApi";
    var _gAr = "graphqlApis";
    var _h22 = "http";
    var _hC = "handlerConfigs";
    var _hCt = "httpConfig";
    var _hE32 = "httpError";
    var _hMC = "healthMetricsConfig";
    var _hQ10 = "httpQuery";
    var _hZI = "hostedZoneId";
    var _i = "id";
    var _iC = "introspectionConfig";
    var _iD = "includeDirectives";
    var _iI = "introspectionId";
    var _iMSDL = "includeModelsSDL";
    var _iR = "introspectionResult";
    var _iS = "introspectionStatus";
    var _iSD = "introspectionStatusDetail";
    var _iT13 = "invokeType";
    var _iTTL = "iatTTL";
    var _iVE = "identityValidationExpression";
    var _in = "indexes";
    var _int = "integration";
    var _is = "issuer";
    var _k = "kind";
    var _l = "location";
    var _lAC = "lambdaAuthorizerConfig";
    var _lC = "lambdaConfig";
    var _lCHA = "lambdaConflictHandlerArn";
    var _lCHC = "lambdaConflictHandlerConfig";
    var _lCo = "logConfig";
    var _lFA = "lambdaFunctionArn";
    var _lL = "logLevel";
    var _lM = "lastModified";
    var _lSMD = "lastSuccessfulMergeDate";
    var _le = "length";
    var _li = "line";
    var _lo = "logs";
    var _m29 = "message";
    var _mAA = "mergedApiArn";
    var _mAERA = "mergedApiExecutionRoleArn";
    var _mAI = "mergedApiIdentifier";
    var _mAIe = "mergedApiId";
    var _mBS = "maxBatchSize";
    var _mC = "metricsConfig";
    var _mR = "maxResults";
    var _mT = "mergeType";
    var _mo = "models";
    var _n = "name";
    var _nT = "nextToken";
    var _o = "owner";
    var _oC = "ownerContact";
    var _oE = "outErrors";
    var _oIDCC = "openIDConnectConfig";
    var _oLMC = "operationLevelMetricsConfig";
    var _oP = "onPublish";
    var _oS = "onSubscribe";
    var _oSSC = "openSearchServiceConfig";
    var _pAM = "publishAuthModes";
    var _pC = "pipelineConfig";
    var _pK = "primaryKey";
    var _qDL = "queryDepthLimit";
    var _r4 = "reason";
    var _rA = "resourceArn";
    var _rAe = "resolverArn";
    var _rCL = "resolverCountLimit";
    var _rDAC = "rdsDataApiConfig";
    var _rDC = "relationalDatabaseConfig";
    var _rDST = "relationalDatabaseSourceType";
    var _rHEC = "rdsHttpEndpointConfig";
    var _rLMB = "resolverLevelMetricsBehavior";
    var _rMT = "requestMappingTemplate";
    var _rMTe = "responseMappingTemplate";
    var _rV = "runtimeVersion";
    var _re = "resolver";
    var _res = "resolvers";
    var _ru = "runtime";
    var _s32 = "smithy.ts.sdk.synthetic.com.amazonaws.appsync";
    var _sA = "secretArn";
    var _sAA = "sourceApiAssociation";
    var _sAAC = "sourceApiAssociationConfig";
    var _sAAS = "sourceApiAssociationStatus";
    var _sAASD = "sourceApiAssociationStatusDetail";
    var _sAASo = "sourceApiAssociationSummaries";
    var _sAAo = "sourceApiArn";
    var _sAI = "sourceApiIdentifier";
    var _sAIo = "sourceApiId";
    var _sAM = "subscribeAuthModes";
    var _sC = "syncConfig";
    var _sR = "signingRegion";
    var _sRA = "serviceRoleArn";
    var _sSN = "signingServiceName";
    var _sc4 = "schema";
    var _sd = "sdl";
    var _se14 = "server";
    var _sp = "span";
    var _st = "status";
    var _sta = "stash";
    var _t = "tags";
    var _tEE = "transitEncryptionEnabled";
    var _tK = "tagKeys";
    var _tN = "typeName";
    var _tNa = "tableName";
    var _te = "template";
    var _tt = "ttl";
    var _ty = "type";
    var _typ = "types";
    var _u = "uris";
    var _uCC = "useCallerCredentials";
    var _uPC = "userPoolConfig";
    var _uPI = "userPoolId";
    var _v = "value";
    var _va = "values";
    var _ve = "versioned";
    var _vi = "visibility";
    var _wWAA = "wafWebAclArn";
    var _xE = "xrayEnabled";
    var n032 = "com.amazonaws.appsync";
    var schema_1 = (init_schema6(), __toCommonJS(schema_exports2));
    var AppSyncServiceException_1 = require_AppSyncServiceException();
    var errors_1 = require_errors6();
    var _s_registry32 = schema_1.TypeRegistry.for(_s32);
    exports2.AppSyncServiceException$ = [-3, _s32, "AppSyncServiceException", 0, [], []];
    _s_registry32.registerError(exports2.AppSyncServiceException$, AppSyncServiceException_1.AppSyncServiceException);
    var n0_registry32 = schema_1.TypeRegistry.for(n032);
    exports2.AccessDeniedException$ = [
      -3,
      n032,
      _ADE13,
      { [_e32]: _c32, [_hE32]: 403 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.AccessDeniedException$, errors_1.AccessDeniedException);
    exports2.ApiKeyLimitExceededException$ = [
      -3,
      n032,
      _AKLEE,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ApiKeyLimitExceededException$, errors_1.ApiKeyLimitExceededException);
    exports2.ApiKeyValidityOutOfBoundsException$ = [
      -3,
      n032,
      _AKVOOBE,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ApiKeyValidityOutOfBoundsException$, errors_1.ApiKeyValidityOutOfBoundsException);
    exports2.ApiLimitExceededException$ = [
      -3,
      n032,
      _ALEE,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ApiLimitExceededException$, errors_1.ApiLimitExceededException);
    exports2.BadRequestException$ = [
      -3,
      n032,
      _BRE,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29, _r4, _d],
      [0, 0, () => exports2.BadRequestDetail$]
    ];
    n0_registry32.registerError(exports2.BadRequestException$, errors_1.BadRequestException);
    exports2.ConcurrentModificationException$ = [
      -3,
      n032,
      _CME,
      { [_e32]: _c32, [_hE32]: 409 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ConcurrentModificationException$, errors_1.ConcurrentModificationException);
    exports2.ConflictException$ = [
      -3,
      n032,
      _CE,
      { [_e32]: _c32, [_hE32]: 409 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ConflictException$, errors_1.ConflictException);
    exports2.GraphQLSchemaException$ = [
      -3,
      n032,
      _GQLSE,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.GraphQLSchemaException$, errors_1.GraphQLSchemaException);
    exports2.InternalFailureException$ = [
      -3,
      n032,
      _IFE,
      { [_e32]: _se14, [_hE32]: 500 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InternalFailureException$, errors_1.InternalFailureException);
    exports2.LimitExceededException$ = [
      -3,
      n032,
      _LEE2,
      { [_e32]: _c32, [_hE32]: 429 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.LimitExceededException$, errors_1.LimitExceededException);
    exports2.NotFoundException$ = [
      -3,
      n032,
      _NFE,
      { [_e32]: _c32, [_hE32]: 404 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.NotFoundException$, errors_1.NotFoundException);
    exports2.ServiceQuotaExceededException$ = [
      -3,
      n032,
      _SQEE,
      { [_e32]: _c32, [_hE32]: 402 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ServiceQuotaExceededException$, errors_1.ServiceQuotaExceededException);
    exports2.UnauthorizedException$ = [
      -3,
      n032,
      _UE10,
      { [_e32]: _c32, [_hE32]: 401 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.UnauthorizedException$, errors_1.UnauthorizedException);
    exports2.errorTypeRegistries = [
      _s_registry32,
      n0_registry32
    ];
    exports2.AdditionalAuthenticationProvider$ = [
      3,
      n032,
      _AAP,
      0,
      [_aT22, _oIDCC, _uPC, _lAC],
      [0, () => exports2.OpenIDConnectConfig$, () => exports2.CognitoUserPoolConfig$, () => exports2.LambdaAuthorizerConfig$]
    ];
    exports2.Api$ = [
      3,
      n032,
      _A10,
      0,
      [_aI10, _n, _oC, _t, _dn, _aA, _cr, _xE, _wWAA, _eC],
      [0, 0, 0, 128 | 0, 128 | 0, 0, 4, 2, 0, () => exports2.EventConfig$]
    ];
    exports2.ApiAssociation$ = [
      3,
      n032,
      _AA,
      0,
      [_dN, _aI10, _aS, _dD],
      [0, 0, 0, 0]
    ];
    exports2.ApiCache$ = [
      3,
      n032,
      _AC,
      0,
      [_tt, _aCB, _tEE, _aREE, _ty, _st, _hMC],
      [1, 0, 2, 2, 0, 0, 0]
    ];
    exports2.ApiKey$ = [
      3,
      n032,
      _AK,
      0,
      [_i, _de, _ex10, _del],
      [0, 0, 1, 1]
    ];
    exports2.AppSyncRuntime$ = [
      3,
      n032,
      _ASR,
      0,
      [_n, _rV],
      [0, 0],
      2
    ];
    exports2.AssociateApiRequest$ = [
      3,
      n032,
      _AAR,
      0,
      [_dN, _aI10],
      [[0, 1], 0],
      2
    ];
    exports2.AssociateApiResponse$ = [
      3,
      n032,
      _AARs,
      0,
      [_aAp],
      [() => exports2.ApiAssociation$]
    ];
    exports2.AssociateMergedGraphqlApiRequest$ = [
      3,
      n032,
      _AMGAR,
      0,
      [_sAI, _mAI, _de, _sAAC],
      [[0, 1], 0, 0, () => exports2.SourceApiAssociationConfig$],
      2
    ];
    exports2.AssociateMergedGraphqlApiResponse$ = [
      3,
      n032,
      _AMGARs,
      0,
      [_sAA],
      [() => exports2.SourceApiAssociation$]
    ];
    exports2.AssociateSourceGraphqlApiRequest$ = [
      3,
      n032,
      _ASGAR,
      0,
      [_mAI, _sAI, _de, _sAAC],
      [[0, 1], 0, 0, () => exports2.SourceApiAssociationConfig$],
      2
    ];
    exports2.AssociateSourceGraphqlApiResponse$ = [
      3,
      n032,
      _ASGARs,
      0,
      [_sAA],
      [() => exports2.SourceApiAssociation$]
    ];
    exports2.AuthMode$ = [
      3,
      n032,
      _AM,
      0,
      [_aTu],
      [0],
      1
    ];
    exports2.AuthorizationConfig$ = [
      3,
      n032,
      _ACu,
      0,
      [_aTut, _aIC],
      [0, () => exports2.AwsIamConfig$],
      1
    ];
    exports2.AuthProvider$ = [
      3,
      n032,
      _AP,
      0,
      [_aTu, _cC, _oIDCC, _lAC],
      [0, () => exports2.CognitoConfig$, () => exports2.OpenIDConnectConfig$, () => exports2.LambdaAuthorizerConfig$],
      1
    ];
    exports2.AwsIamConfig$ = [
      3,
      n032,
      _AIC,
      0,
      [_sR, _sSN],
      [0, 0]
    ];
    exports2.BadRequestDetail$ = [
      3,
      n032,
      _BRD,
      0,
      [_cE],
      [() => CodeErrors]
    ];
    exports2.CachingConfig$ = [
      3,
      n032,
      _CC,
      0,
      [_tt, _cK],
      [1, 64 | 0],
      1
    ];
    exports2.ChannelNamespace$ = [
      3,
      n032,
      _CN,
      0,
      [_aI10, _n, _sAM, _pAM, _cH, _t, _cNA, _cr, _lM, _hC],
      [0, 0, () => AuthModes, () => AuthModes, 0, 128 | 0, 0, 4, 4, () => exports2.HandlerConfigs$]
    ];
    exports2.CodeError$ = [
      3,
      n032,
      _CEo,
      0,
      [_eT, _v, _l],
      [0, 0, () => exports2.CodeErrorLocation$]
    ];
    exports2.CodeErrorLocation$ = [
      3,
      n032,
      _CEL,
      0,
      [_li, _co13, _sp],
      [1, 1, 1]
    ];
    exports2.CognitoConfig$ = [
      3,
      n032,
      _CCo,
      0,
      [_uPI, _aR, _aICR],
      [0, 0, 0],
      2
    ];
    exports2.CognitoUserPoolConfig$ = [
      3,
      n032,
      _CUPC,
      0,
      [_uPI, _aR, _aICR],
      [0, 0, 0],
      2
    ];
    exports2.CreateApiCacheRequest$ = [
      3,
      n032,
      _CACR,
      0,
      [_aI10, _tt, _aCB, _ty, _tEE, _aREE, _hMC],
      [[0, 1], 1, 0, 0, 2, 2, 0],
      4
    ];
    exports2.CreateApiCacheResponse$ = [
      3,
      n032,
      _CACRr,
      0,
      [_aC],
      [() => exports2.ApiCache$]
    ];
    exports2.CreateApiKeyRequest$ = [
      3,
      n032,
      _CAKR,
      0,
      [_aI10, _de, _ex10],
      [[0, 1], 0, 1],
      1
    ];
    exports2.CreateApiKeyResponse$ = [
      3,
      n032,
      _CAKRr,
      0,
      [_aK],
      [() => exports2.ApiKey$]
    ];
    exports2.CreateApiRequest$ = [
      3,
      n032,
      _CAR,
      0,
      [_n, _eC, _oC, _t],
      [0, () => exports2.EventConfig$, 0, 128 | 0],
      2
    ];
    exports2.CreateApiResponse$ = [
      3,
      n032,
      _CARr,
      0,
      [_a10],
      [() => exports2.Api$]
    ];
    exports2.CreateChannelNamespaceRequest$ = [
      3,
      n032,
      _CCNR,
      0,
      [_aI10, _n, _sAM, _pAM, _cH, _t, _hC],
      [[0, 1], 0, () => AuthModes, () => AuthModes, 0, 128 | 0, () => exports2.HandlerConfigs$],
      2
    ];
    exports2.CreateChannelNamespaceResponse$ = [
      3,
      n032,
      _CCNRr,
      0,
      [_cN],
      [() => exports2.ChannelNamespace$]
    ];
    exports2.CreateDataSourceRequest$ = [
      3,
      n032,
      _CDSR,
      0,
      [_aI10, _n, _ty, _de, _sRA, _dC4, _lC, _eCl, _oSSC, _hCt, _rDC, _eBC, _mC],
      [[0, 1], 0, 0, 0, 0, () => exports2.DynamodbDataSourceConfig$, () => exports2.LambdaDataSourceConfig$, () => exports2.ElasticsearchDataSourceConfig$, () => exports2.OpenSearchServiceDataSourceConfig$, () => exports2.HttpDataSourceConfig$, () => exports2.RelationalDatabaseDataSourceConfig$, () => exports2.EventBridgeDataSourceConfig$, 0],
      3
    ];
    exports2.CreateDataSourceResponse$ = [
      3,
      n032,
      _CDSRr,
      0,
      [_dS],
      [() => exports2.DataSource$]
    ];
    exports2.CreateDomainNameRequest$ = [
      3,
      n032,
      _CDNR,
      0,
      [_dN, _cA, _de, _t],
      [0, 0, 0, 128 | 0],
      2
    ];
    exports2.CreateDomainNameResponse$ = [
      3,
      n032,
      _CDNRr,
      0,
      [_dNC],
      [() => exports2.DomainNameConfig$]
    ];
    exports2.CreateFunctionRequest$ = [
      3,
      n032,
      _CFR,
      0,
      [_aI10, _n, _dSN, _de, _rMT, _rMTe, _fV, _sC, _mBS, _ru, _cod],
      [[0, 1], 0, 0, 0, 0, 0, 0, () => exports2.SyncConfig$, 1, () => exports2.AppSyncRuntime$, 0],
      3
    ];
    exports2.CreateFunctionResponse$ = [
      3,
      n032,
      _CFRr,
      0,
      [_fC],
      [() => exports2.FunctionConfiguration$]
    ];
    exports2.CreateGraphqlApiRequest$ = [
      3,
      n032,
      _CGAR,
      0,
      [_n, _aT22, _lCo, _uPC, _oIDCC, _t, _aAP, _xE, _lAC, _aTp, _mAERA, _vi, _oC, _iC, _qDL, _rCL, _eMC],
      [0, 0, () => exports2.LogConfig$, () => exports2.UserPoolConfig$, () => exports2.OpenIDConnectConfig$, 128 | 0, () => AdditionalAuthenticationProviders, 2, () => exports2.LambdaAuthorizerConfig$, 0, 0, 0, 0, 0, 1, 1, () => exports2.EnhancedMetricsConfig$],
      2
    ];
    exports2.CreateGraphqlApiResponse$ = [
      3,
      n032,
      _CGARr,
      0,
      [_gA],
      [() => exports2.GraphqlApi$]
    ];
    exports2.CreateResolverRequest$ = [
      3,
      n032,
      _CRR,
      0,
      [_aI10, _tN, _fN, _dSN, _rMT, _rMTe, _k, _pC, _sC, _cCa, _mBS, _ru, _cod, _mC],
      [[0, 1], [0, 1], 0, 0, 0, 0, 0, () => exports2.PipelineConfig$, () => exports2.SyncConfig$, () => exports2.CachingConfig$, 1, () => exports2.AppSyncRuntime$, 0, 0],
      3
    ];
    exports2.CreateResolverResponse$ = [
      3,
      n032,
      _CRRr,
      0,
      [_re],
      [() => exports2.Resolver$]
    ];
    exports2.CreateTypeRequest$ = [
      3,
      n032,
      _CTR4,
      0,
      [_aI10, _def, _f],
      [[0, 1], 0, 0],
      3
    ];
    exports2.CreateTypeResponse$ = [
      3,
      n032,
      _CTRr4,
      0,
      [_ty],
      [() => exports2.Type$]
    ];
    exports2.DataSource$ = [
      3,
      n032,
      _DS10,
      0,
      [_dSA, _n, _de, _ty, _sRA, _dC4, _lC, _eCl, _oSSC, _hCt, _rDC, _eBC, _mC],
      [0, 0, 0, 0, 0, () => exports2.DynamodbDataSourceConfig$, () => exports2.LambdaDataSourceConfig$, () => exports2.ElasticsearchDataSourceConfig$, () => exports2.OpenSearchServiceDataSourceConfig$, () => exports2.HttpDataSourceConfig$, () => exports2.RelationalDatabaseDataSourceConfig$, () => exports2.EventBridgeDataSourceConfig$, 0]
    ];
    exports2.DataSourceIntrospectionModel$ = [
      3,
      n032,
      _DSIM,
      0,
      [_n, _fi, _pK, _in, _sd],
      [0, () => DataSourceIntrospectionModelFields, () => exports2.DataSourceIntrospectionModelIndex$, () => DataSourceIntrospectionModelIndexes, 0]
    ];
    exports2.DataSourceIntrospectionModelField$ = [
      3,
      n032,
      _DSIMF,
      0,
      [_n, _ty, _le],
      [0, () => exports2.DataSourceIntrospectionModelFieldType$, 1]
    ];
    exports2.DataSourceIntrospectionModelFieldType$ = [
      3,
      n032,
      _DSIMFT,
      0,
      [_k, _n, _ty, _va],
      [0, 0, () => exports2.DataSourceIntrospectionModelFieldType$, 64 | 0]
    ];
    exports2.DataSourceIntrospectionModelIndex$ = [
      3,
      n032,
      _DSIMI,
      0,
      [_n, _fi],
      [0, 64 | 0]
    ];
    exports2.DataSourceIntrospectionResult$ = [
      3,
      n032,
      _DSIR,
      0,
      [_mo, _nT],
      [() => DataSourceIntrospectionModels, 0]
    ];
    exports2.DeleteApiCacheRequest$ = [
      3,
      n032,
      _DACR,
      0,
      [_aI10],
      [[0, 1]],
      1
    ];
    exports2.DeleteApiCacheResponse$ = [
      3,
      n032,
      _DACRe,
      0,
      [],
      []
    ];
    exports2.DeleteApiKeyRequest$ = [
      3,
      n032,
      _DAKR,
      0,
      [_aI10, _i],
      [[0, 1], [0, 1]],
      2
    ];
    exports2.DeleteApiKeyResponse$ = [
      3,
      n032,
      _DAKRe,
      0,
      [],
      []
    ];
    exports2.DeleteApiRequest$ = [
      3,
      n032,
      _DAR,
      0,
      [_aI10],
      [[0, 1]],
      1
    ];
    exports2.DeleteApiResponse$ = [
      3,
      n032,
      _DARe,
      0,
      [],
      []
    ];
    exports2.DeleteChannelNamespaceRequest$ = [
      3,
      n032,
      _DCNR,
      0,
      [_aI10, _n],
      [[0, 1], [0, 1]],
      2
    ];
    exports2.DeleteChannelNamespaceResponse$ = [
      3,
      n032,
      _DCNRe,
      0,
      [],
      []
    ];
    exports2.DeleteDataSourceRequest$ = [
      3,
      n032,
      _DDSR,
      0,
      [_aI10, _n],
      [[0, 1], [0, 1]],
      2
    ];
    exports2.DeleteDataSourceResponse$ = [
      3,
      n032,
      _DDSRe,
      0,
      [],
      []
    ];
    exports2.DeleteDomainNameRequest$ = [
      3,
      n032,
      _DDNR,
      0,
      [_dN],
      [[0, 1]],
      1
    ];
    exports2.DeleteDomainNameResponse$ = [
      3,
      n032,
      _DDNRe,
      0,
      [],
      []
    ];
    exports2.DeleteFunctionRequest$ = [
      3,
      n032,
      _DFR,
      0,
      [_aI10, _fI],
      [[0, 1], [0, 1]],
      2
    ];
    exports2.DeleteFunctionResponse$ = [
      3,
      n032,
      _DFRe,
      0,
      [],
      []
    ];
    exports2.DeleteGraphqlApiRequest$ = [
      3,
      n032,
      _DGAR,
      0,
      [_aI10],
      [[0, 1]],
      1
    ];
    exports2.DeleteGraphqlApiResponse$ = [
      3,
      n032,
      _DGARe,
      0,
      [],
      []
    ];
    exports2.DeleteResolverRequest$ = [
      3,
      n032,
      _DRR,
      0,
      [_aI10, _tN, _fN],
      [[0, 1], [0, 1], [0, 1]],
      3
    ];
    exports2.DeleteResolverResponse$ = [
      3,
      n032,
      _DRRe,
      0,
      [],
      []
    ];
    exports2.DeleteTypeRequest$ = [
      3,
      n032,
      _DTR,
      0,
      [_aI10, _tN],
      [[0, 1], [0, 1]],
      2
    ];
    exports2.DeleteTypeResponse$ = [
      3,
      n032,
      _DTRe,
      0,
      [],
      []
    ];
    exports2.DeltaSyncConfig$ = [
      3,
      n032,
      _DSC,
      0,
      [_bTTTL, _dSTN, _dSTTTL],
      [1, 0, 1]
    ];
    exports2.DisassociateApiRequest$ = [
      3,
      n032,
      _DARi,
      0,
      [_dN],
      [[0, 1]],
      1
    ];
    exports2.DisassociateApiResponse$ = [
      3,
      n032,
      _DARis,
      0,
      [],
      []
    ];
    exports2.DisassociateMergedGraphqlApiRequest$ = [
      3,
      n032,
      _DMGAR,
      0,
      [_sAI, _aIs],
      [[0, 1], [0, 1]],
      2
    ];
    exports2.DisassociateMergedGraphqlApiResponse$ = [
      3,
      n032,
      _DMGARi,
      0,
      [_sAAS],
      [0]
    ];
    exports2.DisassociateSourceGraphqlApiRequest$ = [
      3,
      n032,
      _DSGAR,
      0,
      [_mAI, _aIs],
      [[0, 1], [0, 1]],
      2
    ];
    exports2.DisassociateSourceGraphqlApiResponse$ = [
      3,
      n032,
      _DSGARi,
      0,
      [_sAAS],
      [0]
    ];
    exports2.DomainNameConfig$ = [
      3,
      n032,
      _DNC,
      0,
      [_dN, _de, _cA, _aDN, _hZI, _t, _dNA],
      [0, 0, 0, 0, 0, 128 | 0, 0]
    ];
    exports2.DynamodbDataSourceConfig$ = [
      3,
      n032,
      _DDSC,
      0,
      [_tNa, _aR, _uCC, _dSC, _ve],
      [0, 0, 2, () => exports2.DeltaSyncConfig$, 2],
      2
    ];
    exports2.ElasticsearchDataSourceConfig$ = [
      3,
      n032,
      _EDSC,
      0,
      [_en, _aR],
      [0, 0],
      2
    ];
    exports2.EnhancedMetricsConfig$ = [
      3,
      n032,
      _EMC,
      0,
      [_rLMB, _dSLMB, _oLMC],
      [0, 0, 0],
      3
    ];
    exports2.ErrorDetail$ = [
      3,
      n032,
      _ED,
      0,
      [_m29],
      [0]
    ];
    exports2.EvaluateCodeErrorDetail$ = [
      3,
      n032,
      _ECED,
      0,
      [_m29, _cE],
      [0, () => CodeErrors]
    ];
    exports2.EvaluateCodeRequest$ = [
      3,
      n032,
      _ECR,
      0,
      [_ru, _cod, _con, _fu],
      [() => exports2.AppSyncRuntime$, 0, 0, 0],
      3
    ];
    exports2.EvaluateCodeResponse$ = [
      3,
      n032,
      _ECRv,
      0,
      [_eR, _e32, _lo, _sta, _oE],
      [0, () => exports2.EvaluateCodeErrorDetail$, 64 | 0, 0, 0]
    ];
    exports2.EvaluateMappingTemplateRequest$ = [
      3,
      n032,
      _EMTR,
      0,
      [_te, _con],
      [0, 0],
      2
    ];
    exports2.EvaluateMappingTemplateResponse$ = [
      3,
      n032,
      _EMTRv,
      0,
      [_eR, _e32, _lo, _sta, _oE],
      [0, () => exports2.ErrorDetail$, 64 | 0, 0, 0]
    ];
    exports2.EventBridgeDataSourceConfig$ = [
      3,
      n032,
      _EBDSC,
      0,
      [_eBA],
      [0],
      1
    ];
    exports2.EventConfig$ = [
      3,
      n032,
      _EC,
      0,
      [_aP, _cAM, _dPAM, _dSAM, _lCo],
      [() => AuthProviders, () => AuthModes, () => AuthModes, () => AuthModes, () => exports2.EventLogConfig$],
      4
    ];
    exports2.EventLogConfig$ = [
      3,
      n032,
      _ELC,
      0,
      [_lL, _cWLRA],
      [0, 0],
      2
    ];
    exports2.FlushApiCacheRequest$ = [
      3,
      n032,
      _FACR,
      0,
      [_aI10],
      [[0, 1]],
      1
    ];
    exports2.FlushApiCacheResponse$ = [
      3,
      n032,
      _FACRl,
      0,
      [],
      []
    ];
    exports2.FunctionConfiguration$ = [
      3,
      n032,
      _FC,
      0,
      [_fI, _fA, _n, _de, _dSN, _rMT, _rMTe, _fV, _sC, _mBS, _ru, _cod],
      [0, 0, 0, 0, 0, 0, 0, 0, () => exports2.SyncConfig$, 1, () => exports2.AppSyncRuntime$, 0]
    ];
    exports2.GetApiAssociationRequest$ = [
      3,
      n032,
      _GAAR,
      0,
      [_dN],
      [[0, 1]],
      1
    ];
    exports2.GetApiAssociationResponse$ = [
      3,
      n032,
      _GAARe,
      0,
      [_aAp],
      [() => exports2.ApiAssociation$]
    ];
    exports2.GetApiCacheRequest$ = [
      3,
      n032,
      _GACR,
      0,
      [_aI10],
      [[0, 1]],
      1
    ];
    exports2.GetApiCacheResponse$ = [
      3,
      n032,
      _GACRe,
      0,
      [_aC],
      [() => exports2.ApiCache$]
    ];
    exports2.GetApiRequest$ = [
      3,
      n032,
      _GAR,
      0,
      [_aI10],
      [[0, 1]],
      1
    ];
    exports2.GetApiResponse$ = [
      3,
      n032,
      _GARe,
      0,
      [_a10],
      [() => exports2.Api$]
    ];
    exports2.GetChannelNamespaceRequest$ = [
      3,
      n032,
      _GCNR,
      0,
      [_aI10, _n],
      [[0, 1], [0, 1]],
      2
    ];
    exports2.GetChannelNamespaceResponse$ = [
      3,
      n032,
      _GCNRe,
      0,
      [_cN],
      [() => exports2.ChannelNamespace$]
    ];
    exports2.GetDataSourceIntrospectionRequest$ = [
      3,
      n032,
      _GDSIR,
      0,
      [_iI, _iMSDL, _nT, _mR],
      [[0, 1], [2, { [_hQ10]: _iMSDL }], [0, { [_hQ10]: _nT }], [1, { [_hQ10]: _mR }]],
      1
    ];
    exports2.GetDataSourceIntrospectionResponse$ = [
      3,
      n032,
      _GDSIRe,
      0,
      [_iI, _iS, _iSD, _iR],
      [0, 0, 0, () => exports2.DataSourceIntrospectionResult$]
    ];
    exports2.GetDataSourceRequest$ = [
      3,
      n032,
      _GDSR,
      0,
      [_aI10, _n],
      [[0, 1], [0, 1]],
      2
    ];
    exports2.GetDataSourceResponse$ = [
      3,
      n032,
      _GDSRe,
      0,
      [_dS],
      [() => exports2.DataSource$]
    ];
    exports2.GetDomainNameRequest$ = [
      3,
      n032,
      _GDNR,
      0,
      [_dN],
      [[0, 1]],
      1
    ];
    exports2.GetDomainNameResponse$ = [
      3,
      n032,
      _GDNRe,
      0,
      [_dNC],
      [() => exports2.DomainNameConfig$]
    ];
    exports2.GetFunctionRequest$ = [
      3,
      n032,
      _GFR,
      0,
      [_aI10, _fI],
      [[0, 1], [0, 1]],
      2
    ];
    exports2.GetFunctionResponse$ = [
      3,
      n032,
      _GFRe,
      0,
      [_fC],
      [() => exports2.FunctionConfiguration$]
    ];
    exports2.GetGraphqlApiEnvironmentVariablesRequest$ = [
      3,
      n032,
      _GGAEVR,
      0,
      [_aI10],
      [[0, 1]],
      1
    ];
    exports2.GetGraphqlApiEnvironmentVariablesResponse$ = [
      3,
      n032,
      _GGAEVRe,
      0,
      [_eV],
      [128 | 0]
    ];
    exports2.GetGraphqlApiRequest$ = [
      3,
      n032,
      _GGAR,
      0,
      [_aI10],
      [[0, 1]],
      1
    ];
    exports2.GetGraphqlApiResponse$ = [
      3,
      n032,
      _GGARe,
      0,
      [_gA],
      [() => exports2.GraphqlApi$]
    ];
    exports2.GetIntrospectionSchemaRequest$ = [
      3,
      n032,
      _GISR,
      0,
      [_aI10, _f, _iD],
      [[0, 1], [0, { [_hQ10]: _f }], [2, { [_hQ10]: _iD }]],
      2
    ];
    exports2.GetIntrospectionSchemaResponse$ = [
      3,
      n032,
      _GISRe,
      0,
      [_sc4],
      [[21, 16]]
    ];
    exports2.GetResolverRequest$ = [
      3,
      n032,
      _GRR,
      0,
      [_aI10, _tN, _fN],
      [[0, 1], [0, 1], [0, 1]],
      3
    ];
    exports2.GetResolverResponse$ = [
      3,
      n032,
      _GRRe,
      0,
      [_re],
      [() => exports2.Resolver$]
    ];
    exports2.GetSchemaCreationStatusRequest$ = [
      3,
      n032,
      _GSCSR,
      0,
      [_aI10],
      [[0, 1]],
      1
    ];
    exports2.GetSchemaCreationStatusResponse$ = [
      3,
      n032,
      _GSCSRe,
      0,
      [_st, _det],
      [0, 0]
    ];
    exports2.GetSourceApiAssociationRequest$ = [
      3,
      n032,
      _GSAAR,
      0,
      [_mAI, _aIs],
      [[0, 1], [0, 1]],
      2
    ];
    exports2.GetSourceApiAssociationResponse$ = [
      3,
      n032,
      _GSAARe,
      0,
      [_sAA],
      [() => exports2.SourceApiAssociation$]
    ];
    exports2.GetTypeRequest$ = [
      3,
      n032,
      _GTR,
      0,
      [_aI10, _tN, _f],
      [[0, 1], [0, 1], [0, { [_hQ10]: _f }]],
      3
    ];
    exports2.GetTypeResponse$ = [
      3,
      n032,
      _GTRe,
      0,
      [_ty],
      [() => exports2.Type$]
    ];
    exports2.GraphqlApi$ = [
      3,
      n032,
      _GA,
      0,
      [_n, _aI10, _aT22, _lCo, _uPC, _oIDCC, _ar, _u, _t, _aAP, _xE, _wWAA, _lAC, _dn, _vi, _aTp, _mAERA, _o, _oC, _iC, _qDL, _rCL, _eMC],
      [0, 0, 0, () => exports2.LogConfig$, () => exports2.UserPoolConfig$, () => exports2.OpenIDConnectConfig$, 0, 128 | 0, 128 | 0, () => AdditionalAuthenticationProviders, 2, 0, () => exports2.LambdaAuthorizerConfig$, 128 | 0, 0, 0, 0, 0, 0, 0, 1, 1, () => exports2.EnhancedMetricsConfig$]
    ];
    exports2.HandlerConfig$ = [
      3,
      n032,
      _HC,
      0,
      [_b, _int],
      [0, () => exports2.Integration$],
      2
    ];
    exports2.HandlerConfigs$ = [
      3,
      n032,
      _HCa,
      0,
      [_oP, _oS],
      [() => exports2.HandlerConfig$, () => exports2.HandlerConfig$]
    ];
    exports2.HttpDataSourceConfig$ = [
      3,
      n032,
      _HDSC,
      0,
      [_en, _aCu],
      [0, () => exports2.AuthorizationConfig$]
    ];
    exports2.Integration$ = [
      3,
      n032,
      _I,
      0,
      [_dSN, _lC],
      [0, () => exports2.LambdaConfig$],
      1
    ];
    exports2.LambdaAuthorizerConfig$ = [
      3,
      n032,
      _LAC,
      0,
      [_aU, _aRTIS, _iVE],
      [0, 1, 0],
      1
    ];
    exports2.LambdaConfig$ = [
      3,
      n032,
      _LC,
      0,
      [_iT13],
      [0]
    ];
    exports2.LambdaConflictHandlerConfig$ = [
      3,
      n032,
      _LCHC,
      0,
      [_lCHA],
      [0]
    ];
    exports2.LambdaDataSourceConfig$ = [
      3,
      n032,
      _LDSC,
      0,
      [_lFA],
      [0],
      1
    ];
    exports2.ListApiKeysRequest$ = [
      3,
      n032,
      _LAKR,
      0,
      [_aI10, _nT, _mR],
      [[0, 1], [0, { [_hQ10]: _nT }], [1, { [_hQ10]: _mR }]],
      1
    ];
    exports2.ListApiKeysResponse$ = [
      3,
      n032,
      _LAKRi,
      0,
      [_aKp, _nT],
      [() => ApiKeys, 0]
    ];
    exports2.ListApisRequest$ = [
      3,
      n032,
      _LAR,
      0,
      [_nT, _mR],
      [[0, { [_hQ10]: _nT }], [1, { [_hQ10]: _mR }]]
    ];
    exports2.ListApisResponse$ = [
      3,
      n032,
      _LARi,
      0,
      [_ap, _nT],
      [() => Apis, 0]
    ];
    exports2.ListChannelNamespacesRequest$ = [
      3,
      n032,
      _LCNR,
      0,
      [_aI10, _nT, _mR],
      [[0, 1], [0, { [_hQ10]: _nT }], [1, { [_hQ10]: _mR }]],
      1
    ];
    exports2.ListChannelNamespacesResponse$ = [
      3,
      n032,
      _LCNRi,
      0,
      [_cNh, _nT],
      [() => ChannelNamespaces, 0]
    ];
    exports2.ListDataSourcesRequest$ = [
      3,
      n032,
      _LDSR,
      0,
      [_aI10, _nT, _mR],
      [[0, 1], [0, { [_hQ10]: _nT }], [1, { [_hQ10]: _mR }]],
      1
    ];
    exports2.ListDataSourcesResponse$ = [
      3,
      n032,
      _LDSRi,
      0,
      [_dSa, _nT],
      [() => DataSources, 0]
    ];
    exports2.ListDomainNamesRequest$ = [
      3,
      n032,
      _LDNR,
      0,
      [_nT, _mR],
      [[0, { [_hQ10]: _nT }], [1, { [_hQ10]: _mR }]]
    ];
    exports2.ListDomainNamesResponse$ = [
      3,
      n032,
      _LDNRi,
      0,
      [_dNCo, _nT],
      [() => DomainNameConfigs, 0]
    ];
    exports2.ListFunctionsRequest$ = [
      3,
      n032,
      _LFR,
      0,
      [_aI10, _nT, _mR],
      [[0, 1], [0, { [_hQ10]: _nT }], [1, { [_hQ10]: _mR }]],
      1
    ];
    exports2.ListFunctionsResponse$ = [
      3,
      n032,
      _LFRi,
      0,
      [_fun, _nT],
      [() => Functions, 0]
    ];
    exports2.ListGraphqlApisRequest$ = [
      3,
      n032,
      _LGAR,
      0,
      [_nT, _mR, _aTp, _o],
      [[0, { [_hQ10]: _nT }], [1, { [_hQ10]: _mR }], [0, { [_hQ10]: _aTp }], [0, { [_hQ10]: _o }]]
    ];
    exports2.ListGraphqlApisResponse$ = [
      3,
      n032,
      _LGARi,
      0,
      [_gAr, _nT],
      [() => GraphqlApis, 0]
    ];
    exports2.ListResolversByFunctionRequest$ = [
      3,
      n032,
      _LRBFR,
      0,
      [_aI10, _fI, _nT, _mR],
      [[0, 1], [0, 1], [0, { [_hQ10]: _nT }], [1, { [_hQ10]: _mR }]],
      2
    ];
    exports2.ListResolversByFunctionResponse$ = [
      3,
      n032,
      _LRBFRi,
      0,
      [_res, _nT],
      [() => Resolvers, 0]
    ];
    exports2.ListResolversRequest$ = [
      3,
      n032,
      _LRR,
      0,
      [_aI10, _tN, _nT, _mR],
      [[0, 1], [0, 1], [0, { [_hQ10]: _nT }], [1, { [_hQ10]: _mR }]],
      2
    ];
    exports2.ListResolversResponse$ = [
      3,
      n032,
      _LRRi,
      0,
      [_res, _nT],
      [() => Resolvers, 0]
    ];
    exports2.ListSourceApiAssociationsRequest$ = [
      3,
      n032,
      _LSAAR,
      0,
      [_aI10, _nT, _mR],
      [[0, 1], [0, { [_hQ10]: _nT }], [1, { [_hQ10]: _mR }]],
      1
    ];
    exports2.ListSourceApiAssociationsResponse$ = [
      3,
      n032,
      _LSAARi,
      0,
      [_sAASo, _nT],
      [() => SourceApiAssociationSummaryList, 0]
    ];
    exports2.ListTagsForResourceRequest$ = [
      3,
      n032,
      _LTFRR,
      0,
      [_rA],
      [[0, 1]],
      1
    ];
    exports2.ListTagsForResourceResponse$ = [
      3,
      n032,
      _LTFRRi,
      0,
      [_t],
      [128 | 0]
    ];
    exports2.ListTypesByAssociationRequest$ = [
      3,
      n032,
      _LTBAR,
      0,
      [_mAI, _aIs, _f, _nT, _mR],
      [[0, 1], [0, 1], [0, { [_hQ10]: _f }], [0, { [_hQ10]: _nT }], [1, { [_hQ10]: _mR }]],
      3
    ];
    exports2.ListTypesByAssociationResponse$ = [
      3,
      n032,
      _LTBARi,
      0,
      [_typ, _nT],
      [() => TypeList, 0]
    ];
    exports2.ListTypesRequest$ = [
      3,
      n032,
      _LTR,
      0,
      [_aI10, _f, _nT, _mR],
      [[0, 1], [0, { [_hQ10]: _f }], [0, { [_hQ10]: _nT }], [1, { [_hQ10]: _mR }]],
      2
    ];
    exports2.ListTypesResponse$ = [
      3,
      n032,
      _LTRi,
      0,
      [_typ, _nT],
      [() => TypeList, 0]
    ];
    exports2.LogConfig$ = [
      3,
      n032,
      _LCo,
      0,
      [_fLL, _cWLRA, _eVC],
      [0, 0, 2],
      2
    ];
    exports2.OpenIDConnectConfig$ = [
      3,
      n032,
      _OIDCC,
      0,
      [_is, _cI13, _iTTL, _aTTL],
      [0, 0, 1, 1],
      1
    ];
    exports2.OpenSearchServiceDataSourceConfig$ = [
      3,
      n032,
      _OSSDSC,
      0,
      [_en, _aR],
      [0, 0],
      2
    ];
    exports2.PipelineConfig$ = [
      3,
      n032,
      _PC10,
      0,
      [_fun],
      [64 | 0]
    ];
    exports2.PutGraphqlApiEnvironmentVariablesRequest$ = [
      3,
      n032,
      _PGAEVR,
      0,
      [_aI10, _eV],
      [[0, 1], 128 | 0],
      2
    ];
    exports2.PutGraphqlApiEnvironmentVariablesResponse$ = [
      3,
      n032,
      _PGAEVRu,
      0,
      [_eV],
      [128 | 0]
    ];
    exports2.RdsDataApiConfig$ = [
      3,
      n032,
      _RDAC,
      0,
      [_rA, _sA, _dNa],
      [0, 0, 0],
      3
    ];
    exports2.RdsHttpEndpointConfig$ = [
      3,
      n032,
      _RHEC,
      0,
      [_aR, _dCI, _dNa, _sc4, _aSSA],
      [0, 0, 0, 0, 0]
    ];
    exports2.RelationalDatabaseDataSourceConfig$ = [
      3,
      n032,
      _RDDSC,
      0,
      [_rDST, _rHEC],
      [0, () => exports2.RdsHttpEndpointConfig$]
    ];
    exports2.Resolver$ = [
      3,
      n032,
      _R,
      0,
      [_tN, _fN, _dSN, _rAe, _rMT, _rMTe, _k, _pC, _sC, _cCa, _mBS, _ru, _cod, _mC],
      [0, 0, 0, 0, 0, 0, 0, () => exports2.PipelineConfig$, () => exports2.SyncConfig$, () => exports2.CachingConfig$, 1, () => exports2.AppSyncRuntime$, 0, 0]
    ];
    exports2.SourceApiAssociation$ = [
      3,
      n032,
      _SAA,
      0,
      [_aIs, _aAs, _sAIo, _sAAo, _mAA, _mAIe, _de, _sAAC, _sAAS, _sAASD, _lSMD],
      [0, 0, 0, 0, 0, 0, 0, () => exports2.SourceApiAssociationConfig$, 0, 0, 4]
    ];
    exports2.SourceApiAssociationConfig$ = [
      3,
      n032,
      _SAAC,
      0,
      [_mT],
      [0]
    ];
    exports2.SourceApiAssociationSummary$ = [
      3,
      n032,
      _SAAS,
      0,
      [_aIs, _aAs, _sAIo, _sAAo, _mAIe, _mAA, _de],
      [0, 0, 0, 0, 0, 0, 0]
    ];
    exports2.StartDataSourceIntrospectionRequest$ = [
      3,
      n032,
      _SDSIR,
      0,
      [_rDAC],
      [() => exports2.RdsDataApiConfig$]
    ];
    exports2.StartDataSourceIntrospectionResponse$ = [
      3,
      n032,
      _SDSIRt,
      0,
      [_iI, _iS, _iSD],
      [0, 0, 0]
    ];
    exports2.StartSchemaCreationRequest$ = [
      3,
      n032,
      _SSCR,
      0,
      [_aI10, _def],
      [[0, 1], 21],
      2
    ];
    exports2.StartSchemaCreationResponse$ = [
      3,
      n032,
      _SSCRt,
      0,
      [_st],
      [0]
    ];
    exports2.StartSchemaMergeRequest$ = [
      3,
      n032,
      _SSMR,
      0,
      [_aIs, _mAI],
      [[0, 1], [0, 1]],
      2
    ];
    exports2.StartSchemaMergeResponse$ = [
      3,
      n032,
      _SSMRt,
      0,
      [_sAAS],
      [0]
    ];
    exports2.SyncConfig$ = [
      3,
      n032,
      _SC,
      0,
      [_cHo, _cD, _lCHC],
      [0, 0, () => exports2.LambdaConflictHandlerConfig$]
    ];
    exports2.TagResourceRequest$ = [
      3,
      n032,
      _TRR,
      0,
      [_rA, _t],
      [[0, 1], 128 | 0],
      2
    ];
    exports2.TagResourceResponse$ = [
      3,
      n032,
      _TRRa,
      0,
      [],
      []
    ];
    exports2.Type$ = [
      3,
      n032,
      _T10,
      0,
      [_n, _de, _ar, _def, _f],
      [0, 0, 0, 0, 0]
    ];
    exports2.UntagResourceRequest$ = [
      3,
      n032,
      _URR,
      0,
      [_rA, _tK],
      [[0, 1], [64 | 0, { [_hQ10]: _tK }]],
      2
    ];
    exports2.UntagResourceResponse$ = [
      3,
      n032,
      _URRn,
      0,
      [],
      []
    ];
    exports2.UpdateApiCacheRequest$ = [
      3,
      n032,
      _UACR,
      0,
      [_aI10, _tt, _aCB, _ty, _hMC],
      [[0, 1], 1, 0, 0, 0],
      4
    ];
    exports2.UpdateApiCacheResponse$ = [
      3,
      n032,
      _UACRp,
      0,
      [_aC],
      [() => exports2.ApiCache$]
    ];
    exports2.UpdateApiKeyRequest$ = [
      3,
      n032,
      _UAKR,
      0,
      [_aI10, _i, _de, _ex10],
      [[0, 1], [0, 1], 0, 1],
      2
    ];
    exports2.UpdateApiKeyResponse$ = [
      3,
      n032,
      _UAKRp,
      0,
      [_aK],
      [() => exports2.ApiKey$]
    ];
    exports2.UpdateApiRequest$ = [
      3,
      n032,
      _UAR,
      0,
      [_aI10, _n, _eC, _oC],
      [[0, 1], 0, () => exports2.EventConfig$, 0],
      3
    ];
    exports2.UpdateApiResponse$ = [
      3,
      n032,
      _UARp,
      0,
      [_a10],
      [() => exports2.Api$]
    ];
    exports2.UpdateChannelNamespaceRequest$ = [
      3,
      n032,
      _UCNR,
      0,
      [_aI10, _n, _sAM, _pAM, _cH, _hC],
      [[0, 1], [0, 1], () => AuthModes, () => AuthModes, 0, () => exports2.HandlerConfigs$],
      2
    ];
    exports2.UpdateChannelNamespaceResponse$ = [
      3,
      n032,
      _UCNRp,
      0,
      [_cN],
      [() => exports2.ChannelNamespace$]
    ];
    exports2.UpdateDataSourceRequest$ = [
      3,
      n032,
      _UDSR,
      0,
      [_aI10, _n, _ty, _de, _sRA, _dC4, _lC, _eCl, _oSSC, _hCt, _rDC, _eBC, _mC],
      [[0, 1], [0, 1], 0, 0, 0, () => exports2.DynamodbDataSourceConfig$, () => exports2.LambdaDataSourceConfig$, () => exports2.ElasticsearchDataSourceConfig$, () => exports2.OpenSearchServiceDataSourceConfig$, () => exports2.HttpDataSourceConfig$, () => exports2.RelationalDatabaseDataSourceConfig$, () => exports2.EventBridgeDataSourceConfig$, 0],
      3
    ];
    exports2.UpdateDataSourceResponse$ = [
      3,
      n032,
      _UDSRp,
      0,
      [_dS],
      [() => exports2.DataSource$]
    ];
    exports2.UpdateDomainNameRequest$ = [
      3,
      n032,
      _UDNR,
      0,
      [_dN, _de],
      [[0, 1], 0],
      1
    ];
    exports2.UpdateDomainNameResponse$ = [
      3,
      n032,
      _UDNRp,
      0,
      [_dNC],
      [() => exports2.DomainNameConfig$]
    ];
    exports2.UpdateFunctionRequest$ = [
      3,
      n032,
      _UFR,
      0,
      [_aI10, _n, _fI, _dSN, _de, _rMT, _rMTe, _fV, _sC, _mBS, _ru, _cod],
      [[0, 1], 0, [0, 1], 0, 0, 0, 0, 0, () => exports2.SyncConfig$, 1, () => exports2.AppSyncRuntime$, 0],
      4
    ];
    exports2.UpdateFunctionResponse$ = [
      3,
      n032,
      _UFRp,
      0,
      [_fC],
      [() => exports2.FunctionConfiguration$]
    ];
    exports2.UpdateGraphqlApiRequest$ = [
      3,
      n032,
      _UGAR,
      0,
      [_aI10, _n, _aT22, _lCo, _uPC, _oIDCC, _aAP, _xE, _lAC, _mAERA, _oC, _iC, _qDL, _rCL, _eMC],
      [[0, 1], 0, 0, () => exports2.LogConfig$, () => exports2.UserPoolConfig$, () => exports2.OpenIDConnectConfig$, () => AdditionalAuthenticationProviders, 2, () => exports2.LambdaAuthorizerConfig$, 0, 0, 0, 1, 1, () => exports2.EnhancedMetricsConfig$],
      3
    ];
    exports2.UpdateGraphqlApiResponse$ = [
      3,
      n032,
      _UGARp,
      0,
      [_gA],
      [() => exports2.GraphqlApi$]
    ];
    exports2.UpdateResolverRequest$ = [
      3,
      n032,
      _URRp,
      0,
      [_aI10, _tN, _fN, _dSN, _rMT, _rMTe, _k, _pC, _sC, _cCa, _mBS, _ru, _cod, _mC],
      [[0, 1], [0, 1], [0, 1], 0, 0, 0, 0, () => exports2.PipelineConfig$, () => exports2.SyncConfig$, () => exports2.CachingConfig$, 1, () => exports2.AppSyncRuntime$, 0, 0],
      3
    ];
    exports2.UpdateResolverResponse$ = [
      3,
      n032,
      _URRpd,
      0,
      [_re],
      [() => exports2.Resolver$]
    ];
    exports2.UpdateSourceApiAssociationRequest$ = [
      3,
      n032,
      _USAAR,
      0,
      [_aIs, _mAI, _de, _sAAC],
      [[0, 1], [0, 1], 0, () => exports2.SourceApiAssociationConfig$],
      2
    ];
    exports2.UpdateSourceApiAssociationResponse$ = [
      3,
      n032,
      _USAARp,
      0,
      [_sAA],
      [() => exports2.SourceApiAssociation$]
    ];
    exports2.UpdateTypeRequest$ = [
      3,
      n032,
      _UTR,
      0,
      [_aI10, _tN, _f, _def],
      [[0, 1], [0, 1], 0, 0],
      3
    ];
    exports2.UpdateTypeResponse$ = [
      3,
      n032,
      _UTRp,
      0,
      [_ty],
      [() => exports2.Type$]
    ];
    exports2.UserPoolConfig$ = [
      3,
      n032,
      _UPC,
      0,
      [_uPI, _aR, _dA, _aICR],
      [0, 0, 0, 0],
      3
    ];
    var AdditionalAuthenticationProviders = [
      1,
      n032,
      _AAPd,
      0,
      () => exports2.AdditionalAuthenticationProvider$
    ];
    var ApiKeys = [
      1,
      n032,
      _AKp,
      0,
      () => exports2.ApiKey$
    ];
    var Apis = [
      1,
      n032,
      _Ap,
      0,
      () => exports2.Api$
    ];
    var AuthModes = [
      1,
      n032,
      _AMu,
      0,
      () => exports2.AuthMode$
    ];
    var AuthProviders = [
      1,
      n032,
      _APu,
      0,
      () => exports2.AuthProvider$
    ];
    var CachingKeys = 64 | 0;
    var ChannelNamespaces = [
      1,
      n032,
      _CNh,
      0,
      () => exports2.ChannelNamespace$
    ];
    var CodeErrors = [
      1,
      n032,
      _CEod,
      0,
      () => exports2.CodeError$
    ];
    var DataSourceIntrospectionModelFields = [
      1,
      n032,
      _DSIMFa,
      0,
      () => exports2.DataSourceIntrospectionModelField$
    ];
    var DataSourceIntrospectionModelFieldTypeValues = 64 | 0;
    var DataSourceIntrospectionModelIndexes = [
      1,
      n032,
      _DSIMIa,
      0,
      () => exports2.DataSourceIntrospectionModelIndex$
    ];
    var DataSourceIntrospectionModelIndexFields = 64 | 0;
    var DataSourceIntrospectionModels = [
      1,
      n032,
      _DSIMa,
      0,
      () => exports2.DataSourceIntrospectionModel$
    ];
    var DataSources = [
      1,
      n032,
      _DSa,
      0,
      () => exports2.DataSource$
    ];
    var DomainNameConfigs = [
      1,
      n032,
      _DNCo,
      0,
      () => exports2.DomainNameConfig$
    ];
    var Functions = [
      1,
      n032,
      _F,
      0,
      () => exports2.FunctionConfiguration$
    ];
    var FunctionsIds = 64 | 0;
    var GraphqlApis = [
      1,
      n032,
      _GAr,
      0,
      () => exports2.GraphqlApi$
    ];
    var Logs = 64 | 0;
    var Resolvers = [
      1,
      n032,
      _Re,
      0,
      () => exports2.Resolver$
    ];
    var SourceApiAssociationSummaryList = [
      1,
      n032,
      _SAASL,
      0,
      () => exports2.SourceApiAssociationSummary$
    ];
    var TagKeyList = 64 | 0;
    var TypeList = [
      1,
      n032,
      _TL,
      0,
      () => exports2.Type$
    ];
    var EnvironmentVariableMap = 128 | 0;
    var MapOfStringToString = 128 | 0;
    var TagMap = 128 | 0;
    exports2.AssociateApi$ = [
      9,
      n032,
      _AAs,
      { [_h22]: ["POST", "/v1/domainnames/{domainName}/apiassociation", 200] },
      () => exports2.AssociateApiRequest$,
      () => exports2.AssociateApiResponse$
    ];
    exports2.AssociateMergedGraphqlApi$ = [
      9,
      n032,
      _AMGA,
      { [_h22]: ["POST", "/v1/sourceApis/{sourceApiIdentifier}/mergedApiAssociations", 200] },
      () => exports2.AssociateMergedGraphqlApiRequest$,
      () => exports2.AssociateMergedGraphqlApiResponse$
    ];
    exports2.AssociateSourceGraphqlApi$ = [
      9,
      n032,
      _ASGA,
      { [_h22]: ["POST", "/v1/mergedApis/{mergedApiIdentifier}/sourceApiAssociations", 200] },
      () => exports2.AssociateSourceGraphqlApiRequest$,
      () => exports2.AssociateSourceGraphqlApiResponse$
    ];
    exports2.CreateApi$ = [
      9,
      n032,
      _CA10,
      { [_h22]: ["POST", "/v2/apis", 200] },
      () => exports2.CreateApiRequest$,
      () => exports2.CreateApiResponse$
    ];
    exports2.CreateApiCache$ = [
      9,
      n032,
      _CAC,
      { [_h22]: ["POST", "/v1/apis/{apiId}/ApiCaches", 200] },
      () => exports2.CreateApiCacheRequest$,
      () => exports2.CreateApiCacheResponse$
    ];
    exports2.CreateApiKey$ = [
      9,
      n032,
      _CAK,
      { [_h22]: ["POST", "/v1/apis/{apiId}/apikeys", 200] },
      () => exports2.CreateApiKeyRequest$,
      () => exports2.CreateApiKeyResponse$
    ];
    exports2.CreateChannelNamespace$ = [
      9,
      n032,
      _CCN,
      { [_h22]: ["POST", "/v2/apis/{apiId}/channelNamespaces", 200] },
      () => exports2.CreateChannelNamespaceRequest$,
      () => exports2.CreateChannelNamespaceResponse$
    ];
    exports2.CreateDataSource$ = [
      9,
      n032,
      _CDS,
      { [_h22]: ["POST", "/v1/apis/{apiId}/datasources", 200] },
      () => exports2.CreateDataSourceRequest$,
      () => exports2.CreateDataSourceResponse$
    ];
    exports2.CreateDomainName$ = [
      9,
      n032,
      _CDN,
      { [_h22]: ["POST", "/v1/domainnames", 200] },
      () => exports2.CreateDomainNameRequest$,
      () => exports2.CreateDomainNameResponse$
    ];
    exports2.CreateFunction$ = [
      9,
      n032,
      _CF,
      { [_h22]: ["POST", "/v1/apis/{apiId}/functions", 200] },
      () => exports2.CreateFunctionRequest$,
      () => exports2.CreateFunctionResponse$
    ];
    exports2.CreateGraphqlApi$ = [
      9,
      n032,
      _CGA,
      { [_h22]: ["POST", "/v1/apis", 200] },
      () => exports2.CreateGraphqlApiRequest$,
      () => exports2.CreateGraphqlApiResponse$
    ];
    exports2.CreateResolver$ = [
      9,
      n032,
      _CR,
      { [_h22]: ["POST", "/v1/apis/{apiId}/types/{typeName}/resolvers", 200] },
      () => exports2.CreateResolverRequest$,
      () => exports2.CreateResolverResponse$
    ];
    exports2.CreateType$ = [
      9,
      n032,
      _CT4,
      { [_h22]: ["POST", "/v1/apis/{apiId}/types", 200] },
      () => exports2.CreateTypeRequest$,
      () => exports2.CreateTypeResponse$
    ];
    exports2.DeleteApi$ = [
      9,
      n032,
      _DA,
      { [_h22]: ["DELETE", "/v2/apis/{apiId}", 200] },
      () => exports2.DeleteApiRequest$,
      () => exports2.DeleteApiResponse$
    ];
    exports2.DeleteApiCache$ = [
      9,
      n032,
      _DAC,
      { [_h22]: ["DELETE", "/v1/apis/{apiId}/ApiCaches", 200] },
      () => exports2.DeleteApiCacheRequest$,
      () => exports2.DeleteApiCacheResponse$
    ];
    exports2.DeleteApiKey$ = [
      9,
      n032,
      _DAK,
      { [_h22]: ["DELETE", "/v1/apis/{apiId}/apikeys/{id}", 200] },
      () => exports2.DeleteApiKeyRequest$,
      () => exports2.DeleteApiKeyResponse$
    ];
    exports2.DeleteChannelNamespace$ = [
      9,
      n032,
      _DCN,
      { [_h22]: ["DELETE", "/v2/apis/{apiId}/channelNamespaces/{name}", 200] },
      () => exports2.DeleteChannelNamespaceRequest$,
      () => exports2.DeleteChannelNamespaceResponse$
    ];
    exports2.DeleteDataSource$ = [
      9,
      n032,
      _DDS,
      { [_h22]: ["DELETE", "/v1/apis/{apiId}/datasources/{name}", 200] },
      () => exports2.DeleteDataSourceRequest$,
      () => exports2.DeleteDataSourceResponse$
    ];
    exports2.DeleteDomainName$ = [
      9,
      n032,
      _DDN,
      { [_h22]: ["DELETE", "/v1/domainnames/{domainName}", 200] },
      () => exports2.DeleteDomainNameRequest$,
      () => exports2.DeleteDomainNameResponse$
    ];
    exports2.DeleteFunction$ = [
      9,
      n032,
      _DF,
      { [_h22]: ["DELETE", "/v1/apis/{apiId}/functions/{functionId}", 200] },
      () => exports2.DeleteFunctionRequest$,
      () => exports2.DeleteFunctionResponse$
    ];
    exports2.DeleteGraphqlApi$ = [
      9,
      n032,
      _DGA,
      { [_h22]: ["DELETE", "/v1/apis/{apiId}", 200] },
      () => exports2.DeleteGraphqlApiRequest$,
      () => exports2.DeleteGraphqlApiResponse$
    ];
    exports2.DeleteResolver$ = [
      9,
      n032,
      _DR,
      { [_h22]: ["DELETE", "/v1/apis/{apiId}/types/{typeName}/resolvers/{fieldName}", 200] },
      () => exports2.DeleteResolverRequest$,
      () => exports2.DeleteResolverResponse$
    ];
    exports2.DeleteType$ = [
      9,
      n032,
      _DT,
      { [_h22]: ["DELETE", "/v1/apis/{apiId}/types/{typeName}", 200] },
      () => exports2.DeleteTypeRequest$,
      () => exports2.DeleteTypeResponse$
    ];
    exports2.DisassociateApi$ = [
      9,
      n032,
      _DAi,
      { [_h22]: ["DELETE", "/v1/domainnames/{domainName}/apiassociation", 200] },
      () => exports2.DisassociateApiRequest$,
      () => exports2.DisassociateApiResponse$
    ];
    exports2.DisassociateMergedGraphqlApi$ = [
      9,
      n032,
      _DMGA,
      { [_h22]: ["DELETE", "/v1/sourceApis/{sourceApiIdentifier}/mergedApiAssociations/{associationId}", 200] },
      () => exports2.DisassociateMergedGraphqlApiRequest$,
      () => exports2.DisassociateMergedGraphqlApiResponse$
    ];
    exports2.DisassociateSourceGraphqlApi$ = [
      9,
      n032,
      _DSGA,
      { [_h22]: ["DELETE", "/v1/mergedApis/{mergedApiIdentifier}/sourceApiAssociations/{associationId}", 200] },
      () => exports2.DisassociateSourceGraphqlApiRequest$,
      () => exports2.DisassociateSourceGraphqlApiResponse$
    ];
    exports2.EvaluateCode$ = [
      9,
      n032,
      _ECv,
      { [_h22]: ["POST", "/v1/dataplane-evaluatecode", 200] },
      () => exports2.EvaluateCodeRequest$,
      () => exports2.EvaluateCodeResponse$
    ];
    exports2.EvaluateMappingTemplate$ = [
      9,
      n032,
      _EMT,
      { [_h22]: ["POST", "/v1/dataplane-evaluatetemplate", 200] },
      () => exports2.EvaluateMappingTemplateRequest$,
      () => exports2.EvaluateMappingTemplateResponse$
    ];
    exports2.FlushApiCache$ = [
      9,
      n032,
      _FAC,
      { [_h22]: ["DELETE", "/v1/apis/{apiId}/FlushCache", 200] },
      () => exports2.FlushApiCacheRequest$,
      () => exports2.FlushApiCacheResponse$
    ];
    exports2.GetApi$ = [
      9,
      n032,
      _GAe,
      { [_h22]: ["GET", "/v2/apis/{apiId}", 200] },
      () => exports2.GetApiRequest$,
      () => exports2.GetApiResponse$
    ];
    exports2.GetApiAssociation$ = [
      9,
      n032,
      _GAA,
      { [_h22]: ["GET", "/v1/domainnames/{domainName}/apiassociation", 200] },
      () => exports2.GetApiAssociationRequest$,
      () => exports2.GetApiAssociationResponse$
    ];
    exports2.GetApiCache$ = [
      9,
      n032,
      _GAC,
      { [_h22]: ["GET", "/v1/apis/{apiId}/ApiCaches", 200] },
      () => exports2.GetApiCacheRequest$,
      () => exports2.GetApiCacheResponse$
    ];
    exports2.GetChannelNamespace$ = [
      9,
      n032,
      _GCN,
      { [_h22]: ["GET", "/v2/apis/{apiId}/channelNamespaces/{name}", 200] },
      () => exports2.GetChannelNamespaceRequest$,
      () => exports2.GetChannelNamespaceResponse$
    ];
    exports2.GetDataSource$ = [
      9,
      n032,
      _GDS,
      { [_h22]: ["GET", "/v1/apis/{apiId}/datasources/{name}", 200] },
      () => exports2.GetDataSourceRequest$,
      () => exports2.GetDataSourceResponse$
    ];
    exports2.GetDataSourceIntrospection$ = [
      9,
      n032,
      _GDSI,
      { [_h22]: ["GET", "/v1/datasources/introspections/{introspectionId}", 200] },
      () => exports2.GetDataSourceIntrospectionRequest$,
      () => exports2.GetDataSourceIntrospectionResponse$
    ];
    exports2.GetDomainName$ = [
      9,
      n032,
      _GDN,
      { [_h22]: ["GET", "/v1/domainnames/{domainName}", 200] },
      () => exports2.GetDomainNameRequest$,
      () => exports2.GetDomainNameResponse$
    ];
    exports2.GetFunction$ = [
      9,
      n032,
      _GF,
      { [_h22]: ["GET", "/v1/apis/{apiId}/functions/{functionId}", 200] },
      () => exports2.GetFunctionRequest$,
      () => exports2.GetFunctionResponse$
    ];
    exports2.GetGraphqlApi$ = [
      9,
      n032,
      _GGA,
      { [_h22]: ["GET", "/v1/apis/{apiId}", 200] },
      () => exports2.GetGraphqlApiRequest$,
      () => exports2.GetGraphqlApiResponse$
    ];
    exports2.GetGraphqlApiEnvironmentVariables$ = [
      9,
      n032,
      _GGAEV,
      { [_h22]: ["GET", "/v1/apis/{apiId}/environmentVariables", 200] },
      () => exports2.GetGraphqlApiEnvironmentVariablesRequest$,
      () => exports2.GetGraphqlApiEnvironmentVariablesResponse$
    ];
    exports2.GetIntrospectionSchema$ = [
      9,
      n032,
      _GIS,
      { [_h22]: ["GET", "/v1/apis/{apiId}/schema", 200] },
      () => exports2.GetIntrospectionSchemaRequest$,
      () => exports2.GetIntrospectionSchemaResponse$
    ];
    exports2.GetResolver$ = [
      9,
      n032,
      _GR,
      { [_h22]: ["GET", "/v1/apis/{apiId}/types/{typeName}/resolvers/{fieldName}", 200] },
      () => exports2.GetResolverRequest$,
      () => exports2.GetResolverResponse$
    ];
    exports2.GetSchemaCreationStatus$ = [
      9,
      n032,
      _GSCS,
      { [_h22]: ["GET", "/v1/apis/{apiId}/schemacreation", 200] },
      () => exports2.GetSchemaCreationStatusRequest$,
      () => exports2.GetSchemaCreationStatusResponse$
    ];
    exports2.GetSourceApiAssociation$ = [
      9,
      n032,
      _GSAA,
      { [_h22]: ["GET", "/v1/mergedApis/{mergedApiIdentifier}/sourceApiAssociations/{associationId}", 200] },
      () => exports2.GetSourceApiAssociationRequest$,
      () => exports2.GetSourceApiAssociationResponse$
    ];
    exports2.GetType$ = [
      9,
      n032,
      _GT,
      { [_h22]: ["GET", "/v1/apis/{apiId}/types/{typeName}", 200] },
      () => exports2.GetTypeRequest$,
      () => exports2.GetTypeResponse$
    ];
    exports2.ListApiKeys$ = [
      9,
      n032,
      _LAK,
      { [_h22]: ["GET", "/v1/apis/{apiId}/apikeys", 200] },
      () => exports2.ListApiKeysRequest$,
      () => exports2.ListApiKeysResponse$
    ];
    exports2.ListApis$ = [
      9,
      n032,
      _LA,
      { [_h22]: ["GET", "/v2/apis", 200] },
      () => exports2.ListApisRequest$,
      () => exports2.ListApisResponse$
    ];
    exports2.ListChannelNamespaces$ = [
      9,
      n032,
      _LCN,
      { [_h22]: ["GET", "/v2/apis/{apiId}/channelNamespaces", 200] },
      () => exports2.ListChannelNamespacesRequest$,
      () => exports2.ListChannelNamespacesResponse$
    ];
    exports2.ListDataSources$ = [
      9,
      n032,
      _LDS,
      { [_h22]: ["GET", "/v1/apis/{apiId}/datasources", 200] },
      () => exports2.ListDataSourcesRequest$,
      () => exports2.ListDataSourcesResponse$
    ];
    exports2.ListDomainNames$ = [
      9,
      n032,
      _LDN,
      { [_h22]: ["GET", "/v1/domainnames", 200] },
      () => exports2.ListDomainNamesRequest$,
      () => exports2.ListDomainNamesResponse$
    ];
    exports2.ListFunctions$ = [
      9,
      n032,
      _LF,
      { [_h22]: ["GET", "/v1/apis/{apiId}/functions", 200] },
      () => exports2.ListFunctionsRequest$,
      () => exports2.ListFunctionsResponse$
    ];
    exports2.ListGraphqlApis$ = [
      9,
      n032,
      _LGA,
      { [_h22]: ["GET", "/v1/apis", 200] },
      () => exports2.ListGraphqlApisRequest$,
      () => exports2.ListGraphqlApisResponse$
    ];
    exports2.ListResolvers$ = [
      9,
      n032,
      _LR,
      { [_h22]: ["GET", "/v1/apis/{apiId}/types/{typeName}/resolvers", 200] },
      () => exports2.ListResolversRequest$,
      () => exports2.ListResolversResponse$
    ];
    exports2.ListResolversByFunction$ = [
      9,
      n032,
      _LRBF,
      { [_h22]: ["GET", "/v1/apis/{apiId}/functions/{functionId}/resolvers", 200] },
      () => exports2.ListResolversByFunctionRequest$,
      () => exports2.ListResolversByFunctionResponse$
    ];
    exports2.ListSourceApiAssociations$ = [
      9,
      n032,
      _LSAA,
      { [_h22]: ["GET", "/v1/apis/{apiId}/sourceApiAssociations", 200] },
      () => exports2.ListSourceApiAssociationsRequest$,
      () => exports2.ListSourceApiAssociationsResponse$
    ];
    exports2.ListTagsForResource$ = [
      9,
      n032,
      _LTFR,
      { [_h22]: ["GET", "/v1/tags/{resourceArn}", 200] },
      () => exports2.ListTagsForResourceRequest$,
      () => exports2.ListTagsForResourceResponse$
    ];
    exports2.ListTypes$ = [
      9,
      n032,
      _LT,
      { [_h22]: ["GET", "/v1/apis/{apiId}/types", 200] },
      () => exports2.ListTypesRequest$,
      () => exports2.ListTypesResponse$
    ];
    exports2.ListTypesByAssociation$ = [
      9,
      n032,
      _LTBA,
      { [_h22]: ["GET", "/v1/mergedApis/{mergedApiIdentifier}/sourceApiAssociations/{associationId}/types", 200] },
      () => exports2.ListTypesByAssociationRequest$,
      () => exports2.ListTypesByAssociationResponse$
    ];
    exports2.PutGraphqlApiEnvironmentVariables$ = [
      9,
      n032,
      _PGAEV,
      { [_h22]: ["PUT", "/v1/apis/{apiId}/environmentVariables", 200] },
      () => exports2.PutGraphqlApiEnvironmentVariablesRequest$,
      () => exports2.PutGraphqlApiEnvironmentVariablesResponse$
    ];
    exports2.StartDataSourceIntrospection$ = [
      9,
      n032,
      _SDSI,
      { [_h22]: ["POST", "/v1/datasources/introspections", 200] },
      () => exports2.StartDataSourceIntrospectionRequest$,
      () => exports2.StartDataSourceIntrospectionResponse$
    ];
    exports2.StartSchemaCreation$ = [
      9,
      n032,
      _SSC,
      { [_h22]: ["POST", "/v1/apis/{apiId}/schemacreation", 200] },
      () => exports2.StartSchemaCreationRequest$,
      () => exports2.StartSchemaCreationResponse$
    ];
    exports2.StartSchemaMerge$ = [
      9,
      n032,
      _SSM,
      { [_h22]: ["POST", "/v1/mergedApis/{mergedApiIdentifier}/sourceApiAssociations/{associationId}/merge", 200] },
      () => exports2.StartSchemaMergeRequest$,
      () => exports2.StartSchemaMergeResponse$
    ];
    exports2.TagResource$ = [
      9,
      n032,
      _TR,
      { [_h22]: ["POST", "/v1/tags/{resourceArn}", 200] },
      () => exports2.TagResourceRequest$,
      () => exports2.TagResourceResponse$
    ];
    exports2.UntagResource$ = [
      9,
      n032,
      _UR,
      { [_h22]: ["DELETE", "/v1/tags/{resourceArn}", 200] },
      () => exports2.UntagResourceRequest$,
      () => exports2.UntagResourceResponse$
    ];
    exports2.UpdateApi$ = [
      9,
      n032,
      _UA,
      { [_h22]: ["POST", "/v2/apis/{apiId}", 200] },
      () => exports2.UpdateApiRequest$,
      () => exports2.UpdateApiResponse$
    ];
    exports2.UpdateApiCache$ = [
      9,
      n032,
      _UAC,
      { [_h22]: ["POST", "/v1/apis/{apiId}/ApiCaches/update", 200] },
      () => exports2.UpdateApiCacheRequest$,
      () => exports2.UpdateApiCacheResponse$
    ];
    exports2.UpdateApiKey$ = [
      9,
      n032,
      _UAK,
      { [_h22]: ["POST", "/v1/apis/{apiId}/apikeys/{id}", 200] },
      () => exports2.UpdateApiKeyRequest$,
      () => exports2.UpdateApiKeyResponse$
    ];
    exports2.UpdateChannelNamespace$ = [
      9,
      n032,
      _UCN,
      { [_h22]: ["POST", "/v2/apis/{apiId}/channelNamespaces/{name}", 200] },
      () => exports2.UpdateChannelNamespaceRequest$,
      () => exports2.UpdateChannelNamespaceResponse$
    ];
    exports2.UpdateDataSource$ = [
      9,
      n032,
      _UDS,
      { [_h22]: ["POST", "/v1/apis/{apiId}/datasources/{name}", 200] },
      () => exports2.UpdateDataSourceRequest$,
      () => exports2.UpdateDataSourceResponse$
    ];
    exports2.UpdateDomainName$ = [
      9,
      n032,
      _UDN,
      { [_h22]: ["POST", "/v1/domainnames/{domainName}", 200] },
      () => exports2.UpdateDomainNameRequest$,
      () => exports2.UpdateDomainNameResponse$
    ];
    exports2.UpdateFunction$ = [
      9,
      n032,
      _UF,
      { [_h22]: ["POST", "/v1/apis/{apiId}/functions/{functionId}", 200] },
      () => exports2.UpdateFunctionRequest$,
      () => exports2.UpdateFunctionResponse$
    ];
    exports2.UpdateGraphqlApi$ = [
      9,
      n032,
      _UGA,
      { [_h22]: ["POST", "/v1/apis/{apiId}", 200] },
      () => exports2.UpdateGraphqlApiRequest$,
      () => exports2.UpdateGraphqlApiResponse$
    ];
    exports2.UpdateResolver$ = [
      9,
      n032,
      _URp,
      { [_h22]: ["POST", "/v1/apis/{apiId}/types/{typeName}/resolvers/{fieldName}", 200] },
      () => exports2.UpdateResolverRequest$,
      () => exports2.UpdateResolverResponse$
    ];
    exports2.UpdateSourceApiAssociation$ = [
      9,
      n032,
      _USAA,
      { [_h22]: ["POST", "/v1/mergedApis/{mergedApiIdentifier}/sourceApiAssociations/{associationId}", 200] },
      () => exports2.UpdateSourceApiAssociationRequest$,
      () => exports2.UpdateSourceApiAssociationResponse$
    ];
    exports2.UpdateType$ = [
      9,
      n032,
      _UT,
      { [_h22]: ["POST", "/v1/apis/{apiId}/types/{typeName}", 200] },
      () => exports2.UpdateTypeRequest$,
      () => exports2.UpdateTypeResponse$
    ];
  }
});

// ../../node_modules/@aws-sdk/client-appsync/dist-cjs/runtimeConfig.shared.js
var require_runtimeConfig_shared7 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/dist-cjs/runtimeConfig.shared.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes9(), __toCommonJS(httpAuthSchemes_exports7));
    var protocols_1 = (init_protocols15(), __toCommonJS(protocols_exports12));
    var client_1 = (init_client12(), __toCommonJS(client_exports9));
    var protocols_2 = (init_protocols11(), __toCommonJS(protocols_exports8));
    var serde_1 = (init_serde4(), __toCommonJS(serde_exports2));
    var httpAuthSchemeProvider_1 = require_httpAuthSchemeProvider6();
    var endpointResolver_1 = require_endpointResolver6();
    var schemas_0_1 = require_schemas_06();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2017-07-25",
        base64Decoder: config2?.base64Decoder ?? serde_1.fromBase64,
        base64Encoder: config2?.base64Encoder ?? serde_1.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? endpointResolver_1.defaultEndpointResolver,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? httpAuthSchemeProvider_1.defaultAppSyncHttpAuthSchemeProvider,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new httpAuthSchemes_1.AwsSdkSigV4Signer()
          }
        ],
        logger: config2?.logger ?? new client_1.NoOpLogger(),
        protocol: config2?.protocol ?? protocols_1.AwsRestJsonProtocol,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.appsync",
          errorTypeRegistries: schemas_0_1.errorTypeRegistries,
          xmlNamespace: "http://appsync.amazonaws.com",
          version: "2017-07-25",
          serviceTarget: "AWSDeepdishControlPlaneService"
        },
        serviceId: config2?.serviceId ?? "AppSync",
        urlParser: config2?.urlParser ?? protocols_2.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? serde_1.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? serde_1.toUtf8
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/dist-cjs/runtimeConfig.js
var require_runtimeConfig7 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/dist-cjs/runtimeConfig.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var package_json_1 = tslib_1.__importDefault(require_package6());
    var client_1 = (init_client13(), __toCommonJS(client_exports10));
    var httpAuthSchemes_1 = (init_httpAuthSchemes9(), __toCommonJS(httpAuthSchemes_exports7));
    var credential_provider_node_1 = require_dist_cjs154();
    var client_2 = (init_client12(), __toCommonJS(client_exports9));
    var config_1 = (init_config4(), __toCommonJS(config_exports));
    var retry_1 = (init_retry3(), __toCommonJS(retry_exports2));
    var serde_1 = (init_serde4(), __toCommonJS(serde_exports2));
    var node_http_handler_1 = require_dist_cjs144();
    var runtimeConfig_shared_1 = require_runtimeConfig_shared7();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      (0, client_2.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, config_1.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(client_2.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = (0, runtimeConfig_shared_1.getRuntimeConfig)(config2);
      (0, client_1.emitWarningIfUnsupportedVersion)(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, config_1.loadConfig)(httpAuthSchemes_1.NODE_AUTH_SCHEME_PREFERENCE_OPTIONS, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? serde_1.calculateBodyLength,
        credentialDefaultProvider: config2?.credentialDefaultProvider ?? credential_provider_node_1.defaultProvider,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, client_1.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_json_1.default.version }),
        maxAttempts: config2?.maxAttempts ?? (0, config_1.loadConfig)(retry_1.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, config_1.loadConfig)(config_1.NODE_REGION_CONFIG_OPTIONS, { ...config_1.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: node_http_handler_1.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, config_1.loadConfig)({
          ...retry_1.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || retry_1.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? serde_1.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? node_http_handler_1.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, config_1.loadConfig)(config_1.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, config_1.loadConfig)(config_1.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, config_1.loadConfig)(client_1.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-appsync/dist-cjs/index.js
var require_dist_cjs155 = __commonJS({
  "../../node_modules/@aws-sdk/client-appsync/dist-cjs/index.js"(exports2) {
    "use strict";
    var client$1 = (init_client13(), __toCommonJS(client_exports10));
    var core = (init_dist_es2(), __toCommonJS(dist_es_exports2));
    var client = (init_client12(), __toCommonJS(client_exports9));
    var config2 = (init_config4(), __toCommonJS(config_exports));
    var endpoints = (init_endpoints3(), __toCommonJS(endpoints_exports3));
    var protocols = (init_protocols11(), __toCommonJS(protocols_exports8));
    var retry = (init_retry3(), __toCommonJS(retry_exports2));
    var schema = (init_schema6(), __toCommonJS(schema_exports2));
    var httpAuthSchemeProvider = require_httpAuthSchemeProvider6();
    var runtimeConfig = require_runtimeConfig7();
    var schemas_0 = require_schemas_06();
    var errors = require_errors6();
    var AppSyncServiceException = require_AppSyncServiceException();
    var resolveClientEndpointParameters32 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "appsync"
      });
    }, "resolveClientEndpointParameters");
    var commonParams32 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
    var getHttpAuthExtensionConfiguration32 = /* @__PURE__ */ __name((runtimeConfig2) => {
      const _httpAuthSchemes = runtimeConfig2.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig2.httpAuthSchemeProvider;
      let _credentials = runtimeConfig2.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider2) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider2;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    var resolveHttpAuthRuntimeConfig32 = /* @__PURE__ */ __name((config3) => {
      return {
        httpAuthSchemes: config3.httpAuthSchemes(),
        httpAuthSchemeProvider: config3.httpAuthSchemeProvider(),
        credentials: config3.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
    var resolveRuntimeExtensions32 = /* @__PURE__ */ __name((runtimeConfig2, extensions) => {
      const extensionConfiguration = Object.assign(client$1.getAwsRegionExtensionConfiguration(runtimeConfig2), client.getDefaultExtensionConfiguration(runtimeConfig2), protocols.getHttpHandlerExtensionConfiguration(runtimeConfig2), getHttpAuthExtensionConfiguration32(runtimeConfig2));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig2, client$1.resolveAwsRegionExtensionConfiguration(extensionConfiguration), client.resolveDefaultRuntimeConfig(extensionConfiguration), protocols.resolveHttpHandlerRuntimeConfig(extensionConfiguration), resolveHttpAuthRuntimeConfig32(extensionConfiguration));
    }, "resolveRuntimeExtensions");
    var AppSyncClient2 = class extends client.Client {
      static {
        __name(this, "AppSyncClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = runtimeConfig.getRuntimeConfig(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters32(_config_0);
        const _config_2 = client$1.resolveUserAgentConfig(_config_1);
        const _config_3 = retry.resolveRetryConfig(_config_2);
        const _config_4 = config2.resolveRegionConfig(_config_3);
        const _config_5 = client$1.resolveHostHeaderConfig(_config_4);
        const _config_6 = endpoints.resolveEndpointConfig(_config_5);
        const _config_7 = httpAuthSchemeProvider.resolveHttpAuthSchemeConfig(_config_6);
        const _config_8 = resolveRuntimeExtensions32(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(schema.getSchemaSerdePlugin(this.config));
        this.middlewareStack.use(client$1.getUserAgentPlugin(this.config));
        this.middlewareStack.use(retry.getRetryPlugin(this.config));
        this.middlewareStack.use(protocols.getContentLengthPlugin(this.config));
        this.middlewareStack.use(client$1.getHostHeaderPlugin(this.config));
        this.middlewareStack.use(client$1.getLoggerPlugin(this.config));
        this.middlewareStack.use(client$1.getRecursionDetectionPlugin(this.config));
        this.middlewareStack.use(core.getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: httpAuthSchemeProvider.defaultAppSyncHttpAuthSchemeParametersProvider,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config3) => new core.DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config3.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(core.getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
    var AssociateApiCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "AssociateApi", {}).n("AppSyncClient", "AssociateApiCommand").sc(schemas_0.AssociateApi$).build() {
      static {
        __name(this, "AssociateApiCommand");
      }
    };
    var AssociateMergedGraphqlApiCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "AssociateMergedGraphqlApi", {}).n("AppSyncClient", "AssociateMergedGraphqlApiCommand").sc(schemas_0.AssociateMergedGraphqlApi$).build() {
      static {
        __name(this, "AssociateMergedGraphqlApiCommand");
      }
    };
    var AssociateSourceGraphqlApiCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "AssociateSourceGraphqlApi", {}).n("AppSyncClient", "AssociateSourceGraphqlApiCommand").sc(schemas_0.AssociateSourceGraphqlApi$).build() {
      static {
        __name(this, "AssociateSourceGraphqlApiCommand");
      }
    };
    var CreateApiCacheCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "CreateApiCache", {}).n("AppSyncClient", "CreateApiCacheCommand").sc(schemas_0.CreateApiCache$).build() {
      static {
        __name(this, "CreateApiCacheCommand");
      }
    };
    var CreateApiCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "CreateApi", {}).n("AppSyncClient", "CreateApiCommand").sc(schemas_0.CreateApi$).build() {
      static {
        __name(this, "CreateApiCommand");
      }
    };
    var CreateApiKeyCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "CreateApiKey", {}).n("AppSyncClient", "CreateApiKeyCommand").sc(schemas_0.CreateApiKey$).build() {
      static {
        __name(this, "CreateApiKeyCommand");
      }
    };
    var CreateChannelNamespaceCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "CreateChannelNamespace", {}).n("AppSyncClient", "CreateChannelNamespaceCommand").sc(schemas_0.CreateChannelNamespace$).build() {
      static {
        __name(this, "CreateChannelNamespaceCommand");
      }
    };
    var CreateDataSourceCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "CreateDataSource", {}).n("AppSyncClient", "CreateDataSourceCommand").sc(schemas_0.CreateDataSource$).build() {
      static {
        __name(this, "CreateDataSourceCommand");
      }
    };
    var CreateDomainNameCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "CreateDomainName", {}).n("AppSyncClient", "CreateDomainNameCommand").sc(schemas_0.CreateDomainName$).build() {
      static {
        __name(this, "CreateDomainNameCommand");
      }
    };
    var CreateFunctionCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "CreateFunction", {}).n("AppSyncClient", "CreateFunctionCommand").sc(schemas_0.CreateFunction$).build() {
      static {
        __name(this, "CreateFunctionCommand");
      }
    };
    var CreateGraphqlApiCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "CreateGraphqlApi", {}).n("AppSyncClient", "CreateGraphqlApiCommand").sc(schemas_0.CreateGraphqlApi$).build() {
      static {
        __name(this, "CreateGraphqlApiCommand");
      }
    };
    var CreateResolverCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "CreateResolver", {}).n("AppSyncClient", "CreateResolverCommand").sc(schemas_0.CreateResolver$).build() {
      static {
        __name(this, "CreateResolverCommand");
      }
    };
    var CreateTypeCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "CreateType", {}).n("AppSyncClient", "CreateTypeCommand").sc(schemas_0.CreateType$).build() {
      static {
        __name(this, "CreateTypeCommand");
      }
    };
    var DeleteApiCacheCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "DeleteApiCache", {}).n("AppSyncClient", "DeleteApiCacheCommand").sc(schemas_0.DeleteApiCache$).build() {
      static {
        __name(this, "DeleteApiCacheCommand");
      }
    };
    var DeleteApiCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "DeleteApi", {}).n("AppSyncClient", "DeleteApiCommand").sc(schemas_0.DeleteApi$).build() {
      static {
        __name(this, "DeleteApiCommand");
      }
    };
    var DeleteApiKeyCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "DeleteApiKey", {}).n("AppSyncClient", "DeleteApiKeyCommand").sc(schemas_0.DeleteApiKey$).build() {
      static {
        __name(this, "DeleteApiKeyCommand");
      }
    };
    var DeleteChannelNamespaceCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "DeleteChannelNamespace", {}).n("AppSyncClient", "DeleteChannelNamespaceCommand").sc(schemas_0.DeleteChannelNamespace$).build() {
      static {
        __name(this, "DeleteChannelNamespaceCommand");
      }
    };
    var DeleteDataSourceCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "DeleteDataSource", {}).n("AppSyncClient", "DeleteDataSourceCommand").sc(schemas_0.DeleteDataSource$).build() {
      static {
        __name(this, "DeleteDataSourceCommand");
      }
    };
    var DeleteDomainNameCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "DeleteDomainName", {}).n("AppSyncClient", "DeleteDomainNameCommand").sc(schemas_0.DeleteDomainName$).build() {
      static {
        __name(this, "DeleteDomainNameCommand");
      }
    };
    var DeleteFunctionCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "DeleteFunction", {}).n("AppSyncClient", "DeleteFunctionCommand").sc(schemas_0.DeleteFunction$).build() {
      static {
        __name(this, "DeleteFunctionCommand");
      }
    };
    var DeleteGraphqlApiCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "DeleteGraphqlApi", {}).n("AppSyncClient", "DeleteGraphqlApiCommand").sc(schemas_0.DeleteGraphqlApi$).build() {
      static {
        __name(this, "DeleteGraphqlApiCommand");
      }
    };
    var DeleteResolverCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "DeleteResolver", {}).n("AppSyncClient", "DeleteResolverCommand").sc(schemas_0.DeleteResolver$).build() {
      static {
        __name(this, "DeleteResolverCommand");
      }
    };
    var DeleteTypeCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "DeleteType", {}).n("AppSyncClient", "DeleteTypeCommand").sc(schemas_0.DeleteType$).build() {
      static {
        __name(this, "DeleteTypeCommand");
      }
    };
    var DisassociateApiCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "DisassociateApi", {}).n("AppSyncClient", "DisassociateApiCommand").sc(schemas_0.DisassociateApi$).build() {
      static {
        __name(this, "DisassociateApiCommand");
      }
    };
    var DisassociateMergedGraphqlApiCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "DisassociateMergedGraphqlApi", {}).n("AppSyncClient", "DisassociateMergedGraphqlApiCommand").sc(schemas_0.DisassociateMergedGraphqlApi$).build() {
      static {
        __name(this, "DisassociateMergedGraphqlApiCommand");
      }
    };
    var DisassociateSourceGraphqlApiCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "DisassociateSourceGraphqlApi", {}).n("AppSyncClient", "DisassociateSourceGraphqlApiCommand").sc(schemas_0.DisassociateSourceGraphqlApi$).build() {
      static {
        __name(this, "DisassociateSourceGraphqlApiCommand");
      }
    };
    var EvaluateCodeCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "EvaluateCode", {}).n("AppSyncClient", "EvaluateCodeCommand").sc(schemas_0.EvaluateCode$).build() {
      static {
        __name(this, "EvaluateCodeCommand");
      }
    };
    var EvaluateMappingTemplateCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "EvaluateMappingTemplate", {}).n("AppSyncClient", "EvaluateMappingTemplateCommand").sc(schemas_0.EvaluateMappingTemplate$).build() {
      static {
        __name(this, "EvaluateMappingTemplateCommand");
      }
    };
    var FlushApiCacheCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "FlushApiCache", {}).n("AppSyncClient", "FlushApiCacheCommand").sc(schemas_0.FlushApiCache$).build() {
      static {
        __name(this, "FlushApiCacheCommand");
      }
    };
    var GetApiAssociationCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "GetApiAssociation", {}).n("AppSyncClient", "GetApiAssociationCommand").sc(schemas_0.GetApiAssociation$).build() {
      static {
        __name(this, "GetApiAssociationCommand");
      }
    };
    var GetApiCacheCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "GetApiCache", {}).n("AppSyncClient", "GetApiCacheCommand").sc(schemas_0.GetApiCache$).build() {
      static {
        __name(this, "GetApiCacheCommand");
      }
    };
    var GetApiCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "GetApi", {}).n("AppSyncClient", "GetApiCommand").sc(schemas_0.GetApi$).build() {
      static {
        __name(this, "GetApiCommand");
      }
    };
    var GetChannelNamespaceCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "GetChannelNamespace", {}).n("AppSyncClient", "GetChannelNamespaceCommand").sc(schemas_0.GetChannelNamespace$).build() {
      static {
        __name(this, "GetChannelNamespaceCommand");
      }
    };
    var GetDataSourceCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "GetDataSource", {}).n("AppSyncClient", "GetDataSourceCommand").sc(schemas_0.GetDataSource$).build() {
      static {
        __name(this, "GetDataSourceCommand");
      }
    };
    var GetDataSourceIntrospectionCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "GetDataSourceIntrospection", {}).n("AppSyncClient", "GetDataSourceIntrospectionCommand").sc(schemas_0.GetDataSourceIntrospection$).build() {
      static {
        __name(this, "GetDataSourceIntrospectionCommand");
      }
    };
    var GetDomainNameCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "GetDomainName", {}).n("AppSyncClient", "GetDomainNameCommand").sc(schemas_0.GetDomainName$).build() {
      static {
        __name(this, "GetDomainNameCommand");
      }
    };
    var GetFunctionCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "GetFunction", {}).n("AppSyncClient", "GetFunctionCommand").sc(schemas_0.GetFunction$).build() {
      static {
        __name(this, "GetFunctionCommand");
      }
    };
    var GetGraphqlApiCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "GetGraphqlApi", {}).n("AppSyncClient", "GetGraphqlApiCommand").sc(schemas_0.GetGraphqlApi$).build() {
      static {
        __name(this, "GetGraphqlApiCommand");
      }
    };
    var GetGraphqlApiEnvironmentVariablesCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "GetGraphqlApiEnvironmentVariables", {}).n("AppSyncClient", "GetGraphqlApiEnvironmentVariablesCommand").sc(schemas_0.GetGraphqlApiEnvironmentVariables$).build() {
      static {
        __name(this, "GetGraphqlApiEnvironmentVariablesCommand");
      }
    };
    var GetIntrospectionSchemaCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "GetIntrospectionSchema", {}).n("AppSyncClient", "GetIntrospectionSchemaCommand").sc(schemas_0.GetIntrospectionSchema$).build() {
      static {
        __name(this, "GetIntrospectionSchemaCommand");
      }
    };
    var GetResolverCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "GetResolver", {}).n("AppSyncClient", "GetResolverCommand").sc(schemas_0.GetResolver$).build() {
      static {
        __name(this, "GetResolverCommand");
      }
    };
    var GetSchemaCreationStatusCommand2 = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "GetSchemaCreationStatus", {}).n("AppSyncClient", "GetSchemaCreationStatusCommand").sc(schemas_0.GetSchemaCreationStatus$).build() {
      static {
        __name(this, "GetSchemaCreationStatusCommand");
      }
    };
    var GetSourceApiAssociationCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "GetSourceApiAssociation", {}).n("AppSyncClient", "GetSourceApiAssociationCommand").sc(schemas_0.GetSourceApiAssociation$).build() {
      static {
        __name(this, "GetSourceApiAssociationCommand");
      }
    };
    var GetTypeCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "GetType", {}).n("AppSyncClient", "GetTypeCommand").sc(schemas_0.GetType$).build() {
      static {
        __name(this, "GetTypeCommand");
      }
    };
    var ListApiKeysCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "ListApiKeys", {}).n("AppSyncClient", "ListApiKeysCommand").sc(schemas_0.ListApiKeys$).build() {
      static {
        __name(this, "ListApiKeysCommand");
      }
    };
    var ListApisCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "ListApis", {}).n("AppSyncClient", "ListApisCommand").sc(schemas_0.ListApis$).build() {
      static {
        __name(this, "ListApisCommand");
      }
    };
    var ListChannelNamespacesCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "ListChannelNamespaces", {}).n("AppSyncClient", "ListChannelNamespacesCommand").sc(schemas_0.ListChannelNamespaces$).build() {
      static {
        __name(this, "ListChannelNamespacesCommand");
      }
    };
    var ListDataSourcesCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "ListDataSources", {}).n("AppSyncClient", "ListDataSourcesCommand").sc(schemas_0.ListDataSources$).build() {
      static {
        __name(this, "ListDataSourcesCommand");
      }
    };
    var ListDomainNamesCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "ListDomainNames", {}).n("AppSyncClient", "ListDomainNamesCommand").sc(schemas_0.ListDomainNames$).build() {
      static {
        __name(this, "ListDomainNamesCommand");
      }
    };
    var ListFunctionsCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "ListFunctions", {}).n("AppSyncClient", "ListFunctionsCommand").sc(schemas_0.ListFunctions$).build() {
      static {
        __name(this, "ListFunctionsCommand");
      }
    };
    var ListGraphqlApisCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "ListGraphqlApis", {}).n("AppSyncClient", "ListGraphqlApisCommand").sc(schemas_0.ListGraphqlApis$).build() {
      static {
        __name(this, "ListGraphqlApisCommand");
      }
    };
    var ListResolversByFunctionCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "ListResolversByFunction", {}).n("AppSyncClient", "ListResolversByFunctionCommand").sc(schemas_0.ListResolversByFunction$).build() {
      static {
        __name(this, "ListResolversByFunctionCommand");
      }
    };
    var ListResolversCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "ListResolvers", {}).n("AppSyncClient", "ListResolversCommand").sc(schemas_0.ListResolvers$).build() {
      static {
        __name(this, "ListResolversCommand");
      }
    };
    var ListSourceApiAssociationsCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "ListSourceApiAssociations", {}).n("AppSyncClient", "ListSourceApiAssociationsCommand").sc(schemas_0.ListSourceApiAssociations$).build() {
      static {
        __name(this, "ListSourceApiAssociationsCommand");
      }
    };
    var ListTagsForResourceCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "ListTagsForResource", {}).n("AppSyncClient", "ListTagsForResourceCommand").sc(schemas_0.ListTagsForResource$).build() {
      static {
        __name(this, "ListTagsForResourceCommand");
      }
    };
    var ListTypesByAssociationCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "ListTypesByAssociation", {}).n("AppSyncClient", "ListTypesByAssociationCommand").sc(schemas_0.ListTypesByAssociation$).build() {
      static {
        __name(this, "ListTypesByAssociationCommand");
      }
    };
    var ListTypesCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "ListTypes", {}).n("AppSyncClient", "ListTypesCommand").sc(schemas_0.ListTypes$).build() {
      static {
        __name(this, "ListTypesCommand");
      }
    };
    var PutGraphqlApiEnvironmentVariablesCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "PutGraphqlApiEnvironmentVariables", {}).n("AppSyncClient", "PutGraphqlApiEnvironmentVariablesCommand").sc(schemas_0.PutGraphqlApiEnvironmentVariables$).build() {
      static {
        __name(this, "PutGraphqlApiEnvironmentVariablesCommand");
      }
    };
    var StartDataSourceIntrospectionCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "StartDataSourceIntrospection", {}).n("AppSyncClient", "StartDataSourceIntrospectionCommand").sc(schemas_0.StartDataSourceIntrospection$).build() {
      static {
        __name(this, "StartDataSourceIntrospectionCommand");
      }
    };
    var StartSchemaCreationCommand2 = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "StartSchemaCreation", {}).n("AppSyncClient", "StartSchemaCreationCommand").sc(schemas_0.StartSchemaCreation$).build() {
      static {
        __name(this, "StartSchemaCreationCommand");
      }
    };
    var StartSchemaMergeCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "StartSchemaMerge", {}).n("AppSyncClient", "StartSchemaMergeCommand").sc(schemas_0.StartSchemaMerge$).build() {
      static {
        __name(this, "StartSchemaMergeCommand");
      }
    };
    var TagResourceCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "TagResource", {}).n("AppSyncClient", "TagResourceCommand").sc(schemas_0.TagResource$).build() {
      static {
        __name(this, "TagResourceCommand");
      }
    };
    var UntagResourceCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "UntagResource", {}).n("AppSyncClient", "UntagResourceCommand").sc(schemas_0.UntagResource$).build() {
      static {
        __name(this, "UntagResourceCommand");
      }
    };
    var UpdateApiCacheCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "UpdateApiCache", {}).n("AppSyncClient", "UpdateApiCacheCommand").sc(schemas_0.UpdateApiCache$).build() {
      static {
        __name(this, "UpdateApiCacheCommand");
      }
    };
    var UpdateApiCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "UpdateApi", {}).n("AppSyncClient", "UpdateApiCommand").sc(schemas_0.UpdateApi$).build() {
      static {
        __name(this, "UpdateApiCommand");
      }
    };
    var UpdateApiKeyCommand2 = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "UpdateApiKey", {}).n("AppSyncClient", "UpdateApiKeyCommand").sc(schemas_0.UpdateApiKey$).build() {
      static {
        __name(this, "UpdateApiKeyCommand");
      }
    };
    var UpdateChannelNamespaceCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "UpdateChannelNamespace", {}).n("AppSyncClient", "UpdateChannelNamespaceCommand").sc(schemas_0.UpdateChannelNamespace$).build() {
      static {
        __name(this, "UpdateChannelNamespaceCommand");
      }
    };
    var UpdateDataSourceCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "UpdateDataSource", {}).n("AppSyncClient", "UpdateDataSourceCommand").sc(schemas_0.UpdateDataSource$).build() {
      static {
        __name(this, "UpdateDataSourceCommand");
      }
    };
    var UpdateDomainNameCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "UpdateDomainName", {}).n("AppSyncClient", "UpdateDomainNameCommand").sc(schemas_0.UpdateDomainName$).build() {
      static {
        __name(this, "UpdateDomainNameCommand");
      }
    };
    var UpdateFunctionCommand2 = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "UpdateFunction", {}).n("AppSyncClient", "UpdateFunctionCommand").sc(schemas_0.UpdateFunction$).build() {
      static {
        __name(this, "UpdateFunctionCommand");
      }
    };
    var UpdateGraphqlApiCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "UpdateGraphqlApi", {}).n("AppSyncClient", "UpdateGraphqlApiCommand").sc(schemas_0.UpdateGraphqlApi$).build() {
      static {
        __name(this, "UpdateGraphqlApiCommand");
      }
    };
    var UpdateResolverCommand2 = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "UpdateResolver", {}).n("AppSyncClient", "UpdateResolverCommand").sc(schemas_0.UpdateResolver$).build() {
      static {
        __name(this, "UpdateResolverCommand");
      }
    };
    var UpdateSourceApiAssociationCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "UpdateSourceApiAssociation", {}).n("AppSyncClient", "UpdateSourceApiAssociationCommand").sc(schemas_0.UpdateSourceApiAssociation$).build() {
      static {
        __name(this, "UpdateSourceApiAssociationCommand");
      }
    };
    var UpdateTypeCommand = class extends client.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config3, o10) {
      return [endpoints.getEndpointPlugin(config3, Command3.getEndpointParameterInstructions())];
    }).s("AWSDeepdishControlPlaneService", "UpdateType", {}).n("AppSyncClient", "UpdateTypeCommand").sc(schemas_0.UpdateType$).build() {
      static {
        __name(this, "UpdateTypeCommand");
      }
    };
    var paginateListApiKeys = core.createPaginator(AppSyncClient2, ListApiKeysCommand, "nextToken", "nextToken", "maxResults");
    var paginateListApis = core.createPaginator(AppSyncClient2, ListApisCommand, "nextToken", "nextToken", "maxResults");
    var paginateListChannelNamespaces = core.createPaginator(AppSyncClient2, ListChannelNamespacesCommand, "nextToken", "nextToken", "maxResults");
    var paginateListDataSources = core.createPaginator(AppSyncClient2, ListDataSourcesCommand, "nextToken", "nextToken", "maxResults");
    var paginateListDomainNames = core.createPaginator(AppSyncClient2, ListDomainNamesCommand, "nextToken", "nextToken", "maxResults");
    var paginateListFunctions2 = core.createPaginator(AppSyncClient2, ListFunctionsCommand, "nextToken", "nextToken", "maxResults");
    var paginateListGraphqlApis = core.createPaginator(AppSyncClient2, ListGraphqlApisCommand, "nextToken", "nextToken", "maxResults");
    var paginateListResolversByFunction = core.createPaginator(AppSyncClient2, ListResolversByFunctionCommand, "nextToken", "nextToken", "maxResults");
    var paginateListResolvers = core.createPaginator(AppSyncClient2, ListResolversCommand, "nextToken", "nextToken", "maxResults");
    var paginateListSourceApiAssociations = core.createPaginator(AppSyncClient2, ListSourceApiAssociationsCommand, "nextToken", "nextToken", "maxResults");
    var paginateListTypesByAssociation = core.createPaginator(AppSyncClient2, ListTypesByAssociationCommand, "nextToken", "nextToken", "maxResults");
    var paginateListTypes = core.createPaginator(AppSyncClient2, ListTypesCommand, "nextToken", "nextToken", "maxResults");
    var commands32 = {
      AssociateApiCommand,
      AssociateMergedGraphqlApiCommand,
      AssociateSourceGraphqlApiCommand,
      CreateApiCommand,
      CreateApiCacheCommand,
      CreateApiKeyCommand,
      CreateChannelNamespaceCommand,
      CreateDataSourceCommand,
      CreateDomainNameCommand,
      CreateFunctionCommand,
      CreateGraphqlApiCommand,
      CreateResolverCommand,
      CreateTypeCommand,
      DeleteApiCommand,
      DeleteApiCacheCommand,
      DeleteApiKeyCommand,
      DeleteChannelNamespaceCommand,
      DeleteDataSourceCommand,
      DeleteDomainNameCommand,
      DeleteFunctionCommand,
      DeleteGraphqlApiCommand,
      DeleteResolverCommand,
      DeleteTypeCommand,
      DisassociateApiCommand,
      DisassociateMergedGraphqlApiCommand,
      DisassociateSourceGraphqlApiCommand,
      EvaluateCodeCommand,
      EvaluateMappingTemplateCommand,
      FlushApiCacheCommand,
      GetApiCommand,
      GetApiAssociationCommand,
      GetApiCacheCommand,
      GetChannelNamespaceCommand,
      GetDataSourceCommand,
      GetDataSourceIntrospectionCommand,
      GetDomainNameCommand,
      GetFunctionCommand,
      GetGraphqlApiCommand,
      GetGraphqlApiEnvironmentVariablesCommand,
      GetIntrospectionSchemaCommand,
      GetResolverCommand,
      GetSchemaCreationStatusCommand: GetSchemaCreationStatusCommand2,
      GetSourceApiAssociationCommand,
      GetTypeCommand,
      ListApiKeysCommand,
      ListApisCommand,
      ListChannelNamespacesCommand,
      ListDataSourcesCommand,
      ListDomainNamesCommand,
      ListFunctionsCommand,
      ListGraphqlApisCommand,
      ListResolversCommand,
      ListResolversByFunctionCommand,
      ListSourceApiAssociationsCommand,
      ListTagsForResourceCommand,
      ListTypesCommand,
      ListTypesByAssociationCommand,
      PutGraphqlApiEnvironmentVariablesCommand,
      StartDataSourceIntrospectionCommand,
      StartSchemaCreationCommand: StartSchemaCreationCommand2,
      StartSchemaMergeCommand,
      TagResourceCommand,
      UntagResourceCommand,
      UpdateApiCommand,
      UpdateApiCacheCommand,
      UpdateApiKeyCommand: UpdateApiKeyCommand2,
      UpdateChannelNamespaceCommand,
      UpdateDataSourceCommand,
      UpdateDomainNameCommand,
      UpdateFunctionCommand: UpdateFunctionCommand2,
      UpdateGraphqlApiCommand,
      UpdateResolverCommand: UpdateResolverCommand2,
      UpdateSourceApiAssociationCommand,
      UpdateTypeCommand
    };
    var paginators = {
      paginateListApiKeys,
      paginateListApis,
      paginateListChannelNamespaces,
      paginateListDataSources,
      paginateListDomainNames,
      paginateListFunctions: paginateListFunctions2,
      paginateListGraphqlApis,
      paginateListResolvers,
      paginateListResolversByFunction,
      paginateListSourceApiAssociations,
      paginateListTypes,
      paginateListTypesByAssociation
    };
    var AppSync = class extends AppSyncClient2 {
      static {
        __name(this, "AppSync");
      }
    };
    client.createAggregatedClient(commands32, AppSync, { paginators });
    var AuthenticationType = {
      AMAZON_COGNITO_USER_POOLS: "AMAZON_COGNITO_USER_POOLS",
      API_KEY: "API_KEY",
      AWS_IAM: "AWS_IAM",
      AWS_LAMBDA: "AWS_LAMBDA",
      OPENID_CONNECT: "OPENID_CONNECT"
    };
    var EventLogLevel = {
      ALL: "ALL",
      DEBUG: "DEBUG",
      ERROR: "ERROR",
      INFO: "INFO",
      NONE: "NONE"
    };
    var AssociationStatus = {
      Failed: "FAILED",
      Processing: "PROCESSING",
      Success: "SUCCESS"
    };
    var ApiCachingBehavior = {
      FULL_REQUEST_CACHING: "FULL_REQUEST_CACHING",
      OPERATION_LEVEL_CACHING: "OPERATION_LEVEL_CACHING",
      PER_RESOLVER_CACHING: "PER_RESOLVER_CACHING"
    };
    var CacheHealthMetricsConfig = {
      DISABLED: "DISABLED",
      ENABLED: "ENABLED"
    };
    var ApiCacheStatus = {
      AVAILABLE: "AVAILABLE",
      CREATING: "CREATING",
      DELETING: "DELETING",
      FAILED: "FAILED",
      MODIFYING: "MODIFYING"
    };
    var ApiCacheType = {
      LARGE: "LARGE",
      LARGE_12X: "LARGE_12X",
      LARGE_2X: "LARGE_2X",
      LARGE_4X: "LARGE_4X",
      LARGE_8X: "LARGE_8X",
      MEDIUM: "MEDIUM",
      R4_2XLARGE: "R4_2XLARGE",
      R4_4XLARGE: "R4_4XLARGE",
      R4_8XLARGE: "R4_8XLARGE",
      R4_LARGE: "R4_LARGE",
      R4_XLARGE: "R4_XLARGE",
      SMALL: "SMALL",
      T2_MEDIUM: "T2_MEDIUM",
      T2_SMALL: "T2_SMALL",
      XLARGE: "XLARGE"
    };
    var RuntimeName = {
      APPSYNC_JS: "APPSYNC_JS"
    };
    var BadRequestReason = {
      CODE_ERROR: "CODE_ERROR"
    };
    var MergeType = {
      AUTO_MERGE: "AUTO_MERGE",
      MANUAL_MERGE: "MANUAL_MERGE"
    };
    var SourceApiAssociationStatus = {
      AUTO_MERGE_SCHEDULE_FAILED: "AUTO_MERGE_SCHEDULE_FAILED",
      DELETION_FAILED: "DELETION_FAILED",
      DELETION_IN_PROGRESS: "DELETION_IN_PROGRESS",
      DELETION_SCHEDULED: "DELETION_SCHEDULED",
      MERGE_FAILED: "MERGE_FAILED",
      MERGE_IN_PROGRESS: "MERGE_IN_PROGRESS",
      MERGE_SCHEDULED: "MERGE_SCHEDULED",
      MERGE_SUCCESS: "MERGE_SUCCESS"
    };
    var AuthorizationType = {
      AWS_IAM: "AWS_IAM"
    };
    var HandlerBehavior = {
      CODE: "CODE",
      DIRECT: "DIRECT"
    };
    var InvokeType = {
      EVENT: "EVENT",
      REQUEST_RESPONSE: "REQUEST_RESPONSE"
    };
    var DataSourceLevelMetricsConfig = {
      DISABLED: "DISABLED",
      ENABLED: "ENABLED"
    };
    var RelationalDatabaseSourceType = {
      RDS_HTTP_ENDPOINT: "RDS_HTTP_ENDPOINT"
    };
    var DataSourceType = {
      AMAZON_BEDROCK_RUNTIME: "AMAZON_BEDROCK_RUNTIME",
      AMAZON_DYNAMODB: "AMAZON_DYNAMODB",
      AMAZON_ELASTICSEARCH: "AMAZON_ELASTICSEARCH",
      AMAZON_EVENTBRIDGE: "AMAZON_EVENTBRIDGE",
      AMAZON_OPENSEARCH_SERVICE: "AMAZON_OPENSEARCH_SERVICE",
      AWS_LAMBDA: "AWS_LAMBDA",
      HTTP: "HTTP",
      NONE: "NONE",
      RELATIONAL_DATABASE: "RELATIONAL_DATABASE"
    };
    var ConflictDetectionType = {
      NONE: "NONE",
      VERSION: "VERSION"
    };
    var ConflictHandlerType = {
      AUTOMERGE: "AUTOMERGE",
      LAMBDA: "LAMBDA",
      NONE: "NONE",
      OPTIMISTIC_CONCURRENCY: "OPTIMISTIC_CONCURRENCY"
    };
    var GraphQLApiType = {
      GRAPHQL: "GRAPHQL",
      MERGED: "MERGED"
    };
    var DataSourceLevelMetricsBehavior = {
      FULL_REQUEST_DATA_SOURCE_METRICS: "FULL_REQUEST_DATA_SOURCE_METRICS",
      PER_DATA_SOURCE_METRICS: "PER_DATA_SOURCE_METRICS"
    };
    var OperationLevelMetricsConfig = {
      DISABLED: "DISABLED",
      ENABLED: "ENABLED"
    };
    var ResolverLevelMetricsBehavior = {
      FULL_REQUEST_RESOLVER_METRICS: "FULL_REQUEST_RESOLVER_METRICS",
      PER_RESOLVER_METRICS: "PER_RESOLVER_METRICS"
    };
    var GraphQLApiIntrospectionConfig = {
      DISABLED: "DISABLED",
      ENABLED: "ENABLED"
    };
    var FieldLogLevel = {
      ALL: "ALL",
      DEBUG: "DEBUG",
      ERROR: "ERROR",
      INFO: "INFO",
      NONE: "NONE"
    };
    var DefaultAction = {
      ALLOW: "ALLOW",
      DENY: "DENY"
    };
    var GraphQLApiVisibility = {
      GLOBAL: "GLOBAL",
      PRIVATE: "PRIVATE"
    };
    var ResolverKind = {
      PIPELINE: "PIPELINE",
      UNIT: "UNIT"
    };
    var ResolverLevelMetricsConfig = {
      DISABLED: "DISABLED",
      ENABLED: "ENABLED"
    };
    var TypeDefinitionFormat = {
      JSON: "JSON",
      SDL: "SDL"
    };
    var DataSourceIntrospectionStatus = {
      FAILED: "FAILED",
      PROCESSING: "PROCESSING",
      SUCCESS: "SUCCESS"
    };
    var OutputType = {
      JSON: "JSON",
      SDL: "SDL"
    };
    var SchemaStatus = {
      Active: "ACTIVE",
      Deleting: "DELETING",
      Failed: "FAILED",
      NotApplicable: "NOT_APPLICABLE",
      Processing: "PROCESSING",
      Success: "SUCCESS"
    };
    var Ownership = {
      CURRENT_ACCOUNT: "CURRENT_ACCOUNT",
      OTHER_ACCOUNTS: "OTHER_ACCOUNTS"
    };
    exports2.$Command = client.Command;
    exports2.__Client = client.Client;
    exports2.AppSyncServiceException = AppSyncServiceException.AppSyncServiceException;
    exports2.ApiCacheStatus = ApiCacheStatus;
    exports2.ApiCacheType = ApiCacheType;
    exports2.ApiCachingBehavior = ApiCachingBehavior;
    exports2.AppSync = AppSync;
    exports2.AppSyncClient = AppSyncClient2;
    exports2.AssociateApiCommand = AssociateApiCommand;
    exports2.AssociateMergedGraphqlApiCommand = AssociateMergedGraphqlApiCommand;
    exports2.AssociateSourceGraphqlApiCommand = AssociateSourceGraphqlApiCommand;
    exports2.AssociationStatus = AssociationStatus;
    exports2.AuthenticationType = AuthenticationType;
    exports2.AuthorizationType = AuthorizationType;
    exports2.BadRequestReason = BadRequestReason;
    exports2.CacheHealthMetricsConfig = CacheHealthMetricsConfig;
    exports2.ConflictDetectionType = ConflictDetectionType;
    exports2.ConflictHandlerType = ConflictHandlerType;
    exports2.CreateApiCacheCommand = CreateApiCacheCommand;
    exports2.CreateApiCommand = CreateApiCommand;
    exports2.CreateApiKeyCommand = CreateApiKeyCommand;
    exports2.CreateChannelNamespaceCommand = CreateChannelNamespaceCommand;
    exports2.CreateDataSourceCommand = CreateDataSourceCommand;
    exports2.CreateDomainNameCommand = CreateDomainNameCommand;
    exports2.CreateFunctionCommand = CreateFunctionCommand;
    exports2.CreateGraphqlApiCommand = CreateGraphqlApiCommand;
    exports2.CreateResolverCommand = CreateResolverCommand;
    exports2.CreateTypeCommand = CreateTypeCommand;
    exports2.DataSourceIntrospectionStatus = DataSourceIntrospectionStatus;
    exports2.DataSourceLevelMetricsBehavior = DataSourceLevelMetricsBehavior;
    exports2.DataSourceLevelMetricsConfig = DataSourceLevelMetricsConfig;
    exports2.DataSourceType = DataSourceType;
    exports2.DefaultAction = DefaultAction;
    exports2.DeleteApiCacheCommand = DeleteApiCacheCommand;
    exports2.DeleteApiCommand = DeleteApiCommand;
    exports2.DeleteApiKeyCommand = DeleteApiKeyCommand;
    exports2.DeleteChannelNamespaceCommand = DeleteChannelNamespaceCommand;
    exports2.DeleteDataSourceCommand = DeleteDataSourceCommand;
    exports2.DeleteDomainNameCommand = DeleteDomainNameCommand;
    exports2.DeleteFunctionCommand = DeleteFunctionCommand;
    exports2.DeleteGraphqlApiCommand = DeleteGraphqlApiCommand;
    exports2.DeleteResolverCommand = DeleteResolverCommand;
    exports2.DeleteTypeCommand = DeleteTypeCommand;
    exports2.DisassociateApiCommand = DisassociateApiCommand;
    exports2.DisassociateMergedGraphqlApiCommand = DisassociateMergedGraphqlApiCommand;
    exports2.DisassociateSourceGraphqlApiCommand = DisassociateSourceGraphqlApiCommand;
    exports2.EvaluateCodeCommand = EvaluateCodeCommand;
    exports2.EvaluateMappingTemplateCommand = EvaluateMappingTemplateCommand;
    exports2.EventLogLevel = EventLogLevel;
    exports2.FieldLogLevel = FieldLogLevel;
    exports2.FlushApiCacheCommand = FlushApiCacheCommand;
    exports2.GetApiAssociationCommand = GetApiAssociationCommand;
    exports2.GetApiCacheCommand = GetApiCacheCommand;
    exports2.GetApiCommand = GetApiCommand;
    exports2.GetChannelNamespaceCommand = GetChannelNamespaceCommand;
    exports2.GetDataSourceCommand = GetDataSourceCommand;
    exports2.GetDataSourceIntrospectionCommand = GetDataSourceIntrospectionCommand;
    exports2.GetDomainNameCommand = GetDomainNameCommand;
    exports2.GetFunctionCommand = GetFunctionCommand;
    exports2.GetGraphqlApiCommand = GetGraphqlApiCommand;
    exports2.GetGraphqlApiEnvironmentVariablesCommand = GetGraphqlApiEnvironmentVariablesCommand;
    exports2.GetIntrospectionSchemaCommand = GetIntrospectionSchemaCommand;
    exports2.GetResolverCommand = GetResolverCommand;
    exports2.GetSchemaCreationStatusCommand = GetSchemaCreationStatusCommand2;
    exports2.GetSourceApiAssociationCommand = GetSourceApiAssociationCommand;
    exports2.GetTypeCommand = GetTypeCommand;
    exports2.GraphQLApiIntrospectionConfig = GraphQLApiIntrospectionConfig;
    exports2.GraphQLApiType = GraphQLApiType;
    exports2.GraphQLApiVisibility = GraphQLApiVisibility;
    exports2.HandlerBehavior = HandlerBehavior;
    exports2.InvokeType = InvokeType;
    exports2.ListApiKeysCommand = ListApiKeysCommand;
    exports2.ListApisCommand = ListApisCommand;
    exports2.ListChannelNamespacesCommand = ListChannelNamespacesCommand;
    exports2.ListDataSourcesCommand = ListDataSourcesCommand;
    exports2.ListDomainNamesCommand = ListDomainNamesCommand;
    exports2.ListFunctionsCommand = ListFunctionsCommand;
    exports2.ListGraphqlApisCommand = ListGraphqlApisCommand;
    exports2.ListResolversByFunctionCommand = ListResolversByFunctionCommand;
    exports2.ListResolversCommand = ListResolversCommand;
    exports2.ListSourceApiAssociationsCommand = ListSourceApiAssociationsCommand;
    exports2.ListTagsForResourceCommand = ListTagsForResourceCommand;
    exports2.ListTypesByAssociationCommand = ListTypesByAssociationCommand;
    exports2.ListTypesCommand = ListTypesCommand;
    exports2.MergeType = MergeType;
    exports2.OperationLevelMetricsConfig = OperationLevelMetricsConfig;
    exports2.OutputType = OutputType;
    exports2.Ownership = Ownership;
    exports2.PutGraphqlApiEnvironmentVariablesCommand = PutGraphqlApiEnvironmentVariablesCommand;
    exports2.RelationalDatabaseSourceType = RelationalDatabaseSourceType;
    exports2.ResolverKind = ResolverKind;
    exports2.ResolverLevelMetricsBehavior = ResolverLevelMetricsBehavior;
    exports2.ResolverLevelMetricsConfig = ResolverLevelMetricsConfig;
    exports2.RuntimeName = RuntimeName;
    exports2.SchemaStatus = SchemaStatus;
    exports2.SourceApiAssociationStatus = SourceApiAssociationStatus;
    exports2.StartDataSourceIntrospectionCommand = StartDataSourceIntrospectionCommand;
    exports2.StartSchemaCreationCommand = StartSchemaCreationCommand2;
    exports2.StartSchemaMergeCommand = StartSchemaMergeCommand;
    exports2.TagResourceCommand = TagResourceCommand;
    exports2.TypeDefinitionFormat = TypeDefinitionFormat;
    exports2.UntagResourceCommand = UntagResourceCommand;
    exports2.UpdateApiCacheCommand = UpdateApiCacheCommand;
    exports2.UpdateApiCommand = UpdateApiCommand;
    exports2.UpdateApiKeyCommand = UpdateApiKeyCommand2;
    exports2.UpdateChannelNamespaceCommand = UpdateChannelNamespaceCommand;
    exports2.UpdateDataSourceCommand = UpdateDataSourceCommand;
    exports2.UpdateDomainNameCommand = UpdateDomainNameCommand;
    exports2.UpdateFunctionCommand = UpdateFunctionCommand2;
    exports2.UpdateGraphqlApiCommand = UpdateGraphqlApiCommand;
    exports2.UpdateResolverCommand = UpdateResolverCommand2;
    exports2.UpdateSourceApiAssociationCommand = UpdateSourceApiAssociationCommand;
    exports2.UpdateTypeCommand = UpdateTypeCommand;
    exports2.paginateListApiKeys = paginateListApiKeys;
    exports2.paginateListApis = paginateListApis;
    exports2.paginateListChannelNamespaces = paginateListChannelNamespaces;
    exports2.paginateListDataSources = paginateListDataSources;
    exports2.paginateListDomainNames = paginateListDomainNames;
    exports2.paginateListFunctions = paginateListFunctions2;
    exports2.paginateListGraphqlApis = paginateListGraphqlApis;
    exports2.paginateListResolvers = paginateListResolvers;
    exports2.paginateListResolversByFunction = paginateListResolversByFunction;
    exports2.paginateListSourceApiAssociations = paginateListSourceApiAssociations;
    exports2.paginateListTypes = paginateListTypes;
    exports2.paginateListTypesByAssociation = paginateListTypesByAssociation;
    Object.prototype.hasOwnProperty.call(schemas_0, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: schemas_0["__proto__"]
    });
    Object.keys(schemas_0).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = schemas_0[k32];
    });
    Object.prototype.hasOwnProperty.call(errors, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: errors["__proto__"]
    });
    Object.keys(errors).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = errors[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-bedrock-agentcore-control/dist-cjs/auth/httpAuthSchemeProvider.js
var require_httpAuthSchemeProvider7 = __commonJS({
  "../../node_modules/@aws-sdk/client-bedrock-agentcore-control/dist-cjs/auth/httpAuthSchemeProvider.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.resolveHttpAuthSchemeConfig = exports2.defaultBedrockAgentCoreControlHttpAuthSchemeProvider = exports2.defaultBedrockAgentCoreControlHttpAuthSchemeParametersProvider = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var util_middleware_1 = require_dist_cjs6();
    var defaultBedrockAgentCoreControlHttpAuthSchemeParametersProvider = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, util_middleware_1.getSmithyContext)(context).operation,
        region: await (0, util_middleware_1.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultBedrockAgentCoreControlHttpAuthSchemeParametersProvider");
    exports2.defaultBedrockAgentCoreControlHttpAuthSchemeParametersProvider = defaultBedrockAgentCoreControlHttpAuthSchemeParametersProvider;
    function createAwsAuthSigv4HttpAuthOption32(authParameters) {
      return {
        schemeId: "aws.auth#sigv4",
        signingProperties: {
          name: "bedrock-agentcore",
          region: authParameters.region
        },
        propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
          signingProperties: {
            config: config2,
            context
          }
        }), "propertiesExtractor")
      };
    }
    __name(createAwsAuthSigv4HttpAuthOption32, "createAwsAuthSigv4HttpAuthOption");
    var defaultBedrockAgentCoreControlHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption32(authParameters));
        }
      }
      return options;
    }, "defaultBedrockAgentCoreControlHttpAuthSchemeProvider");
    exports2.defaultBedrockAgentCoreControlHttpAuthSchemeProvider = defaultBedrockAgentCoreControlHttpAuthSchemeProvider;
    var resolveHttpAuthSchemeConfig32 = /* @__PURE__ */ __name((config2) => {
      const config_0 = (0, httpAuthSchemes_1.resolveAwsSdkSigV4Config)(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, util_middleware_1.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
    exports2.resolveHttpAuthSchemeConfig = resolveHttpAuthSchemeConfig32;
  }
});

// ../../node_modules/@aws-sdk/client-bedrock-agentcore-control/package.json
var require_package7 = __commonJS({
  "../../node_modules/@aws-sdk/client-bedrock-agentcore-control/package.json"(exports2, module2) {
    module2.exports = {
      name: "@aws-sdk/client-bedrock-agentcore-control",
      description: "AWS SDK for JavaScript Bedrock Agentcore Control Client for Node.js, Browser and React Native",
      version: "3.1036.0",
      scripts: {
        build: "concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline client-bedrock-agentcore-control",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        "extract:docs": "api-extractor run --local",
        "generate:client": "node ../../scripts/generate-clients/single-service --solo bedrock-agentcore-control",
        "test:index": "tsc --noEmit ./test/index-types.ts && node ./test/index-objects.spec.mjs"
      },
      main: "./dist-cjs/index.js",
      types: "./dist-types/index.d.ts",
      module: "./dist-es/index.js",
      sideEffects: false,
      dependencies: {
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.5",
        "@aws-sdk/credential-provider-node": "^3.972.36",
        "@aws-sdk/middleware-host-header": "^3.972.10",
        "@aws-sdk/middleware-logger": "^3.972.10",
        "@aws-sdk/middleware-recursion-detection": "^3.972.11",
        "@aws-sdk/middleware-user-agent": "^3.972.35",
        "@aws-sdk/region-config-resolver": "^3.972.13",
        "@aws-sdk/types": "^3.973.8",
        "@aws-sdk/util-endpoints": "^3.996.8",
        "@aws-sdk/util-user-agent-browser": "^3.972.10",
        "@aws-sdk/util-user-agent-node": "^3.973.21",
        "@smithy/config-resolver": "^4.4.17",
        "@smithy/core": "^3.23.17",
        "@smithy/fetch-http-handler": "^5.3.17",
        "@smithy/hash-node": "^4.2.14",
        "@smithy/invalid-dependency": "^4.2.14",
        "@smithy/middleware-content-length": "^4.2.14",
        "@smithy/middleware-endpoint": "^4.4.32",
        "@smithy/middleware-retry": "^4.5.5",
        "@smithy/middleware-serde": "^4.2.20",
        "@smithy/middleware-stack": "^4.2.14",
        "@smithy/node-config-provider": "^4.3.14",
        "@smithy/node-http-handler": "^4.6.1",
        "@smithy/protocol-http": "^5.3.14",
        "@smithy/smithy-client": "^4.12.13",
        "@smithy/types": "^4.14.1",
        "@smithy/url-parser": "^4.2.14",
        "@smithy/util-base64": "^4.3.2",
        "@smithy/util-body-length-browser": "^4.2.2",
        "@smithy/util-body-length-node": "^4.2.3",
        "@smithy/util-defaults-mode-browser": "^4.3.49",
        "@smithy/util-defaults-mode-node": "^4.2.54",
        "@smithy/util-endpoints": "^3.4.2",
        "@smithy/util-middleware": "^4.2.14",
        "@smithy/util-retry": "^4.3.4",
        "@smithy/util-utf8": "^4.2.2",
        "@smithy/util-waiter": "^4.2.16",
        tslib: "^2.6.2"
      },
      devDependencies: {
        "@tsconfig/node20": "20.1.8",
        "@types/node": "^20.14.8",
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3"
      },
      engines: {
        node: ">=20.0.0"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "dist-*/**"
      ],
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      browser: {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.browser"
      },
      "react-native": {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.native"
      },
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/clients/client-bedrock-agentcore-control",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "clients/client-bedrock-agentcore-control"
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-bedrock-agentcore-control/dist-cjs/endpoint/bdd.js
var require_bdd7 = __commonJS({
  "../../node_modules/@aws-sdk/client-bedrock-agentcore-control/dist-cjs/endpoint/bdd.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.bdd = void 0;
    var util_endpoints_1 = require_dist_cjs20();
    var k32 = "ref";
    var a32 = -1;
    var b32 = true;
    var c32 = "isSet";
    var d32 = "PartitionResult";
    var e32 = "booleanEquals";
    var f32 = "getAttr";
    var g32 = { [k32]: "Endpoint" };
    var h32 = { [k32]: d32 };
    var i32 = {};
    var j32 = [{ [k32]: "Region" }];
    var _data32 = {
      conditions: [
        [c32, [g32]],
        [c32, j32],
        ["aws.partition", j32, d32],
        [e32, [{ [k32]: "UseFIPS" }, b32]],
        [e32, [{ [k32]: "UseDualStack" }, b32]],
        [e32, [{ fn: f32, argv: [h32, "supportsDualStack"] }, b32]],
        [e32, [{ fn: f32, argv: [h32, "supportsFIPS"] }, b32]]
      ],
      results: [
        [a32],
        [a32, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a32, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [g32, i32],
        ["https://bedrock-agentcore-control-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", i32],
        [a32, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://bedrock-agentcore-control-fips.{Region}.{PartitionResult#dnsSuffix}", i32],
        [a32, "FIPS is enabled but this partition does not support FIPS"],
        ["https://bedrock-agentcore-control.{Region}.{PartitionResult#dualStackDnsSuffix}", i32],
        [a32, "DualStack is enabled but this partition does not support DualStack"],
        ["https://bedrock-agentcore-control.{Region}.{PartitionResult#dnsSuffix}", i32],
        [a32, "Invalid Configuration: Missing Region"]
      ]
    };
    var root32 = 2;
    var r32 = 1e8;
    var nodes32 = new Int32Array([
      -1,
      1,
      -1,
      0,
      12,
      3,
      1,
      4,
      r32 + 11,
      2,
      5,
      r32 + 11,
      3,
      8,
      6,
      4,
      7,
      r32 + 10,
      5,
      r32 + 8,
      r32 + 9,
      4,
      10,
      9,
      6,
      r32 + 6,
      r32 + 7,
      5,
      11,
      r32 + 5,
      6,
      r32 + 4,
      r32 + 5,
      3,
      r32 + 1,
      13,
      4,
      r32 + 2,
      r32 + 3
    ]);
    exports2.bdd = util_endpoints_1.BinaryDecisionDiagram.from(nodes32, root32, _data32.conditions, _data32.results);
  }
});

// ../../node_modules/@aws-sdk/client-bedrock-agentcore-control/dist-cjs/endpoint/endpointResolver.js
var require_endpointResolver7 = __commonJS({
  "../../node_modules/@aws-sdk/client-bedrock-agentcore-control/dist-cjs/endpoint/endpointResolver.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.defaultEndpointResolver = void 0;
    var util_endpoints_1 = require_dist_cjs21();
    var util_endpoints_2 = require_dist_cjs20();
    var bdd_1 = require_bdd7();
    var cache32 = new util_endpoints_2.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    var defaultEndpointResolver32 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache32.get(endpointParams, () => (0, util_endpoints_2.decideEndpoint)(bdd_1.bdd, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    exports2.defaultEndpointResolver = defaultEndpointResolver32;
    util_endpoints_2.customEndpointFunctions.aws = util_endpoints_1.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-bedrock-agentcore-control/dist-cjs/models/BedrockAgentCoreControlServiceException.js
var require_BedrockAgentCoreControlServiceException = __commonJS({
  "../../node_modules/@aws-sdk/client-bedrock-agentcore-control/dist-cjs/models/BedrockAgentCoreControlServiceException.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.BedrockAgentCoreControlServiceException = exports2.__ServiceException = void 0;
    var smithy_client_1 = require_dist_cjs34();
    Object.defineProperty(exports2, "__ServiceException", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return smithy_client_1.ServiceException;
    }, "get") });
    var BedrockAgentCoreControlServiceException = class _BedrockAgentCoreControlServiceException extends smithy_client_1.ServiceException {
      static {
        __name(this, "BedrockAgentCoreControlServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _BedrockAgentCoreControlServiceException.prototype);
      }
    };
    exports2.BedrockAgentCoreControlServiceException = BedrockAgentCoreControlServiceException;
  }
});

// ../../node_modules/@aws-sdk/client-bedrock-agentcore-control/dist-cjs/models/errors.js
var require_errors7 = __commonJS({
  "../../node_modules/@aws-sdk/client-bedrock-agentcore-control/dist-cjs/models/errors.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ConcurrentModificationException = exports2.ThrottledException = exports2.ServiceException = exports2.UnauthorizedException = exports2.ResourceLimitExceededException = exports2.EncryptionFailure = exports2.DecryptionFailure = exports2.ValidationException = exports2.ThrottlingException = exports2.ServiceQuotaExceededException = exports2.ResourceNotFoundException = exports2.InternalServerException = exports2.ConflictException = exports2.AccessDeniedException = void 0;
    var BedrockAgentCoreControlServiceException_1 = require_BedrockAgentCoreControlServiceException();
    var AccessDeniedException13 = class _AccessDeniedException extends BedrockAgentCoreControlServiceException_1.BedrockAgentCoreControlServiceException {
      static {
        __name(this, "AccessDeniedException");
      }
      name = "AccessDeniedException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "AccessDeniedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AccessDeniedException.prototype);
      }
    };
    exports2.AccessDeniedException = AccessDeniedException13;
    var ConflictException = class _ConflictException extends BedrockAgentCoreControlServiceException_1.BedrockAgentCoreControlServiceException {
      static {
        __name(this, "ConflictException");
      }
      name = "ConflictException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ConflictException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ConflictException.prototype);
      }
    };
    exports2.ConflictException = ConflictException;
    var InternalServerException13 = class _InternalServerException extends BedrockAgentCoreControlServiceException_1.BedrockAgentCoreControlServiceException {
      static {
        __name(this, "InternalServerException");
      }
      name = "InternalServerException";
      $fault = "server";
      constructor(opts) {
        super({
          name: "InternalServerException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _InternalServerException.prototype);
      }
    };
    exports2.InternalServerException = InternalServerException13;
    var ResourceNotFoundException12 = class _ResourceNotFoundException extends BedrockAgentCoreControlServiceException_1.BedrockAgentCoreControlServiceException {
      static {
        __name(this, "ResourceNotFoundException");
      }
      name = "ResourceNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ResourceNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceNotFoundException.prototype);
      }
    };
    exports2.ResourceNotFoundException = ResourceNotFoundException12;
    var ServiceQuotaExceededException = class _ServiceQuotaExceededException extends BedrockAgentCoreControlServiceException_1.BedrockAgentCoreControlServiceException {
      static {
        __name(this, "ServiceQuotaExceededException");
      }
      name = "ServiceQuotaExceededException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ServiceQuotaExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ServiceQuotaExceededException.prototype);
      }
    };
    exports2.ServiceQuotaExceededException = ServiceQuotaExceededException;
    var ThrottlingException = class _ThrottlingException extends BedrockAgentCoreControlServiceException_1.BedrockAgentCoreControlServiceException {
      static {
        __name(this, "ThrottlingException");
      }
      name = "ThrottlingException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ThrottlingException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ThrottlingException.prototype);
      }
    };
    exports2.ThrottlingException = ThrottlingException;
    var ValidationException10 = class _ValidationException extends BedrockAgentCoreControlServiceException_1.BedrockAgentCoreControlServiceException {
      static {
        __name(this, "ValidationException");
      }
      name = "ValidationException";
      $fault = "client";
      reason;
      fieldList;
      constructor(opts) {
        super({
          name: "ValidationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ValidationException.prototype);
        this.reason = opts.reason;
        this.fieldList = opts.fieldList;
      }
    };
    exports2.ValidationException = ValidationException10;
    var DecryptionFailure = class _DecryptionFailure extends BedrockAgentCoreControlServiceException_1.BedrockAgentCoreControlServiceException {
      static {
        __name(this, "DecryptionFailure");
      }
      name = "DecryptionFailure";
      $fault = "client";
      constructor(opts) {
        super({
          name: "DecryptionFailure",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DecryptionFailure.prototype);
      }
    };
    exports2.DecryptionFailure = DecryptionFailure;
    var EncryptionFailure = class _EncryptionFailure extends BedrockAgentCoreControlServiceException_1.BedrockAgentCoreControlServiceException {
      static {
        __name(this, "EncryptionFailure");
      }
      name = "EncryptionFailure";
      $fault = "client";
      constructor(opts) {
        super({
          name: "EncryptionFailure",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _EncryptionFailure.prototype);
      }
    };
    exports2.EncryptionFailure = EncryptionFailure;
    var ResourceLimitExceededException = class _ResourceLimitExceededException extends BedrockAgentCoreControlServiceException_1.BedrockAgentCoreControlServiceException {
      static {
        __name(this, "ResourceLimitExceededException");
      }
      name = "ResourceLimitExceededException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ResourceLimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceLimitExceededException.prototype);
      }
    };
    exports2.ResourceLimitExceededException = ResourceLimitExceededException;
    var UnauthorizedException10 = class _UnauthorizedException extends BedrockAgentCoreControlServiceException_1.BedrockAgentCoreControlServiceException {
      static {
        __name(this, "UnauthorizedException");
      }
      name = "UnauthorizedException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "UnauthorizedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnauthorizedException.prototype);
      }
    };
    exports2.UnauthorizedException = UnauthorizedException10;
    var ServiceException4 = class _ServiceException extends BedrockAgentCoreControlServiceException_1.BedrockAgentCoreControlServiceException {
      static {
        __name(this, "ServiceException");
      }
      name = "ServiceException";
      $fault = "server";
      $retryable = {};
      constructor(opts) {
        super({
          name: "ServiceException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _ServiceException.prototype);
      }
    };
    exports2.ServiceException = ServiceException4;
    var ThrottledException = class _ThrottledException extends BedrockAgentCoreControlServiceException_1.BedrockAgentCoreControlServiceException {
      static {
        __name(this, "ThrottledException");
      }
      name = "ThrottledException";
      $fault = "client";
      $retryable = {};
      constructor(opts) {
        super({
          name: "ThrottledException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ThrottledException.prototype);
      }
    };
    exports2.ThrottledException = ThrottledException;
    var ConcurrentModificationException = class _ConcurrentModificationException extends BedrockAgentCoreControlServiceException_1.BedrockAgentCoreControlServiceException {
      static {
        __name(this, "ConcurrentModificationException");
      }
      name = "ConcurrentModificationException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ConcurrentModificationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ConcurrentModificationException.prototype);
      }
    };
    exports2.ConcurrentModificationException = ConcurrentModificationException;
  }
});

// ../../node_modules/@aws-sdk/client-bedrock-agentcore-control/dist-cjs/schemas/schemas_0.js
var require_schemas_07 = __commonJS({
  "../../node_modules/@aws-sdk/client-bedrock-agentcore-control/dist-cjs/schemas/schemas_0.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.CreateAgentRuntimeRequest$ = exports2.CreateAgentRuntimeEndpointResponse$ = exports2.CreateAgentRuntimeEndpointRequest$ = exports2.ContentConfiguration$ = exports2.ContainerConfiguration$ = exports2.CodeInterpreterSummary$ = exports2.CodeInterpreterNetworkConfiguration$ = exports2.CodeConfiguration$ = exports2.CloudWatchOutputConfig$ = exports2.CloudWatchLogsInputConfig$ = exports2.Certificate$ = exports2.CedarPolicy$ = exports2.CategoricalScaleDefinition$ = exports2.BrowserSummary$ = exports2.BrowserSigningConfigOutput$ = exports2.BrowserSigningConfigInput$ = exports2.BrowserProfileSummary$ = exports2.BrowserNetworkConfiguration$ = exports2.BrowserEnterprisePolicy$ = exports2.BedrockEvaluatorModelConfig$ = exports2.AuthorizingClaimMatchValueType$ = exports2.AtlassianOauth2ProviderConfigOutput$ = exports2.AtlassianOauth2ProviderConfigInput$ = exports2.ApprovalConfiguration$ = exports2.ApiKeyCredentialProviderItem$ = exports2.ApiGatewayToolOverride$ = exports2.ApiGatewayToolFilter$ = exports2.ApiGatewayToolConfiguration$ = exports2.ApiGatewayTargetConfiguration$ = exports2.AgentSkillsDescriptor$ = exports2.AgentRuntimeEndpoint$ = exports2.AgentRuntime$ = exports2.AgentCardDefinition$ = exports2.A2aDescriptor$ = exports2.errorTypeRegistries = exports2.ValidationException$ = exports2.UnauthorizedException$ = exports2.ThrottlingException$ = exports2.ThrottledException$ = exports2.ServiceQuotaExceededException$ = exports2.ServiceException$ = exports2.ResourceNotFoundException$ = exports2.ResourceLimitExceededException$ = exports2.InternalServerException$ = exports2.EncryptionFailure$ = exports2.DecryptionFailure$ = exports2.ConflictException$ = exports2.ConcurrentModificationException$ = exports2.AccessDeniedException$ = exports2.BedrockAgentCoreControlServiceException$ = void 0;
    exports2.DeleteBrowserResponse$ = exports2.DeleteBrowserRequest$ = exports2.DeleteBrowserProfileResponse$ = exports2.DeleteBrowserProfileRequest$ = exports2.DeleteApiKeyCredentialProviderResponse$ = exports2.DeleteApiKeyCredentialProviderRequest$ = exports2.DeleteAgentRuntimeResponse$ = exports2.DeleteAgentRuntimeRequest$ = exports2.DeleteAgentRuntimeEndpointResponse$ = exports2.DeleteAgentRuntimeEndpointRequest$ = exports2.CustomOauth2ProviderConfigOutput$ = exports2.CustomOauth2ProviderConfigInput$ = exports2.CustomMemoryStrategyInput$ = exports2.CustomJWTAuthorizerConfiguration$ = exports2.CustomDescriptor$ = exports2.CustomClaimValidationType$ = exports2.CredentialProviderConfiguration$ = exports2.CreateWorkloadIdentityResponse$ = exports2.CreateWorkloadIdentityRequest$ = exports2.CreateRegistryResponse$ = exports2.CreateRegistryRequest$ = exports2.CreateRegistryRecordResponse$ = exports2.CreateRegistryRecordRequest$ = exports2.CreatePolicyResponse$ = exports2.CreatePolicyRequest$ = exports2.CreatePolicyEngineResponse$ = exports2.CreatePolicyEngineRequest$ = exports2.CreateOnlineEvaluationConfigResponse$ = exports2.CreateOnlineEvaluationConfigRequest$ = exports2.CreateOauth2CredentialProviderResponse$ = exports2.CreateOauth2CredentialProviderRequest$ = exports2.CreateMemoryOutput$ = exports2.CreateMemoryInput$ = exports2.CreateHarnessResponse$ = exports2.CreateHarnessRequest$ = exports2.CreateGatewayTargetResponse$ = exports2.CreateGatewayTargetRequest$ = exports2.CreateGatewayResponse$ = exports2.CreateGatewayRequest$ = exports2.CreateEvaluatorResponse$ = exports2.CreateEvaluatorRequest$ = exports2.CreateCodeInterpreterResponse$ = exports2.CreateCodeInterpreterRequest$ = exports2.CreateBrowserResponse$ = exports2.CreateBrowserRequest$ = exports2.CreateBrowserProfileResponse$ = exports2.CreateBrowserProfileRequest$ = exports2.CreateApiKeyCredentialProviderResponse$ = exports2.CreateApiKeyCredentialProviderRequest$ = exports2.CreateAgentRuntimeResponse$ = void 0;
    exports2.GetAgentRuntimeEndpointRequest$ = exports2.GatewayTarget$ = exports2.GatewaySummary$ = exports2.GatewayPolicyEngineConfiguration$ = exports2.GatewayInterceptorConfiguration$ = exports2.GatewayApiKeyCredentialProvider$ = exports2.FromUrlSynchronizationConfiguration$ = exports2.Finding$ = exports2.Filter$ = exports2.EvaluatorSummary$ = exports2.EpisodicReflectionOverride$ = exports2.EpisodicReflectionConfigurationInput$ = exports2.EpisodicReflectionConfiguration$ = exports2.EpisodicOverrideReflectionConfigurationInput$ = exports2.EpisodicOverrideExtractionConfigurationInput$ = exports2.EpisodicOverrideConsolidationConfigurationInput$ = exports2.EpisodicOverrideConfigurationInput$ = exports2.EpisodicMemoryStrategyInput$ = exports2.EpisodicExtractionOverride$ = exports2.EpisodicConsolidationOverride$ = exports2.Descriptors$ = exports2.DeleteWorkloadIdentityResponse$ = exports2.DeleteWorkloadIdentityRequest$ = exports2.DeleteResourcePolicyResponse$ = exports2.DeleteResourcePolicyRequest$ = exports2.DeleteRegistryResponse$ = exports2.DeleteRegistryRequest$ = exports2.DeleteRegistryRecordResponse$ = exports2.DeleteRegistryRecordRequest$ = exports2.DeletePolicyResponse$ = exports2.DeletePolicyRequest$ = exports2.DeletePolicyEngineResponse$ = exports2.DeletePolicyEngineRequest$ = exports2.DeleteOnlineEvaluationConfigResponse$ = exports2.DeleteOnlineEvaluationConfigRequest$ = exports2.DeleteOauth2CredentialProviderResponse$ = exports2.DeleteOauth2CredentialProviderRequest$ = exports2.DeleteMemoryStrategyInput$ = exports2.DeleteMemoryOutput$ = exports2.DeleteMemoryInput$ = exports2.DeleteHarnessResponse$ = exports2.DeleteHarnessRequest$ = exports2.DeleteGatewayTargetResponse$ = exports2.DeleteGatewayTargetRequest$ = exports2.DeleteGatewayResponse$ = exports2.DeleteGatewayRequest$ = exports2.DeleteEvaluatorResponse$ = exports2.DeleteEvaluatorRequest$ = exports2.DeleteCodeInterpreterResponse$ = exports2.DeleteCodeInterpreterRequest$ = void 0;
    exports2.HarnessAgentCoreMemoryConfiguration$ = exports2.HarnessAgentCoreGatewayConfig$ = exports2.HarnessAgentCoreCodeInterpreterConfig$ = exports2.HarnessAgentCoreBrowserConfig$ = exports2.Harness$ = exports2.GoogleOauth2ProviderConfigOutput$ = exports2.GoogleOauth2ProviderConfigInput$ = exports2.GithubOauth2ProviderConfigOutput$ = exports2.GithubOauth2ProviderConfigInput$ = exports2.GetWorkloadIdentityResponse$ = exports2.GetWorkloadIdentityRequest$ = exports2.GetTokenVaultResponse$ = exports2.GetTokenVaultRequest$ = exports2.GetResourcePolicyResponse$ = exports2.GetResourcePolicyRequest$ = exports2.GetRegistryResponse$ = exports2.GetRegistryRequest$ = exports2.GetRegistryRecordResponse$ = exports2.GetRegistryRecordRequest$ = exports2.GetPolicyResponse$ = exports2.GetPolicyRequest$ = exports2.GetPolicyGenerationResponse$ = exports2.GetPolicyGenerationRequest$ = exports2.GetPolicyEngineResponse$ = exports2.GetPolicyEngineRequest$ = exports2.GetOnlineEvaluationConfigResponse$ = exports2.GetOnlineEvaluationConfigRequest$ = exports2.GetOauth2CredentialProviderResponse$ = exports2.GetOauth2CredentialProviderRequest$ = exports2.GetMemoryOutput$ = exports2.GetMemoryInput$ = exports2.GetHarnessResponse$ = exports2.GetHarnessRequest$ = exports2.GetGatewayTargetResponse$ = exports2.GetGatewayTargetRequest$ = exports2.GetGatewayResponse$ = exports2.GetGatewayRequest$ = exports2.GetEvaluatorResponse$ = exports2.GetEvaluatorRequest$ = exports2.GetCodeInterpreterResponse$ = exports2.GetCodeInterpreterRequest$ = exports2.GetBrowserResponse$ = exports2.GetBrowserRequest$ = exports2.GetBrowserProfileResponse$ = exports2.GetBrowserProfileRequest$ = exports2.GetApiKeyCredentialProviderResponse$ = exports2.GetApiKeyCredentialProviderRequest$ = exports2.GetAgentRuntimeResponse$ = exports2.GetAgentRuntimeRequest$ = exports2.GetAgentRuntimeEndpointResponse$ = void 0;
    exports2.ListMemoriesInput$ = exports2.ListHarnessesResponse$ = exports2.ListHarnessesRequest$ = exports2.ListGatewayTargetsResponse$ = exports2.ListGatewayTargetsRequest$ = exports2.ListGatewaysResponse$ = exports2.ListGatewaysRequest$ = exports2.ListEvaluatorsResponse$ = exports2.ListEvaluatorsRequest$ = exports2.ListCodeInterpretersResponse$ = exports2.ListCodeInterpretersRequest$ = exports2.ListBrowsersResponse$ = exports2.ListBrowsersRequest$ = exports2.ListBrowserProfilesResponse$ = exports2.ListBrowserProfilesRequest$ = exports2.ListApiKeyCredentialProvidersResponse$ = exports2.ListApiKeyCredentialProvidersRequest$ = exports2.ListAgentRuntimeVersionsResponse$ = exports2.ListAgentRuntimeVersionsRequest$ = exports2.ListAgentRuntimesResponse$ = exports2.ListAgentRuntimesRequest$ = exports2.ListAgentRuntimeEndpointsResponse$ = exports2.ListAgentRuntimeEndpointsRequest$ = exports2.LinkedinOauth2ProviderConfigOutput$ = exports2.LinkedinOauth2ProviderConfigInput$ = exports2.LifecycleConfiguration$ = exports2.LambdaInterceptorConfiguration$ = exports2.LambdaEvaluatorConfig$ = exports2.KmsConfiguration$ = exports2.KinesisResource$ = exports2.InvocationConfigurationInput$ = exports2.InvocationConfiguration$ = exports2.InterceptorInputConfiguration$ = exports2.InferenceConfiguration$ = exports2.IncludedOauth2ProviderConfigOutput$ = exports2.IncludedOauth2ProviderConfigInput$ = exports2.IamCredentialProvider$ = exports2.HarnessTruncationConfiguration$ = exports2.HarnessTool$ = exports2.HarnessSummary$ = exports2.HarnessSummarizationConfiguration$ = exports2.HarnessSlidingWindowConfiguration$ = exports2.HarnessRemoteMcpConfig$ = exports2.HarnessOpenAiModelConfig$ = exports2.HarnessInlineFunctionConfig$ = exports2.HarnessGeminiModelConfig$ = exports2.HarnessBedrockModelConfig$ = exports2.HarnessAgentCoreRuntimeEnvironmentRequest$ = exports2.HarnessAgentCoreRuntimeEnvironment$ = exports2.HarnessAgentCoreMemoryRetrievalConfig$ = void 0;
    exports2.Policy$ = exports2.OutputConfig$ = exports2.OnlineEvaluationConfigSummary$ = exports2.OAuthCredentialProvider$ = exports2.Oauth2CredentialProviderItem$ = exports2.Oauth2AuthorizationServerMetadata$ = exports2.OAuth2AuthorizationData$ = exports2.NumericalScaleDefinition$ = exports2.NetworkConfiguration$ = exports2.ModifyStrategyConfiguration$ = exports2.ModifySelfManagedConfiguration$ = exports2.ModifyMemoryStrategyInput$ = exports2.ModifyMemoryStrategies$ = exports2.ModifyInvocationConfigurationInput$ = exports2.MicrosoftOauth2ProviderConfigOutput$ = exports2.MicrosoftOauth2ProviderConfigInput$ = exports2.MetadataConfiguration$ = exports2.MessageBasedTriggerInput$ = exports2.MessageBasedTrigger$ = exports2.MemorySummary$ = exports2.MemoryStrategy$ = exports2.Memory$ = exports2.McpServerTargetConfiguration$ = exports2.McpLambdaTargetConfiguration$ = exports2.MCPGatewayConfiguration$ = exports2.McpDescriptor$ = exports2.ManagedResourceDetails$ = exports2.ManagedLatticeResource$ = exports2.LlmAsAJudgeEvaluatorConfig$ = exports2.ListWorkloadIdentitiesResponse$ = exports2.ListWorkloadIdentitiesRequest$ = exports2.ListTagsForResourceResponse$ = exports2.ListTagsForResourceRequest$ = exports2.ListRegistryRecordsResponse$ = exports2.ListRegistryRecordsRequest$ = exports2.ListRegistriesResponse$ = exports2.ListRegistriesRequest$ = exports2.ListPolicyGenerationsResponse$ = exports2.ListPolicyGenerationsRequest$ = exports2.ListPolicyGenerationAssetsResponse$ = exports2.ListPolicyGenerationAssetsRequest$ = exports2.ListPolicyEnginesResponse$ = exports2.ListPolicyEnginesRequest$ = exports2.ListPoliciesResponse$ = exports2.ListPoliciesRequest$ = exports2.ListOnlineEvaluationConfigsResponse$ = exports2.ListOnlineEvaluationConfigsRequest$ = exports2.ListOauth2CredentialProvidersResponse$ = exports2.ListOauth2CredentialProvidersRequest$ = exports2.ListMemoriesOutput$ = void 0;
    exports2.SummaryOverrideConsolidationConfigurationInput$ = exports2.SummaryOverrideConfigurationInput$ = exports2.SummaryMemoryStrategyInput$ = exports2.SummaryConsolidationOverride$ = exports2.SubmitRegistryRecordForApprovalResponse$ = exports2.SubmitRegistryRecordForApprovalRequest$ = exports2.StreamDeliveryResources$ = exports2.StrategyConfiguration$ = exports2.StartPolicyGenerationResponse$ = exports2.StartPolicyGenerationRequest$ = exports2.SlackOauth2ProviderConfigOutput$ = exports2.SlackOauth2ProviderConfigInput$ = exports2.SkillMdDefinition$ = exports2.SkillDefinition$ = exports2.SetTokenVaultCMKResponse$ = exports2.SetTokenVaultCMKRequest$ = exports2.SessionStorageConfiguration$ = exports2.SessionConfig$ = exports2.ServerDefinition$ = exports2.SemanticOverrideExtractionConfigurationInput$ = exports2.SemanticOverrideConsolidationConfigurationInput$ = exports2.SemanticOverrideConfigurationInput$ = exports2.SemanticMemoryStrategyInput$ = exports2.SemanticExtractionOverride$ = exports2.SemanticConsolidationOverride$ = exports2.SelfManagedConfigurationInput$ = exports2.SelfManagedConfiguration$ = exports2.SecretsManagerLocation$ = exports2.Secret$ = exports2.SchemaDefinition$ = exports2.SamplingConfig$ = exports2.SalesforceOauth2ProviderConfigOutput$ = exports2.SalesforceOauth2ProviderConfigInput$ = exports2.S3Location$ = exports2.S3Configuration$ = exports2.RuntimeMetadataConfiguration$ = exports2.Rule$ = exports2.RegistrySummary$ = exports2.RegistryRecordSummary$ = exports2.RegistryRecordOAuthCredentialProvider$ = exports2.RegistryRecordIamCredentialProvider$ = exports2.RegistryRecordCredentialProviderConfiguration$ = exports2.RecordingConfig$ = exports2.PutResourcePolicyResponse$ = exports2.PutResourcePolicyRequest$ = exports2.ProtocolConfiguration$ = exports2.PolicyGenerationDetails$ = exports2.PolicyGenerationAsset$ = exports2.PolicyGeneration$ = exports2.PolicyEngine$ = void 0;
    exports2.UpdateOauth2CredentialProviderRequest$ = exports2.UpdateMemoryOutput$ = exports2.UpdateMemoryInput$ = exports2.UpdateHarnessResponse$ = exports2.UpdateHarnessRequest$ = exports2.UpdateGatewayTargetResponse$ = exports2.UpdateGatewayTargetRequest$ = exports2.UpdateGatewayResponse$ = exports2.UpdateGatewayRequest$ = exports2.UpdateEvaluatorResponse$ = exports2.UpdateEvaluatorRequest$ = exports2.UpdatedToolsDefinition$ = exports2.UpdatedSynchronizationType$ = exports2.UpdatedSynchronizationConfiguration$ = exports2.UpdatedSkillMdDefinition$ = exports2.UpdatedSkillDefinition$ = exports2.UpdatedServerDefinition$ = exports2.UpdatedMcpDescriptorFields$ = exports2.UpdatedMcpDescriptor$ = exports2.UpdatedHarnessMemoryConfiguration$ = exports2.UpdatedHarnessEnvironmentArtifact$ = exports2.UpdatedDescriptorsUnion$ = exports2.UpdatedDescriptors$ = exports2.UpdatedDescription$ = exports2.UpdatedCustomDescriptor$ = exports2.UpdatedAuthorizerConfiguration$ = exports2.UpdatedApprovalConfiguration$ = exports2.UpdatedAgentSkillsDescriptorFields$ = exports2.UpdatedAgentSkillsDescriptor$ = exports2.UpdatedA2aDescriptor$ = exports2.UpdateApiKeyCredentialProviderResponse$ = exports2.UpdateApiKeyCredentialProviderRequest$ = exports2.UpdateAgentRuntimeResponse$ = exports2.UpdateAgentRuntimeRequest$ = exports2.UpdateAgentRuntimeEndpointResponse$ = exports2.UpdateAgentRuntimeEndpointRequest$ = exports2.UntagResourceResponse$ = exports2.UntagResourceRequest$ = exports2.ToolsDefinition$ = exports2.ToolDefinition$ = exports2.TokenBasedTriggerInput$ = exports2.TokenBasedTrigger$ = exports2.TimeBasedTriggerInput$ = exports2.TimeBasedTrigger$ = exports2.TargetSummary$ = exports2.TagResourceResponse$ = exports2.TagResourceRequest$ = exports2.SynchronizeGatewayTargetsResponse$ = exports2.SynchronizeGatewayTargetsRequest$ = exports2.SynchronizationConfiguration$ = void 0;
    exports2.FilterValue$ = exports2.FilesystemConfiguration$ = exports2.ExtractionConfiguration$ = exports2.EvaluatorReference$ = exports2.EvaluatorModelConfig$ = exports2.EvaluatorConfig$ = exports2.DataSourceConfig$ = exports2.CustomReflectionConfigurationInput$ = exports2.CustomReflectionConfiguration$ = exports2.CustomExtractionConfigurationInput$ = exports2.CustomExtractionConfiguration$ = exports2.CustomConsolidationConfigurationInput$ = exports2.CustomConsolidationConfiguration$ = exports2.CustomConfigurationInput$ = exports2.CredentialProvider$ = exports2.Content$ = exports2.ConsolidationConfiguration$ = exports2.CodeBasedEvaluatorConfig$ = exports2.Code$ = exports2.ClaimMatchValueType$ = exports2.CertificateLocation$ = exports2.AuthorizerConfiguration$ = exports2.AuthorizationData$ = exports2.ApiSchemaConfiguration$ = exports2.AgentRuntimeArtifact$ = exports2.WorkloadIdentityType$ = exports2.WorkloadIdentityDetails$ = exports2.VpcConfig$ = exports2.ValidationExceptionField$ = exports2.UserPreferenceOverrideExtractionConfigurationInput$ = exports2.UserPreferenceOverrideConsolidationConfigurationInput$ = exports2.UserPreferenceOverrideConfigurationInput$ = exports2.UserPreferenceMemoryStrategyInput$ = exports2.UserPreferenceExtractionOverride$ = exports2.UserPreferenceConsolidationOverride$ = exports2.UpdateWorkloadIdentityResponse$ = exports2.UpdateWorkloadIdentityRequest$ = exports2.UpdateRegistryResponse$ = exports2.UpdateRegistryRequest$ = exports2.UpdateRegistryRecordStatusResponse$ = exports2.UpdateRegistryRecordStatusRequest$ = exports2.UpdateRegistryRecordResponse$ = exports2.UpdateRegistryRecordRequest$ = exports2.UpdatePolicyResponse$ = exports2.UpdatePolicyRequest$ = exports2.UpdatePolicyEngineResponse$ = exports2.UpdatePolicyEngineRequest$ = exports2.UpdateOnlineEvaluationConfigResponse$ = exports2.UpdateOnlineEvaluationConfigRequest$ = exports2.UpdateOauth2CredentialProviderResponse$ = void 0;
    exports2.CreatePolicyEngine$ = exports2.CreatePolicy$ = exports2.CreateOnlineEvaluationConfig$ = exports2.CreateOauth2CredentialProvider$ = exports2.CreateMemory$ = exports2.CreateHarness$ = exports2.CreateGatewayTarget$ = exports2.CreateGateway$ = exports2.CreateEvaluator$ = exports2.CreateCodeInterpreter$ = exports2.CreateBrowserProfile$ = exports2.CreateBrowser$ = exports2.CreateApiKeyCredentialProvider$ = exports2.CreateAgentRuntimeEndpoint$ = exports2.CreateAgentRuntime$ = exports2.TriggerConditionInput$ = exports2.TriggerCondition$ = exports2.ToolSchema$ = exports2.TargetConfiguration$ = exports2.StreamDeliveryResource$ = exports2.SelfManagedLatticeResource$ = exports2.ResourceLocation$ = exports2.Resource$ = exports2.RequestHeaderConfiguration$ = exports2.RegistryRecordCredentialProviderUnion$ = exports2.ReflectionConfiguration$ = exports2.RatingScale$ = exports2.PrivateEndpoint$ = exports2.PolicyDefinition$ = exports2.Oauth2ProviderConfigOutput$ = exports2.Oauth2ProviderConfigInput$ = exports2.Oauth2Discovery$ = exports2.ModifyReflectionConfiguration$ = exports2.ModifyExtractionConfiguration$ = exports2.ModifyConsolidationConfiguration$ = exports2.MemoryStrategyInput$ = exports2.McpToolSchemaConfiguration$ = exports2.McpTargetConfiguration$ = exports2.InterceptorConfiguration$ = exports2.HarnessTruncationStrategyConfiguration$ = exports2.HarnessToolConfiguration$ = exports2.HarnessSystemContentBlock$ = exports2.HarnessSkill$ = exports2.HarnessModelConfiguration$ = exports2.HarnessMemoryConfiguration$ = exports2.HarnessGatewayOutboundAuth$ = exports2.HarnessEnvironmentProviderRequest$ = exports2.HarnessEnvironmentProvider$ = exports2.HarnessEnvironmentArtifact$ = exports2.GatewayProtocolConfiguration$ = void 0;
    exports2.ListCodeInterpreters$ = exports2.ListBrowsers$ = exports2.ListBrowserProfiles$ = exports2.ListApiKeyCredentialProviders$ = exports2.ListAgentRuntimeVersions$ = exports2.ListAgentRuntimes$ = exports2.ListAgentRuntimeEndpoints$ = exports2.GetWorkloadIdentity$ = exports2.GetTokenVault$ = exports2.GetResourcePolicy$ = exports2.GetRegistryRecord$ = exports2.GetRegistry$ = exports2.GetPolicyGeneration$ = exports2.GetPolicyEngine$ = exports2.GetPolicy$ = exports2.GetOnlineEvaluationConfig$ = exports2.GetOauth2CredentialProvider$ = exports2.GetMemory$ = exports2.GetHarness$ = exports2.GetGatewayTarget$ = exports2.GetGateway$ = exports2.GetEvaluator$ = exports2.GetCodeInterpreter$ = exports2.GetBrowserProfile$ = exports2.GetBrowser$ = exports2.GetApiKeyCredentialProvider$ = exports2.GetAgentRuntimeEndpoint$ = exports2.GetAgentRuntime$ = exports2.DeleteWorkloadIdentity$ = exports2.DeleteResourcePolicy$ = exports2.DeleteRegistryRecord$ = exports2.DeleteRegistry$ = exports2.DeletePolicyEngine$ = exports2.DeletePolicy$ = exports2.DeleteOnlineEvaluationConfig$ = exports2.DeleteOauth2CredentialProvider$ = exports2.DeleteMemory$ = exports2.DeleteHarness$ = exports2.DeleteGatewayTarget$ = exports2.DeleteGateway$ = exports2.DeleteEvaluator$ = exports2.DeleteCodeInterpreter$ = exports2.DeleteBrowserProfile$ = exports2.DeleteBrowser$ = exports2.DeleteApiKeyCredentialProvider$ = exports2.DeleteAgentRuntimeEndpoint$ = exports2.DeleteAgentRuntime$ = exports2.CreateWorkloadIdentity$ = exports2.CreateRegistryRecord$ = exports2.CreateRegistry$ = void 0;
    exports2.UpdateWorkloadIdentity$ = exports2.UpdateRegistryRecordStatus$ = exports2.UpdateRegistryRecord$ = exports2.UpdateRegistry$ = exports2.UpdatePolicyEngine$ = exports2.UpdatePolicy$ = exports2.UpdateOnlineEvaluationConfig$ = exports2.UpdateOauth2CredentialProvider$ = exports2.UpdateMemory$ = exports2.UpdateHarness$ = exports2.UpdateGatewayTarget$ = exports2.UpdateGateway$ = exports2.UpdateEvaluator$ = exports2.UpdateApiKeyCredentialProvider$ = exports2.UpdateAgentRuntimeEndpoint$ = exports2.UpdateAgentRuntime$ = exports2.UntagResource$ = exports2.TagResource$ = exports2.SynchronizeGatewayTargets$ = exports2.SubmitRegistryRecordForApproval$ = exports2.StartPolicyGeneration$ = exports2.SetTokenVaultCMK$ = exports2.PutResourcePolicy$ = exports2.ListWorkloadIdentities$ = exports2.ListTagsForResource$ = exports2.ListRegistryRecords$ = exports2.ListRegistries$ = exports2.ListPolicyGenerations$ = exports2.ListPolicyGenerationAssets$ = exports2.ListPolicyEngines$ = exports2.ListPolicies$ = exports2.ListOnlineEvaluationConfigs$ = exports2.ListOauth2CredentialProviders$ = exports2.ListMemories$ = exports2.ListHarnesses$ = exports2.ListGatewayTargets$ = exports2.ListGateways$ = exports2.ListEvaluators$ = void 0;
    var _AC = "ApprovalConfiguration";
    var _ACD = "AgentCardDefinition";
    var _ACMVT = "AuthorizingClaimMatchValueType";
    var _ACu = "AuthorizerConfiguration";
    var _AD = "A2aDescriptor";
    var _ADE13 = "AccessDeniedException";
    var _ADu = "AuthorizationData";
    var _AGTC = "ApiGatewayTargetConfiguration";
    var _AGTCp = "ApiGatewayToolConfiguration";
    var _AGTF = "ApiGatewayToolFilter";
    var _AGTFp = "ApiGatewayToolFilters";
    var _AGTO = "ApiGatewayToolOverride";
    var _AGTOp = "ApiGatewayToolOverrides";
    var _AKCP = "ApiKeyCredentialProviders";
    var _AKCPI = "ApiKeyCredentialProviderItem";
    var _AKT = "ApiKeyType";
    var _AOPCI = "AtlassianOauth2ProviderConfigInput";
    var _AOPCO = "AtlassianOauth2ProviderConfigOutput";
    var _AR10 = "AgentRuntime";
    var _ARA = "AgentRuntimeArtifact";
    var _ARE = "AgentRuntimeEndpoint";
    var _AREg = "AgentRuntimeEndpoints";
    var _ARg = "AgentRuntimes";
    var _ASC = "ApiSchemaConfiguration";
    var _ASD = "AgentSkillsDescriptor";
    var _BEMC = "BedrockEvaluatorModelConfig";
    var _BEP = "BrowserEnterprisePolicy";
    var _BEPr = "BrowserEnterprisePolicies";
    var _BNC = "BrowserNetworkConfiguration";
    var _BPS = "BrowserProfileSummary";
    var _BPSr = "BrowserProfileSummaries";
    var _BS = "BrowserSummary";
    var _BSCI = "BrowserSigningConfigInput";
    var _BSCO = "BrowserSigningConfigOutput";
    var _BSr = "BrowserSummaries";
    var _C11 = "Certificate";
    var _CAKCP = "CreateApiKeyCredentialProvider";
    var _CAKCPR = "CreateApiKeyCredentialProviderRequest";
    var _CAKCPRr = "CreateApiKeyCredentialProviderResponse";
    var _CAR = "CreateAgentRuntime";
    var _CARE = "CreateAgentRuntimeEndpoint";
    var _CARER = "CreateAgentRuntimeEndpointRequest";
    var _CARERr = "CreateAgentRuntimeEndpointResponse";
    var _CARR = "CreateAgentRuntimeRequest";
    var _CARRr = "CreateAgentRuntimeResponse";
    var _CB = "CreateBrowser";
    var _CBEC = "CodeBasedEvaluatorConfig";
    var _CBP = "CreateBrowserProfile";
    var _CBPR = "CreateBrowserProfileRequest";
    var _CBPRr = "CreateBrowserProfileResponse";
    var _CBR = "CreateBrowserRequest";
    var _CBRr = "CreateBrowserResponse";
    var _CC = "CodeConfiguration";
    var _CCC = "CustomConsolidationConfiguration";
    var _CCCI = "CustomConsolidationConfigurationInput";
    var _CCI = "CustomConfigurationInput";
    var _CCIR = "CreateCodeInterpreterRequest";
    var _CCIRr = "CreateCodeInterpreterResponse";
    var _CCIr = "CreateCodeInterpreter";
    var _CCL = "ContentConfigurationList";
    var _CCVT = "CustomClaimValidationType";
    var _CCVTu = "CustomClaimValidationsType";
    var _CCo = "ContainerConfiguration";
    var _CCon = "ContentConfiguration";
    var _CCons = "ConsolidationConfiguration";
    var _CD = "CustomDescriptor";
    var _CE = "ConflictException";
    var _CEC = "CustomExtractionConfiguration";
    var _CECI = "CustomExtractionConfigurationInput";
    var _CER = "CreateEvaluatorRequest";
    var _CERr = "CreateEvaluatorResponse";
    var _CEr = "CreateEvaluator";
    var _CG = "CreateGateway";
    var _CGR = "CreateGatewayRequest";
    var _CGRr = "CreateGatewayResponse";
    var _CGT = "CreateGatewayTarget";
    var _CGTR = "CreateGatewayTargetRequest";
    var _CGTRr = "CreateGatewayTargetResponse";
    var _CH = "CreateHarness";
    var _CHR = "CreateHarnessRequest";
    var _CHRr = "CreateHarnessResponse";
    var _CINC = "CodeInterpreterNetworkConfiguration";
    var _CIS = "CodeInterpreterSummary";
    var _CISo = "CodeInterpreterSummaries";
    var _CJWTAC = "CustomJWTAuthorizerConfiguration";
    var _CL = "CertificateLocation";
    var _CM = "CreateMemory";
    var _CME = "ConcurrentModificationException";
    var _CMI = "CreateMemoryInput";
    var _CMO = "CreateMemoryOutput";
    var _CMSI = "CustomMemoryStrategyInput";
    var _CMVT = "ClaimMatchValueType";
    var _COCP = "CreateOauth2CredentialProvider";
    var _COCPR = "CreateOauth2CredentialProviderRequest";
    var _COCPRr = "CreateOauth2CredentialProviderResponse";
    var _COEC = "CreateOnlineEvaluationConfig";
    var _COECR = "CreateOnlineEvaluationConfigRequest";
    var _COECRr = "CreateOnlineEvaluationConfigResponse";
    var _COPCI = "CustomOauth2ProviderConfigInput";
    var _COPCO = "CustomOauth2ProviderConfigOutput";
    var _CP = "CedarPolicy";
    var _CPC = "CredentialProviderConfiguration";
    var _CPCr = "CredentialProviderConfigurations";
    var _CPE = "CreatePolicyEngine";
    var _CPER = "CreatePolicyEngineRequest";
    var _CPERr = "CreatePolicyEngineResponse";
    var _CPR = "CreatePolicyRequest";
    var _CPRr = "CreatePolicyResponse";
    var _CPr = "CredentialProvider";
    var _CPre = "CreatePolicy";
    var _CR = "CreateRegistry";
    var _CRC = "CustomReflectionConfiguration";
    var _CRCI = "CustomReflectionConfigurationInput";
    var _CRR = "CreateRegistryRequest";
    var _CRRR = "CreateRegistryRecordRequest";
    var _CRRRr = "CreateRegistryRecordResponse";
    var _CRRr = "CreateRegistryResponse";
    var _CRRre = "CreateRegistryRecord";
    var _CSD = "CategoricalScaleDefinition";
    var _CSDa = "CategoricalScaleDefinitions";
    var _CST = "ClientSecretType";
    var _CWI = "CreateWorkloadIdentity";
    var _CWIR = "CreateWorkloadIdentityRequest";
    var _CWIRr = "CreateWorkloadIdentityResponse";
    var _CWLIC = "CloudWatchLogsInputConfig";
    var _CWOC = "CloudWatchOutputConfig";
    var _Ce = "Certificates";
    var _Co = "Code";
    var _Con = "Content";
    var _D = "Description";
    var _DAKCP = "DeleteApiKeyCredentialProvider";
    var _DAKCPR = "DeleteApiKeyCredentialProviderRequest";
    var _DAKCPRe = "DeleteApiKeyCredentialProviderResponse";
    var _DAR = "DeleteAgentRuntime";
    var _DARE = "DeleteAgentRuntimeEndpoint";
    var _DARER = "DeleteAgentRuntimeEndpointRequest";
    var _DARERe = "DeleteAgentRuntimeEndpointResponse";
    var _DARR = "DeleteAgentRuntimeRequest";
    var _DARRe = "DeleteAgentRuntimeResponse";
    var _DB = "DeleteBrowser";
    var _DBP = "DeleteBrowserProfile";
    var _DBPR = "DeleteBrowserProfileRequest";
    var _DBPRe = "DeleteBrowserProfileResponse";
    var _DBR = "DeleteBrowserRequest";
    var _DBRe = "DeleteBrowserResponse";
    var _DCI = "DeleteCodeInterpreter";
    var _DCIR = "DeleteCodeInterpreterRequest";
    var _DCIRe = "DeleteCodeInterpreterResponse";
    var _DE = "DeleteEvaluator";
    var _DER = "DeleteEvaluatorRequest";
    var _DERe = "DeleteEvaluatorResponse";
    var _DF = "DecryptionFailure";
    var _DG = "DeleteGateway";
    var _DGR = "DeleteGatewayRequest";
    var _DGRe = "DeleteGatewayResponse";
    var _DGT = "DeleteGatewayTarget";
    var _DGTR = "DeleteGatewayTargetRequest";
    var _DGTRe = "DeleteGatewayTargetResponse";
    var _DH = "DeleteHarness";
    var _DHR = "DeleteHarnessRequest";
    var _DHRe = "DeleteHarnessResponse";
    var _DM = "DeleteMemory";
    var _DMI = "DeleteMemoryInput";
    var _DMO = "DeleteMemoryOutput";
    var _DMSI = "DeleteMemoryStrategyInput";
    var _DMSL = "DeleteMemoryStrategiesList";
    var _DOCP = "DeleteOauth2CredentialProvider";
    var _DOCPR = "DeleteOauth2CredentialProviderRequest";
    var _DOCPRe = "DeleteOauth2CredentialProviderResponse";
    var _DOEC = "DeleteOnlineEvaluationConfig";
    var _DOECR = "DeleteOnlineEvaluationConfigRequest";
    var _DOECRe = "DeleteOnlineEvaluationConfigResponse";
    var _DP = "DeletePolicy";
    var _DPE = "DeletePolicyEngine";
    var _DPER = "DeletePolicyEngineRequest";
    var _DPERe = "DeletePolicyEngineResponse";
    var _DPR = "DeletePolicyRequest";
    var _DPRe = "DeletePolicyResponse";
    var _DR = "DeleteRegistry";
    var _DRP = "DeleteResourcePolicy";
    var _DRPR = "DeleteResourcePolicyRequest";
    var _DRPRe = "DeleteResourcePolicyResponse";
    var _DRR = "DeleteRegistryRequest";
    var _DRRR = "DeleteRegistryRecordRequest";
    var _DRRRe = "DeleteRegistryRecordResponse";
    var _DRRe = "DeleteRegistryResponse";
    var _DRRel = "DeleteRegistryRecord";
    var _DSC = "DataSourceConfig";
    var _DWI = "DeleteWorkloadIdentity";
    var _DWIR = "DeleteWorkloadIdentityRequest";
    var _DWIRe = "DeleteWorkloadIdentityResponse";
    var _De = "Descriptors";
    var _EC = "EvaluatorConfig";
    var _ECD = "EvaluationConfigDescription";
    var _ECO = "EpisodicConsolidationOverride";
    var _ECx = "ExtractionConfiguration";
    var _ED = "EvaluatorDescription";
    var _EEO = "EpisodicExtractionOverride";
    var _EF = "EncryptionFailure";
    var _EI10 = "EvaluatorInstructions";
    var _EL = "EvaluatorList";
    var _EMC = "EvaluatorModelConfig";
    var _EMSI = "EpisodicMemoryStrategyInput";
    var _EN = "EndpointName";
    var _EOCCI = "EpisodicOverrideConsolidationConfigurationInput";
    var _EOCI = "EpisodicOverrideConfigurationInput";
    var _EOECI = "EpisodicOverrideExtractionConfigurationInput";
    var _EORCI = "EpisodicOverrideReflectionConfigurationInput";
    var _ER = "EvaluatorReference";
    var _ERC = "EpisodicReflectionConfiguration";
    var _ERCI = "EpisodicReflectionConfigurationInput";
    var _ERO = "EpisodicReflectionOverride";
    var _ES = "EvaluatorSummary";
    var _ESL = "EvaluatorSummaryList";
    var _EVM = "EnvironmentVariablesMap";
    var _F = "Filter";
    var _FC = "FilesystemConfigurations";
    var _FCi = "FilesystemConfiguration";
    var _FL = "FilterList";
    var _FUSC = "FromUrlSynchronizationConfiguration";
    var _FV = "FilterValue";
    var _Fi = "Finding";
    var _Fin = "Findings";
    var _GAKCP = "GatewayApiKeyCredentialProvider";
    var _GAKCPR = "GetApiKeyCredentialProviderRequest";
    var _GAKCPRe = "GetApiKeyCredentialProviderResponse";
    var _GAKCPe = "GetApiKeyCredentialProvider";
    var _GAR = "GetAgentRuntime";
    var _GARE = "GetAgentRuntimeEndpoint";
    var _GARER = "GetAgentRuntimeEndpointRequest";
    var _GARERe = "GetAgentRuntimeEndpointResponse";
    var _GARR = "GetAgentRuntimeRequest";
    var _GARRe = "GetAgentRuntimeResponse";
    var _GB = "GetBrowser";
    var _GBP = "GetBrowserProfile";
    var _GBPR = "GetBrowserProfileRequest";
    var _GBPRe = "GetBrowserProfileResponse";
    var _GBR = "GetBrowserRequest";
    var _GBRe = "GetBrowserResponse";
    var _GCI = "GetCodeInterpreter";
    var _GCIR = "GetCodeInterpreterRequest";
    var _GCIRe = "GetCodeInterpreterResponse";
    var _GD = "GatewayDescription";
    var _GE = "GetEvaluator";
    var _GER = "GetEvaluatorRequest";
    var _GERe = "GetEvaluatorResponse";
    var _GG = "GetGateway";
    var _GGR = "GetGatewayRequest";
    var _GGRe = "GetGatewayResponse";
    var _GGT = "GetGatewayTarget";
    var _GGTR = "GetGatewayTargetRequest";
    var _GGTRe = "GetGatewayTargetResponse";
    var _GH = "GetHarness";
    var _GHR = "GetHarnessRequest";
    var _GHRe = "GetHarnessResponse";
    var _GIC = "GatewayInterceptorConfiguration";
    var _GICa = "GatewayInterceptorConfigurations";
    var _GM = "GetMemory";
    var _GMI = "GetMemoryInput";
    var _GMO = "GetMemoryOutput";
    var _GN = "GatewayName";
    var _GOCP = "GetOauth2CredentialProvider";
    var _GOCPR = "GetOauth2CredentialProviderRequest";
    var _GOCPRe = "GetOauth2CredentialProviderResponse";
    var _GOEC = "GetOnlineEvaluationConfig";
    var _GOECR = "GetOnlineEvaluationConfigRequest";
    var _GOECRe = "GetOnlineEvaluationConfigResponse";
    var _GOPCI = "GithubOauth2ProviderConfigInput";
    var _GOPCIo = "GoogleOauth2ProviderConfigInput";
    var _GOPCO = "GithubOauth2ProviderConfigOutput";
    var _GOPCOo = "GoogleOauth2ProviderConfigOutput";
    var _GP = "GetPolicy";
    var _GPC = "GatewayProtocolConfiguration";
    var _GPE = "GetPolicyEngine";
    var _GPEC = "GatewayPolicyEngineConfiguration";
    var _GPER = "GetPolicyEngineRequest";
    var _GPERe = "GetPolicyEngineResponse";
    var _GPG = "GetPolicyGeneration";
    var _GPGR = "GetPolicyGenerationRequest";
    var _GPGRe = "GetPolicyGenerationResponse";
    var _GPR = "GetPolicyRequest";
    var _GPRe = "GetPolicyResponse";
    var _GR = "GetRegistry";
    var _GRP = "GetResourcePolicy";
    var _GRPR = "GetResourcePolicyRequest";
    var _GRPRe = "GetResourcePolicyResponse";
    var _GRR = "GetRegistryRequest";
    var _GRRR = "GetRegistryRecordRequest";
    var _GRRRe = "GetRegistryRecordResponse";
    var _GRRe = "GetRegistryResponse";
    var _GRRet = "GetRegistryRecord";
    var _GS = "GatewaySummary";
    var _GSa = "GatewaySummaries";
    var _GT = "GatewayTarget";
    var _GTL = "GatewayTargetList";
    var _GTV = "GetTokenVault";
    var _GTVR = "GetTokenVaultRequest";
    var _GTVRe = "GetTokenVaultResponse";
    var _GWI = "GetWorkloadIdentity";
    var _GWIR = "GetWorkloadIdentityRequest";
    var _GWIRe = "GetWorkloadIdentityResponse";
    var _H = "Harness";
    var _HACBC = "HarnessAgentCoreBrowserConfig";
    var _HACCIC = "HarnessAgentCoreCodeInterpreterConfig";
    var _HACGC = "HarnessAgentCoreGatewayConfig";
    var _HACMC = "HarnessAgentCoreMemoryConfiguration";
    var _HACMRC = "HarnessAgentCoreMemoryRetrievalConfig";
    var _HACMRCa = "HarnessAgentCoreMemoryRetrievalConfigs";
    var _HACRE = "HarnessAgentCoreRuntimeEnvironment";
    var _HACRER = "HarnessAgentCoreRuntimeEnvironmentRequest";
    var _HBMC = "HarnessBedrockModelConfig";
    var _HEA = "HarnessEnvironmentArtifact";
    var _HEP = "HarnessEnvironmentProvider";
    var _HEPR = "HarnessEnvironmentProviderRequest";
    var _HGMC = "HarnessGeminiModelConfig";
    var _HGOA = "HarnessGatewayOutboundAuth";
    var _HHM = "HttpHeadersMap";
    var _HIFC = "HarnessInlineFunctionConfig";
    var _HIFD = "HarnessInlineFunctionDescription";
    var _HMC = "HarnessMemoryConfiguration";
    var _HMCa = "HarnessModelConfiguration";
    var _HOAMC = "HarnessOpenAiModelConfig";
    var _HRMC = "HarnessRemoteMcpConfig";
    var _HRMU = "HarnessRemoteMcpUrl";
    var _HS = "HarnessSummary";
    var _HSC = "HarnessSummarizationConfiguration";
    var _HSCB = "HarnessSystemContentBlock";
    var _HSP = "HarnessSystemPrompt";
    var _HSWC = "HarnessSlidingWindowConfiguration";
    var _HSa = "HarnessSkills";
    var _HSar = "HarnessSummaries";
    var _HSarn = "HarnessSkill";
    var _HT = "HarnessTool";
    var _HTC = "HarnessTruncationConfiguration";
    var _HTCa = "HarnessToolConfiguration";
    var _HTSC = "HarnessTruncationStrategyConfiguration";
    var _HTa = "HarnessTools";
    var _IC = "InferenceConfiguration";
    var _ICI = "InvocationConfigurationInput";
    var _ICP = "IamCredentialProvider";
    var _ICn = "InvocationConfiguration";
    var _ICnt = "InterceptorConfiguration";
    var _IIC = "InterceptorInputConfiguration";
    var _IOPCI = "IncludedOauth2ProviderConfigInput";
    var _IOPCO = "IncludedOauth2ProviderConfigOutput";
    var _IP = "InlinePayload";
    var _ISE13 = "InternalServerException";
    var _KC = "KmsConfiguration";
    var _KR = "KinesisResource";
    var _LAAJEC = "LlmAsAJudgeEvaluatorConfig";
    var _LAKCP = "ListApiKeyCredentialProviders";
    var _LAKCPR = "ListApiKeyCredentialProvidersRequest";
    var _LAKCPRi = "ListApiKeyCredentialProvidersResponse";
    var _LAR = "ListAgentRuntimes";
    var _LARE = "ListAgentRuntimeEndpoints";
    var _LARER = "ListAgentRuntimeEndpointsRequest";
    var _LARERi = "ListAgentRuntimeEndpointsResponse";
    var _LARR = "ListAgentRuntimesRequest";
    var _LARRi = "ListAgentRuntimesResponse";
    var _LARV = "ListAgentRuntimeVersions";
    var _LARVR = "ListAgentRuntimeVersionsRequest";
    var _LARVRi = "ListAgentRuntimeVersionsResponse";
    var _LB = "ListBrowsers";
    var _LBP = "ListBrowserProfiles";
    var _LBPR = "ListBrowserProfilesRequest";
    var _LBPRi = "ListBrowserProfilesResponse";
    var _LBR = "ListBrowsersRequest";
    var _LBRi = "ListBrowsersResponse";
    var _LC = "LifecycleConfiguration";
    var _LCI = "ListCodeInterpreters";
    var _LCIR = "ListCodeInterpretersRequest";
    var _LCIRi = "ListCodeInterpretersResponse";
    var _LE = "ListEvaluators";
    var _LEC = "LambdaEvaluatorConfig";
    var _LER = "ListEvaluatorsRequest";
    var _LERi = "ListEvaluatorsResponse";
    var _LG = "ListGateways";
    var _LGR = "ListGatewaysRequest";
    var _LGRi = "ListGatewaysResponse";
    var _LGT = "ListGatewayTargets";
    var _LGTR = "ListGatewayTargetsRequest";
    var _LGTRi = "ListGatewayTargetsResponse";
    var _LH = "ListHarnesses";
    var _LHR = "ListHarnessesRequest";
    var _LHRi = "ListHarnessesResponse";
    var _LIC = "LambdaInterceptorConfiguration";
    var _LM2 = "ListMemories";
    var _LMI = "ListMemoriesInput";
    var _LMO = "ListMemoriesOutput";
    var _LOCP = "ListOauth2CredentialProviders";
    var _LOCPR = "ListOauth2CredentialProvidersRequest";
    var _LOCPRi = "ListOauth2CredentialProvidersResponse";
    var _LOEC = "ListOnlineEvaluationConfigs";
    var _LOECR = "ListOnlineEvaluationConfigsRequest";
    var _LOECRi = "ListOnlineEvaluationConfigsResponse";
    var _LOPCI = "LinkedinOauth2ProviderConfigInput";
    var _LOPCO = "LinkedinOauth2ProviderConfigOutput";
    var _LP = "ListPolicies";
    var _LPE = "ListPolicyEngines";
    var _LPER = "ListPolicyEnginesRequest";
    var _LPERi = "ListPolicyEnginesResponse";
    var _LPG = "ListPolicyGenerations";
    var _LPGA = "ListPolicyGenerationAssets";
    var _LPGAR = "ListPolicyGenerationAssetsRequest";
    var _LPGARi = "ListPolicyGenerationAssetsResponse";
    var _LPGR = "ListPolicyGenerationsRequest";
    var _LPGRi = "ListPolicyGenerationsResponse";
    var _LPR = "ListPoliciesRequest";
    var _LPRi = "ListPoliciesResponse";
    var _LR = "ListRegistries";
    var _LRR = "ListRegistriesRequest";
    var _LRRR = "ListRegistryRecordsRequest";
    var _LRRRi = "ListRegistryRecordsResponse";
    var _LRRi = "ListRegistriesResponse";
    var _LRRis = "ListRegistryRecords";
    var _LTFR = "ListTagsForResource";
    var _LTFRR = "ListTagsForResourceRequest";
    var _LTFRRi = "ListTagsForResourceResponse";
    var _LWI = "ListWorkloadIdentities";
    var _LWIR = "ListWorkloadIdentitiesRequest";
    var _LWIRi = "ListWorkloadIdentitiesResponse";
    var _M = "Memory";
    var _MBT = "MessageBasedTrigger";
    var _MBTI = "MessageBasedTriggerInput";
    var _MC = "MetadataConfiguration";
    var _MCC = "ModifyConsolidationConfiguration";
    var _MCPGC = "MCPGatewayConfiguration";
    var _MD = "McpDescriptor";
    var _MEC = "ModifyExtractionConfiguration";
    var _MICI = "ModifyInvocationConfigurationInput";
    var _MLR = "ManagedLatticeResource";
    var _MLTC = "McpLambdaTargetConfiguration";
    var _MMS = "ModifyMemoryStrategies";
    var _MMSI = "ModifyMemoryStrategyInput";
    var _MMSL = "ModifyMemoryStrategiesList";
    var _MOPCI = "MicrosoftOauth2ProviderConfigInput";
    var _MOPCO = "MicrosoftOauth2ProviderConfigOutput";
    var _MRC = "ModifyReflectionConfiguration";
    var _MRD = "ManagedResourceDetails";
    var _MS = "MemoryStrategy";
    var _MSC = "ModifyStrategyConfiguration";
    var _MSI = "MemoryStrategyInput";
    var _MSIL = "MemoryStrategyInputList";
    var _MSL = "MemoryStrategyList";
    var _MSLe = "MemorySummaryList";
    var _MSMC = "ModifySelfManagedConfiguration";
    var _MSTC = "McpServerTargetConfiguration";
    var _MSe = "MemorySummary";
    var _MTC = "McpTargetConfiguration";
    var _MTSC = "McpToolSchemaConfiguration";
    var _NC = "NetworkConfiguration";
    var _NSD = "NumericalScaleDefinition";
    var _NSDu = "NumericalScaleDefinitions";
    var _OAAD = "OAuth2AuthorizationData";
    var _OACP = "OAuthCredentialProvider";
    var _OACPV = "OAuthCustomParametersValue";
    var _OACPu = "OAuthCustomParameters";
    var _OASM = "Oauth2AuthorizationServerMetadata";
    var _OC = "OutputConfig";
    var _OCP = "Oauth2CredentialProviders";
    var _OCPI = "Oauth2CredentialProviderItem";
    var _OD = "Oauth2Discovery";
    var _OECS = "OnlineEvaluationConfigSummary";
    var _OECSL = "OnlineEvaluationConfigSummaryList";
    var _OPCI = "Oauth2ProviderConfigInput";
    var _OPCO = "Oauth2ProviderConfigOutput";
    var _P10 = "Prompt";
    var _PC10 = "ProtocolConfiguration";
    var _PD = "PolicyDefinition";
    var _PE = "PolicyEngine";
    var _PEMR = "PrivateEndpointManagedResources";
    var _PEo = "PolicyEngines";
    var _PEr = "PrivateEndpoint";
    var _PG = "PolicyGeneration";
    var _PGA = "PolicyGenerationAsset";
    var _PGAo = "PolicyGenerationAssets";
    var _PGD = "PolicyGenerationDetails";
    var _PGo = "PolicyGenerations";
    var _PRP = "PutResourcePolicy";
    var _PRPR = "PutResourcePolicyRequest";
    var _PRPRu = "PutResourcePolicyResponse";
    var _Po = "Policy";
    var _Pol = "Policies";
    var _R = "Rule";
    var _RC10 = "RecordingConfig";
    var _RCe = "ReflectionConfiguration";
    var _RHC = "RequestHeaderConfiguration";
    var _RL = "ResourceLocation";
    var _RLEE = "ResourceLimitExceededException";
    var _RMC = "RuntimeMetadataConfiguration";
    var _RNFE11 = "ResourceNotFoundException";
    var _RRCPC = "RegistryRecordCredentialProviderConfiguration";
    var _RRCPCL = "RegistryRecordCredentialProviderConfigurationList";
    var _RRCPU = "RegistryRecordCredentialProviderUnion";
    var _RRICP = "RegistryRecordIamCredentialProvider";
    var _RROACP = "RegistryRecordOAuthCredentialProvider";
    var _RRS = "RegistryRecordSummary";
    var _RRSL = "RegistryRecordSummaryList";
    var _RS = "RegistrySummary";
    var _RSL = "RegistrySummaryList";
    var _RSa = "RatingScale";
    var _Re = "Resource";
    var _S = "Secret";
    var _SC = "S3Configuration";
    var _SCO = "SemanticConsolidationOverride";
    var _SCOu = "SummaryConsolidationOverride";
    var _SCa = "SamplingConfig";
    var _SCe = "SessionConfig";
    var _SCt = "StrategyConfiguration";
    var _SCy = "SynchronizationConfiguration";
    var _SD = "SchemaDefinition";
    var _SDR = "StreamDeliveryResources";
    var _SDRL = "StreamDeliveryResourcesList";
    var _SDRt = "StreamDeliveryResource";
    var _SDe = "ServerDefinition";
    var _SDk = "SkillDefinition";
    var _SE = "ServiceException";
    var _SEO = "SemanticExtractionOverride";
    var _SGT = "SynchronizeGatewayTargets";
    var _SGTR = "SynchronizeGatewayTargetsRequest";
    var _SGTRy = "SynchronizeGatewayTargetsResponse";
    var _SJ = "SensitiveJson";
    var _SL = "S3Location";
    var _SMC = "SelfManagedConfiguration";
    var _SMCI = "SelfManagedConfigurationInput";
    var _SMD = "SkillMdDefinition";
    var _SML = "SecretsManagerLocation";
    var _SMLR = "SelfManagedLatticeResource";
    var _SMSI = "SemanticMemoryStrategyInput";
    var _SMSIu = "SummaryMemoryStrategyInput";
    var _SOCCI = "SemanticOverrideConsolidationConfigurationInput";
    var _SOCCIu = "SummaryOverrideConsolidationConfigurationInput";
    var _SOCI = "SemanticOverrideConfigurationInput";
    var _SOCIu = "SummaryOverrideConfigurationInput";
    var _SOECI = "SemanticOverrideExtractionConfigurationInput";
    var _SOPCI = "SalesforceOauth2ProviderConfigInput";
    var _SOPCIl = "SlackOauth2ProviderConfigInput";
    var _SOPCO = "SalesforceOauth2ProviderConfigOutput";
    var _SOPCOl = "SlackOauth2ProviderConfigOutput";
    var _SP = "SchemaProperties";
    var _SPG = "StartPolicyGeneration";
    var _SPGR = "StartPolicyGenerationRequest";
    var _SPGRt = "StartPolicyGenerationResponse";
    var _SQEE = "ServiceQuotaExceededException";
    var _SRRFA = "SubmitRegistryRecordForApproval";
    var _SRRFAR = "SubmitRegistryRecordForApprovalRequest";
    var _SRRFARu = "SubmitRegistryRecordForApprovalResponse";
    var _SSC = "SessionStorageConfiguration";
    var _ST11 = "SensitiveText";
    var _STVCMK = "SetTokenVaultCMK";
    var _STVCMKR = "SetTokenVaultCMKRequest";
    var _STVCMKRe = "SetTokenVaultCMKResponse";
    var _TBT = "TimeBasedTrigger";
    var _TBTI = "TimeBasedTriggerInput";
    var _TBTIo = "TokenBasedTriggerInput";
    var _TBTo = "TokenBasedTrigger";
    var _TC10 = "TargetConfiguration";
    var _TCI = "TriggerConditionInput";
    var _TCIL = "TriggerConditionInputList";
    var _TCL = "TriggerConditionsList";
    var _TCr = "TriggerCondition";
    var _TD = "TargetDescription";
    var _TDo = "ToolDefinition";
    var _TDoo = "ToolsDefinition";
    var _TDool = "ToolDefinitions";
    var _TE = "ThrottledException";
    var _TEh = "ThrottlingException";
    var _TN = "TargetName";
    var _TR = "TagResource";
    var _TRR = "TagResourceRequest";
    var _TRRa = "TagResourceResponse";
    var _TS = "TargetSummary";
    var _TSa = "TargetSummaries";
    var _TSo = "ToolSchema";
    var _UAC = "UpdatedApprovalConfiguration";
    var _UACp = "UpdatedAuthorizerConfiguration";
    var _UAD = "UpdatedA2aDescriptor";
    var _UAKCP = "UpdateApiKeyCredentialProvider";
    var _UAKCPR = "UpdateApiKeyCredentialProviderRequest";
    var _UAKCPRp = "UpdateApiKeyCredentialProviderResponse";
    var _UAR = "UpdateAgentRuntime";
    var _UARE = "UpdateAgentRuntimeEndpoint";
    var _UARER = "UpdateAgentRuntimeEndpointRequest";
    var _UARERp = "UpdateAgentRuntimeEndpointResponse";
    var _UARR = "UpdateAgentRuntimeRequest";
    var _UARRp = "UpdateAgentRuntimeResponse";
    var _UASD = "UpdatedAgentSkillsDescriptor";
    var _UASDF = "UpdatedAgentSkillsDescriptorFields";
    var _UCD = "UpdatedCustomDescriptor";
    var _UD = "UpdatedDescription";
    var _UDU = "UpdatedDescriptorsUnion";
    var _UDp = "UpdatedDescriptors";
    var _UE10 = "UnauthorizedException";
    var _UER = "UpdateEvaluatorRequest";
    var _UERp = "UpdateEvaluatorResponse";
    var _UEp = "UpdateEvaluator";
    var _UG = "UpdateGateway";
    var _UGR = "UpdateGatewayRequest";
    var _UGRp = "UpdateGatewayResponse";
    var _UGT = "UpdateGatewayTarget";
    var _UGTR = "UpdateGatewayTargetRequest";
    var _UGTRp = "UpdateGatewayTargetResponse";
    var _UH = "UpdateHarness";
    var _UHEA = "UpdatedHarnessEnvironmentArtifact";
    var _UHMC = "UpdatedHarnessMemoryConfiguration";
    var _UHR = "UpdateHarnessRequest";
    var _UHRp = "UpdateHarnessResponse";
    var _UM = "UpdateMemory";
    var _UMD = "UpdatedMcpDescriptor";
    var _UMDF = "UpdatedMcpDescriptorFields";
    var _UMI = "UpdateMemoryInput";
    var _UMO = "UpdateMemoryOutput";
    var _UOCP = "UpdateOauth2CredentialProvider";
    var _UOCPR = "UpdateOauth2CredentialProviderRequest";
    var _UOCPRp = "UpdateOauth2CredentialProviderResponse";
    var _UOEC = "UpdateOnlineEvaluationConfig";
    var _UOECR = "UpdateOnlineEvaluationConfigRequest";
    var _UOECRp = "UpdateOnlineEvaluationConfigResponse";
    var _UP = "UpdatePolicy";
    var _UPCO = "UserPreferenceConsolidationOverride";
    var _UPE = "UpdatePolicyEngine";
    var _UPEO = "UserPreferenceExtractionOverride";
    var _UPER = "UpdatePolicyEngineRequest";
    var _UPERp = "UpdatePolicyEngineResponse";
    var _UPMSI = "UserPreferenceMemoryStrategyInput";
    var _UPOCCI = "UserPreferenceOverrideConsolidationConfigurationInput";
    var _UPOCI = "UserPreferenceOverrideConfigurationInput";
    var _UPOECI = "UserPreferenceOverrideExtractionConfigurationInput";
    var _UPR = "UpdatePolicyRequest";
    var _UPRp = "UpdatePolicyResponse";
    var _UR = "UntagResource";
    var _URR = "UntagResourceRequest";
    var _URRR = "UpdateRegistryRecordRequest";
    var _URRRp = "UpdateRegistryRecordResponse";
    var _URRS = "UpdateRegistryRecordStatus";
    var _URRSR = "UpdateRegistryRecordStatusRequest";
    var _URRSRp = "UpdateRegistryRecordStatusResponse";
    var _URRn = "UntagResourceResponse";
    var _URRp = "UpdateRegistryRequest";
    var _URRpd = "UpdateRegistryResponse";
    var _URRpda = "UpdateRegistryRecord";
    var _URp = "UpdateRegistry";
    var _USC = "UpdatedSynchronizationConfiguration";
    var _USD = "UpdatedServerDefinition";
    var _USDp = "UpdatedSkillDefinition";
    var _USMD = "UpdatedSkillMdDefinition";
    var _UST = "UpdatedSynchronizationType";
    var _UTD = "UpdatedToolsDefinition";
    var _UWI = "UpdateWorkloadIdentity";
    var _UWIR = "UpdateWorkloadIdentityRequest";
    var _UWIRp = "UpdateWorkloadIdentityResponse";
    var _VC = "VpcConfig";
    var _VE10 = "ValidationException";
    var _VEF = "ValidationExceptionField";
    var _VEFL = "ValidationExceptionFieldList";
    var _WID = "WorkloadIdentityDetails";
    var _WIL = "WorkloadIdentityList";
    var _WIT10 = "WorkloadIdentityType";
    var _a10 = "a2a";
    var _aA = "autoApproval";
    var _aAl = "allowedAudience";
    var _aC = "agentCard";
    var _aCB = "agentCoreBrowser";
    var _aCCI = "agentCoreCodeInterpreter";
    var _aCG = "agentCoreGateway";
    var _aCMC = "agentCoreMemoryConfiguration";
    var _aCMV = "authorizingClaimMatchValue";
    var _aCRE = "agentCoreRuntimeEnvironment";
    var _aCl = "allowedClients";
    var _aCp = "approvalConfiguration";
    var _aCu = "authorizerConfiguration";
    var _aD = "authorizationData";
    var _aE = "authorizationEndpoint";
    var _aG = "apiGateway";
    var _aGTC = "apiGatewayToolConfiguration";
    var _aI10 = "actorId";
    var _aIw = "awsIam";
    var _aK = "apiKey";
    var _aKA = "apiKeyArn";
    var _aKCP = "apiKeyCredentialProvider";
    var _aKSA = "apiKeySecretArn";
    var _aMRF = "additionalModelRequestFields";
    var _aMS = "addMemoryStrategies";
    var _aOPC = "atlassianOauth2ProviderConfig";
    var _aQP = "allowedQueryParameters";
    var _aR = "agentRuntimes";
    var _aRA = "agentRuntimeArn";
    var _aRAg = "agentRuntimeArtifact";
    var _aREA = "agentRuntimeEndpointArn";
    var _aRH = "allowedRequestHeaders";
    var _aRHl = "allowedResponseHeaders";
    var _aRI = "agentRuntimeId";
    var _aRN = "agentRuntimeName";
    var _aRORU = "allowedResourceOauth2ReturnUrls";
    var _aRV = "agentRuntimeVersion";
    var _aS = "allowedScopes";
    var _aSM = "authorizationServerMetadata";
    var _aSg = "agentSkills";
    var _aT22 = "authorizerType";
    var _aTP = "appendToPrompt";
    var _aTl = "allowedTools";
    var _aU = "authorizationUrl";
    var _ar = "arn";
    var _b = "bucket";
    var _bA = "browserArn";
    var _bEMC = "bedrockEvaluatorModelConfig";
    var _bI = "browserId";
    var _bMC = "bedrockModelConfig";
    var _bOAI = "bucketOwnerAccountId";
    var _bS = "browserSigning";
    var _bSr = "browserSummaries";
    var _bV = "booleanValue";
    var _c32 = "client";
    var _cA = "createdAt";
    var _cB = "codeBased";
    var _cC = "customClaims";
    var _cCC = "customConsolidationConfiguration";
    var _cCo = "contentConfigurations";
    var _cCod = "codeConfiguration";
    var _cCon = "containerConfiguration";
    var _cEC = "customExtractionConfiguration";
    var _cI13 = "clientId";
    var _cIA = "codeInterpreterArn";
    var _cII = "codeInterpreterId";
    var _cIS = "codeInterpreterSummaries";
    var _cJWTA = "customJWTAuthorizer";
    var _cL = "credentialLocation";
    var _cMO = "claimMatchOperator";
    var _cMS = "customMemoryStrategy";
    var _cMV = "claimMatchValue";
    var _cOPC = "customOauth2ProviderConfig";
    var _cP = "credentialProvider";
    var _cPA = "credentialProviderArn";
    var _cPC = "credentialProviderConfigurations";
    var _cPN = "credentialParameterName";
    var _cPT = "credentialProviderType";
    var _cPV = "credentialProviderVendor";
    var _cPr = "credentialPrefix";
    var _cPre = "credentialProviders";
    var _cPu = "customParameters";
    var _cRC = "customReflectionConfiguration";
    var _cS4 = "clientSecret";
    var _cSA = "clientSecretArn";
    var _cT = "createdTime";
    var _cTl = "clientToken";
    var _cU = "containerUri";
    var _cUa = "callbackUrl";
    var _cWC = "cloudWatchConfig";
    var _cWL = "cloudWatchLogs";
    var _ca = "categorical";
    var _ce = "certificates";
    var _ced = "cedar";
    var _co13 = "code";
    var _con = "configuration";
    var _conf = "config";
    var _cons = "consolidation";
    var _cont = "content";
    var _cu = "custom";
    var _d = "description";
    var _dMS = "deleteMemoryStrategies";
    var _dRU = "defaultReturnUrl";
    var _dSA = "dataStreamArn";
    var _dSC = "dataSourceConfig";
    var _dT = "descriptorType";
    var _dU = "discoveryUrl";
    var _dV = "doubleValue";
    var _de = "definition";
    var _des = "descriptors";
    var _do = "domain";
    var _e32 = "error";
    var _eA = "evaluatorArn";
    var _eAn = "environmentArtifact";
    var _eC = "evaluatorConfig";
    var _eCO = "episodicConsolidationOverride";
    var _eED = "eventExpiryDuration";
    var _eEO = "episodicExtractionOverride";
    var _eERA = "evaluationExecutionRoleArn";
    var _eI13 = "evaluatorId";
    var _eIAT = "endpointIpAddressType";
    var _eKA = "encryptionKeyArn";
    var _eL = "exceptionLevel";
    var _eMS = "episodicMemoryStrategy";
    var _eN = "endpointName";
    var _eNv = "evaluatorName";
    var _eO = "episodicOverride";
    var _eOC = "enableOnCreate";
    var _eP = "entryPoint";
    var _ePn = "enterprisePolicies";
    var _eRA = "executionRoleArn";
    var _eRC = "episodicReflectionConfiguration";
    var _eRO = "episodicReflectionOverride";
    var _eS = "executionStatus";
    var _eT = "evaluatorType";
    var _eV = "environmentVariables";
    var _en = "enabled";
    var _end = "endpoint";
    var _env = "environment";
    var _ev = "evaluators";
    var _ex10 = "extraction";
    var _f = "findings";
    var _fC = "filesystemConfigurations";
    var _fL = "fieldList";
    var _fP = "filterPath";
    var _fR = "failureReason";
    var _fU = "fromUrl";
    var _fi = "filters";
    var _gA = "gatewayArn";
    var _gI = "gatewayId";
    var _gIa = "gatewayIdentifier";
    var _gMC = "geminiModelConfig";
    var _gOPC = "googleOauth2ProviderConfig";
    var _gOPCi = "githubOauth2ProviderConfig";
    var _gT13 = "grantType";
    var _gU = "gatewayUrl";
    var _h22 = "harness";
    var _hCWS = "historicalContextWindowSize";
    var _hE32 = "httpError";
    var _hI = "harnessId";
    var _hN = "harnessName";
    var _hQ10 = "httpQuery";
    var _ha = "harnesses";
    var _he = "headers";
    var _ht = "http";
    var _i = "id";
    var _iC = "inlineContent";
    var _iCP = "iamCredentialProvider";
    var _iCn = "inferenceConfig";
    var _iCnp = "inputConfiguration";
    var _iCnt = "interceptorConfigurations";
    var _iCnv = "invocationConfiguration";
    var _iF = "inlineFunction";
    var _iOPC = "includedOauth2ProviderConfig";
    var _iP = "interceptionPoints";
    var _iPn = "inlinePayload";
    var _iRST = "idleRuntimeSessionTimeout";
    var _iS = "inputSchema";
    var _iST = "idleSessionTimeout";
    var _iT13 = "idempotencyToken";
    var _iTCN = "inboundTokenClaimName";
    var _iTCVT = "inboundTokenClaimValueType";
    var _in = "interceptor";
    var _ins = "instructions";
    var _is = "issuer";
    var _it = "items";
    var _k = "key";
    var _kC = "kmsConfiguration";
    var _kKA = "kmsKeyArn";
    var _kT = "keyType";
    var _ki = "kinesis";
    var _l = "location";
    var _lA = "lambdaArn";
    var _lAAJ = "llmAsAJudge";
    var _lC = "lifecycleConfiguration";
    var _lCa = "lambdaConfig";
    var _lFM = "lockedForModification";
    var _lGN = "logGroupNames";
    var _lGNo = "logGroupName";
    var _lM = "listingMode";
    var _lMD = "lastModifiedDate";
    var _lOPC = "linkedinOauth2ProviderConfig";
    var _lSA = "lastSavedAt";
    var _lSAa = "lastSynchronizedAt";
    var _lSBI = "lastSavedBrowserId";
    var _lSBSI = "lastSavedBrowserSessionId";
    var _lTIS = "lambdaTimeoutInSeconds";
    var _lUA = "lastUpdatedAt";
    var _lUT = "lastUpdatedTime";
    var _lV = "liveVersion";
    var _la = "label";
    var _lam = "lambda";
    var _le = "level";
    var _m29 = "message";
    var _mBT = "messageBasedTrigger";
    var _mC = "metadataConfiguration";
    var _mCe = "messagesCount";
    var _mCes = "messageCount";
    var _mCo = "modelConfig";
    var _mERA = "memoryExecutionRoleArn";
    var _mI = "modelId";
    var _mIa = "maxIterations";
    var _mIe = "memoryId";
    var _mL = "maxLifetime";
    var _mLR = "managedLatticeResource";
    var _mMS = "modifyMemoryStrategies";
    var _mOPC = "microsoftOauth2ProviderConfig";
    var _mP = "mountPath";
    var _mR = "maxResults";
    var _mS = "memoryStrategies";
    var _mSI = "memoryStrategyId";
    var _mSc = "mcpServer";
    var _mT = "maxTokens";
    var _mTS = "mcpToolSchema";
    var _mVS = "matchValueString";
    var _mVSL = "matchValueStringList";
    var _mc = "mcp";
    var _me = "methods";
    var _mem = "memory";
    var _memo = "memories";
    var _met = "method";
    var _mo = "model";
    var _mod = "mode";
    var _n = "name";
    var _nC = "networkConfiguration";
    var _nM = "networkMode";
    var _nMC = "networkModeConfig";
    var _nT = "namespaceTemplates";
    var _nTe = "nextToken";
    var _na = "namespaces";
    var _no = "none";
    var _nu = "numerical";
    var _o = "operator";
    var _oA = "outboundAuth";
    var _oAMC = "openAiModelConfig";
    var _oAS = "openApiSchema";
    var _oC = "outputConfig";
    var _oCP = "oauthCredentialProvider";
    var _oD = "oauthDiscovery";
    var _oEC = "onlineEvaluationConfigs";
    var _oECA = "onlineEvaluationConfigArn";
    var _oECI = "onlineEvaluationConfigId";
    var _oECN = "onlineEvaluationConfigName";
    var _oPCI = "oauth2ProviderConfigInput";
    var _oPCO = "oauth2ProviderConfigOutput";
    var _oS = "outputSchema";
    var _oV = "optionalValue";
    var _oa = "oauth2";
    var _oau = "oauth";
    var _p = "path";
    var _pA = "profileArn";
    var _pAo = "policyArn";
    var _pAr = "providerArn";
    var _pC = "protocolConfiguration";
    var _pDBN = "payloadDeliveryBucketName";
    var _pE = "privateEndpoint";
    var _pEA = "policyEngineArn";
    var _pEC = "policyEngineConfiguration";
    var _pEI = "policyEngineId";
    var _pEMR = "privateEndpointManagedResources";
    var _pEo = "policyEngines";
    var _pG = "policyGenerations";
    var _pGA = "policyGenerationArn";
    var _pGAI = "policyGenerationAssetId";
    var _pGAo = "policyGenerationAssets";
    var _pGI = "policyGenerationId";
    var _pGo = "policyGeneration";
    var _pI = "profileId";
    var _pIo = "policyId";
    var _pRH = "passRequestHeaders";
    var _pRM = "preserveRecentMessages";
    var _pS = "profileSummaries";
    var _pT = "protocolType";
    var _pV = "protocolVersion";
    var _po = "policy";
    var _pol = "policies";
    var _pr = "prefix";
    var _pro = "properties";
    var _r4 = "reason";
    var _rA = "roleArn";
    var _rAA = "resourceAssociationArn";
    var _rAI = "restApiId";
    var _rAe = "recordArn";
    var _rAeg = "registryArn";
    var _rAes = "resourceArn";
    var _rC10 = "reflectionConfiguration";
    var _rCI = "resourceConfigurationIdentifier";
    var _rCe = "retrievalConfig";
    var _rD = "routingDomain";
    var _rE = "runtimeEndpoints";
    var _rGA = "resourceGatewayArn";
    var _rHA = "requestHeaderAllowlist";
    var _rHC = "requestHeaderConfiguration";
    var _rI = "registryId";
    var _rIe = "recordId";
    var _rM = "remoteMcp";
    var _rMMDSV = "requireMMDSV2";
    var _rP = "resourcePriority";
    var _rR = "registryRecords";
    var _rS = "relevanceScore";
    var _rSa = "ratingScale";
    var _rT13 = "responseTypes";
    var _rTF = "rawTextFragment";
    var _rTa = "rawText";
    var _rV = "recordVersion";
    var _re = "recording";
    var _ref = "reflection";
    var _reg = "region";
    var _regi = "registries";
    var _req = "required";
    var _res = "resource";
    var _reso = "resources";
    var _ru = "runtime";
    var _rul = "rule";
    var _s32 = "smithy.ts.sdk.synthetic.com.amazonaws.bedrockagentcorecontrol";
    var _sA = "secretArn";
    var _sC = "synchronizationConfiguration";
    var _sCO = "semanticConsolidationOverride";
    var _sCOu = "summaryConsolidationOverride";
    var _sCa = "samplingConfig";
    var _sCe = "sessionConfig";
    var _sD = "skillDefinition";
    var _sDR = "streamDeliveryResources";
    var _sEO = "semanticExtractionOverride";
    var _sG = "securityGroups";
    var _sGI = "securityGroupIds";
    var _sI = "strategyId";
    var _sIu = "subnetIds";
    var _sL = "s3Location";
    var _sM = "skillMd";
    var _sMC = "selfManagedConfiguration";
    var _sMLR = "selfManagedLatticeResource";
    var _sMS = "semanticMemoryStrategy";
    var _sMSu = "summaryMemoryStrategy";
    var _sMe = "secretsManager";
    var _sMm = "smithyModel";
    var _sN = "serviceNames";
    var _sO = "semanticOverride";
    var _sOPC = "slackOauth2ProviderConfig";
    var _sOPCa = "salesforceOauth2ProviderConfig";
    var _sOu = "summaryOverride";
    var _sP = "systemPrompt";
    var _sPa = "samplingPercentage";
    var _sPe = "serverProtocol";
    var _sR = "statusReasons";
    var _sRt = "statusReason";
    var _sRu = "summaryRatio";
    var _sS = "stopSequences";
    var _sSP = "summarizationSystemPrompt";
    var _sSe = "sessionStorage";
    var _sT19 = "synchronizationType";
    var _sTM = "sessionTimeoutMinutes";
    var _sTe = "searchType";
    var _sV = "schemaVersion";
    var _sVt = "stringValue";
    var _sVu = "supportedVersions";
    var _sW = "slidingWindow";
    var _s_ = "s3";
    var _sc4 = "scopes";
    var _se14 = "server";
    var _ser = "service";
    var _sk = "skills";
    var _st = "status";
    var _sta = "stage";
    var _stat = "statement";
    var _str = "strategy";
    var _stra = "strategies";
    var _su = "subnets";
    var _sum = "summarization";
    var _t = "type";
    var _tA = "topicArn";
    var _tBT = "tokenBasedTrigger";
    var _tBTi = "timeBasedTrigger";
    var _tC = "targetConfiguration";
    var _tCo = "tokenCount";
    var _tCr = "triggerConditions";
    var _tE = "tokenEndpoint";
    var _tEAM = "tokenEndpointAuthMethods";
    var _tF = "toolFilters";
    var _tI10 = "targetId";
    var _tIL = "targetIdList";
    var _tIe = "tenantId";
    var _tK = "topK";
    var _tKa = "tagKeys";
    var _tO10 = "toolOverrides";
    var _tP = "topP";
    var _tRS = "targetResourceScope";
    var _tS = "timeoutSeconds";
    var _tSo = "toolSchema";
    var _tSr = "triggerSynchronization";
    var _tV = "targetVersion";
    var _tVI = "tokenVaultId";
    var _ta = "tags";
    var _tar = "targets";
    var _te = "temperature";
    var _tex = "text";
    var _to = "tools";
    var _tr = "truncation";
    var _u = "url";
    var _uA = "updatedAt";
    var _uI = "userId";
    var _uPCO = "userPreferenceConsolidationOverride";
    var _uPEO = "userPreferenceExtractionOverride";
    var _uPMS = "userPreferenceMemoryStrategy";
    var _uPO = "userPreferenceOverride";
    var _ur = "uri";
    var _v = "value";
    var _vC = "vpcConfig";
    var _vI = "vpcIdentifier";
    var _vIe = "versionId";
    var _vM = "validationMode";
    var _ve = "version";
    var _vi = "view";
    var _wI = "workloadIdentities";
    var _wIA = "workloadIdentityArn";
    var _wID = "workloadIdentityDetails";
    var n032 = "com.amazonaws.bedrockagentcorecontrol";
    var schema_1 = (init_schema4(), __toCommonJS(schema_exports));
    var BedrockAgentCoreControlServiceException_1 = require_BedrockAgentCoreControlServiceException();
    var errors_1 = require_errors7();
    var _s_registry32 = schema_1.TypeRegistry.for(_s32);
    exports2.BedrockAgentCoreControlServiceException$ = [-3, _s32, "BedrockAgentCoreControlServiceException", 0, [], []];
    _s_registry32.registerError(exports2.BedrockAgentCoreControlServiceException$, BedrockAgentCoreControlServiceException_1.BedrockAgentCoreControlServiceException);
    var n0_registry32 = schema_1.TypeRegistry.for(n032);
    exports2.AccessDeniedException$ = [
      -3,
      n032,
      _ADE13,
      { [_e32]: _c32, [_hE32]: 403 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.AccessDeniedException$, errors_1.AccessDeniedException);
    exports2.ConcurrentModificationException$ = [
      -3,
      n032,
      _CME,
      { [_e32]: _c32, [_hE32]: 409 },
      [_m29],
      [0],
      1
    ];
    n0_registry32.registerError(exports2.ConcurrentModificationException$, errors_1.ConcurrentModificationException);
    exports2.ConflictException$ = [
      -3,
      n032,
      _CE,
      { [_e32]: _c32, [_hE32]: 409 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ConflictException$, errors_1.ConflictException);
    exports2.DecryptionFailure$ = [
      -3,
      n032,
      _DF,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0],
      1
    ];
    n0_registry32.registerError(exports2.DecryptionFailure$, errors_1.DecryptionFailure);
    exports2.EncryptionFailure$ = [
      -3,
      n032,
      _EF,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0],
      1
    ];
    n0_registry32.registerError(exports2.EncryptionFailure$, errors_1.EncryptionFailure);
    exports2.InternalServerException$ = [
      -3,
      n032,
      _ISE13,
      { [_e32]: _se14, [_hE32]: 500 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InternalServerException$, errors_1.InternalServerException);
    exports2.ResourceLimitExceededException$ = [
      -3,
      n032,
      _RLEE,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ResourceLimitExceededException$, errors_1.ResourceLimitExceededException);
    exports2.ResourceNotFoundException$ = [
      -3,
      n032,
      _RNFE11,
      { [_e32]: _c32, [_hE32]: 404 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ResourceNotFoundException$, errors_1.ResourceNotFoundException);
    exports2.ServiceException$ = [
      -3,
      n032,
      _SE,
      { [_e32]: _se14, [_hE32]: 500 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ServiceException$, errors_1.ServiceException);
    exports2.ServiceQuotaExceededException$ = [
      -3,
      n032,
      _SQEE,
      { [_e32]: _c32, [_hE32]: 402 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ServiceQuotaExceededException$, errors_1.ServiceQuotaExceededException);
    exports2.ThrottledException$ = [
      -3,
      n032,
      _TE,
      { [_e32]: _c32, [_hE32]: 429 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ThrottledException$, errors_1.ThrottledException);
    exports2.ThrottlingException$ = [
      -3,
      n032,
      _TEh,
      { [_e32]: _c32, [_hE32]: 429 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ThrottlingException$, errors_1.ThrottlingException);
    exports2.UnauthorizedException$ = [
      -3,
      n032,
      _UE10,
      { [_e32]: _c32, [_hE32]: 401 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.UnauthorizedException$, errors_1.UnauthorizedException);
    exports2.ValidationException$ = [
      -3,
      n032,
      _VE10,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29, _r4, _fL],
      [0, 0, () => ValidationExceptionFieldList],
      2
    ];
    n0_registry32.registerError(exports2.ValidationException$, errors_1.ValidationException);
    exports2.errorTypeRegistries = [
      _s_registry32,
      n0_registry32
    ];
    var ApiKeyType = [0, n032, _AKT, 8, 0];
    var ClientSecretType = [0, n032, _CST, 8, 0];
    var Description = [0, n032, _D, 8, 0];
    var EndpointName = [0, n032, _EN, 8, 0];
    var EvaluationConfigDescription = [0, n032, _ECD, 8, 0];
    var EvaluatorDescription = [0, n032, _ED, 8, 0];
    var EvaluatorInstructions = [0, n032, _EI10, 8, 0];
    var GatewayDescription = [0, n032, _GD, 8, 0];
    var GatewayName = [0, n032, _GN, 8, 0];
    var HarnessInlineFunctionDescription = [0, n032, _HIFD, 8, 0];
    var HarnessRemoteMcpUrl = [0, n032, _HRMU, 8, 0];
    var InlinePayload = [0, n032, _IP, 8, 0];
    var OAuthCustomParametersValue = [0, n032, _OACPV, 8, 0];
    var Prompt = [0, n032, _P10, 8, 0];
    var SensitiveJson = [0, n032, _SJ, 8, 15];
    var SensitiveText = [0, n032, _ST11, 8, 0];
    var TargetDescription = [0, n032, _TD, 8, 0];
    var TargetName = [0, n032, _TN, 8, 0];
    exports2.A2aDescriptor$ = [
      3,
      n032,
      _AD,
      0,
      [_aC],
      [() => exports2.AgentCardDefinition$]
    ];
    exports2.AgentCardDefinition$ = [
      3,
      n032,
      _ACD,
      0,
      [_sV, _iC],
      [0, 0]
    ];
    exports2.AgentRuntime$ = [
      3,
      n032,
      _AR10,
      0,
      [_aRA, _aRI, _aRV, _aRN, _d, _lUA, _st],
      [0, 0, 0, 0, [() => Description, 0], 5, 0],
      7
    ];
    exports2.AgentRuntimeEndpoint$ = [
      3,
      n032,
      _ARE,
      0,
      [_n, _aREA, _aRA, _st, _i, _cA, _lUA, _lV, _tV, _d],
      [[() => EndpointName, 0], 0, 0, 0, 0, 5, 5, 0, 0, 0],
      7
    ];
    exports2.AgentSkillsDescriptor$ = [
      3,
      n032,
      _ASD,
      0,
      [_sM, _sD],
      [() => exports2.SkillMdDefinition$, () => exports2.SkillDefinition$]
    ];
    exports2.ApiGatewayTargetConfiguration$ = [
      3,
      n032,
      _AGTC,
      0,
      [_rAI, _sta, _aGTC],
      [0, 0, () => exports2.ApiGatewayToolConfiguration$],
      3
    ];
    exports2.ApiGatewayToolConfiguration$ = [
      3,
      n032,
      _AGTCp,
      0,
      [_tF, _tO10],
      [() => ApiGatewayToolFilters, () => ApiGatewayToolOverrides],
      1
    ];
    exports2.ApiGatewayToolFilter$ = [
      3,
      n032,
      _AGTF,
      0,
      [_fP, _me],
      [0, 64 | 0],
      2
    ];
    exports2.ApiGatewayToolOverride$ = [
      3,
      n032,
      _AGTO,
      0,
      [_n, _p, _met, _d],
      [0, 0, 0, 0],
      3
    ];
    exports2.ApiKeyCredentialProviderItem$ = [
      3,
      n032,
      _AKCPI,
      0,
      [_n, _cPA, _cT, _lUT],
      [0, 0, 4, 4],
      4
    ];
    exports2.ApprovalConfiguration$ = [
      3,
      n032,
      _AC,
      0,
      [_aA],
      [2]
    ];
    exports2.AtlassianOauth2ProviderConfigInput$ = [
      3,
      n032,
      _AOPCI,
      0,
      [_cI13, _cS4],
      [0, [() => ClientSecretType, 0]],
      2
    ];
    exports2.AtlassianOauth2ProviderConfigOutput$ = [
      3,
      n032,
      _AOPCO,
      0,
      [_oD, _cI13],
      [() => exports2.Oauth2Discovery$, 0],
      1
    ];
    exports2.AuthorizingClaimMatchValueType$ = [
      3,
      n032,
      _ACMVT,
      0,
      [_cMV, _cMO],
      [() => exports2.ClaimMatchValueType$, 0],
      2
    ];
    exports2.BedrockEvaluatorModelConfig$ = [
      3,
      n032,
      _BEMC,
      0,
      [_mI, _iCn, _aMRF],
      [0, () => exports2.InferenceConfiguration$, 15],
      1
    ];
    exports2.BrowserEnterprisePolicy$ = [
      3,
      n032,
      _BEP,
      0,
      [_l, _t],
      [() => exports2.ResourceLocation$, 0],
      1
    ];
    exports2.BrowserNetworkConfiguration$ = [
      3,
      n032,
      _BNC,
      0,
      [_nM, _vC],
      [0, () => exports2.VpcConfig$],
      1
    ];
    exports2.BrowserProfileSummary$ = [
      3,
      n032,
      _BPS,
      0,
      [_pI, _pA, _n, _st, _cA, _lUA, _d, _lSA, _lSBSI, _lSBI],
      [0, 0, 0, 0, 5, 5, [() => Description, 0], 5, 0, 0],
      6
    ];
    exports2.BrowserSigningConfigInput$ = [
      3,
      n032,
      _BSCI,
      0,
      [_en],
      [2],
      1
    ];
    exports2.BrowserSigningConfigOutput$ = [
      3,
      n032,
      _BSCO,
      0,
      [_en],
      [2],
      1
    ];
    exports2.BrowserSummary$ = [
      3,
      n032,
      _BS,
      0,
      [_bI, _bA, _st, _cA, _n, _d, _lUA],
      [0, 0, 0, 5, 0, [() => Description, 0], 5],
      4
    ];
    exports2.CategoricalScaleDefinition$ = [
      3,
      n032,
      _CSD,
      0,
      [_de, _la],
      [0, 0],
      2
    ];
    exports2.CedarPolicy$ = [
      3,
      n032,
      _CP,
      0,
      [_stat],
      [0],
      1
    ];
    exports2.Certificate$ = [
      3,
      n032,
      _C11,
      0,
      [_l],
      [() => exports2.CertificateLocation$],
      1
    ];
    exports2.CloudWatchLogsInputConfig$ = [
      3,
      n032,
      _CWLIC,
      0,
      [_lGN, _sN],
      [64 | 0, 64 | 0],
      2
    ];
    exports2.CloudWatchOutputConfig$ = [
      3,
      n032,
      _CWOC,
      0,
      [_lGNo],
      [0],
      1
    ];
    exports2.CodeConfiguration$ = [
      3,
      n032,
      _CC,
      0,
      [_co13, _ru, _eP],
      [() => exports2.Code$, 0, 64 | 0],
      3
    ];
    exports2.CodeInterpreterNetworkConfiguration$ = [
      3,
      n032,
      _CINC,
      0,
      [_nM, _vC],
      [0, () => exports2.VpcConfig$],
      1
    ];
    exports2.CodeInterpreterSummary$ = [
      3,
      n032,
      _CIS,
      0,
      [_cII, _cIA, _st, _cA, _n, _d, _lUA],
      [0, 0, 0, 5, 0, [() => Description, 0], 5],
      4
    ];
    exports2.ContainerConfiguration$ = [
      3,
      n032,
      _CCo,
      0,
      [_cU],
      [0],
      1
    ];
    exports2.ContentConfiguration$ = [
      3,
      n032,
      _CCon,
      0,
      [_t, _le],
      [0, 0],
      1
    ];
    exports2.CreateAgentRuntimeEndpointRequest$ = [
      3,
      n032,
      _CARER,
      0,
      [_aRI, _n, _aRV, _d, _cTl, _ta],
      [[0, 1], [() => EndpointName, 0], 0, 0, [0, 4], 128 | 0],
      2
    ];
    exports2.CreateAgentRuntimeEndpointResponse$ = [
      3,
      n032,
      _CARERr,
      0,
      [_tV, _aREA, _aRA, _st, _cA, _aRI, _eN],
      [0, 0, 0, 0, 5, 0, [() => EndpointName, 0]],
      5
    ];
    exports2.CreateAgentRuntimeRequest$ = [
      3,
      n032,
      _CARR,
      0,
      [_aRN, _aRAg, _rA, _nC, _cTl, _d, _aCu, _rHC, _pC, _lC, _eV, _fC, _ta],
      [0, () => exports2.AgentRuntimeArtifact$, 0, () => exports2.NetworkConfiguration$, [0, 4], [() => Description, 0], () => exports2.AuthorizerConfiguration$, () => exports2.RequestHeaderConfiguration$, () => exports2.ProtocolConfiguration$, () => exports2.LifecycleConfiguration$, [() => EnvironmentVariablesMap, 0], () => FilesystemConfigurations, 128 | 0],
      4
    ];
    exports2.CreateAgentRuntimeResponse$ = [
      3,
      n032,
      _CARRr,
      0,
      [_aRA, _aRI, _aRV, _cA, _st, _wID],
      [0, 0, 0, 5, 0, () => exports2.WorkloadIdentityDetails$],
      5
    ];
    exports2.CreateApiKeyCredentialProviderRequest$ = [
      3,
      n032,
      _CAKCPR,
      0,
      [_n, _aK, _ta],
      [0, [() => ApiKeyType, 0], 128 | 0],
      2
    ];
    exports2.CreateApiKeyCredentialProviderResponse$ = [
      3,
      n032,
      _CAKCPRr,
      0,
      [_aKSA, _n, _cPA],
      [() => exports2.Secret$, 0, 0],
      3
    ];
    exports2.CreateBrowserProfileRequest$ = [
      3,
      n032,
      _CBPR,
      0,
      [_n, _d, _cTl, _ta],
      [0, [() => Description, 0], [0, 4], 128 | 0],
      1
    ];
    exports2.CreateBrowserProfileResponse$ = [
      3,
      n032,
      _CBPRr,
      0,
      [_pI, _pA, _cA, _st],
      [0, 0, 5, 0],
      4
    ];
    exports2.CreateBrowserRequest$ = [
      3,
      n032,
      _CBR,
      0,
      [_n, _nC, _d, _eRA, _re, _bS, _ePn, _ce, _cTl, _ta],
      [0, () => exports2.BrowserNetworkConfiguration$, [() => Description, 0], 0, () => exports2.RecordingConfig$, () => exports2.BrowserSigningConfigInput$, () => BrowserEnterprisePolicies, () => Certificates, [0, 4], 128 | 0],
      2
    ];
    exports2.CreateBrowserResponse$ = [
      3,
      n032,
      _CBRr,
      0,
      [_bI, _bA, _cA, _st],
      [0, 0, 5, 0],
      4
    ];
    exports2.CreateCodeInterpreterRequest$ = [
      3,
      n032,
      _CCIR,
      0,
      [_n, _nC, _d, _eRA, _ce, _cTl, _ta],
      [0, () => exports2.CodeInterpreterNetworkConfiguration$, [() => Description, 0], 0, () => Certificates, [0, 4], 128 | 0],
      2
    ];
    exports2.CreateCodeInterpreterResponse$ = [
      3,
      n032,
      _CCIRr,
      0,
      [_cII, _cIA, _cA, _st],
      [0, 0, 5, 0],
      4
    ];
    exports2.CreateEvaluatorRequest$ = [
      3,
      n032,
      _CER,
      0,
      [_eNv, _eC, _le, _cTl, _d, _ta],
      [0, [() => exports2.EvaluatorConfig$, 0], 0, [0, 4], [() => EvaluatorDescription, 0], 128 | 0],
      3
    ];
    exports2.CreateEvaluatorResponse$ = [
      3,
      n032,
      _CERr,
      0,
      [_eA, _eI13, _cA, _st],
      [0, 0, 4, 0],
      4
    ];
    exports2.CreateGatewayRequest$ = [
      3,
      n032,
      _CGR,
      0,
      [_n, _rA, _pT, _aT22, _d, _cTl, _pC, _aCu, _kKA, _iCnt, _pEC, _eL, _ta],
      [[() => GatewayName, 0], 0, 0, 0, [() => GatewayDescription, 0], [0, 4], () => exports2.GatewayProtocolConfiguration$, () => exports2.AuthorizerConfiguration$, 0, () => GatewayInterceptorConfigurations, () => exports2.GatewayPolicyEngineConfiguration$, 0, 128 | 0],
      4
    ];
    exports2.CreateGatewayResponse$ = [
      3,
      n032,
      _CGRr,
      0,
      [_gA, _gI, _cA, _uA, _st, _n, _pT, _aT22, _gU, _sR, _d, _rA, _pC, _aCu, _kKA, _iCnt, _pEC, _wID, _eL],
      [0, 0, 5, 5, 0, [() => GatewayName, 0], 0, 0, 0, 64 | 0, [() => GatewayDescription, 0], 0, () => exports2.GatewayProtocolConfiguration$, () => exports2.AuthorizerConfiguration$, 0, () => GatewayInterceptorConfigurations, () => exports2.GatewayPolicyEngineConfiguration$, () => exports2.WorkloadIdentityDetails$, 0],
      8
    ];
    exports2.CreateGatewayTargetRequest$ = [
      3,
      n032,
      _CGTR,
      0,
      [_gIa, _n, _tC, _d, _cTl, _cPC, _mC, _pE],
      [[0, 1], [() => TargetName, 0], [() => exports2.TargetConfiguration$, 0], [() => TargetDescription, 0], [0, 4], [() => CredentialProviderConfigurations, 0], () => exports2.MetadataConfiguration$, () => exports2.PrivateEndpoint$],
      3
    ];
    exports2.CreateGatewayTargetResponse$ = [
      3,
      n032,
      _CGTRr,
      0,
      [_gA, _tI10, _cA, _uA, _st, _n, _tC, _cPC, _sR, _d, _lSAa, _mC, _pE, _pEMR, _aD],
      [0, 0, 5, 5, 0, [() => TargetName, 0], [() => exports2.TargetConfiguration$, 0], [() => CredentialProviderConfigurations, 0], 64 | 0, [() => TargetDescription, 0], 5, () => exports2.MetadataConfiguration$, () => exports2.PrivateEndpoint$, () => PrivateEndpointManagedResources, () => exports2.AuthorizationData$],
      8
    ];
    exports2.CreateHarnessRequest$ = [
      3,
      n032,
      _CHR,
      0,
      [_hN, _eRA, _cTl, _env, _eAn, _eV, _aCu, _mo, _sP, _to, _sk, _aTl, _mem, _tr, _mIa, _mT, _tS, _ta],
      [0, 0, [0, 4], () => exports2.HarnessEnvironmentProviderRequest$, () => exports2.HarnessEnvironmentArtifact$, [() => EnvironmentVariablesMap, 0], () => exports2.AuthorizerConfiguration$, () => exports2.HarnessModelConfiguration$, [() => HarnessSystemPrompt, 0], [() => HarnessTools, 0], () => HarnessSkills, 64 | 0, () => exports2.HarnessMemoryConfiguration$, () => exports2.HarnessTruncationConfiguration$, 1, 1, 1, 128 | 0],
      2
    ];
    exports2.CreateHarnessResponse$ = [
      3,
      n032,
      _CHRr,
      0,
      [_h22],
      [[() => exports2.Harness$, 0]],
      1
    ];
    exports2.CreateMemoryInput$ = [
      3,
      n032,
      _CMI,
      0,
      [_n, _eED, _cTl, _d, _eKA, _mERA, _mS, _sDR, _ta],
      [0, 1, [0, 4], [() => Description, 0], 0, 0, [() => MemoryStrategyInputList, 0], () => exports2.StreamDeliveryResources$, 128 | 0],
      2
    ];
    exports2.CreateMemoryOutput$ = [
      3,
      n032,
      _CMO,
      0,
      [_mem],
      [[() => exports2.Memory$, 0]]
    ];
    exports2.CreateOauth2CredentialProviderRequest$ = [
      3,
      n032,
      _COCPR,
      0,
      [_n, _cPV, _oPCI, _ta],
      [0, 0, [() => exports2.Oauth2ProviderConfigInput$, 0], 128 | 0],
      3
    ];
    exports2.CreateOauth2CredentialProviderResponse$ = [
      3,
      n032,
      _COCPRr,
      0,
      [_cSA, _n, _cPA, _cUa, _oPCO],
      [() => exports2.Secret$, 0, 0, 0, () => exports2.Oauth2ProviderConfigOutput$],
      3
    ];
    exports2.CreateOnlineEvaluationConfigRequest$ = [
      3,
      n032,
      _COECR,
      0,
      [_oECN, _rul, _dSC, _ev, _eERA, _eOC, _cTl, _d, _ta],
      [0, () => exports2.Rule$, () => exports2.DataSourceConfig$, () => EvaluatorList, 0, 2, [0, 4], [() => EvaluationConfigDescription, 0], 128 | 0],
      6
    ];
    exports2.CreateOnlineEvaluationConfigResponse$ = [
      3,
      n032,
      _COECRr,
      0,
      [_oECA, _oECI, _cA, _st, _eS, _oC, _fR],
      [0, 0, 4, 0, 0, () => exports2.OutputConfig$, 0],
      5
    ];
    exports2.CreatePolicyEngineRequest$ = [
      3,
      n032,
      _CPER,
      0,
      [_n, _d, _cTl, _eKA, _ta],
      [0, [() => Description, 0], [0, 4], 0, 128 | 0],
      1
    ];
    exports2.CreatePolicyEngineResponse$ = [
      3,
      n032,
      _CPERr,
      0,
      [_pEI, _n, _cA, _uA, _pEA, _st, _sR, _d, _eKA],
      [0, 0, 5, 5, 0, 0, 64 | 0, [() => Description, 0], 0],
      7
    ];
    exports2.CreatePolicyRequest$ = [
      3,
      n032,
      _CPR,
      0,
      [_n, _de, _pEI, _d, _vM, _cTl],
      [0, () => exports2.PolicyDefinition$, [0, 1], [() => Description, 0], 0, [0, 4]],
      3
    ];
    exports2.CreatePolicyResponse$ = [
      3,
      n032,
      _CPRr,
      0,
      [_pIo, _n, _pEI, _de, _cA, _uA, _pAo, _st, _sR, _d],
      [0, 0, 0, () => exports2.PolicyDefinition$, 5, 5, 0, 0, 64 | 0, [() => Description, 0]],
      9
    ];
    exports2.CreateRegistryRecordRequest$ = [
      3,
      n032,
      _CRRR,
      0,
      [_rI, _n, _dT, _d, _des, _rV, _sT19, _sC, _cTl],
      [[0, 1], 0, 0, [() => Description, 0], () => exports2.Descriptors$, 0, 0, () => exports2.SynchronizationConfiguration$, [0, 4]],
      3
    ];
    exports2.CreateRegistryRecordResponse$ = [
      3,
      n032,
      _CRRRr,
      0,
      [_rAe, _st],
      [0, 0],
      2
    ];
    exports2.CreateRegistryRequest$ = [
      3,
      n032,
      _CRR,
      0,
      [_n, _d, _aT22, _aCu, _cTl, _aCp],
      [0, [() => Description, 0], 0, () => exports2.AuthorizerConfiguration$, [0, 4], () => exports2.ApprovalConfiguration$],
      1
    ];
    exports2.CreateRegistryResponse$ = [
      3,
      n032,
      _CRRr,
      0,
      [_rAeg],
      [0],
      1
    ];
    exports2.CreateWorkloadIdentityRequest$ = [
      3,
      n032,
      _CWIR,
      0,
      [_n, _aRORU, _ta],
      [0, 64 | 0, 128 | 0],
      1
    ];
    exports2.CreateWorkloadIdentityResponse$ = [
      3,
      n032,
      _CWIRr,
      0,
      [_n, _wIA, _aRORU],
      [0, 0, 64 | 0],
      2
    ];
    exports2.CredentialProviderConfiguration$ = [
      3,
      n032,
      _CPC,
      0,
      [_cPT, _cP],
      [0, [() => exports2.CredentialProvider$, 0]],
      1
    ];
    exports2.CustomClaimValidationType$ = [
      3,
      n032,
      _CCVT,
      0,
      [_iTCN, _iTCVT, _aCMV],
      [0, 0, () => exports2.AuthorizingClaimMatchValueType$],
      3
    ];
    exports2.CustomDescriptor$ = [
      3,
      n032,
      _CD,
      0,
      [_iC],
      [0]
    ];
    exports2.CustomJWTAuthorizerConfiguration$ = [
      3,
      n032,
      _CJWTAC,
      0,
      [_dU, _aAl, _aCl, _aS, _cC],
      [0, 64 | 0, 64 | 0, 64 | 0, () => CustomClaimValidationsType],
      1
    ];
    exports2.CustomMemoryStrategyInput$ = [
      3,
      n032,
      _CMSI,
      0,
      [_n, _d, _na, _nT, _con],
      [0, [() => Description, 0], 64 | 0, 64 | 0, [() => exports2.CustomConfigurationInput$, 0]],
      1
    ];
    exports2.CustomOauth2ProviderConfigInput$ = [
      3,
      n032,
      _COPCI,
      0,
      [_oD, _cI13, _cS4],
      [() => exports2.Oauth2Discovery$, 0, [() => ClientSecretType, 0]],
      3
    ];
    exports2.CustomOauth2ProviderConfigOutput$ = [
      3,
      n032,
      _COPCO,
      0,
      [_oD, _cI13],
      [() => exports2.Oauth2Discovery$, 0],
      1
    ];
    exports2.DeleteAgentRuntimeEndpointRequest$ = [
      3,
      n032,
      _DARER,
      0,
      [_aRI, _eN, _cTl],
      [[0, 1], [() => EndpointName, 1], [0, { [_hQ10]: _cTl, [_iT13]: 1 }]],
      2
    ];
    exports2.DeleteAgentRuntimeEndpointResponse$ = [
      3,
      n032,
      _DARERe,
      0,
      [_st, _aRI, _eN],
      [0, 0, [() => EndpointName, 0]],
      1
    ];
    exports2.DeleteAgentRuntimeRequest$ = [
      3,
      n032,
      _DARR,
      0,
      [_aRI, _cTl],
      [[0, 1], [0, { [_hQ10]: _cTl, [_iT13]: 1 }]],
      1
    ];
    exports2.DeleteAgentRuntimeResponse$ = [
      3,
      n032,
      _DARRe,
      0,
      [_st, _aRI],
      [0, 0],
      1
    ];
    exports2.DeleteApiKeyCredentialProviderRequest$ = [
      3,
      n032,
      _DAKCPR,
      0,
      [_n],
      [0],
      1
    ];
    exports2.DeleteApiKeyCredentialProviderResponse$ = [
      3,
      n032,
      _DAKCPRe,
      0,
      [],
      []
    ];
    exports2.DeleteBrowserProfileRequest$ = [
      3,
      n032,
      _DBPR,
      0,
      [_pI, _cTl],
      [[0, 1], [0, { [_hQ10]: _cTl, [_iT13]: 1 }]],
      1
    ];
    exports2.DeleteBrowserProfileResponse$ = [
      3,
      n032,
      _DBPRe,
      0,
      [_pI, _pA, _st, _lUA, _lSA],
      [0, 0, 0, 5, 5],
      4
    ];
    exports2.DeleteBrowserRequest$ = [
      3,
      n032,
      _DBR,
      0,
      [_bI, _cTl],
      [[0, 1], [0, { [_hQ10]: _cTl, [_iT13]: 1 }]],
      1
    ];
    exports2.DeleteBrowserResponse$ = [
      3,
      n032,
      _DBRe,
      0,
      [_bI, _st, _lUA],
      [0, 0, 5],
      3
    ];
    exports2.DeleteCodeInterpreterRequest$ = [
      3,
      n032,
      _DCIR,
      0,
      [_cII, _cTl],
      [[0, 1], [0, { [_hQ10]: _cTl, [_iT13]: 1 }]],
      1
    ];
    exports2.DeleteCodeInterpreterResponse$ = [
      3,
      n032,
      _DCIRe,
      0,
      [_cII, _st, _lUA],
      [0, 0, 5],
      3
    ];
    exports2.DeleteEvaluatorRequest$ = [
      3,
      n032,
      _DER,
      0,
      [_eI13],
      [[0, 1]],
      1
    ];
    exports2.DeleteEvaluatorResponse$ = [
      3,
      n032,
      _DERe,
      0,
      [_eA, _eI13, _st],
      [0, 0, 0],
      3
    ];
    exports2.DeleteGatewayRequest$ = [
      3,
      n032,
      _DGR,
      0,
      [_gIa],
      [[0, 1]],
      1
    ];
    exports2.DeleteGatewayResponse$ = [
      3,
      n032,
      _DGRe,
      0,
      [_gI, _st, _sR],
      [0, 0, 64 | 0],
      2
    ];
    exports2.DeleteGatewayTargetRequest$ = [
      3,
      n032,
      _DGTR,
      0,
      [_gIa, _tI10],
      [[0, 1], [0, 1]],
      2
    ];
    exports2.DeleteGatewayTargetResponse$ = [
      3,
      n032,
      _DGTRe,
      0,
      [_gA, _tI10, _st, _sR],
      [0, 0, 0, 64 | 0],
      3
    ];
    exports2.DeleteHarnessRequest$ = [
      3,
      n032,
      _DHR,
      0,
      [_hI, _cTl],
      [[0, 1], [0, { [_hQ10]: _cTl, [_iT13]: 1 }]],
      1
    ];
    exports2.DeleteHarnessResponse$ = [
      3,
      n032,
      _DHRe,
      0,
      [_h22],
      [[() => exports2.Harness$, 0]]
    ];
    exports2.DeleteMemoryInput$ = [
      3,
      n032,
      _DMI,
      0,
      [_mIe, _cTl],
      [[0, 1], [0, { [_hQ10]: _cTl, [_iT13]: 1 }]],
      1
    ];
    exports2.DeleteMemoryOutput$ = [
      3,
      n032,
      _DMO,
      0,
      [_mIe, _st],
      [0, 0],
      1
    ];
    exports2.DeleteMemoryStrategyInput$ = [
      3,
      n032,
      _DMSI,
      0,
      [_mSI],
      [0],
      1
    ];
    exports2.DeleteOauth2CredentialProviderRequest$ = [
      3,
      n032,
      _DOCPR,
      0,
      [_n],
      [0],
      1
    ];
    exports2.DeleteOauth2CredentialProviderResponse$ = [
      3,
      n032,
      _DOCPRe,
      0,
      [],
      []
    ];
    exports2.DeleteOnlineEvaluationConfigRequest$ = [
      3,
      n032,
      _DOECR,
      0,
      [_oECI],
      [[0, 1]],
      1
    ];
    exports2.DeleteOnlineEvaluationConfigResponse$ = [
      3,
      n032,
      _DOECRe,
      0,
      [_oECA, _oECI, _st],
      [0, 0, 0],
      3
    ];
    exports2.DeletePolicyEngineRequest$ = [
      3,
      n032,
      _DPER,
      0,
      [_pEI],
      [[0, 1]],
      1
    ];
    exports2.DeletePolicyEngineResponse$ = [
      3,
      n032,
      _DPERe,
      0,
      [_pEI, _n, _cA, _uA, _pEA, _st, _sR, _d, _eKA],
      [0, 0, 5, 5, 0, 0, 64 | 0, [() => Description, 0], 0],
      7
    ];
    exports2.DeletePolicyRequest$ = [
      3,
      n032,
      _DPR,
      0,
      [_pEI, _pIo],
      [[0, 1], [0, 1]],
      2
    ];
    exports2.DeletePolicyResponse$ = [
      3,
      n032,
      _DPRe,
      0,
      [_pIo, _n, _pEI, _de, _cA, _uA, _pAo, _st, _sR, _d],
      [0, 0, 0, () => exports2.PolicyDefinition$, 5, 5, 0, 0, 64 | 0, [() => Description, 0]],
      9
    ];
    exports2.DeleteRegistryRecordRequest$ = [
      3,
      n032,
      _DRRR,
      0,
      [_rI, _rIe],
      [[0, 1], [0, 1]],
      2
    ];
    exports2.DeleteRegistryRecordResponse$ = [
      3,
      n032,
      _DRRRe,
      0,
      [],
      []
    ];
    exports2.DeleteRegistryRequest$ = [
      3,
      n032,
      _DRR,
      0,
      [_rI],
      [[0, 1]],
      1
    ];
    exports2.DeleteRegistryResponse$ = [
      3,
      n032,
      _DRRe,
      0,
      [_st],
      [0],
      1
    ];
    exports2.DeleteResourcePolicyRequest$ = [
      3,
      n032,
      _DRPR,
      0,
      [_rAes],
      [[0, 1]],
      1
    ];
    exports2.DeleteResourcePolicyResponse$ = [
      3,
      n032,
      _DRPRe,
      0,
      [],
      []
    ];
    exports2.DeleteWorkloadIdentityRequest$ = [
      3,
      n032,
      _DWIR,
      0,
      [_n],
      [0],
      1
    ];
    exports2.DeleteWorkloadIdentityResponse$ = [
      3,
      n032,
      _DWIRe,
      0,
      [],
      []
    ];
    exports2.Descriptors$ = [
      3,
      n032,
      _De,
      0,
      [_mc, _a10, _cu, _aSg],
      [() => exports2.McpDescriptor$, () => exports2.A2aDescriptor$, () => exports2.CustomDescriptor$, () => exports2.AgentSkillsDescriptor$]
    ];
    exports2.EpisodicConsolidationOverride$ = [
      3,
      n032,
      _ECO,
      0,
      [_aTP, _mI],
      [[() => Prompt, 0], 0],
      2
    ];
    exports2.EpisodicExtractionOverride$ = [
      3,
      n032,
      _EEO,
      0,
      [_aTP, _mI],
      [[() => Prompt, 0], 0],
      2
    ];
    exports2.EpisodicMemoryStrategyInput$ = [
      3,
      n032,
      _EMSI,
      0,
      [_n, _d, _na, _nT, _rC10],
      [0, [() => Description, 0], 64 | 0, 64 | 0, () => exports2.EpisodicReflectionConfigurationInput$],
      1
    ];
    exports2.EpisodicOverrideConfigurationInput$ = [
      3,
      n032,
      _EOCI,
      0,
      [_ex10, _cons, _ref],
      [[() => exports2.EpisodicOverrideExtractionConfigurationInput$, 0], [() => exports2.EpisodicOverrideConsolidationConfigurationInput$, 0], [() => exports2.EpisodicOverrideReflectionConfigurationInput$, 0]]
    ];
    exports2.EpisodicOverrideConsolidationConfigurationInput$ = [
      3,
      n032,
      _EOCCI,
      0,
      [_aTP, _mI],
      [[() => Prompt, 0], 0],
      2
    ];
    exports2.EpisodicOverrideExtractionConfigurationInput$ = [
      3,
      n032,
      _EOECI,
      0,
      [_aTP, _mI],
      [[() => Prompt, 0], 0],
      2
    ];
    exports2.EpisodicOverrideReflectionConfigurationInput$ = [
      3,
      n032,
      _EORCI,
      0,
      [_aTP, _mI, _na, _nT],
      [[() => Prompt, 0], 0, 64 | 0, 64 | 0],
      2
    ];
    exports2.EpisodicReflectionConfiguration$ = [
      3,
      n032,
      _ERC,
      0,
      [_na, _nT],
      [64 | 0, 64 | 0]
    ];
    exports2.EpisodicReflectionConfigurationInput$ = [
      3,
      n032,
      _ERCI,
      0,
      [_na, _nT],
      [64 | 0, 64 | 0]
    ];
    exports2.EpisodicReflectionOverride$ = [
      3,
      n032,
      _ERO,
      0,
      [_aTP, _mI, _na, _nT],
      [[() => Prompt, 0], 0, 64 | 0, 64 | 0],
      2
    ];
    exports2.EvaluatorSummary$ = [
      3,
      n032,
      _ES,
      0,
      [_eA, _eI13, _eNv, _eT, _st, _cA, _uA, _d, _le, _lFM],
      [0, 0, 0, 0, 0, 4, 4, [() => EvaluatorDescription, 0], 0, 2],
      7
    ];
    exports2.Filter$ = [
      3,
      n032,
      _F,
      0,
      [_k, _o, _v],
      [0, 0, () => exports2.FilterValue$],
      3
    ];
    exports2.Finding$ = [
      3,
      n032,
      _Fi,
      0,
      [_t, _d],
      [0, 0]
    ];
    exports2.FromUrlSynchronizationConfiguration$ = [
      3,
      n032,
      _FUSC,
      0,
      [_u, _cPC],
      [0, () => RegistryRecordCredentialProviderConfigurationList],
      1
    ];
    exports2.GatewayApiKeyCredentialProvider$ = [
      3,
      n032,
      _GAKCP,
      0,
      [_pAr, _cPN, _cPr, _cL],
      [0, 0, 0, 0],
      1
    ];
    exports2.GatewayInterceptorConfiguration$ = [
      3,
      n032,
      _GIC,
      0,
      [_in, _iP, _iCnp],
      [() => exports2.InterceptorConfiguration$, 64 | 0, () => exports2.InterceptorInputConfiguration$],
      2
    ];
    exports2.GatewayPolicyEngineConfiguration$ = [
      3,
      n032,
      _GPEC,
      0,
      [_ar, _mod],
      [0, 0],
      2
    ];
    exports2.GatewaySummary$ = [
      3,
      n032,
      _GS,
      0,
      [_gI, _n, _st, _cA, _uA, _aT22, _pT, _d],
      [0, [() => GatewayName, 0], 0, 5, 5, 0, 0, [() => GatewayDescription, 0]],
      7
    ];
    exports2.GatewayTarget$ = [
      3,
      n032,
      _GT,
      0,
      [_gA, _tI10, _cA, _uA, _st, _n, _tC, _cPC, _sR, _d, _lSAa, _mC, _pE, _pEMR, _aD],
      [0, 0, 5, 5, 0, [() => TargetName, 0], [() => exports2.TargetConfiguration$, 0], [() => CredentialProviderConfigurations, 0], 64 | 0, [() => TargetDescription, 0], 5, () => exports2.MetadataConfiguration$, () => exports2.PrivateEndpoint$, () => PrivateEndpointManagedResources, () => exports2.AuthorizationData$],
      8
    ];
    exports2.GetAgentRuntimeEndpointRequest$ = [
      3,
      n032,
      _GARER,
      0,
      [_aRI, _eN],
      [[0, 1], [() => EndpointName, 1]],
      2
    ];
    exports2.GetAgentRuntimeEndpointResponse$ = [
      3,
      n032,
      _GARERe,
      0,
      [_aREA, _aRA, _st, _cA, _lUA, _n, _i, _lV, _tV, _d, _fR],
      [0, 0, 0, 5, 5, [() => EndpointName, 0], 0, 0, 0, 0, 0],
      7
    ];
    exports2.GetAgentRuntimeRequest$ = [
      3,
      n032,
      _GARR,
      0,
      [_aRI, _aRV],
      [[0, 1], [0, { [_hQ10]: _ve }]],
      1
    ];
    exports2.GetAgentRuntimeResponse$ = [
      3,
      n032,
      _GARRe,
      0,
      [_aRA, _aRN, _aRI, _aRV, _cA, _lUA, _rA, _nC, _st, _lC, _fR, _d, _wID, _aRAg, _pC, _eV, _aCu, _rHC, _mC, _fC],
      [0, 0, 0, 0, 5, 5, 0, () => exports2.NetworkConfiguration$, 0, () => exports2.LifecycleConfiguration$, 0, [() => Description, 0], () => exports2.WorkloadIdentityDetails$, () => exports2.AgentRuntimeArtifact$, () => exports2.ProtocolConfiguration$, [() => EnvironmentVariablesMap, 0], () => exports2.AuthorizerConfiguration$, () => exports2.RequestHeaderConfiguration$, () => exports2.RuntimeMetadataConfiguration$, () => FilesystemConfigurations],
      10
    ];
    exports2.GetApiKeyCredentialProviderRequest$ = [
      3,
      n032,
      _GAKCPR,
      0,
      [_n],
      [0],
      1
    ];
    exports2.GetApiKeyCredentialProviderResponse$ = [
      3,
      n032,
      _GAKCPRe,
      0,
      [_aKSA, _n, _cPA, _cT, _lUT],
      [() => exports2.Secret$, 0, 0, 4, 4],
      5
    ];
    exports2.GetBrowserProfileRequest$ = [
      3,
      n032,
      _GBPR,
      0,
      [_pI],
      [[0, 1]],
      1
    ];
    exports2.GetBrowserProfileResponse$ = [
      3,
      n032,
      _GBPRe,
      0,
      [_pI, _pA, _n, _st, _cA, _lUA, _d, _lSA, _lSBSI, _lSBI],
      [0, 0, 0, 0, 5, 5, [() => Description, 0], 5, 0, 0],
      6
    ];
    exports2.GetBrowserRequest$ = [
      3,
      n032,
      _GBR,
      0,
      [_bI],
      [[0, 1]],
      1
    ];
    exports2.GetBrowserResponse$ = [
      3,
      n032,
      _GBRe,
      0,
      [_bI, _bA, _n, _nC, _st, _cA, _lUA, _d, _eRA, _re, _bS, _ePn, _ce, _fR],
      [0, 0, 0, () => exports2.BrowserNetworkConfiguration$, 0, 5, 5, [() => Description, 0], 0, () => exports2.RecordingConfig$, () => exports2.BrowserSigningConfigOutput$, () => BrowserEnterprisePolicies, () => Certificates, 0],
      7
    ];
    exports2.GetCodeInterpreterRequest$ = [
      3,
      n032,
      _GCIR,
      0,
      [_cII],
      [[0, 1]],
      1
    ];
    exports2.GetCodeInterpreterResponse$ = [
      3,
      n032,
      _GCIRe,
      0,
      [_cII, _cIA, _n, _nC, _st, _cA, _lUA, _d, _eRA, _ce, _fR],
      [0, 0, 0, () => exports2.CodeInterpreterNetworkConfiguration$, 0, 5, 5, [() => Description, 0], 0, () => Certificates, 0],
      7
    ];
    exports2.GetEvaluatorRequest$ = [
      3,
      n032,
      _GER,
      0,
      [_eI13],
      [[0, 1]],
      1
    ];
    exports2.GetEvaluatorResponse$ = [
      3,
      n032,
      _GERe,
      0,
      [_eA, _eI13, _eNv, _eC, _le, _st, _cA, _uA, _d, _lFM],
      [0, 0, 0, [() => exports2.EvaluatorConfig$, 0], 0, 0, 4, 4, [() => EvaluatorDescription, 0], 2],
      8
    ];
    exports2.GetGatewayRequest$ = [
      3,
      n032,
      _GGR,
      0,
      [_gIa],
      [[0, 1]],
      1
    ];
    exports2.GetGatewayResponse$ = [
      3,
      n032,
      _GGRe,
      0,
      [_gA, _gI, _cA, _uA, _st, _n, _pT, _aT22, _gU, _sR, _d, _rA, _pC, _aCu, _kKA, _iCnt, _pEC, _wID, _eL],
      [0, 0, 5, 5, 0, [() => GatewayName, 0], 0, 0, 0, 64 | 0, [() => GatewayDescription, 0], 0, () => exports2.GatewayProtocolConfiguration$, () => exports2.AuthorizerConfiguration$, 0, () => GatewayInterceptorConfigurations, () => exports2.GatewayPolicyEngineConfiguration$, () => exports2.WorkloadIdentityDetails$, 0],
      8
    ];
    exports2.GetGatewayTargetRequest$ = [
      3,
      n032,
      _GGTR,
      0,
      [_gIa, _tI10],
      [[0, 1], [0, 1]],
      2
    ];
    exports2.GetGatewayTargetResponse$ = [
      3,
      n032,
      _GGTRe,
      0,
      [_gA, _tI10, _cA, _uA, _st, _n, _tC, _cPC, _sR, _d, _lSAa, _mC, _pE, _pEMR, _aD],
      [0, 0, 5, 5, 0, [() => TargetName, 0], [() => exports2.TargetConfiguration$, 0], [() => CredentialProviderConfigurations, 0], 64 | 0, [() => TargetDescription, 0], 5, () => exports2.MetadataConfiguration$, () => exports2.PrivateEndpoint$, () => PrivateEndpointManagedResources, () => exports2.AuthorizationData$],
      8
    ];
    exports2.GetHarnessRequest$ = [
      3,
      n032,
      _GHR,
      0,
      [_hI],
      [[0, 1]],
      1
    ];
    exports2.GetHarnessResponse$ = [
      3,
      n032,
      _GHRe,
      0,
      [_h22],
      [[() => exports2.Harness$, 0]],
      1
    ];
    exports2.GetMemoryInput$ = [
      3,
      n032,
      _GMI,
      0,
      [_mIe, _vi],
      [[0, 1], [0, { [_hQ10]: _vi }]],
      1
    ];
    exports2.GetMemoryOutput$ = [
      3,
      n032,
      _GMO,
      0,
      [_mem],
      [[() => exports2.Memory$, 0]],
      1
    ];
    exports2.GetOauth2CredentialProviderRequest$ = [
      3,
      n032,
      _GOCPR,
      0,
      [_n],
      [0],
      1
    ];
    exports2.GetOauth2CredentialProviderResponse$ = [
      3,
      n032,
      _GOCPRe,
      0,
      [_cSA, _n, _cPA, _cPV, _oPCO, _cT, _lUT, _cUa],
      [() => exports2.Secret$, 0, 0, 0, () => exports2.Oauth2ProviderConfigOutput$, 4, 4, 0],
      7
    ];
    exports2.GetOnlineEvaluationConfigRequest$ = [
      3,
      n032,
      _GOECR,
      0,
      [_oECI],
      [[0, 1]],
      1
    ];
    exports2.GetOnlineEvaluationConfigResponse$ = [
      3,
      n032,
      _GOECRe,
      0,
      [_oECA, _oECI, _oECN, _rul, _dSC, _ev, _st, _eS, _cA, _uA, _d, _oC, _eERA, _fR],
      [0, 0, 0, () => exports2.Rule$, () => exports2.DataSourceConfig$, () => EvaluatorList, 0, 0, 4, 4, [() => EvaluationConfigDescription, 0], () => exports2.OutputConfig$, 0, 0],
      10
    ];
    exports2.GetPolicyEngineRequest$ = [
      3,
      n032,
      _GPER,
      0,
      [_pEI],
      [[0, 1]],
      1
    ];
    exports2.GetPolicyEngineResponse$ = [
      3,
      n032,
      _GPERe,
      0,
      [_pEI, _n, _cA, _uA, _pEA, _st, _sR, _d, _eKA],
      [0, 0, 5, 5, 0, 0, 64 | 0, [() => Description, 0], 0],
      7
    ];
    exports2.GetPolicyGenerationRequest$ = [
      3,
      n032,
      _GPGR,
      0,
      [_pGI, _pEI],
      [[0, 1], [0, 1]],
      2
    ];
    exports2.GetPolicyGenerationResponse$ = [
      3,
      n032,
      _GPGRe,
      0,
      [_pEI, _pGI, _n, _pGA, _res, _cA, _uA, _st, _sR, _f],
      [0, 0, 0, 0, () => exports2.Resource$, 5, 5, 0, 64 | 0, 0],
      9
    ];
    exports2.GetPolicyRequest$ = [
      3,
      n032,
      _GPR,
      0,
      [_pEI, _pIo],
      [[0, 1], [0, 1]],
      2
    ];
    exports2.GetPolicyResponse$ = [
      3,
      n032,
      _GPRe,
      0,
      [_pIo, _n, _pEI, _de, _cA, _uA, _pAo, _st, _sR, _d],
      [0, 0, 0, () => exports2.PolicyDefinition$, 5, 5, 0, 0, 64 | 0, [() => Description, 0]],
      9
    ];
    exports2.GetRegistryRecordRequest$ = [
      3,
      n032,
      _GRRR,
      0,
      [_rI, _rIe],
      [[0, 1], [0, 1]],
      2
    ];
    exports2.GetRegistryRecordResponse$ = [
      3,
      n032,
      _GRRRe,
      0,
      [_rAeg, _rAe, _rIe, _n, _dT, _des, _st, _cA, _uA, _d, _rV, _sRt, _sT19, _sC],
      [0, 0, 0, 0, 0, () => exports2.Descriptors$, 0, 5, 5, [() => Description, 0], 0, 0, 0, () => exports2.SynchronizationConfiguration$],
      9
    ];
    exports2.GetRegistryRequest$ = [
      3,
      n032,
      _GRR,
      0,
      [_rI],
      [[0, 1]],
      1
    ];
    exports2.GetRegistryResponse$ = [
      3,
      n032,
      _GRRe,
      0,
      [_n, _rI, _rAeg, _st, _cA, _uA, _d, _aT22, _aCu, _aCp, _sRt],
      [0, 0, 0, 0, 5, 5, [() => Description, 0], 0, () => exports2.AuthorizerConfiguration$, () => exports2.ApprovalConfiguration$, 0],
      6
    ];
    exports2.GetResourcePolicyRequest$ = [
      3,
      n032,
      _GRPR,
      0,
      [_rAes],
      [[0, 1]],
      1
    ];
    exports2.GetResourcePolicyResponse$ = [
      3,
      n032,
      _GRPRe,
      0,
      [_po],
      [0]
    ];
    exports2.GetTokenVaultRequest$ = [
      3,
      n032,
      _GTVR,
      0,
      [_tVI],
      [0]
    ];
    exports2.GetTokenVaultResponse$ = [
      3,
      n032,
      _GTVRe,
      0,
      [_tVI, _kC, _lMD],
      [0, () => exports2.KmsConfiguration$, 4],
      3
    ];
    exports2.GetWorkloadIdentityRequest$ = [
      3,
      n032,
      _GWIR,
      0,
      [_n],
      [0],
      1
    ];
    exports2.GetWorkloadIdentityResponse$ = [
      3,
      n032,
      _GWIRe,
      0,
      [_n, _wIA, _cT, _lUT, _aRORU],
      [0, 0, 4, 4, 64 | 0],
      4
    ];
    exports2.GithubOauth2ProviderConfigInput$ = [
      3,
      n032,
      _GOPCI,
      0,
      [_cI13, _cS4],
      [0, [() => ClientSecretType, 0]],
      2
    ];
    exports2.GithubOauth2ProviderConfigOutput$ = [
      3,
      n032,
      _GOPCO,
      0,
      [_oD, _cI13],
      [() => exports2.Oauth2Discovery$, 0],
      1
    ];
    exports2.GoogleOauth2ProviderConfigInput$ = [
      3,
      n032,
      _GOPCIo,
      0,
      [_cI13, _cS4],
      [0, [() => ClientSecretType, 0]],
      2
    ];
    exports2.GoogleOauth2ProviderConfigOutput$ = [
      3,
      n032,
      _GOPCOo,
      0,
      [_oD, _cI13],
      [() => exports2.Oauth2Discovery$, 0],
      1
    ];
    exports2.Harness$ = [
      3,
      n032,
      _H,
      0,
      [_hI, _hN, _ar, _st, _eRA, _cA, _uA, _mo, _sP, _to, _sk, _aTl, _tr, _env, _eAn, _eV, _aCu, _mem, _mIa, _mT, _tS, _fR],
      [0, 0, 0, 0, 0, 5, 5, () => exports2.HarnessModelConfiguration$, [() => HarnessSystemPrompt, 0], [() => HarnessTools, 0], () => HarnessSkills, 64 | 0, () => exports2.HarnessTruncationConfiguration$, () => exports2.HarnessEnvironmentProvider$, () => exports2.HarnessEnvironmentArtifact$, [() => EnvironmentVariablesMap, 0], () => exports2.AuthorizerConfiguration$, () => exports2.HarnessMemoryConfiguration$, 1, 1, 1, 0],
      14
    ];
    exports2.HarnessAgentCoreBrowserConfig$ = [
      3,
      n032,
      _HACBC,
      0,
      [_bA],
      [0]
    ];
    exports2.HarnessAgentCoreCodeInterpreterConfig$ = [
      3,
      n032,
      _HACCIC,
      0,
      [_cIA],
      [0]
    ];
    exports2.HarnessAgentCoreGatewayConfig$ = [
      3,
      n032,
      _HACGC,
      0,
      [_gA, _oA],
      [0, [() => exports2.HarnessGatewayOutboundAuth$, 0]],
      1
    ];
    exports2.HarnessAgentCoreMemoryConfiguration$ = [
      3,
      n032,
      _HACMC,
      0,
      [_ar, _aI10, _mCe, _rCe],
      [0, 0, 1, () => HarnessAgentCoreMemoryRetrievalConfigs],
      1
    ];
    exports2.HarnessAgentCoreMemoryRetrievalConfig$ = [
      3,
      n032,
      _HACMRC,
      0,
      [_tK, _rS, _sI],
      [1, 1, 0]
    ];
    exports2.HarnessAgentCoreRuntimeEnvironment$ = [
      3,
      n032,
      _HACRE,
      0,
      [_aRA, _aRN, _aRI, _lC, _nC, _fC],
      [0, 0, 0, () => exports2.LifecycleConfiguration$, () => exports2.NetworkConfiguration$, () => FilesystemConfigurations],
      5
    ];
    exports2.HarnessAgentCoreRuntimeEnvironmentRequest$ = [
      3,
      n032,
      _HACRER,
      0,
      [_lC, _nC, _fC],
      [() => exports2.LifecycleConfiguration$, () => exports2.NetworkConfiguration$, () => FilesystemConfigurations]
    ];
    exports2.HarnessBedrockModelConfig$ = [
      3,
      n032,
      _HBMC,
      0,
      [_mI, _mT, _te, _tP],
      [0, 1, 1, 1],
      1
    ];
    exports2.HarnessGeminiModelConfig$ = [
      3,
      n032,
      _HGMC,
      0,
      [_mI, _aKA, _mT, _te, _tP, _tK],
      [0, 0, 1, 1, 1, 1],
      2
    ];
    exports2.HarnessInlineFunctionConfig$ = [
      3,
      n032,
      _HIFC,
      0,
      [_d, _iS],
      [[() => HarnessInlineFunctionDescription, 0], [() => SensitiveJson, 0]],
      2
    ];
    exports2.HarnessOpenAiModelConfig$ = [
      3,
      n032,
      _HOAMC,
      0,
      [_mI, _aKA, _mT, _te, _tP],
      [0, 0, 1, 1, 1],
      2
    ];
    exports2.HarnessRemoteMcpConfig$ = [
      3,
      n032,
      _HRMC,
      0,
      [_u, _he],
      [[() => HarnessRemoteMcpUrl, 0], [() => HttpHeadersMap, 0]],
      1
    ];
    exports2.HarnessSlidingWindowConfiguration$ = [
      3,
      n032,
      _HSWC,
      0,
      [_mCe],
      [1]
    ];
    exports2.HarnessSummarizationConfiguration$ = [
      3,
      n032,
      _HSC,
      0,
      [_sRu, _pRM, _sSP],
      [1, 1, 0]
    ];
    exports2.HarnessSummary$ = [
      3,
      n032,
      _HS,
      0,
      [_hI, _hN, _ar, _st, _cA, _uA],
      [0, 0, 0, 0, 5, 5],
      6
    ];
    exports2.HarnessTool$ = [
      3,
      n032,
      _HT,
      0,
      [_t, _n, _conf],
      [0, 0, [() => exports2.HarnessToolConfiguration$, 0]],
      1
    ];
    exports2.HarnessTruncationConfiguration$ = [
      3,
      n032,
      _HTC,
      0,
      [_str, _conf],
      [0, () => exports2.HarnessTruncationStrategyConfiguration$],
      1
    ];
    exports2.IamCredentialProvider$ = [
      3,
      n032,
      _ICP,
      0,
      [_ser, _reg],
      [0, 0],
      1
    ];
    exports2.IncludedOauth2ProviderConfigInput$ = [
      3,
      n032,
      _IOPCI,
      0,
      [_cI13, _cS4, _is, _aE, _tE],
      [0, [() => ClientSecretType, 0], 0, 0, 0],
      2
    ];
    exports2.IncludedOauth2ProviderConfigOutput$ = [
      3,
      n032,
      _IOPCO,
      0,
      [_oD, _cI13],
      [() => exports2.Oauth2Discovery$, 0],
      1
    ];
    exports2.InferenceConfiguration$ = [
      3,
      n032,
      _IC,
      0,
      [_mT, _te, _tP, _sS],
      [1, 1, 1, 64 | 0]
    ];
    exports2.InterceptorInputConfiguration$ = [
      3,
      n032,
      _IIC,
      0,
      [_pRH],
      [2],
      1
    ];
    exports2.InvocationConfiguration$ = [
      3,
      n032,
      _ICn,
      0,
      [_tA, _pDBN],
      [0, 0],
      2
    ];
    exports2.InvocationConfigurationInput$ = [
      3,
      n032,
      _ICI,
      0,
      [_tA, _pDBN],
      [0, 0],
      2
    ];
    exports2.KinesisResource$ = [
      3,
      n032,
      _KR,
      0,
      [_dSA, _cCo],
      [0, () => ContentConfigurationList],
      2
    ];
    exports2.KmsConfiguration$ = [
      3,
      n032,
      _KC,
      0,
      [_kT, _kKA],
      [0, 0],
      1
    ];
    exports2.LambdaEvaluatorConfig$ = [
      3,
      n032,
      _LEC,
      0,
      [_lA, _lTIS],
      [0, 1],
      1
    ];
    exports2.LambdaInterceptorConfiguration$ = [
      3,
      n032,
      _LIC,
      0,
      [_ar],
      [0],
      1
    ];
    exports2.LifecycleConfiguration$ = [
      3,
      n032,
      _LC,
      0,
      [_iRST, _mL],
      [1, 1]
    ];
    exports2.LinkedinOauth2ProviderConfigInput$ = [
      3,
      n032,
      _LOPCI,
      0,
      [_cI13, _cS4],
      [0, [() => ClientSecretType, 0]],
      2
    ];
    exports2.LinkedinOauth2ProviderConfigOutput$ = [
      3,
      n032,
      _LOPCO,
      0,
      [_oD, _cI13],
      [() => exports2.Oauth2Discovery$, 0],
      1
    ];
    exports2.ListAgentRuntimeEndpointsRequest$ = [
      3,
      n032,
      _LARER,
      0,
      [_aRI, _mR, _nTe],
      [[0, 1], [1, { [_hQ10]: _mR }], [0, { [_hQ10]: _nTe }]],
      1
    ];
    exports2.ListAgentRuntimeEndpointsResponse$ = [
      3,
      n032,
      _LARERi,
      0,
      [_rE, _nTe],
      [[() => AgentRuntimeEndpoints, 0], 0],
      1
    ];
    exports2.ListAgentRuntimesRequest$ = [
      3,
      n032,
      _LARR,
      0,
      [_mR, _nTe],
      [[1, { [_hQ10]: _mR }], [0, { [_hQ10]: _nTe }]]
    ];
    exports2.ListAgentRuntimesResponse$ = [
      3,
      n032,
      _LARRi,
      0,
      [_aR, _nTe],
      [[() => AgentRuntimes, 0], 0],
      1
    ];
    exports2.ListAgentRuntimeVersionsRequest$ = [
      3,
      n032,
      _LARVR,
      0,
      [_aRI, _mR, _nTe],
      [[0, 1], [1, { [_hQ10]: _mR }], [0, { [_hQ10]: _nTe }]],
      1
    ];
    exports2.ListAgentRuntimeVersionsResponse$ = [
      3,
      n032,
      _LARVRi,
      0,
      [_aR, _nTe],
      [[() => AgentRuntimes, 0], 0],
      1
    ];
    exports2.ListApiKeyCredentialProvidersRequest$ = [
      3,
      n032,
      _LAKCPR,
      0,
      [_nTe, _mR],
      [0, 1]
    ];
    exports2.ListApiKeyCredentialProvidersResponse$ = [
      3,
      n032,
      _LAKCPRi,
      0,
      [_cPre, _nTe],
      [() => ApiKeyCredentialProviders, 0],
      1
    ];
    exports2.ListBrowserProfilesRequest$ = [
      3,
      n032,
      _LBPR,
      0,
      [_mR, _nTe, _n],
      [[1, { [_hQ10]: _mR }], [0, { [_hQ10]: _nTe }], 0]
    ];
    exports2.ListBrowserProfilesResponse$ = [
      3,
      n032,
      _LBPRi,
      0,
      [_pS, _nTe],
      [[() => BrowserProfileSummaries, 0], 0],
      1
    ];
    exports2.ListBrowsersRequest$ = [
      3,
      n032,
      _LBR,
      0,
      [_mR, _nTe, _t],
      [[1, { [_hQ10]: _mR }], [0, { [_hQ10]: _nTe }], [0, { [_hQ10]: _t }]]
    ];
    exports2.ListBrowsersResponse$ = [
      3,
      n032,
      _LBRi,
      0,
      [_bSr, _nTe],
      [[() => BrowserSummaries, 0], 0],
      1
    ];
    exports2.ListCodeInterpretersRequest$ = [
      3,
      n032,
      _LCIR,
      0,
      [_mR, _nTe, _t],
      [[1, { [_hQ10]: _mR }], [0, { [_hQ10]: _nTe }], [0, { [_hQ10]: _t }]]
    ];
    exports2.ListCodeInterpretersResponse$ = [
      3,
      n032,
      _LCIRi,
      0,
      [_cIS, _nTe],
      [[() => CodeInterpreterSummaries, 0], 0],
      1
    ];
    exports2.ListEvaluatorsRequest$ = [
      3,
      n032,
      _LER,
      0,
      [_nTe, _mR],
      [[0, { [_hQ10]: _nTe }], [1, { [_hQ10]: _mR }]]
    ];
    exports2.ListEvaluatorsResponse$ = [
      3,
      n032,
      _LERi,
      0,
      [_ev, _nTe],
      [[() => EvaluatorSummaryList, 0], 0],
      1
    ];
    exports2.ListGatewaysRequest$ = [
      3,
      n032,
      _LGR,
      0,
      [_mR, _nTe],
      [[1, { [_hQ10]: _mR }], [0, { [_hQ10]: _nTe }]]
    ];
    exports2.ListGatewaysResponse$ = [
      3,
      n032,
      _LGRi,
      0,
      [_it, _nTe],
      [[() => GatewaySummaries, 0], 0],
      1
    ];
    exports2.ListGatewayTargetsRequest$ = [
      3,
      n032,
      _LGTR,
      0,
      [_gIa, _mR, _nTe],
      [[0, 1], [1, { [_hQ10]: _mR }], [0, { [_hQ10]: _nTe }]],
      1
    ];
    exports2.ListGatewayTargetsResponse$ = [
      3,
      n032,
      _LGTRi,
      0,
      [_it, _nTe],
      [[() => TargetSummaries, 0], 0],
      1
    ];
    exports2.ListHarnessesRequest$ = [
      3,
      n032,
      _LHR,
      0,
      [_mR, _nTe],
      [[1, { [_hQ10]: _mR }], [0, { [_hQ10]: _nTe }]]
    ];
    exports2.ListHarnessesResponse$ = [
      3,
      n032,
      _LHRi,
      0,
      [_ha, _nTe],
      [() => HarnessSummaries, 0],
      1
    ];
    exports2.ListMemoriesInput$ = [
      3,
      n032,
      _LMI,
      0,
      [_mR, _nTe],
      [1, 0]
    ];
    exports2.ListMemoriesOutput$ = [
      3,
      n032,
      _LMO,
      0,
      [_memo, _nTe],
      [() => MemorySummaryList, 0],
      1
    ];
    exports2.ListOauth2CredentialProvidersRequest$ = [
      3,
      n032,
      _LOCPR,
      0,
      [_nTe, _mR],
      [0, 1]
    ];
    exports2.ListOauth2CredentialProvidersResponse$ = [
      3,
      n032,
      _LOCPRi,
      0,
      [_cPre, _nTe],
      [() => Oauth2CredentialProviders, 0],
      1
    ];
    exports2.ListOnlineEvaluationConfigsRequest$ = [
      3,
      n032,
      _LOECR,
      0,
      [_nTe, _mR],
      [[0, { [_hQ10]: _nTe }], [1, { [_hQ10]: _mR }]]
    ];
    exports2.ListOnlineEvaluationConfigsResponse$ = [
      3,
      n032,
      _LOECRi,
      0,
      [_oEC, _nTe],
      [[() => OnlineEvaluationConfigSummaryList, 0], 0],
      1
    ];
    exports2.ListPoliciesRequest$ = [
      3,
      n032,
      _LPR,
      0,
      [_pEI, _nTe, _mR, _tRS],
      [[0, 1], [0, { [_hQ10]: _nTe }], [1, { [_hQ10]: _mR }], [0, { [_hQ10]: _tRS }]],
      1
    ];
    exports2.ListPoliciesResponse$ = [
      3,
      n032,
      _LPRi,
      0,
      [_pol, _nTe],
      [[() => Policies, 0], 0],
      1
    ];
    exports2.ListPolicyEnginesRequest$ = [
      3,
      n032,
      _LPER,
      0,
      [_nTe, _mR],
      [[0, { [_hQ10]: _nTe }], [1, { [_hQ10]: _mR }]]
    ];
    exports2.ListPolicyEnginesResponse$ = [
      3,
      n032,
      _LPERi,
      0,
      [_pEo, _nTe],
      [[() => PolicyEngines, 0], 0],
      1
    ];
    exports2.ListPolicyGenerationAssetsRequest$ = [
      3,
      n032,
      _LPGAR,
      0,
      [_pGI, _pEI, _nTe, _mR],
      [[0, 1], [0, 1], [0, { [_hQ10]: _nTe }], [1, { [_hQ10]: _mR }]],
      2
    ];
    exports2.ListPolicyGenerationAssetsResponse$ = [
      3,
      n032,
      _LPGARi,
      0,
      [_pGAo, _nTe],
      [() => PolicyGenerationAssets, 0]
    ];
    exports2.ListPolicyGenerationsRequest$ = [
      3,
      n032,
      _LPGR,
      0,
      [_pEI, _nTe, _mR],
      [[0, 1], [0, { [_hQ10]: _nTe }], [1, { [_hQ10]: _mR }]],
      1
    ];
    exports2.ListPolicyGenerationsResponse$ = [
      3,
      n032,
      _LPGRi,
      0,
      [_pG, _nTe],
      [() => PolicyGenerations, 0],
      1
    ];
    exports2.ListRegistriesRequest$ = [
      3,
      n032,
      _LRR,
      0,
      [_mR, _nTe, _st],
      [[1, { [_hQ10]: _mR }], [0, { [_hQ10]: _nTe }], [0, { [_hQ10]: _st }]]
    ];
    exports2.ListRegistriesResponse$ = [
      3,
      n032,
      _LRRi,
      0,
      [_regi, _nTe],
      [[() => RegistrySummaryList, 0], 0],
      1
    ];
    exports2.ListRegistryRecordsRequest$ = [
      3,
      n032,
      _LRRR,
      0,
      [_rI, _mR, _nTe, _n, _st, _dT],
      [[0, 1], [1, { [_hQ10]: _mR }], [0, { [_hQ10]: _nTe }], [0, { [_hQ10]: _n }], [0, { [_hQ10]: _st }], [0, { [_hQ10]: _dT }]],
      1
    ];
    exports2.ListRegistryRecordsResponse$ = [
      3,
      n032,
      _LRRRi,
      0,
      [_rR, _nTe],
      [[() => RegistryRecordSummaryList, 0], 0],
      1
    ];
    exports2.ListTagsForResourceRequest$ = [
      3,
      n032,
      _LTFRR,
      0,
      [_rAes],
      [[0, 1]],
      1
    ];
    exports2.ListTagsForResourceResponse$ = [
      3,
      n032,
      _LTFRRi,
      0,
      [_ta],
      [128 | 0]
    ];
    exports2.ListWorkloadIdentitiesRequest$ = [
      3,
      n032,
      _LWIR,
      0,
      [_nTe, _mR],
      [0, 1]
    ];
    exports2.ListWorkloadIdentitiesResponse$ = [
      3,
      n032,
      _LWIRi,
      0,
      [_wI, _nTe],
      [() => WorkloadIdentityList, 0],
      1
    ];
    exports2.LlmAsAJudgeEvaluatorConfig$ = [
      3,
      n032,
      _LAAJEC,
      0,
      [_ins, _rSa, _mCo],
      [[() => EvaluatorInstructions, 0], [() => exports2.RatingScale$, 0], () => exports2.EvaluatorModelConfig$],
      3
    ];
    exports2.ManagedLatticeResource$ = [
      3,
      n032,
      _MLR,
      0,
      [_vI, _sIu, _eIAT, _sGI, _ta, _rD],
      [0, 64 | 0, 0, 64 | 0, 128 | 0, 0],
      3
    ];
    exports2.ManagedResourceDetails$ = [
      3,
      n032,
      _MRD,
      0,
      [_do, _rGA, _rAA],
      [0, 0, 0]
    ];
    exports2.McpDescriptor$ = [
      3,
      n032,
      _MD,
      0,
      [_se14, _to],
      [() => exports2.ServerDefinition$, () => exports2.ToolsDefinition$]
    ];
    exports2.MCPGatewayConfiguration$ = [
      3,
      n032,
      _MCPGC,
      0,
      [_sVu, _ins, _sTe],
      [64 | 0, 0, 0]
    ];
    exports2.McpLambdaTargetConfiguration$ = [
      3,
      n032,
      _MLTC,
      0,
      [_lA, _tSo],
      [0, () => exports2.ToolSchema$],
      2
    ];
    exports2.McpServerTargetConfiguration$ = [
      3,
      n032,
      _MSTC,
      0,
      [_end, _mTS, _rP, _lM],
      [0, [() => exports2.McpToolSchemaConfiguration$, 0], 1, 0],
      1
    ];
    exports2.Memory$ = [
      3,
      n032,
      _M,
      0,
      [_ar, _i, _n, _eED, _st, _cA, _uA, _d, _eKA, _mERA, _fR, _stra, _sDR],
      [0, 0, 0, 1, 0, 4, 4, [() => Description, 0], 0, 0, 0, [() => MemoryStrategyList, 0], () => exports2.StreamDeliveryResources$],
      7
    ];
    exports2.MemoryStrategy$ = [
      3,
      n032,
      _MS,
      0,
      [_sI, _n, _t, _na, _nT, _d, _con, _cA, _uA, _st],
      [0, 0, 0, 64 | 0, 64 | 0, [() => Description, 0], [() => exports2.StrategyConfiguration$, 0], 4, 4, 0],
      5
    ];
    exports2.MemorySummary$ = [
      3,
      n032,
      _MSe,
      0,
      [_cA, _uA, _ar, _i, _st],
      [4, 4, 0, 0, 0],
      2
    ];
    exports2.MessageBasedTrigger$ = [
      3,
      n032,
      _MBT,
      0,
      [_mCes],
      [1]
    ];
    exports2.MessageBasedTriggerInput$ = [
      3,
      n032,
      _MBTI,
      0,
      [_mCes],
      [1]
    ];
    exports2.MetadataConfiguration$ = [
      3,
      n032,
      _MC,
      0,
      [_aRH, _aQP, _aRHl],
      [64 | 0, 64 | 0, 64 | 0]
    ];
    exports2.MicrosoftOauth2ProviderConfigInput$ = [
      3,
      n032,
      _MOPCI,
      0,
      [_cI13, _cS4, _tIe],
      [0, [() => ClientSecretType, 0], 0],
      2
    ];
    exports2.MicrosoftOauth2ProviderConfigOutput$ = [
      3,
      n032,
      _MOPCO,
      0,
      [_oD, _cI13],
      [() => exports2.Oauth2Discovery$, 0],
      1
    ];
    exports2.ModifyInvocationConfigurationInput$ = [
      3,
      n032,
      _MICI,
      0,
      [_tA, _pDBN],
      [0, 0]
    ];
    exports2.ModifyMemoryStrategies$ = [
      3,
      n032,
      _MMS,
      0,
      [_aMS, _mMS, _dMS],
      [[() => MemoryStrategyInputList, 0], [() => ModifyMemoryStrategiesList, 0], () => DeleteMemoryStrategiesList]
    ];
    exports2.ModifyMemoryStrategyInput$ = [
      3,
      n032,
      _MMSI,
      0,
      [_mSI, _d, _na, _nT, _con],
      [0, [() => Description, 0], 64 | 0, 64 | 0, [() => exports2.ModifyStrategyConfiguration$, 0]],
      1
    ];
    exports2.ModifySelfManagedConfiguration$ = [
      3,
      n032,
      _MSMC,
      0,
      [_tCr, _iCnv, _hCWS],
      [() => TriggerConditionInputList, () => exports2.ModifyInvocationConfigurationInput$, 1]
    ];
    exports2.ModifyStrategyConfiguration$ = [
      3,
      n032,
      _MSC,
      0,
      [_ex10, _cons, _ref, _sMC],
      [[() => exports2.ModifyExtractionConfiguration$, 0], [() => exports2.ModifyConsolidationConfiguration$, 0], [() => exports2.ModifyReflectionConfiguration$, 0], () => exports2.ModifySelfManagedConfiguration$]
    ];
    exports2.NetworkConfiguration$ = [
      3,
      n032,
      _NC,
      0,
      [_nM, _nMC],
      [0, () => exports2.VpcConfig$],
      1
    ];
    exports2.NumericalScaleDefinition$ = [
      3,
      n032,
      _NSD,
      0,
      [_de, _v, _la],
      [0, 1, 0],
      3
    ];
    exports2.OAuth2AuthorizationData$ = [
      3,
      n032,
      _OAAD,
      0,
      [_aU, _uI],
      [0, 0],
      1
    ];
    exports2.Oauth2AuthorizationServerMetadata$ = [
      3,
      n032,
      _OASM,
      0,
      [_is, _aE, _tE, _rT13, _tEAM],
      [0, 0, 0, 64 | 0, 64 | 0],
      3
    ];
    exports2.Oauth2CredentialProviderItem$ = [
      3,
      n032,
      _OCPI,
      0,
      [_n, _cPV, _cPA, _cT, _lUT],
      [0, 0, 0, 4, 4],
      5
    ];
    exports2.OAuthCredentialProvider$ = [
      3,
      n032,
      _OACP,
      0,
      [_pAr, _sc4, _cPu, _gT13, _dRU],
      [0, 64 | 0, [() => OAuthCustomParameters, 0], 0, 0],
      2
    ];
    exports2.OnlineEvaluationConfigSummary$ = [
      3,
      n032,
      _OECS,
      0,
      [_oECA, _oECI, _oECN, _st, _eS, _cA, _uA, _d, _fR],
      [0, 0, 0, 0, 0, 4, 4, [() => EvaluationConfigDescription, 0], 0],
      7
    ];
    exports2.OutputConfig$ = [
      3,
      n032,
      _OC,
      0,
      [_cWC],
      [() => exports2.CloudWatchOutputConfig$],
      1
    ];
    exports2.Policy$ = [
      3,
      n032,
      _Po,
      0,
      [_pIo, _n, _pEI, _de, _cA, _uA, _pAo, _st, _sR, _d],
      [0, 0, 0, () => exports2.PolicyDefinition$, 5, 5, 0, 0, 64 | 0, [() => Description, 0]],
      9
    ];
    exports2.PolicyEngine$ = [
      3,
      n032,
      _PE,
      0,
      [_pEI, _n, _cA, _uA, _pEA, _st, _sR, _d, _eKA],
      [0, 0, 5, 5, 0, 0, 64 | 0, [() => Description, 0], 0],
      7
    ];
    exports2.PolicyGeneration$ = [
      3,
      n032,
      _PG,
      0,
      [_pEI, _pGI, _n, _pGA, _res, _cA, _uA, _st, _sR, _f],
      [0, 0, 0, 0, () => exports2.Resource$, 5, 5, 0, 64 | 0, 0],
      9
    ];
    exports2.PolicyGenerationAsset$ = [
      3,
      n032,
      _PGA,
      0,
      [_pGAI, _rTF, _f, _de],
      [0, 0, () => Findings, () => exports2.PolicyDefinition$],
      3
    ];
    exports2.PolicyGenerationDetails$ = [
      3,
      n032,
      _PGD,
      0,
      [_pGI, _pGAI],
      [0, 0],
      2
    ];
    exports2.ProtocolConfiguration$ = [
      3,
      n032,
      _PC10,
      0,
      [_sPe],
      [0],
      1
    ];
    exports2.PutResourcePolicyRequest$ = [
      3,
      n032,
      _PRPR,
      0,
      [_rAes, _po],
      [[0, 1], 0],
      2
    ];
    exports2.PutResourcePolicyResponse$ = [
      3,
      n032,
      _PRPRu,
      0,
      [_po],
      [0],
      1
    ];
    exports2.RecordingConfig$ = [
      3,
      n032,
      _RC10,
      0,
      [_en, _sL],
      [2, () => exports2.S3Location$]
    ];
    exports2.RegistryRecordCredentialProviderConfiguration$ = [
      3,
      n032,
      _RRCPC,
      0,
      [_cPT, _cP],
      [0, () => exports2.RegistryRecordCredentialProviderUnion$],
      2
    ];
    exports2.RegistryRecordIamCredentialProvider$ = [
      3,
      n032,
      _RRICP,
      0,
      [_rA, _ser, _reg],
      [0, 0, 0]
    ];
    exports2.RegistryRecordOAuthCredentialProvider$ = [
      3,
      n032,
      _RROACP,
      0,
      [_pAr, _gT13, _sc4, _cPu],
      [0, 0, 64 | 0, 128 | 0],
      1
    ];
    exports2.RegistryRecordSummary$ = [
      3,
      n032,
      _RRS,
      0,
      [_rAeg, _rAe, _rIe, _n, _dT, _rV, _st, _cA, _uA, _d],
      [0, 0, 0, 0, 0, 0, 0, 5, 5, [() => Description, 0]],
      9
    ];
    exports2.RegistrySummary$ = [
      3,
      n032,
      _RS,
      0,
      [_n, _rI, _rAeg, _st, _cA, _uA, _d, _aT22, _sRt],
      [0, 0, 0, 0, 5, 5, [() => Description, 0], 0, 0],
      6
    ];
    exports2.Rule$ = [
      3,
      n032,
      _R,
      0,
      [_sCa, _fi, _sCe],
      [() => exports2.SamplingConfig$, () => FilterList, () => exports2.SessionConfig$],
      1
    ];
    exports2.RuntimeMetadataConfiguration$ = [
      3,
      n032,
      _RMC,
      0,
      [_rMMDSV],
      [2],
      1
    ];
    exports2.S3Configuration$ = [
      3,
      n032,
      _SC,
      0,
      [_ur, _bOAI],
      [0, 0]
    ];
    exports2.S3Location$ = [
      3,
      n032,
      _SL,
      0,
      [_b, _pr, _vIe],
      [0, 0, 0],
      2
    ];
    exports2.SalesforceOauth2ProviderConfigInput$ = [
      3,
      n032,
      _SOPCI,
      0,
      [_cI13, _cS4],
      [0, [() => ClientSecretType, 0]],
      2
    ];
    exports2.SalesforceOauth2ProviderConfigOutput$ = [
      3,
      n032,
      _SOPCO,
      0,
      [_oD, _cI13],
      [() => exports2.Oauth2Discovery$, 0],
      1
    ];
    exports2.SamplingConfig$ = [
      3,
      n032,
      _SCa,
      0,
      [_sPa],
      [1],
      1
    ];
    exports2.SchemaDefinition$ = [
      3,
      n032,
      _SD,
      0,
      [_t, _pro, _req, _it, _d],
      [0, () => SchemaProperties, 64 | 0, () => exports2.SchemaDefinition$, 0],
      1
    ];
    exports2.Secret$ = [
      3,
      n032,
      _S,
      0,
      [_sA],
      [0],
      1
    ];
    exports2.SecretsManagerLocation$ = [
      3,
      n032,
      _SML,
      0,
      [_sA],
      [0],
      1
    ];
    exports2.SelfManagedConfiguration$ = [
      3,
      n032,
      _SMC,
      0,
      [_tCr, _iCnv, _hCWS],
      [() => TriggerConditionsList, () => exports2.InvocationConfiguration$, 1],
      3
    ];
    exports2.SelfManagedConfigurationInput$ = [
      3,
      n032,
      _SMCI,
      0,
      [_iCnv, _tCr, _hCWS],
      [() => exports2.InvocationConfigurationInput$, () => TriggerConditionInputList, 1],
      1
    ];
    exports2.SemanticConsolidationOverride$ = [
      3,
      n032,
      _SCO,
      0,
      [_aTP, _mI],
      [[() => Prompt, 0], 0],
      2
    ];
    exports2.SemanticExtractionOverride$ = [
      3,
      n032,
      _SEO,
      0,
      [_aTP, _mI],
      [[() => Prompt, 0], 0],
      2
    ];
    exports2.SemanticMemoryStrategyInput$ = [
      3,
      n032,
      _SMSI,
      0,
      [_n, _d, _na, _nT],
      [0, [() => Description, 0], 64 | 0, 64 | 0],
      1
    ];
    exports2.SemanticOverrideConfigurationInput$ = [
      3,
      n032,
      _SOCI,
      0,
      [_ex10, _cons],
      [[() => exports2.SemanticOverrideExtractionConfigurationInput$, 0], [() => exports2.SemanticOverrideConsolidationConfigurationInput$, 0]]
    ];
    exports2.SemanticOverrideConsolidationConfigurationInput$ = [
      3,
      n032,
      _SOCCI,
      0,
      [_aTP, _mI],
      [[() => Prompt, 0], 0],
      2
    ];
    exports2.SemanticOverrideExtractionConfigurationInput$ = [
      3,
      n032,
      _SOECI,
      0,
      [_aTP, _mI],
      [[() => Prompt, 0], 0],
      2
    ];
    exports2.ServerDefinition$ = [
      3,
      n032,
      _SDe,
      0,
      [_sV, _iC],
      [0, 0]
    ];
    exports2.SessionConfig$ = [
      3,
      n032,
      _SCe,
      0,
      [_sTM],
      [1],
      1
    ];
    exports2.SessionStorageConfiguration$ = [
      3,
      n032,
      _SSC,
      0,
      [_mP],
      [0],
      1
    ];
    exports2.SetTokenVaultCMKRequest$ = [
      3,
      n032,
      _STVCMKR,
      0,
      [_kC, _tVI],
      [() => exports2.KmsConfiguration$, 0],
      1
    ];
    exports2.SetTokenVaultCMKResponse$ = [
      3,
      n032,
      _STVCMKRe,
      0,
      [_tVI, _kC, _lMD],
      [0, () => exports2.KmsConfiguration$, 4],
      3
    ];
    exports2.SkillDefinition$ = [
      3,
      n032,
      _SDk,
      0,
      [_sV, _iC],
      [0, 0]
    ];
    exports2.SkillMdDefinition$ = [
      3,
      n032,
      _SMD,
      0,
      [_iC],
      [0]
    ];
    exports2.SlackOauth2ProviderConfigInput$ = [
      3,
      n032,
      _SOPCIl,
      0,
      [_cI13, _cS4],
      [0, [() => ClientSecretType, 0]],
      2
    ];
    exports2.SlackOauth2ProviderConfigOutput$ = [
      3,
      n032,
      _SOPCOl,
      0,
      [_oD, _cI13],
      [() => exports2.Oauth2Discovery$, 0],
      1
    ];
    exports2.StartPolicyGenerationRequest$ = [
      3,
      n032,
      _SPGR,
      0,
      [_pEI, _res, _cont, _n, _cTl],
      [[0, 1], () => exports2.Resource$, () => exports2.Content$, 0, [0, 4]],
      4
    ];
    exports2.StartPolicyGenerationResponse$ = [
      3,
      n032,
      _SPGRt,
      0,
      [_pEI, _pGI, _n, _pGA, _res, _cA, _uA, _st, _sR, _f],
      [0, 0, 0, 0, () => exports2.Resource$, 5, 5, 0, 64 | 0, 0],
      9
    ];
    exports2.StrategyConfiguration$ = [
      3,
      n032,
      _SCt,
      0,
      [_t, _ex10, _cons, _ref, _sMC],
      [0, [() => exports2.ExtractionConfiguration$, 0], [() => exports2.ConsolidationConfiguration$, 0], [() => exports2.ReflectionConfiguration$, 0], () => exports2.SelfManagedConfiguration$]
    ];
    exports2.StreamDeliveryResources$ = [
      3,
      n032,
      _SDR,
      0,
      [_reso],
      [() => StreamDeliveryResourcesList],
      1
    ];
    exports2.SubmitRegistryRecordForApprovalRequest$ = [
      3,
      n032,
      _SRRFAR,
      0,
      [_rI, _rIe],
      [[0, 1], [0, 1]],
      2
    ];
    exports2.SubmitRegistryRecordForApprovalResponse$ = [
      3,
      n032,
      _SRRFARu,
      0,
      [_rAeg, _rAe, _rIe, _st, _uA],
      [0, 0, 0, 0, 5],
      5
    ];
    exports2.SummaryConsolidationOverride$ = [
      3,
      n032,
      _SCOu,
      0,
      [_aTP, _mI],
      [[() => Prompt, 0], 0],
      2
    ];
    exports2.SummaryMemoryStrategyInput$ = [
      3,
      n032,
      _SMSIu,
      0,
      [_n, _d, _na, _nT],
      [0, [() => Description, 0], 64 | 0, 64 | 0],
      1
    ];
    exports2.SummaryOverrideConfigurationInput$ = [
      3,
      n032,
      _SOCIu,
      0,
      [_cons],
      [[() => exports2.SummaryOverrideConsolidationConfigurationInput$, 0]]
    ];
    exports2.SummaryOverrideConsolidationConfigurationInput$ = [
      3,
      n032,
      _SOCCIu,
      0,
      [_aTP, _mI],
      [[() => Prompt, 0], 0],
      2
    ];
    exports2.SynchronizationConfiguration$ = [
      3,
      n032,
      _SCy,
      0,
      [_fU],
      [() => exports2.FromUrlSynchronizationConfiguration$]
    ];
    exports2.SynchronizeGatewayTargetsRequest$ = [
      3,
      n032,
      _SGTR,
      0,
      [_gIa, _tIL],
      [[0, 1], 64 | 0],
      2
    ];
    exports2.SynchronizeGatewayTargetsResponse$ = [
      3,
      n032,
      _SGTRy,
      0,
      [_tar],
      [[() => GatewayTargetList, 0]]
    ];
    exports2.TagResourceRequest$ = [
      3,
      n032,
      _TRR,
      0,
      [_rAes, _ta],
      [[0, 1], 128 | 0],
      2
    ];
    exports2.TagResourceResponse$ = [
      3,
      n032,
      _TRRa,
      0,
      [],
      []
    ];
    exports2.TargetSummary$ = [
      3,
      n032,
      _TS,
      0,
      [_tI10, _n, _st, _cA, _uA, _d, _rP],
      [0, [() => TargetName, 0], 0, 5, 5, [() => TargetDescription, 0], 1],
      5
    ];
    exports2.TimeBasedTrigger$ = [
      3,
      n032,
      _TBT,
      0,
      [_iST],
      [1]
    ];
    exports2.TimeBasedTriggerInput$ = [
      3,
      n032,
      _TBTI,
      0,
      [_iST],
      [1]
    ];
    exports2.TokenBasedTrigger$ = [
      3,
      n032,
      _TBTo,
      0,
      [_tCo],
      [1]
    ];
    exports2.TokenBasedTriggerInput$ = [
      3,
      n032,
      _TBTIo,
      0,
      [_tCo],
      [1]
    ];
    exports2.ToolDefinition$ = [
      3,
      n032,
      _TDo,
      0,
      [_n, _d, _iS, _oS],
      [0, 0, () => exports2.SchemaDefinition$, () => exports2.SchemaDefinition$],
      3
    ];
    exports2.ToolsDefinition$ = [
      3,
      n032,
      _TDoo,
      0,
      [_pV, _iC],
      [0, 0]
    ];
    exports2.UntagResourceRequest$ = [
      3,
      n032,
      _URR,
      0,
      [_rAes, _tKa],
      [[0, 1], [64 | 0, { [_hQ10]: _tKa }]],
      2
    ];
    exports2.UntagResourceResponse$ = [
      3,
      n032,
      _URRn,
      0,
      [],
      []
    ];
    exports2.UpdateAgentRuntimeEndpointRequest$ = [
      3,
      n032,
      _UARER,
      0,
      [_aRI, _eN, _aRV, _d, _cTl],
      [[0, 1], [() => EndpointName, 1], 0, 0, [0, 4]],
      2
    ];
    exports2.UpdateAgentRuntimeEndpointResponse$ = [
      3,
      n032,
      _UARERp,
      0,
      [_aREA, _aRA, _st, _cA, _lUA, _lV, _tV],
      [0, 0, 0, 5, 5, 0, 0],
      5
    ];
    exports2.UpdateAgentRuntimeRequest$ = [
      3,
      n032,
      _UARR,
      0,
      [_aRI, _aRAg, _rA, _nC, _d, _aCu, _rHC, _pC, _lC, _mC, _eV, _fC, _cTl],
      [[0, 1], () => exports2.AgentRuntimeArtifact$, 0, () => exports2.NetworkConfiguration$, [() => Description, 0], () => exports2.AuthorizerConfiguration$, () => exports2.RequestHeaderConfiguration$, () => exports2.ProtocolConfiguration$, () => exports2.LifecycleConfiguration$, () => exports2.RuntimeMetadataConfiguration$, [() => EnvironmentVariablesMap, 0], () => FilesystemConfigurations, [0, 4]],
      4
    ];
    exports2.UpdateAgentRuntimeResponse$ = [
      3,
      n032,
      _UARRp,
      0,
      [_aRA, _aRI, _aRV, _cA, _lUA, _st, _wID],
      [0, 0, 0, 5, 5, 0, () => exports2.WorkloadIdentityDetails$],
      6
    ];
    exports2.UpdateApiKeyCredentialProviderRequest$ = [
      3,
      n032,
      _UAKCPR,
      0,
      [_n, _aK],
      [0, [() => ApiKeyType, 0]],
      2
    ];
    exports2.UpdateApiKeyCredentialProviderResponse$ = [
      3,
      n032,
      _UAKCPRp,
      0,
      [_aKSA, _n, _cPA, _cT, _lUT],
      [() => exports2.Secret$, 0, 0, 4, 4],
      5
    ];
    exports2.UpdatedA2aDescriptor$ = [
      3,
      n032,
      _UAD,
      0,
      [_oV],
      [() => exports2.A2aDescriptor$]
    ];
    exports2.UpdatedAgentSkillsDescriptor$ = [
      3,
      n032,
      _UASD,
      0,
      [_oV],
      [() => exports2.UpdatedAgentSkillsDescriptorFields$]
    ];
    exports2.UpdatedAgentSkillsDescriptorFields$ = [
      3,
      n032,
      _UASDF,
      0,
      [_sM, _sD],
      [() => exports2.UpdatedSkillMdDefinition$, () => exports2.UpdatedSkillDefinition$]
    ];
    exports2.UpdatedApprovalConfiguration$ = [
      3,
      n032,
      _UAC,
      0,
      [_oV],
      [() => exports2.ApprovalConfiguration$]
    ];
    exports2.UpdatedAuthorizerConfiguration$ = [
      3,
      n032,
      _UACp,
      0,
      [_oV],
      [() => exports2.AuthorizerConfiguration$]
    ];
    exports2.UpdatedCustomDescriptor$ = [
      3,
      n032,
      _UCD,
      0,
      [_oV],
      [() => exports2.CustomDescriptor$]
    ];
    exports2.UpdatedDescription$ = [
      3,
      n032,
      _UD,
      0,
      [_oV],
      [[() => Description, 0]]
    ];
    exports2.UpdatedDescriptors$ = [
      3,
      n032,
      _UDp,
      0,
      [_oV],
      [() => exports2.UpdatedDescriptorsUnion$]
    ];
    exports2.UpdatedDescriptorsUnion$ = [
      3,
      n032,
      _UDU,
      0,
      [_mc, _a10, _cu, _aSg],
      [() => exports2.UpdatedMcpDescriptor$, () => exports2.UpdatedA2aDescriptor$, () => exports2.UpdatedCustomDescriptor$, () => exports2.UpdatedAgentSkillsDescriptor$]
    ];
    exports2.UpdatedHarnessEnvironmentArtifact$ = [
      3,
      n032,
      _UHEA,
      0,
      [_oV],
      [() => exports2.HarnessEnvironmentArtifact$]
    ];
    exports2.UpdatedHarnessMemoryConfiguration$ = [
      3,
      n032,
      _UHMC,
      0,
      [_oV],
      [() => exports2.HarnessMemoryConfiguration$]
    ];
    exports2.UpdatedMcpDescriptor$ = [
      3,
      n032,
      _UMD,
      0,
      [_oV],
      [() => exports2.UpdatedMcpDescriptorFields$]
    ];
    exports2.UpdatedMcpDescriptorFields$ = [
      3,
      n032,
      _UMDF,
      0,
      [_se14, _to],
      [() => exports2.UpdatedServerDefinition$, () => exports2.UpdatedToolsDefinition$]
    ];
    exports2.UpdatedServerDefinition$ = [
      3,
      n032,
      _USD,
      0,
      [_oV],
      [() => exports2.ServerDefinition$]
    ];
    exports2.UpdatedSkillDefinition$ = [
      3,
      n032,
      _USDp,
      0,
      [_oV],
      [() => exports2.SkillDefinition$]
    ];
    exports2.UpdatedSkillMdDefinition$ = [
      3,
      n032,
      _USMD,
      0,
      [_oV],
      [() => exports2.SkillMdDefinition$]
    ];
    exports2.UpdatedSynchronizationConfiguration$ = [
      3,
      n032,
      _USC,
      0,
      [_oV],
      [() => exports2.SynchronizationConfiguration$]
    ];
    exports2.UpdatedSynchronizationType$ = [
      3,
      n032,
      _UST,
      0,
      [_oV],
      [0]
    ];
    exports2.UpdatedToolsDefinition$ = [
      3,
      n032,
      _UTD,
      0,
      [_oV],
      [() => exports2.ToolsDefinition$]
    ];
    exports2.UpdateEvaluatorRequest$ = [
      3,
      n032,
      _UER,
      0,
      [_eI13, _cTl, _d, _eC, _le],
      [[0, 1], [0, 4], [() => EvaluatorDescription, 0], [() => exports2.EvaluatorConfig$, 0], 0],
      1
    ];
    exports2.UpdateEvaluatorResponse$ = [
      3,
      n032,
      _UERp,
      0,
      [_eA, _eI13, _uA, _st],
      [0, 0, 4, 0],
      4
    ];
    exports2.UpdateGatewayRequest$ = [
      3,
      n032,
      _UGR,
      0,
      [_gIa, _n, _rA, _pT, _aT22, _d, _pC, _aCu, _kKA, _iCnt, _pEC, _eL],
      [[0, 1], [() => GatewayName, 0], 0, 0, 0, [() => GatewayDescription, 0], () => exports2.GatewayProtocolConfiguration$, () => exports2.AuthorizerConfiguration$, 0, () => GatewayInterceptorConfigurations, () => exports2.GatewayPolicyEngineConfiguration$, 0],
      5
    ];
    exports2.UpdateGatewayResponse$ = [
      3,
      n032,
      _UGRp,
      0,
      [_gA, _gI, _cA, _uA, _st, _n, _pT, _aT22, _gU, _sR, _d, _rA, _pC, _aCu, _kKA, _iCnt, _pEC, _wID, _eL],
      [0, 0, 5, 5, 0, [() => GatewayName, 0], 0, 0, 0, 64 | 0, [() => GatewayDescription, 0], 0, () => exports2.GatewayProtocolConfiguration$, () => exports2.AuthorizerConfiguration$, 0, () => GatewayInterceptorConfigurations, () => exports2.GatewayPolicyEngineConfiguration$, () => exports2.WorkloadIdentityDetails$, 0],
      8
    ];
    exports2.UpdateGatewayTargetRequest$ = [
      3,
      n032,
      _UGTR,
      0,
      [_gIa, _tI10, _n, _tC, _d, _cPC, _mC, _pE],
      [[0, 1], [0, 1], [() => TargetName, 0], [() => exports2.TargetConfiguration$, 0], [() => TargetDescription, 0], [() => CredentialProviderConfigurations, 0], () => exports2.MetadataConfiguration$, () => exports2.PrivateEndpoint$],
      4
    ];
    exports2.UpdateGatewayTargetResponse$ = [
      3,
      n032,
      _UGTRp,
      0,
      [_gA, _tI10, _cA, _uA, _st, _n, _tC, _cPC, _sR, _d, _lSAa, _mC, _pE, _pEMR, _aD],
      [0, 0, 5, 5, 0, [() => TargetName, 0], [() => exports2.TargetConfiguration$, 0], [() => CredentialProviderConfigurations, 0], 64 | 0, [() => TargetDescription, 0], 5, () => exports2.MetadataConfiguration$, () => exports2.PrivateEndpoint$, () => PrivateEndpointManagedResources, () => exports2.AuthorizationData$],
      8
    ];
    exports2.UpdateHarnessRequest$ = [
      3,
      n032,
      _UHR,
      0,
      [_hI, _cTl, _eRA, _env, _eAn, _eV, _aCu, _mo, _sP, _to, _sk, _aTl, _mem, _tr, _mIa, _mT, _tS],
      [[0, 1], [0, 4], 0, () => exports2.HarnessEnvironmentProviderRequest$, () => exports2.UpdatedHarnessEnvironmentArtifact$, [() => EnvironmentVariablesMap, 0], () => exports2.UpdatedAuthorizerConfiguration$, () => exports2.HarnessModelConfiguration$, [() => HarnessSystemPrompt, 0], [() => HarnessTools, 0], () => HarnessSkills, 64 | 0, () => exports2.UpdatedHarnessMemoryConfiguration$, () => exports2.HarnessTruncationConfiguration$, 1, 1, 1],
      1
    ];
    exports2.UpdateHarnessResponse$ = [
      3,
      n032,
      _UHRp,
      0,
      [_h22],
      [[() => exports2.Harness$, 0]],
      1
    ];
    exports2.UpdateMemoryInput$ = [
      3,
      n032,
      _UMI,
      0,
      [_mIe, _cTl, _d, _eED, _mERA, _mS, _sDR],
      [[0, 1], [0, 4], [() => Description, 0], 1, 0, [() => exports2.ModifyMemoryStrategies$, 0], () => exports2.StreamDeliveryResources$],
      1
    ];
    exports2.UpdateMemoryOutput$ = [
      3,
      n032,
      _UMO,
      0,
      [_mem],
      [[() => exports2.Memory$, 0]]
    ];
    exports2.UpdateOauth2CredentialProviderRequest$ = [
      3,
      n032,
      _UOCPR,
      0,
      [_n, _cPV, _oPCI],
      [0, 0, [() => exports2.Oauth2ProviderConfigInput$, 0]],
      3
    ];
    exports2.UpdateOauth2CredentialProviderResponse$ = [
      3,
      n032,
      _UOCPRp,
      0,
      [_cSA, _n, _cPV, _cPA, _oPCO, _cT, _lUT, _cUa],
      [() => exports2.Secret$, 0, 0, 0, () => exports2.Oauth2ProviderConfigOutput$, 4, 4, 0],
      7
    ];
    exports2.UpdateOnlineEvaluationConfigRequest$ = [
      3,
      n032,
      _UOECR,
      0,
      [_oECI, _cTl, _d, _rul, _dSC, _ev, _eERA, _eS],
      [[0, 1], [0, 4], [() => EvaluationConfigDescription, 0], () => exports2.Rule$, () => exports2.DataSourceConfig$, () => EvaluatorList, 0, 0],
      1
    ];
    exports2.UpdateOnlineEvaluationConfigResponse$ = [
      3,
      n032,
      _UOECRp,
      0,
      [_oECA, _oECI, _uA, _st, _eS, _fR],
      [0, 0, 4, 0, 0, 0],
      5
    ];
    exports2.UpdatePolicyEngineRequest$ = [
      3,
      n032,
      _UPER,
      0,
      [_pEI, _d],
      [[0, 1], [() => exports2.UpdatedDescription$, 0]],
      1
    ];
    exports2.UpdatePolicyEngineResponse$ = [
      3,
      n032,
      _UPERp,
      0,
      [_pEI, _n, _cA, _uA, _pEA, _st, _sR, _d, _eKA],
      [0, 0, 5, 5, 0, 0, 64 | 0, [() => Description, 0], 0],
      7
    ];
    exports2.UpdatePolicyRequest$ = [
      3,
      n032,
      _UPR,
      0,
      [_pEI, _pIo, _d, _de, _vM],
      [[0, 1], [0, 1], [() => exports2.UpdatedDescription$, 0], () => exports2.PolicyDefinition$, 0],
      2
    ];
    exports2.UpdatePolicyResponse$ = [
      3,
      n032,
      _UPRp,
      0,
      [_pIo, _n, _pEI, _de, _cA, _uA, _pAo, _st, _sR, _d],
      [0, 0, 0, () => exports2.PolicyDefinition$, 5, 5, 0, 0, 64 | 0, [() => Description, 0]],
      9
    ];
    exports2.UpdateRegistryRecordRequest$ = [
      3,
      n032,
      _URRR,
      0,
      [_rI, _rIe, _n, _d, _dT, _des, _rV, _sT19, _sC, _tSr],
      [[0, 1], [0, 1], 0, [() => exports2.UpdatedDescription$, 0], 0, () => exports2.UpdatedDescriptors$, 0, () => exports2.UpdatedSynchronizationType$, () => exports2.UpdatedSynchronizationConfiguration$, 2],
      2
    ];
    exports2.UpdateRegistryRecordResponse$ = [
      3,
      n032,
      _URRRp,
      0,
      [_rAeg, _rAe, _rIe, _n, _dT, _des, _st, _cA, _uA, _d, _rV, _sRt, _sT19, _sC],
      [0, 0, 0, 0, 0, () => exports2.Descriptors$, 0, 5, 5, [() => Description, 0], 0, 0, 0, () => exports2.SynchronizationConfiguration$],
      9
    ];
    exports2.UpdateRegistryRecordStatusRequest$ = [
      3,
      n032,
      _URRSR,
      0,
      [_rI, _rIe, _st, _sRt],
      [[0, 1], [0, 1], 0, 0],
      4
    ];
    exports2.UpdateRegistryRecordStatusResponse$ = [
      3,
      n032,
      _URRSRp,
      0,
      [_rAeg, _rAe, _rIe, _st, _sRt, _uA],
      [0, 0, 0, 0, 0, 5],
      6
    ];
    exports2.UpdateRegistryRequest$ = [
      3,
      n032,
      _URRp,
      0,
      [_rI, _n, _d, _aCu, _aCp],
      [[0, 1], 0, [() => exports2.UpdatedDescription$, 0], () => exports2.UpdatedAuthorizerConfiguration$, () => exports2.UpdatedApprovalConfiguration$],
      1
    ];
    exports2.UpdateRegistryResponse$ = [
      3,
      n032,
      _URRpd,
      0,
      [_n, _rI, _rAeg, _st, _cA, _uA, _d, _aT22, _aCu, _aCp, _sRt],
      [0, 0, 0, 0, 5, 5, [() => Description, 0], 0, () => exports2.AuthorizerConfiguration$, () => exports2.ApprovalConfiguration$, 0],
      6
    ];
    exports2.UpdateWorkloadIdentityRequest$ = [
      3,
      n032,
      _UWIR,
      0,
      [_n, _aRORU],
      [0, 64 | 0],
      1
    ];
    exports2.UpdateWorkloadIdentityResponse$ = [
      3,
      n032,
      _UWIRp,
      0,
      [_n, _wIA, _cT, _lUT, _aRORU],
      [0, 0, 4, 4, 64 | 0],
      4
    ];
    exports2.UserPreferenceConsolidationOverride$ = [
      3,
      n032,
      _UPCO,
      0,
      [_aTP, _mI],
      [[() => Prompt, 0], 0],
      2
    ];
    exports2.UserPreferenceExtractionOverride$ = [
      3,
      n032,
      _UPEO,
      0,
      [_aTP, _mI],
      [[() => Prompt, 0], 0],
      2
    ];
    exports2.UserPreferenceMemoryStrategyInput$ = [
      3,
      n032,
      _UPMSI,
      0,
      [_n, _d, _na, _nT],
      [0, [() => Description, 0], 64 | 0, 64 | 0],
      1
    ];
    exports2.UserPreferenceOverrideConfigurationInput$ = [
      3,
      n032,
      _UPOCI,
      0,
      [_ex10, _cons],
      [[() => exports2.UserPreferenceOverrideExtractionConfigurationInput$, 0], [() => exports2.UserPreferenceOverrideConsolidationConfigurationInput$, 0]]
    ];
    exports2.UserPreferenceOverrideConsolidationConfigurationInput$ = [
      3,
      n032,
      _UPOCCI,
      0,
      [_aTP, _mI],
      [[() => Prompt, 0], 0],
      2
    ];
    exports2.UserPreferenceOverrideExtractionConfigurationInput$ = [
      3,
      n032,
      _UPOECI,
      0,
      [_aTP, _mI],
      [[() => Prompt, 0], 0],
      2
    ];
    exports2.ValidationExceptionField$ = [
      3,
      n032,
      _VEF,
      0,
      [_n, _m29],
      [0, 0],
      2
    ];
    exports2.VpcConfig$ = [
      3,
      n032,
      _VC,
      0,
      [_sG, _su],
      [64 | 0, 64 | 0],
      2
    ];
    exports2.WorkloadIdentityDetails$ = [
      3,
      n032,
      _WID,
      0,
      [_wIA],
      [0],
      1
    ];
    exports2.WorkloadIdentityType$ = [
      3,
      n032,
      _WIT10,
      0,
      [_n, _wIA],
      [0, 0],
      2
    ];
    var __Unit = "unit";
    var AgentRuntimeEndpoints = [
      1,
      n032,
      _AREg,
      0,
      [
        () => exports2.AgentRuntimeEndpoint$,
        0
      ]
    ];
    var AgentRuntimes = [
      1,
      n032,
      _ARg,
      0,
      [
        () => exports2.AgentRuntime$,
        0
      ]
    ];
    var AllowedAudienceList = 64 | 0;
    var AllowedClientsList = 64 | 0;
    var AllowedQueryParameters = 64 | 0;
    var AllowedRequestHeaders = 64 | 0;
    var AllowedResponseHeaders = 64 | 0;
    var AllowedScopesType = 64 | 0;
    var ApiGatewayToolFilters = [
      1,
      n032,
      _AGTFp,
      0,
      () => exports2.ApiGatewayToolFilter$
    ];
    var ApiGatewayToolOverrides = [
      1,
      n032,
      _AGTOp,
      0,
      () => exports2.ApiGatewayToolOverride$
    ];
    var ApiKeyCredentialProviders = [
      1,
      n032,
      _AKCP,
      0,
      () => exports2.ApiKeyCredentialProviderItem$
    ];
    var BrowserEnterprisePolicies = [
      1,
      n032,
      _BEPr,
      0,
      () => exports2.BrowserEnterprisePolicy$
    ];
    var BrowserProfileSummaries = [
      1,
      n032,
      _BPSr,
      0,
      [
        () => exports2.BrowserProfileSummary$,
        0
      ]
    ];
    var BrowserSummaries = [
      1,
      n032,
      _BSr,
      0,
      [
        () => exports2.BrowserSummary$,
        0
      ]
    ];
    var CategoricalScaleDefinitions = [
      1,
      n032,
      _CSDa,
      0,
      () => exports2.CategoricalScaleDefinition$
    ];
    var Certificates = [
      1,
      n032,
      _Ce,
      0,
      () => exports2.Certificate$
    ];
    var CodeInterpreterSummaries = [
      1,
      n032,
      _CISo,
      0,
      [
        () => exports2.CodeInterpreterSummary$,
        0
      ]
    ];
    var ContentConfigurationList = [
      1,
      n032,
      _CCL,
      0,
      () => exports2.ContentConfiguration$
    ];
    var CredentialProviderConfigurations = [
      1,
      n032,
      _CPCr,
      0,
      [
        () => exports2.CredentialProviderConfiguration$,
        0
      ]
    ];
    var CustomClaimValidationsType = [
      1,
      n032,
      _CCVTu,
      0,
      () => exports2.CustomClaimValidationType$
    ];
    var DeleteMemoryStrategiesList = [
      1,
      n032,
      _DMSL,
      0,
      () => exports2.DeleteMemoryStrategyInput$
    ];
    var EntryPoints = 64 | 0;
    var EvaluatorList = [
      1,
      n032,
      _EL,
      0,
      () => exports2.EvaluatorReference$
    ];
    var EvaluatorSummaryList = [
      1,
      n032,
      _ESL,
      0,
      [
        () => exports2.EvaluatorSummary$,
        0
      ]
    ];
    var FilesystemConfigurations = [
      1,
      n032,
      _FC,
      0,
      () => exports2.FilesystemConfiguration$
    ];
    var FilterList = [
      1,
      n032,
      _FL,
      0,
      () => exports2.Filter$
    ];
    var Findings = [
      1,
      n032,
      _Fin,
      0,
      () => exports2.Finding$
    ];
    var GatewayInterceptionPoints = 64 | 0;
    var GatewayInterceptorConfigurations = [
      1,
      n032,
      _GICa,
      0,
      () => exports2.GatewayInterceptorConfiguration$
    ];
    var GatewaySummaries = [
      1,
      n032,
      _GSa,
      0,
      [
        () => exports2.GatewaySummary$,
        0
      ]
    ];
    var GatewayTargetList = [
      1,
      n032,
      _GTL,
      0,
      [
        () => exports2.GatewayTarget$,
        0
      ]
    ];
    var HarnessAllowedTools = 64 | 0;
    var HarnessSkills = [
      1,
      n032,
      _HSa,
      0,
      () => exports2.HarnessSkill$
    ];
    var HarnessSummaries = [
      1,
      n032,
      _HSar,
      0,
      () => exports2.HarnessSummary$
    ];
    var HarnessSystemPrompt = [
      1,
      n032,
      _HSP,
      0,
      [
        () => exports2.HarnessSystemContentBlock$,
        0
      ]
    ];
    var HarnessTools = [
      1,
      n032,
      _HTa,
      0,
      [
        () => exports2.HarnessTool$,
        0
      ]
    ];
    var LogGroupNamesList = 64 | 0;
    var MatchValueStringList = 64 | 0;
    var McpSupportedVersions = 64 | 0;
    var MemoryStrategyInputList = [
      1,
      n032,
      _MSIL,
      0,
      [
        () => exports2.MemoryStrategyInput$,
        0
      ]
    ];
    var MemoryStrategyList = [
      1,
      n032,
      _MSL,
      0,
      [
        () => exports2.MemoryStrategy$,
        0
      ]
    ];
    var MemorySummaryList = [
      1,
      n032,
      _MSLe,
      0,
      () => exports2.MemorySummary$
    ];
    var ModifyMemoryStrategiesList = [
      1,
      n032,
      _MMSL,
      0,
      [
        () => exports2.ModifyMemoryStrategyInput$,
        0
      ]
    ];
    var NamespacesList = 64 | 0;
    var NonEmptyStringList = 64 | 0;
    var NumericalScaleDefinitions = [
      1,
      n032,
      _NSDu,
      0,
      () => exports2.NumericalScaleDefinition$
    ];
    var Oauth2CredentialProviders = [
      1,
      n032,
      _OCP,
      0,
      () => exports2.Oauth2CredentialProviderItem$
    ];
    var OAuthScopes = 64 | 0;
    var OnlineEvaluationConfigSummaryList = [
      1,
      n032,
      _OECSL,
      0,
      [
        () => exports2.OnlineEvaluationConfigSummary$,
        0
      ]
    ];
    var Policies = [
      1,
      n032,
      _Pol,
      0,
      [
        () => exports2.Policy$,
        0
      ]
    ];
    var PolicyEngines = [
      1,
      n032,
      _PEo,
      0,
      [
        () => exports2.PolicyEngine$,
        0
      ]
    ];
    var PolicyGenerationAssets = [
      1,
      n032,
      _PGAo,
      0,
      () => exports2.PolicyGenerationAsset$
    ];
    var PolicyGenerations = [
      1,
      n032,
      _PGo,
      0,
      () => exports2.PolicyGeneration$
    ];
    var PolicyStatusReasons = 64 | 0;
    var PrivateEndpointManagedResources = [
      1,
      n032,
      _PEMR,
      0,
      () => exports2.ManagedResourceDetails$
    ];
    var RegistryRecordCredentialProviderConfigurationList = [
      1,
      n032,
      _RRCPCL,
      0,
      () => exports2.RegistryRecordCredentialProviderConfiguration$
    ];
    var RegistryRecordSummaryList = [
      1,
      n032,
      _RRSL,
      0,
      [
        () => exports2.RegistryRecordSummary$,
        0
      ]
    ];
    var RegistrySummaryList = [
      1,
      n032,
      _RSL,
      0,
      [
        () => exports2.RegistrySummary$,
        0
      ]
    ];
    var RequestHeaderAllowlist = 64 | 0;
    var RequiredProperties = 64 | 0;
    var ResourceOauth2ReturnUrlListType = 64 | 0;
    var ResponseListType = 64 | 0;
    var RestApiMethods = 64 | 0;
    var ScopeList = 64 | 0;
    var SecurityGroupIds = 64 | 0;
    var SecurityGroups = 64 | 0;
    var ServiceNamesList = 64 | 0;
    var StatusReasons = 64 | 0;
    var StreamDeliveryResourcesList = [
      1,
      n032,
      _SDRL,
      0,
      () => exports2.StreamDeliveryResource$
    ];
    var SubnetIds = 64 | 0;
    var Subnets = 64 | 0;
    var TagKeyList = 64 | 0;
    var TargetIdList = 64 | 0;
    var TargetSummaries = [
      1,
      n032,
      _TSa,
      0,
      [
        () => exports2.TargetSummary$,
        0
      ]
    ];
    var TokenEndpointAuthMethodsType = 64 | 0;
    var ToolDefinitions = [
      1,
      n032,
      _TDool,
      0,
      () => exports2.ToolDefinition$
    ];
    var TriggerConditionInputList = [
      1,
      n032,
      _TCIL,
      0,
      () => exports2.TriggerConditionInput$
    ];
    var TriggerConditionsList = [
      1,
      n032,
      _TCL,
      0,
      () => exports2.TriggerCondition$
    ];
    var ValidationExceptionFieldList = [
      1,
      n032,
      _VEFL,
      0,
      () => exports2.ValidationExceptionField$
    ];
    var WorkloadIdentityList = [
      1,
      n032,
      _WIL,
      0,
      () => exports2.WorkloadIdentityType$
    ];
    var CustomParameterMap = 128 | 0;
    var EnvironmentVariablesMap = [
      2,
      n032,
      _EVM,
      8,
      0,
      0
    ];
    var HarnessAgentCoreMemoryRetrievalConfigs = [
      2,
      n032,
      _HACMRCa,
      0,
      0,
      () => exports2.HarnessAgentCoreMemoryRetrievalConfig$
    ];
    var HttpHeadersMap = [
      2,
      n032,
      _HHM,
      8,
      0,
      0
    ];
    var OAuthCustomParameters = [
      2,
      n032,
      _OACPu,
      0,
      [
        0,
        0
      ],
      [
        () => OAuthCustomParametersValue,
        0
      ]
    ];
    var SchemaProperties = [
      2,
      n032,
      _SP,
      0,
      0,
      () => exports2.SchemaDefinition$
    ];
    var TagsMap = 128 | 0;
    exports2.AgentRuntimeArtifact$ = [
      4,
      n032,
      _ARA,
      0,
      [_cCon, _cCod],
      [() => exports2.ContainerConfiguration$, () => exports2.CodeConfiguration$]
    ];
    exports2.ApiSchemaConfiguration$ = [
      4,
      n032,
      _ASC,
      0,
      [_s_, _iPn],
      [() => exports2.S3Configuration$, [() => InlinePayload, 0]]
    ];
    exports2.AuthorizationData$ = [
      4,
      n032,
      _ADu,
      0,
      [_oa],
      [() => exports2.OAuth2AuthorizationData$]
    ];
    exports2.AuthorizerConfiguration$ = [
      4,
      n032,
      _ACu,
      0,
      [_cJWTA],
      [() => exports2.CustomJWTAuthorizerConfiguration$]
    ];
    exports2.CertificateLocation$ = [
      4,
      n032,
      _CL,
      0,
      [_sMe],
      [() => exports2.SecretsManagerLocation$]
    ];
    exports2.ClaimMatchValueType$ = [
      4,
      n032,
      _CMVT,
      0,
      [_mVS, _mVSL],
      [0, 64 | 0]
    ];
    exports2.Code$ = [
      4,
      n032,
      _Co,
      0,
      [_s_],
      [() => exports2.S3Location$]
    ];
    exports2.CodeBasedEvaluatorConfig$ = [
      4,
      n032,
      _CBEC,
      0,
      [_lCa],
      [() => exports2.LambdaEvaluatorConfig$]
    ];
    exports2.ConsolidationConfiguration$ = [
      4,
      n032,
      _CCons,
      0,
      [_cCC],
      [[() => exports2.CustomConsolidationConfiguration$, 0]]
    ];
    exports2.Content$ = [
      4,
      n032,
      _Con,
      0,
      [_rTa],
      [0]
    ];
    exports2.CredentialProvider$ = [
      4,
      n032,
      _CPr,
      0,
      [_oCP, _aKCP, _iCP],
      [[() => exports2.OAuthCredentialProvider$, 0], () => exports2.GatewayApiKeyCredentialProvider$, () => exports2.IamCredentialProvider$]
    ];
    exports2.CustomConfigurationInput$ = [
      4,
      n032,
      _CCI,
      0,
      [_sO, _sOu, _uPO, _eO, _sMC],
      [[() => exports2.SemanticOverrideConfigurationInput$, 0], [() => exports2.SummaryOverrideConfigurationInput$, 0], [() => exports2.UserPreferenceOverrideConfigurationInput$, 0], [() => exports2.EpisodicOverrideConfigurationInput$, 0], () => exports2.SelfManagedConfigurationInput$]
    ];
    exports2.CustomConsolidationConfiguration$ = [
      4,
      n032,
      _CCC,
      0,
      [_sCO, _sCOu, _uPCO, _eCO],
      [[() => exports2.SemanticConsolidationOverride$, 0], [() => exports2.SummaryConsolidationOverride$, 0], [() => exports2.UserPreferenceConsolidationOverride$, 0], [() => exports2.EpisodicConsolidationOverride$, 0]]
    ];
    exports2.CustomConsolidationConfigurationInput$ = [
      4,
      n032,
      _CCCI,
      0,
      [_sCO, _sCOu, _uPCO, _eCO],
      [[() => exports2.SemanticOverrideConsolidationConfigurationInput$, 0], [() => exports2.SummaryOverrideConsolidationConfigurationInput$, 0], [() => exports2.UserPreferenceOverrideConsolidationConfigurationInput$, 0], [() => exports2.EpisodicOverrideConsolidationConfigurationInput$, 0]]
    ];
    exports2.CustomExtractionConfiguration$ = [
      4,
      n032,
      _CEC,
      0,
      [_sEO, _uPEO, _eEO],
      [[() => exports2.SemanticExtractionOverride$, 0], [() => exports2.UserPreferenceExtractionOverride$, 0], [() => exports2.EpisodicExtractionOverride$, 0]]
    ];
    exports2.CustomExtractionConfigurationInput$ = [
      4,
      n032,
      _CECI,
      0,
      [_sEO, _uPEO, _eEO],
      [[() => exports2.SemanticOverrideExtractionConfigurationInput$, 0], [() => exports2.UserPreferenceOverrideExtractionConfigurationInput$, 0], [() => exports2.EpisodicOverrideExtractionConfigurationInput$, 0]]
    ];
    exports2.CustomReflectionConfiguration$ = [
      4,
      n032,
      _CRC,
      0,
      [_eRO],
      [[() => exports2.EpisodicReflectionOverride$, 0]]
    ];
    exports2.CustomReflectionConfigurationInput$ = [
      4,
      n032,
      _CRCI,
      0,
      [_eRO],
      [[() => exports2.EpisodicOverrideReflectionConfigurationInput$, 0]]
    ];
    exports2.DataSourceConfig$ = [
      4,
      n032,
      _DSC,
      0,
      [_cWL],
      [() => exports2.CloudWatchLogsInputConfig$]
    ];
    exports2.EvaluatorConfig$ = [
      4,
      n032,
      _EC,
      0,
      [_lAAJ, _cB],
      [[() => exports2.LlmAsAJudgeEvaluatorConfig$, 0], () => exports2.CodeBasedEvaluatorConfig$]
    ];
    exports2.EvaluatorModelConfig$ = [
      4,
      n032,
      _EMC,
      0,
      [_bEMC],
      [() => exports2.BedrockEvaluatorModelConfig$]
    ];
    exports2.EvaluatorReference$ = [
      4,
      n032,
      _ER,
      0,
      [_eI13],
      [0]
    ];
    exports2.ExtractionConfiguration$ = [
      4,
      n032,
      _ECx,
      0,
      [_cEC],
      [[() => exports2.CustomExtractionConfiguration$, 0]]
    ];
    exports2.FilesystemConfiguration$ = [
      4,
      n032,
      _FCi,
      0,
      [_sSe],
      [() => exports2.SessionStorageConfiguration$]
    ];
    exports2.FilterValue$ = [
      4,
      n032,
      _FV,
      0,
      [_sVt, _dV, _bV],
      [0, 1, 2]
    ];
    exports2.GatewayProtocolConfiguration$ = [
      4,
      n032,
      _GPC,
      0,
      [_mc],
      [() => exports2.MCPGatewayConfiguration$]
    ];
    exports2.HarnessEnvironmentArtifact$ = [
      4,
      n032,
      _HEA,
      0,
      [_cCon],
      [() => exports2.ContainerConfiguration$]
    ];
    exports2.HarnessEnvironmentProvider$ = [
      4,
      n032,
      _HEP,
      0,
      [_aCRE],
      [() => exports2.HarnessAgentCoreRuntimeEnvironment$]
    ];
    exports2.HarnessEnvironmentProviderRequest$ = [
      4,
      n032,
      _HEPR,
      0,
      [_aCRE],
      [() => exports2.HarnessAgentCoreRuntimeEnvironmentRequest$]
    ];
    exports2.HarnessGatewayOutboundAuth$ = [
      4,
      n032,
      _HGOA,
      0,
      [_aIw, _no, _oau],
      [() => __Unit, () => __Unit, [() => exports2.OAuthCredentialProvider$, 0]]
    ];
    exports2.HarnessMemoryConfiguration$ = [
      4,
      n032,
      _HMC,
      0,
      [_aCMC],
      [() => exports2.HarnessAgentCoreMemoryConfiguration$]
    ];
    exports2.HarnessModelConfiguration$ = [
      4,
      n032,
      _HMCa,
      0,
      [_bMC, _oAMC, _gMC],
      [() => exports2.HarnessBedrockModelConfig$, () => exports2.HarnessOpenAiModelConfig$, () => exports2.HarnessGeminiModelConfig$]
    ];
    exports2.HarnessSkill$ = [
      4,
      n032,
      _HSarn,
      0,
      [_p],
      [0]
    ];
    exports2.HarnessSystemContentBlock$ = [
      4,
      n032,
      _HSCB,
      0,
      [_tex],
      [[() => SensitiveText, 0]]
    ];
    exports2.HarnessToolConfiguration$ = [
      4,
      n032,
      _HTCa,
      0,
      [_rM, _aCB, _aCG, _iF, _aCCI],
      [[() => exports2.HarnessRemoteMcpConfig$, 0], () => exports2.HarnessAgentCoreBrowserConfig$, [() => exports2.HarnessAgentCoreGatewayConfig$, 0], [() => exports2.HarnessInlineFunctionConfig$, 0], () => exports2.HarnessAgentCoreCodeInterpreterConfig$]
    ];
    exports2.HarnessTruncationStrategyConfiguration$ = [
      4,
      n032,
      _HTSC,
      0,
      [_sW, _sum],
      [() => exports2.HarnessSlidingWindowConfiguration$, () => exports2.HarnessSummarizationConfiguration$]
    ];
    exports2.InterceptorConfiguration$ = [
      4,
      n032,
      _ICnt,
      0,
      [_lam],
      [() => exports2.LambdaInterceptorConfiguration$]
    ];
    exports2.McpTargetConfiguration$ = [
      4,
      n032,
      _MTC,
      0,
      [_oAS, _sMm, _lam, _mSc, _aG],
      [[() => exports2.ApiSchemaConfiguration$, 0], [() => exports2.ApiSchemaConfiguration$, 0], () => exports2.McpLambdaTargetConfiguration$, [() => exports2.McpServerTargetConfiguration$, 0], () => exports2.ApiGatewayTargetConfiguration$]
    ];
    exports2.McpToolSchemaConfiguration$ = [
      4,
      n032,
      _MTSC,
      0,
      [_s_, _iPn],
      [() => exports2.S3Configuration$, [() => InlinePayload, 0]]
    ];
    exports2.MemoryStrategyInput$ = [
      4,
      n032,
      _MSI,
      0,
      [_sMS, _sMSu, _uPMS, _cMS, _eMS],
      [[() => exports2.SemanticMemoryStrategyInput$, 0], [() => exports2.SummaryMemoryStrategyInput$, 0], [() => exports2.UserPreferenceMemoryStrategyInput$, 0], [() => exports2.CustomMemoryStrategyInput$, 0], [() => exports2.EpisodicMemoryStrategyInput$, 0]]
    ];
    exports2.ModifyConsolidationConfiguration$ = [
      4,
      n032,
      _MCC,
      0,
      [_cCC],
      [[() => exports2.CustomConsolidationConfigurationInput$, 0]]
    ];
    exports2.ModifyExtractionConfiguration$ = [
      4,
      n032,
      _MEC,
      0,
      [_cEC],
      [[() => exports2.CustomExtractionConfigurationInput$, 0]]
    ];
    exports2.ModifyReflectionConfiguration$ = [
      4,
      n032,
      _MRC,
      0,
      [_eRC, _cRC],
      [() => exports2.EpisodicReflectionConfigurationInput$, [() => exports2.CustomReflectionConfigurationInput$, 0]]
    ];
    exports2.Oauth2Discovery$ = [
      4,
      n032,
      _OD,
      0,
      [_dU, _aSM],
      [0, () => exports2.Oauth2AuthorizationServerMetadata$]
    ];
    exports2.Oauth2ProviderConfigInput$ = [
      4,
      n032,
      _OPCI,
      0,
      [_cOPC, _gOPC, _gOPCi, _sOPC, _sOPCa, _mOPC, _aOPC, _lOPC, _iOPC],
      [[() => exports2.CustomOauth2ProviderConfigInput$, 0], [() => exports2.GoogleOauth2ProviderConfigInput$, 0], [() => exports2.GithubOauth2ProviderConfigInput$, 0], [() => exports2.SlackOauth2ProviderConfigInput$, 0], [() => exports2.SalesforceOauth2ProviderConfigInput$, 0], [() => exports2.MicrosoftOauth2ProviderConfigInput$, 0], [() => exports2.AtlassianOauth2ProviderConfigInput$, 0], [() => exports2.LinkedinOauth2ProviderConfigInput$, 0], [() => exports2.IncludedOauth2ProviderConfigInput$, 0]]
    ];
    exports2.Oauth2ProviderConfigOutput$ = [
      4,
      n032,
      _OPCO,
      0,
      [_cOPC, _gOPC, _gOPCi, _sOPC, _sOPCa, _mOPC, _aOPC, _lOPC, _iOPC],
      [() => exports2.CustomOauth2ProviderConfigOutput$, () => exports2.GoogleOauth2ProviderConfigOutput$, () => exports2.GithubOauth2ProviderConfigOutput$, () => exports2.SlackOauth2ProviderConfigOutput$, () => exports2.SalesforceOauth2ProviderConfigOutput$, () => exports2.MicrosoftOauth2ProviderConfigOutput$, () => exports2.AtlassianOauth2ProviderConfigOutput$, () => exports2.LinkedinOauth2ProviderConfigOutput$, () => exports2.IncludedOauth2ProviderConfigOutput$]
    ];
    exports2.PolicyDefinition$ = [
      4,
      n032,
      _PD,
      0,
      [_ced, _pGo],
      [() => exports2.CedarPolicy$, () => exports2.PolicyGenerationDetails$]
    ];
    exports2.PrivateEndpoint$ = [
      4,
      n032,
      _PEr,
      0,
      [_sMLR, _mLR],
      [() => exports2.SelfManagedLatticeResource$, () => exports2.ManagedLatticeResource$]
    ];
    exports2.RatingScale$ = [
      4,
      n032,
      _RSa,
      8,
      [_nu, _ca],
      [() => NumericalScaleDefinitions, () => CategoricalScaleDefinitions]
    ];
    exports2.ReflectionConfiguration$ = [
      4,
      n032,
      _RCe,
      0,
      [_cRC, _eRC],
      [[() => exports2.CustomReflectionConfiguration$, 0], () => exports2.EpisodicReflectionConfiguration$]
    ];
    exports2.RegistryRecordCredentialProviderUnion$ = [
      4,
      n032,
      _RRCPU,
      0,
      [_oCP, _iCP],
      [() => exports2.RegistryRecordOAuthCredentialProvider$, () => exports2.RegistryRecordIamCredentialProvider$]
    ];
    exports2.RequestHeaderConfiguration$ = [
      4,
      n032,
      _RHC,
      0,
      [_rHA],
      [64 | 0]
    ];
    exports2.Resource$ = [
      4,
      n032,
      _Re,
      0,
      [_ar],
      [0]
    ];
    exports2.ResourceLocation$ = [
      4,
      n032,
      _RL,
      0,
      [_s_],
      [() => exports2.S3Location$]
    ];
    exports2.SelfManagedLatticeResource$ = [
      4,
      n032,
      _SMLR,
      0,
      [_rCI],
      [0]
    ];
    exports2.StreamDeliveryResource$ = [
      4,
      n032,
      _SDRt,
      0,
      [_ki],
      [() => exports2.KinesisResource$]
    ];
    exports2.TargetConfiguration$ = [
      4,
      n032,
      _TC10,
      0,
      [_mc],
      [[() => exports2.McpTargetConfiguration$, 0]]
    ];
    exports2.ToolSchema$ = [
      4,
      n032,
      _TSo,
      0,
      [_s_, _iPn],
      [() => exports2.S3Configuration$, () => ToolDefinitions]
    ];
    exports2.TriggerCondition$ = [
      4,
      n032,
      _TCr,
      0,
      [_mBT, _tBT, _tBTi],
      [() => exports2.MessageBasedTrigger$, () => exports2.TokenBasedTrigger$, () => exports2.TimeBasedTrigger$]
    ];
    exports2.TriggerConditionInput$ = [
      4,
      n032,
      _TCI,
      0,
      [_mBT, _tBT, _tBTi],
      [() => exports2.MessageBasedTriggerInput$, () => exports2.TokenBasedTriggerInput$, () => exports2.TimeBasedTriggerInput$]
    ];
    exports2.CreateAgentRuntime$ = [
      9,
      n032,
      _CAR,
      { [_ht]: ["PUT", "/runtimes/", 202] },
      () => exports2.CreateAgentRuntimeRequest$,
      () => exports2.CreateAgentRuntimeResponse$
    ];
    exports2.CreateAgentRuntimeEndpoint$ = [
      9,
      n032,
      _CARE,
      { [_ht]: ["PUT", "/runtimes/{agentRuntimeId}/runtime-endpoints/", 202] },
      () => exports2.CreateAgentRuntimeEndpointRequest$,
      () => exports2.CreateAgentRuntimeEndpointResponse$
    ];
    exports2.CreateApiKeyCredentialProvider$ = [
      9,
      n032,
      _CAKCP,
      { [_ht]: ["POST", "/identities/CreateApiKeyCredentialProvider", 201] },
      () => exports2.CreateApiKeyCredentialProviderRequest$,
      () => exports2.CreateApiKeyCredentialProviderResponse$
    ];
    exports2.CreateBrowser$ = [
      9,
      n032,
      _CB,
      { [_ht]: ["PUT", "/browsers", 202] },
      () => exports2.CreateBrowserRequest$,
      () => exports2.CreateBrowserResponse$
    ];
    exports2.CreateBrowserProfile$ = [
      9,
      n032,
      _CBP,
      { [_ht]: ["PUT", "/browser-profiles", 200] },
      () => exports2.CreateBrowserProfileRequest$,
      () => exports2.CreateBrowserProfileResponse$
    ];
    exports2.CreateCodeInterpreter$ = [
      9,
      n032,
      _CCIr,
      { [_ht]: ["PUT", "/code-interpreters", 202] },
      () => exports2.CreateCodeInterpreterRequest$,
      () => exports2.CreateCodeInterpreterResponse$
    ];
    exports2.CreateEvaluator$ = [
      9,
      n032,
      _CEr,
      { [_ht]: ["POST", "/evaluators/create", 202] },
      () => exports2.CreateEvaluatorRequest$,
      () => exports2.CreateEvaluatorResponse$
    ];
    exports2.CreateGateway$ = [
      9,
      n032,
      _CG,
      { [_ht]: ["POST", "/gateways/", 202] },
      () => exports2.CreateGatewayRequest$,
      () => exports2.CreateGatewayResponse$
    ];
    exports2.CreateGatewayTarget$ = [
      9,
      n032,
      _CGT,
      { [_ht]: ["POST", "/gateways/{gatewayIdentifier}/targets/", 202] },
      () => exports2.CreateGatewayTargetRequest$,
      () => exports2.CreateGatewayTargetResponse$
    ];
    exports2.CreateHarness$ = [
      9,
      n032,
      _CH,
      { [_ht]: ["POST", "/harnesses", 201] },
      () => exports2.CreateHarnessRequest$,
      () => exports2.CreateHarnessResponse$
    ];
    exports2.CreateMemory$ = [
      9,
      n032,
      _CM,
      { [_ht]: ["POST", "/memories/create", 202] },
      () => exports2.CreateMemoryInput$,
      () => exports2.CreateMemoryOutput$
    ];
    exports2.CreateOauth2CredentialProvider$ = [
      9,
      n032,
      _COCP,
      { [_ht]: ["POST", "/identities/CreateOauth2CredentialProvider", 201] },
      () => exports2.CreateOauth2CredentialProviderRequest$,
      () => exports2.CreateOauth2CredentialProviderResponse$
    ];
    exports2.CreateOnlineEvaluationConfig$ = [
      9,
      n032,
      _COEC,
      { [_ht]: ["POST", "/online-evaluation-configs/create", 202] },
      () => exports2.CreateOnlineEvaluationConfigRequest$,
      () => exports2.CreateOnlineEvaluationConfigResponse$
    ];
    exports2.CreatePolicy$ = [
      9,
      n032,
      _CPre,
      { [_ht]: ["POST", "/policy-engines/{policyEngineId}/policies", 202] },
      () => exports2.CreatePolicyRequest$,
      () => exports2.CreatePolicyResponse$
    ];
    exports2.CreatePolicyEngine$ = [
      9,
      n032,
      _CPE,
      { [_ht]: ["POST", "/policy-engines", 202] },
      () => exports2.CreatePolicyEngineRequest$,
      () => exports2.CreatePolicyEngineResponse$
    ];
    exports2.CreateRegistry$ = [
      9,
      n032,
      _CR,
      { [_ht]: ["POST", "/registries", 202] },
      () => exports2.CreateRegistryRequest$,
      () => exports2.CreateRegistryResponse$
    ];
    exports2.CreateRegistryRecord$ = [
      9,
      n032,
      _CRRre,
      { [_ht]: ["POST", "/registries/{registryId}/records", 202] },
      () => exports2.CreateRegistryRecordRequest$,
      () => exports2.CreateRegistryRecordResponse$
    ];
    exports2.CreateWorkloadIdentity$ = [
      9,
      n032,
      _CWI,
      { [_ht]: ["POST", "/identities/CreateWorkloadIdentity", 201] },
      () => exports2.CreateWorkloadIdentityRequest$,
      () => exports2.CreateWorkloadIdentityResponse$
    ];
    exports2.DeleteAgentRuntime$ = [
      9,
      n032,
      _DAR,
      { [_ht]: ["DELETE", "/runtimes/{agentRuntimeId}/", 202] },
      () => exports2.DeleteAgentRuntimeRequest$,
      () => exports2.DeleteAgentRuntimeResponse$
    ];
    exports2.DeleteAgentRuntimeEndpoint$ = [
      9,
      n032,
      _DARE,
      { [_ht]: ["DELETE", "/runtimes/{agentRuntimeId}/runtime-endpoints/{endpointName}/", 202] },
      () => exports2.DeleteAgentRuntimeEndpointRequest$,
      () => exports2.DeleteAgentRuntimeEndpointResponse$
    ];
    exports2.DeleteApiKeyCredentialProvider$ = [
      9,
      n032,
      _DAKCP,
      { [_ht]: ["POST", "/identities/DeleteApiKeyCredentialProvider", 204] },
      () => exports2.DeleteApiKeyCredentialProviderRequest$,
      () => exports2.DeleteApiKeyCredentialProviderResponse$
    ];
    exports2.DeleteBrowser$ = [
      9,
      n032,
      _DB,
      { [_ht]: ["DELETE", "/browsers/{browserId}", 202] },
      () => exports2.DeleteBrowserRequest$,
      () => exports2.DeleteBrowserResponse$
    ];
    exports2.DeleteBrowserProfile$ = [
      9,
      n032,
      _DBP,
      { [_ht]: ["DELETE", "/browser-profiles/{profileId}", 200] },
      () => exports2.DeleteBrowserProfileRequest$,
      () => exports2.DeleteBrowserProfileResponse$
    ];
    exports2.DeleteCodeInterpreter$ = [
      9,
      n032,
      _DCI,
      { [_ht]: ["DELETE", "/code-interpreters/{codeInterpreterId}", 202] },
      () => exports2.DeleteCodeInterpreterRequest$,
      () => exports2.DeleteCodeInterpreterResponse$
    ];
    exports2.DeleteEvaluator$ = [
      9,
      n032,
      _DE,
      { [_ht]: ["DELETE", "/evaluators/{evaluatorId}", 202] },
      () => exports2.DeleteEvaluatorRequest$,
      () => exports2.DeleteEvaluatorResponse$
    ];
    exports2.DeleteGateway$ = [
      9,
      n032,
      _DG,
      { [_ht]: ["DELETE", "/gateways/{gatewayIdentifier}/", 202] },
      () => exports2.DeleteGatewayRequest$,
      () => exports2.DeleteGatewayResponse$
    ];
    exports2.DeleteGatewayTarget$ = [
      9,
      n032,
      _DGT,
      { [_ht]: ["DELETE", "/gateways/{gatewayIdentifier}/targets/{targetId}/", 202] },
      () => exports2.DeleteGatewayTargetRequest$,
      () => exports2.DeleteGatewayTargetResponse$
    ];
    exports2.DeleteHarness$ = [
      9,
      n032,
      _DH,
      { [_ht]: ["DELETE", "/harnesses/{harnessId}", 200] },
      () => exports2.DeleteHarnessRequest$,
      () => exports2.DeleteHarnessResponse$
    ];
    exports2.DeleteMemory$ = [
      9,
      n032,
      _DM,
      { [_ht]: ["DELETE", "/memories/{memoryId}/delete", 202] },
      () => exports2.DeleteMemoryInput$,
      () => exports2.DeleteMemoryOutput$
    ];
    exports2.DeleteOauth2CredentialProvider$ = [
      9,
      n032,
      _DOCP,
      { [_ht]: ["POST", "/identities/DeleteOauth2CredentialProvider", 204] },
      () => exports2.DeleteOauth2CredentialProviderRequest$,
      () => exports2.DeleteOauth2CredentialProviderResponse$
    ];
    exports2.DeleteOnlineEvaluationConfig$ = [
      9,
      n032,
      _DOEC,
      { [_ht]: ["DELETE", "/online-evaluation-configs/{onlineEvaluationConfigId}", 202] },
      () => exports2.DeleteOnlineEvaluationConfigRequest$,
      () => exports2.DeleteOnlineEvaluationConfigResponse$
    ];
    exports2.DeletePolicy$ = [
      9,
      n032,
      _DP,
      { [_ht]: ["DELETE", "/policy-engines/{policyEngineId}/policies/{policyId}", 202] },
      () => exports2.DeletePolicyRequest$,
      () => exports2.DeletePolicyResponse$
    ];
    exports2.DeletePolicyEngine$ = [
      9,
      n032,
      _DPE,
      { [_ht]: ["DELETE", "/policy-engines/{policyEngineId}", 202] },
      () => exports2.DeletePolicyEngineRequest$,
      () => exports2.DeletePolicyEngineResponse$
    ];
    exports2.DeleteRegistry$ = [
      9,
      n032,
      _DR,
      { [_ht]: ["DELETE", "/registries/{registryId}", 202] },
      () => exports2.DeleteRegistryRequest$,
      () => exports2.DeleteRegistryResponse$
    ];
    exports2.DeleteRegistryRecord$ = [
      9,
      n032,
      _DRRel,
      { [_ht]: ["DELETE", "/registries/{registryId}/records/{recordId}", 200] },
      () => exports2.DeleteRegistryRecordRequest$,
      () => exports2.DeleteRegistryRecordResponse$
    ];
    exports2.DeleteResourcePolicy$ = [
      9,
      n032,
      _DRP,
      { [_ht]: ["DELETE", "/resourcepolicy/{resourceArn}", 204] },
      () => exports2.DeleteResourcePolicyRequest$,
      () => exports2.DeleteResourcePolicyResponse$
    ];
    exports2.DeleteWorkloadIdentity$ = [
      9,
      n032,
      _DWI,
      { [_ht]: ["POST", "/identities/DeleteWorkloadIdentity", 204] },
      () => exports2.DeleteWorkloadIdentityRequest$,
      () => exports2.DeleteWorkloadIdentityResponse$
    ];
    exports2.GetAgentRuntime$ = [
      9,
      n032,
      _GAR,
      { [_ht]: ["GET", "/runtimes/{agentRuntimeId}/", 200] },
      () => exports2.GetAgentRuntimeRequest$,
      () => exports2.GetAgentRuntimeResponse$
    ];
    exports2.GetAgentRuntimeEndpoint$ = [
      9,
      n032,
      _GARE,
      { [_ht]: ["GET", "/runtimes/{agentRuntimeId}/runtime-endpoints/{endpointName}/", 200] },
      () => exports2.GetAgentRuntimeEndpointRequest$,
      () => exports2.GetAgentRuntimeEndpointResponse$
    ];
    exports2.GetApiKeyCredentialProvider$ = [
      9,
      n032,
      _GAKCPe,
      { [_ht]: ["POST", "/identities/GetApiKeyCredentialProvider", 200] },
      () => exports2.GetApiKeyCredentialProviderRequest$,
      () => exports2.GetApiKeyCredentialProviderResponse$
    ];
    exports2.GetBrowser$ = [
      9,
      n032,
      _GB,
      { [_ht]: ["GET", "/browsers/{browserId}", 200] },
      () => exports2.GetBrowserRequest$,
      () => exports2.GetBrowserResponse$
    ];
    exports2.GetBrowserProfile$ = [
      9,
      n032,
      _GBP,
      { [_ht]: ["GET", "/browser-profiles/{profileId}", 200] },
      () => exports2.GetBrowserProfileRequest$,
      () => exports2.GetBrowserProfileResponse$
    ];
    exports2.GetCodeInterpreter$ = [
      9,
      n032,
      _GCI,
      { [_ht]: ["GET", "/code-interpreters/{codeInterpreterId}", 200] },
      () => exports2.GetCodeInterpreterRequest$,
      () => exports2.GetCodeInterpreterResponse$
    ];
    exports2.GetEvaluator$ = [
      9,
      n032,
      _GE,
      { [_ht]: ["GET", "/evaluators/{evaluatorId}", 200] },
      () => exports2.GetEvaluatorRequest$,
      () => exports2.GetEvaluatorResponse$
    ];
    exports2.GetGateway$ = [
      9,
      n032,
      _GG,
      { [_ht]: ["GET", "/gateways/{gatewayIdentifier}/", 200] },
      () => exports2.GetGatewayRequest$,
      () => exports2.GetGatewayResponse$
    ];
    exports2.GetGatewayTarget$ = [
      9,
      n032,
      _GGT,
      { [_ht]: ["GET", "/gateways/{gatewayIdentifier}/targets/{targetId}/", 200] },
      () => exports2.GetGatewayTargetRequest$,
      () => exports2.GetGatewayTargetResponse$
    ];
    exports2.GetHarness$ = [
      9,
      n032,
      _GH,
      { [_ht]: ["GET", "/harnesses/{harnessId}", 200] },
      () => exports2.GetHarnessRequest$,
      () => exports2.GetHarnessResponse$
    ];
    exports2.GetMemory$ = [
      9,
      n032,
      _GM,
      { [_ht]: ["GET", "/memories/{memoryId}/details", 200] },
      () => exports2.GetMemoryInput$,
      () => exports2.GetMemoryOutput$
    ];
    exports2.GetOauth2CredentialProvider$ = [
      9,
      n032,
      _GOCP,
      { [_ht]: ["POST", "/identities/GetOauth2CredentialProvider", 200] },
      () => exports2.GetOauth2CredentialProviderRequest$,
      () => exports2.GetOauth2CredentialProviderResponse$
    ];
    exports2.GetOnlineEvaluationConfig$ = [
      9,
      n032,
      _GOEC,
      { [_ht]: ["GET", "/online-evaluation-configs/{onlineEvaluationConfigId}", 200] },
      () => exports2.GetOnlineEvaluationConfigRequest$,
      () => exports2.GetOnlineEvaluationConfigResponse$
    ];
    exports2.GetPolicy$ = [
      9,
      n032,
      _GP,
      { [_ht]: ["GET", "/policy-engines/{policyEngineId}/policies/{policyId}", 200] },
      () => exports2.GetPolicyRequest$,
      () => exports2.GetPolicyResponse$
    ];
    exports2.GetPolicyEngine$ = [
      9,
      n032,
      _GPE,
      { [_ht]: ["GET", "/policy-engines/{policyEngineId}", 200] },
      () => exports2.GetPolicyEngineRequest$,
      () => exports2.GetPolicyEngineResponse$
    ];
    exports2.GetPolicyGeneration$ = [
      9,
      n032,
      _GPG,
      { [_ht]: ["GET", "/policy-engines/{policyEngineId}/policy-generations/{policyGenerationId}", 200] },
      () => exports2.GetPolicyGenerationRequest$,
      () => exports2.GetPolicyGenerationResponse$
    ];
    exports2.GetRegistry$ = [
      9,
      n032,
      _GR,
      { [_ht]: ["GET", "/registries/{registryId}", 200] },
      () => exports2.GetRegistryRequest$,
      () => exports2.GetRegistryResponse$
    ];
    exports2.GetRegistryRecord$ = [
      9,
      n032,
      _GRRet,
      { [_ht]: ["GET", "/registries/{registryId}/records/{recordId}", 200] },
      () => exports2.GetRegistryRecordRequest$,
      () => exports2.GetRegistryRecordResponse$
    ];
    exports2.GetResourcePolicy$ = [
      9,
      n032,
      _GRP,
      { [_ht]: ["GET", "/resourcepolicy/{resourceArn}", 200] },
      () => exports2.GetResourcePolicyRequest$,
      () => exports2.GetResourcePolicyResponse$
    ];
    exports2.GetTokenVault$ = [
      9,
      n032,
      _GTV,
      { [_ht]: ["POST", "/identities/get-token-vault", 200] },
      () => exports2.GetTokenVaultRequest$,
      () => exports2.GetTokenVaultResponse$
    ];
    exports2.GetWorkloadIdentity$ = [
      9,
      n032,
      _GWI,
      { [_ht]: ["POST", "/identities/GetWorkloadIdentity", 200] },
      () => exports2.GetWorkloadIdentityRequest$,
      () => exports2.GetWorkloadIdentityResponse$
    ];
    exports2.ListAgentRuntimeEndpoints$ = [
      9,
      n032,
      _LARE,
      { [_ht]: ["POST", "/runtimes/{agentRuntimeId}/runtime-endpoints/", 200] },
      () => exports2.ListAgentRuntimeEndpointsRequest$,
      () => exports2.ListAgentRuntimeEndpointsResponse$
    ];
    exports2.ListAgentRuntimes$ = [
      9,
      n032,
      _LAR,
      { [_ht]: ["POST", "/runtimes/", 200] },
      () => exports2.ListAgentRuntimesRequest$,
      () => exports2.ListAgentRuntimesResponse$
    ];
    exports2.ListAgentRuntimeVersions$ = [
      9,
      n032,
      _LARV,
      { [_ht]: ["POST", "/runtimes/{agentRuntimeId}/versions/", 200] },
      () => exports2.ListAgentRuntimeVersionsRequest$,
      () => exports2.ListAgentRuntimeVersionsResponse$
    ];
    exports2.ListApiKeyCredentialProviders$ = [
      9,
      n032,
      _LAKCP,
      { [_ht]: ["POST", "/identities/ListApiKeyCredentialProviders", 200] },
      () => exports2.ListApiKeyCredentialProvidersRequest$,
      () => exports2.ListApiKeyCredentialProvidersResponse$
    ];
    exports2.ListBrowserProfiles$ = [
      9,
      n032,
      _LBP,
      { [_ht]: ["POST", "/browser-profiles", 200] },
      () => exports2.ListBrowserProfilesRequest$,
      () => exports2.ListBrowserProfilesResponse$
    ];
    exports2.ListBrowsers$ = [
      9,
      n032,
      _LB,
      { [_ht]: ["POST", "/browsers", 200] },
      () => exports2.ListBrowsersRequest$,
      () => exports2.ListBrowsersResponse$
    ];
    exports2.ListCodeInterpreters$ = [
      9,
      n032,
      _LCI,
      { [_ht]: ["POST", "/code-interpreters", 200] },
      () => exports2.ListCodeInterpretersRequest$,
      () => exports2.ListCodeInterpretersResponse$
    ];
    exports2.ListEvaluators$ = [
      9,
      n032,
      _LE,
      { [_ht]: ["POST", "/evaluators", 200] },
      () => exports2.ListEvaluatorsRequest$,
      () => exports2.ListEvaluatorsResponse$
    ];
    exports2.ListGateways$ = [
      9,
      n032,
      _LG,
      { [_ht]: ["GET", "/gateways/", 200] },
      () => exports2.ListGatewaysRequest$,
      () => exports2.ListGatewaysResponse$
    ];
    exports2.ListGatewayTargets$ = [
      9,
      n032,
      _LGT,
      { [_ht]: ["GET", "/gateways/{gatewayIdentifier}/targets/", 200] },
      () => exports2.ListGatewayTargetsRequest$,
      () => exports2.ListGatewayTargetsResponse$
    ];
    exports2.ListHarnesses$ = [
      9,
      n032,
      _LH,
      { [_ht]: ["GET", "/harnesses", 200] },
      () => exports2.ListHarnessesRequest$,
      () => exports2.ListHarnessesResponse$
    ];
    exports2.ListMemories$ = [
      9,
      n032,
      _LM2,
      { [_ht]: ["POST", "/memories/", 200] },
      () => exports2.ListMemoriesInput$,
      () => exports2.ListMemoriesOutput$
    ];
    exports2.ListOauth2CredentialProviders$ = [
      9,
      n032,
      _LOCP,
      { [_ht]: ["POST", "/identities/ListOauth2CredentialProviders", 200] },
      () => exports2.ListOauth2CredentialProvidersRequest$,
      () => exports2.ListOauth2CredentialProvidersResponse$
    ];
    exports2.ListOnlineEvaluationConfigs$ = [
      9,
      n032,
      _LOEC,
      { [_ht]: ["POST", "/online-evaluation-configs", 200] },
      () => exports2.ListOnlineEvaluationConfigsRequest$,
      () => exports2.ListOnlineEvaluationConfigsResponse$
    ];
    exports2.ListPolicies$ = [
      9,
      n032,
      _LP,
      { [_ht]: ["GET", "/policy-engines/{policyEngineId}/policies", 200] },
      () => exports2.ListPoliciesRequest$,
      () => exports2.ListPoliciesResponse$
    ];
    exports2.ListPolicyEngines$ = [
      9,
      n032,
      _LPE,
      { [_ht]: ["GET", "/policy-engines", 200] },
      () => exports2.ListPolicyEnginesRequest$,
      () => exports2.ListPolicyEnginesResponse$
    ];
    exports2.ListPolicyGenerationAssets$ = [
      9,
      n032,
      _LPGA,
      { [_ht]: ["GET", "/policy-engines/{policyEngineId}/policy-generations/{policyGenerationId}/assets", 200] },
      () => exports2.ListPolicyGenerationAssetsRequest$,
      () => exports2.ListPolicyGenerationAssetsResponse$
    ];
    exports2.ListPolicyGenerations$ = [
      9,
      n032,
      _LPG,
      { [_ht]: ["GET", "/policy-engines/{policyEngineId}/policy-generations", 200] },
      () => exports2.ListPolicyGenerationsRequest$,
      () => exports2.ListPolicyGenerationsResponse$
    ];
    exports2.ListRegistries$ = [
      9,
      n032,
      _LR,
      { [_ht]: ["GET", "/registries", 200] },
      () => exports2.ListRegistriesRequest$,
      () => exports2.ListRegistriesResponse$
    ];
    exports2.ListRegistryRecords$ = [
      9,
      n032,
      _LRRis,
      { [_ht]: ["GET", "/registries/{registryId}/records", 200] },
      () => exports2.ListRegistryRecordsRequest$,
      () => exports2.ListRegistryRecordsResponse$
    ];
    exports2.ListTagsForResource$ = [
      9,
      n032,
      _LTFR,
      { [_ht]: ["GET", "/tags/{resourceArn}", 200] },
      () => exports2.ListTagsForResourceRequest$,
      () => exports2.ListTagsForResourceResponse$
    ];
    exports2.ListWorkloadIdentities$ = [
      9,
      n032,
      _LWI,
      { [_ht]: ["POST", "/identities/ListWorkloadIdentities", 200] },
      () => exports2.ListWorkloadIdentitiesRequest$,
      () => exports2.ListWorkloadIdentitiesResponse$
    ];
    exports2.PutResourcePolicy$ = [
      9,
      n032,
      _PRP,
      { [_ht]: ["PUT", "/resourcepolicy/{resourceArn}", 201] },
      () => exports2.PutResourcePolicyRequest$,
      () => exports2.PutResourcePolicyResponse$
    ];
    exports2.SetTokenVaultCMK$ = [
      9,
      n032,
      _STVCMK,
      { [_ht]: ["POST", "/identities/set-token-vault-cmk", 200] },
      () => exports2.SetTokenVaultCMKRequest$,
      () => exports2.SetTokenVaultCMKResponse$
    ];
    exports2.StartPolicyGeneration$ = [
      9,
      n032,
      _SPG,
      { [_ht]: ["POST", "/policy-engines/{policyEngineId}/policy-generations", 202] },
      () => exports2.StartPolicyGenerationRequest$,
      () => exports2.StartPolicyGenerationResponse$
    ];
    exports2.SubmitRegistryRecordForApproval$ = [
      9,
      n032,
      _SRRFA,
      { [_ht]: ["POST", "/registries/{registryId}/records/{recordId}/submit-for-approval", 202] },
      () => exports2.SubmitRegistryRecordForApprovalRequest$,
      () => exports2.SubmitRegistryRecordForApprovalResponse$
    ];
    exports2.SynchronizeGatewayTargets$ = [
      9,
      n032,
      _SGT,
      { [_ht]: ["PUT", "/gateways/{gatewayIdentifier}/synchronizeTargets", 202] },
      () => exports2.SynchronizeGatewayTargetsRequest$,
      () => exports2.SynchronizeGatewayTargetsResponse$
    ];
    exports2.TagResource$ = [
      9,
      n032,
      _TR,
      { [_ht]: ["POST", "/tags/{resourceArn}", 204] },
      () => exports2.TagResourceRequest$,
      () => exports2.TagResourceResponse$
    ];
    exports2.UntagResource$ = [
      9,
      n032,
      _UR,
      { [_ht]: ["DELETE", "/tags/{resourceArn}", 204] },
      () => exports2.UntagResourceRequest$,
      () => exports2.UntagResourceResponse$
    ];
    exports2.UpdateAgentRuntime$ = [
      9,
      n032,
      _UAR,
      { [_ht]: ["PUT", "/runtimes/{agentRuntimeId}/", 202] },
      () => exports2.UpdateAgentRuntimeRequest$,
      () => exports2.UpdateAgentRuntimeResponse$
    ];
    exports2.UpdateAgentRuntimeEndpoint$ = [
      9,
      n032,
      _UARE,
      { [_ht]: ["PUT", "/runtimes/{agentRuntimeId}/runtime-endpoints/{endpointName}/", 202] },
      () => exports2.UpdateAgentRuntimeEndpointRequest$,
      () => exports2.UpdateAgentRuntimeEndpointResponse$
    ];
    exports2.UpdateApiKeyCredentialProvider$ = [
      9,
      n032,
      _UAKCP,
      { [_ht]: ["POST", "/identities/UpdateApiKeyCredentialProvider", 200] },
      () => exports2.UpdateApiKeyCredentialProviderRequest$,
      () => exports2.UpdateApiKeyCredentialProviderResponse$
    ];
    exports2.UpdateEvaluator$ = [
      9,
      n032,
      _UEp,
      { [_ht]: ["PUT", "/evaluators/{evaluatorId}", 202] },
      () => exports2.UpdateEvaluatorRequest$,
      () => exports2.UpdateEvaluatorResponse$
    ];
    exports2.UpdateGateway$ = [
      9,
      n032,
      _UG,
      { [_ht]: ["PUT", "/gateways/{gatewayIdentifier}/", 202] },
      () => exports2.UpdateGatewayRequest$,
      () => exports2.UpdateGatewayResponse$
    ];
    exports2.UpdateGatewayTarget$ = [
      9,
      n032,
      _UGT,
      { [_ht]: ["PUT", "/gateways/{gatewayIdentifier}/targets/{targetId}/", 202] },
      () => exports2.UpdateGatewayTargetRequest$,
      () => exports2.UpdateGatewayTargetResponse$
    ];
    exports2.UpdateHarness$ = [
      9,
      n032,
      _UH,
      { [_ht]: ["PATCH", "/harnesses/{harnessId}", 200] },
      () => exports2.UpdateHarnessRequest$,
      () => exports2.UpdateHarnessResponse$
    ];
    exports2.UpdateMemory$ = [
      9,
      n032,
      _UM,
      { [_ht]: ["PUT", "/memories/{memoryId}/update", 202] },
      () => exports2.UpdateMemoryInput$,
      () => exports2.UpdateMemoryOutput$
    ];
    exports2.UpdateOauth2CredentialProvider$ = [
      9,
      n032,
      _UOCP,
      { [_ht]: ["POST", "/identities/UpdateOauth2CredentialProvider", 200] },
      () => exports2.UpdateOauth2CredentialProviderRequest$,
      () => exports2.UpdateOauth2CredentialProviderResponse$
    ];
    exports2.UpdateOnlineEvaluationConfig$ = [
      9,
      n032,
      _UOEC,
      { [_ht]: ["PUT", "/online-evaluation-configs/{onlineEvaluationConfigId}", 202] },
      () => exports2.UpdateOnlineEvaluationConfigRequest$,
      () => exports2.UpdateOnlineEvaluationConfigResponse$
    ];
    exports2.UpdatePolicy$ = [
      9,
      n032,
      _UP,
      { [_ht]: ["PATCH", "/policy-engines/{policyEngineId}/policies/{policyId}", 202] },
      () => exports2.UpdatePolicyRequest$,
      () => exports2.UpdatePolicyResponse$
    ];
    exports2.UpdatePolicyEngine$ = [
      9,
      n032,
      _UPE,
      { [_ht]: ["PATCH", "/policy-engines/{policyEngineId}", 202] },
      () => exports2.UpdatePolicyEngineRequest$,
      () => exports2.UpdatePolicyEngineResponse$
    ];
    exports2.UpdateRegistry$ = [
      9,
      n032,
      _URp,
      { [_ht]: ["PATCH", "/registries/{registryId}", 202] },
      () => exports2.UpdateRegistryRequest$,
      () => exports2.UpdateRegistryResponse$
    ];
    exports2.UpdateRegistryRecord$ = [
      9,
      n032,
      _URRpda,
      { [_ht]: ["PATCH", "/registries/{registryId}/records/{recordId}", 202] },
      () => exports2.UpdateRegistryRecordRequest$,
      () => exports2.UpdateRegistryRecordResponse$
    ];
    exports2.UpdateRegistryRecordStatus$ = [
      9,
      n032,
      _URRS,
      { [_ht]: ["PATCH", "/registries/{registryId}/records/{recordId}/status", 202] },
      () => exports2.UpdateRegistryRecordStatusRequest$,
      () => exports2.UpdateRegistryRecordStatusResponse$
    ];
    exports2.UpdateWorkloadIdentity$ = [
      9,
      n032,
      _UWI,
      { [_ht]: ["POST", "/identities/UpdateWorkloadIdentity", 200] },
      () => exports2.UpdateWorkloadIdentityRequest$,
      () => exports2.UpdateWorkloadIdentityResponse$
    ];
  }
});

// ../../node_modules/@aws-sdk/client-bedrock-agentcore-control/dist-cjs/runtimeConfig.shared.js
var require_runtimeConfig_shared8 = __commonJS({
  "../../node_modules/@aws-sdk/client-bedrock-agentcore-control/dist-cjs/runtimeConfig.shared.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var protocols_1 = (init_protocols8(), __toCommonJS(protocols_exports5));
    var smithy_client_1 = require_dist_cjs34();
    var url_parser_1 = require_dist_cjs18();
    var util_base64_1 = require_dist_cjs10();
    var util_utf8_1 = require_dist_cjs9();
    var httpAuthSchemeProvider_1 = require_httpAuthSchemeProvider7();
    var endpointResolver_1 = require_endpointResolver7();
    var schemas_0_1 = require_schemas_07();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2023-06-05",
        base64Decoder: config2?.base64Decoder ?? util_base64_1.fromBase64,
        base64Encoder: config2?.base64Encoder ?? util_base64_1.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? endpointResolver_1.defaultEndpointResolver,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? httpAuthSchemeProvider_1.defaultBedrockAgentCoreControlHttpAuthSchemeProvider,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new httpAuthSchemes_1.AwsSdkSigV4Signer()
          }
        ],
        logger: config2?.logger ?? new smithy_client_1.NoOpLogger(),
        protocol: config2?.protocol ?? protocols_1.AwsRestJsonProtocol,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.bedrockagentcorecontrol",
          errorTypeRegistries: schemas_0_1.errorTypeRegistries,
          version: "2023-06-05",
          serviceTarget: "AmazonBedrockAgentCoreControl"
        },
        serviceId: config2?.serviceId ?? "Bedrock AgentCore Control",
        urlParser: config2?.urlParser ?? url_parser_1.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? util_utf8_1.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? util_utf8_1.toUtf8
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-bedrock-agentcore-control/dist-cjs/runtimeConfig.js
var require_runtimeConfig8 = __commonJS({
  "../../node_modules/@aws-sdk/client-bedrock-agentcore-control/dist-cjs/runtimeConfig.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var package_json_1 = tslib_1.__importDefault(require_package7());
    var client_1 = (init_client8(), __toCommonJS(client_exports7));
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var credential_provider_node_1 = require_dist_cjs122();
    var util_user_agent_node_1 = require_dist_cjs113();
    var config_resolver_1 = require_dist_cjs25();
    var hash_node_1 = require_dist_cjs44();
    var middleware_retry_1 = require_dist_cjs106();
    var node_config_provider_1 = require_dist_cjs29();
    var node_http_handler_1 = require_dist_cjs13();
    var smithy_client_1 = require_dist_cjs34();
    var util_body_length_node_1 = require_dist_cjs45();
    var util_defaults_mode_node_1 = require_dist_cjs46();
    var util_retry_1 = require_dist_cjs22();
    var runtimeConfig_shared_1 = require_runtimeConfig_shared8();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      (0, smithy_client_1.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, util_defaults_mode_node_1.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(smithy_client_1.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = (0, runtimeConfig_shared_1.getRuntimeConfig)(config2);
      (0, client_1.emitWarningIfUnsupportedVersion)(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, node_config_provider_1.loadConfig)(httpAuthSchemes_1.NODE_AUTH_SCHEME_PREFERENCE_OPTIONS, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? util_body_length_node_1.calculateBodyLength,
        credentialDefaultProvider: config2?.credentialDefaultProvider ?? credential_provider_node_1.defaultProvider,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, util_user_agent_node_1.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_json_1.default.version }),
        maxAttempts: config2?.maxAttempts ?? (0, node_config_provider_1.loadConfig)(middleware_retry_1.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_REGION_CONFIG_OPTIONS, { ...config_resolver_1.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: node_http_handler_1.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, node_config_provider_1.loadConfig)({
          ...middleware_retry_1.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || util_retry_1.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? hash_node_1.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? node_http_handler_1.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, node_config_provider_1.loadConfig)(util_user_agent_node_1.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@smithy/util-waiter/dist-cjs/index.js
var require_dist_cjs156 = __commonJS({
  "../../node_modules/@smithy/util-waiter/dist-cjs/index.js"(exports2) {
    "use strict";
    var getCircularReplacer3 = /* @__PURE__ */ __name(() => {
      const seen = /* @__PURE__ */ new WeakSet();
      return (key, value) => {
        if (typeof value === "object" && value !== null) {
          if (seen.has(value)) {
            return "[Circular]";
          }
          seen.add(value);
        }
        return value;
      };
    }, "getCircularReplacer");
    var sleep4 = /* @__PURE__ */ __name((seconds) => {
      return new Promise((resolve13) => setTimeout(resolve13, seconds * 1e3));
    }, "sleep");
    var waiterServiceDefaults3 = {
      minDelay: 2,
      maxDelay: 120
    };
    exports2.WaiterState = void 0;
    (function(WaiterState3) {
      WaiterState3["ABORTED"] = "ABORTED";
      WaiterState3["FAILURE"] = "FAILURE";
      WaiterState3["SUCCESS"] = "SUCCESS";
      WaiterState3["RETRY"] = "RETRY";
      WaiterState3["TIMEOUT"] = "TIMEOUT";
    })(exports2.WaiterState || (exports2.WaiterState = {}));
    var checkExceptions3 = /* @__PURE__ */ __name((result2) => {
      if (result2.state === exports2.WaiterState.ABORTED) {
        const abortError = new Error(`${JSON.stringify({
          ...result2,
          reason: "Request was aborted"
        }, getCircularReplacer3())}`);
        abortError.name = "AbortError";
        throw abortError;
      } else if (result2.state === exports2.WaiterState.TIMEOUT) {
        const timeoutError = new Error(`${JSON.stringify({
          ...result2,
          reason: "Waiter has timed out"
        }, getCircularReplacer3())}`);
        timeoutError.name = "TimeoutError";
        throw timeoutError;
      } else if (result2.state !== exports2.WaiterState.SUCCESS) {
        throw new Error(`${JSON.stringify(result2, getCircularReplacer3())}`);
      }
      return result2;
    }, "checkExceptions");
    var exponentialBackoffWithJitter3 = /* @__PURE__ */ __name((minDelay, maxDelay, attemptCeiling, attempt) => {
      if (attempt > attemptCeiling)
        return maxDelay;
      const delay = minDelay * 2 ** (attempt - 1);
      return randomInRange3(minDelay, delay);
    }, "exponentialBackoffWithJitter");
    var randomInRange3 = /* @__PURE__ */ __name((min, max) => min + Math.random() * (max - min), "randomInRange");
    var runPolling3 = /* @__PURE__ */ __name(async ({ minDelay, maxDelay, maxWaitTime, abortController, client, abortSignal }, input, acceptorChecks) => {
      const observedResponses = {};
      const { state: state13, reason } = await acceptorChecks(client, input);
      if (reason) {
        const message2 = createMessageFromResponse3(reason);
        observedResponses[message2] |= 0;
        observedResponses[message2] += 1;
      }
      if (state13 !== exports2.WaiterState.RETRY) {
        return { state: state13, reason, observedResponses };
      }
      let currentAttempt = 1;
      const waitUntil = Date.now() + maxWaitTime * 1e3;
      const attemptCeiling = Math.log(maxDelay / minDelay) / Math.log(2) + 1;
      while (true) {
        if (abortController?.signal?.aborted || abortSignal?.aborted) {
          const message2 = "AbortController signal aborted.";
          observedResponses[message2] |= 0;
          observedResponses[message2] += 1;
          return { state: exports2.WaiterState.ABORTED, observedResponses };
        }
        const delay = exponentialBackoffWithJitter3(minDelay, maxDelay, attemptCeiling, currentAttempt);
        if (Date.now() + delay * 1e3 > waitUntil) {
          return { state: exports2.WaiterState.TIMEOUT, observedResponses };
        }
        await sleep4(delay);
        const { state: state14, reason: reason2 } = await acceptorChecks(client, input);
        if (reason2) {
          const message2 = createMessageFromResponse3(reason2);
          observedResponses[message2] |= 0;
          observedResponses[message2] += 1;
        }
        if (state14 !== exports2.WaiterState.RETRY) {
          return { state: state14, reason: reason2, observedResponses };
        }
        currentAttempt += 1;
      }
    }, "runPolling");
    var createMessageFromResponse3 = /* @__PURE__ */ __name((reason) => {
      if (reason?.$responseBodyText) {
        return `Deserialization error for body: ${reason.$responseBodyText}`;
      }
      if (reason?.$metadata?.httpStatusCode) {
        if (reason.$response || reason.message) {
          return `${reason.$response?.statusCode ?? reason.$metadata.httpStatusCode ?? "Unknown"}: ${reason.message}`;
        }
        return `${reason.$metadata.httpStatusCode}: OK`;
      }
      return String(reason?.message ?? JSON.stringify(reason, getCircularReplacer3()) ?? "Unknown");
    }, "createMessageFromResponse");
    var validateWaiterOptions3 = /* @__PURE__ */ __name((options) => {
      if (options.maxWaitTime <= 0) {
        throw new Error(`WaiterConfiguration.maxWaitTime must be greater than 0`);
      } else if (options.minDelay <= 0) {
        throw new Error(`WaiterConfiguration.minDelay must be greater than 0`);
      } else if (options.maxDelay <= 0) {
        throw new Error(`WaiterConfiguration.maxDelay must be greater than 0`);
      } else if (options.maxWaitTime <= options.minDelay) {
        throw new Error(`WaiterConfiguration.maxWaitTime [${options.maxWaitTime}] must be greater than WaiterConfiguration.minDelay [${options.minDelay}] for this waiter`);
      } else if (options.maxDelay < options.minDelay) {
        throw new Error(`WaiterConfiguration.maxDelay [${options.maxDelay}] must be greater than WaiterConfiguration.minDelay [${options.minDelay}] for this waiter`);
      }
    }, "validateWaiterOptions");
    var abortTimeout3 = /* @__PURE__ */ __name((abortSignal) => {
      let onAbort;
      const promise = new Promise((resolve13) => {
        onAbort = /* @__PURE__ */ __name(() => resolve13({ state: exports2.WaiterState.ABORTED }), "onAbort");
        if (typeof abortSignal.addEventListener === "function") {
          abortSignal.addEventListener("abort", onAbort);
        } else {
          abortSignal.onabort = onAbort;
        }
      });
      return {
        clearListener() {
          if (typeof abortSignal.removeEventListener === "function") {
            abortSignal.removeEventListener("abort", onAbort);
          }
        },
        aborted: promise
      };
    }, "abortTimeout");
    var createWaiter3 = /* @__PURE__ */ __name(async (options, input, acceptorChecks) => {
      const params = {
        ...waiterServiceDefaults3,
        ...options
      };
      validateWaiterOptions3(params);
      const exitConditions = [runPolling3(params, input, acceptorChecks)];
      const finalize = [];
      if (options.abortSignal) {
        const { aborted, clearListener } = abortTimeout3(options.abortSignal);
        finalize.push(clearListener);
        exitConditions.push(aborted);
      }
      if (options.abortController?.signal) {
        const { aborted, clearListener } = abortTimeout3(options.abortController.signal);
        finalize.push(clearListener);
        exitConditions.push(aborted);
      }
      return Promise.race(exitConditions).then((result2) => {
        for (const fn of finalize) {
          fn();
        }
        return result2;
      });
    }, "createWaiter");
    exports2.checkExceptions = checkExceptions3;
    exports2.createWaiter = createWaiter3;
    exports2.waiterServiceDefaults = waiterServiceDefaults3;
  }
});

// ../../node_modules/@aws-sdk/client-bedrock-agentcore-control/dist-cjs/index.js
var require_dist_cjs157 = __commonJS({
  "../../node_modules/@aws-sdk/client-bedrock-agentcore-control/dist-cjs/index.js"(exports2) {
    "use strict";
    var middlewareHostHeader = require_dist_cjs3();
    var middlewareLogger = require_dist_cjs4();
    var middlewareRecursionDetection = require_dist_cjs5();
    var middlewareUserAgent = require_dist_cjs104();
    var configResolver = require_dist_cjs25();
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var schema = (init_schema4(), __toCommonJS(schema_exports));
    var middlewareContentLength = require_dist_cjs26();
    var middlewareEndpoint = require_dist_cjs31();
    var middlewareRetry = require_dist_cjs106();
    var smithyClient = require_dist_cjs34();
    var httpAuthSchemeProvider = require_httpAuthSchemeProvider7();
    var runtimeConfig = require_runtimeConfig8();
    var regionConfigResolver = require_dist_cjs48();
    var protocolHttp = require_dist_cjs2();
    var schemas_0 = require_schemas_07();
    var utilWaiter = require_dist_cjs156();
    var errors = require_errors7();
    var BedrockAgentCoreControlServiceException = require_BedrockAgentCoreControlServiceException();
    var resolveClientEndpointParameters32 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "bedrock-agentcore"
      });
    }, "resolveClientEndpointParameters");
    var commonParams32 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
    var getHttpAuthExtensionConfiguration32 = /* @__PURE__ */ __name((runtimeConfig2) => {
      const _httpAuthSchemes = runtimeConfig2.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig2.httpAuthSchemeProvider;
      let _credentials = runtimeConfig2.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider2) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider2;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    var resolveHttpAuthRuntimeConfig32 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
    var resolveRuntimeExtensions32 = /* @__PURE__ */ __name((runtimeConfig2, extensions) => {
      const extensionConfiguration = Object.assign(regionConfigResolver.getAwsRegionExtensionConfiguration(runtimeConfig2), smithyClient.getDefaultExtensionConfiguration(runtimeConfig2), protocolHttp.getHttpHandlerExtensionConfiguration(runtimeConfig2), getHttpAuthExtensionConfiguration32(runtimeConfig2));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig2, regionConfigResolver.resolveAwsRegionExtensionConfiguration(extensionConfiguration), smithyClient.resolveDefaultRuntimeConfig(extensionConfiguration), protocolHttp.resolveHttpHandlerRuntimeConfig(extensionConfiguration), resolveHttpAuthRuntimeConfig32(extensionConfiguration));
    }, "resolveRuntimeExtensions");
    var BedrockAgentCoreControlClient2 = class extends smithyClient.Client {
      static {
        __name(this, "BedrockAgentCoreControlClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = runtimeConfig.getRuntimeConfig(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters32(_config_0);
        const _config_2 = middlewareUserAgent.resolveUserAgentConfig(_config_1);
        const _config_3 = middlewareRetry.resolveRetryConfig(_config_2);
        const _config_4 = configResolver.resolveRegionConfig(_config_3);
        const _config_5 = middlewareHostHeader.resolveHostHeaderConfig(_config_4);
        const _config_6 = middlewareEndpoint.resolveEndpointConfig(_config_5);
        const _config_7 = httpAuthSchemeProvider.resolveHttpAuthSchemeConfig(_config_6);
        const _config_8 = resolveRuntimeExtensions32(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(schema.getSchemaSerdePlugin(this.config));
        this.middlewareStack.use(middlewareUserAgent.getUserAgentPlugin(this.config));
        this.middlewareStack.use(middlewareRetry.getRetryPlugin(this.config));
        this.middlewareStack.use(middlewareContentLength.getContentLengthPlugin(this.config));
        this.middlewareStack.use(middlewareHostHeader.getHostHeaderPlugin(this.config));
        this.middlewareStack.use(middlewareLogger.getLoggerPlugin(this.config));
        this.middlewareStack.use(middlewareRecursionDetection.getRecursionDetectionPlugin(this.config));
        this.middlewareStack.use(core.getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: httpAuthSchemeProvider.defaultBedrockAgentCoreControlHttpAuthSchemeParametersProvider,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new core.DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(core.getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
    var CreateAgentRuntimeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "CreateAgentRuntime", {}).n("BedrockAgentCoreControlClient", "CreateAgentRuntimeCommand").sc(schemas_0.CreateAgentRuntime$).build() {
      static {
        __name(this, "CreateAgentRuntimeCommand");
      }
    };
    var CreateAgentRuntimeEndpointCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "CreateAgentRuntimeEndpoint", {}).n("BedrockAgentCoreControlClient", "CreateAgentRuntimeEndpointCommand").sc(schemas_0.CreateAgentRuntimeEndpoint$).build() {
      static {
        __name(this, "CreateAgentRuntimeEndpointCommand");
      }
    };
    var CreateApiKeyCredentialProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "CreateApiKeyCredentialProvider", {}).n("BedrockAgentCoreControlClient", "CreateApiKeyCredentialProviderCommand").sc(schemas_0.CreateApiKeyCredentialProvider$).build() {
      static {
        __name(this, "CreateApiKeyCredentialProviderCommand");
      }
    };
    var CreateBrowserCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "CreateBrowser", {}).n("BedrockAgentCoreControlClient", "CreateBrowserCommand").sc(schemas_0.CreateBrowser$).build() {
      static {
        __name(this, "CreateBrowserCommand");
      }
    };
    var CreateBrowserProfileCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "CreateBrowserProfile", {}).n("BedrockAgentCoreControlClient", "CreateBrowserProfileCommand").sc(schemas_0.CreateBrowserProfile$).build() {
      static {
        __name(this, "CreateBrowserProfileCommand");
      }
    };
    var CreateCodeInterpreterCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "CreateCodeInterpreter", {}).n("BedrockAgentCoreControlClient", "CreateCodeInterpreterCommand").sc(schemas_0.CreateCodeInterpreter$).build() {
      static {
        __name(this, "CreateCodeInterpreterCommand");
      }
    };
    var CreateEvaluatorCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "CreateEvaluator", {}).n("BedrockAgentCoreControlClient", "CreateEvaluatorCommand").sc(schemas_0.CreateEvaluator$).build() {
      static {
        __name(this, "CreateEvaluatorCommand");
      }
    };
    var CreateGatewayCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "CreateGateway", {}).n("BedrockAgentCoreControlClient", "CreateGatewayCommand").sc(schemas_0.CreateGateway$).build() {
      static {
        __name(this, "CreateGatewayCommand");
      }
    };
    var CreateGatewayTargetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "CreateGatewayTarget", {}).n("BedrockAgentCoreControlClient", "CreateGatewayTargetCommand").sc(schemas_0.CreateGatewayTarget$).build() {
      static {
        __name(this, "CreateGatewayTargetCommand");
      }
    };
    var CreateHarnessCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "CreateHarness", {}).n("BedrockAgentCoreControlClient", "CreateHarnessCommand").sc(schemas_0.CreateHarness$).build() {
      static {
        __name(this, "CreateHarnessCommand");
      }
    };
    var CreateMemoryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "CreateMemory", {}).n("BedrockAgentCoreControlClient", "CreateMemoryCommand").sc(schemas_0.CreateMemory$).build() {
      static {
        __name(this, "CreateMemoryCommand");
      }
    };
    var CreateOauth2CredentialProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "CreateOauth2CredentialProvider", {}).n("BedrockAgentCoreControlClient", "CreateOauth2CredentialProviderCommand").sc(schemas_0.CreateOauth2CredentialProvider$).build() {
      static {
        __name(this, "CreateOauth2CredentialProviderCommand");
      }
    };
    var CreateOnlineEvaluationConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "CreateOnlineEvaluationConfig", {}).n("BedrockAgentCoreControlClient", "CreateOnlineEvaluationConfigCommand").sc(schemas_0.CreateOnlineEvaluationConfig$).build() {
      static {
        __name(this, "CreateOnlineEvaluationConfigCommand");
      }
    };
    var CreatePolicyCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "CreatePolicy", {}).n("BedrockAgentCoreControlClient", "CreatePolicyCommand").sc(schemas_0.CreatePolicy$).build() {
      static {
        __name(this, "CreatePolicyCommand");
      }
    };
    var CreatePolicyEngineCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "CreatePolicyEngine", {}).n("BedrockAgentCoreControlClient", "CreatePolicyEngineCommand").sc(schemas_0.CreatePolicyEngine$).build() {
      static {
        __name(this, "CreatePolicyEngineCommand");
      }
    };
    var CreateRegistryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "CreateRegistry", {}).n("BedrockAgentCoreControlClient", "CreateRegistryCommand").sc(schemas_0.CreateRegistry$).build() {
      static {
        __name(this, "CreateRegistryCommand");
      }
    };
    var CreateRegistryRecordCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "CreateRegistryRecord", {}).n("BedrockAgentCoreControlClient", "CreateRegistryRecordCommand").sc(schemas_0.CreateRegistryRecord$).build() {
      static {
        __name(this, "CreateRegistryRecordCommand");
      }
    };
    var CreateWorkloadIdentityCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "CreateWorkloadIdentity", {}).n("BedrockAgentCoreControlClient", "CreateWorkloadIdentityCommand").sc(schemas_0.CreateWorkloadIdentity$).build() {
      static {
        __name(this, "CreateWorkloadIdentityCommand");
      }
    };
    var DeleteAgentRuntimeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "DeleteAgentRuntime", {}).n("BedrockAgentCoreControlClient", "DeleteAgentRuntimeCommand").sc(schemas_0.DeleteAgentRuntime$).build() {
      static {
        __name(this, "DeleteAgentRuntimeCommand");
      }
    };
    var DeleteAgentRuntimeEndpointCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "DeleteAgentRuntimeEndpoint", {}).n("BedrockAgentCoreControlClient", "DeleteAgentRuntimeEndpointCommand").sc(schemas_0.DeleteAgentRuntimeEndpoint$).build() {
      static {
        __name(this, "DeleteAgentRuntimeEndpointCommand");
      }
    };
    var DeleteApiKeyCredentialProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "DeleteApiKeyCredentialProvider", {}).n("BedrockAgentCoreControlClient", "DeleteApiKeyCredentialProviderCommand").sc(schemas_0.DeleteApiKeyCredentialProvider$).build() {
      static {
        __name(this, "DeleteApiKeyCredentialProviderCommand");
      }
    };
    var DeleteBrowserCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "DeleteBrowser", {}).n("BedrockAgentCoreControlClient", "DeleteBrowserCommand").sc(schemas_0.DeleteBrowser$).build() {
      static {
        __name(this, "DeleteBrowserCommand");
      }
    };
    var DeleteBrowserProfileCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "DeleteBrowserProfile", {}).n("BedrockAgentCoreControlClient", "DeleteBrowserProfileCommand").sc(schemas_0.DeleteBrowserProfile$).build() {
      static {
        __name(this, "DeleteBrowserProfileCommand");
      }
    };
    var DeleteCodeInterpreterCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "DeleteCodeInterpreter", {}).n("BedrockAgentCoreControlClient", "DeleteCodeInterpreterCommand").sc(schemas_0.DeleteCodeInterpreter$).build() {
      static {
        __name(this, "DeleteCodeInterpreterCommand");
      }
    };
    var DeleteEvaluatorCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "DeleteEvaluator", {}).n("BedrockAgentCoreControlClient", "DeleteEvaluatorCommand").sc(schemas_0.DeleteEvaluator$).build() {
      static {
        __name(this, "DeleteEvaluatorCommand");
      }
    };
    var DeleteGatewayCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "DeleteGateway", {}).n("BedrockAgentCoreControlClient", "DeleteGatewayCommand").sc(schemas_0.DeleteGateway$).build() {
      static {
        __name(this, "DeleteGatewayCommand");
      }
    };
    var DeleteGatewayTargetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "DeleteGatewayTarget", {}).n("BedrockAgentCoreControlClient", "DeleteGatewayTargetCommand").sc(schemas_0.DeleteGatewayTarget$).build() {
      static {
        __name(this, "DeleteGatewayTargetCommand");
      }
    };
    var DeleteHarnessCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "DeleteHarness", {}).n("BedrockAgentCoreControlClient", "DeleteHarnessCommand").sc(schemas_0.DeleteHarness$).build() {
      static {
        __name(this, "DeleteHarnessCommand");
      }
    };
    var DeleteMemoryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "DeleteMemory", {}).n("BedrockAgentCoreControlClient", "DeleteMemoryCommand").sc(schemas_0.DeleteMemory$).build() {
      static {
        __name(this, "DeleteMemoryCommand");
      }
    };
    var DeleteOauth2CredentialProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "DeleteOauth2CredentialProvider", {}).n("BedrockAgentCoreControlClient", "DeleteOauth2CredentialProviderCommand").sc(schemas_0.DeleteOauth2CredentialProvider$).build() {
      static {
        __name(this, "DeleteOauth2CredentialProviderCommand");
      }
    };
    var DeleteOnlineEvaluationConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "DeleteOnlineEvaluationConfig", {}).n("BedrockAgentCoreControlClient", "DeleteOnlineEvaluationConfigCommand").sc(schemas_0.DeleteOnlineEvaluationConfig$).build() {
      static {
        __name(this, "DeleteOnlineEvaluationConfigCommand");
      }
    };
    var DeletePolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "DeletePolicy", {}).n("BedrockAgentCoreControlClient", "DeletePolicyCommand").sc(schemas_0.DeletePolicy$).build() {
      static {
        __name(this, "DeletePolicyCommand");
      }
    };
    var DeletePolicyEngineCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "DeletePolicyEngine", {}).n("BedrockAgentCoreControlClient", "DeletePolicyEngineCommand").sc(schemas_0.DeletePolicyEngine$).build() {
      static {
        __name(this, "DeletePolicyEngineCommand");
      }
    };
    var DeleteRegistryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "DeleteRegistry", {}).n("BedrockAgentCoreControlClient", "DeleteRegistryCommand").sc(schemas_0.DeleteRegistry$).build() {
      static {
        __name(this, "DeleteRegistryCommand");
      }
    };
    var DeleteRegistryRecordCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "DeleteRegistryRecord", {}).n("BedrockAgentCoreControlClient", "DeleteRegistryRecordCommand").sc(schemas_0.DeleteRegistryRecord$).build() {
      static {
        __name(this, "DeleteRegistryRecordCommand");
      }
    };
    var DeleteResourcePolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "DeleteResourcePolicy", {}).n("BedrockAgentCoreControlClient", "DeleteResourcePolicyCommand").sc(schemas_0.DeleteResourcePolicy$).build() {
      static {
        __name(this, "DeleteResourcePolicyCommand");
      }
    };
    var DeleteWorkloadIdentityCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "DeleteWorkloadIdentity", {}).n("BedrockAgentCoreControlClient", "DeleteWorkloadIdentityCommand").sc(schemas_0.DeleteWorkloadIdentity$).build() {
      static {
        __name(this, "DeleteWorkloadIdentityCommand");
      }
    };
    var GetAgentRuntimeCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "GetAgentRuntime", {}).n("BedrockAgentCoreControlClient", "GetAgentRuntimeCommand").sc(schemas_0.GetAgentRuntime$).build() {
      static {
        __name(this, "GetAgentRuntimeCommand");
      }
    };
    var GetAgentRuntimeEndpointCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "GetAgentRuntimeEndpoint", {}).n("BedrockAgentCoreControlClient", "GetAgentRuntimeEndpointCommand").sc(schemas_0.GetAgentRuntimeEndpoint$).build() {
      static {
        __name(this, "GetAgentRuntimeEndpointCommand");
      }
    };
    var GetApiKeyCredentialProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "GetApiKeyCredentialProvider", {}).n("BedrockAgentCoreControlClient", "GetApiKeyCredentialProviderCommand").sc(schemas_0.GetApiKeyCredentialProvider$).build() {
      static {
        __name(this, "GetApiKeyCredentialProviderCommand");
      }
    };
    var GetBrowserCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "GetBrowser", {}).n("BedrockAgentCoreControlClient", "GetBrowserCommand").sc(schemas_0.GetBrowser$).build() {
      static {
        __name(this, "GetBrowserCommand");
      }
    };
    var GetBrowserProfileCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "GetBrowserProfile", {}).n("BedrockAgentCoreControlClient", "GetBrowserProfileCommand").sc(schemas_0.GetBrowserProfile$).build() {
      static {
        __name(this, "GetBrowserProfileCommand");
      }
    };
    var GetCodeInterpreterCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "GetCodeInterpreter", {}).n("BedrockAgentCoreControlClient", "GetCodeInterpreterCommand").sc(schemas_0.GetCodeInterpreter$).build() {
      static {
        __name(this, "GetCodeInterpreterCommand");
      }
    };
    var GetEvaluatorCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "GetEvaluator", {}).n("BedrockAgentCoreControlClient", "GetEvaluatorCommand").sc(schemas_0.GetEvaluator$).build() {
      static {
        __name(this, "GetEvaluatorCommand");
      }
    };
    var GetGatewayCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "GetGateway", {}).n("BedrockAgentCoreControlClient", "GetGatewayCommand").sc(schemas_0.GetGateway$).build() {
      static {
        __name(this, "GetGatewayCommand");
      }
    };
    var GetGatewayTargetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "GetGatewayTarget", {}).n("BedrockAgentCoreControlClient", "GetGatewayTargetCommand").sc(schemas_0.GetGatewayTarget$).build() {
      static {
        __name(this, "GetGatewayTargetCommand");
      }
    };
    var GetHarnessCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "GetHarness", {}).n("BedrockAgentCoreControlClient", "GetHarnessCommand").sc(schemas_0.GetHarness$).build() {
      static {
        __name(this, "GetHarnessCommand");
      }
    };
    var GetMemoryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "GetMemory", {}).n("BedrockAgentCoreControlClient", "GetMemoryCommand").sc(schemas_0.GetMemory$).build() {
      static {
        __name(this, "GetMemoryCommand");
      }
    };
    var GetOauth2CredentialProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "GetOauth2CredentialProvider", {}).n("BedrockAgentCoreControlClient", "GetOauth2CredentialProviderCommand").sc(schemas_0.GetOauth2CredentialProvider$).build() {
      static {
        __name(this, "GetOauth2CredentialProviderCommand");
      }
    };
    var GetOnlineEvaluationConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "GetOnlineEvaluationConfig", {}).n("BedrockAgentCoreControlClient", "GetOnlineEvaluationConfigCommand").sc(schemas_0.GetOnlineEvaluationConfig$).build() {
      static {
        __name(this, "GetOnlineEvaluationConfigCommand");
      }
    };
    var GetPolicyCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "GetPolicy", {}).n("BedrockAgentCoreControlClient", "GetPolicyCommand").sc(schemas_0.GetPolicy$).build() {
      static {
        __name(this, "GetPolicyCommand");
      }
    };
    var GetPolicyEngineCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "GetPolicyEngine", {}).n("BedrockAgentCoreControlClient", "GetPolicyEngineCommand").sc(schemas_0.GetPolicyEngine$).build() {
      static {
        __name(this, "GetPolicyEngineCommand");
      }
    };
    var GetPolicyGenerationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "GetPolicyGeneration", {}).n("BedrockAgentCoreControlClient", "GetPolicyGenerationCommand").sc(schemas_0.GetPolicyGeneration$).build() {
      static {
        __name(this, "GetPolicyGenerationCommand");
      }
    };
    var GetRegistryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "GetRegistry", {}).n("BedrockAgentCoreControlClient", "GetRegistryCommand").sc(schemas_0.GetRegistry$).build() {
      static {
        __name(this, "GetRegistryCommand");
      }
    };
    var GetRegistryRecordCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "GetRegistryRecord", {}).n("BedrockAgentCoreControlClient", "GetRegistryRecordCommand").sc(schemas_0.GetRegistryRecord$).build() {
      static {
        __name(this, "GetRegistryRecordCommand");
      }
    };
    var GetResourcePolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "GetResourcePolicy", {}).n("BedrockAgentCoreControlClient", "GetResourcePolicyCommand").sc(schemas_0.GetResourcePolicy$).build() {
      static {
        __name(this, "GetResourcePolicyCommand");
      }
    };
    var GetTokenVaultCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "GetTokenVault", {}).n("BedrockAgentCoreControlClient", "GetTokenVaultCommand").sc(schemas_0.GetTokenVault$).build() {
      static {
        __name(this, "GetTokenVaultCommand");
      }
    };
    var GetWorkloadIdentityCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "GetWorkloadIdentity", {}).n("BedrockAgentCoreControlClient", "GetWorkloadIdentityCommand").sc(schemas_0.GetWorkloadIdentity$).build() {
      static {
        __name(this, "GetWorkloadIdentityCommand");
      }
    };
    var ListAgentRuntimeEndpointsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "ListAgentRuntimeEndpoints", {}).n("BedrockAgentCoreControlClient", "ListAgentRuntimeEndpointsCommand").sc(schemas_0.ListAgentRuntimeEndpoints$).build() {
      static {
        __name(this, "ListAgentRuntimeEndpointsCommand");
      }
    };
    var ListAgentRuntimesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "ListAgentRuntimes", {}).n("BedrockAgentCoreControlClient", "ListAgentRuntimesCommand").sc(schemas_0.ListAgentRuntimes$).build() {
      static {
        __name(this, "ListAgentRuntimesCommand");
      }
    };
    var ListAgentRuntimeVersionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "ListAgentRuntimeVersions", {}).n("BedrockAgentCoreControlClient", "ListAgentRuntimeVersionsCommand").sc(schemas_0.ListAgentRuntimeVersions$).build() {
      static {
        __name(this, "ListAgentRuntimeVersionsCommand");
      }
    };
    var ListApiKeyCredentialProvidersCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "ListApiKeyCredentialProviders", {}).n("BedrockAgentCoreControlClient", "ListApiKeyCredentialProvidersCommand").sc(schemas_0.ListApiKeyCredentialProviders$).build() {
      static {
        __name(this, "ListApiKeyCredentialProvidersCommand");
      }
    };
    var ListBrowserProfilesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "ListBrowserProfiles", {}).n("BedrockAgentCoreControlClient", "ListBrowserProfilesCommand").sc(schemas_0.ListBrowserProfiles$).build() {
      static {
        __name(this, "ListBrowserProfilesCommand");
      }
    };
    var ListBrowsersCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "ListBrowsers", {}).n("BedrockAgentCoreControlClient", "ListBrowsersCommand").sc(schemas_0.ListBrowsers$).build() {
      static {
        __name(this, "ListBrowsersCommand");
      }
    };
    var ListCodeInterpretersCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "ListCodeInterpreters", {}).n("BedrockAgentCoreControlClient", "ListCodeInterpretersCommand").sc(schemas_0.ListCodeInterpreters$).build() {
      static {
        __name(this, "ListCodeInterpretersCommand");
      }
    };
    var ListEvaluatorsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "ListEvaluators", {}).n("BedrockAgentCoreControlClient", "ListEvaluatorsCommand").sc(schemas_0.ListEvaluators$).build() {
      static {
        __name(this, "ListEvaluatorsCommand");
      }
    };
    var ListGatewaysCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "ListGateways", {}).n("BedrockAgentCoreControlClient", "ListGatewaysCommand").sc(schemas_0.ListGateways$).build() {
      static {
        __name(this, "ListGatewaysCommand");
      }
    };
    var ListGatewayTargetsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "ListGatewayTargets", {}).n("BedrockAgentCoreControlClient", "ListGatewayTargetsCommand").sc(schemas_0.ListGatewayTargets$).build() {
      static {
        __name(this, "ListGatewayTargetsCommand");
      }
    };
    var ListHarnessesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "ListHarnesses", {}).n("BedrockAgentCoreControlClient", "ListHarnessesCommand").sc(schemas_0.ListHarnesses$).build() {
      static {
        __name(this, "ListHarnessesCommand");
      }
    };
    var ListMemoriesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "ListMemories", {}).n("BedrockAgentCoreControlClient", "ListMemoriesCommand").sc(schemas_0.ListMemories$).build() {
      static {
        __name(this, "ListMemoriesCommand");
      }
    };
    var ListOauth2CredentialProvidersCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "ListOauth2CredentialProviders", {}).n("BedrockAgentCoreControlClient", "ListOauth2CredentialProvidersCommand").sc(schemas_0.ListOauth2CredentialProviders$).build() {
      static {
        __name(this, "ListOauth2CredentialProvidersCommand");
      }
    };
    var ListOnlineEvaluationConfigsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "ListOnlineEvaluationConfigs", {}).n("BedrockAgentCoreControlClient", "ListOnlineEvaluationConfigsCommand").sc(schemas_0.ListOnlineEvaluationConfigs$).build() {
      static {
        __name(this, "ListOnlineEvaluationConfigsCommand");
      }
    };
    var ListPoliciesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "ListPolicies", {}).n("BedrockAgentCoreControlClient", "ListPoliciesCommand").sc(schemas_0.ListPolicies$).build() {
      static {
        __name(this, "ListPoliciesCommand");
      }
    };
    var ListPolicyEnginesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "ListPolicyEngines", {}).n("BedrockAgentCoreControlClient", "ListPolicyEnginesCommand").sc(schemas_0.ListPolicyEngines$).build() {
      static {
        __name(this, "ListPolicyEnginesCommand");
      }
    };
    var ListPolicyGenerationAssetsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "ListPolicyGenerationAssets", {}).n("BedrockAgentCoreControlClient", "ListPolicyGenerationAssetsCommand").sc(schemas_0.ListPolicyGenerationAssets$).build() {
      static {
        __name(this, "ListPolicyGenerationAssetsCommand");
      }
    };
    var ListPolicyGenerationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "ListPolicyGenerations", {}).n("BedrockAgentCoreControlClient", "ListPolicyGenerationsCommand").sc(schemas_0.ListPolicyGenerations$).build() {
      static {
        __name(this, "ListPolicyGenerationsCommand");
      }
    };
    var ListRegistriesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "ListRegistries", {}).n("BedrockAgentCoreControlClient", "ListRegistriesCommand").sc(schemas_0.ListRegistries$).build() {
      static {
        __name(this, "ListRegistriesCommand");
      }
    };
    var ListRegistryRecordsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "ListRegistryRecords", {}).n("BedrockAgentCoreControlClient", "ListRegistryRecordsCommand").sc(schemas_0.ListRegistryRecords$).build() {
      static {
        __name(this, "ListRegistryRecordsCommand");
      }
    };
    var ListTagsForResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "ListTagsForResource", {}).n("BedrockAgentCoreControlClient", "ListTagsForResourceCommand").sc(schemas_0.ListTagsForResource$).build() {
      static {
        __name(this, "ListTagsForResourceCommand");
      }
    };
    var ListWorkloadIdentitiesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "ListWorkloadIdentities", {}).n("BedrockAgentCoreControlClient", "ListWorkloadIdentitiesCommand").sc(schemas_0.ListWorkloadIdentities$).build() {
      static {
        __name(this, "ListWorkloadIdentitiesCommand");
      }
    };
    var PutResourcePolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "PutResourcePolicy", {}).n("BedrockAgentCoreControlClient", "PutResourcePolicyCommand").sc(schemas_0.PutResourcePolicy$).build() {
      static {
        __name(this, "PutResourcePolicyCommand");
      }
    };
    var SetTokenVaultCMKCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "SetTokenVaultCMK", {}).n("BedrockAgentCoreControlClient", "SetTokenVaultCMKCommand").sc(schemas_0.SetTokenVaultCMK$).build() {
      static {
        __name(this, "SetTokenVaultCMKCommand");
      }
    };
    var StartPolicyGenerationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "StartPolicyGeneration", {}).n("BedrockAgentCoreControlClient", "StartPolicyGenerationCommand").sc(schemas_0.StartPolicyGeneration$).build() {
      static {
        __name(this, "StartPolicyGenerationCommand");
      }
    };
    var SubmitRegistryRecordForApprovalCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "SubmitRegistryRecordForApproval", {}).n("BedrockAgentCoreControlClient", "SubmitRegistryRecordForApprovalCommand").sc(schemas_0.SubmitRegistryRecordForApproval$).build() {
      static {
        __name(this, "SubmitRegistryRecordForApprovalCommand");
      }
    };
    var SynchronizeGatewayTargetsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "SynchronizeGatewayTargets", {}).n("BedrockAgentCoreControlClient", "SynchronizeGatewayTargetsCommand").sc(schemas_0.SynchronizeGatewayTargets$).build() {
      static {
        __name(this, "SynchronizeGatewayTargetsCommand");
      }
    };
    var TagResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "TagResource", {}).n("BedrockAgentCoreControlClient", "TagResourceCommand").sc(schemas_0.TagResource$).build() {
      static {
        __name(this, "TagResourceCommand");
      }
    };
    var UntagResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "UntagResource", {}).n("BedrockAgentCoreControlClient", "UntagResourceCommand").sc(schemas_0.UntagResource$).build() {
      static {
        __name(this, "UntagResourceCommand");
      }
    };
    var UpdateAgentRuntimeCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "UpdateAgentRuntime", {}).n("BedrockAgentCoreControlClient", "UpdateAgentRuntimeCommand").sc(schemas_0.UpdateAgentRuntime$).build() {
      static {
        __name(this, "UpdateAgentRuntimeCommand");
      }
    };
    var UpdateAgentRuntimeEndpointCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "UpdateAgentRuntimeEndpoint", {}).n("BedrockAgentCoreControlClient", "UpdateAgentRuntimeEndpointCommand").sc(schemas_0.UpdateAgentRuntimeEndpoint$).build() {
      static {
        __name(this, "UpdateAgentRuntimeEndpointCommand");
      }
    };
    var UpdateApiKeyCredentialProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "UpdateApiKeyCredentialProvider", {}).n("BedrockAgentCoreControlClient", "UpdateApiKeyCredentialProviderCommand").sc(schemas_0.UpdateApiKeyCredentialProvider$).build() {
      static {
        __name(this, "UpdateApiKeyCredentialProviderCommand");
      }
    };
    var UpdateEvaluatorCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "UpdateEvaluator", {}).n("BedrockAgentCoreControlClient", "UpdateEvaluatorCommand").sc(schemas_0.UpdateEvaluator$).build() {
      static {
        __name(this, "UpdateEvaluatorCommand");
      }
    };
    var UpdateGatewayCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "UpdateGateway", {}).n("BedrockAgentCoreControlClient", "UpdateGatewayCommand").sc(schemas_0.UpdateGateway$).build() {
      static {
        __name(this, "UpdateGatewayCommand");
      }
    };
    var UpdateGatewayTargetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "UpdateGatewayTarget", {}).n("BedrockAgentCoreControlClient", "UpdateGatewayTargetCommand").sc(schemas_0.UpdateGatewayTarget$).build() {
      static {
        __name(this, "UpdateGatewayTargetCommand");
      }
    };
    var UpdateHarnessCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "UpdateHarness", {}).n("BedrockAgentCoreControlClient", "UpdateHarnessCommand").sc(schemas_0.UpdateHarness$).build() {
      static {
        __name(this, "UpdateHarnessCommand");
      }
    };
    var UpdateMemoryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "UpdateMemory", {}).n("BedrockAgentCoreControlClient", "UpdateMemoryCommand").sc(schemas_0.UpdateMemory$).build() {
      static {
        __name(this, "UpdateMemoryCommand");
      }
    };
    var UpdateOauth2CredentialProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "UpdateOauth2CredentialProvider", {}).n("BedrockAgentCoreControlClient", "UpdateOauth2CredentialProviderCommand").sc(schemas_0.UpdateOauth2CredentialProvider$).build() {
      static {
        __name(this, "UpdateOauth2CredentialProviderCommand");
      }
    };
    var UpdateOnlineEvaluationConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "UpdateOnlineEvaluationConfig", {}).n("BedrockAgentCoreControlClient", "UpdateOnlineEvaluationConfigCommand").sc(schemas_0.UpdateOnlineEvaluationConfig$).build() {
      static {
        __name(this, "UpdateOnlineEvaluationConfigCommand");
      }
    };
    var UpdatePolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "UpdatePolicy", {}).n("BedrockAgentCoreControlClient", "UpdatePolicyCommand").sc(schemas_0.UpdatePolicy$).build() {
      static {
        __name(this, "UpdatePolicyCommand");
      }
    };
    var UpdatePolicyEngineCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "UpdatePolicyEngine", {}).n("BedrockAgentCoreControlClient", "UpdatePolicyEngineCommand").sc(schemas_0.UpdatePolicyEngine$).build() {
      static {
        __name(this, "UpdatePolicyEngineCommand");
      }
    };
    var UpdateRegistryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "UpdateRegistry", {}).n("BedrockAgentCoreControlClient", "UpdateRegistryCommand").sc(schemas_0.UpdateRegistry$).build() {
      static {
        __name(this, "UpdateRegistryCommand");
      }
    };
    var UpdateRegistryRecordCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "UpdateRegistryRecord", {}).n("BedrockAgentCoreControlClient", "UpdateRegistryRecordCommand").sc(schemas_0.UpdateRegistryRecord$).build() {
      static {
        __name(this, "UpdateRegistryRecordCommand");
      }
    };
    var UpdateRegistryRecordStatusCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "UpdateRegistryRecordStatus", {}).n("BedrockAgentCoreControlClient", "UpdateRegistryRecordStatusCommand").sc(schemas_0.UpdateRegistryRecordStatus$).build() {
      static {
        __name(this, "UpdateRegistryRecordStatusCommand");
      }
    };
    var UpdateWorkloadIdentityCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonBedrockAgentCoreControl", "UpdateWorkloadIdentity", {}).n("BedrockAgentCoreControlClient", "UpdateWorkloadIdentityCommand").sc(schemas_0.UpdateWorkloadIdentity$).build() {
      static {
        __name(this, "UpdateWorkloadIdentityCommand");
      }
    };
    var paginateListAgentRuntimeEndpoints = core.createPaginator(BedrockAgentCoreControlClient2, ListAgentRuntimeEndpointsCommand, "nextToken", "nextToken", "maxResults");
    var paginateListAgentRuntimes = core.createPaginator(BedrockAgentCoreControlClient2, ListAgentRuntimesCommand, "nextToken", "nextToken", "maxResults");
    var paginateListAgentRuntimeVersions = core.createPaginator(BedrockAgentCoreControlClient2, ListAgentRuntimeVersionsCommand, "nextToken", "nextToken", "maxResults");
    var paginateListApiKeyCredentialProviders = core.createPaginator(BedrockAgentCoreControlClient2, ListApiKeyCredentialProvidersCommand, "nextToken", "nextToken", "maxResults");
    var paginateListBrowserProfiles = core.createPaginator(BedrockAgentCoreControlClient2, ListBrowserProfilesCommand, "nextToken", "nextToken", "maxResults");
    var paginateListBrowsers = core.createPaginator(BedrockAgentCoreControlClient2, ListBrowsersCommand, "nextToken", "nextToken", "maxResults");
    var paginateListCodeInterpreters = core.createPaginator(BedrockAgentCoreControlClient2, ListCodeInterpretersCommand, "nextToken", "nextToken", "maxResults");
    var paginateListEvaluators = core.createPaginator(BedrockAgentCoreControlClient2, ListEvaluatorsCommand, "nextToken", "nextToken", "maxResults");
    var paginateListGateways = core.createPaginator(BedrockAgentCoreControlClient2, ListGatewaysCommand, "nextToken", "nextToken", "maxResults");
    var paginateListGatewayTargets = core.createPaginator(BedrockAgentCoreControlClient2, ListGatewayTargetsCommand, "nextToken", "nextToken", "maxResults");
    var paginateListHarnesses = core.createPaginator(BedrockAgentCoreControlClient2, ListHarnessesCommand, "nextToken", "nextToken", "maxResults");
    var paginateListMemories = core.createPaginator(BedrockAgentCoreControlClient2, ListMemoriesCommand, "nextToken", "nextToken", "maxResults");
    var paginateListOauth2CredentialProviders = core.createPaginator(BedrockAgentCoreControlClient2, ListOauth2CredentialProvidersCommand, "nextToken", "nextToken", "maxResults");
    var paginateListOnlineEvaluationConfigs = core.createPaginator(BedrockAgentCoreControlClient2, ListOnlineEvaluationConfigsCommand, "nextToken", "nextToken", "maxResults");
    var paginateListPolicies = core.createPaginator(BedrockAgentCoreControlClient2, ListPoliciesCommand, "nextToken", "nextToken", "maxResults");
    var paginateListPolicyEngines = core.createPaginator(BedrockAgentCoreControlClient2, ListPolicyEnginesCommand, "nextToken", "nextToken", "maxResults");
    var paginateListPolicyGenerationAssets = core.createPaginator(BedrockAgentCoreControlClient2, ListPolicyGenerationAssetsCommand, "nextToken", "nextToken", "maxResults");
    var paginateListPolicyGenerations = core.createPaginator(BedrockAgentCoreControlClient2, ListPolicyGenerationsCommand, "nextToken", "nextToken", "maxResults");
    var paginateListRegistries = core.createPaginator(BedrockAgentCoreControlClient2, ListRegistriesCommand, "nextToken", "nextToken", "maxResults");
    var paginateListRegistryRecords = core.createPaginator(BedrockAgentCoreControlClient2, ListRegistryRecordsCommand, "nextToken", "nextToken", "maxResults");
    var paginateListWorkloadIdentities = core.createPaginator(BedrockAgentCoreControlClient2, ListWorkloadIdentitiesCommand, "nextToken", "nextToken", "maxResults");
    var checkState$5 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new GetMemoryCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.memory.status;
          }, "returnComparator");
          if (returnComparator() === "CREATING") {
            return { state: utilWaiter.WaiterState.RETRY, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.memory.status;
          }, "returnComparator");
          if (returnComparator() === "ACTIVE") {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.memory.status;
          }, "returnComparator");
          if (returnComparator() === "FAILED") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$5");
    var waitForMemoryCreated = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 2, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$5);
    }, "waitForMemoryCreated");
    var waitUntilMemoryCreated = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 2, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$5);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilMemoryCreated");
    var checkState$4 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new GetPolicyCommand2(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.status;
          }, "returnComparator");
          if (returnComparator() === "ACTIVE") {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.status;
          }, "returnComparator");
          if (returnComparator() === "CREATE_FAILED") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.status;
          }, "returnComparator");
          if (returnComparator() === "UPDATE_FAILED") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.status;
          }, "returnComparator");
          if (returnComparator() === "DELETE_FAILED") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$4");
    var waitForPolicyActive = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$4);
    }, "waitForPolicyActive");
    var waitUntilPolicyActive = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$4);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilPolicyActive");
    var checkState$3 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new GetPolicyCommand2(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.status;
          }, "returnComparator");
          if (returnComparator() === "DELETING") {
            return { state: utilWaiter.WaiterState.RETRY, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.status;
          }, "returnComparator");
          if (returnComparator() === "DELETE_FAILED") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "ResourceNotFoundException") {
          return { state: utilWaiter.WaiterState.SUCCESS, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$3");
    var waitForPolicyDeleted = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 2, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$3);
    }, "waitForPolicyDeleted");
    var waitUntilPolicyDeleted = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 2, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$3);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilPolicyDeleted");
    var checkState$2 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new GetPolicyEngineCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.status;
          }, "returnComparator");
          if (returnComparator() === "ACTIVE") {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.status;
          }, "returnComparator");
          if (returnComparator() === "CREATE_FAILED") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.status;
          }, "returnComparator");
          if (returnComparator() === "UPDATE_FAILED") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.status;
          }, "returnComparator");
          if (returnComparator() === "DELETE_FAILED") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$2");
    var waitForPolicyEngineActive = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$2);
    }, "waitForPolicyEngineActive");
    var waitUntilPolicyEngineActive = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$2);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilPolicyEngineActive");
    var checkState$1 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new GetPolicyEngineCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.status;
          }, "returnComparator");
          if (returnComparator() === "DELETING") {
            return { state: utilWaiter.WaiterState.RETRY, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.status;
          }, "returnComparator");
          if (returnComparator() === "DELETE_FAILED") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "ResourceNotFoundException") {
          return { state: utilWaiter.WaiterState.SUCCESS, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$1");
    var waitForPolicyEngineDeleted = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 2, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$1);
    }, "waitForPolicyEngineDeleted");
    var waitUntilPolicyEngineDeleted = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 2, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$1);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilPolicyEngineDeleted");
    var checkState = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new GetPolicyGenerationCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.status;
          }, "returnComparator");
          if (returnComparator() === "GENERATED") {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.status;
          }, "returnComparator");
          if (returnComparator() === "GENERATING") {
            return { state: utilWaiter.WaiterState.RETRY, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.status;
          }, "returnComparator");
          if (returnComparator() === "GENERATE_FAILED") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.status;
          }, "returnComparator");
          if (returnComparator() === "DELETE_FAILED") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState");
    var waitForPolicyGenerationCompleted = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState);
    }, "waitForPolicyGenerationCompleted");
    var waitUntilPolicyGenerationCompleted = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilPolicyGenerationCompleted");
    var commands32 = {
      CreateAgentRuntimeCommand,
      CreateAgentRuntimeEndpointCommand,
      CreateApiKeyCredentialProviderCommand,
      CreateBrowserCommand,
      CreateBrowserProfileCommand,
      CreateCodeInterpreterCommand,
      CreateEvaluatorCommand,
      CreateGatewayCommand,
      CreateGatewayTargetCommand,
      CreateHarnessCommand,
      CreateMemoryCommand,
      CreateOauth2CredentialProviderCommand,
      CreateOnlineEvaluationConfigCommand,
      CreatePolicyCommand: CreatePolicyCommand2,
      CreatePolicyEngineCommand,
      CreateRegistryCommand,
      CreateRegistryRecordCommand,
      CreateWorkloadIdentityCommand,
      DeleteAgentRuntimeCommand,
      DeleteAgentRuntimeEndpointCommand,
      DeleteApiKeyCredentialProviderCommand,
      DeleteBrowserCommand,
      DeleteBrowserProfileCommand,
      DeleteCodeInterpreterCommand,
      DeleteEvaluatorCommand,
      DeleteGatewayCommand,
      DeleteGatewayTargetCommand,
      DeleteHarnessCommand,
      DeleteMemoryCommand,
      DeleteOauth2CredentialProviderCommand,
      DeleteOnlineEvaluationConfigCommand,
      DeletePolicyCommand,
      DeletePolicyEngineCommand,
      DeleteRegistryCommand,
      DeleteRegistryRecordCommand,
      DeleteResourcePolicyCommand,
      DeleteWorkloadIdentityCommand,
      GetAgentRuntimeCommand: GetAgentRuntimeCommand2,
      GetAgentRuntimeEndpointCommand,
      GetApiKeyCredentialProviderCommand,
      GetBrowserCommand,
      GetBrowserProfileCommand,
      GetCodeInterpreterCommand,
      GetEvaluatorCommand,
      GetGatewayCommand,
      GetGatewayTargetCommand,
      GetHarnessCommand,
      GetMemoryCommand,
      GetOauth2CredentialProviderCommand,
      GetOnlineEvaluationConfigCommand,
      GetPolicyCommand: GetPolicyCommand2,
      GetPolicyEngineCommand,
      GetPolicyGenerationCommand,
      GetRegistryCommand,
      GetRegistryRecordCommand,
      GetResourcePolicyCommand,
      GetTokenVaultCommand,
      GetWorkloadIdentityCommand,
      ListAgentRuntimeEndpointsCommand,
      ListAgentRuntimesCommand,
      ListAgentRuntimeVersionsCommand,
      ListApiKeyCredentialProvidersCommand,
      ListBrowserProfilesCommand,
      ListBrowsersCommand,
      ListCodeInterpretersCommand,
      ListEvaluatorsCommand,
      ListGatewaysCommand,
      ListGatewayTargetsCommand,
      ListHarnessesCommand,
      ListMemoriesCommand,
      ListOauth2CredentialProvidersCommand,
      ListOnlineEvaluationConfigsCommand,
      ListPoliciesCommand,
      ListPolicyEnginesCommand,
      ListPolicyGenerationAssetsCommand,
      ListPolicyGenerationsCommand,
      ListRegistriesCommand,
      ListRegistryRecordsCommand,
      ListTagsForResourceCommand,
      ListWorkloadIdentitiesCommand,
      PutResourcePolicyCommand,
      SetTokenVaultCMKCommand,
      StartPolicyGenerationCommand,
      SubmitRegistryRecordForApprovalCommand,
      SynchronizeGatewayTargetsCommand,
      TagResourceCommand,
      UntagResourceCommand,
      UpdateAgentRuntimeCommand: UpdateAgentRuntimeCommand2,
      UpdateAgentRuntimeEndpointCommand,
      UpdateApiKeyCredentialProviderCommand,
      UpdateEvaluatorCommand,
      UpdateGatewayCommand,
      UpdateGatewayTargetCommand,
      UpdateHarnessCommand,
      UpdateMemoryCommand,
      UpdateOauth2CredentialProviderCommand,
      UpdateOnlineEvaluationConfigCommand,
      UpdatePolicyCommand,
      UpdatePolicyEngineCommand,
      UpdateRegistryCommand,
      UpdateRegistryRecordCommand,
      UpdateRegistryRecordStatusCommand,
      UpdateWorkloadIdentityCommand
    };
    var paginators = {
      paginateListAgentRuntimeEndpoints,
      paginateListAgentRuntimes,
      paginateListAgentRuntimeVersions,
      paginateListApiKeyCredentialProviders,
      paginateListBrowserProfiles,
      paginateListBrowsers,
      paginateListCodeInterpreters,
      paginateListEvaluators,
      paginateListGateways,
      paginateListGatewayTargets,
      paginateListHarnesses,
      paginateListMemories,
      paginateListOauth2CredentialProviders,
      paginateListOnlineEvaluationConfigs,
      paginateListPolicies,
      paginateListPolicyEngines,
      paginateListPolicyGenerationAssets,
      paginateListPolicyGenerations,
      paginateListRegistries,
      paginateListRegistryRecords,
      paginateListWorkloadIdentities
    };
    var waiters = {
      waitUntilMemoryCreated,
      waitUntilPolicyActive,
      waitUntilPolicyDeleted,
      waitUntilPolicyEngineActive,
      waitUntilPolicyEngineDeleted,
      waitUntilPolicyGenerationCompleted
    };
    var BedrockAgentCoreControl = class extends BedrockAgentCoreControlClient2 {
      static {
        __name(this, "BedrockAgentCoreControl");
      }
    };
    smithyClient.createAggregatedClient(commands32, BedrockAgentCoreControl, { paginators, waiters });
    var AgentRuntimeEndpointStatus = {
      CREATE_FAILED: "CREATE_FAILED",
      CREATING: "CREATING",
      DELETING: "DELETING",
      READY: "READY",
      UPDATE_FAILED: "UPDATE_FAILED",
      UPDATING: "UPDATING"
    };
    var ValidationExceptionReason = {
      CANNOT_PARSE: "CannotParse",
      FIELD_VALIDATION_FAILED: "FieldValidationFailed",
      IDEMPOTENT_PARAMETER_MISMATCH_EXCEPTION: "IdempotentParameterMismatchException",
      RESOURCE_CONFLICT: "ResourceConflict",
      ROOT_EVENT_IN_OTHER_SESSION: "EventInOtherSession"
    };
    var AgentManagedRuntimeType = {
      PYTHON_3_10: "PYTHON_3_10",
      PYTHON_3_11: "PYTHON_3_11",
      PYTHON_3_12: "PYTHON_3_12",
      PYTHON_3_13: "PYTHON_3_13",
      PYTHON_3_14: "PYTHON_3_14"
    };
    var ClaimMatchOperatorType = {
      CONTAINS: "CONTAINS",
      CONTAINS_ANY: "CONTAINS_ANY",
      EQUALS: "EQUALS"
    };
    var InboundTokenClaimValueType = {
      STRING: "STRING",
      STRING_ARRAY: "STRING_ARRAY"
    };
    var NetworkMode = {
      PUBLIC: "PUBLIC",
      VPC: "VPC"
    };
    var ServerProtocol = {
      A2A: "A2A",
      AGUI: "AGUI",
      HTTP: "HTTP",
      MCP: "MCP"
    };
    var AgentRuntimeStatus = {
      CREATE_FAILED: "CREATE_FAILED",
      CREATING: "CREATING",
      DELETING: "DELETING",
      READY: "READY",
      UPDATE_FAILED: "UPDATE_FAILED",
      UPDATING: "UPDATING"
    };
    var BrowserProfileStatus = {
      DELETED: "DELETED",
      DELETING: "DELETING",
      READY: "READY",
      SAVING: "SAVING"
    };
    var BrowserEnterprisePolicyType = {
      MANAGED: "MANAGED",
      RECOMMENDED: "RECOMMENDED"
    };
    var BrowserNetworkMode = {
      PUBLIC: "PUBLIC",
      VPC: "VPC"
    };
    var BrowserStatus = {
      CREATE_FAILED: "CREATE_FAILED",
      CREATING: "CREATING",
      DELETED: "DELETED",
      DELETE_FAILED: "DELETE_FAILED",
      DELETING: "DELETING",
      READY: "READY"
    };
    var ResourceType = {
      CUSTOM: "CUSTOM",
      SYSTEM: "SYSTEM"
    };
    var CodeInterpreterNetworkMode = {
      PUBLIC: "PUBLIC",
      SANDBOX: "SANDBOX",
      VPC: "VPC"
    };
    var CodeInterpreterStatus = {
      CREATE_FAILED: "CREATE_FAILED",
      CREATING: "CREATING",
      DELETED: "DELETED",
      DELETE_FAILED: "DELETE_FAILED",
      DELETING: "DELETING",
      READY: "READY"
    };
    var EvaluatorLevel = {
      SESSION: "SESSION",
      TOOL_CALL: "TOOL_CALL",
      TRACE: "TRACE"
    };
    var EvaluatorStatus = {
      ACTIVE: "ACTIVE",
      CREATE_FAILED: "CREATE_FAILED",
      CREATING: "CREATING",
      DELETING: "DELETING",
      UPDATE_FAILED: "UPDATE_FAILED",
      UPDATING: "UPDATING"
    };
    var EvaluatorType = {
      BUILTIN: "Builtin",
      CODE: "CustomCode",
      CUSTOM: "Custom"
    };
    var AuthorizerType = {
      AWS_IAM: "AWS_IAM",
      CUSTOM_JWT: "CUSTOM_JWT",
      NONE: "NONE"
    };
    var ExceptionLevel = {
      DEBUG: "DEBUG"
    };
    var GatewayInterceptionPoint = {
      REQUEST: "REQUEST",
      RESPONSE: "RESPONSE"
    };
    var GatewayPolicyEngineMode = {
      ENFORCE: "ENFORCE",
      LOG_ONLY: "LOG_ONLY"
    };
    var SearchType = {
      SEMANTIC: "SEMANTIC"
    };
    var GatewayProtocolType = {
      MCP: "MCP"
    };
    var GatewayStatus = {
      CREATING: "CREATING",
      DELETING: "DELETING",
      FAILED: "FAILED",
      READY: "READY",
      UPDATE_UNSUCCESSFUL: "UPDATE_UNSUCCESSFUL",
      UPDATING: "UPDATING"
    };
    var ApiKeyCredentialLocation = {
      HEADER: "HEADER",
      QUERY_PARAMETER: "QUERY_PARAMETER"
    };
    var OAuthGrantType = {
      AUTHORIZATION_CODE: "AUTHORIZATION_CODE",
      CLIENT_CREDENTIALS: "CLIENT_CREDENTIALS"
    };
    var CredentialProviderType = {
      API_KEY: "API_KEY",
      GATEWAY_IAM_ROLE: "GATEWAY_IAM_ROLE",
      OAUTH: "OAUTH"
    };
    var EndpointIpAddressType = {
      IPV4: "IPV4",
      IPV6: "IPV6"
    };
    var RestApiMethod = {
      DELETE: "DELETE",
      GET: "GET",
      HEAD: "HEAD",
      OPTIONS: "OPTIONS",
      PATCH: "PATCH",
      POST: "POST",
      PUT: "PUT"
    };
    var SchemaType = {
      ARRAY: "array",
      BOOLEAN: "boolean",
      INTEGER: "integer",
      NUMBER: "number",
      OBJECT: "object",
      STRING: "string"
    };
    var ListingMode = {
      DEFAULT: "DEFAULT",
      DYNAMIC: "DYNAMIC"
    };
    var TargetStatus = {
      CREATE_PENDING_AUTH: "CREATE_PENDING_AUTH",
      CREATING: "CREATING",
      DELETING: "DELETING",
      FAILED: "FAILED",
      READY: "READY",
      SYNCHRONIZE_PENDING_AUTH: "SYNCHRONIZE_PENDING_AUTH",
      SYNCHRONIZE_UNSUCCESSFUL: "SYNCHRONIZE_UNSUCCESSFUL",
      SYNCHRONIZING: "SYNCHRONIZING",
      UPDATE_PENDING_AUTH: "UPDATE_PENDING_AUTH",
      UPDATE_UNSUCCESSFUL: "UPDATE_UNSUCCESSFUL",
      UPDATING: "UPDATING"
    };
    var KeyType = {
      CustomerManagedKey: "CustomerManagedKey",
      ServiceManagedKey: "ServiceManagedKey"
    };
    var HarnessToolType = {
      AGENTCORE_BROWSER: "agentcore_browser",
      AGENTCORE_CODE_INTERPRETER: "agentcore_code_interpreter",
      AGENTCORE_GATEWAY: "agentcore_gateway",
      INLINE_FUNCTION: "inline_function",
      REMOTE_MCP: "remote_mcp"
    };
    var HarnessTruncationStrategy = {
      NONE: "none",
      SLIDING_WINDOW: "sliding_window",
      SUMMARIZATION: "summarization"
    };
    var HarnessStatus = {
      CREATE_FAILED: "CREATE_FAILED",
      CREATING: "CREATING",
      DELETE_FAILED: "DELETE_FAILED",
      DELETING: "DELETING",
      READY: "READY",
      UPDATE_FAILED: "UPDATE_FAILED",
      UPDATING: "UPDATING"
    };
    var ContentLevel = {
      FULL_CONTENT: "FULL_CONTENT",
      METADATA_ONLY: "METADATA_ONLY"
    };
    var ContentType = {
      MEMORY_RECORDS: "MEMORY_RECORDS"
    };
    var MemoryStatus = {
      ACTIVE: "ACTIVE",
      CREATING: "CREATING",
      DELETING: "DELETING",
      FAILED: "FAILED"
    };
    var OverrideType = {
      EPISODIC_OVERRIDE: "EPISODIC_OVERRIDE",
      SELF_MANAGED: "SELF_MANAGED",
      SEMANTIC_OVERRIDE: "SEMANTIC_OVERRIDE",
      SUMMARY_OVERRIDE: "SUMMARY_OVERRIDE",
      USER_PREFERENCE_OVERRIDE: "USER_PREFERENCE_OVERRIDE"
    };
    var MemoryStrategyStatus = {
      ACTIVE: "ACTIVE",
      CREATING: "CREATING",
      DELETING: "DELETING",
      FAILED: "FAILED"
    };
    var MemoryStrategyType = {
      CUSTOM: "CUSTOM",
      EPISODIC: "EPISODIC",
      SEMANTIC: "SEMANTIC",
      SUMMARIZATION: "SUMMARIZATION",
      USER_PREFERENCE: "USER_PREFERENCE"
    };
    var MemoryView = {
      FULL: "full",
      WITHOUT_DECRYPTION: "without_decryption"
    };
    var CredentialProviderVendorType = {
      AtlassianOauth2: "AtlassianOauth2",
      Auth0Oauth2: "Auth0Oauth2",
      CognitoOauth2: "CognitoOauth2",
      CustomOauth2: "CustomOauth2",
      CyberArkOauth2: "CyberArkOauth2",
      DropboxOauth2: "DropboxOauth2",
      FacebookOauth2: "FacebookOauth2",
      FusionAuthOauth2: "FusionAuthOauth2",
      GithubOauth2: "GithubOauth2",
      GoogleOauth2: "GoogleOauth2",
      HubspotOauth2: "HubspotOauth2",
      LinkedinOauth2: "LinkedinOauth2",
      MicrosoftOauth2: "MicrosoftOauth2",
      NotionOauth2: "NotionOauth2",
      OktaOauth2: "OktaOauth2",
      OneLoginOauth2: "OneLoginOauth2",
      PingOneOauth2: "PingOneOauth2",
      RedditOauth2: "RedditOauth2",
      SalesforceOauth2: "SalesforceOauth2",
      SlackOauth2: "SlackOauth2",
      SpotifyOauth2: "SpotifyOauth2",
      TwitchOauth2: "TwitchOauth2",
      XOauth2: "XOauth2",
      YandexOauth2: "YandexOauth2",
      ZoomOauth2: "ZoomOauth2"
    };
    var FilterOperator = {
      CONTAINS: "Contains",
      EQUALS: "Equals",
      GREATER_THAN: "GreaterThan",
      GREATER_THAN_OR_EQUAL: "GreaterThanOrEqual",
      LESS_THAN: "LessThan",
      LESS_THAN_OR_EQUAL: "LessThanOrEqual",
      NOT_CONTAINS: "NotContains",
      NOT_EQUALS: "NotEquals"
    };
    var OnlineEvaluationExecutionStatus = {
      DISABLED: "DISABLED",
      ENABLED: "ENABLED"
    };
    var OnlineEvaluationConfigStatus = {
      ACTIVE: "ACTIVE",
      CREATE_FAILED: "CREATE_FAILED",
      CREATING: "CREATING",
      DELETING: "DELETING",
      ERROR: "ERROR",
      UPDATE_FAILED: "UPDATE_FAILED",
      UPDATING: "UPDATING"
    };
    var PolicyEngineStatus = {
      ACTIVE: "ACTIVE",
      CREATE_FAILED: "CREATE_FAILED",
      CREATING: "CREATING",
      DELETE_FAILED: "DELETE_FAILED",
      DELETING: "DELETING",
      UPDATE_FAILED: "UPDATE_FAILED",
      UPDATING: "UPDATING"
    };
    var PolicyGenerationStatus = {
      DELETE_FAILED: "DELETE_FAILED",
      GENERATED: "GENERATED",
      GENERATE_FAILED: "GENERATE_FAILED",
      GENERATING: "GENERATING"
    };
    var FindingType = {
      ALLOW_ALL: "ALLOW_ALL",
      ALLOW_NONE: "ALLOW_NONE",
      DENY_ALL: "DENY_ALL",
      DENY_NONE: "DENY_NONE",
      INVALID: "INVALID",
      NOT_TRANSLATABLE: "NOT_TRANSLATABLE",
      VALID: "VALID"
    };
    var PolicyValidationMode = {
      FAIL_ON_ANY_FINDINGS: "FAIL_ON_ANY_FINDINGS",
      IGNORE_ALL_FINDINGS: "IGNORE_ALL_FINDINGS"
    };
    var PolicyStatus = {
      ACTIVE: "ACTIVE",
      CREATE_FAILED: "CREATE_FAILED",
      CREATING: "CREATING",
      DELETE_FAILED: "DELETE_FAILED",
      DELETING: "DELETING",
      UPDATE_FAILED: "UPDATE_FAILED",
      UPDATING: "UPDATING"
    };
    var DescriptorType = {
      A2A: "A2A",
      AGENT_SKILLS: "AGENT_SKILLS",
      CUSTOM: "CUSTOM",
      MCP: "MCP"
    };
    var RegistryRecordOAuthGrantType = {
      CLIENT_CREDENTIALS: "CLIENT_CREDENTIALS"
    };
    var RegistryRecordCredentialProviderType = {
      IAM: "IAM",
      OAUTH: "OAUTH"
    };
    var SynchronizationType = {
      URL: "URL"
    };
    var RegistryRecordStatus = {
      APPROVED: "APPROVED",
      CREATE_FAILED: "CREATE_FAILED",
      CREATING: "CREATING",
      DEPRECATED: "DEPRECATED",
      DRAFT: "DRAFT",
      PENDING_APPROVAL: "PENDING_APPROVAL",
      REJECTED: "REJECTED",
      UPDATE_FAILED: "UPDATE_FAILED",
      UPDATING: "UPDATING"
    };
    var RegistryAuthorizerType = {
      AWS_IAM: "AWS_IAM",
      CUSTOM_JWT: "CUSTOM_JWT"
    };
    var RegistryStatus = {
      CREATE_FAILED: "CREATE_FAILED",
      CREATING: "CREATING",
      DELETE_FAILED: "DELETE_FAILED",
      DELETING: "DELETING",
      READY: "READY",
      UPDATE_FAILED: "UPDATE_FAILED",
      UPDATING: "UPDATING"
    };
    exports2.$Command = smithyClient.Command;
    exports2.__Client = smithyClient.Client;
    exports2.BedrockAgentCoreControlServiceException = BedrockAgentCoreControlServiceException.BedrockAgentCoreControlServiceException;
    exports2.AgentManagedRuntimeType = AgentManagedRuntimeType;
    exports2.AgentRuntimeEndpointStatus = AgentRuntimeEndpointStatus;
    exports2.AgentRuntimeStatus = AgentRuntimeStatus;
    exports2.ApiKeyCredentialLocation = ApiKeyCredentialLocation;
    exports2.AuthorizerType = AuthorizerType;
    exports2.BedrockAgentCoreControl = BedrockAgentCoreControl;
    exports2.BedrockAgentCoreControlClient = BedrockAgentCoreControlClient2;
    exports2.BrowserEnterprisePolicyType = BrowserEnterprisePolicyType;
    exports2.BrowserNetworkMode = BrowserNetworkMode;
    exports2.BrowserProfileStatus = BrowserProfileStatus;
    exports2.BrowserStatus = BrowserStatus;
    exports2.ClaimMatchOperatorType = ClaimMatchOperatorType;
    exports2.CodeInterpreterNetworkMode = CodeInterpreterNetworkMode;
    exports2.CodeInterpreterStatus = CodeInterpreterStatus;
    exports2.ContentLevel = ContentLevel;
    exports2.ContentType = ContentType;
    exports2.CreateAgentRuntimeCommand = CreateAgentRuntimeCommand;
    exports2.CreateAgentRuntimeEndpointCommand = CreateAgentRuntimeEndpointCommand;
    exports2.CreateApiKeyCredentialProviderCommand = CreateApiKeyCredentialProviderCommand;
    exports2.CreateBrowserCommand = CreateBrowserCommand;
    exports2.CreateBrowserProfileCommand = CreateBrowserProfileCommand;
    exports2.CreateCodeInterpreterCommand = CreateCodeInterpreterCommand;
    exports2.CreateEvaluatorCommand = CreateEvaluatorCommand;
    exports2.CreateGatewayCommand = CreateGatewayCommand;
    exports2.CreateGatewayTargetCommand = CreateGatewayTargetCommand;
    exports2.CreateHarnessCommand = CreateHarnessCommand;
    exports2.CreateMemoryCommand = CreateMemoryCommand;
    exports2.CreateOauth2CredentialProviderCommand = CreateOauth2CredentialProviderCommand;
    exports2.CreateOnlineEvaluationConfigCommand = CreateOnlineEvaluationConfigCommand;
    exports2.CreatePolicyCommand = CreatePolicyCommand2;
    exports2.CreatePolicyEngineCommand = CreatePolicyEngineCommand;
    exports2.CreateRegistryCommand = CreateRegistryCommand;
    exports2.CreateRegistryRecordCommand = CreateRegistryRecordCommand;
    exports2.CreateWorkloadIdentityCommand = CreateWorkloadIdentityCommand;
    exports2.CredentialProviderType = CredentialProviderType;
    exports2.CredentialProviderVendorType = CredentialProviderVendorType;
    exports2.DeleteAgentRuntimeCommand = DeleteAgentRuntimeCommand;
    exports2.DeleteAgentRuntimeEndpointCommand = DeleteAgentRuntimeEndpointCommand;
    exports2.DeleteApiKeyCredentialProviderCommand = DeleteApiKeyCredentialProviderCommand;
    exports2.DeleteBrowserCommand = DeleteBrowserCommand;
    exports2.DeleteBrowserProfileCommand = DeleteBrowserProfileCommand;
    exports2.DeleteCodeInterpreterCommand = DeleteCodeInterpreterCommand;
    exports2.DeleteEvaluatorCommand = DeleteEvaluatorCommand;
    exports2.DeleteGatewayCommand = DeleteGatewayCommand;
    exports2.DeleteGatewayTargetCommand = DeleteGatewayTargetCommand;
    exports2.DeleteHarnessCommand = DeleteHarnessCommand;
    exports2.DeleteMemoryCommand = DeleteMemoryCommand;
    exports2.DeleteOauth2CredentialProviderCommand = DeleteOauth2CredentialProviderCommand;
    exports2.DeleteOnlineEvaluationConfigCommand = DeleteOnlineEvaluationConfigCommand;
    exports2.DeletePolicyCommand = DeletePolicyCommand;
    exports2.DeletePolicyEngineCommand = DeletePolicyEngineCommand;
    exports2.DeleteRegistryCommand = DeleteRegistryCommand;
    exports2.DeleteRegistryRecordCommand = DeleteRegistryRecordCommand;
    exports2.DeleteResourcePolicyCommand = DeleteResourcePolicyCommand;
    exports2.DeleteWorkloadIdentityCommand = DeleteWorkloadIdentityCommand;
    exports2.DescriptorType = DescriptorType;
    exports2.EndpointIpAddressType = EndpointIpAddressType;
    exports2.EvaluatorLevel = EvaluatorLevel;
    exports2.EvaluatorStatus = EvaluatorStatus;
    exports2.EvaluatorType = EvaluatorType;
    exports2.ExceptionLevel = ExceptionLevel;
    exports2.FilterOperator = FilterOperator;
    exports2.FindingType = FindingType;
    exports2.GatewayInterceptionPoint = GatewayInterceptionPoint;
    exports2.GatewayPolicyEngineMode = GatewayPolicyEngineMode;
    exports2.GatewayProtocolType = GatewayProtocolType;
    exports2.GatewayStatus = GatewayStatus;
    exports2.GetAgentRuntimeCommand = GetAgentRuntimeCommand2;
    exports2.GetAgentRuntimeEndpointCommand = GetAgentRuntimeEndpointCommand;
    exports2.GetApiKeyCredentialProviderCommand = GetApiKeyCredentialProviderCommand;
    exports2.GetBrowserCommand = GetBrowserCommand;
    exports2.GetBrowserProfileCommand = GetBrowserProfileCommand;
    exports2.GetCodeInterpreterCommand = GetCodeInterpreterCommand;
    exports2.GetEvaluatorCommand = GetEvaluatorCommand;
    exports2.GetGatewayCommand = GetGatewayCommand;
    exports2.GetGatewayTargetCommand = GetGatewayTargetCommand;
    exports2.GetHarnessCommand = GetHarnessCommand;
    exports2.GetMemoryCommand = GetMemoryCommand;
    exports2.GetOauth2CredentialProviderCommand = GetOauth2CredentialProviderCommand;
    exports2.GetOnlineEvaluationConfigCommand = GetOnlineEvaluationConfigCommand;
    exports2.GetPolicyCommand = GetPolicyCommand2;
    exports2.GetPolicyEngineCommand = GetPolicyEngineCommand;
    exports2.GetPolicyGenerationCommand = GetPolicyGenerationCommand;
    exports2.GetRegistryCommand = GetRegistryCommand;
    exports2.GetRegistryRecordCommand = GetRegistryRecordCommand;
    exports2.GetResourcePolicyCommand = GetResourcePolicyCommand;
    exports2.GetTokenVaultCommand = GetTokenVaultCommand;
    exports2.GetWorkloadIdentityCommand = GetWorkloadIdentityCommand;
    exports2.HarnessStatus = HarnessStatus;
    exports2.HarnessToolType = HarnessToolType;
    exports2.HarnessTruncationStrategy = HarnessTruncationStrategy;
    exports2.InboundTokenClaimValueType = InboundTokenClaimValueType;
    exports2.KeyType = KeyType;
    exports2.ListAgentRuntimeEndpointsCommand = ListAgentRuntimeEndpointsCommand;
    exports2.ListAgentRuntimeVersionsCommand = ListAgentRuntimeVersionsCommand;
    exports2.ListAgentRuntimesCommand = ListAgentRuntimesCommand;
    exports2.ListApiKeyCredentialProvidersCommand = ListApiKeyCredentialProvidersCommand;
    exports2.ListBrowserProfilesCommand = ListBrowserProfilesCommand;
    exports2.ListBrowsersCommand = ListBrowsersCommand;
    exports2.ListCodeInterpretersCommand = ListCodeInterpretersCommand;
    exports2.ListEvaluatorsCommand = ListEvaluatorsCommand;
    exports2.ListGatewayTargetsCommand = ListGatewayTargetsCommand;
    exports2.ListGatewaysCommand = ListGatewaysCommand;
    exports2.ListHarnessesCommand = ListHarnessesCommand;
    exports2.ListMemoriesCommand = ListMemoriesCommand;
    exports2.ListOauth2CredentialProvidersCommand = ListOauth2CredentialProvidersCommand;
    exports2.ListOnlineEvaluationConfigsCommand = ListOnlineEvaluationConfigsCommand;
    exports2.ListPoliciesCommand = ListPoliciesCommand;
    exports2.ListPolicyEnginesCommand = ListPolicyEnginesCommand;
    exports2.ListPolicyGenerationAssetsCommand = ListPolicyGenerationAssetsCommand;
    exports2.ListPolicyGenerationsCommand = ListPolicyGenerationsCommand;
    exports2.ListRegistriesCommand = ListRegistriesCommand;
    exports2.ListRegistryRecordsCommand = ListRegistryRecordsCommand;
    exports2.ListTagsForResourceCommand = ListTagsForResourceCommand;
    exports2.ListWorkloadIdentitiesCommand = ListWorkloadIdentitiesCommand;
    exports2.ListingMode = ListingMode;
    exports2.MemoryStatus = MemoryStatus;
    exports2.MemoryStrategyStatus = MemoryStrategyStatus;
    exports2.MemoryStrategyType = MemoryStrategyType;
    exports2.MemoryView = MemoryView;
    exports2.NetworkMode = NetworkMode;
    exports2.OAuthGrantType = OAuthGrantType;
    exports2.OnlineEvaluationConfigStatus = OnlineEvaluationConfigStatus;
    exports2.OnlineEvaluationExecutionStatus = OnlineEvaluationExecutionStatus;
    exports2.OverrideType = OverrideType;
    exports2.PolicyEngineStatus = PolicyEngineStatus;
    exports2.PolicyGenerationStatus = PolicyGenerationStatus;
    exports2.PolicyStatus = PolicyStatus;
    exports2.PolicyValidationMode = PolicyValidationMode;
    exports2.PutResourcePolicyCommand = PutResourcePolicyCommand;
    exports2.RegistryAuthorizerType = RegistryAuthorizerType;
    exports2.RegistryRecordCredentialProviderType = RegistryRecordCredentialProviderType;
    exports2.RegistryRecordOAuthGrantType = RegistryRecordOAuthGrantType;
    exports2.RegistryRecordStatus = RegistryRecordStatus;
    exports2.RegistryStatus = RegistryStatus;
    exports2.ResourceType = ResourceType;
    exports2.RestApiMethod = RestApiMethod;
    exports2.SchemaType = SchemaType;
    exports2.SearchType = SearchType;
    exports2.ServerProtocol = ServerProtocol;
    exports2.SetTokenVaultCMKCommand = SetTokenVaultCMKCommand;
    exports2.StartPolicyGenerationCommand = StartPolicyGenerationCommand;
    exports2.SubmitRegistryRecordForApprovalCommand = SubmitRegistryRecordForApprovalCommand;
    exports2.SynchronizationType = SynchronizationType;
    exports2.SynchronizeGatewayTargetsCommand = SynchronizeGatewayTargetsCommand;
    exports2.TagResourceCommand = TagResourceCommand;
    exports2.TargetStatus = TargetStatus;
    exports2.UntagResourceCommand = UntagResourceCommand;
    exports2.UpdateAgentRuntimeCommand = UpdateAgentRuntimeCommand2;
    exports2.UpdateAgentRuntimeEndpointCommand = UpdateAgentRuntimeEndpointCommand;
    exports2.UpdateApiKeyCredentialProviderCommand = UpdateApiKeyCredentialProviderCommand;
    exports2.UpdateEvaluatorCommand = UpdateEvaluatorCommand;
    exports2.UpdateGatewayCommand = UpdateGatewayCommand;
    exports2.UpdateGatewayTargetCommand = UpdateGatewayTargetCommand;
    exports2.UpdateHarnessCommand = UpdateHarnessCommand;
    exports2.UpdateMemoryCommand = UpdateMemoryCommand;
    exports2.UpdateOauth2CredentialProviderCommand = UpdateOauth2CredentialProviderCommand;
    exports2.UpdateOnlineEvaluationConfigCommand = UpdateOnlineEvaluationConfigCommand;
    exports2.UpdatePolicyCommand = UpdatePolicyCommand;
    exports2.UpdatePolicyEngineCommand = UpdatePolicyEngineCommand;
    exports2.UpdateRegistryCommand = UpdateRegistryCommand;
    exports2.UpdateRegistryRecordCommand = UpdateRegistryRecordCommand;
    exports2.UpdateRegistryRecordStatusCommand = UpdateRegistryRecordStatusCommand;
    exports2.UpdateWorkloadIdentityCommand = UpdateWorkloadIdentityCommand;
    exports2.ValidationExceptionReason = ValidationExceptionReason;
    exports2.paginateListAgentRuntimeEndpoints = paginateListAgentRuntimeEndpoints;
    exports2.paginateListAgentRuntimeVersions = paginateListAgentRuntimeVersions;
    exports2.paginateListAgentRuntimes = paginateListAgentRuntimes;
    exports2.paginateListApiKeyCredentialProviders = paginateListApiKeyCredentialProviders;
    exports2.paginateListBrowserProfiles = paginateListBrowserProfiles;
    exports2.paginateListBrowsers = paginateListBrowsers;
    exports2.paginateListCodeInterpreters = paginateListCodeInterpreters;
    exports2.paginateListEvaluators = paginateListEvaluators;
    exports2.paginateListGatewayTargets = paginateListGatewayTargets;
    exports2.paginateListGateways = paginateListGateways;
    exports2.paginateListHarnesses = paginateListHarnesses;
    exports2.paginateListMemories = paginateListMemories;
    exports2.paginateListOauth2CredentialProviders = paginateListOauth2CredentialProviders;
    exports2.paginateListOnlineEvaluationConfigs = paginateListOnlineEvaluationConfigs;
    exports2.paginateListPolicies = paginateListPolicies;
    exports2.paginateListPolicyEngines = paginateListPolicyEngines;
    exports2.paginateListPolicyGenerationAssets = paginateListPolicyGenerationAssets;
    exports2.paginateListPolicyGenerations = paginateListPolicyGenerations;
    exports2.paginateListRegistries = paginateListRegistries;
    exports2.paginateListRegistryRecords = paginateListRegistryRecords;
    exports2.paginateListWorkloadIdentities = paginateListWorkloadIdentities;
    exports2.waitForMemoryCreated = waitForMemoryCreated;
    exports2.waitForPolicyActive = waitForPolicyActive;
    exports2.waitForPolicyDeleted = waitForPolicyDeleted;
    exports2.waitForPolicyEngineActive = waitForPolicyEngineActive;
    exports2.waitForPolicyEngineDeleted = waitForPolicyEngineDeleted;
    exports2.waitForPolicyGenerationCompleted = waitForPolicyGenerationCompleted;
    exports2.waitUntilMemoryCreated = waitUntilMemoryCreated;
    exports2.waitUntilPolicyActive = waitUntilPolicyActive;
    exports2.waitUntilPolicyDeleted = waitUntilPolicyDeleted;
    exports2.waitUntilPolicyEngineActive = waitUntilPolicyEngineActive;
    exports2.waitUntilPolicyEngineDeleted = waitUntilPolicyEngineDeleted;
    exports2.waitUntilPolicyGenerationCompleted = waitUntilPolicyGenerationCompleted;
    Object.prototype.hasOwnProperty.call(schemas_0, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: schemas_0["__proto__"]
    });
    Object.keys(schemas_0).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = schemas_0[k32];
    });
    Object.prototype.hasOwnProperty.call(errors, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: errors["__proto__"]
    });
    Object.keys(errors).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = errors[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-cloudcontrol/dist-cjs/auth/httpAuthSchemeProvider.js
var require_httpAuthSchemeProvider8 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudcontrol/dist-cjs/auth/httpAuthSchemeProvider.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.resolveHttpAuthSchemeConfig = exports2.defaultCloudControlHttpAuthSchemeProvider = exports2.defaultCloudControlHttpAuthSchemeParametersProvider = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var util_middleware_1 = require_dist_cjs6();
    var defaultCloudControlHttpAuthSchemeParametersProvider = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, util_middleware_1.getSmithyContext)(context).operation,
        region: await (0, util_middleware_1.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultCloudControlHttpAuthSchemeParametersProvider");
    exports2.defaultCloudControlHttpAuthSchemeParametersProvider = defaultCloudControlHttpAuthSchemeParametersProvider;
    function createAwsAuthSigv4HttpAuthOption32(authParameters) {
      return {
        schemeId: "aws.auth#sigv4",
        signingProperties: {
          name: "cloudcontrolapi",
          region: authParameters.region
        },
        propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
          signingProperties: {
            config: config2,
            context
          }
        }), "propertiesExtractor")
      };
    }
    __name(createAwsAuthSigv4HttpAuthOption32, "createAwsAuthSigv4HttpAuthOption");
    var defaultCloudControlHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption32(authParameters));
        }
      }
      return options;
    }, "defaultCloudControlHttpAuthSchemeProvider");
    exports2.defaultCloudControlHttpAuthSchemeProvider = defaultCloudControlHttpAuthSchemeProvider;
    var resolveHttpAuthSchemeConfig32 = /* @__PURE__ */ __name((config2) => {
      const config_0 = (0, httpAuthSchemes_1.resolveAwsSdkSigV4Config)(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, util_middleware_1.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
    exports2.resolveHttpAuthSchemeConfig = resolveHttpAuthSchemeConfig32;
  }
});

// ../../node_modules/@aws-sdk/client-cloudcontrol/package.json
var require_package8 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudcontrol/package.json"(exports2, module2) {
    module2.exports = {
      name: "@aws-sdk/client-cloudcontrol",
      description: "AWS SDK for JavaScript Cloudcontrol Client for Node.js, Browser and React Native",
      version: "3.1036.0",
      scripts: {
        build: "concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline client-cloudcontrol",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        "extract:docs": "api-extractor run --local",
        "generate:client": "node ../../scripts/generate-clients/single-service --solo cloudcontrol",
        "test:index": "tsc --noEmit ./test/index-types.ts && node ./test/index-objects.spec.mjs"
      },
      main: "./dist-cjs/index.js",
      types: "./dist-types/index.d.ts",
      module: "./dist-es/index.js",
      sideEffects: false,
      dependencies: {
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.5",
        "@aws-sdk/credential-provider-node": "^3.972.36",
        "@aws-sdk/middleware-host-header": "^3.972.10",
        "@aws-sdk/middleware-logger": "^3.972.10",
        "@aws-sdk/middleware-recursion-detection": "^3.972.11",
        "@aws-sdk/middleware-user-agent": "^3.972.35",
        "@aws-sdk/region-config-resolver": "^3.972.13",
        "@aws-sdk/types": "^3.973.8",
        "@aws-sdk/util-endpoints": "^3.996.8",
        "@aws-sdk/util-user-agent-browser": "^3.972.10",
        "@aws-sdk/util-user-agent-node": "^3.973.21",
        "@smithy/config-resolver": "^4.4.17",
        "@smithy/core": "^3.23.17",
        "@smithy/fetch-http-handler": "^5.3.17",
        "@smithy/hash-node": "^4.2.14",
        "@smithy/invalid-dependency": "^4.2.14",
        "@smithy/middleware-content-length": "^4.2.14",
        "@smithy/middleware-endpoint": "^4.4.32",
        "@smithy/middleware-retry": "^4.5.5",
        "@smithy/middleware-serde": "^4.2.20",
        "@smithy/middleware-stack": "^4.2.14",
        "@smithy/node-config-provider": "^4.3.14",
        "@smithy/node-http-handler": "^4.6.1",
        "@smithy/protocol-http": "^5.3.14",
        "@smithy/smithy-client": "^4.12.13",
        "@smithy/types": "^4.14.1",
        "@smithy/url-parser": "^4.2.14",
        "@smithy/util-base64": "^4.3.2",
        "@smithy/util-body-length-browser": "^4.2.2",
        "@smithy/util-body-length-node": "^4.2.3",
        "@smithy/util-defaults-mode-browser": "^4.3.49",
        "@smithy/util-defaults-mode-node": "^4.2.54",
        "@smithy/util-endpoints": "^3.4.2",
        "@smithy/util-middleware": "^4.2.14",
        "@smithy/util-retry": "^4.3.4",
        "@smithy/util-utf8": "^4.2.2",
        "@smithy/util-waiter": "^4.2.16",
        tslib: "^2.6.2"
      },
      devDependencies: {
        "@tsconfig/node20": "20.1.8",
        "@types/node": "^20.14.8",
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3"
      },
      engines: {
        node: ">=20.0.0"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "dist-*/**"
      ],
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      browser: {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.browser"
      },
      "react-native": {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.native"
      },
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/clients/client-cloudcontrol",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "clients/client-cloudcontrol"
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudcontrol/dist-cjs/endpoint/bdd.js
var require_bdd8 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudcontrol/dist-cjs/endpoint/bdd.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.bdd = void 0;
    var util_endpoints_1 = require_dist_cjs20();
    var k32 = "ref";
    var a32 = -1;
    var b32 = true;
    var c32 = "isSet";
    var d32 = "PartitionResult";
    var e32 = "booleanEquals";
    var f32 = "getAttr";
    var g32 = { [k32]: "Endpoint" };
    var h32 = { [k32]: d32 };
    var i32 = {};
    var j32 = [{ [k32]: "Region" }];
    var _data32 = {
      conditions: [
        [c32, [g32]],
        [c32, j32],
        ["aws.partition", j32, d32],
        [e32, [{ [k32]: "UseFIPS" }, b32]],
        [e32, [{ [k32]: "UseDualStack" }, b32]],
        [e32, [{ fn: f32, argv: [h32, "supportsDualStack"] }, b32]],
        [e32, [{ fn: f32, argv: [h32, "supportsFIPS"] }, b32]]
      ],
      results: [
        [a32],
        [a32, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a32, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [g32, i32],
        ["https://cloudcontrolapi-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", i32],
        [a32, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://cloudcontrolapi-fips.{Region}.{PartitionResult#dnsSuffix}", i32],
        [a32, "FIPS is enabled but this partition does not support FIPS"],
        ["https://cloudcontrolapi.{Region}.{PartitionResult#dualStackDnsSuffix}", i32],
        [a32, "DualStack is enabled but this partition does not support DualStack"],
        ["https://cloudcontrolapi.{Region}.{PartitionResult#dnsSuffix}", i32],
        [a32, "Invalid Configuration: Missing Region"]
      ]
    };
    var root32 = 2;
    var r32 = 1e8;
    var nodes32 = new Int32Array([
      -1,
      1,
      -1,
      0,
      12,
      3,
      1,
      4,
      r32 + 11,
      2,
      5,
      r32 + 11,
      3,
      8,
      6,
      4,
      7,
      r32 + 10,
      5,
      r32 + 8,
      r32 + 9,
      4,
      10,
      9,
      6,
      r32 + 6,
      r32 + 7,
      5,
      11,
      r32 + 5,
      6,
      r32 + 4,
      r32 + 5,
      3,
      r32 + 1,
      13,
      4,
      r32 + 2,
      r32 + 3
    ]);
    exports2.bdd = util_endpoints_1.BinaryDecisionDiagram.from(nodes32, root32, _data32.conditions, _data32.results);
  }
});

// ../../node_modules/@aws-sdk/client-cloudcontrol/dist-cjs/endpoint/endpointResolver.js
var require_endpointResolver8 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudcontrol/dist-cjs/endpoint/endpointResolver.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.defaultEndpointResolver = void 0;
    var util_endpoints_1 = require_dist_cjs21();
    var util_endpoints_2 = require_dist_cjs20();
    var bdd_1 = require_bdd8();
    var cache32 = new util_endpoints_2.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    var defaultEndpointResolver32 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache32.get(endpointParams, () => (0, util_endpoints_2.decideEndpoint)(bdd_1.bdd, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    exports2.defaultEndpointResolver = defaultEndpointResolver32;
    util_endpoints_2.customEndpointFunctions.aws = util_endpoints_1.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-cloudcontrol/dist-cjs/models/CloudControlServiceException.js
var require_CloudControlServiceException = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudcontrol/dist-cjs/models/CloudControlServiceException.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.CloudControlServiceException = exports2.__ServiceException = void 0;
    var smithy_client_1 = require_dist_cjs34();
    Object.defineProperty(exports2, "__ServiceException", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return smithy_client_1.ServiceException;
    }, "get") });
    var CloudControlServiceException = class _CloudControlServiceException extends smithy_client_1.ServiceException {
      static {
        __name(this, "CloudControlServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _CloudControlServiceException.prototype);
      }
    };
    exports2.CloudControlServiceException = CloudControlServiceException;
  }
});

// ../../node_modules/@aws-sdk/client-cloudcontrol/dist-cjs/models/errors.js
var require_errors8 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudcontrol/dist-cjs/models/errors.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.UnsupportedActionException = exports2.TypeNotFoundException = exports2.ThrottlingException = exports2.ServiceLimitExceededException = exports2.ServiceInternalErrorException = exports2.ResourceNotFoundException = exports2.ResourceConflictException = exports2.PrivateTypeException = exports2.NotUpdatableException = exports2.NotStabilizedException = exports2.NetworkFailureException = exports2.InvalidRequestException = exports2.InvalidCredentialsException = exports2.HandlerInternalFailureException = exports2.HandlerFailureException = exports2.GeneralServiceException = exports2.ConcurrentOperationException = exports2.ClientTokenConflictException = exports2.RequestTokenNotFoundException = exports2.ConcurrentModificationException = exports2.AlreadyExistsException = void 0;
    var CloudControlServiceException_1 = require_CloudControlServiceException();
    var AlreadyExistsException = class _AlreadyExistsException extends CloudControlServiceException_1.CloudControlServiceException {
      static {
        __name(this, "AlreadyExistsException");
      }
      name = "AlreadyExistsException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "AlreadyExistsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AlreadyExistsException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.AlreadyExistsException = AlreadyExistsException;
    var ConcurrentModificationException = class _ConcurrentModificationException extends CloudControlServiceException_1.CloudControlServiceException {
      static {
        __name(this, "ConcurrentModificationException");
      }
      name = "ConcurrentModificationException";
      $fault = "server";
      Message;
      constructor(opts) {
        super({
          name: "ConcurrentModificationException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _ConcurrentModificationException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ConcurrentModificationException = ConcurrentModificationException;
    var RequestTokenNotFoundException = class _RequestTokenNotFoundException extends CloudControlServiceException_1.CloudControlServiceException {
      static {
        __name(this, "RequestTokenNotFoundException");
      }
      name = "RequestTokenNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "RequestTokenNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _RequestTokenNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.RequestTokenNotFoundException = RequestTokenNotFoundException;
    var ClientTokenConflictException = class _ClientTokenConflictException extends CloudControlServiceException_1.CloudControlServiceException {
      static {
        __name(this, "ClientTokenConflictException");
      }
      name = "ClientTokenConflictException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "ClientTokenConflictException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ClientTokenConflictException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ClientTokenConflictException = ClientTokenConflictException;
    var ConcurrentOperationException = class _ConcurrentOperationException extends CloudControlServiceException_1.CloudControlServiceException {
      static {
        __name(this, "ConcurrentOperationException");
      }
      name = "ConcurrentOperationException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "ConcurrentOperationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ConcurrentOperationException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ConcurrentOperationException = ConcurrentOperationException;
    var GeneralServiceException = class _GeneralServiceException extends CloudControlServiceException_1.CloudControlServiceException {
      static {
        __name(this, "GeneralServiceException");
      }
      name = "GeneralServiceException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "GeneralServiceException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _GeneralServiceException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.GeneralServiceException = GeneralServiceException;
    var HandlerFailureException = class _HandlerFailureException extends CloudControlServiceException_1.CloudControlServiceException {
      static {
        __name(this, "HandlerFailureException");
      }
      name = "HandlerFailureException";
      $fault = "server";
      Message;
      constructor(opts) {
        super({
          name: "HandlerFailureException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _HandlerFailureException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.HandlerFailureException = HandlerFailureException;
    var HandlerInternalFailureException = class _HandlerInternalFailureException extends CloudControlServiceException_1.CloudControlServiceException {
      static {
        __name(this, "HandlerInternalFailureException");
      }
      name = "HandlerInternalFailureException";
      $fault = "server";
      Message;
      constructor(opts) {
        super({
          name: "HandlerInternalFailureException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _HandlerInternalFailureException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.HandlerInternalFailureException = HandlerInternalFailureException;
    var InvalidCredentialsException = class _InvalidCredentialsException extends CloudControlServiceException_1.CloudControlServiceException {
      static {
        __name(this, "InvalidCredentialsException");
      }
      name = "InvalidCredentialsException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidCredentialsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidCredentialsException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidCredentialsException = InvalidCredentialsException;
    var InvalidRequestException13 = class _InvalidRequestException extends CloudControlServiceException_1.CloudControlServiceException {
      static {
        __name(this, "InvalidRequestException");
      }
      name = "InvalidRequestException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidRequestException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidRequestException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidRequestException = InvalidRequestException13;
    var NetworkFailureException = class _NetworkFailureException extends CloudControlServiceException_1.CloudControlServiceException {
      static {
        __name(this, "NetworkFailureException");
      }
      name = "NetworkFailureException";
      $fault = "server";
      Message;
      constructor(opts) {
        super({
          name: "NetworkFailureException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _NetworkFailureException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.NetworkFailureException = NetworkFailureException;
    var NotStabilizedException = class _NotStabilizedException extends CloudControlServiceException_1.CloudControlServiceException {
      static {
        __name(this, "NotStabilizedException");
      }
      name = "NotStabilizedException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "NotStabilizedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _NotStabilizedException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.NotStabilizedException = NotStabilizedException;
    var NotUpdatableException = class _NotUpdatableException extends CloudControlServiceException_1.CloudControlServiceException {
      static {
        __name(this, "NotUpdatableException");
      }
      name = "NotUpdatableException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "NotUpdatableException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _NotUpdatableException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.NotUpdatableException = NotUpdatableException;
    var PrivateTypeException = class _PrivateTypeException extends CloudControlServiceException_1.CloudControlServiceException {
      static {
        __name(this, "PrivateTypeException");
      }
      name = "PrivateTypeException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "PrivateTypeException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _PrivateTypeException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.PrivateTypeException = PrivateTypeException;
    var ResourceConflictException2 = class _ResourceConflictException extends CloudControlServiceException_1.CloudControlServiceException {
      static {
        __name(this, "ResourceConflictException");
      }
      name = "ResourceConflictException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "ResourceConflictException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceConflictException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ResourceConflictException = ResourceConflictException2;
    var ResourceNotFoundException12 = class _ResourceNotFoundException extends CloudControlServiceException_1.CloudControlServiceException {
      static {
        __name(this, "ResourceNotFoundException");
      }
      name = "ResourceNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "ResourceNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ResourceNotFoundException = ResourceNotFoundException12;
    var ServiceInternalErrorException = class _ServiceInternalErrorException extends CloudControlServiceException_1.CloudControlServiceException {
      static {
        __name(this, "ServiceInternalErrorException");
      }
      name = "ServiceInternalErrorException";
      $fault = "server";
      Message;
      constructor(opts) {
        super({
          name: "ServiceInternalErrorException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _ServiceInternalErrorException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ServiceInternalErrorException = ServiceInternalErrorException;
    var ServiceLimitExceededException = class _ServiceLimitExceededException extends CloudControlServiceException_1.CloudControlServiceException {
      static {
        __name(this, "ServiceLimitExceededException");
      }
      name = "ServiceLimitExceededException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "ServiceLimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ServiceLimitExceededException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ServiceLimitExceededException = ServiceLimitExceededException;
    var ThrottlingException = class _ThrottlingException extends CloudControlServiceException_1.CloudControlServiceException {
      static {
        __name(this, "ThrottlingException");
      }
      name = "ThrottlingException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "ThrottlingException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ThrottlingException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ThrottlingException = ThrottlingException;
    var TypeNotFoundException = class _TypeNotFoundException extends CloudControlServiceException_1.CloudControlServiceException {
      static {
        __name(this, "TypeNotFoundException");
      }
      name = "TypeNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "TypeNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TypeNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.TypeNotFoundException = TypeNotFoundException;
    var UnsupportedActionException = class _UnsupportedActionException extends CloudControlServiceException_1.CloudControlServiceException {
      static {
        __name(this, "UnsupportedActionException");
      }
      name = "UnsupportedActionException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "UnsupportedActionException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnsupportedActionException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.UnsupportedActionException = UnsupportedActionException;
  }
});

// ../../node_modules/@aws-sdk/client-cloudcontrol/dist-cjs/schemas/schemas_0.js
var require_schemas_08 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudcontrol/dist-cjs/schemas/schemas_0.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ListResources$ = exports2.ListResourceRequests$ = exports2.GetResourceRequestStatus$ = exports2.GetResource$ = exports2.DeleteResource$ = exports2.CreateResource$ = exports2.CancelResourceRequest$ = exports2.UpdateResourceOutput$ = exports2.UpdateResourceInput$ = exports2.ResourceRequestStatusFilter$ = exports2.ResourceDescription$ = exports2.ProgressEvent$ = exports2.ListResourcesOutput$ = exports2.ListResourcesInput$ = exports2.ListResourceRequestsOutput$ = exports2.ListResourceRequestsInput$ = exports2.HookProgressEvent$ = exports2.GetResourceRequestStatusOutput$ = exports2.GetResourceRequestStatusInput$ = exports2.GetResourceOutput$ = exports2.GetResourceInput$ = exports2.DeleteResourceOutput$ = exports2.DeleteResourceInput$ = exports2.CreateResourceOutput$ = exports2.CreateResourceInput$ = exports2.CancelResourceRequestOutput$ = exports2.CancelResourceRequestInput$ = exports2.errorTypeRegistries = exports2.UnsupportedActionException$ = exports2.TypeNotFoundException$ = exports2.ThrottlingException$ = exports2.ServiceLimitExceededException$ = exports2.ServiceInternalErrorException$ = exports2.ResourceNotFoundException$ = exports2.ResourceConflictException$ = exports2.RequestTokenNotFoundException$ = exports2.PrivateTypeException$ = exports2.NotUpdatableException$ = exports2.NotStabilizedException$ = exports2.NetworkFailureException$ = exports2.InvalidRequestException$ = exports2.InvalidCredentialsException$ = exports2.HandlerInternalFailureException$ = exports2.HandlerFailureException$ = exports2.GeneralServiceException$ = exports2.ConcurrentOperationException$ = exports2.ConcurrentModificationException$ = exports2.ClientTokenConflictException$ = exports2.AlreadyExistsException$ = exports2.CloudControlServiceException$ = void 0;
    exports2.UpdateResource$ = void 0;
    var _AEE = "AlreadyExistsException";
    var _CME = "ConcurrentModificationException";
    var _COE = "ConcurrentOperationException";
    var _CR = "CreateResource";
    var _CRI = "CreateResourceInput";
    var _CRO = "CreateResourceOutput";
    var _CRR = "CancelResourceRequest";
    var _CRRI = "CancelResourceRequestInput";
    var _CRRO = "CancelResourceRequestOutput";
    var _CT4 = "ClientToken";
    var _CTCE = "ClientTokenConflictException";
    var _DR = "DeleteResource";
    var _DRI = "DeleteResourceInput";
    var _DRO = "DeleteResourceOutput";
    var _DS10 = "DesiredState";
    var _EC = "ErrorCode";
    var _ET = "EventTime";
    var _FM = "FailureMode";
    var _GR = "GetResource";
    var _GRI = "GetResourceInput";
    var _GRO = "GetResourceOutput";
    var _GRRS = "GetResourceRequestStatus";
    var _GRRSI = "GetResourceRequestStatusInput";
    var _GRRSO = "GetResourceRequestStatusOutput";
    var _GSE = "GeneralServiceException";
    var _HET = "HookEventTime";
    var _HFE = "HandlerFailureException";
    var _HIFE = "HandlerInternalFailureException";
    var _HPE = "HooksProgressEvent";
    var _HPEo = "HookProgressEvent";
    var _HRT = "HooksRequestToken";
    var _HS = "HookStatus";
    var _HSM = "HookStatusMessage";
    var _HTA = "HookTypeArn";
    var _HTN = "HookTypeName";
    var _HTVI = "HookTypeVersionId";
    var _I = "Identifier";
    var _ICE4 = "InvalidCredentialsException";
    var _IP = "InvocationPoint";
    var _IRE13 = "InvalidRequestException";
    var _LR = "ListResources";
    var _LRI = "ListResourcesInput";
    var _LRO = "ListResourcesOutput";
    var _LRR = "ListResourceRequests";
    var _LRRI = "ListResourceRequestsInput";
    var _LRRO = "ListResourceRequestsOutput";
    var _M = "Message";
    var _MR = "MaxResults";
    var _NFE = "NetworkFailureException";
    var _NSE = "NotStabilizedException";
    var _NT = "NextToken";
    var _NUE = "NotUpdatableException";
    var _O = "Operation";
    var _OS = "OperationStatus";
    var _OSp = "OperationStatuses";
    var _Op = "Operations";
    var _P10 = "Properties";
    var _PD = "PatchDocument";
    var _PE = "ProgressEvent";
    var _PTE = "PrivateTypeException";
    var _RA10 = "RoleArn";
    var _RAe = "RetryAfter";
    var _RCE2 = "ResourceConflictException";
    var _RD = "ResourceDescription";
    var _RDe = "ResourceDescriptions";
    var _RM = "ResourceModel";
    var _RNFE11 = "ResourceNotFoundException";
    var _RRSF = "ResourceRequestStatusFilter";
    var _RRSS = "ResourceRequestStatusSummaries";
    var _RT13 = "RequestToken";
    var _RTNFE = "RequestTokenNotFoundException";
    var _SIEE = "ServiceInternalErrorException";
    var _SLEE = "ServiceLimitExceededException";
    var _SM = "StatusMessage";
    var _TE = "ThrottlingException";
    var _TN = "TypeName";
    var _TNFE = "TypeNotFoundException";
    var _TVI = "TypeVersionId";
    var _UAE = "UnsupportedActionException";
    var _UR = "UpdateResource";
    var _URI = "UpdateResourceInput";
    var _URO = "UpdateResourceOutput";
    var _aQE10 = "awsQueryError";
    var _c32 = "client";
    var _e32 = "error";
    var _hE32 = "httpError";
    var _s32 = "smithy.ts.sdk.synthetic.com.amazonaws.cloudcontrol";
    var _se14 = "server";
    var n032 = "com.amazonaws.cloudcontrol";
    var schema_1 = (init_schema4(), __toCommonJS(schema_exports));
    var CloudControlServiceException_1 = require_CloudControlServiceException();
    var errors_1 = require_errors8();
    var _s_registry32 = schema_1.TypeRegistry.for(_s32);
    exports2.CloudControlServiceException$ = [-3, _s32, "CloudControlServiceException", 0, [], []];
    _s_registry32.registerError(exports2.CloudControlServiceException$, CloudControlServiceException_1.CloudControlServiceException);
    var n0_registry32 = schema_1.TypeRegistry.for(n032);
    exports2.AlreadyExistsException$ = [
      -3,
      n032,
      _AEE,
      { [_aQE10]: [`AlreadyExistsException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.AlreadyExistsException$, errors_1.AlreadyExistsException);
    exports2.ClientTokenConflictException$ = [
      -3,
      n032,
      _CTCE,
      { [_aQE10]: [`ClientTokenConflictException`, 409], [_e32]: _c32, [_hE32]: 409 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ClientTokenConflictException$, errors_1.ClientTokenConflictException);
    exports2.ConcurrentModificationException$ = [
      -3,
      n032,
      _CME,
      { [_aQE10]: [`ConcurrentModificationException`, 500], [_e32]: _se14, [_hE32]: 500 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ConcurrentModificationException$, errors_1.ConcurrentModificationException);
    exports2.ConcurrentOperationException$ = [
      -3,
      n032,
      _COE,
      { [_aQE10]: [`ConcurrentOperationException`, 409], [_e32]: _c32, [_hE32]: 409 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ConcurrentOperationException$, errors_1.ConcurrentOperationException);
    exports2.GeneralServiceException$ = [
      -3,
      n032,
      _GSE,
      { [_aQE10]: [`GeneralServiceException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.GeneralServiceException$, errors_1.GeneralServiceException);
    exports2.HandlerFailureException$ = [
      -3,
      n032,
      _HFE,
      { [_aQE10]: [`HandlerFailureException`, 502], [_e32]: _se14, [_hE32]: 502 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.HandlerFailureException$, errors_1.HandlerFailureException);
    exports2.HandlerInternalFailureException$ = [
      -3,
      n032,
      _HIFE,
      { [_aQE10]: [`HandlerInternalFailureException`, 502], [_e32]: _se14, [_hE32]: 502 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.HandlerInternalFailureException$, errors_1.HandlerInternalFailureException);
    exports2.InvalidCredentialsException$ = [
      -3,
      n032,
      _ICE4,
      { [_aQE10]: [`InvalidCredentialsException`, 401], [_e32]: _c32, [_hE32]: 401 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidCredentialsException$, errors_1.InvalidCredentialsException);
    exports2.InvalidRequestException$ = [
      -3,
      n032,
      _IRE13,
      { [_aQE10]: [`InvalidRequestException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidRequestException$, errors_1.InvalidRequestException);
    exports2.NetworkFailureException$ = [
      -3,
      n032,
      _NFE,
      { [_aQE10]: [`NetworkFailureException`, 502], [_e32]: _se14, [_hE32]: 502 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.NetworkFailureException$, errors_1.NetworkFailureException);
    exports2.NotStabilizedException$ = [
      -3,
      n032,
      _NSE,
      { [_aQE10]: [`NotStabilizedException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.NotStabilizedException$, errors_1.NotStabilizedException);
    exports2.NotUpdatableException$ = [
      -3,
      n032,
      _NUE,
      { [_aQE10]: [`NotUpdatableException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.NotUpdatableException$, errors_1.NotUpdatableException);
    exports2.PrivateTypeException$ = [
      -3,
      n032,
      _PTE,
      { [_aQE10]: [`PrivateTypeException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.PrivateTypeException$, errors_1.PrivateTypeException);
    exports2.RequestTokenNotFoundException$ = [
      -3,
      n032,
      _RTNFE,
      { [_aQE10]: [`RequestTokenNotFoundException`, 404], [_e32]: _c32, [_hE32]: 404 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.RequestTokenNotFoundException$, errors_1.RequestTokenNotFoundException);
    exports2.ResourceConflictException$ = [
      -3,
      n032,
      _RCE2,
      { [_aQE10]: [`ResourceConflictException`, 409], [_e32]: _c32, [_hE32]: 409 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ResourceConflictException$, errors_1.ResourceConflictException);
    exports2.ResourceNotFoundException$ = [
      -3,
      n032,
      _RNFE11,
      { [_aQE10]: [`ResourceNotFoundException`, 404], [_e32]: _c32, [_hE32]: 404 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ResourceNotFoundException$, errors_1.ResourceNotFoundException);
    exports2.ServiceInternalErrorException$ = [
      -3,
      n032,
      _SIEE,
      { [_aQE10]: [`ServiceInternalErrorException`, 502], [_e32]: _se14, [_hE32]: 502 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ServiceInternalErrorException$, errors_1.ServiceInternalErrorException);
    exports2.ServiceLimitExceededException$ = [
      -3,
      n032,
      _SLEE,
      { [_aQE10]: [`ServiceLimitExceededException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ServiceLimitExceededException$, errors_1.ServiceLimitExceededException);
    exports2.ThrottlingException$ = [
      -3,
      n032,
      _TE,
      { [_aQE10]: [`ThrottlingException`, 429], [_e32]: _c32, [_hE32]: 429 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ThrottlingException$, errors_1.ThrottlingException);
    exports2.TypeNotFoundException$ = [
      -3,
      n032,
      _TNFE,
      { [_aQE10]: [`TypeNotFoundException`, 404], [_e32]: _c32, [_hE32]: 404 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.TypeNotFoundException$, errors_1.TypeNotFoundException);
    exports2.UnsupportedActionException$ = [
      -3,
      n032,
      _UAE,
      { [_aQE10]: [`UnsupportedActionException`, 405], [_e32]: _c32, [_hE32]: 405 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.UnsupportedActionException$, errors_1.UnsupportedActionException);
    exports2.errorTypeRegistries = [
      _s_registry32,
      n0_registry32
    ];
    var PatchDocument = [0, n032, _PD, 8, 0];
    var Properties = [0, n032, _P10, 8, 0];
    exports2.CancelResourceRequestInput$ = [
      3,
      n032,
      _CRRI,
      0,
      [_RT13],
      [0],
      1
    ];
    exports2.CancelResourceRequestOutput$ = [
      3,
      n032,
      _CRRO,
      0,
      [_PE],
      [[() => exports2.ProgressEvent$, 0]]
    ];
    exports2.CreateResourceInput$ = [
      3,
      n032,
      _CRI,
      0,
      [_TN, _DS10, _TVI, _RA10, _CT4],
      [0, [() => Properties, 0], 0, 0, [0, 4]],
      2
    ];
    exports2.CreateResourceOutput$ = [
      3,
      n032,
      _CRO,
      0,
      [_PE],
      [[() => exports2.ProgressEvent$, 0]]
    ];
    exports2.DeleteResourceInput$ = [
      3,
      n032,
      _DRI,
      0,
      [_TN, _I, _TVI, _RA10, _CT4],
      [0, 0, 0, 0, [0, 4]],
      2
    ];
    exports2.DeleteResourceOutput$ = [
      3,
      n032,
      _DRO,
      0,
      [_PE],
      [[() => exports2.ProgressEvent$, 0]]
    ];
    exports2.GetResourceInput$ = [
      3,
      n032,
      _GRI,
      0,
      [_TN, _I, _TVI, _RA10],
      [0, 0, 0, 0],
      2
    ];
    exports2.GetResourceOutput$ = [
      3,
      n032,
      _GRO,
      0,
      [_TN, _RD],
      [0, [() => exports2.ResourceDescription$, 0]]
    ];
    exports2.GetResourceRequestStatusInput$ = [
      3,
      n032,
      _GRRSI,
      0,
      [_RT13],
      [0],
      1
    ];
    exports2.GetResourceRequestStatusOutput$ = [
      3,
      n032,
      _GRRSO,
      0,
      [_PE, _HPE],
      [[() => exports2.ProgressEvent$, 0], () => HooksProgressEvent]
    ];
    exports2.HookProgressEvent$ = [
      3,
      n032,
      _HPEo,
      0,
      [_HTN, _HTVI, _HTA, _IP, _HS, _HET, _HSM, _FM],
      [0, 0, 0, 0, 0, 4, 0, 0]
    ];
    exports2.ListResourceRequestsInput$ = [
      3,
      n032,
      _LRRI,
      0,
      [_MR, _NT, _RRSF],
      [1, 0, () => exports2.ResourceRequestStatusFilter$]
    ];
    exports2.ListResourceRequestsOutput$ = [
      3,
      n032,
      _LRRO,
      0,
      [_RRSS, _NT],
      [[() => ResourceRequestStatusSummaries, 0], 0]
    ];
    exports2.ListResourcesInput$ = [
      3,
      n032,
      _LRI,
      0,
      [_TN, _TVI, _RA10, _NT, _MR, _RM],
      [0, 0, 0, 0, 1, [() => Properties, 0]],
      1
    ];
    exports2.ListResourcesOutput$ = [
      3,
      n032,
      _LRO,
      0,
      [_TN, _RDe, _NT],
      [0, [() => ResourceDescriptions, 0], 0]
    ];
    exports2.ProgressEvent$ = [
      3,
      n032,
      _PE,
      0,
      [_TN, _I, _RT13, _HRT, _O, _OS, _ET, _RM, _SM, _EC, _RAe],
      [0, 0, 0, 0, 0, 0, 4, [() => Properties, 0], 0, 0, 4]
    ];
    exports2.ResourceDescription$ = [
      3,
      n032,
      _RD,
      0,
      [_I, _P10],
      [0, [() => Properties, 0]]
    ];
    exports2.ResourceRequestStatusFilter$ = [
      3,
      n032,
      _RRSF,
      0,
      [_Op, _OSp],
      [64 | 0, 64 | 0]
    ];
    exports2.UpdateResourceInput$ = [
      3,
      n032,
      _URI,
      0,
      [_TN, _I, _PD, _TVI, _RA10, _CT4],
      [0, 0, [() => PatchDocument, 0], 0, 0, [0, 4]],
      3
    ];
    exports2.UpdateResourceOutput$ = [
      3,
      n032,
      _URO,
      0,
      [_PE],
      [[() => exports2.ProgressEvent$, 0]]
    ];
    var HooksProgressEvent = [
      1,
      n032,
      _HPE,
      0,
      () => exports2.HookProgressEvent$
    ];
    var Operations = 64 | 0;
    var OperationStatuses = 64 | 0;
    var ResourceDescriptions = [
      1,
      n032,
      _RDe,
      0,
      [
        () => exports2.ResourceDescription$,
        0
      ]
    ];
    var ResourceRequestStatusSummaries = [
      1,
      n032,
      _RRSS,
      0,
      [
        () => exports2.ProgressEvent$,
        0
      ]
    ];
    exports2.CancelResourceRequest$ = [
      9,
      n032,
      _CRR,
      2,
      () => exports2.CancelResourceRequestInput$,
      () => exports2.CancelResourceRequestOutput$
    ];
    exports2.CreateResource$ = [
      9,
      n032,
      _CR,
      0,
      () => exports2.CreateResourceInput$,
      () => exports2.CreateResourceOutput$
    ];
    exports2.DeleteResource$ = [
      9,
      n032,
      _DR,
      0,
      () => exports2.DeleteResourceInput$,
      () => exports2.DeleteResourceOutput$
    ];
    exports2.GetResource$ = [
      9,
      n032,
      _GR,
      0,
      () => exports2.GetResourceInput$,
      () => exports2.GetResourceOutput$
    ];
    exports2.GetResourceRequestStatus$ = [
      9,
      n032,
      _GRRS,
      0,
      () => exports2.GetResourceRequestStatusInput$,
      () => exports2.GetResourceRequestStatusOutput$
    ];
    exports2.ListResourceRequests$ = [
      9,
      n032,
      _LRR,
      0,
      () => exports2.ListResourceRequestsInput$,
      () => exports2.ListResourceRequestsOutput$
    ];
    exports2.ListResources$ = [
      9,
      n032,
      _LR,
      0,
      () => exports2.ListResourcesInput$,
      () => exports2.ListResourcesOutput$
    ];
    exports2.UpdateResource$ = [
      9,
      n032,
      _UR,
      0,
      () => exports2.UpdateResourceInput$,
      () => exports2.UpdateResourceOutput$
    ];
  }
});

// ../../node_modules/@aws-sdk/client-cloudcontrol/dist-cjs/runtimeConfig.shared.js
var require_runtimeConfig_shared9 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudcontrol/dist-cjs/runtimeConfig.shared.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var protocols_1 = (init_protocols8(), __toCommonJS(protocols_exports5));
    var smithy_client_1 = require_dist_cjs34();
    var url_parser_1 = require_dist_cjs18();
    var util_base64_1 = require_dist_cjs10();
    var util_utf8_1 = require_dist_cjs9();
    var httpAuthSchemeProvider_1 = require_httpAuthSchemeProvider8();
    var endpointResolver_1 = require_endpointResolver8();
    var schemas_0_1 = require_schemas_08();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2021-09-30",
        base64Decoder: config2?.base64Decoder ?? util_base64_1.fromBase64,
        base64Encoder: config2?.base64Encoder ?? util_base64_1.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? endpointResolver_1.defaultEndpointResolver,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? httpAuthSchemeProvider_1.defaultCloudControlHttpAuthSchemeProvider,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new httpAuthSchemes_1.AwsSdkSigV4Signer()
          }
        ],
        logger: config2?.logger ?? new smithy_client_1.NoOpLogger(),
        protocol: config2?.protocol ?? protocols_1.AwsJson1_0Protocol,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.cloudcontrol",
          errorTypeRegistries: schemas_0_1.errorTypeRegistries,
          version: "2021-09-30",
          serviceTarget: "CloudApiService"
        },
        serviceId: config2?.serviceId ?? "CloudControl",
        urlParser: config2?.urlParser ?? url_parser_1.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? util_utf8_1.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? util_utf8_1.toUtf8
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-cloudcontrol/dist-cjs/runtimeConfig.js
var require_runtimeConfig9 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudcontrol/dist-cjs/runtimeConfig.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var package_json_1 = tslib_1.__importDefault(require_package8());
    var client_1 = (init_client8(), __toCommonJS(client_exports7));
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var credential_provider_node_1 = require_dist_cjs122();
    var util_user_agent_node_1 = require_dist_cjs113();
    var config_resolver_1 = require_dist_cjs25();
    var hash_node_1 = require_dist_cjs44();
    var middleware_retry_1 = require_dist_cjs106();
    var node_config_provider_1 = require_dist_cjs29();
    var node_http_handler_1 = require_dist_cjs13();
    var smithy_client_1 = require_dist_cjs34();
    var util_body_length_node_1 = require_dist_cjs45();
    var util_defaults_mode_node_1 = require_dist_cjs46();
    var util_retry_1 = require_dist_cjs22();
    var runtimeConfig_shared_1 = require_runtimeConfig_shared9();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      (0, smithy_client_1.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, util_defaults_mode_node_1.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(smithy_client_1.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = (0, runtimeConfig_shared_1.getRuntimeConfig)(config2);
      (0, client_1.emitWarningIfUnsupportedVersion)(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, node_config_provider_1.loadConfig)(httpAuthSchemes_1.NODE_AUTH_SCHEME_PREFERENCE_OPTIONS, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? util_body_length_node_1.calculateBodyLength,
        credentialDefaultProvider: config2?.credentialDefaultProvider ?? credential_provider_node_1.defaultProvider,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, util_user_agent_node_1.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_json_1.default.version }),
        maxAttempts: config2?.maxAttempts ?? (0, node_config_provider_1.loadConfig)(middleware_retry_1.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_REGION_CONFIG_OPTIONS, { ...config_resolver_1.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: node_http_handler_1.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, node_config_provider_1.loadConfig)({
          ...middleware_retry_1.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || util_retry_1.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? hash_node_1.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? node_http_handler_1.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, node_config_provider_1.loadConfig)(util_user_agent_node_1.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-cloudcontrol/dist-cjs/index.js
var require_dist_cjs158 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudcontrol/dist-cjs/index.js"(exports2) {
    "use strict";
    var middlewareHostHeader = require_dist_cjs3();
    var middlewareLogger = require_dist_cjs4();
    var middlewareRecursionDetection = require_dist_cjs5();
    var middlewareUserAgent = require_dist_cjs104();
    var configResolver = require_dist_cjs25();
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var schema = (init_schema4(), __toCommonJS(schema_exports));
    var middlewareContentLength = require_dist_cjs26();
    var middlewareEndpoint = require_dist_cjs31();
    var middlewareRetry = require_dist_cjs106();
    var smithyClient = require_dist_cjs34();
    var httpAuthSchemeProvider = require_httpAuthSchemeProvider8();
    var runtimeConfig = require_runtimeConfig9();
    var regionConfigResolver = require_dist_cjs48();
    var protocolHttp = require_dist_cjs2();
    var schemas_0 = require_schemas_08();
    var utilWaiter = require_dist_cjs156();
    var errors = require_errors8();
    var CloudControlServiceException = require_CloudControlServiceException();
    var resolveClientEndpointParameters32 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "cloudcontrolapi"
      });
    }, "resolveClientEndpointParameters");
    var commonParams32 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
    var getHttpAuthExtensionConfiguration32 = /* @__PURE__ */ __name((runtimeConfig2) => {
      const _httpAuthSchemes = runtimeConfig2.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig2.httpAuthSchemeProvider;
      let _credentials = runtimeConfig2.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider2) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider2;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    var resolveHttpAuthRuntimeConfig32 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
    var resolveRuntimeExtensions32 = /* @__PURE__ */ __name((runtimeConfig2, extensions) => {
      const extensionConfiguration = Object.assign(regionConfigResolver.getAwsRegionExtensionConfiguration(runtimeConfig2), smithyClient.getDefaultExtensionConfiguration(runtimeConfig2), protocolHttp.getHttpHandlerExtensionConfiguration(runtimeConfig2), getHttpAuthExtensionConfiguration32(runtimeConfig2));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig2, regionConfigResolver.resolveAwsRegionExtensionConfiguration(extensionConfiguration), smithyClient.resolveDefaultRuntimeConfig(extensionConfiguration), protocolHttp.resolveHttpHandlerRuntimeConfig(extensionConfiguration), resolveHttpAuthRuntimeConfig32(extensionConfiguration));
    }, "resolveRuntimeExtensions");
    var CloudControlClient2 = class extends smithyClient.Client {
      static {
        __name(this, "CloudControlClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = runtimeConfig.getRuntimeConfig(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters32(_config_0);
        const _config_2 = middlewareUserAgent.resolveUserAgentConfig(_config_1);
        const _config_3 = middlewareRetry.resolveRetryConfig(_config_2);
        const _config_4 = configResolver.resolveRegionConfig(_config_3);
        const _config_5 = middlewareHostHeader.resolveHostHeaderConfig(_config_4);
        const _config_6 = middlewareEndpoint.resolveEndpointConfig(_config_5);
        const _config_7 = httpAuthSchemeProvider.resolveHttpAuthSchemeConfig(_config_6);
        const _config_8 = resolveRuntimeExtensions32(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(schema.getSchemaSerdePlugin(this.config));
        this.middlewareStack.use(middlewareUserAgent.getUserAgentPlugin(this.config));
        this.middlewareStack.use(middlewareRetry.getRetryPlugin(this.config));
        this.middlewareStack.use(middlewareContentLength.getContentLengthPlugin(this.config));
        this.middlewareStack.use(middlewareHostHeader.getHostHeaderPlugin(this.config));
        this.middlewareStack.use(middlewareLogger.getLoggerPlugin(this.config));
        this.middlewareStack.use(middlewareRecursionDetection.getRecursionDetectionPlugin(this.config));
        this.middlewareStack.use(core.getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: httpAuthSchemeProvider.defaultCloudControlHttpAuthSchemeParametersProvider,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new core.DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(core.getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
    var CancelResourceRequestCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudApiService", "CancelResourceRequest", {}).n("CloudControlClient", "CancelResourceRequestCommand").sc(schemas_0.CancelResourceRequest$).build() {
      static {
        __name(this, "CancelResourceRequestCommand");
      }
    };
    var CreateResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudApiService", "CreateResource", {}).n("CloudControlClient", "CreateResourceCommand").sc(schemas_0.CreateResource$).build() {
      static {
        __name(this, "CreateResourceCommand");
      }
    };
    var DeleteResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudApiService", "DeleteResource", {}).n("CloudControlClient", "DeleteResourceCommand").sc(schemas_0.DeleteResource$).build() {
      static {
        __name(this, "DeleteResourceCommand");
      }
    };
    var GetResourceCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudApiService", "GetResource", {}).n("CloudControlClient", "GetResourceCommand").sc(schemas_0.GetResource$).build() {
      static {
        __name(this, "GetResourceCommand");
      }
    };
    var GetResourceRequestStatusCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudApiService", "GetResourceRequestStatus", {}).n("CloudControlClient", "GetResourceRequestStatusCommand").sc(schemas_0.GetResourceRequestStatus$).build() {
      static {
        __name(this, "GetResourceRequestStatusCommand");
      }
    };
    var ListResourceRequestsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudApiService", "ListResourceRequests", {}).n("CloudControlClient", "ListResourceRequestsCommand").sc(schemas_0.ListResourceRequests$).build() {
      static {
        __name(this, "ListResourceRequestsCommand");
      }
    };
    var ListResourcesCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudApiService", "ListResources", {}).n("CloudControlClient", "ListResourcesCommand").sc(schemas_0.ListResources$).build() {
      static {
        __name(this, "ListResourcesCommand");
      }
    };
    var UpdateResourceCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CloudApiService", "UpdateResource", {}).n("CloudControlClient", "UpdateResourceCommand").sc(schemas_0.UpdateResource$).build() {
      static {
        __name(this, "UpdateResourceCommand");
      }
    };
    var paginateListResourceRequests = core.createPaginator(CloudControlClient2, ListResourceRequestsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListResources = core.createPaginator(CloudControlClient2, ListResourcesCommand2, "NextToken", "NextToken", "MaxResults");
    var checkState = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new GetResourceRequestStatusCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.ProgressEvent.OperationStatus;
          }, "returnComparator");
          if (returnComparator() === "SUCCESS") {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.ProgressEvent.OperationStatus;
          }, "returnComparator");
          if (returnComparator() === "FAILED") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.ProgressEvent.OperationStatus;
          }, "returnComparator");
          if (returnComparator() === "CANCEL_COMPLETE") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState");
    var waitForResourceRequestSuccess = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState);
    }, "waitForResourceRequestSuccess");
    var waitUntilResourceRequestSuccess = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilResourceRequestSuccess");
    var commands32 = {
      CancelResourceRequestCommand,
      CreateResourceCommand,
      DeleteResourceCommand,
      GetResourceCommand: GetResourceCommand2,
      GetResourceRequestStatusCommand,
      ListResourceRequestsCommand,
      ListResourcesCommand: ListResourcesCommand2,
      UpdateResourceCommand: UpdateResourceCommand2
    };
    var paginators = {
      paginateListResourceRequests,
      paginateListResources
    };
    var waiters = {
      waitUntilResourceRequestSuccess
    };
    var CloudControl = class extends CloudControlClient2 {
      static {
        __name(this, "CloudControl");
      }
    };
    smithyClient.createAggregatedClient(commands32, CloudControl, { paginators, waiters });
    var HandlerErrorCode = {
      ACCESS_DENIED: "AccessDenied",
      ALREADY_EXISTS: "AlreadyExists",
      GENERAL_SERVICE_EXCEPTION: "GeneralServiceException",
      INTERNAL_FAILURE: "InternalFailure",
      INVALID_CREDENTIALS: "InvalidCredentials",
      INVALID_REQUEST: "InvalidRequest",
      NETWORK_FAILURE: "NetworkFailure",
      NOT_FOUND: "NotFound",
      NOT_STABILIZED: "NotStabilized",
      NOT_UPDATABLE: "NotUpdatable",
      RESOURCE_CONFLICT: "ResourceConflict",
      SERVICE_INTERNAL_ERROR: "ServiceInternalError",
      SERVICE_LIMIT_EXCEEDED: "ServiceLimitExceeded",
      SERVICE_TIMEOUT: "ServiceTimeout",
      THROTTLING: "Throttling",
      UNAUTHORIZED_TAGGING_OPERATION: "UnauthorizedTaggingOperation"
    };
    var Operation = {
      CREATE: "CREATE",
      DELETE: "DELETE",
      UPDATE: "UPDATE"
    };
    var OperationStatus = {
      CANCEL_COMPLETE: "CANCEL_COMPLETE",
      CANCEL_IN_PROGRESS: "CANCEL_IN_PROGRESS",
      FAILED: "FAILED",
      IN_PROGRESS: "IN_PROGRESS",
      PENDING: "PENDING",
      SUCCESS: "SUCCESS"
    };
    exports2.$Command = smithyClient.Command;
    exports2.__Client = smithyClient.Client;
    exports2.CloudControlServiceException = CloudControlServiceException.CloudControlServiceException;
    exports2.CancelResourceRequestCommand = CancelResourceRequestCommand;
    exports2.CloudControl = CloudControl;
    exports2.CloudControlClient = CloudControlClient2;
    exports2.CreateResourceCommand = CreateResourceCommand;
    exports2.DeleteResourceCommand = DeleteResourceCommand;
    exports2.GetResourceCommand = GetResourceCommand2;
    exports2.GetResourceRequestStatusCommand = GetResourceRequestStatusCommand;
    exports2.HandlerErrorCode = HandlerErrorCode;
    exports2.ListResourceRequestsCommand = ListResourceRequestsCommand;
    exports2.ListResourcesCommand = ListResourcesCommand2;
    exports2.Operation = Operation;
    exports2.OperationStatus = OperationStatus;
    exports2.UpdateResourceCommand = UpdateResourceCommand2;
    exports2.paginateListResourceRequests = paginateListResourceRequests;
    exports2.paginateListResources = paginateListResources;
    exports2.waitForResourceRequestSuccess = waitForResourceRequestSuccess;
    exports2.waitUntilResourceRequestSuccess = waitUntilResourceRequestSuccess;
    Object.prototype.hasOwnProperty.call(schemas_0, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: schemas_0["__proto__"]
    });
    Object.keys(schemas_0).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = schemas_0[k32];
    });
    Object.prototype.hasOwnProperty.call(errors, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: errors["__proto__"]
    });
    Object.keys(errors).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = errors[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-cloudwatch-logs/dist-cjs/auth/httpAuthSchemeProvider.js
var require_httpAuthSchemeProvider9 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudwatch-logs/dist-cjs/auth/httpAuthSchemeProvider.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.resolveHttpAuthSchemeConfig = exports2.defaultCloudWatchLogsHttpAuthSchemeProvider = exports2.defaultCloudWatchLogsHttpAuthSchemeParametersProvider = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var util_middleware_1 = require_dist_cjs6();
    var defaultCloudWatchLogsHttpAuthSchemeParametersProvider = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, util_middleware_1.getSmithyContext)(context).operation,
        region: await (0, util_middleware_1.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultCloudWatchLogsHttpAuthSchemeParametersProvider");
    exports2.defaultCloudWatchLogsHttpAuthSchemeParametersProvider = defaultCloudWatchLogsHttpAuthSchemeParametersProvider;
    function createAwsAuthSigv4HttpAuthOption32(authParameters) {
      return {
        schemeId: "aws.auth#sigv4",
        signingProperties: {
          name: "logs",
          region: authParameters.region
        },
        propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
          signingProperties: {
            config: config2,
            context
          }
        }), "propertiesExtractor")
      };
    }
    __name(createAwsAuthSigv4HttpAuthOption32, "createAwsAuthSigv4HttpAuthOption");
    var defaultCloudWatchLogsHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption32(authParameters));
        }
      }
      return options;
    }, "defaultCloudWatchLogsHttpAuthSchemeProvider");
    exports2.defaultCloudWatchLogsHttpAuthSchemeProvider = defaultCloudWatchLogsHttpAuthSchemeProvider;
    var resolveHttpAuthSchemeConfig32 = /* @__PURE__ */ __name((config2) => {
      const config_0 = (0, httpAuthSchemes_1.resolveAwsSdkSigV4Config)(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, util_middleware_1.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
    exports2.resolveHttpAuthSchemeConfig = resolveHttpAuthSchemeConfig32;
  }
});

// ../../node_modules/@aws-sdk/client-cloudwatch-logs/package.json
var require_package9 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudwatch-logs/package.json"(exports2, module2) {
    module2.exports = {
      name: "@aws-sdk/client-cloudwatch-logs",
      description: "AWS SDK for JavaScript Cloudwatch Logs Client for Node.js, Browser and React Native",
      version: "3.1036.0",
      scripts: {
        build: "concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline client-cloudwatch-logs",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        "extract:docs": "api-extractor run --local",
        "generate:client": "node ../../scripts/generate-clients/single-service --solo cloudwatch-logs",
        test: "yarn g:vitest run --passWithNoTests",
        "test:e2e": "yarn g:vitest run -c vitest.config.e2e.mts",
        "test:e2e:watch": "yarn g:vitest watch -c vitest.config.e2e.mts",
        "test:index": "tsc --noEmit ./test/index-types.ts && node ./test/index-objects.spec.mjs",
        "test:integration": "yarn g:vitest run --passWithNoTests -c vitest.config.integ.mts",
        "test:integration:watch": "yarn g:vitest run --passWithNoTests -c vitest.config.integ.mts",
        "test:watch": "yarn g:vitest watch --passWithNoTests"
      },
      main: "./dist-cjs/index.js",
      types: "./dist-types/index.d.ts",
      module: "./dist-es/index.js",
      sideEffects: false,
      dependencies: {
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.5",
        "@aws-sdk/credential-provider-node": "^3.972.36",
        "@aws-sdk/middleware-host-header": "^3.972.10",
        "@aws-sdk/middleware-logger": "^3.972.10",
        "@aws-sdk/middleware-recursion-detection": "^3.972.11",
        "@aws-sdk/middleware-user-agent": "^3.972.35",
        "@aws-sdk/region-config-resolver": "^3.972.13",
        "@aws-sdk/types": "^3.973.8",
        "@aws-sdk/util-endpoints": "^3.996.8",
        "@aws-sdk/util-user-agent-browser": "^3.972.10",
        "@aws-sdk/util-user-agent-node": "^3.973.21",
        "@smithy/config-resolver": "^4.4.17",
        "@smithy/core": "^3.23.17",
        "@smithy/eventstream-serde-browser": "^4.2.14",
        "@smithy/eventstream-serde-config-resolver": "^4.3.14",
        "@smithy/eventstream-serde-node": "^4.2.14",
        "@smithy/fetch-http-handler": "^5.3.17",
        "@smithy/hash-node": "^4.2.14",
        "@smithy/invalid-dependency": "^4.2.14",
        "@smithy/middleware-content-length": "^4.2.14",
        "@smithy/middleware-endpoint": "^4.4.32",
        "@smithy/middleware-retry": "^4.5.5",
        "@smithy/middleware-serde": "^4.2.20",
        "@smithy/middleware-stack": "^4.2.14",
        "@smithy/node-config-provider": "^4.3.14",
        "@smithy/node-http-handler": "^4.6.1",
        "@smithy/protocol-http": "^5.3.14",
        "@smithy/smithy-client": "^4.12.13",
        "@smithy/types": "^4.14.1",
        "@smithy/url-parser": "^4.2.14",
        "@smithy/util-base64": "^4.3.2",
        "@smithy/util-body-length-browser": "^4.2.2",
        "@smithy/util-body-length-node": "^4.2.3",
        "@smithy/util-defaults-mode-browser": "^4.3.49",
        "@smithy/util-defaults-mode-node": "^4.2.54",
        "@smithy/util-endpoints": "^3.4.2",
        "@smithy/util-middleware": "^4.2.14",
        "@smithy/util-retry": "^4.3.4",
        "@smithy/util-utf8": "^4.2.2",
        tslib: "^2.6.2"
      },
      devDependencies: {
        "@smithy/snapshot-testing": "^2.0.8",
        "@tsconfig/node20": "20.1.8",
        "@types/node": "^20.14.8",
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3",
        vitest: "^4.0.17"
      },
      engines: {
        node: ">=20.0.0"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "dist-*/**"
      ],
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      browser: {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.browser"
      },
      "react-native": {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.native"
      },
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/clients/client-cloudwatch-logs",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "clients/client-cloudwatch-logs"
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-cloudwatch-logs/dist-cjs/endpoint/bdd.js
var require_bdd9 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudwatch-logs/dist-cjs/endpoint/bdd.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.bdd = void 0;
    var util_endpoints_1 = require_dist_cjs20();
    var m20 = "ref";
    var a32 = -1;
    var b32 = true;
    var c32 = "isSet";
    var d32 = "PartitionResult";
    var e32 = "booleanEquals";
    var f32 = "getAttr";
    var g32 = "stringEquals";
    var h32 = { [m20]: "Endpoint" };
    var i32 = { [m20]: d32 };
    var j32 = { [m20]: "Region" };
    var k32 = {};
    var l20 = [j32];
    var _data32 = {
      conditions: [
        [c32, [h32]],
        [c32, l20],
        ["aws.partition", l20, d32],
        [e32, [{ [m20]: "UseFIPS" }, b32]],
        [e32, [{ [m20]: "UseDualStack" }, b32]],
        [e32, [{ fn: f32, argv: [i32, "supportsDualStack"] }, b32]],
        [e32, [{ fn: f32, argv: [i32, "supportsFIPS"] }, b32]],
        [g32, [j32, "us-gov-east-1"]],
        [g32, [j32, "us-gov-west-1"]]
      ],
      results: [
        [a32],
        [a32, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a32, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [h32, k32],
        ["https://logs-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", k32],
        [a32, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://logs.us-gov-east-1.amazonaws.com", k32],
        ["https://logs.us-gov-west-1.amazonaws.com", k32],
        ["https://logs-fips.{Region}.{PartitionResult#dnsSuffix}", k32],
        [a32, "FIPS is enabled but this partition does not support FIPS"],
        ["https://logs.{Region}.{PartitionResult#dualStackDnsSuffix}", k32],
        [a32, "DualStack is enabled but this partition does not support DualStack"],
        ["https://logs.{Region}.{PartitionResult#dnsSuffix}", k32],
        [a32, "Invalid Configuration: Missing Region"]
      ]
    };
    var root32 = 2;
    var r32 = 1e8;
    var nodes32 = new Int32Array([
      -1,
      1,
      -1,
      0,
      14,
      3,
      1,
      4,
      r32 + 13,
      2,
      5,
      r32 + 13,
      3,
      8,
      6,
      4,
      7,
      r32 + 12,
      5,
      r32 + 10,
      r32 + 11,
      4,
      12,
      9,
      6,
      10,
      r32 + 9,
      7,
      r32 + 6,
      11,
      8,
      r32 + 7,
      r32 + 8,
      5,
      13,
      r32 + 5,
      6,
      r32 + 4,
      r32 + 5,
      3,
      r32 + 1,
      15,
      4,
      r32 + 2,
      r32 + 3
    ]);
    exports2.bdd = util_endpoints_1.BinaryDecisionDiagram.from(nodes32, root32, _data32.conditions, _data32.results);
  }
});

// ../../node_modules/@aws-sdk/client-cloudwatch-logs/dist-cjs/endpoint/endpointResolver.js
var require_endpointResolver9 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudwatch-logs/dist-cjs/endpoint/endpointResolver.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.defaultEndpointResolver = void 0;
    var util_endpoints_1 = require_dist_cjs21();
    var util_endpoints_2 = require_dist_cjs20();
    var bdd_1 = require_bdd9();
    var cache32 = new util_endpoints_2.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    var defaultEndpointResolver32 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache32.get(endpointParams, () => (0, util_endpoints_2.decideEndpoint)(bdd_1.bdd, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    exports2.defaultEndpointResolver = defaultEndpointResolver32;
    util_endpoints_2.customEndpointFunctions.aws = util_endpoints_1.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-cloudwatch-logs/dist-cjs/models/CloudWatchLogsServiceException.js
var require_CloudWatchLogsServiceException = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudwatch-logs/dist-cjs/models/CloudWatchLogsServiceException.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.CloudWatchLogsServiceException = exports2.__ServiceException = void 0;
    var smithy_client_1 = require_dist_cjs34();
    Object.defineProperty(exports2, "__ServiceException", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return smithy_client_1.ServiceException;
    }, "get") });
    var CloudWatchLogsServiceException = class _CloudWatchLogsServiceException extends smithy_client_1.ServiceException {
      static {
        __name(this, "CloudWatchLogsServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _CloudWatchLogsServiceException.prototype);
      }
    };
    exports2.CloudWatchLogsServiceException = CloudWatchLogsServiceException;
  }
});

// ../../node_modules/@aws-sdk/client-cloudwatch-logs/dist-cjs/models/errors.js
var require_errors9 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudwatch-logs/dist-cjs/models/errors.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.TooManyTagsException = exports2.MalformedQueryException = exports2.SessionTimeoutException = exports2.SessionStreamingException = exports2.UnrecognizedClientException = exports2.InvalidSequenceTokenException = exports2.InternalStreamingException = exports2.DataAlreadyAcceptedException = exports2.ResourceAlreadyExistsException = exports2.LimitExceededException = exports2.ServiceQuotaExceededException = exports2.ConflictException = exports2.InvalidOperationException = exports2.ValidationException = exports2.ThrottlingException = exports2.InternalServerException = exports2.ServiceUnavailableException = exports2.ResourceNotFoundException = exports2.OperationAbortedException = exports2.InvalidParameterException = exports2.AccessDeniedException = void 0;
    var CloudWatchLogsServiceException_1 = require_CloudWatchLogsServiceException();
    var AccessDeniedException13 = class _AccessDeniedException extends CloudWatchLogsServiceException_1.CloudWatchLogsServiceException {
      static {
        __name(this, "AccessDeniedException");
      }
      name = "AccessDeniedException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "AccessDeniedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AccessDeniedException.prototype);
      }
    };
    exports2.AccessDeniedException = AccessDeniedException13;
    var InvalidParameterException2 = class _InvalidParameterException extends CloudWatchLogsServiceException_1.CloudWatchLogsServiceException {
      static {
        __name(this, "InvalidParameterException");
      }
      name = "InvalidParameterException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidParameterException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidParameterException.prototype);
      }
    };
    exports2.InvalidParameterException = InvalidParameterException2;
    var OperationAbortedException = class _OperationAbortedException extends CloudWatchLogsServiceException_1.CloudWatchLogsServiceException {
      static {
        __name(this, "OperationAbortedException");
      }
      name = "OperationAbortedException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "OperationAbortedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _OperationAbortedException.prototype);
      }
    };
    exports2.OperationAbortedException = OperationAbortedException;
    var ResourceNotFoundException12 = class _ResourceNotFoundException extends CloudWatchLogsServiceException_1.CloudWatchLogsServiceException {
      static {
        __name(this, "ResourceNotFoundException");
      }
      name = "ResourceNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ResourceNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceNotFoundException.prototype);
      }
    };
    exports2.ResourceNotFoundException = ResourceNotFoundException12;
    var ServiceUnavailableException = class _ServiceUnavailableException extends CloudWatchLogsServiceException_1.CloudWatchLogsServiceException {
      static {
        __name(this, "ServiceUnavailableException");
      }
      name = "ServiceUnavailableException";
      $fault = "server";
      constructor(opts) {
        super({
          name: "ServiceUnavailableException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _ServiceUnavailableException.prototype);
      }
    };
    exports2.ServiceUnavailableException = ServiceUnavailableException;
    var InternalServerException13 = class _InternalServerException extends CloudWatchLogsServiceException_1.CloudWatchLogsServiceException {
      static {
        __name(this, "InternalServerException");
      }
      name = "InternalServerException";
      $fault = "server";
      constructor(opts) {
        super({
          name: "InternalServerException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _InternalServerException.prototype);
      }
    };
    exports2.InternalServerException = InternalServerException13;
    var ThrottlingException = class _ThrottlingException extends CloudWatchLogsServiceException_1.CloudWatchLogsServiceException {
      static {
        __name(this, "ThrottlingException");
      }
      name = "ThrottlingException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ThrottlingException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ThrottlingException.prototype);
      }
    };
    exports2.ThrottlingException = ThrottlingException;
    var ValidationException10 = class _ValidationException extends CloudWatchLogsServiceException_1.CloudWatchLogsServiceException {
      static {
        __name(this, "ValidationException");
      }
      name = "ValidationException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ValidationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ValidationException.prototype);
      }
    };
    exports2.ValidationException = ValidationException10;
    var InvalidOperationException = class _InvalidOperationException extends CloudWatchLogsServiceException_1.CloudWatchLogsServiceException {
      static {
        __name(this, "InvalidOperationException");
      }
      name = "InvalidOperationException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidOperationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidOperationException.prototype);
      }
    };
    exports2.InvalidOperationException = InvalidOperationException;
    var ConflictException = class _ConflictException extends CloudWatchLogsServiceException_1.CloudWatchLogsServiceException {
      static {
        __name(this, "ConflictException");
      }
      name = "ConflictException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ConflictException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ConflictException.prototype);
      }
    };
    exports2.ConflictException = ConflictException;
    var ServiceQuotaExceededException = class _ServiceQuotaExceededException extends CloudWatchLogsServiceException_1.CloudWatchLogsServiceException {
      static {
        __name(this, "ServiceQuotaExceededException");
      }
      name = "ServiceQuotaExceededException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ServiceQuotaExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ServiceQuotaExceededException.prototype);
      }
    };
    exports2.ServiceQuotaExceededException = ServiceQuotaExceededException;
    var LimitExceededException2 = class _LimitExceededException extends CloudWatchLogsServiceException_1.CloudWatchLogsServiceException {
      static {
        __name(this, "LimitExceededException");
      }
      name = "LimitExceededException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "LimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _LimitExceededException.prototype);
      }
    };
    exports2.LimitExceededException = LimitExceededException2;
    var ResourceAlreadyExistsException = class _ResourceAlreadyExistsException extends CloudWatchLogsServiceException_1.CloudWatchLogsServiceException {
      static {
        __name(this, "ResourceAlreadyExistsException");
      }
      name = "ResourceAlreadyExistsException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ResourceAlreadyExistsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceAlreadyExistsException.prototype);
      }
    };
    exports2.ResourceAlreadyExistsException = ResourceAlreadyExistsException;
    var DataAlreadyAcceptedException = class _DataAlreadyAcceptedException extends CloudWatchLogsServiceException_1.CloudWatchLogsServiceException {
      static {
        __name(this, "DataAlreadyAcceptedException");
      }
      name = "DataAlreadyAcceptedException";
      $fault = "client";
      expectedSequenceToken;
      constructor(opts) {
        super({
          name: "DataAlreadyAcceptedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DataAlreadyAcceptedException.prototype);
        this.expectedSequenceToken = opts.expectedSequenceToken;
      }
    };
    exports2.DataAlreadyAcceptedException = DataAlreadyAcceptedException;
    var InternalStreamingException = class _InternalStreamingException extends CloudWatchLogsServiceException_1.CloudWatchLogsServiceException {
      static {
        __name(this, "InternalStreamingException");
      }
      name = "InternalStreamingException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InternalStreamingException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InternalStreamingException.prototype);
      }
    };
    exports2.InternalStreamingException = InternalStreamingException;
    var InvalidSequenceTokenException = class _InvalidSequenceTokenException extends CloudWatchLogsServiceException_1.CloudWatchLogsServiceException {
      static {
        __name(this, "InvalidSequenceTokenException");
      }
      name = "InvalidSequenceTokenException";
      $fault = "client";
      expectedSequenceToken;
      constructor(opts) {
        super({
          name: "InvalidSequenceTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidSequenceTokenException.prototype);
        this.expectedSequenceToken = opts.expectedSequenceToken;
      }
    };
    exports2.InvalidSequenceTokenException = InvalidSequenceTokenException;
    var UnrecognizedClientException = class _UnrecognizedClientException extends CloudWatchLogsServiceException_1.CloudWatchLogsServiceException {
      static {
        __name(this, "UnrecognizedClientException");
      }
      name = "UnrecognizedClientException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "UnrecognizedClientException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnrecognizedClientException.prototype);
      }
    };
    exports2.UnrecognizedClientException = UnrecognizedClientException;
    var SessionStreamingException = class _SessionStreamingException extends CloudWatchLogsServiceException_1.CloudWatchLogsServiceException {
      static {
        __name(this, "SessionStreamingException");
      }
      name = "SessionStreamingException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "SessionStreamingException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _SessionStreamingException.prototype);
      }
    };
    exports2.SessionStreamingException = SessionStreamingException;
    var SessionTimeoutException = class _SessionTimeoutException extends CloudWatchLogsServiceException_1.CloudWatchLogsServiceException {
      static {
        __name(this, "SessionTimeoutException");
      }
      name = "SessionTimeoutException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "SessionTimeoutException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _SessionTimeoutException.prototype);
      }
    };
    exports2.SessionTimeoutException = SessionTimeoutException;
    var MalformedQueryException = class _MalformedQueryException extends CloudWatchLogsServiceException_1.CloudWatchLogsServiceException {
      static {
        __name(this, "MalformedQueryException");
      }
      name = "MalformedQueryException";
      $fault = "client";
      queryCompileError;
      constructor(opts) {
        super({
          name: "MalformedQueryException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _MalformedQueryException.prototype);
        this.queryCompileError = opts.queryCompileError;
      }
    };
    exports2.MalformedQueryException = MalformedQueryException;
    var TooManyTagsException = class _TooManyTagsException extends CloudWatchLogsServiceException_1.CloudWatchLogsServiceException {
      static {
        __name(this, "TooManyTagsException");
      }
      name = "TooManyTagsException";
      $fault = "client";
      resourceName;
      constructor(opts) {
        super({
          name: "TooManyTagsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyTagsException.prototype);
        this.resourceName = opts.resourceName;
      }
    };
    exports2.TooManyTagsException = TooManyTagsException;
  }
});

// ../../node_modules/@aws-sdk/client-cloudwatch-logs/dist-cjs/schemas/schemas_0.js
var require_schemas_09 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudwatch-logs/dist-cjs/schemas/schemas_0.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.CreateLookupTableRequest$ = exports2.CreateLogStreamRequest$ = exports2.CreateLogGroupRequest$ = exports2.CreateLogAnomalyDetectorResponse$ = exports2.CreateLogAnomalyDetectorRequest$ = exports2.CreateImportTaskResponse$ = exports2.CreateImportTaskRequest$ = exports2.CreateExportTaskResponse$ = exports2.CreateExportTaskRequest$ = exports2.CreateDeliveryResponse$ = exports2.CreateDeliveryRequest$ = exports2.CopyValueEntry$ = exports2.CopyValue$ = exports2.ConfigurationTemplateDeliveryConfigValues$ = exports2.ConfigurationTemplate$ = exports2.CancelImportTaskResponse$ = exports2.CancelImportTaskRequest$ = exports2.CancelExportTaskRequest$ = exports2.AssociateSourceToS3TableIntegrationResponse$ = exports2.AssociateSourceToS3TableIntegrationRequest$ = exports2.AssociateKmsKeyRequest$ = exports2.AnomalyDetector$ = exports2.Anomaly$ = exports2.AggregateLogGroupSummary$ = exports2.AddKeys$ = exports2.AddKeyEntry$ = exports2.AccountPolicy$ = exports2.errorTypeRegistries = exports2.ValidationException$ = exports2.UnrecognizedClientException$ = exports2.TooManyTagsException$ = exports2.ThrottlingException$ = exports2.SessionTimeoutException$ = exports2.SessionStreamingException$ = exports2.ServiceUnavailableException$ = exports2.ServiceQuotaExceededException$ = exports2.ResourceNotFoundException$ = exports2.ResourceAlreadyExistsException$ = exports2.OperationAbortedException$ = exports2.MalformedQueryException$ = exports2.LimitExceededException$ = exports2.InvalidSequenceTokenException$ = exports2.InvalidParameterException$ = exports2.InvalidOperationException$ = exports2.InternalStreamingException$ = exports2.InternalServerException$ = exports2.DataAlreadyAcceptedException$ = exports2.ConflictException$ = exports2.AccessDeniedException$ = exports2.CloudWatchLogsServiceException$ = void 0;
    exports2.DescribeExportTasksResponse$ = exports2.DescribeExportTasksRequest$ = exports2.DescribeDestinationsResponse$ = exports2.DescribeDestinationsRequest$ = exports2.DescribeDeliverySourcesResponse$ = exports2.DescribeDeliverySourcesRequest$ = exports2.DescribeDeliveryDestinationsResponse$ = exports2.DescribeDeliveryDestinationsRequest$ = exports2.DescribeDeliveriesResponse$ = exports2.DescribeDeliveriesRequest$ = exports2.DescribeConfigurationTemplatesResponse$ = exports2.DescribeConfigurationTemplatesRequest$ = exports2.DescribeAccountPoliciesResponse$ = exports2.DescribeAccountPoliciesRequest$ = exports2.DeliverySource$ = exports2.DeliveryDestinationConfiguration$ = exports2.DeliveryDestination$ = exports2.Delivery$ = exports2.DeleteTransformerRequest$ = exports2.DeleteSubscriptionFilterRequest$ = exports2.DeleteScheduledQueryResponse$ = exports2.DeleteScheduledQueryRequest$ = exports2.DeleteRetentionPolicyRequest$ = exports2.DeleteResourcePolicyRequest$ = exports2.DeleteQueryDefinitionResponse$ = exports2.DeleteQueryDefinitionRequest$ = exports2.DeleteMetricFilterRequest$ = exports2.DeleteLookupTableRequest$ = exports2.DeleteLogStreamRequest$ = exports2.DeleteLogGroupRequest$ = exports2.DeleteLogAnomalyDetectorRequest$ = exports2.DeleteKeys$ = exports2.DeleteIntegrationResponse$ = exports2.DeleteIntegrationRequest$ = exports2.DeleteIndexPolicyResponse$ = exports2.DeleteIndexPolicyRequest$ = exports2.DeleteDestinationRequest$ = exports2.DeleteDeliverySourceRequest$ = exports2.DeleteDeliveryRequest$ = exports2.DeleteDeliveryDestinationRequest$ = exports2.DeleteDeliveryDestinationPolicyRequest$ = exports2.DeleteDataProtectionPolicyRequest$ = exports2.DeleteAccountPolicyRequest$ = exports2.DateTimeConverter$ = exports2.DataSourceFilter$ = exports2.DataSource$ = exports2.CSV$ = exports2.CreateScheduledQueryResponse$ = exports2.CreateScheduledQueryRequest$ = exports2.CreateLookupTableResponse$ = void 0;
    exports2.GetIntegrationResponse$ = exports2.GetIntegrationRequest$ = exports2.GetDeliverySourceResponse$ = exports2.GetDeliverySourceRequest$ = exports2.GetDeliveryResponse$ = exports2.GetDeliveryRequest$ = exports2.GetDeliveryDestinationResponse$ = exports2.GetDeliveryDestinationRequest$ = exports2.GetDeliveryDestinationPolicyResponse$ = exports2.GetDeliveryDestinationPolicyRequest$ = exports2.GetDataProtectionPolicyResponse$ = exports2.GetDataProtectionPolicyRequest$ = exports2.FilterLogEventsResponse$ = exports2.FilterLogEventsRequest$ = exports2.FilteredLogEvent$ = exports2.FieldsData$ = exports2.FieldIndex$ = exports2.ExportTaskStatus$ = exports2.ExportTaskExecutionInfo$ = exports2.ExportTask$ = exports2.Entity$ = exports2.DisassociateSourceFromS3TableIntegrationResponse$ = exports2.DisassociateSourceFromS3TableIntegrationRequest$ = exports2.DisassociateKmsKeyRequest$ = exports2.DestinationConfiguration$ = exports2.Destination$ = exports2.DescribeSubscriptionFiltersResponse$ = exports2.DescribeSubscriptionFiltersRequest$ = exports2.DescribeResourcePoliciesResponse$ = exports2.DescribeResourcePoliciesRequest$ = exports2.DescribeQueryDefinitionsResponse$ = exports2.DescribeQueryDefinitionsRequest$ = exports2.DescribeQueriesResponse$ = exports2.DescribeQueriesRequest$ = exports2.DescribeMetricFiltersResponse$ = exports2.DescribeMetricFiltersRequest$ = exports2.DescribeLookupTablesResponse$ = exports2.DescribeLookupTablesRequest$ = exports2.DescribeLogStreamsResponse$ = exports2.DescribeLogStreamsRequest$ = exports2.DescribeLogGroupsResponse$ = exports2.DescribeLogGroupsRequest$ = exports2.DescribeIndexPoliciesResponse$ = exports2.DescribeIndexPoliciesRequest$ = exports2.DescribeImportTasksResponse$ = exports2.DescribeImportTasksRequest$ = exports2.DescribeImportTaskBatchesResponse$ = exports2.DescribeImportTaskBatchesRequest$ = exports2.DescribeFieldIndexesResponse$ = exports2.DescribeFieldIndexesRequest$ = void 0;
    exports2.ListTagsLogGroupRequest$ = exports2.ListTagsForResourceResponse$ = exports2.ListTagsForResourceRequest$ = exports2.ListSourcesForS3TableIntegrationResponse$ = exports2.ListSourcesForS3TableIntegrationRequest$ = exports2.ListScheduledQueriesResponse$ = exports2.ListScheduledQueriesRequest$ = exports2.ListLogGroupsResponse$ = exports2.ListLogGroupsRequest$ = exports2.ListLogGroupsForQueryResponse$ = exports2.ListLogGroupsForQueryRequest$ = exports2.ListLogAnomalyDetectorsResponse$ = exports2.ListLogAnomalyDetectorsRequest$ = exports2.ListIntegrationsResponse$ = exports2.ListIntegrationsRequest$ = exports2.ListAnomaliesResponse$ = exports2.ListAnomaliesRequest$ = exports2.ListAggregateLogGroupSummariesResponse$ = exports2.ListAggregateLogGroupSummariesRequest$ = exports2.IntegrationSummary$ = exports2.InputLogEvent$ = exports2.IndexPolicy$ = exports2.ImportStatistics$ = exports2.ImportFilter$ = exports2.ImportBatch$ = exports2.Import$ = exports2.GroupingIdentifier$ = exports2.Grok$ = exports2.GetTransformerResponse$ = exports2.GetTransformerRequest$ = exports2.GetScheduledQueryResponse$ = exports2.GetScheduledQueryRequest$ = exports2.GetScheduledQueryHistoryResponse$ = exports2.GetScheduledQueryHistoryRequest$ = exports2.GetQueryResultsResponse$ = exports2.GetQueryResultsRequest$ = exports2.GetLookupTableResponse$ = exports2.GetLookupTableRequest$ = exports2.GetLogRecordResponse$ = exports2.GetLogRecordRequest$ = exports2.GetLogObjectResponse$ = exports2.GetLogObjectRequest$ = exports2.GetLogGroupFieldsResponse$ = exports2.GetLogGroupFieldsRequest$ = exports2.GetLogFieldsResponse$ = exports2.GetLogFieldsRequest$ = exports2.GetLogEventsResponse$ = exports2.GetLogEventsRequest$ = exports2.GetLogAnomalyDetectorResponse$ = exports2.GetLogAnomalyDetectorRequest$ = void 0;
    exports2.PutDeliveryDestinationPolicyResponse$ = exports2.PutDeliveryDestinationPolicyRequest$ = exports2.PutDataProtectionPolicyResponse$ = exports2.PutDataProtectionPolicyRequest$ = exports2.PutBearerTokenAuthenticationRequest$ = exports2.PutAccountPolicyResponse$ = exports2.PutAccountPolicyRequest$ = exports2.Processor$ = exports2.Policy$ = exports2.PatternToken$ = exports2.ParseWAF$ = exports2.ParseVPC$ = exports2.ParseToOCSF$ = exports2.ParseRoute53$ = exports2.ParsePostgres$ = exports2.ParseKeyValue$ = exports2.ParseJSON$ = exports2.ParseCloudfront$ = exports2.OutputLogEvent$ = exports2.OpenSearchWorkspace$ = exports2.OpenSearchResourceStatus$ = exports2.OpenSearchResourceConfig$ = exports2.OpenSearchNetworkPolicy$ = exports2.OpenSearchLifecyclePolicy$ = exports2.OpenSearchIntegrationDetails$ = exports2.OpenSearchEncryptionPolicy$ = exports2.OpenSearchDataSource$ = exports2.OpenSearchDataAccessPolicy$ = exports2.OpenSearchCollection$ = exports2.OpenSearchApplication$ = exports2.MoveKeys$ = exports2.MoveKeyEntry$ = exports2.MetricTransformation$ = exports2.MetricFilterMatchRecord$ = exports2.MetricFilter$ = exports2.LowerCaseString$ = exports2.LookupTable$ = exports2.LogStream$ = exports2.LogGroupSummary$ = exports2.LogGroupField$ = exports2.LogGroup$ = exports2.LogFieldType$ = exports2.LogFieldsListItem$ = exports2.LogEvent$ = exports2.LiveTailSessionUpdate$ = exports2.LiveTailSessionStart$ = exports2.LiveTailSessionMetadata$ = exports2.LiveTailSessionLogEvent$ = exports2.ListToMap$ = exports2.ListTagsLogGroupResponse$ = void 0;
    exports2.SubscriptionFilter$ = exports2.StopQueryResponse$ = exports2.StopQueryRequest$ = exports2.StartQueryResponse$ = exports2.StartQueryRequest$ = exports2.StartLiveTailResponse$ = exports2.StartLiveTailRequest$ = exports2.SplitStringEntry$ = exports2.SplitString$ = exports2.SearchedLogStream$ = exports2.ScheduledQuerySummary$ = exports2.ScheduledQueryDestination$ = exports2.S3TableIntegrationSource$ = exports2.S3DeliveryConfiguration$ = exports2.S3Configuration$ = exports2.ResultField$ = exports2.ResourcePolicy$ = exports2.RenameKeys$ = exports2.RenameKeyEntry$ = exports2.RejectedLogEventsInfo$ = exports2.RejectedEntityInfo$ = exports2.RecordField$ = exports2.QueryStatistics$ = exports2.QueryParameter$ = exports2.QueryInfo$ = exports2.QueryDefinition$ = exports2.QueryCompileErrorLocation$ = exports2.QueryCompileError$ = exports2.PutTransformerRequest$ = exports2.PutSubscriptionFilterRequest$ = exports2.PutRetentionPolicyRequest$ = exports2.PutResourcePolicyResponse$ = exports2.PutResourcePolicyRequest$ = exports2.PutQueryDefinitionResponse$ = exports2.PutQueryDefinitionRequest$ = exports2.PutMetricFilterRequest$ = exports2.PutLogGroupDeletionProtectionRequest$ = exports2.PutLogEventsResponse$ = exports2.PutLogEventsRequest$ = exports2.PutIntegrationResponse$ = exports2.PutIntegrationRequest$ = exports2.PutIndexPolicyResponse$ = exports2.PutIndexPolicyRequest$ = exports2.PutDestinationResponse$ = exports2.PutDestinationRequest$ = exports2.PutDestinationPolicyRequest$ = exports2.PutDeliverySourceResponse$ = exports2.PutDeliverySourceRequest$ = exports2.PutDeliveryDestinationResponse$ = exports2.PutDeliveryDestinationRequest$ = void 0;
    exports2.DeleteIntegration$ = exports2.DeleteIndexPolicy$ = exports2.DeleteDestination$ = exports2.DeleteDeliverySource$ = exports2.DeleteDeliveryDestinationPolicy$ = exports2.DeleteDeliveryDestination$ = exports2.DeleteDelivery$ = exports2.DeleteDataProtectionPolicy$ = exports2.DeleteAccountPolicy$ = exports2.CreateScheduledQuery$ = exports2.CreateLookupTable$ = exports2.CreateLogStream$ = exports2.CreateLogGroup$ = exports2.CreateLogAnomalyDetector$ = exports2.CreateImportTask$ = exports2.CreateExportTask$ = exports2.CreateDelivery$ = exports2.CancelImportTask$ = exports2.CancelExportTask$ = exports2.AssociateSourceToS3TableIntegration$ = exports2.AssociateKmsKey$ = exports2.StartLiveTailResponseStream$ = exports2.ResourceConfig$ = exports2.IntegrationDetails$ = exports2.GetLogObjectResponseStream$ = exports2.UpperCaseString$ = exports2.UpdateScheduledQueryResponse$ = exports2.UpdateScheduledQueryRequest$ = exports2.UpdateLookupTableResponse$ = exports2.UpdateLookupTableRequest$ = exports2.UpdateLogAnomalyDetectorRequest$ = exports2.UpdateDeliveryConfigurationResponse$ = exports2.UpdateDeliveryConfigurationRequest$ = exports2.UpdateAnomalyRequest$ = exports2.UntagResourceRequest$ = exports2.UntagLogGroupRequest$ = exports2.TypeConverterEntry$ = exports2.TypeConverter$ = exports2.TrimString$ = exports2.TriggerHistoryRecord$ = exports2.TransformedLogRecord$ = exports2.TestTransformerResponse$ = exports2.TestTransformerRequest$ = exports2.TestMetricFilterResponse$ = exports2.TestMetricFilterRequest$ = exports2.TagResourceRequest$ = exports2.TagLogGroupRequest$ = exports2.SuppressionPeriod$ = exports2.SubstituteStringEntry$ = exports2.SubstituteString$ = void 0;
    exports2.GetTransformer$ = exports2.GetScheduledQueryHistory$ = exports2.GetScheduledQuery$ = exports2.GetQueryResults$ = exports2.GetLookupTable$ = exports2.GetLogRecord$ = exports2.GetLogObject$ = exports2.GetLogGroupFields$ = exports2.GetLogFields$ = exports2.GetLogEvents$ = exports2.GetLogAnomalyDetector$ = exports2.GetIntegration$ = exports2.GetDeliverySource$ = exports2.GetDeliveryDestinationPolicy$ = exports2.GetDeliveryDestination$ = exports2.GetDelivery$ = exports2.GetDataProtectionPolicy$ = exports2.FilterLogEvents$ = exports2.DisassociateSourceFromS3TableIntegration$ = exports2.DisassociateKmsKey$ = exports2.DescribeSubscriptionFilters$ = exports2.DescribeResourcePolicies$ = exports2.DescribeQueryDefinitions$ = exports2.DescribeQueries$ = exports2.DescribeMetricFilters$ = exports2.DescribeLookupTables$ = exports2.DescribeLogStreams$ = exports2.DescribeLogGroups$ = exports2.DescribeIndexPolicies$ = exports2.DescribeImportTasks$ = exports2.DescribeImportTaskBatches$ = exports2.DescribeFieldIndexes$ = exports2.DescribeExportTasks$ = exports2.DescribeDestinations$ = exports2.DescribeDeliverySources$ = exports2.DescribeDeliveryDestinations$ = exports2.DescribeDeliveries$ = exports2.DescribeConfigurationTemplates$ = exports2.DescribeAccountPolicies$ = exports2.DeleteTransformer$ = exports2.DeleteSubscriptionFilter$ = exports2.DeleteScheduledQuery$ = exports2.DeleteRetentionPolicy$ = exports2.DeleteResourcePolicy$ = exports2.DeleteQueryDefinition$ = exports2.DeleteMetricFilter$ = exports2.DeleteLookupTable$ = exports2.DeleteLogStream$ = exports2.DeleteLogGroup$ = exports2.DeleteLogAnomalyDetector$ = void 0;
    exports2.UpdateScheduledQuery$ = exports2.UpdateLookupTable$ = exports2.UpdateLogAnomalyDetector$ = exports2.UpdateDeliveryConfiguration$ = exports2.UpdateAnomaly$ = exports2.UntagResource$ = exports2.UntagLogGroup$ = exports2.TestTransformer$ = exports2.TestMetricFilter$ = exports2.TagResource$ = exports2.TagLogGroup$ = exports2.StopQuery$ = exports2.StartQuery$ = exports2.StartLiveTail$ = exports2.PutTransformer$ = exports2.PutSubscriptionFilter$ = exports2.PutRetentionPolicy$ = exports2.PutResourcePolicy$ = exports2.PutQueryDefinition$ = exports2.PutMetricFilter$ = exports2.PutLogGroupDeletionProtection$ = exports2.PutLogEvents$ = exports2.PutIntegration$ = exports2.PutIndexPolicy$ = exports2.PutDestinationPolicy$ = exports2.PutDestination$ = exports2.PutDeliverySource$ = exports2.PutDeliveryDestinationPolicy$ = exports2.PutDeliveryDestination$ = exports2.PutDataProtectionPolicy$ = exports2.PutBearerTokenAuthentication$ = exports2.PutAccountPolicy$ = exports2.ListTagsLogGroup$ = exports2.ListTagsForResource$ = exports2.ListSourcesForS3TableIntegration$ = exports2.ListScheduledQueries$ = exports2.ListLogGroupsForQuery$ = exports2.ListLogGroups$ = exports2.ListLogAnomalyDetectors$ = exports2.ListIntegrations$ = exports2.ListAnomalies$ = exports2.ListAggregateLogGroupSummaries$ = void 0;
    var _A10 = "Anomaly";
    var _AD = "AnomalyDetector";
    var _ADE13 = "AccessDeniedException";
    var _ADn = "AnomalyDetectors";
    var _AF = "AllowedFields";
    var _AK = "AddKeys";
    var _AKE = "AddKeyEntry";
    var _AKEd = "AddKeyEntries";
    var _AKK = "AssociateKmsKey";
    var _AKKR = "AssociateKmsKeyRequest";
    var _ALGS = "AggregateLogGroupSummary";
    var _ALGSg = "AggregateLogGroupSummaries";
    var _AP = "AccountPolicy";
    var _APc = "AccountPolicies";
    var _ASTSTI = "AssociateSourceToS3TableIntegration";
    var _ASTSTIR = "AssociateSourceToS3TableIntegrationRequest";
    var _ASTSTIRs = "AssociateSourceToS3TableIntegrationResponse";
    var _An = "Anomalies";
    var _CD = "CreateDelivery";
    var _CDR = "CreateDeliveryRequest";
    var _CDRr = "CreateDeliveryResponse";
    var _CE = "ConflictException";
    var _CET = "CancelExportTask";
    var _CETR = "CancelExportTaskRequest";
    var _CETRr = "CreateExportTaskRequest";
    var _CETRre = "CreateExportTaskResponse";
    var _CETr = "CreateExportTask";
    var _CIT = "CancelImportTask";
    var _CITR = "CancelImportTaskRequest";
    var _CITRa = "CancelImportTaskResponse";
    var _CITRr = "CreateImportTaskRequest";
    var _CITRre = "CreateImportTaskResponse";
    var _CITr = "CreateImportTask";
    var _CLAD = "CreateLogAnomalyDetector";
    var _CLADR = "CreateLogAnomalyDetectorRequest";
    var _CLADRr = "CreateLogAnomalyDetectorResponse";
    var _CLG = "CreateLogGroup";
    var _CLGR = "CreateLogGroupRequest";
    var _CLS = "CreateLogStream";
    var _CLSR = "CreateLogStreamRequest";
    var _CLT = "CreateLookupTable";
    var _CLTR = "CreateLookupTableRequest";
    var _CLTRr = "CreateLookupTableResponse";
    var _CSQ = "CreateScheduledQuery";
    var _CSQR = "CreateScheduledQueryRequest";
    var _CSQRr = "CreateScheduledQueryResponse";
    var _CSV = "CSV";
    var _CT4 = "ConfigurationTemplate";
    var _CTDCV = "ConfigurationTemplateDeliveryConfigValues";
    var _CTo = "ConfigurationTemplates";
    var _CV4 = "CopyValue";
    var _CVE = "CopyValueEntry";
    var _CVEo = "CopyValueEntries";
    var _D = "Delivery";
    var _DAAE = "DataAlreadyAcceptedException";
    var _DAP = "DeleteAccountPolicy";
    var _DAPR = "DeleteAccountPolicyRequest";
    var _DAPRe = "DescribeAccountPoliciesRequest";
    var _DAPRes = "DescribeAccountPoliciesResponse";
    var _DAPe = "DescribeAccountPolicies";
    var _DC = "DestinationConfiguration";
    var _DCT = "DescribeConfigurationTemplates";
    var _DCTR = "DescribeConfigurationTemplatesRequest";
    var _DCTRe = "DescribeConfigurationTemplatesResponse";
    var _DD = "DeliveryDestination";
    var _DDC = "DeliveryDestinationConfiguration";
    var _DDD = "DeleteDeliveryDestination";
    var _DDDP = "DeleteDeliveryDestinationPolicy";
    var _DDDPR = "DeleteDeliveryDestinationPolicyRequest";
    var _DDDR = "DeleteDeliveryDestinationRequest";
    var _DDDRe = "DescribeDeliveryDestinationsRequest";
    var _DDDRes = "DescribeDeliveryDestinationsResponse";
    var _DDDe = "DescribeDeliveryDestinations";
    var _DDPP = "DeleteDataProtectionPolicy";
    var _DDPPR = "DeleteDataProtectionPolicyRequest";
    var _DDR = "DeleteDeliveryRequest";
    var _DDRe = "DeleteDestinationRequest";
    var _DDRes = "DescribeDeliveriesRequest";
    var _DDResc = "DescribeDeliveriesResponse";
    var _DDRescr = "DescribeDestinationsRequest";
    var _DDRescri = "DescribeDestinationsResponse";
    var _DDS = "DeleteDeliverySource";
    var _DDSR = "DeleteDeliverySourceRequest";
    var _DDSRe = "DescribeDeliverySourcesRequest";
    var _DDSRes = "DescribeDeliverySourcesResponse";
    var _DDSe = "DescribeDeliverySources";
    var _DDe = "DeliveryDestinations";
    var _DDel = "DeleteDelivery";
    var _DDele = "DeleteDestination";
    var _DDes = "DescribeDeliveries";
    var _DDesc = "DescribeDestinations";
    var _DET = "DescribeExportTasks";
    var _DETR = "DescribeExportTasksRequest";
    var _DETRe = "DescribeExportTasksResponse";
    var _DFI = "DescribeFieldIndexes";
    var _DFIR = "DescribeFieldIndexesRequest";
    var _DFIRe = "DescribeFieldIndexesResponse";
    var _DI = "DeleteIntegration";
    var _DIP = "DeleteIndexPolicy";
    var _DIPR = "DeleteIndexPolicyRequest";
    var _DIPRe = "DeleteIndexPolicyResponse";
    var _DIPRes = "DescribeIndexPoliciesRequest";
    var _DIPResc = "DescribeIndexPoliciesResponse";
    var _DIPe = "DescribeIndexPolicies";
    var _DIR = "DeleteIntegrationRequest";
    var _DIRe = "DeleteIntegrationResponse";
    var _DIT = "DescribeImportTasks";
    var _DITB = "DescribeImportTaskBatches";
    var _DITBR = "DescribeImportTaskBatchesRequest";
    var _DITBRe = "DescribeImportTaskBatchesResponse";
    var _DITR = "DescribeImportTasksRequest";
    var _DITRe = "DescribeImportTasksResponse";
    var _DK = "DeleteKeys";
    var _DKK = "DisassociateKmsKey";
    var _DKKR = "DisassociateKmsKeyRequest";
    var _DLAD = "DeleteLogAnomalyDetector";
    var _DLADR = "DeleteLogAnomalyDetectorRequest";
    var _DLG = "DeleteLogGroup";
    var _DLGR = "DeleteLogGroupRequest";
    var _DLGRe = "DescribeLogGroupsRequest";
    var _DLGRes = "DescribeLogGroupsResponse";
    var _DLGe = "DescribeLogGroups";
    var _DLS = "DeleteLogStream";
    var _DLSR = "DeleteLogStreamRequest";
    var _DLSRe = "DescribeLogStreamsRequest";
    var _DLSRes = "DescribeLogStreamsResponse";
    var _DLSe = "DescribeLogStreams";
    var _DLT = "DeleteLookupTable";
    var _DLTR = "DeleteLookupTableRequest";
    var _DLTRe = "DescribeLookupTablesRequest";
    var _DLTRes = "DescribeLookupTablesResponse";
    var _DLTe = "DescribeLookupTables";
    var _DMF = "DeleteMetricFilter";
    var _DMFR = "DeleteMetricFilterRequest";
    var _DMFRe = "DescribeMetricFiltersRequest";
    var _DMFRes = "DescribeMetricFiltersResponse";
    var _DMFe = "DescribeMetricFilters";
    var _DNP = "DestinationNamePrefix";
    var _DQ = "DescribeQueries";
    var _DQD = "DeleteQueryDefinition";
    var _DQDR = "DeleteQueryDefinitionRequest";
    var _DQDRe = "DeleteQueryDefinitionResponse";
    var _DQDRes = "DescribeQueryDefinitionsRequest";
    var _DQDResc = "DescribeQueryDefinitionsResponse";
    var _DQDe = "DescribeQueryDefinitions";
    var _DQR = "DescribeQueriesRequest";
    var _DQRe = "DescribeQueriesResponse";
    var _DRP = "DeleteResourcePolicy";
    var _DRPR = "DeleteResourcePolicyRequest";
    var _DRPRe = "DeleteRetentionPolicyRequest";
    var _DRPRes = "DescribeResourcePoliciesRequest";
    var _DRPResc = "DescribeResourcePoliciesResponse";
    var _DRPe = "DeleteRetentionPolicy";
    var _DRPes = "DescribeResourcePolicies";
    var _DS10 = "DataSource";
    var _DSF = "DataSourceFilter";
    var _DSFR = "DeleteSubscriptionFilterRequest";
    var _DSFRe = "DescribeSubscriptionFiltersRequest";
    var _DSFRes = "DescribeSubscriptionFiltersResponse";
    var _DSFSTI = "DisassociateSourceFromS3TableIntegration";
    var _DSFSTIR = "DisassociateSourceFromS3TableIntegrationRequest";
    var _DSFSTIRi = "DisassociateSourceFromS3TableIntegrationResponse";
    var _DSFa = "DataSourceFilters";
    var _DSFe = "DeleteSubscriptionFilter";
    var _DSFes = "DescribeSubscriptionFilters";
    var _DSQ = "DeleteScheduledQuery";
    var _DSQR = "DeleteScheduledQueryRequest";
    var _DSQRe = "DeleteScheduledQueryResponse";
    var _DSe = "DeliverySource";
    var _DSel = "DeliverySources";
    var _DT = "DeleteTransformer";
    var _DTC = "DateTimeConverter";
    var _DTR = "DeleteTransformerRequest";
    var _De = "Destination";
    var _Del = "Deliveries";
    var _Des = "Destinations";
    var _E11 = "Entity";
    var _ET = "ExportTask";
    var _ETEI = "ExportTaskExecutionInfo";
    var _ETS = "ExportTaskStatus";
    var _ETx = "ExportTasks";
    var _FD = "FieldsData";
    var _FI = "FieldIndex";
    var _FIi = "FieldIndexes";
    var _FLE = "FilteredLogEvent";
    var _FLER = "FilterLogEventsRequest";
    var _FLERi = "FilterLogEventsResponse";
    var _FLEi = "FilteredLogEvents";
    var _FLEil = "FilterLogEvents";
    var _G = "Grok";
    var _GD = "GetDelivery";
    var _GDD = "GetDeliveryDestination";
    var _GDDP = "GetDeliveryDestinationPolicy";
    var _GDDPR = "GetDeliveryDestinationPolicyRequest";
    var _GDDPRe = "GetDeliveryDestinationPolicyResponse";
    var _GDDR = "GetDeliveryDestinationRequest";
    var _GDDRe = "GetDeliveryDestinationResponse";
    var _GDPP = "GetDataProtectionPolicy";
    var _GDPPR = "GetDataProtectionPolicyRequest";
    var _GDPPRe = "GetDataProtectionPolicyResponse";
    var _GDR = "GetDeliveryRequest";
    var _GDRe = "GetDeliveryResponse";
    var _GDS = "GetDeliverySource";
    var _GDSR = "GetDeliverySourceRequest";
    var _GDSRe = "GetDeliverySourceResponse";
    var _GI2 = "GroupingIdentifier";
    var _GIR2 = "GetIntegrationRequest";
    var _GIRe = "GetIntegrationResponse";
    var _GIe = "GetIntegration";
    var _GIr = "GroupingIdentifiers";
    var _GLAD = "GetLogAnomalyDetector";
    var _GLADR = "GetLogAnomalyDetectorRequest";
    var _GLADRe = "GetLogAnomalyDetectorResponse";
    var _GLE = "GetLogEvents";
    var _GLER = "GetLogEventsRequest";
    var _GLERe = "GetLogEventsResponse";
    var _GLF = "GetLogFields";
    var _GLFR = "GetLogFieldsRequest";
    var _GLFRe = "GetLogFieldsResponse";
    var _GLGF = "GetLogGroupFields";
    var _GLGFR = "GetLogGroupFieldsRequest";
    var _GLGFRe = "GetLogGroupFieldsResponse";
    var _GLO = "GetLogObject";
    var _GLOR = "GetLogObjectRequest";
    var _GLORS = "GetLogObjectResponseStream";
    var _GLORe = "GetLogObjectResponse";
    var _GLR = "GetLogRecord";
    var _GLRR = "GetLogRecordRequest";
    var _GLRRe = "GetLogRecordResponse";
    var _GLT = "GetLookupTable";
    var _GLTR = "GetLookupTableRequest";
    var _GLTRe = "GetLookupTableResponse";
    var _GQR = "GetQueryResults";
    var _GQRR = "GetQueryResultsRequest";
    var _GQRRe = "GetQueryResultsResponse";
    var _GSQ = "GetScheduledQuery";
    var _GSQH = "GetScheduledQueryHistory";
    var _GSQHR = "GetScheduledQueryHistoryRequest";
    var _GSQHRe = "GetScheduledQueryHistoryResponse";
    var _GSQR = "GetScheduledQueryRequest";
    var _GSQRe = "GetScheduledQueryResponse";
    var _GT = "GetTransformer";
    var _GTR = "GetTransformerRequest";
    var _GTRe = "GetTransformerResponse";
    var _I = "Import";
    var _IB = "ImportBatch";
    var _IBL = "ImportBatchList";
    var _ID = "IntegrationDetails";
    var _IF = "ImportFilter";
    var _IL = "ImportList";
    var _ILE = "InputLogEvent";
    var _ILEn = "InputLogEvents";
    var _IOE = "InvalidOperationException";
    var _IP = "IndexPolicy";
    var _IPE2 = "InvalidParameterException";
    var _IPn = "IndexPolicies";
    var _IS = "ImportStatistics";
    var _ISE13 = "InternalServerException";
    var _ISEn4 = "InternalStreamingException";
    var _ISTE = "InvalidSequenceTokenException";
    var _ISn = "IntegrationSummary";
    var _ISnt = "IntegrationSummaries";
    var _LA = "ListAnomalies";
    var _LALGS = "ListAggregateLogGroupSummaries";
    var _LALGSR = "ListAggregateLogGroupSummariesRequest";
    var _LALGSRi = "ListAggregateLogGroupSummariesResponse";
    var _LAR = "ListAnomaliesRequest";
    var _LARi = "ListAnomaliesResponse";
    var _LCS = "LowerCaseString";
    var _LE = "LogEvent";
    var _LEE2 = "LimitExceededException";
    var _LFL = "LogFieldsList";
    var _LFLI = "LogFieldsListItem";
    var _LFT = "LogFieldType";
    var _LG = "LogGroup";
    var _LGF = "LogGroupField";
    var _LGFL = "LogGroupFieldList";
    var _LGS = "LogGroupSummary";
    var _LGSo = "LogGroupSummaries";
    var _LGo = "LogGroups";
    var _LI = "ListIntegrations";
    var _LIR = "ListIntegrationsRequest";
    var _LIRi = "ListIntegrationsResponse";
    var _LLAD = "ListLogAnomalyDetectors";
    var _LLADR = "ListLogAnomalyDetectorsRequest";
    var _LLADRi = "ListLogAnomalyDetectorsResponse";
    var _LLG = "ListLogGroups";
    var _LLGFQ = "ListLogGroupsForQuery";
    var _LLGFQR = "ListLogGroupsForQueryRequest";
    var _LLGFQRi = "ListLogGroupsForQueryResponse";
    var _LLGR = "ListLogGroupsRequest";
    var _LLGRi = "ListLogGroupsResponse";
    var _LS = "LogStream";
    var _LSFSTI = "ListSourcesForS3TableIntegration";
    var _LSFSTIR = "ListSourcesForS3TableIntegrationRequest";
    var _LSFSTIRi = "ListSourcesForS3TableIntegrationResponse";
    var _LSQ = "ListScheduledQueries";
    var _LSQR = "ListScheduledQueriesRequest";
    var _LSQRi = "ListScheduledQueriesResponse";
    var _LSo = "LogSamples";
    var _LSog = "LogStreams";
    var _LT = "LookupTable";
    var _LTFR = "ListTagsForResource";
    var _LTFRR = "ListTagsForResourceRequest";
    var _LTFRRi = "ListTagsForResourceResponse";
    var _LTLG = "ListTagsLogGroup";
    var _LTLGR = "ListTagsLogGroupRequest";
    var _LTLGRi = "ListTagsLogGroupResponse";
    var _LTM = "ListToMap";
    var _LTSLE = "LiveTailSessionLogEvent";
    var _LTSM = "LiveTailSessionMetadata";
    var _LTSR = "LiveTailSessionResults";
    var _LTSS = "LiveTailSessionStart";
    var _LTSU = "LiveTailSessionUpdate";
    var _LTo = "LookupTables";
    var _MF = "MetricFilter";
    var _MFM = "MetricFilterMatches";
    var _MFMR = "MetricFilterMatchRecord";
    var _MFe = "MetricFilters";
    var _MK = "MoveKeys";
    var _MKE = "MoveKeyEntry";
    var _MKEo = "MoveKeyEntries";
    var _MQE = "MalformedQueryException";
    var _MT = "MetricTransformation";
    var _MTe = "MetricTransformations";
    var _OAE = "OperationAbortedException";
    var _OLE = "OutputLogEvent";
    var _OLEu = "OutputLogEvents";
    var _OSA = "OpenSearchApplication";
    var _OSC = "OpenSearchCollection";
    var _OSDAP = "OpenSearchDataAccessPolicy";
    var _OSDS = "OpenSearchDataSource";
    var _OSEP = "OpenSearchEncryptionPolicy";
    var _OSID = "OpenSearchIntegrationDetails";
    var _OSLP = "OpenSearchLifecyclePolicy";
    var _OSNP = "OpenSearchNetworkPolicy";
    var _OSRC = "OpenSearchResourceConfig";
    var _OSRS = "OpenSearchResourceStatus";
    var _OSW = "OpenSearchWorkspace";
    var _P10 = "Policy";
    var _PAP = "PutAccountPolicy";
    var _PAPR = "PutAccountPolicyRequest";
    var _PAPRu = "PutAccountPolicyResponse";
    var _PBTA = "PutBearerTokenAuthentication";
    var _PBTAR = "PutBearerTokenAuthenticationRequest";
    var _PC10 = "ParseCloudfront";
    var _PD = "PutDestination";
    var _PDD = "PutDeliveryDestination";
    var _PDDP = "PutDeliveryDestinationPolicy";
    var _PDDPR = "PutDeliveryDestinationPolicyRequest";
    var _PDDPRu = "PutDeliveryDestinationPolicyResponse";
    var _PDDR = "PutDeliveryDestinationRequest";
    var _PDDRu = "PutDeliveryDestinationResponse";
    var _PDP = "PutDestinationPolicy";
    var _PDPP = "PutDataProtectionPolicy";
    var _PDPPR = "PutDataProtectionPolicyRequest";
    var _PDPPRu = "PutDataProtectionPolicyResponse";
    var _PDPR = "PutDestinationPolicyRequest";
    var _PDR = "PutDestinationRequest";
    var _PDRu = "PutDestinationResponse";
    var _PDS = "PutDeliverySource";
    var _PDSR = "PutDeliverySourceRequest";
    var _PDSRu = "PutDeliverySourceResponse";
    var _PI10 = "PutIntegration";
    var _PIP = "PutIndexPolicy";
    var _PIPR = "PutIndexPolicyRequest";
    var _PIPRu = "PutIndexPolicyResponse";
    var _PIR = "PutIntegrationRequest";
    var _PIRu = "PutIntegrationResponse";
    var _PJSON = "ParseJSON";
    var _PKV = "ParseKeyValue";
    var _PLE = "PutLogEvents";
    var _PLER = "PutLogEventsRequest";
    var _PLERu = "PutLogEventsResponse";
    var _PLGDP = "PutLogGroupDeletionProtection";
    var _PLGDPR = "PutLogGroupDeletionProtectionRequest";
    var _PMF = "PutMetricFilter";
    var _PMFR = "PutMetricFilterRequest";
    var _PP = "ParsePostgres";
    var _PQD = "PutQueryDefinition";
    var _PQDR = "PutQueryDefinitionRequest";
    var _PQDRu = "PutQueryDefinitionResponse";
    var _PR = "ParseRoute53";
    var _PRP = "PutResourcePolicy";
    var _PRPR = "PutResourcePolicyRequest";
    var _PRPRu = "PutResourcePolicyResponse";
    var _PRPRut = "PutRetentionPolicyRequest";
    var _PRPu = "PutRetentionPolicy";
    var _PSF = "PutSubscriptionFilter";
    var _PSFR = "PutSubscriptionFilterRequest";
    var _PT = "PatternToken";
    var _PTOCSF = "ParseToOCSF";
    var _PTR = "PutTransformerRequest";
    var _PTa = "PatternTokens";
    var _PTu = "PutTransformer";
    var _PVPC = "ParseVPC";
    var _PWAF = "ParseWAF";
    var _Pr10 = "Processor";
    var _Pro = "Processors";
    var _QCE = "QueryCompileError";
    var _QCEL = "QueryCompileErrorLocation";
    var _QD = "QueryDefinition";
    var _QDL = "QueryDefinitionList";
    var _QI = "QueryInfo";
    var _QIL = "QueryInfoList";
    var _QP = "QueryParameter";
    var _QPL = "QueryParameterList";
    var _QR = "QueryResults";
    var _QS = "QueryStatistics";
    var _RAEE = "ResourceAlreadyExistsException";
    var _RC10 = "ResourceConfig";
    var _REI = "RejectedEntityInfo";
    var _RF = "RecordField";
    var _RFe = "ResultField";
    var _RK = "RenameKeys";
    var _RKE = "RenameKeyEntry";
    var _RKEe = "RenameKeyEntries";
    var _RLEI = "RejectedLogEventsInfo";
    var _RNFE11 = "ResourceNotFoundException";
    var _RP = "ResourcePolicy";
    var _RPe = "ResourcePolicies";
    var _RR = "ResultRows";
    var _SC = "S3Configuration";
    var _SDC = "S3DeliveryConfiguration";
    var _SF = "SubscriptionFilter";
    var _SFu = "SubscriptionFilters";
    var _SLS = "SearchedLogStream";
    var _SLSe = "SearchedLogStreams";
    var _SLT = "StartLiveTail";
    var _SLTR = "StartLiveTailRequest";
    var _SLTRS = "StartLiveTailResponseStream";
    var _SLTRt = "StartLiveTailResponse";
    var _SP = "SuppressionPeriod";
    var _SQ = "StartQuery";
    var _SQD = "ScheduledQueryDestination";
    var _SQDL = "ScheduledQueryDestinationList";
    var _SQEE = "ServiceQuotaExceededException";
    var _SQR = "StartQueryRequest";
    var _SQRt = "StartQueryResponse";
    var _SQRto = "StopQueryRequest";
    var _SQRtop = "StopQueryResponse";
    var _SQS = "ScheduledQuerySummary";
    var _SQSL = "ScheduledQuerySummaryList";
    var _SQt = "StopQuery";
    var _SS = "SplitString";
    var _SSE = "SessionStreamingException";
    var _SSEp = "SplitStringEntry";
    var _SSEpl = "SplitStringEntries";
    var _SSEu = "SubstituteStringEntry";
    var _SSEub = "SubstituteStringEntries";
    var _SSu = "SubstituteString";
    var _STE = "SessionTimeoutException";
    var _STIS = "S3TableIntegrationSource";
    var _STISa = "S3TableIntegrationSources";
    var _SUE = "ServiceUnavailableException";
    var _TC10 = "TypeConverter";
    var _TCE = "TypeConverterEntry";
    var _TCEy = "TypeConverterEntries";
    var _TE = "ThrottlingException";
    var _THR = "TriggerHistoryRecord";
    var _THRL = "TriggerHistoryRecordList";
    var _TL = "TransformedLogs";
    var _TLG = "TagLogGroup";
    var _TLGR = "TagLogGroupRequest";
    var _TLR = "TransformedLogRecord";
    var _TMF = "TestMetricFilter";
    var _TMFR = "TestMetricFilterRequest";
    var _TMFRe = "TestMetricFilterResponse";
    var _TMTE = "TooManyTagsException";
    var _TR = "TagResource";
    var _TRR = "TagResourceRequest";
    var _TS = "TrimString";
    var _TT = "TestTransformer";
    var _TTR = "TestTransformerRequest";
    var _TTRe = "TestTransformerResponse";
    var _UA = "UpdateAnomaly";
    var _UAR = "UpdateAnomalyRequest";
    var _UCE4 = "UnrecognizedClientException";
    var _UCS = "UpperCaseString";
    var _UDC = "UpdateDeliveryConfiguration";
    var _UDCR = "UpdateDeliveryConfigurationRequest";
    var _UDCRp = "UpdateDeliveryConfigurationResponse";
    var _ULAD = "UpdateLogAnomalyDetector";
    var _ULADR = "UpdateLogAnomalyDetectorRequest";
    var _ULG = "UntagLogGroup";
    var _ULGR = "UntagLogGroupRequest";
    var _ULT = "UpdateLookupTable";
    var _ULTR = "UpdateLookupTableRequest";
    var _ULTRp = "UpdateLookupTableResponse";
    var _UR = "UntagResource";
    var _URR = "UntagResourceRequest";
    var _USQ = "UpdateScheduledQuery";
    var _USQR = "UpdateScheduledQueryRequest";
    var _USQRp = "UpdateScheduledQueryResponse";
    var _VE10 = "ValidationException";
    var _a10 = "active";
    var _aA = "applicationArn";
    var _aAFAVLDFR = "allowedActionForAllowVendedLogsDeliveryForResource";
    var _aD = "anomalyDetectors";
    var _aDA = "anomalyDetectorArn";
    var _aDS = "anomalyDetectorStatus";
    var _aE = "applicationEndpoint";
    var _aF = "allowedFields";
    var _aFD = "allowedFieldDelimiters";
    var _aI10 = "accountId";
    var _aIc = "accountIdentifiers";
    var _aIn = "anomalyId";
    var _aIp = "applicationId";
    var _aK = "addKeys";
    var _aLGS = "aggregateLogGroupSummaries";
    var _aOF = "allowedOutputFormats";
    var _aOTL = "applyOnTransformedLogs";
    var _aP = "accountPolicies";
    var _aPc = "accessPolicy";
    var _aPcc = "accountPolicy";
    var _aSPF = "allowedSuffixPathFields";
    var _aVT = "anomalyVisibilityTime";
    var _an = "anomalies";
    var _ap = "application";
    var _ar = "arn";
    var _at = "attributes";
    var _b = "baseline";
    var _bI = "batchId";
    var _bIS = "batchImportStatus";
    var _bIy = "bytesImported";
    var _bS = "bytesScanned";
    var _bTAE = "bearerTokenAuthenticationEnabled";
    var _c32 = "client";
    var _cA = "createdAt";
    var _cAo = "collectionArn";
    var _cE = "collectionEndpoint";
    var _cT = "creationTime";
    var _cTS = "creationTimeStamp";
    var _cTSr = "createdTimeStamp";
    var _cTl = "clientToken";
    var _cTo = "configurationTemplates";
    var _cTom = "completionTime";
    var _cTr = "createTime";
    var _cV13 = "copyValue";
    var _co13 = "columns";
    var _cod = "code";
    var _col = "collection";
    var _cs = "csv";
    var _d = "description";
    var _dA = "destinationArn";
    var _dC4 = "destinationConfiguration";
    var _dD = "deliveryDestinations";
    var _dDA = "deliveryDestinationArn";
    var _dDC = "deliveryDestinationConfiguration";
    var _dDCV = "defaultDeliveryConfigValues";
    var _dDN = "deliveryDestinationName";
    var _dDP = "deliveryDestinationPolicy";
    var _dDT = "deliveryDestinationType";
    var _dDTe = "deliveryDestinationTypes";
    var _dDe = "deliveryDestination";
    var _dI = "destinationIdentifier";
    var _dK = "deleteKeys";
    var _dN = "detectorName";
    var _dNe = "destinationName";
    var _dP = "destinationPrefix";
    var _dPE = "deletionProtectionEnabled";
    var _dPS = "dataProtectionStatus";
    var _dRA = "destinationResourceArn";
    var _dS = "dataSource";
    var _dSN = "deliverySourceName";
    var _dSNa = "dataSourceName";
    var _dSRA = "dataSourceRoleArn";
    var _dST = "dataSourceType";
    var _dSa = "dataSources";
    var _dSe = "deliverySources";
    var _dSel = "deliverySource";
    var _dT = "destinationType";
    var _dTC = "dateTimeConverter";
    var _dTP = "dynamicTokenPosition";
    var _dV = "defaultValue";
    var _dVP = "dashboardViewerPrincipals";
    var _da = "data";
    var _de = "delivery";
    var _del = "delimiter";
    var _deli = "deliveries";
    var _des = "destination";
    var _desc = "descending";
    var _dest = "destinations";
    var _di = "dimensions";
    var _dis = "distribution";
    var _e32 = "error";
    var _eBS = "estimatedBytesSkipped";
    var _eCO = "endCharOffset";
    var _eET = "endEventTime";
    var _eF = "evaluationFrequency";
    var _eHCP = "enableHiveCompatiblePath";
    var _eI13 = "executionInfo";
    var _eIv = "eventId";
    var _eK = "encryptionKey";
    var _eLEEI = "expiredLogEventEndIndex";
    var _eM = "errorMessage";
    var _eMv = "eventMessage";
    var _eN = "eventNumber";
    var _eP = "encryptionPolicy";
    var _eRA = "executionRoleArn";
    var _eRI = "expectedRevisionId";
    var _eRS = "estimatedRecordsSkipped";
    var _eS = "executionStatuses";
    var _eSF = "emitSystemFields";
    var _eSFD = "emitSystemFieldDimensions";
    var _eST = "expectedSequenceToken";
    var _eSv = "eventSource";
    var _eSx = "executionStatus";
    var _eT = "exportTasks";
    var _eTn = "endTime";
    var _eTr = "errorType";
    var _eV = "extractedValues";
    var _el = "element";
    var _en = "entries";
    var _ena = "enabled";
    var _end = "endpoint";
    var _ent = "entity";
    var _enu = "enumerations";
    var _ev = "events";
    var _f = "from";
    var _fD = "fieldDelimiter";
    var _fE = "flattenedElement";
    var _fET = "firstEventTime";
    var _fETi = "firstEventTimestamp";
    var _fI = "fieldIndexes";
    var _fIN = "fieldIndexName";
    var _fINi = "fieldIndexNames";
    var _fLGA = "filterLogGroupArn";
    var _fN = "filterName";
    var _fNP = "filterNamePrefix";
    var _fP = "filterPattern";
    var _fS = "firstSeen";
    var _fSC = "fieldSelectionCriteria";
    var _fSi = "fieldStream";
    var _fU = "forceUpdate";
    var _fi = "fields";
    var _fie = "field";
    var _fl = "flatten";
    var _fo = "force";
    var _g = "grok";
    var _gB = "groupBy";
    var _gI = "groupingIdentifiers";
    var _h22 = "histogram";
    var _hE32 = "httpError";
    var _i = "identifier";
    var _iA = "integrationArn";
    var _iB = "importBatches";
    var _iD = "integrationDetails";
    var _iDA = "importDestinationArn";
    var _iDs = "isDynamic";
    var _iF = "importFilter";
    var _iI = "importId";
    var _iLA = "includeLinkedAccounts";
    var _iN = "integrationName";
    var _iNP = "integrationNamePrefix";
    var _iP = "indexPolicies";
    var _iPLS = "isPatternLevelSuppression";
    var _iPn = "inheritedProperties";
    var _iPnd = "indexPolicy";
    var _iRA = "importRoleArn";
    var _iS = "importStatistics";
    var _iSA = "importSourceArn";
    var _iSm = "importStatus";
    var _iSn = "integrationStatus";
    var _iSnt = "integrationSummaries";
    var _iT13 = "ingestionTime";
    var _iTN = "inferredTokenName";
    var _iTn = "integrationType";
    var _id = "id";
    var _im = "imports";
    var _in = "interleaved";
    var _k = "key";
    var _kA = "keyAttributes";
    var _kKA = "kmsKeyArn";
    var _kKI = "kmsKeyId";
    var _kP = "keyPrefix";
    var _kVD = "keyValueDelimiter";
    var _l = "locale";
    var _lCS = "lowerCaseString";
    var _lE = "logEvents";
    var _lEFP = "logEventFilterPattern";
    var _lEM = "logEventMessages";
    var _lES = "lastExecutionStatus";
    var _lET = "lastEventTime";
    var _lETa = "lastEventTimestamp";
    var _lF = "logFields";
    var _lFN = "logFieldName";
    var _lFT = "logFieldType";
    var _lG = "logGroups";
    var _lGA = "logGroupArn";
    var _lGAL = "logGroupArnList";
    var _lGC = "logGroupCount";
    var _lGCo = "logGroupClass";
    var _lGF = "logGroupFields";
    var _lGI = "logGroupIdentifiers";
    var _lGIo = "logGroupIdentifier";
    var _lGN = "logGroupName";
    var _lGNP = "logGroupNamePrefix";
    var _lGNPo = "logGroupNamePattern";
    var _lGNo = "logGroupNames";
    var _lGS = "logGroupsScanned";
    var _lIT = "lastIngestionTime";
    var _lM = "lastModified";
    var _lMT = "lastModifiedTime";
    var _lMTS = "lastModifiedTimeStamp";
    var _lOP = "logObjectPointer";
    var _lP = "lifecyclePolicy";
    var _lR = "logRecord";
    var _lRP = "logRecordPointer";
    var _lS = "lastSeen";
    var _lSN = "logStreamName";
    var _lSNP = "logStreamNamePrefix";
    var _lSNPo = "logStreamNamePrefixes";
    var _lSNo = "logStreamNames";
    var _lST = "lastScanTime";
    var _lSo = "logSamples";
    var _lSog = "logStreams";
    var _lT = "logType";
    var _lTA = "lookupTableArn";
    var _lTM = "listToMap";
    var _lTN = "lookupTableName";
    var _lTNP = "lookupTableNamePrefix";
    var _lTT = "lastTriggeredTime";
    var _lTo = "logTypes";
    var _lToo = "lookupTables";
    var _lUT = "lastUpdatedTime";
    var _lUTa = "lastUpdateTime";
    var _li = "limit";
    var _lo = "location";
    var _m29 = "message";
    var _mF = "metricFilters";
    var _mFC = "metricFilterCount";
    var _mK = "moveKeys";
    var _mN = "metricName";
    var _mNe = "metricNamespace";
    var _mP = "matchPatterns";
    var _mR = "maxResults";
    var _mT = "metricTransformations";
    var _mV = "metricValue";
    var _mVa = "mappingVersion";
    var _ma = "match";
    var _man = "mandatory";
    var _mat = "matches";
    var _n = "name";
    var _nBT = "nextBackwardToken";
    var _nFT = "nextForwardToken";
    var _nMV = "nonMatchValue";
    var _nP = "networkPolicy";
    var _nST = "nextSequenceToken";
    var _nT = "nextToken";
    var _oAI = "ownerAccountId";
    var _oB = "orderBy";
    var _oF = "outputFormat";
    var _oIE = "overwriteIfExists";
    var _oSID = "openSearchIntegrationDetails";
    var _oSRC = "openSearchResourceConfig";
    var _oV = "ocsfVersion";
    var _p = "priority";
    var _pC = "parseCloudfront";
    var _pD = "policyDocument";
    var _pI = "patternId";
    var _pIr = "processedIdentifier";
    var _pJSON = "parseJSON";
    var _pKV = "parseKeyValue";
    var _pN = "policyName";
    var _pP = "parsePostgres";
    var _pR = "patternRegex";
    var _pRa = "parseRoute53";
    var _pS = "patternString";
    var _pSo = "policyScope";
    var _pT = "policyType";
    var _pTOCSF = "parseToOCSF";
    var _pTa = "patternTokens";
    var _pVPC = "parseVPC";
    var _pWAF = "parseWAF";
    var _pa = "parameters";
    var _pe = "percent";
    var _po = "policy";
    var _q = "queries";
    var _qC = "quoteCharacter";
    var _qCE = "queryCompileError";
    var _qD = "queryDefinitions";
    var _qDI = "queryDefinitionId";
    var _qDNP = "queryDefinitionNamePrefix";
    var _qDu = "queryDuration";
    var _qI = "queryId";
    var _qL = "queryLanguage";
    var _qS = "queryString";
    var _r4 = "results";
    var _rA = "resourceArn";
    var _rAe = "resourceArns";
    var _rAo = "roleArn";
    var _rC10 = "recordsCount";
    var _rCe = "resourceConfig";
    var _rD = "retentionDays";
    var _rEI = "rejectedEntityInfo";
    var _rF = "recordFields";
    var _rI = "resourceIdentifier";
    var _rID = "retentionInDays";
    var _rIe = "requestId";
    var _rIev = "revisionId";
    var _rK = "renameKeys";
    var _rLEI = "rejectedLogEventsInfo";
    var _rM = "recordsMatched";
    var _rN10 = "resourceName";
    var _rP = "resourcePolicies";
    var _rPe = "resourcePolicy";
    var _rS = "recordsScanned";
    var _rSe = "responseStream";
    var _rT13 = "resourceType";
    var _rTe = "resourceTypes";
    var _rTen = "renameTo";
    var _s32 = "smithy.ts.sdk.synthetic.com.amazonaws.cloudwatchlogs";
    var _sB = "sizeBytes";
    var _sBt = "storedBytes";
    var _sC = "selectionCriteria";
    var _sCO = "startCharOffset";
    var _sCe = "searchedCompletely";
    var _sCo = "s3Configuration";
    var _sCt = "statusCode";
    var _sD = "suppressedDate";
    var _sDC = "s3DeliveryConfiguration";
    var _sE = "scheduleExpression";
    var _sET = "scheduleEndTime";
    var _sETt = "startEventTime";
    var _sF = "subscriptionFilters";
    var _sFH = "startFromHead";
    var _sI = "sessionId";
    var _sLS = "searchedLogStreams";
    var _sM = "sessionMetadata";
    var _sMt = "statusMessage";
    var _sP = "suffixPath";
    var _sPu = "suppressionPeriod";
    var _sQ = "scheduledQueries";
    var _sQA = "scheduledQueryArn";
    var _sR = "sessionResults";
    var _sRt = "statusReason";
    var _sS = "suppressionState";
    var _sST = "scheduleStartTime";
    var _sSe = "sessionStart";
    var _sSp = "splitString";
    var _sSu = "substituteString";
    var _sT19 = "sourceTimezone";
    var _sTO = "startTimeOffset";
    var _sTe = "sequenceToken";
    var _sTt = "startTime";
    var _sTu = "suppressionType";
    var _sU = "suppressedUntil";
    var _sUe = "sessionUpdate";
    var _sUu = "suppressionUnit";
    var _sa = "sampled";
    var _sc4 = "scope";
    var _se14 = "server";
    var _ser = "service";
    var _so = "source";
    var _sou = "sources";
    var _st = "state";
    var _sta = "status";
    var _stat = "statistics";
    var _str = "streaming";
    var _su = "suppressed";
    var _suc = "success";
    var _t = "target";
    var _tA = "targetArn";
    var _tB = "tableBody";
    var _tC = "transformerConfig";
    var _tCy = "typeConverter";
    var _tEM = "transformedEventMessage";
    var _tF = "targetFormat";
    var _tFa = "tableFields";
    var _tH = "triggerHistory";
    var _tI10 = "taskId";
    var _tK = "tagKeys";
    var _tL = "transformedLogs";
    var _tN = "taskName";
    var _tNLESI = "tooNewLogEventStartIndex";
    var _tOLEEI = "tooOldLogEventEndIndex";
    var _tS = "tokenString";
    var _tSr = "trimString";
    var _tT13 = "targetTimezone";
    var _tTr = "triggeredTimestamp";
    var _ta = "tags";
    var _ti = "timezone";
    var _tim = "timestamp";
    var _time = "time";
    var _to = "to";
    var _ty = "type";
    var _u = "unmask";
    var _uCS = "upperCaseString";
    var _uI = "userIdentity";
    var _uST = "uploadSequenceToken";
    var _un = "unit";
    var _v = "value";
    var _vK = "valueKey";
    var _w = "workspace";
    var _wI = "workspaceId";
    var _wK = "withKeys";
    var n032 = "com.amazonaws.cloudwatchlogs";
    var schema_1 = (init_schema4(), __toCommonJS(schema_exports));
    var CloudWatchLogsServiceException_1 = require_CloudWatchLogsServiceException();
    var errors_1 = require_errors9();
    var _s_registry32 = schema_1.TypeRegistry.for(_s32);
    exports2.CloudWatchLogsServiceException$ = [-3, _s32, "CloudWatchLogsServiceException", 0, [], []];
    _s_registry32.registerError(exports2.CloudWatchLogsServiceException$, CloudWatchLogsServiceException_1.CloudWatchLogsServiceException);
    var n0_registry32 = schema_1.TypeRegistry.for(n032);
    exports2.AccessDeniedException$ = [
      -3,
      n032,
      _ADE13,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.AccessDeniedException$, errors_1.AccessDeniedException);
    exports2.ConflictException$ = [
      -3,
      n032,
      _CE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ConflictException$, errors_1.ConflictException);
    exports2.DataAlreadyAcceptedException$ = [
      -3,
      n032,
      _DAAE,
      { [_e32]: _c32 },
      [_eST, _m29],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.DataAlreadyAcceptedException$, errors_1.DataAlreadyAcceptedException);
    exports2.InternalServerException$ = [
      -3,
      n032,
      _ISE13,
      { [_e32]: _se14, [_hE32]: 500 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InternalServerException$, errors_1.InternalServerException);
    exports2.InternalStreamingException$ = [
      -3,
      n032,
      _ISEn4,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InternalStreamingException$, errors_1.InternalStreamingException);
    exports2.InvalidOperationException$ = [
      -3,
      n032,
      _IOE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidOperationException$, errors_1.InvalidOperationException);
    exports2.InvalidParameterException$ = [
      -3,
      n032,
      _IPE2,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidParameterException$, errors_1.InvalidParameterException);
    exports2.InvalidSequenceTokenException$ = [
      -3,
      n032,
      _ISTE,
      { [_e32]: _c32 },
      [_eST, _m29],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.InvalidSequenceTokenException$, errors_1.InvalidSequenceTokenException);
    exports2.LimitExceededException$ = [
      -3,
      n032,
      _LEE2,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.LimitExceededException$, errors_1.LimitExceededException);
    exports2.MalformedQueryException$ = [
      -3,
      n032,
      _MQE,
      { [_e32]: _c32 },
      [_qCE, _m29],
      [() => exports2.QueryCompileError$, 0]
    ];
    n0_registry32.registerError(exports2.MalformedQueryException$, errors_1.MalformedQueryException);
    exports2.OperationAbortedException$ = [
      -3,
      n032,
      _OAE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.OperationAbortedException$, errors_1.OperationAbortedException);
    exports2.ResourceAlreadyExistsException$ = [
      -3,
      n032,
      _RAEE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ResourceAlreadyExistsException$, errors_1.ResourceAlreadyExistsException);
    exports2.ResourceNotFoundException$ = [
      -3,
      n032,
      _RNFE11,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ResourceNotFoundException$, errors_1.ResourceNotFoundException);
    exports2.ServiceQuotaExceededException$ = [
      -3,
      n032,
      _SQEE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ServiceQuotaExceededException$, errors_1.ServiceQuotaExceededException);
    exports2.ServiceUnavailableException$ = [
      -3,
      n032,
      _SUE,
      { [_e32]: _se14 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ServiceUnavailableException$, errors_1.ServiceUnavailableException);
    exports2.SessionStreamingException$ = [
      -3,
      n032,
      _SSE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.SessionStreamingException$, errors_1.SessionStreamingException);
    exports2.SessionTimeoutException$ = [
      -3,
      n032,
      _STE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.SessionTimeoutException$, errors_1.SessionTimeoutException);
    exports2.ThrottlingException$ = [
      -3,
      n032,
      _TE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ThrottlingException$, errors_1.ThrottlingException);
    exports2.TooManyTagsException$ = [
      -3,
      n032,
      _TMTE,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29, _rN10],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.TooManyTagsException$, errors_1.TooManyTagsException);
    exports2.UnrecognizedClientException$ = [
      -3,
      n032,
      _UCE4,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.UnrecognizedClientException$, errors_1.UnrecognizedClientException);
    exports2.ValidationException$ = [
      -3,
      n032,
      _VE10,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ValidationException$, errors_1.ValidationException);
    exports2.errorTypeRegistries = [
      _s_registry32,
      n0_registry32
    ];
    exports2.AccountPolicy$ = [
      3,
      n032,
      _AP,
      0,
      [_pN, _pD, _lUT, _pT, _sc4, _sC, _aI10],
      [0, 0, 1, 0, 0, 0, 0]
    ];
    exports2.AddKeyEntry$ = [
      3,
      n032,
      _AKE,
      0,
      [_k, _v, _oIE],
      [0, 0, 2],
      2
    ];
    exports2.AddKeys$ = [
      3,
      n032,
      _AK,
      0,
      [_en],
      [() => AddKeyEntries],
      1
    ];
    exports2.AggregateLogGroupSummary$ = [
      3,
      n032,
      _ALGS,
      0,
      [_lGC, _gI],
      [1, () => GroupingIdentifiers]
    ];
    exports2.Anomaly$ = [
      3,
      n032,
      _A10,
      0,
      [_aIn, _pI, _aDA, _pS, _fS, _lS, _d, _a10, _st, _h22, _lSo, _pTa, _lGAL, _pR, _p, _su, _sD, _sU, _iPLS],
      [0, 0, 0, 0, 1, 1, 0, 2, 0, 128 | 1, () => LogSamples, () => PatternTokens, 64 | 0, 0, 0, 2, 1, 1, 2],
      13
    ];
    exports2.AnomalyDetector$ = [
      3,
      n032,
      _AD,
      0,
      [_aDA, _dN, _lGAL, _eF, _fP, _aDS, _kKI, _cTS, _lMTS, _aVT],
      [0, 0, 64 | 0, 0, 0, 0, 0, 1, 1, 1]
    ];
    exports2.AssociateKmsKeyRequest$ = [
      3,
      n032,
      _AKKR,
      0,
      [_kKI, _lGN, _rI],
      [0, 0, 0],
      1
    ];
    exports2.AssociateSourceToS3TableIntegrationRequest$ = [
      3,
      n032,
      _ASTSTIR,
      0,
      [_iA, _dS],
      [0, () => exports2.DataSource$],
      2
    ];
    exports2.AssociateSourceToS3TableIntegrationResponse$ = [
      3,
      n032,
      _ASTSTIRs,
      0,
      [_i],
      [0]
    ];
    exports2.CancelExportTaskRequest$ = [
      3,
      n032,
      _CETR,
      0,
      [_tI10],
      [0],
      1
    ];
    exports2.CancelImportTaskRequest$ = [
      3,
      n032,
      _CITR,
      0,
      [_iI],
      [0],
      1
    ];
    exports2.CancelImportTaskResponse$ = [
      3,
      n032,
      _CITRa,
      0,
      [_iI, _iS, _iSm, _cT, _lUT],
      [0, () => exports2.ImportStatistics$, 0, 1, 1]
    ];
    exports2.ConfigurationTemplate$ = [
      3,
      n032,
      _CT4,
      0,
      [_ser, _lT, _rT13, _dDT, _dDCV, _aF, _aOF, _aAFAVLDFR, _aFD, _aSPF],
      [0, 0, 0, 0, () => exports2.ConfigurationTemplateDeliveryConfigValues$, () => AllowedFields, 64 | 0, 0, 64 | 0, 64 | 0]
    ];
    exports2.ConfigurationTemplateDeliveryConfigValues$ = [
      3,
      n032,
      _CTDCV,
      0,
      [_rF, _fD, _sDC],
      [64 | 0, 0, () => exports2.S3DeliveryConfiguration$]
    ];
    exports2.CopyValue$ = [
      3,
      n032,
      _CV4,
      0,
      [_en],
      [() => CopyValueEntries],
      1
    ];
    exports2.CopyValueEntry$ = [
      3,
      n032,
      _CVE,
      0,
      [_so, _t, _oIE],
      [0, 0, 2],
      2
    ];
    exports2.CreateDeliveryRequest$ = [
      3,
      n032,
      _CDR,
      0,
      [_dSN, _dDA, _rF, _fD, _sDC, _ta],
      [0, 0, 64 | 0, 0, () => exports2.S3DeliveryConfiguration$, 128 | 0],
      2
    ];
    exports2.CreateDeliveryResponse$ = [
      3,
      n032,
      _CDRr,
      0,
      [_de],
      [() => exports2.Delivery$]
    ];
    exports2.CreateExportTaskRequest$ = [
      3,
      n032,
      _CETRr,
      0,
      [_lGN, _f, _to, _des, _tN, _lSNP, _dP],
      [0, 1, 1, 0, 0, 0, 0],
      4
    ];
    exports2.CreateExportTaskResponse$ = [
      3,
      n032,
      _CETRre,
      0,
      [_tI10],
      [0]
    ];
    exports2.CreateImportTaskRequest$ = [
      3,
      n032,
      _CITRr,
      0,
      [_iSA, _iRA, _iF],
      [0, 0, () => exports2.ImportFilter$],
      2
    ];
    exports2.CreateImportTaskResponse$ = [
      3,
      n032,
      _CITRre,
      0,
      [_iI, _iDA, _cT],
      [0, 0, 1]
    ];
    exports2.CreateLogAnomalyDetectorRequest$ = [
      3,
      n032,
      _CLADR,
      0,
      [_lGAL, _dN, _eF, _fP, _kKI, _aVT, _ta],
      [64 | 0, 0, 0, 0, 0, 1, 128 | 0],
      1
    ];
    exports2.CreateLogAnomalyDetectorResponse$ = [
      3,
      n032,
      _CLADRr,
      0,
      [_aDA],
      [0]
    ];
    exports2.CreateLogGroupRequest$ = [
      3,
      n032,
      _CLGR,
      0,
      [_lGN, _kKI, _ta, _lGCo, _dPE],
      [0, 0, 128 | 0, 0, 2],
      1
    ];
    exports2.CreateLogStreamRequest$ = [
      3,
      n032,
      _CLSR,
      0,
      [_lGN, _lSN],
      [0, 0],
      2
    ];
    exports2.CreateLookupTableRequest$ = [
      3,
      n032,
      _CLTR,
      0,
      [_lTN, _tB, _d, _kKI, _ta],
      [0, 0, 0, 0, 128 | 0],
      2
    ];
    exports2.CreateLookupTableResponse$ = [
      3,
      n032,
      _CLTRr,
      0,
      [_lTA, _cA],
      [0, 1]
    ];
    exports2.CreateScheduledQueryRequest$ = [
      3,
      n032,
      _CSQR,
      0,
      [_n, _qL, _qS, _sE, _eRA, _d, _lGI, _ti, _sTO, _dC4, _sST, _sET, _st, _ta],
      [0, 0, 0, 0, 0, 0, 64 | 0, 0, 1, () => exports2.DestinationConfiguration$, 1, 1, 0, 128 | 0],
      5
    ];
    exports2.CreateScheduledQueryResponse$ = [
      3,
      n032,
      _CSQRr,
      0,
      [_sQA, _st],
      [0, 0]
    ];
    exports2.CSV$ = [
      3,
      n032,
      _CSV,
      0,
      [_qC, _del, _co13, _so, _des],
      [0, 0, 64 | 0, 0, 0]
    ];
    exports2.DataSource$ = [
      3,
      n032,
      _DS10,
      0,
      [_n, _ty],
      [0, 0],
      1
    ];
    exports2.DataSourceFilter$ = [
      3,
      n032,
      _DSF,
      0,
      [_n, _ty],
      [0, 0],
      1
    ];
    exports2.DateTimeConverter$ = [
      3,
      n032,
      _DTC,
      0,
      [_so, _t, _mP, _tF, _sT19, _tT13, _l],
      [0, 0, 64 | 0, 0, 0, 0, 0],
      3
    ];
    exports2.DeleteAccountPolicyRequest$ = [
      3,
      n032,
      _DAPR,
      0,
      [_pN, _pT],
      [0, 0],
      2
    ];
    exports2.DeleteDataProtectionPolicyRequest$ = [
      3,
      n032,
      _DDPPR,
      0,
      [_lGIo],
      [0],
      1
    ];
    exports2.DeleteDeliveryDestinationPolicyRequest$ = [
      3,
      n032,
      _DDDPR,
      0,
      [_dDN],
      [0],
      1
    ];
    exports2.DeleteDeliveryDestinationRequest$ = [
      3,
      n032,
      _DDDR,
      0,
      [_n],
      [0],
      1
    ];
    exports2.DeleteDeliveryRequest$ = [
      3,
      n032,
      _DDR,
      0,
      [_id],
      [0],
      1
    ];
    exports2.DeleteDeliverySourceRequest$ = [
      3,
      n032,
      _DDSR,
      0,
      [_n],
      [0],
      1
    ];
    exports2.DeleteDestinationRequest$ = [
      3,
      n032,
      _DDRe,
      0,
      [_dNe],
      [0],
      1
    ];
    exports2.DeleteIndexPolicyRequest$ = [
      3,
      n032,
      _DIPR,
      0,
      [_lGIo],
      [0],
      1
    ];
    exports2.DeleteIndexPolicyResponse$ = [
      3,
      n032,
      _DIPRe,
      0,
      [],
      []
    ];
    exports2.DeleteIntegrationRequest$ = [
      3,
      n032,
      _DIR,
      0,
      [_iN, _fo],
      [0, 2],
      1
    ];
    exports2.DeleteIntegrationResponse$ = [
      3,
      n032,
      _DIRe,
      0,
      [],
      []
    ];
    exports2.DeleteKeys$ = [
      3,
      n032,
      _DK,
      0,
      [_wK],
      [64 | 0],
      1
    ];
    exports2.DeleteLogAnomalyDetectorRequest$ = [
      3,
      n032,
      _DLADR,
      0,
      [_aDA],
      [0],
      1
    ];
    exports2.DeleteLogGroupRequest$ = [
      3,
      n032,
      _DLGR,
      0,
      [_lGN],
      [0],
      1
    ];
    exports2.DeleteLogStreamRequest$ = [
      3,
      n032,
      _DLSR,
      0,
      [_lGN, _lSN],
      [0, 0],
      2
    ];
    exports2.DeleteLookupTableRequest$ = [
      3,
      n032,
      _DLTR,
      0,
      [_lTA],
      [0],
      1
    ];
    exports2.DeleteMetricFilterRequest$ = [
      3,
      n032,
      _DMFR,
      0,
      [_lGN, _fN],
      [0, 0],
      2
    ];
    exports2.DeleteQueryDefinitionRequest$ = [
      3,
      n032,
      _DQDR,
      0,
      [_qDI],
      [0],
      1
    ];
    exports2.DeleteQueryDefinitionResponse$ = [
      3,
      n032,
      _DQDRe,
      0,
      [_suc],
      [2]
    ];
    exports2.DeleteResourcePolicyRequest$ = [
      3,
      n032,
      _DRPR,
      0,
      [_pN, _rA, _eRI],
      [0, 0, 0]
    ];
    exports2.DeleteRetentionPolicyRequest$ = [
      3,
      n032,
      _DRPRe,
      0,
      [_lGN],
      [0],
      1
    ];
    exports2.DeleteScheduledQueryRequest$ = [
      3,
      n032,
      _DSQR,
      0,
      [_i],
      [0],
      1
    ];
    exports2.DeleteScheduledQueryResponse$ = [
      3,
      n032,
      _DSQRe,
      0,
      [],
      []
    ];
    exports2.DeleteSubscriptionFilterRequest$ = [
      3,
      n032,
      _DSFR,
      0,
      [_lGN, _fN],
      [0, 0],
      2
    ];
    exports2.DeleteTransformerRequest$ = [
      3,
      n032,
      _DTR,
      0,
      [_lGIo],
      [0],
      1
    ];
    exports2.Delivery$ = [
      3,
      n032,
      _D,
      0,
      [_id, _ar, _dSN, _dDA, _dDT, _rF, _fD, _sDC, _ta],
      [0, 0, 0, 0, 0, 64 | 0, 0, () => exports2.S3DeliveryConfiguration$, 128 | 0]
    ];
    exports2.DeliveryDestination$ = [
      3,
      n032,
      _DD,
      0,
      [_n, _ar, _dDT, _oF, _dDC, _ta],
      [0, 0, 0, 0, () => exports2.DeliveryDestinationConfiguration$, 128 | 0]
    ];
    exports2.DeliveryDestinationConfiguration$ = [
      3,
      n032,
      _DDC,
      0,
      [_dRA],
      [0],
      1
    ];
    exports2.DeliverySource$ = [
      3,
      n032,
      _DSe,
      0,
      [_n, _ar, _rAe, _ser, _lT, _ta],
      [0, 0, 64 | 0, 0, 0, 128 | 0]
    ];
    exports2.DescribeAccountPoliciesRequest$ = [
      3,
      n032,
      _DAPRe,
      0,
      [_pT, _pN, _aIc, _nT],
      [0, 0, 64 | 0, 0],
      1
    ];
    exports2.DescribeAccountPoliciesResponse$ = [
      3,
      n032,
      _DAPRes,
      0,
      [_aP, _nT],
      [() => AccountPolicies, 0]
    ];
    exports2.DescribeConfigurationTemplatesRequest$ = [
      3,
      n032,
      _DCTR,
      0,
      [_ser, _lTo, _rTe, _dDTe, _nT, _li],
      [0, 64 | 0, 64 | 0, 64 | 0, 0, 1]
    ];
    exports2.DescribeConfigurationTemplatesResponse$ = [
      3,
      n032,
      _DCTRe,
      0,
      [_cTo, _nT],
      [() => ConfigurationTemplates, 0]
    ];
    exports2.DescribeDeliveriesRequest$ = [
      3,
      n032,
      _DDRes,
      0,
      [_nT, _li],
      [0, 1]
    ];
    exports2.DescribeDeliveriesResponse$ = [
      3,
      n032,
      _DDResc,
      0,
      [_deli, _nT],
      [() => Deliveries, 0]
    ];
    exports2.DescribeDeliveryDestinationsRequest$ = [
      3,
      n032,
      _DDDRe,
      0,
      [_nT, _li],
      [0, 1]
    ];
    exports2.DescribeDeliveryDestinationsResponse$ = [
      3,
      n032,
      _DDDRes,
      0,
      [_dD, _nT],
      [() => DeliveryDestinations, 0]
    ];
    exports2.DescribeDeliverySourcesRequest$ = [
      3,
      n032,
      _DDSRe,
      0,
      [_nT, _li],
      [0, 1]
    ];
    exports2.DescribeDeliverySourcesResponse$ = [
      3,
      n032,
      _DDSRes,
      0,
      [_dSe, _nT],
      [() => DeliverySources, 0]
    ];
    exports2.DescribeDestinationsRequest$ = [
      3,
      n032,
      _DDRescr,
      0,
      [_DNP, _nT, _li],
      [0, 0, 1]
    ];
    exports2.DescribeDestinationsResponse$ = [
      3,
      n032,
      _DDRescri,
      0,
      [_dest, _nT],
      [() => Destinations, 0]
    ];
    exports2.DescribeExportTasksRequest$ = [
      3,
      n032,
      _DETR,
      0,
      [_tI10, _sCt, _nT, _li],
      [0, 0, 0, 1]
    ];
    exports2.DescribeExportTasksResponse$ = [
      3,
      n032,
      _DETRe,
      0,
      [_eT, _nT],
      [() => ExportTasks, 0]
    ];
    exports2.DescribeFieldIndexesRequest$ = [
      3,
      n032,
      _DFIR,
      0,
      [_lGI, _nT],
      [64 | 0, 0],
      1
    ];
    exports2.DescribeFieldIndexesResponse$ = [
      3,
      n032,
      _DFIRe,
      0,
      [_fI, _nT],
      [() => FieldIndexes, 0]
    ];
    exports2.DescribeImportTaskBatchesRequest$ = [
      3,
      n032,
      _DITBR,
      0,
      [_iI, _bIS, _li, _nT],
      [0, 64 | 0, 1, 0],
      1
    ];
    exports2.DescribeImportTaskBatchesResponse$ = [
      3,
      n032,
      _DITBRe,
      0,
      [_iSA, _iI, _iB, _nT],
      [0, 0, () => ImportBatchList, 0]
    ];
    exports2.DescribeImportTasksRequest$ = [
      3,
      n032,
      _DITR,
      0,
      [_iI, _iSm, _iSA, _li, _nT],
      [0, 0, 0, 1, 0]
    ];
    exports2.DescribeImportTasksResponse$ = [
      3,
      n032,
      _DITRe,
      0,
      [_im, _nT],
      [() => ImportList, 0]
    ];
    exports2.DescribeIndexPoliciesRequest$ = [
      3,
      n032,
      _DIPRes,
      0,
      [_lGI, _nT],
      [64 | 0, 0],
      1
    ];
    exports2.DescribeIndexPoliciesResponse$ = [
      3,
      n032,
      _DIPResc,
      0,
      [_iP, _nT],
      [() => IndexPolicies, 0]
    ];
    exports2.DescribeLogGroupsRequest$ = [
      3,
      n032,
      _DLGRe,
      0,
      [_aIc, _lGNP, _lGNPo, _nT, _li, _iLA, _lGCo, _lGI],
      [64 | 0, 0, 0, 0, 1, 2, 0, 64 | 0]
    ];
    exports2.DescribeLogGroupsResponse$ = [
      3,
      n032,
      _DLGRes,
      0,
      [_lG, _nT],
      [() => LogGroups, 0]
    ];
    exports2.DescribeLogStreamsRequest$ = [
      3,
      n032,
      _DLSRe,
      0,
      [_lGN, _lGIo, _lSNP, _oB, _desc, _nT, _li],
      [0, 0, 0, 0, 2, 0, 1]
    ];
    exports2.DescribeLogStreamsResponse$ = [
      3,
      n032,
      _DLSRes,
      0,
      [_lSog, _nT],
      [() => LogStreams, 0]
    ];
    exports2.DescribeLookupTablesRequest$ = [
      3,
      n032,
      _DLTRe,
      0,
      [_lTNP, _mR, _nT],
      [0, 1, 0]
    ];
    exports2.DescribeLookupTablesResponse$ = [
      3,
      n032,
      _DLTRes,
      0,
      [_lToo, _nT],
      [() => LookupTables, 0]
    ];
    exports2.DescribeMetricFiltersRequest$ = [
      3,
      n032,
      _DMFRe,
      0,
      [_lGN, _fNP, _nT, _li, _mN, _mNe],
      [0, 0, 0, 1, 0, 0]
    ];
    exports2.DescribeMetricFiltersResponse$ = [
      3,
      n032,
      _DMFRes,
      0,
      [_mF, _nT],
      [() => MetricFilters, 0]
    ];
    exports2.DescribeQueriesRequest$ = [
      3,
      n032,
      _DQR,
      0,
      [_lGN, _sta, _mR, _nT, _qL],
      [0, 0, 1, 0, 0]
    ];
    exports2.DescribeQueriesResponse$ = [
      3,
      n032,
      _DQRe,
      0,
      [_q, _nT],
      [() => QueryInfoList, 0]
    ];
    exports2.DescribeQueryDefinitionsRequest$ = [
      3,
      n032,
      _DQDRes,
      0,
      [_qL, _qDNP, _mR, _nT],
      [0, 0, 1, 0]
    ];
    exports2.DescribeQueryDefinitionsResponse$ = [
      3,
      n032,
      _DQDResc,
      0,
      [_qD, _nT],
      [() => QueryDefinitionList, 0]
    ];
    exports2.DescribeResourcePoliciesRequest$ = [
      3,
      n032,
      _DRPRes,
      0,
      [_nT, _li, _rA, _pSo],
      [0, 1, 0, 0]
    ];
    exports2.DescribeResourcePoliciesResponse$ = [
      3,
      n032,
      _DRPResc,
      0,
      [_rP, _nT],
      [() => ResourcePolicies, 0]
    ];
    exports2.DescribeSubscriptionFiltersRequest$ = [
      3,
      n032,
      _DSFRe,
      0,
      [_lGN, _fNP, _nT, _li],
      [0, 0, 0, 1],
      1
    ];
    exports2.DescribeSubscriptionFiltersResponse$ = [
      3,
      n032,
      _DSFRes,
      0,
      [_sF, _nT],
      [() => SubscriptionFilters, 0]
    ];
    exports2.Destination$ = [
      3,
      n032,
      _De,
      0,
      [_dNe, _tA, _rAo, _aPc, _ar, _cT],
      [0, 0, 0, 0, 0, 1]
    ];
    exports2.DestinationConfiguration$ = [
      3,
      n032,
      _DC,
      0,
      [_sCo],
      [() => exports2.S3Configuration$],
      1
    ];
    exports2.DisassociateKmsKeyRequest$ = [
      3,
      n032,
      _DKKR,
      0,
      [_lGN, _rI],
      [0, 0]
    ];
    exports2.DisassociateSourceFromS3TableIntegrationRequest$ = [
      3,
      n032,
      _DSFSTIR,
      0,
      [_i],
      [0],
      1
    ];
    exports2.DisassociateSourceFromS3TableIntegrationResponse$ = [
      3,
      n032,
      _DSFSTIRi,
      0,
      [_i],
      [0]
    ];
    exports2.Entity$ = [
      3,
      n032,
      _E11,
      0,
      [_kA, _at],
      [128 | 0, 128 | 0]
    ];
    exports2.ExportTask$ = [
      3,
      n032,
      _ET,
      0,
      [_tI10, _tN, _lGN, _f, _to, _des, _dP, _sta, _eI13],
      [0, 0, 0, 1, 1, 0, 0, () => exports2.ExportTaskStatus$, () => exports2.ExportTaskExecutionInfo$]
    ];
    exports2.ExportTaskExecutionInfo$ = [
      3,
      n032,
      _ETEI,
      0,
      [_cT, _cTom],
      [1, 1]
    ];
    exports2.ExportTaskStatus$ = [
      3,
      n032,
      _ETS,
      0,
      [_cod, _m29],
      [0, 0]
    ];
    exports2.FieldIndex$ = [
      3,
      n032,
      _FI,
      0,
      [_lGIo, _fIN, _lST, _fET, _lET, _ty],
      [0, 0, 1, 1, 1, 0]
    ];
    exports2.FieldsData$ = [
      3,
      n032,
      _FD,
      0,
      [_da],
      [21]
    ];
    exports2.FilteredLogEvent$ = [
      3,
      n032,
      _FLE,
      0,
      [_lSN, _tim, _m29, _iT13, _eIv],
      [0, 1, 0, 1, 0]
    ];
    exports2.FilterLogEventsRequest$ = [
      3,
      n032,
      _FLER,
      0,
      [_lGN, _lGIo, _lSNo, _lSNP, _sTt, _eTn, _fP, _nT, _li, _in, _u],
      [0, 0, 64 | 0, 0, 1, 1, 0, 0, 1, 2, 2]
    ];
    exports2.FilterLogEventsResponse$ = [
      3,
      n032,
      _FLERi,
      0,
      [_ev, _sLS, _nT],
      [() => FilteredLogEvents, () => SearchedLogStreams, 0]
    ];
    exports2.GetDataProtectionPolicyRequest$ = [
      3,
      n032,
      _GDPPR,
      0,
      [_lGIo],
      [0],
      1
    ];
    exports2.GetDataProtectionPolicyResponse$ = [
      3,
      n032,
      _GDPPRe,
      0,
      [_lGIo, _pD, _lUT],
      [0, 0, 1]
    ];
    exports2.GetDeliveryDestinationPolicyRequest$ = [
      3,
      n032,
      _GDDPR,
      0,
      [_dDN],
      [0],
      1
    ];
    exports2.GetDeliveryDestinationPolicyResponse$ = [
      3,
      n032,
      _GDDPRe,
      0,
      [_po],
      [() => exports2.Policy$]
    ];
    exports2.GetDeliveryDestinationRequest$ = [
      3,
      n032,
      _GDDR,
      0,
      [_n],
      [0],
      1
    ];
    exports2.GetDeliveryDestinationResponse$ = [
      3,
      n032,
      _GDDRe,
      0,
      [_dDe],
      [() => exports2.DeliveryDestination$]
    ];
    exports2.GetDeliveryRequest$ = [
      3,
      n032,
      _GDR,
      0,
      [_id],
      [0],
      1
    ];
    exports2.GetDeliveryResponse$ = [
      3,
      n032,
      _GDRe,
      0,
      [_de],
      [() => exports2.Delivery$]
    ];
    exports2.GetDeliverySourceRequest$ = [
      3,
      n032,
      _GDSR,
      0,
      [_n],
      [0],
      1
    ];
    exports2.GetDeliverySourceResponse$ = [
      3,
      n032,
      _GDSRe,
      0,
      [_dSel],
      [() => exports2.DeliverySource$]
    ];
    exports2.GetIntegrationRequest$ = [
      3,
      n032,
      _GIR2,
      0,
      [_iN],
      [0],
      1
    ];
    exports2.GetIntegrationResponse$ = [
      3,
      n032,
      _GIRe,
      0,
      [_iN, _iTn, _iSn, _iD],
      [0, 0, 0, () => exports2.IntegrationDetails$]
    ];
    exports2.GetLogAnomalyDetectorRequest$ = [
      3,
      n032,
      _GLADR,
      0,
      [_aDA],
      [0],
      1
    ];
    exports2.GetLogAnomalyDetectorResponse$ = [
      3,
      n032,
      _GLADRe,
      0,
      [_dN, _lGAL, _eF, _fP, _aDS, _kKI, _cTS, _lMTS, _aVT],
      [0, 64 | 0, 0, 0, 0, 0, 1, 1, 1]
    ];
    exports2.GetLogEventsRequest$ = [
      3,
      n032,
      _GLER,
      0,
      [_lSN, _lGN, _lGIo, _sTt, _eTn, _nT, _li, _sFH, _u],
      [0, 0, 0, 1, 1, 0, 1, 2, 2],
      1
    ];
    exports2.GetLogEventsResponse$ = [
      3,
      n032,
      _GLERe,
      0,
      [_ev, _nFT, _nBT],
      [() => OutputLogEvents, 0, 0]
    ];
    exports2.GetLogFieldsRequest$ = [
      3,
      n032,
      _GLFR,
      0,
      [_dSNa, _dST],
      [0, 0],
      2
    ];
    exports2.GetLogFieldsResponse$ = [
      3,
      n032,
      _GLFRe,
      0,
      [_lF],
      [() => LogFieldsList]
    ];
    exports2.GetLogGroupFieldsRequest$ = [
      3,
      n032,
      _GLGFR,
      0,
      [_lGN, _time, _lGIo],
      [0, 1, 0]
    ];
    exports2.GetLogGroupFieldsResponse$ = [
      3,
      n032,
      _GLGFRe,
      0,
      [_lGF],
      [() => LogGroupFieldList]
    ];
    exports2.GetLogObjectRequest$ = [
      3,
      n032,
      _GLOR,
      0,
      [_lOP, _u],
      [0, 2],
      1
    ];
    exports2.GetLogObjectResponse$ = [
      3,
      n032,
      _GLORe,
      0,
      [_fSi],
      [[() => exports2.GetLogObjectResponseStream$, 0]]
    ];
    exports2.GetLogRecordRequest$ = [
      3,
      n032,
      _GLRR,
      0,
      [_lRP, _u],
      [0, 2],
      1
    ];
    exports2.GetLogRecordResponse$ = [
      3,
      n032,
      _GLRRe,
      0,
      [_lR],
      [128 | 0]
    ];
    exports2.GetLookupTableRequest$ = [
      3,
      n032,
      _GLTR,
      0,
      [_lTA],
      [0],
      1
    ];
    exports2.GetLookupTableResponse$ = [
      3,
      n032,
      _GLTRe,
      0,
      [_lTA, _lTN, _d, _tB, _sB, _lUT, _kKI],
      [0, 0, 0, 0, 1, 1, 0]
    ];
    exports2.GetQueryResultsRequest$ = [
      3,
      n032,
      _GQRR,
      0,
      [_qI],
      [0],
      1
    ];
    exports2.GetQueryResultsResponse$ = [
      3,
      n032,
      _GQRRe,
      0,
      [_qL, _r4, _stat, _sta, _eK],
      [0, () => QueryResults, () => exports2.QueryStatistics$, 0, 0]
    ];
    exports2.GetScheduledQueryHistoryRequest$ = [
      3,
      n032,
      _GSQHR,
      0,
      [_i, _sTt, _eTn, _eS, _mR, _nT],
      [0, 1, 1, 64 | 0, 1, 0],
      3
    ];
    exports2.GetScheduledQueryHistoryResponse$ = [
      3,
      n032,
      _GSQHRe,
      0,
      [_n, _sQA, _tH, _nT],
      [0, 0, () => TriggerHistoryRecordList, 0]
    ];
    exports2.GetScheduledQueryRequest$ = [
      3,
      n032,
      _GSQR,
      0,
      [_i],
      [0],
      1
    ];
    exports2.GetScheduledQueryResponse$ = [
      3,
      n032,
      _GSQRe,
      0,
      [_sQA, _n, _d, _qL, _qS, _lGI, _sE, _ti, _sTO, _dC4, _st, _lTT, _lES, _sST, _sET, _eRA, _cT, _lUT],
      [0, 0, 0, 0, 0, 64 | 0, 0, 0, 1, () => exports2.DestinationConfiguration$, 0, 1, 0, 1, 1, 0, 1, 1]
    ];
    exports2.GetTransformerRequest$ = [
      3,
      n032,
      _GTR,
      0,
      [_lGIo],
      [0],
      1
    ];
    exports2.GetTransformerResponse$ = [
      3,
      n032,
      _GTRe,
      0,
      [_lGIo, _cT, _lMT, _tC],
      [0, 1, 1, () => Processors]
    ];
    exports2.Grok$ = [
      3,
      n032,
      _G,
      0,
      [_ma, _so],
      [0, 0],
      1
    ];
    exports2.GroupingIdentifier$ = [
      3,
      n032,
      _GI2,
      0,
      [_k, _v],
      [0, 0]
    ];
    exports2.Import$ = [
      3,
      n032,
      _I,
      0,
      [_iI, _iSA, _iSm, _iDA, _iS, _iF, _cT, _lUT, _eM],
      [0, 0, 0, 0, () => exports2.ImportStatistics$, () => exports2.ImportFilter$, 1, 1, 0]
    ];
    exports2.ImportBatch$ = [
      3,
      n032,
      _IB,
      0,
      [_bI, _sta, _eM],
      [0, 0, 0],
      2
    ];
    exports2.ImportFilter$ = [
      3,
      n032,
      _IF,
      0,
      [_sETt, _eET],
      [1, 1]
    ];
    exports2.ImportStatistics$ = [
      3,
      n032,
      _IS,
      0,
      [_bIy],
      [1]
    ];
    exports2.IndexPolicy$ = [
      3,
      n032,
      _IP,
      0,
      [_lGIo, _lUTa, _pD, _pN, _so],
      [0, 1, 0, 0, 0]
    ];
    exports2.InputLogEvent$ = [
      3,
      n032,
      _ILE,
      0,
      [_tim, _m29],
      [1, 0],
      2
    ];
    exports2.IntegrationSummary$ = [
      3,
      n032,
      _ISn,
      0,
      [_iN, _iTn, _iSn],
      [0, 0, 0]
    ];
    exports2.ListAggregateLogGroupSummariesRequest$ = [
      3,
      n032,
      _LALGSR,
      0,
      [_gB, _aIc, _iLA, _lGCo, _lGNPo, _dSa, _nT, _li],
      [0, 64 | 0, 2, 0, 0, () => DataSourceFilters, 0, 1],
      1
    ];
    exports2.ListAggregateLogGroupSummariesResponse$ = [
      3,
      n032,
      _LALGSRi,
      0,
      [_aLGS, _nT],
      [() => AggregateLogGroupSummaries, 0]
    ];
    exports2.ListAnomaliesRequest$ = [
      3,
      n032,
      _LAR,
      0,
      [_aDA, _sS, _li, _nT],
      [0, 0, 1, 0]
    ];
    exports2.ListAnomaliesResponse$ = [
      3,
      n032,
      _LARi,
      0,
      [_an, _nT],
      [() => Anomalies, 0]
    ];
    exports2.ListIntegrationsRequest$ = [
      3,
      n032,
      _LIR,
      0,
      [_iNP, _iTn, _iSn],
      [0, 0, 0]
    ];
    exports2.ListIntegrationsResponse$ = [
      3,
      n032,
      _LIRi,
      0,
      [_iSnt],
      [() => IntegrationSummaries]
    ];
    exports2.ListLogAnomalyDetectorsRequest$ = [
      3,
      n032,
      _LLADR,
      0,
      [_fLGA, _li, _nT],
      [0, 1, 0]
    ];
    exports2.ListLogAnomalyDetectorsResponse$ = [
      3,
      n032,
      _LLADRi,
      0,
      [_aD, _nT],
      [() => AnomalyDetectors, 0]
    ];
    exports2.ListLogGroupsForQueryRequest$ = [
      3,
      n032,
      _LLGFQR,
      0,
      [_qI, _nT, _mR],
      [0, 0, 1],
      1
    ];
    exports2.ListLogGroupsForQueryResponse$ = [
      3,
      n032,
      _LLGFQRi,
      0,
      [_lGI, _nT],
      [64 | 0, 0]
    ];
    exports2.ListLogGroupsRequest$ = [
      3,
      n032,
      _LLGR,
      0,
      [_lGNPo, _lGCo, _iLA, _aIc, _nT, _li, _dSa, _fINi],
      [0, 0, 2, 64 | 0, 0, 1, () => DataSourceFilters, 64 | 0]
    ];
    exports2.ListLogGroupsResponse$ = [
      3,
      n032,
      _LLGRi,
      0,
      [_lG, _nT],
      [() => LogGroupSummaries, 0]
    ];
    exports2.ListScheduledQueriesRequest$ = [
      3,
      n032,
      _LSQR,
      0,
      [_mR, _nT, _st],
      [1, 0, 0]
    ];
    exports2.ListScheduledQueriesResponse$ = [
      3,
      n032,
      _LSQRi,
      0,
      [_nT, _sQ],
      [0, () => ScheduledQuerySummaryList]
    ];
    exports2.ListSourcesForS3TableIntegrationRequest$ = [
      3,
      n032,
      _LSFSTIR,
      0,
      [_iA, _mR, _nT],
      [0, 1, 0],
      1
    ];
    exports2.ListSourcesForS3TableIntegrationResponse$ = [
      3,
      n032,
      _LSFSTIRi,
      0,
      [_sou, _nT],
      [() => S3TableIntegrationSources, 0]
    ];
    exports2.ListTagsForResourceRequest$ = [
      3,
      n032,
      _LTFRR,
      0,
      [_rA],
      [0],
      1
    ];
    exports2.ListTagsForResourceResponse$ = [
      3,
      n032,
      _LTFRRi,
      0,
      [_ta],
      [128 | 0]
    ];
    exports2.ListTagsLogGroupRequest$ = [
      3,
      n032,
      _LTLGR,
      0,
      [_lGN],
      [0],
      1
    ];
    exports2.ListTagsLogGroupResponse$ = [
      3,
      n032,
      _LTLGRi,
      0,
      [_ta],
      [128 | 0]
    ];
    exports2.ListToMap$ = [
      3,
      n032,
      _LTM,
      0,
      [_so, _k, _vK, _t, _fl, _fE],
      [0, 0, 0, 0, 2, 0],
      2
    ];
    exports2.LiveTailSessionLogEvent$ = [
      3,
      n032,
      _LTSLE,
      0,
      [_lSN, _lGIo, _m29, _tim, _iT13],
      [0, 0, 0, 1, 1]
    ];
    exports2.LiveTailSessionMetadata$ = [
      3,
      n032,
      _LTSM,
      0,
      [_sa],
      [2]
    ];
    exports2.LiveTailSessionStart$ = [
      3,
      n032,
      _LTSS,
      0,
      [_rIe, _sI, _lGI, _lSNo, _lSNPo, _lEFP],
      [0, 0, 64 | 0, 64 | 0, 64 | 0, 0]
    ];
    exports2.LiveTailSessionUpdate$ = [
      3,
      n032,
      _LTSU,
      0,
      [_sM, _sR],
      [() => exports2.LiveTailSessionMetadata$, () => LiveTailSessionResults]
    ];
    exports2.LogEvent$ = [
      3,
      n032,
      _LE,
      0,
      [_tim, _m29],
      [1, 0]
    ];
    exports2.LogFieldsListItem$ = [
      3,
      n032,
      _LFLI,
      0,
      [_lFN, _lFT],
      [0, () => exports2.LogFieldType$]
    ];
    exports2.LogFieldType$ = [
      3,
      n032,
      _LFT,
      0,
      [_ty, _el, _fi],
      [0, () => exports2.LogFieldType$, () => LogFieldsList]
    ];
    exports2.LogGroup$ = [
      3,
      n032,
      _LG,
      0,
      [_lGN, _cT, _rID, _mFC, _ar, _sBt, _kKI, _dPS, _iPn, _lGCo, _lGA, _dPE, _bTAE],
      [0, 1, 1, 1, 0, 1, 0, 0, 64 | 0, 0, 0, 2, 2]
    ];
    exports2.LogGroupField$ = [
      3,
      n032,
      _LGF,
      0,
      [_n, _pe],
      [0, 1]
    ];
    exports2.LogGroupSummary$ = [
      3,
      n032,
      _LGS,
      0,
      [_lGN, _lGA, _lGCo],
      [0, 0, 0]
    ];
    exports2.LogStream$ = [
      3,
      n032,
      _LS,
      0,
      [_lSN, _cT, _fETi, _lETa, _lIT, _uST, _ar, _sBt],
      [0, 1, 1, 1, 1, 0, 0, 1]
    ];
    exports2.LookupTable$ = [
      3,
      n032,
      _LT,
      0,
      [_lTA, _lTN, _d, _tFa, _rC10, _sB, _lUT, _kKI],
      [0, 0, 0, 64 | 0, 1, 1, 1, 0]
    ];
    exports2.LowerCaseString$ = [
      3,
      n032,
      _LCS,
      0,
      [_wK],
      [64 | 0],
      1
    ];
    exports2.MetricFilter$ = [
      3,
      n032,
      _MF,
      0,
      [_fN, _fP, _mT, _cT, _lGN, _aOTL, _fSC, _eSFD],
      [0, 0, () => MetricTransformations, 1, 0, 2, 0, 64 | 0]
    ];
    exports2.MetricFilterMatchRecord$ = [
      3,
      n032,
      _MFMR,
      0,
      [_eN, _eMv, _eV],
      [1, 0, 128 | 0]
    ];
    exports2.MetricTransformation$ = [
      3,
      n032,
      _MT,
      0,
      [_mN, _mNe, _mV, _dV, _di, _un],
      [0, 0, 0, 1, 128 | 0, 0],
      3
    ];
    exports2.MoveKeyEntry$ = [
      3,
      n032,
      _MKE,
      0,
      [_so, _t, _oIE],
      [0, 0, 2],
      2
    ];
    exports2.MoveKeys$ = [
      3,
      n032,
      _MK,
      0,
      [_en],
      [() => MoveKeyEntries],
      1
    ];
    exports2.OpenSearchApplication$ = [
      3,
      n032,
      _OSA,
      0,
      [_aE, _aA, _aIp, _sta],
      [0, 0, 0, () => exports2.OpenSearchResourceStatus$]
    ];
    exports2.OpenSearchCollection$ = [
      3,
      n032,
      _OSC,
      0,
      [_cE, _cAo, _sta],
      [0, 0, () => exports2.OpenSearchResourceStatus$]
    ];
    exports2.OpenSearchDataAccessPolicy$ = [
      3,
      n032,
      _OSDAP,
      0,
      [_pN, _sta],
      [0, () => exports2.OpenSearchResourceStatus$]
    ];
    exports2.OpenSearchDataSource$ = [
      3,
      n032,
      _OSDS,
      0,
      [_dSNa, _sta],
      [0, () => exports2.OpenSearchResourceStatus$]
    ];
    exports2.OpenSearchEncryptionPolicy$ = [
      3,
      n032,
      _OSEP,
      0,
      [_pN, _sta],
      [0, () => exports2.OpenSearchResourceStatus$]
    ];
    exports2.OpenSearchIntegrationDetails$ = [
      3,
      n032,
      _OSID,
      0,
      [_dS, _ap, _col, _w, _eP, _nP, _aPc, _lP],
      [() => exports2.OpenSearchDataSource$, () => exports2.OpenSearchApplication$, () => exports2.OpenSearchCollection$, () => exports2.OpenSearchWorkspace$, () => exports2.OpenSearchEncryptionPolicy$, () => exports2.OpenSearchNetworkPolicy$, () => exports2.OpenSearchDataAccessPolicy$, () => exports2.OpenSearchLifecyclePolicy$]
    ];
    exports2.OpenSearchLifecyclePolicy$ = [
      3,
      n032,
      _OSLP,
      0,
      [_pN, _sta],
      [0, () => exports2.OpenSearchResourceStatus$]
    ];
    exports2.OpenSearchNetworkPolicy$ = [
      3,
      n032,
      _OSNP,
      0,
      [_pN, _sta],
      [0, () => exports2.OpenSearchResourceStatus$]
    ];
    exports2.OpenSearchResourceConfig$ = [
      3,
      n032,
      _OSRC,
      0,
      [_dSRA, _dVP, _rD, _kKA, _aA],
      [0, 64 | 0, 1, 0, 0],
      3
    ];
    exports2.OpenSearchResourceStatus$ = [
      3,
      n032,
      _OSRS,
      0,
      [_sta, _sMt],
      [0, 0]
    ];
    exports2.OpenSearchWorkspace$ = [
      3,
      n032,
      _OSW,
      0,
      [_wI, _sta],
      [0, () => exports2.OpenSearchResourceStatus$]
    ];
    exports2.OutputLogEvent$ = [
      3,
      n032,
      _OLE,
      0,
      [_tim, _m29, _iT13],
      [1, 0, 1]
    ];
    exports2.ParseCloudfront$ = [
      3,
      n032,
      _PC10,
      0,
      [_so],
      [0]
    ];
    exports2.ParseJSON$ = [
      3,
      n032,
      _PJSON,
      0,
      [_so, _des],
      [0, 0]
    ];
    exports2.ParseKeyValue$ = [
      3,
      n032,
      _PKV,
      0,
      [_so, _des, _fD, _kVD, _kP, _nMV, _oIE],
      [0, 0, 0, 0, 0, 0, 2]
    ];
    exports2.ParsePostgres$ = [
      3,
      n032,
      _PP,
      0,
      [_so],
      [0]
    ];
    exports2.ParseRoute53$ = [
      3,
      n032,
      _PR,
      0,
      [_so],
      [0]
    ];
    exports2.ParseToOCSF$ = [
      3,
      n032,
      _PTOCSF,
      0,
      [_eSv, _oV, _so, _mVa],
      [0, 0, 0, 0],
      2
    ];
    exports2.ParseVPC$ = [
      3,
      n032,
      _PVPC,
      0,
      [_so],
      [0]
    ];
    exports2.ParseWAF$ = [
      3,
      n032,
      _PWAF,
      0,
      [_so],
      [0]
    ];
    exports2.PatternToken$ = [
      3,
      n032,
      _PT,
      0,
      [_dTP, _iDs, _tS, _enu, _iTN],
      [1, 2, 0, 128 | 1, 0]
    ];
    exports2.Policy$ = [
      3,
      n032,
      _P10,
      0,
      [_dDP],
      [0]
    ];
    exports2.Processor$ = [
      3,
      n032,
      _Pr10,
      0,
      [_aK, _cV13, _cs, _dTC, _dK, _g, _lTM, _lCS, _mK, _pC, _pJSON, _pKV, _pRa, _pTOCSF, _pP, _pVPC, _pWAF, _rK, _sSp, _sSu, _tSr, _tCy, _uCS],
      [() => exports2.AddKeys$, () => exports2.CopyValue$, () => exports2.CSV$, () => exports2.DateTimeConverter$, () => exports2.DeleteKeys$, () => exports2.Grok$, () => exports2.ListToMap$, () => exports2.LowerCaseString$, () => exports2.MoveKeys$, () => exports2.ParseCloudfront$, () => exports2.ParseJSON$, () => exports2.ParseKeyValue$, () => exports2.ParseRoute53$, () => exports2.ParseToOCSF$, () => exports2.ParsePostgres$, () => exports2.ParseVPC$, () => exports2.ParseWAF$, () => exports2.RenameKeys$, () => exports2.SplitString$, () => exports2.SubstituteString$, () => exports2.TrimString$, () => exports2.TypeConverter$, () => exports2.UpperCaseString$]
    ];
    exports2.PutAccountPolicyRequest$ = [
      3,
      n032,
      _PAPR,
      0,
      [_pN, _pD, _pT, _sc4, _sC],
      [0, 0, 0, 0, 0],
      3
    ];
    exports2.PutAccountPolicyResponse$ = [
      3,
      n032,
      _PAPRu,
      0,
      [_aPcc],
      [() => exports2.AccountPolicy$]
    ];
    exports2.PutBearerTokenAuthenticationRequest$ = [
      3,
      n032,
      _PBTAR,
      0,
      [_lGIo, _bTAE],
      [0, 2],
      2
    ];
    exports2.PutDataProtectionPolicyRequest$ = [
      3,
      n032,
      _PDPPR,
      0,
      [_lGIo, _pD],
      [0, 0],
      2
    ];
    exports2.PutDataProtectionPolicyResponse$ = [
      3,
      n032,
      _PDPPRu,
      0,
      [_lGIo, _pD, _lUT],
      [0, 0, 1]
    ];
    exports2.PutDeliveryDestinationPolicyRequest$ = [
      3,
      n032,
      _PDDPR,
      0,
      [_dDN, _dDP],
      [0, 0],
      2
    ];
    exports2.PutDeliveryDestinationPolicyResponse$ = [
      3,
      n032,
      _PDDPRu,
      0,
      [_po],
      [() => exports2.Policy$]
    ];
    exports2.PutDeliveryDestinationRequest$ = [
      3,
      n032,
      _PDDR,
      0,
      [_n, _oF, _dDC, _dDT, _ta],
      [0, 0, () => exports2.DeliveryDestinationConfiguration$, 0, 128 | 0],
      1
    ];
    exports2.PutDeliveryDestinationResponse$ = [
      3,
      n032,
      _PDDRu,
      0,
      [_dDe],
      [() => exports2.DeliveryDestination$]
    ];
    exports2.PutDeliverySourceRequest$ = [
      3,
      n032,
      _PDSR,
      0,
      [_n, _rA, _lT, _ta],
      [0, 0, 0, 128 | 0],
      3
    ];
    exports2.PutDeliverySourceResponse$ = [
      3,
      n032,
      _PDSRu,
      0,
      [_dSel],
      [() => exports2.DeliverySource$]
    ];
    exports2.PutDestinationPolicyRequest$ = [
      3,
      n032,
      _PDPR,
      0,
      [_dNe, _aPc, _fU],
      [0, 0, 2],
      2
    ];
    exports2.PutDestinationRequest$ = [
      3,
      n032,
      _PDR,
      0,
      [_dNe, _tA, _rAo, _ta],
      [0, 0, 0, 128 | 0],
      3
    ];
    exports2.PutDestinationResponse$ = [
      3,
      n032,
      _PDRu,
      0,
      [_des],
      [() => exports2.Destination$]
    ];
    exports2.PutIndexPolicyRequest$ = [
      3,
      n032,
      _PIPR,
      0,
      [_lGIo, _pD],
      [0, 0],
      2
    ];
    exports2.PutIndexPolicyResponse$ = [
      3,
      n032,
      _PIPRu,
      0,
      [_iPnd],
      [() => exports2.IndexPolicy$]
    ];
    exports2.PutIntegrationRequest$ = [
      3,
      n032,
      _PIR,
      0,
      [_iN, _rCe, _iTn],
      [0, () => exports2.ResourceConfig$, 0],
      3
    ];
    exports2.PutIntegrationResponse$ = [
      3,
      n032,
      _PIRu,
      0,
      [_iN, _iSn],
      [0, 0]
    ];
    exports2.PutLogEventsRequest$ = [
      3,
      n032,
      _PLER,
      0,
      [_lGN, _lSN, _lE, _sTe, _ent],
      [0, 0, () => InputLogEvents, 0, () => exports2.Entity$],
      3
    ];
    exports2.PutLogEventsResponse$ = [
      3,
      n032,
      _PLERu,
      0,
      [_nST, _rLEI, _rEI],
      [0, () => exports2.RejectedLogEventsInfo$, () => exports2.RejectedEntityInfo$]
    ];
    exports2.PutLogGroupDeletionProtectionRequest$ = [
      3,
      n032,
      _PLGDPR,
      0,
      [_lGIo, _dPE],
      [0, 2],
      2
    ];
    exports2.PutMetricFilterRequest$ = [
      3,
      n032,
      _PMFR,
      0,
      [_lGN, _fN, _fP, _mT, _aOTL, _fSC, _eSFD],
      [0, 0, 0, () => MetricTransformations, 2, 0, 64 | 0],
      4
    ];
    exports2.PutQueryDefinitionRequest$ = [
      3,
      n032,
      _PQDR,
      0,
      [_n, _qS, _qL, _qDI, _lGNo, _cTl, _pa],
      [0, 0, 0, 0, 64 | 0, [0, 4], () => QueryParameterList],
      2
    ];
    exports2.PutQueryDefinitionResponse$ = [
      3,
      n032,
      _PQDRu,
      0,
      [_qDI],
      [0]
    ];
    exports2.PutResourcePolicyRequest$ = [
      3,
      n032,
      _PRPR,
      0,
      [_pN, _pD, _rA, _eRI],
      [0, 0, 0, 0]
    ];
    exports2.PutResourcePolicyResponse$ = [
      3,
      n032,
      _PRPRu,
      0,
      [_rPe, _rIev],
      [() => exports2.ResourcePolicy$, 0]
    ];
    exports2.PutRetentionPolicyRequest$ = [
      3,
      n032,
      _PRPRut,
      0,
      [_lGN, _rID],
      [0, 1],
      2
    ];
    exports2.PutSubscriptionFilterRequest$ = [
      3,
      n032,
      _PSFR,
      0,
      [_lGN, _fN, _fP, _dA, _rAo, _dis, _aOTL, _fSC, _eSF],
      [0, 0, 0, 0, 0, 0, 2, 0, 64 | 0],
      4
    ];
    exports2.PutTransformerRequest$ = [
      3,
      n032,
      _PTR,
      0,
      [_lGIo, _tC],
      [0, () => Processors],
      2
    ];
    exports2.QueryCompileError$ = [
      3,
      n032,
      _QCE,
      0,
      [_lo, _m29],
      [() => exports2.QueryCompileErrorLocation$, 0]
    ];
    exports2.QueryCompileErrorLocation$ = [
      3,
      n032,
      _QCEL,
      0,
      [_sCO, _eCO],
      [1, 1]
    ];
    exports2.QueryDefinition$ = [
      3,
      n032,
      _QD,
      0,
      [_qL, _qDI, _n, _qS, _lM, _lGNo, _pa],
      [0, 0, 0, 0, 1, 64 | 0, () => QueryParameterList]
    ];
    exports2.QueryInfo$ = [
      3,
      n032,
      _QI,
      0,
      [_qL, _qI, _qS, _sta, _cTr, _lGN, _qDu, _bS, _uI],
      [0, 0, 0, 0, 1, 0, 1, 1, 0]
    ];
    exports2.QueryParameter$ = [
      3,
      n032,
      _QP,
      0,
      [_n, _dV, _d],
      [0, 0, 0],
      1
    ];
    exports2.QueryStatistics$ = [
      3,
      n032,
      _QS,
      0,
      [_rM, _rS, _eRS, _bS, _eBS, _lGS],
      [1, 1, 1, 1, 1, 1]
    ];
    exports2.RecordField$ = [
      3,
      n032,
      _RF,
      0,
      [_n, _man],
      [0, 2]
    ];
    exports2.RejectedEntityInfo$ = [
      3,
      n032,
      _REI,
      0,
      [_eTr],
      [0],
      1
    ];
    exports2.RejectedLogEventsInfo$ = [
      3,
      n032,
      _RLEI,
      0,
      [_tNLESI, _tOLEEI, _eLEEI],
      [1, 1, 1]
    ];
    exports2.RenameKeyEntry$ = [
      3,
      n032,
      _RKE,
      0,
      [_k, _rTen, _oIE],
      [0, 0, 2],
      2
    ];
    exports2.RenameKeys$ = [
      3,
      n032,
      _RK,
      0,
      [_en],
      [() => RenameKeyEntries],
      1
    ];
    exports2.ResourcePolicy$ = [
      3,
      n032,
      _RP,
      0,
      [_pN, _pD, _lUT, _pSo, _rA, _rIev],
      [0, 0, 1, 0, 0, 0]
    ];
    exports2.ResultField$ = [
      3,
      n032,
      _RFe,
      0,
      [_fie, _v],
      [0, 0]
    ];
    exports2.S3Configuration$ = [
      3,
      n032,
      _SC,
      0,
      [_dI, _rAo, _oAI, _kKI],
      [0, 0, 0, 0],
      2
    ];
    exports2.S3DeliveryConfiguration$ = [
      3,
      n032,
      _SDC,
      0,
      [_sP, _eHCP],
      [0, 2]
    ];
    exports2.S3TableIntegrationSource$ = [
      3,
      n032,
      _STIS,
      0,
      [_i, _dS, _sta, _sRt, _cTSr],
      [0, () => exports2.DataSource$, 0, 0, 1]
    ];
    exports2.ScheduledQueryDestination$ = [
      3,
      n032,
      _SQD,
      0,
      [_dT, _dI, _sta, _pIr, _eM],
      [0, 0, 0, 0, 0]
    ];
    exports2.ScheduledQuerySummary$ = [
      3,
      n032,
      _SQS,
      0,
      [_sQA, _n, _st, _lTT, _lES, _sE, _ti, _dC4, _cT, _lUT],
      [0, 0, 0, 1, 0, 0, 0, () => exports2.DestinationConfiguration$, 1, 1]
    ];
    exports2.SearchedLogStream$ = [
      3,
      n032,
      _SLS,
      0,
      [_lSN, _sCe],
      [0, 2]
    ];
    exports2.SplitString$ = [
      3,
      n032,
      _SS,
      0,
      [_en],
      [() => SplitStringEntries],
      1
    ];
    exports2.SplitStringEntry$ = [
      3,
      n032,
      _SSEp,
      0,
      [_so, _del],
      [0, 0],
      2
    ];
    exports2.StartLiveTailRequest$ = [
      3,
      n032,
      _SLTR,
      0,
      [_lGI, _lSNo, _lSNPo, _lEFP],
      [64 | 0, 64 | 0, 64 | 0, 0],
      1
    ];
    exports2.StartLiveTailResponse$ = [
      3,
      n032,
      _SLTRt,
      0,
      [_rSe],
      [[() => exports2.StartLiveTailResponseStream$, 0]]
    ];
    exports2.StartQueryRequest$ = [
      3,
      n032,
      _SQR,
      0,
      [_sTt, _eTn, _qS, _qL, _lGN, _lGNo, _lGI, _li],
      [1, 1, 0, 0, 0, 64 | 0, 64 | 0, 1],
      3
    ];
    exports2.StartQueryResponse$ = [
      3,
      n032,
      _SQRt,
      0,
      [_qI],
      [0]
    ];
    exports2.StopQueryRequest$ = [
      3,
      n032,
      _SQRto,
      0,
      [_qI],
      [0],
      1
    ];
    exports2.StopQueryResponse$ = [
      3,
      n032,
      _SQRtop,
      0,
      [_suc],
      [2]
    ];
    exports2.SubscriptionFilter$ = [
      3,
      n032,
      _SF,
      0,
      [_fN, _lGN, _fP, _dA, _rAo, _dis, _aOTL, _cT, _fSC, _eSF],
      [0, 0, 0, 0, 0, 0, 2, 1, 0, 64 | 0]
    ];
    exports2.SubstituteString$ = [
      3,
      n032,
      _SSu,
      0,
      [_en],
      [() => SubstituteStringEntries],
      1
    ];
    exports2.SubstituteStringEntry$ = [
      3,
      n032,
      _SSEu,
      0,
      [_so, _f, _to],
      [0, 0, 0],
      3
    ];
    exports2.SuppressionPeriod$ = [
      3,
      n032,
      _SP,
      0,
      [_v, _sUu],
      [1, 0]
    ];
    exports2.TagLogGroupRequest$ = [
      3,
      n032,
      _TLGR,
      0,
      [_lGN, _ta],
      [0, 128 | 0],
      2
    ];
    exports2.TagResourceRequest$ = [
      3,
      n032,
      _TRR,
      0,
      [_rA, _ta],
      [0, 128 | 0],
      2
    ];
    exports2.TestMetricFilterRequest$ = [
      3,
      n032,
      _TMFR,
      0,
      [_fP, _lEM],
      [0, 64 | 0],
      2
    ];
    exports2.TestMetricFilterResponse$ = [
      3,
      n032,
      _TMFRe,
      0,
      [_mat],
      [() => MetricFilterMatches]
    ];
    exports2.TestTransformerRequest$ = [
      3,
      n032,
      _TTR,
      0,
      [_tC, _lEM],
      [() => Processors, 64 | 0],
      2
    ];
    exports2.TestTransformerResponse$ = [
      3,
      n032,
      _TTRe,
      0,
      [_tL],
      [() => TransformedLogs]
    ];
    exports2.TransformedLogRecord$ = [
      3,
      n032,
      _TLR,
      0,
      [_eN, _eMv, _tEM],
      [1, 0, 0]
    ];
    exports2.TriggerHistoryRecord$ = [
      3,
      n032,
      _THR,
      0,
      [_qI, _eSx, _tTr, _eM, _dest],
      [0, 0, 1, 0, () => ScheduledQueryDestinationList]
    ];
    exports2.TrimString$ = [
      3,
      n032,
      _TS,
      0,
      [_wK],
      [64 | 0],
      1
    ];
    exports2.TypeConverter$ = [
      3,
      n032,
      _TC10,
      0,
      [_en],
      [() => TypeConverterEntries],
      1
    ];
    exports2.TypeConverterEntry$ = [
      3,
      n032,
      _TCE,
      0,
      [_k, _ty],
      [0, 0],
      2
    ];
    exports2.UntagLogGroupRequest$ = [
      3,
      n032,
      _ULGR,
      0,
      [_lGN, _ta],
      [0, 64 | 0],
      2
    ];
    exports2.UntagResourceRequest$ = [
      3,
      n032,
      _URR,
      0,
      [_rA, _tK],
      [0, 64 | 0],
      2
    ];
    exports2.UpdateAnomalyRequest$ = [
      3,
      n032,
      _UAR,
      0,
      [_aDA, _aIn, _pI, _sTu, _sPu, _b],
      [0, 0, 0, 0, () => exports2.SuppressionPeriod$, 2],
      1
    ];
    exports2.UpdateDeliveryConfigurationRequest$ = [
      3,
      n032,
      _UDCR,
      0,
      [_id, _rF, _fD, _sDC],
      [0, 64 | 0, 0, () => exports2.S3DeliveryConfiguration$],
      1
    ];
    exports2.UpdateDeliveryConfigurationResponse$ = [
      3,
      n032,
      _UDCRp,
      0,
      [],
      []
    ];
    exports2.UpdateLogAnomalyDetectorRequest$ = [
      3,
      n032,
      _ULADR,
      0,
      [_aDA, _ena, _eF, _fP, _aVT],
      [0, 2, 0, 0, 1],
      2
    ];
    exports2.UpdateLookupTableRequest$ = [
      3,
      n032,
      _ULTR,
      0,
      [_lTA, _tB, _d, _kKI],
      [0, 0, 0, 0],
      2
    ];
    exports2.UpdateLookupTableResponse$ = [
      3,
      n032,
      _ULTRp,
      0,
      [_lTA, _lUT],
      [0, 1]
    ];
    exports2.UpdateScheduledQueryRequest$ = [
      3,
      n032,
      _USQR,
      0,
      [_i, _qL, _qS, _sE, _eRA, _d, _lGI, _ti, _sTO, _dC4, _sST, _sET, _st],
      [0, 0, 0, 0, 0, 0, 64 | 0, 0, 1, () => exports2.DestinationConfiguration$, 1, 1, 0],
      5
    ];
    exports2.UpdateScheduledQueryResponse$ = [
      3,
      n032,
      _USQRp,
      0,
      [_sQA, _n, _d, _qL, _qS, _lGI, _sE, _ti, _sTO, _dC4, _st, _lTT, _lES, _sST, _sET, _eRA, _cT, _lUT],
      [0, 0, 0, 0, 0, 64 | 0, 0, 0, 1, () => exports2.DestinationConfiguration$, 0, 1, 0, 1, 1, 0, 1, 1]
    ];
    exports2.UpperCaseString$ = [
      3,
      n032,
      _UCS,
      0,
      [_wK],
      [64 | 0],
      1
    ];
    var __Unit = "unit";
    var AccountIds = 64 | 0;
    var AccountPolicies = [
      1,
      n032,
      _APc,
      0,
      () => exports2.AccountPolicy$
    ];
    var AddKeyEntries = [
      1,
      n032,
      _AKEd,
      0,
      () => exports2.AddKeyEntry$
    ];
    var AggregateLogGroupSummaries = [
      1,
      n032,
      _ALGSg,
      0,
      () => exports2.AggregateLogGroupSummary$
    ];
    var AllowedFieldDelimiters = 64 | 0;
    var AllowedFields = [
      1,
      n032,
      _AF,
      0,
      () => exports2.RecordField$
    ];
    var Anomalies = [
      1,
      n032,
      _An,
      0,
      () => exports2.Anomaly$
    ];
    var AnomalyDetectors = [
      1,
      n032,
      _ADn,
      0,
      () => exports2.AnomalyDetector$
    ];
    var Columns = 64 | 0;
    var ConfigurationTemplates = [
      1,
      n032,
      _CTo,
      0,
      () => exports2.ConfigurationTemplate$
    ];
    var CopyValueEntries = [
      1,
      n032,
      _CVEo,
      0,
      () => exports2.CopyValueEntry$
    ];
    var DashboardViewerPrincipals = 64 | 0;
    var DataSourceFilters = [
      1,
      n032,
      _DSFa,
      0,
      () => exports2.DataSourceFilter$
    ];
    var DeleteWithKeys = 64 | 0;
    var Deliveries = [
      1,
      n032,
      _Del,
      0,
      () => exports2.Delivery$
    ];
    var DeliveryDestinations = [
      1,
      n032,
      _DDe,
      0,
      () => exports2.DeliveryDestination$
    ];
    var DeliveryDestinationTypes = 64 | 0;
    var DeliverySources = [
      1,
      n032,
      _DSel,
      0,
      () => exports2.DeliverySource$
    ];
    var DescribeFieldIndexesLogGroupIdentifiers = 64 | 0;
    var DescribeIndexPoliciesLogGroupIdentifiers = 64 | 0;
    var DescribeLogGroupsLogGroupIdentifiers = 64 | 0;
    var Destinations = [
      1,
      n032,
      _Des,
      0,
      () => exports2.Destination$
    ];
    var EmitSystemFields = 64 | 0;
    var ExecutionStatusList = 64 | 0;
    var ExportTasks = [
      1,
      n032,
      _ETx,
      0,
      () => exports2.ExportTask$
    ];
    var FieldIndexes = [
      1,
      n032,
      _FIi,
      0,
      () => exports2.FieldIndex$
    ];
    var FieldIndexNames = 64 | 0;
    var FilteredLogEvents = [
      1,
      n032,
      _FLEi,
      0,
      () => exports2.FilteredLogEvent$
    ];
    var GroupingIdentifiers = [
      1,
      n032,
      _GIr,
      0,
      () => exports2.GroupingIdentifier$
    ];
    var ImportBatchList = [
      1,
      n032,
      _IBL,
      0,
      () => exports2.ImportBatch$
    ];
    var ImportList = [
      1,
      n032,
      _IL,
      0,
      () => exports2.Import$
    ];
    var ImportStatusList = 64 | 0;
    var IndexPolicies = [
      1,
      n032,
      _IPn,
      0,
      () => exports2.IndexPolicy$
    ];
    var InheritedProperties = 64 | 0;
    var InputLogEvents = [
      1,
      n032,
      _ILEn,
      0,
      () => exports2.InputLogEvent$
    ];
    var InputLogStreamNames = 64 | 0;
    var IntegrationSummaries = [
      1,
      n032,
      _ISnt,
      0,
      () => exports2.IntegrationSummary$
    ];
    var LiveTailSessionResults = [
      1,
      n032,
      _LTSR,
      0,
      () => exports2.LiveTailSessionLogEvent$
    ];
    var LogFieldsList = [
      1,
      n032,
      _LFL,
      0,
      () => exports2.LogFieldsListItem$
    ];
    var LogGroupArnList = 64 | 0;
    var LogGroupFieldList = [
      1,
      n032,
      _LGFL,
      0,
      () => exports2.LogGroupField$
    ];
    var LogGroupIdentifiers = 64 | 0;
    var LogGroupNames = 64 | 0;
    var LogGroups = [
      1,
      n032,
      _LGo,
      0,
      () => exports2.LogGroup$
    ];
    var LogGroupSummaries = [
      1,
      n032,
      _LGSo,
      0,
      () => exports2.LogGroupSummary$
    ];
    var LogSamples = [
      1,
      n032,
      _LSo,
      0,
      () => exports2.LogEvent$
    ];
    var LogStreams = [
      1,
      n032,
      _LSog,
      0,
      () => exports2.LogStream$
    ];
    var LogTypes = 64 | 0;
    var LookupTables = [
      1,
      n032,
      _LTo,
      0,
      () => exports2.LookupTable$
    ];
    var LowerCaseStringWithKeys = 64 | 0;
    var MatchPatterns = 64 | 0;
    var MetricFilterMatches = [
      1,
      n032,
      _MFM,
      0,
      () => exports2.MetricFilterMatchRecord$
    ];
    var MetricFilters = [
      1,
      n032,
      _MFe,
      0,
      () => exports2.MetricFilter$
    ];
    var MetricTransformations = [
      1,
      n032,
      _MTe,
      0,
      () => exports2.MetricTransformation$
    ];
    var MoveKeyEntries = [
      1,
      n032,
      _MKEo,
      0,
      () => exports2.MoveKeyEntry$
    ];
    var OutputFormats = 64 | 0;
    var OutputLogEvents = [
      1,
      n032,
      _OLEu,
      0,
      () => exports2.OutputLogEvent$
    ];
    var PatternTokens = [
      1,
      n032,
      _PTa,
      0,
      () => exports2.PatternToken$
    ];
    var Processors = [
      1,
      n032,
      _Pro,
      0,
      () => exports2.Processor$
    ];
    var QueryDefinitionList = [
      1,
      n032,
      _QDL,
      0,
      () => exports2.QueryDefinition$
    ];
    var QueryInfoList = [
      1,
      n032,
      _QIL,
      0,
      () => exports2.QueryInfo$
    ];
    var QueryParameterList = [
      1,
      n032,
      _QPL,
      0,
      () => exports2.QueryParameter$
    ];
    var QueryResults = [
      1,
      n032,
      _QR,
      0,
      () => ResultRows
    ];
    var RecordFields = 64 | 0;
    var RenameKeyEntries = [
      1,
      n032,
      _RKEe,
      0,
      () => exports2.RenameKeyEntry$
    ];
    var ResourceArns = 64 | 0;
    var ResourcePolicies = [
      1,
      n032,
      _RPe,
      0,
      () => exports2.ResourcePolicy$
    ];
    var ResourceTypes = 64 | 0;
    var ResultRows = [
      1,
      n032,
      _RR,
      0,
      () => exports2.ResultField$
    ];
    var S3TableIntegrationSources = [
      1,
      n032,
      _STISa,
      0,
      () => exports2.S3TableIntegrationSource$
    ];
    var ScheduledQueryDestinationList = [
      1,
      n032,
      _SQDL,
      0,
      () => exports2.ScheduledQueryDestination$
    ];
    var ScheduledQueryLogGroupIdentifiers = 64 | 0;
    var ScheduledQuerySummaryList = [
      1,
      n032,
      _SQSL,
      0,
      () => exports2.ScheduledQuerySummary$
    ];
    var SearchedLogStreams = [
      1,
      n032,
      _SLSe,
      0,
      () => exports2.SearchedLogStream$
    ];
    var SplitStringEntries = [
      1,
      n032,
      _SSEpl,
      0,
      () => exports2.SplitStringEntry$
    ];
    var StartLiveTailLogGroupIdentifiers = 64 | 0;
    var SubscriptionFilters = [
      1,
      n032,
      _SFu,
      0,
      () => exports2.SubscriptionFilter$
    ];
    var SubstituteStringEntries = [
      1,
      n032,
      _SSEub,
      0,
      () => exports2.SubstituteStringEntry$
    ];
    var TableFields = 64 | 0;
    var TagKeyList = 64 | 0;
    var TagList = 64 | 0;
    var TestEventMessages = 64 | 0;
    var TransformedLogs = [
      1,
      n032,
      _TL,
      0,
      () => exports2.TransformedLogRecord$
    ];
    var TriggerHistoryRecordList = [
      1,
      n032,
      _THRL,
      0,
      () => exports2.TriggerHistoryRecord$
    ];
    var TrimStringWithKeys = 64 | 0;
    var TypeConverterEntries = [
      1,
      n032,
      _TCEy,
      0,
      () => exports2.TypeConverterEntry$
    ];
    var UpperCaseStringWithKeys = 64 | 0;
    var Dimensions = 128 | 0;
    var EntityAttributes = 128 | 0;
    var EntityKeyAttributes = 128 | 0;
    var Enumerations = 128 | 1;
    var ExtractedValues = 128 | 0;
    var Histogram = 128 | 1;
    var LogRecord = 128 | 0;
    var Tags = 128 | 0;
    exports2.GetLogObjectResponseStream$ = [
      4,
      n032,
      _GLORS,
      { [_str]: 1 },
      [_fi, _ISEn4],
      [() => exports2.FieldsData$, [() => exports2.InternalStreamingException$, 0]]
    ];
    exports2.IntegrationDetails$ = [
      4,
      n032,
      _ID,
      0,
      [_oSID],
      [() => exports2.OpenSearchIntegrationDetails$]
    ];
    exports2.ResourceConfig$ = [
      4,
      n032,
      _RC10,
      0,
      [_oSRC],
      [() => exports2.OpenSearchResourceConfig$]
    ];
    exports2.StartLiveTailResponseStream$ = [
      4,
      n032,
      _SLTRS,
      { [_str]: 1 },
      [_sSe, _sUe, _STE, _SSE],
      [() => exports2.LiveTailSessionStart$, () => exports2.LiveTailSessionUpdate$, [() => exports2.SessionTimeoutException$, 0], [() => exports2.SessionStreamingException$, 0]]
    ];
    exports2.AssociateKmsKey$ = [
      9,
      n032,
      _AKK,
      0,
      () => exports2.AssociateKmsKeyRequest$,
      () => __Unit
    ];
    exports2.AssociateSourceToS3TableIntegration$ = [
      9,
      n032,
      _ASTSTI,
      0,
      () => exports2.AssociateSourceToS3TableIntegrationRequest$,
      () => exports2.AssociateSourceToS3TableIntegrationResponse$
    ];
    exports2.CancelExportTask$ = [
      9,
      n032,
      _CET,
      0,
      () => exports2.CancelExportTaskRequest$,
      () => __Unit
    ];
    exports2.CancelImportTask$ = [
      9,
      n032,
      _CIT,
      0,
      () => exports2.CancelImportTaskRequest$,
      () => exports2.CancelImportTaskResponse$
    ];
    exports2.CreateDelivery$ = [
      9,
      n032,
      _CD,
      0,
      () => exports2.CreateDeliveryRequest$,
      () => exports2.CreateDeliveryResponse$
    ];
    exports2.CreateExportTask$ = [
      9,
      n032,
      _CETr,
      0,
      () => exports2.CreateExportTaskRequest$,
      () => exports2.CreateExportTaskResponse$
    ];
    exports2.CreateImportTask$ = [
      9,
      n032,
      _CITr,
      0,
      () => exports2.CreateImportTaskRequest$,
      () => exports2.CreateImportTaskResponse$
    ];
    exports2.CreateLogAnomalyDetector$ = [
      9,
      n032,
      _CLAD,
      0,
      () => exports2.CreateLogAnomalyDetectorRequest$,
      () => exports2.CreateLogAnomalyDetectorResponse$
    ];
    exports2.CreateLogGroup$ = [
      9,
      n032,
      _CLG,
      0,
      () => exports2.CreateLogGroupRequest$,
      () => __Unit
    ];
    exports2.CreateLogStream$ = [
      9,
      n032,
      _CLS,
      0,
      () => exports2.CreateLogStreamRequest$,
      () => __Unit
    ];
    exports2.CreateLookupTable$ = [
      9,
      n032,
      _CLT,
      0,
      () => exports2.CreateLookupTableRequest$,
      () => exports2.CreateLookupTableResponse$
    ];
    exports2.CreateScheduledQuery$ = [
      9,
      n032,
      _CSQ,
      0,
      () => exports2.CreateScheduledQueryRequest$,
      () => exports2.CreateScheduledQueryResponse$
    ];
    exports2.DeleteAccountPolicy$ = [
      9,
      n032,
      _DAP,
      0,
      () => exports2.DeleteAccountPolicyRequest$,
      () => __Unit
    ];
    exports2.DeleteDataProtectionPolicy$ = [
      9,
      n032,
      _DDPP,
      0,
      () => exports2.DeleteDataProtectionPolicyRequest$,
      () => __Unit
    ];
    exports2.DeleteDelivery$ = [
      9,
      n032,
      _DDel,
      0,
      () => exports2.DeleteDeliveryRequest$,
      () => __Unit
    ];
    exports2.DeleteDeliveryDestination$ = [
      9,
      n032,
      _DDD,
      0,
      () => exports2.DeleteDeliveryDestinationRequest$,
      () => __Unit
    ];
    exports2.DeleteDeliveryDestinationPolicy$ = [
      9,
      n032,
      _DDDP,
      0,
      () => exports2.DeleteDeliveryDestinationPolicyRequest$,
      () => __Unit
    ];
    exports2.DeleteDeliverySource$ = [
      9,
      n032,
      _DDS,
      0,
      () => exports2.DeleteDeliverySourceRequest$,
      () => __Unit
    ];
    exports2.DeleteDestination$ = [
      9,
      n032,
      _DDele,
      0,
      () => exports2.DeleteDestinationRequest$,
      () => __Unit
    ];
    exports2.DeleteIndexPolicy$ = [
      9,
      n032,
      _DIP,
      0,
      () => exports2.DeleteIndexPolicyRequest$,
      () => exports2.DeleteIndexPolicyResponse$
    ];
    exports2.DeleteIntegration$ = [
      9,
      n032,
      _DI,
      0,
      () => exports2.DeleteIntegrationRequest$,
      () => exports2.DeleteIntegrationResponse$
    ];
    exports2.DeleteLogAnomalyDetector$ = [
      9,
      n032,
      _DLAD,
      0,
      () => exports2.DeleteLogAnomalyDetectorRequest$,
      () => __Unit
    ];
    exports2.DeleteLogGroup$ = [
      9,
      n032,
      _DLG,
      0,
      () => exports2.DeleteLogGroupRequest$,
      () => __Unit
    ];
    exports2.DeleteLogStream$ = [
      9,
      n032,
      _DLS,
      0,
      () => exports2.DeleteLogStreamRequest$,
      () => __Unit
    ];
    exports2.DeleteLookupTable$ = [
      9,
      n032,
      _DLT,
      0,
      () => exports2.DeleteLookupTableRequest$,
      () => __Unit
    ];
    exports2.DeleteMetricFilter$ = [
      9,
      n032,
      _DMF,
      0,
      () => exports2.DeleteMetricFilterRequest$,
      () => __Unit
    ];
    exports2.DeleteQueryDefinition$ = [
      9,
      n032,
      _DQD,
      0,
      () => exports2.DeleteQueryDefinitionRequest$,
      () => exports2.DeleteQueryDefinitionResponse$
    ];
    exports2.DeleteResourcePolicy$ = [
      9,
      n032,
      _DRP,
      0,
      () => exports2.DeleteResourcePolicyRequest$,
      () => __Unit
    ];
    exports2.DeleteRetentionPolicy$ = [
      9,
      n032,
      _DRPe,
      0,
      () => exports2.DeleteRetentionPolicyRequest$,
      () => __Unit
    ];
    exports2.DeleteScheduledQuery$ = [
      9,
      n032,
      _DSQ,
      0,
      () => exports2.DeleteScheduledQueryRequest$,
      () => exports2.DeleteScheduledQueryResponse$
    ];
    exports2.DeleteSubscriptionFilter$ = [
      9,
      n032,
      _DSFe,
      0,
      () => exports2.DeleteSubscriptionFilterRequest$,
      () => __Unit
    ];
    exports2.DeleteTransformer$ = [
      9,
      n032,
      _DT,
      0,
      () => exports2.DeleteTransformerRequest$,
      () => __Unit
    ];
    exports2.DescribeAccountPolicies$ = [
      9,
      n032,
      _DAPe,
      0,
      () => exports2.DescribeAccountPoliciesRequest$,
      () => exports2.DescribeAccountPoliciesResponse$
    ];
    exports2.DescribeConfigurationTemplates$ = [
      9,
      n032,
      _DCT,
      0,
      () => exports2.DescribeConfigurationTemplatesRequest$,
      () => exports2.DescribeConfigurationTemplatesResponse$
    ];
    exports2.DescribeDeliveries$ = [
      9,
      n032,
      _DDes,
      0,
      () => exports2.DescribeDeliveriesRequest$,
      () => exports2.DescribeDeliveriesResponse$
    ];
    exports2.DescribeDeliveryDestinations$ = [
      9,
      n032,
      _DDDe,
      0,
      () => exports2.DescribeDeliveryDestinationsRequest$,
      () => exports2.DescribeDeliveryDestinationsResponse$
    ];
    exports2.DescribeDeliverySources$ = [
      9,
      n032,
      _DDSe,
      0,
      () => exports2.DescribeDeliverySourcesRequest$,
      () => exports2.DescribeDeliverySourcesResponse$
    ];
    exports2.DescribeDestinations$ = [
      9,
      n032,
      _DDesc,
      0,
      () => exports2.DescribeDestinationsRequest$,
      () => exports2.DescribeDestinationsResponse$
    ];
    exports2.DescribeExportTasks$ = [
      9,
      n032,
      _DET,
      0,
      () => exports2.DescribeExportTasksRequest$,
      () => exports2.DescribeExportTasksResponse$
    ];
    exports2.DescribeFieldIndexes$ = [
      9,
      n032,
      _DFI,
      0,
      () => exports2.DescribeFieldIndexesRequest$,
      () => exports2.DescribeFieldIndexesResponse$
    ];
    exports2.DescribeImportTaskBatches$ = [
      9,
      n032,
      _DITB,
      0,
      () => exports2.DescribeImportTaskBatchesRequest$,
      () => exports2.DescribeImportTaskBatchesResponse$
    ];
    exports2.DescribeImportTasks$ = [
      9,
      n032,
      _DIT,
      0,
      () => exports2.DescribeImportTasksRequest$,
      () => exports2.DescribeImportTasksResponse$
    ];
    exports2.DescribeIndexPolicies$ = [
      9,
      n032,
      _DIPe,
      0,
      () => exports2.DescribeIndexPoliciesRequest$,
      () => exports2.DescribeIndexPoliciesResponse$
    ];
    exports2.DescribeLogGroups$ = [
      9,
      n032,
      _DLGe,
      0,
      () => exports2.DescribeLogGroupsRequest$,
      () => exports2.DescribeLogGroupsResponse$
    ];
    exports2.DescribeLogStreams$ = [
      9,
      n032,
      _DLSe,
      0,
      () => exports2.DescribeLogStreamsRequest$,
      () => exports2.DescribeLogStreamsResponse$
    ];
    exports2.DescribeLookupTables$ = [
      9,
      n032,
      _DLTe,
      0,
      () => exports2.DescribeLookupTablesRequest$,
      () => exports2.DescribeLookupTablesResponse$
    ];
    exports2.DescribeMetricFilters$ = [
      9,
      n032,
      _DMFe,
      0,
      () => exports2.DescribeMetricFiltersRequest$,
      () => exports2.DescribeMetricFiltersResponse$
    ];
    exports2.DescribeQueries$ = [
      9,
      n032,
      _DQ,
      0,
      () => exports2.DescribeQueriesRequest$,
      () => exports2.DescribeQueriesResponse$
    ];
    exports2.DescribeQueryDefinitions$ = [
      9,
      n032,
      _DQDe,
      0,
      () => exports2.DescribeQueryDefinitionsRequest$,
      () => exports2.DescribeQueryDefinitionsResponse$
    ];
    exports2.DescribeResourcePolicies$ = [
      9,
      n032,
      _DRPes,
      0,
      () => exports2.DescribeResourcePoliciesRequest$,
      () => exports2.DescribeResourcePoliciesResponse$
    ];
    exports2.DescribeSubscriptionFilters$ = [
      9,
      n032,
      _DSFes,
      0,
      () => exports2.DescribeSubscriptionFiltersRequest$,
      () => exports2.DescribeSubscriptionFiltersResponse$
    ];
    exports2.DisassociateKmsKey$ = [
      9,
      n032,
      _DKK,
      0,
      () => exports2.DisassociateKmsKeyRequest$,
      () => __Unit
    ];
    exports2.DisassociateSourceFromS3TableIntegration$ = [
      9,
      n032,
      _DSFSTI,
      0,
      () => exports2.DisassociateSourceFromS3TableIntegrationRequest$,
      () => exports2.DisassociateSourceFromS3TableIntegrationResponse$
    ];
    exports2.FilterLogEvents$ = [
      9,
      n032,
      _FLEil,
      0,
      () => exports2.FilterLogEventsRequest$,
      () => exports2.FilterLogEventsResponse$
    ];
    exports2.GetDataProtectionPolicy$ = [
      9,
      n032,
      _GDPP,
      0,
      () => exports2.GetDataProtectionPolicyRequest$,
      () => exports2.GetDataProtectionPolicyResponse$
    ];
    exports2.GetDelivery$ = [
      9,
      n032,
      _GD,
      0,
      () => exports2.GetDeliveryRequest$,
      () => exports2.GetDeliveryResponse$
    ];
    exports2.GetDeliveryDestination$ = [
      9,
      n032,
      _GDD,
      0,
      () => exports2.GetDeliveryDestinationRequest$,
      () => exports2.GetDeliveryDestinationResponse$
    ];
    exports2.GetDeliveryDestinationPolicy$ = [
      9,
      n032,
      _GDDP,
      0,
      () => exports2.GetDeliveryDestinationPolicyRequest$,
      () => exports2.GetDeliveryDestinationPolicyResponse$
    ];
    exports2.GetDeliverySource$ = [
      9,
      n032,
      _GDS,
      0,
      () => exports2.GetDeliverySourceRequest$,
      () => exports2.GetDeliverySourceResponse$
    ];
    exports2.GetIntegration$ = [
      9,
      n032,
      _GIe,
      0,
      () => exports2.GetIntegrationRequest$,
      () => exports2.GetIntegrationResponse$
    ];
    exports2.GetLogAnomalyDetector$ = [
      9,
      n032,
      _GLAD,
      0,
      () => exports2.GetLogAnomalyDetectorRequest$,
      () => exports2.GetLogAnomalyDetectorResponse$
    ];
    exports2.GetLogEvents$ = [
      9,
      n032,
      _GLE,
      0,
      () => exports2.GetLogEventsRequest$,
      () => exports2.GetLogEventsResponse$
    ];
    exports2.GetLogFields$ = [
      9,
      n032,
      _GLF,
      0,
      () => exports2.GetLogFieldsRequest$,
      () => exports2.GetLogFieldsResponse$
    ];
    exports2.GetLogGroupFields$ = [
      9,
      n032,
      _GLGF,
      0,
      () => exports2.GetLogGroupFieldsRequest$,
      () => exports2.GetLogGroupFieldsResponse$
    ];
    exports2.GetLogObject$ = [
      9,
      n032,
      _GLO,
      { [_end]: ["stream-"] },
      () => exports2.GetLogObjectRequest$,
      () => exports2.GetLogObjectResponse$
    ];
    exports2.GetLogRecord$ = [
      9,
      n032,
      _GLR,
      0,
      () => exports2.GetLogRecordRequest$,
      () => exports2.GetLogRecordResponse$
    ];
    exports2.GetLookupTable$ = [
      9,
      n032,
      _GLT,
      0,
      () => exports2.GetLookupTableRequest$,
      () => exports2.GetLookupTableResponse$
    ];
    exports2.GetQueryResults$ = [
      9,
      n032,
      _GQR,
      0,
      () => exports2.GetQueryResultsRequest$,
      () => exports2.GetQueryResultsResponse$
    ];
    exports2.GetScheduledQuery$ = [
      9,
      n032,
      _GSQ,
      0,
      () => exports2.GetScheduledQueryRequest$,
      () => exports2.GetScheduledQueryResponse$
    ];
    exports2.GetScheduledQueryHistory$ = [
      9,
      n032,
      _GSQH,
      0,
      () => exports2.GetScheduledQueryHistoryRequest$,
      () => exports2.GetScheduledQueryHistoryResponse$
    ];
    exports2.GetTransformer$ = [
      9,
      n032,
      _GT,
      0,
      () => exports2.GetTransformerRequest$,
      () => exports2.GetTransformerResponse$
    ];
    exports2.ListAggregateLogGroupSummaries$ = [
      9,
      n032,
      _LALGS,
      0,
      () => exports2.ListAggregateLogGroupSummariesRequest$,
      () => exports2.ListAggregateLogGroupSummariesResponse$
    ];
    exports2.ListAnomalies$ = [
      9,
      n032,
      _LA,
      0,
      () => exports2.ListAnomaliesRequest$,
      () => exports2.ListAnomaliesResponse$
    ];
    exports2.ListIntegrations$ = [
      9,
      n032,
      _LI,
      0,
      () => exports2.ListIntegrationsRequest$,
      () => exports2.ListIntegrationsResponse$
    ];
    exports2.ListLogAnomalyDetectors$ = [
      9,
      n032,
      _LLAD,
      0,
      () => exports2.ListLogAnomalyDetectorsRequest$,
      () => exports2.ListLogAnomalyDetectorsResponse$
    ];
    exports2.ListLogGroups$ = [
      9,
      n032,
      _LLG,
      0,
      () => exports2.ListLogGroupsRequest$,
      () => exports2.ListLogGroupsResponse$
    ];
    exports2.ListLogGroupsForQuery$ = [
      9,
      n032,
      _LLGFQ,
      0,
      () => exports2.ListLogGroupsForQueryRequest$,
      () => exports2.ListLogGroupsForQueryResponse$
    ];
    exports2.ListScheduledQueries$ = [
      9,
      n032,
      _LSQ,
      0,
      () => exports2.ListScheduledQueriesRequest$,
      () => exports2.ListScheduledQueriesResponse$
    ];
    exports2.ListSourcesForS3TableIntegration$ = [
      9,
      n032,
      _LSFSTI,
      0,
      () => exports2.ListSourcesForS3TableIntegrationRequest$,
      () => exports2.ListSourcesForS3TableIntegrationResponse$
    ];
    exports2.ListTagsForResource$ = [
      9,
      n032,
      _LTFR,
      0,
      () => exports2.ListTagsForResourceRequest$,
      () => exports2.ListTagsForResourceResponse$
    ];
    exports2.ListTagsLogGroup$ = [
      9,
      n032,
      _LTLG,
      0,
      () => exports2.ListTagsLogGroupRequest$,
      () => exports2.ListTagsLogGroupResponse$
    ];
    exports2.PutAccountPolicy$ = [
      9,
      n032,
      _PAP,
      0,
      () => exports2.PutAccountPolicyRequest$,
      () => exports2.PutAccountPolicyResponse$
    ];
    exports2.PutBearerTokenAuthentication$ = [
      9,
      n032,
      _PBTA,
      0,
      () => exports2.PutBearerTokenAuthenticationRequest$,
      () => __Unit
    ];
    exports2.PutDataProtectionPolicy$ = [
      9,
      n032,
      _PDPP,
      0,
      () => exports2.PutDataProtectionPolicyRequest$,
      () => exports2.PutDataProtectionPolicyResponse$
    ];
    exports2.PutDeliveryDestination$ = [
      9,
      n032,
      _PDD,
      0,
      () => exports2.PutDeliveryDestinationRequest$,
      () => exports2.PutDeliveryDestinationResponse$
    ];
    exports2.PutDeliveryDestinationPolicy$ = [
      9,
      n032,
      _PDDP,
      0,
      () => exports2.PutDeliveryDestinationPolicyRequest$,
      () => exports2.PutDeliveryDestinationPolicyResponse$
    ];
    exports2.PutDeliverySource$ = [
      9,
      n032,
      _PDS,
      0,
      () => exports2.PutDeliverySourceRequest$,
      () => exports2.PutDeliverySourceResponse$
    ];
    exports2.PutDestination$ = [
      9,
      n032,
      _PD,
      0,
      () => exports2.PutDestinationRequest$,
      () => exports2.PutDestinationResponse$
    ];
    exports2.PutDestinationPolicy$ = [
      9,
      n032,
      _PDP,
      0,
      () => exports2.PutDestinationPolicyRequest$,
      () => __Unit
    ];
    exports2.PutIndexPolicy$ = [
      9,
      n032,
      _PIP,
      0,
      () => exports2.PutIndexPolicyRequest$,
      () => exports2.PutIndexPolicyResponse$
    ];
    exports2.PutIntegration$ = [
      9,
      n032,
      _PI10,
      0,
      () => exports2.PutIntegrationRequest$,
      () => exports2.PutIntegrationResponse$
    ];
    exports2.PutLogEvents$ = [
      9,
      n032,
      _PLE,
      0,
      () => exports2.PutLogEventsRequest$,
      () => exports2.PutLogEventsResponse$
    ];
    exports2.PutLogGroupDeletionProtection$ = [
      9,
      n032,
      _PLGDP,
      0,
      () => exports2.PutLogGroupDeletionProtectionRequest$,
      () => __Unit
    ];
    exports2.PutMetricFilter$ = [
      9,
      n032,
      _PMF,
      0,
      () => exports2.PutMetricFilterRequest$,
      () => __Unit
    ];
    exports2.PutQueryDefinition$ = [
      9,
      n032,
      _PQD,
      0,
      () => exports2.PutQueryDefinitionRequest$,
      () => exports2.PutQueryDefinitionResponse$
    ];
    exports2.PutResourcePolicy$ = [
      9,
      n032,
      _PRP,
      0,
      () => exports2.PutResourcePolicyRequest$,
      () => exports2.PutResourcePolicyResponse$
    ];
    exports2.PutRetentionPolicy$ = [
      9,
      n032,
      _PRPu,
      0,
      () => exports2.PutRetentionPolicyRequest$,
      () => __Unit
    ];
    exports2.PutSubscriptionFilter$ = [
      9,
      n032,
      _PSF,
      0,
      () => exports2.PutSubscriptionFilterRequest$,
      () => __Unit
    ];
    exports2.PutTransformer$ = [
      9,
      n032,
      _PTu,
      0,
      () => exports2.PutTransformerRequest$,
      () => __Unit
    ];
    exports2.StartLiveTail$ = [
      9,
      n032,
      _SLT,
      { [_end]: ["stream-"] },
      () => exports2.StartLiveTailRequest$,
      () => exports2.StartLiveTailResponse$
    ];
    exports2.StartQuery$ = [
      9,
      n032,
      _SQ,
      0,
      () => exports2.StartQueryRequest$,
      () => exports2.StartQueryResponse$
    ];
    exports2.StopQuery$ = [
      9,
      n032,
      _SQt,
      0,
      () => exports2.StopQueryRequest$,
      () => exports2.StopQueryResponse$
    ];
    exports2.TagLogGroup$ = [
      9,
      n032,
      _TLG,
      0,
      () => exports2.TagLogGroupRequest$,
      () => __Unit
    ];
    exports2.TagResource$ = [
      9,
      n032,
      _TR,
      0,
      () => exports2.TagResourceRequest$,
      () => __Unit
    ];
    exports2.TestMetricFilter$ = [
      9,
      n032,
      _TMF,
      0,
      () => exports2.TestMetricFilterRequest$,
      () => exports2.TestMetricFilterResponse$
    ];
    exports2.TestTransformer$ = [
      9,
      n032,
      _TT,
      0,
      () => exports2.TestTransformerRequest$,
      () => exports2.TestTransformerResponse$
    ];
    exports2.UntagLogGroup$ = [
      9,
      n032,
      _ULG,
      0,
      () => exports2.UntagLogGroupRequest$,
      () => __Unit
    ];
    exports2.UntagResource$ = [
      9,
      n032,
      _UR,
      0,
      () => exports2.UntagResourceRequest$,
      () => __Unit
    ];
    exports2.UpdateAnomaly$ = [
      9,
      n032,
      _UA,
      0,
      () => exports2.UpdateAnomalyRequest$,
      () => __Unit
    ];
    exports2.UpdateDeliveryConfiguration$ = [
      9,
      n032,
      _UDC,
      0,
      () => exports2.UpdateDeliveryConfigurationRequest$,
      () => exports2.UpdateDeliveryConfigurationResponse$
    ];
    exports2.UpdateLogAnomalyDetector$ = [
      9,
      n032,
      _ULAD,
      0,
      () => exports2.UpdateLogAnomalyDetectorRequest$,
      () => __Unit
    ];
    exports2.UpdateLookupTable$ = [
      9,
      n032,
      _ULT,
      0,
      () => exports2.UpdateLookupTableRequest$,
      () => exports2.UpdateLookupTableResponse$
    ];
    exports2.UpdateScheduledQuery$ = [
      9,
      n032,
      _USQ,
      0,
      () => exports2.UpdateScheduledQueryRequest$,
      () => exports2.UpdateScheduledQueryResponse$
    ];
  }
});

// ../../node_modules/@aws-sdk/client-cloudwatch-logs/dist-cjs/runtimeConfig.shared.js
var require_runtimeConfig_shared10 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudwatch-logs/dist-cjs/runtimeConfig.shared.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var protocols_1 = (init_protocols8(), __toCommonJS(protocols_exports5));
    var smithy_client_1 = require_dist_cjs34();
    var url_parser_1 = require_dist_cjs18();
    var util_base64_1 = require_dist_cjs10();
    var util_utf8_1 = require_dist_cjs9();
    var httpAuthSchemeProvider_1 = require_httpAuthSchemeProvider9();
    var endpointResolver_1 = require_endpointResolver9();
    var schemas_0_1 = require_schemas_09();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2014-03-28",
        base64Decoder: config2?.base64Decoder ?? util_base64_1.fromBase64,
        base64Encoder: config2?.base64Encoder ?? util_base64_1.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? endpointResolver_1.defaultEndpointResolver,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? httpAuthSchemeProvider_1.defaultCloudWatchLogsHttpAuthSchemeProvider,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new httpAuthSchemes_1.AwsSdkSigV4Signer()
          }
        ],
        logger: config2?.logger ?? new smithy_client_1.NoOpLogger(),
        protocol: config2?.protocol ?? protocols_1.AwsJson1_1Protocol,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.cloudwatchlogs",
          errorTypeRegistries: schemas_0_1.errorTypeRegistries,
          xmlNamespace: "http://monitoring.amazonaws.com/doc/2014-03-28/",
          version: "2014-03-28",
          serviceTarget: "Logs_20140328"
        },
        serviceId: config2?.serviceId ?? "CloudWatch Logs",
        urlParser: config2?.urlParser ?? url_parser_1.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? util_utf8_1.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? util_utf8_1.toUtf8
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-cloudwatch-logs/dist-cjs/runtimeConfig.js
var require_runtimeConfig10 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudwatch-logs/dist-cjs/runtimeConfig.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var package_json_1 = tslib_1.__importDefault(require_package9());
    var client_1 = (init_client8(), __toCommonJS(client_exports7));
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var credential_provider_node_1 = require_dist_cjs122();
    var util_user_agent_node_1 = require_dist_cjs113();
    var config_resolver_1 = require_dist_cjs25();
    var eventstream_serde_node_1 = require_dist_cjs85();
    var hash_node_1 = require_dist_cjs44();
    var middleware_retry_1 = require_dist_cjs106();
    var node_config_provider_1 = require_dist_cjs29();
    var node_http_handler_1 = require_dist_cjs13();
    var smithy_client_1 = require_dist_cjs34();
    var util_body_length_node_1 = require_dist_cjs45();
    var util_defaults_mode_node_1 = require_dist_cjs46();
    var util_retry_1 = require_dist_cjs22();
    var runtimeConfig_shared_1 = require_runtimeConfig_shared10();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      (0, smithy_client_1.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, util_defaults_mode_node_1.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(smithy_client_1.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = (0, runtimeConfig_shared_1.getRuntimeConfig)(config2);
      (0, client_1.emitWarningIfUnsupportedVersion)(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, node_config_provider_1.loadConfig)(httpAuthSchemes_1.NODE_AUTH_SCHEME_PREFERENCE_OPTIONS, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? util_body_length_node_1.calculateBodyLength,
        credentialDefaultProvider: config2?.credentialDefaultProvider ?? credential_provider_node_1.defaultProvider,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, util_user_agent_node_1.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_json_1.default.version }),
        eventStreamSerdeProvider: config2?.eventStreamSerdeProvider ?? eventstream_serde_node_1.eventStreamSerdeProvider,
        maxAttempts: config2?.maxAttempts ?? (0, node_config_provider_1.loadConfig)(middleware_retry_1.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_REGION_CONFIG_OPTIONS, { ...config_resolver_1.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: node_http_handler_1.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, node_config_provider_1.loadConfig)({
          ...middleware_retry_1.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || util_retry_1.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? hash_node_1.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? node_http_handler_1.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, node_config_provider_1.loadConfig)(util_user_agent_node_1.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-cloudwatch-logs/dist-cjs/index.js
var require_dist_cjs159 = __commonJS({
  "../../node_modules/@aws-sdk/client-cloudwatch-logs/dist-cjs/index.js"(exports2) {
    "use strict";
    var middlewareHostHeader = require_dist_cjs3();
    var middlewareLogger = require_dist_cjs4();
    var middlewareRecursionDetection = require_dist_cjs5();
    var middlewareUserAgent = require_dist_cjs104();
    var configResolver = require_dist_cjs25();
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var schema = (init_schema4(), __toCommonJS(schema_exports));
    var eventstreamSerdeConfigResolver = require_dist_cjs70();
    var middlewareContentLength = require_dist_cjs26();
    var middlewareEndpoint = require_dist_cjs31();
    var middlewareRetry = require_dist_cjs106();
    var smithyClient = require_dist_cjs34();
    var httpAuthSchemeProvider = require_httpAuthSchemeProvider9();
    var runtimeConfig = require_runtimeConfig10();
    var regionConfigResolver = require_dist_cjs48();
    var protocolHttp = require_dist_cjs2();
    var schemas_0 = require_schemas_09();
    var errors = require_errors9();
    var CloudWatchLogsServiceException = require_CloudWatchLogsServiceException();
    var resolveClientEndpointParameters32 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "logs"
      });
    }, "resolveClientEndpointParameters");
    var commonParams32 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
    var getHttpAuthExtensionConfiguration32 = /* @__PURE__ */ __name((runtimeConfig2) => {
      const _httpAuthSchemes = runtimeConfig2.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig2.httpAuthSchemeProvider;
      let _credentials = runtimeConfig2.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider2) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider2;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    var resolveHttpAuthRuntimeConfig32 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
    var resolveRuntimeExtensions32 = /* @__PURE__ */ __name((runtimeConfig2, extensions) => {
      const extensionConfiguration = Object.assign(regionConfigResolver.getAwsRegionExtensionConfiguration(runtimeConfig2), smithyClient.getDefaultExtensionConfiguration(runtimeConfig2), protocolHttp.getHttpHandlerExtensionConfiguration(runtimeConfig2), getHttpAuthExtensionConfiguration32(runtimeConfig2));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig2, regionConfigResolver.resolveAwsRegionExtensionConfiguration(extensionConfiguration), smithyClient.resolveDefaultRuntimeConfig(extensionConfiguration), protocolHttp.resolveHttpHandlerRuntimeConfig(extensionConfiguration), resolveHttpAuthRuntimeConfig32(extensionConfiguration));
    }, "resolveRuntimeExtensions");
    var CloudWatchLogsClient2 = class extends smithyClient.Client {
      static {
        __name(this, "CloudWatchLogsClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = runtimeConfig.getRuntimeConfig(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters32(_config_0);
        const _config_2 = middlewareUserAgent.resolveUserAgentConfig(_config_1);
        const _config_3 = middlewareRetry.resolveRetryConfig(_config_2);
        const _config_4 = configResolver.resolveRegionConfig(_config_3);
        const _config_5 = middlewareHostHeader.resolveHostHeaderConfig(_config_4);
        const _config_6 = middlewareEndpoint.resolveEndpointConfig(_config_5);
        const _config_7 = eventstreamSerdeConfigResolver.resolveEventStreamSerdeConfig(_config_6);
        const _config_8 = httpAuthSchemeProvider.resolveHttpAuthSchemeConfig(_config_7);
        const _config_9 = resolveRuntimeExtensions32(_config_8, configuration?.extensions || []);
        this.config = _config_9;
        this.middlewareStack.use(schema.getSchemaSerdePlugin(this.config));
        this.middlewareStack.use(middlewareUserAgent.getUserAgentPlugin(this.config));
        this.middlewareStack.use(middlewareRetry.getRetryPlugin(this.config));
        this.middlewareStack.use(middlewareContentLength.getContentLengthPlugin(this.config));
        this.middlewareStack.use(middlewareHostHeader.getHostHeaderPlugin(this.config));
        this.middlewareStack.use(middlewareLogger.getLoggerPlugin(this.config));
        this.middlewareStack.use(middlewareRecursionDetection.getRecursionDetectionPlugin(this.config));
        this.middlewareStack.use(core.getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: httpAuthSchemeProvider.defaultCloudWatchLogsHttpAuthSchemeParametersProvider,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new core.DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(core.getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
    var AssociateKmsKeyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "AssociateKmsKey", {}).n("CloudWatchLogsClient", "AssociateKmsKeyCommand").sc(schemas_0.AssociateKmsKey$).build() {
      static {
        __name(this, "AssociateKmsKeyCommand");
      }
    };
    var AssociateSourceToS3TableIntegrationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "AssociateSourceToS3TableIntegration", {}).n("CloudWatchLogsClient", "AssociateSourceToS3TableIntegrationCommand").sc(schemas_0.AssociateSourceToS3TableIntegration$).build() {
      static {
        __name(this, "AssociateSourceToS3TableIntegrationCommand");
      }
    };
    var CancelExportTaskCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "CancelExportTask", {}).n("CloudWatchLogsClient", "CancelExportTaskCommand").sc(schemas_0.CancelExportTask$).build() {
      static {
        __name(this, "CancelExportTaskCommand");
      }
    };
    var CancelImportTaskCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "CancelImportTask", {}).n("CloudWatchLogsClient", "CancelImportTaskCommand").sc(schemas_0.CancelImportTask$).build() {
      static {
        __name(this, "CancelImportTaskCommand");
      }
    };
    var CreateDeliveryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "CreateDelivery", {}).n("CloudWatchLogsClient", "CreateDeliveryCommand").sc(schemas_0.CreateDelivery$).build() {
      static {
        __name(this, "CreateDeliveryCommand");
      }
    };
    var CreateExportTaskCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "CreateExportTask", {}).n("CloudWatchLogsClient", "CreateExportTaskCommand").sc(schemas_0.CreateExportTask$).build() {
      static {
        __name(this, "CreateExportTaskCommand");
      }
    };
    var CreateImportTaskCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "CreateImportTask", {}).n("CloudWatchLogsClient", "CreateImportTaskCommand").sc(schemas_0.CreateImportTask$).build() {
      static {
        __name(this, "CreateImportTaskCommand");
      }
    };
    var CreateLogAnomalyDetectorCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "CreateLogAnomalyDetector", {}).n("CloudWatchLogsClient", "CreateLogAnomalyDetectorCommand").sc(schemas_0.CreateLogAnomalyDetector$).build() {
      static {
        __name(this, "CreateLogAnomalyDetectorCommand");
      }
    };
    var CreateLogGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "CreateLogGroup", {}).n("CloudWatchLogsClient", "CreateLogGroupCommand").sc(schemas_0.CreateLogGroup$).build() {
      static {
        __name(this, "CreateLogGroupCommand");
      }
    };
    var CreateLogStreamCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "CreateLogStream", {}).n("CloudWatchLogsClient", "CreateLogStreamCommand").sc(schemas_0.CreateLogStream$).build() {
      static {
        __name(this, "CreateLogStreamCommand");
      }
    };
    var CreateLookupTableCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "CreateLookupTable", {}).n("CloudWatchLogsClient", "CreateLookupTableCommand").sc(schemas_0.CreateLookupTable$).build() {
      static {
        __name(this, "CreateLookupTableCommand");
      }
    };
    var CreateScheduledQueryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "CreateScheduledQuery", {}).n("CloudWatchLogsClient", "CreateScheduledQueryCommand").sc(schemas_0.CreateScheduledQuery$).build() {
      static {
        __name(this, "CreateScheduledQueryCommand");
      }
    };
    var DeleteAccountPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DeleteAccountPolicy", {}).n("CloudWatchLogsClient", "DeleteAccountPolicyCommand").sc(schemas_0.DeleteAccountPolicy$).build() {
      static {
        __name(this, "DeleteAccountPolicyCommand");
      }
    };
    var DeleteDataProtectionPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DeleteDataProtectionPolicy", {}).n("CloudWatchLogsClient", "DeleteDataProtectionPolicyCommand").sc(schemas_0.DeleteDataProtectionPolicy$).build() {
      static {
        __name(this, "DeleteDataProtectionPolicyCommand");
      }
    };
    var DeleteDeliveryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DeleteDelivery", {}).n("CloudWatchLogsClient", "DeleteDeliveryCommand").sc(schemas_0.DeleteDelivery$).build() {
      static {
        __name(this, "DeleteDeliveryCommand");
      }
    };
    var DeleteDeliveryDestinationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DeleteDeliveryDestination", {}).n("CloudWatchLogsClient", "DeleteDeliveryDestinationCommand").sc(schemas_0.DeleteDeliveryDestination$).build() {
      static {
        __name(this, "DeleteDeliveryDestinationCommand");
      }
    };
    var DeleteDeliveryDestinationPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DeleteDeliveryDestinationPolicy", {}).n("CloudWatchLogsClient", "DeleteDeliveryDestinationPolicyCommand").sc(schemas_0.DeleteDeliveryDestinationPolicy$).build() {
      static {
        __name(this, "DeleteDeliveryDestinationPolicyCommand");
      }
    };
    var DeleteDeliverySourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DeleteDeliverySource", {}).n("CloudWatchLogsClient", "DeleteDeliverySourceCommand").sc(schemas_0.DeleteDeliverySource$).build() {
      static {
        __name(this, "DeleteDeliverySourceCommand");
      }
    };
    var DeleteDestinationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DeleteDestination", {}).n("CloudWatchLogsClient", "DeleteDestinationCommand").sc(schemas_0.DeleteDestination$).build() {
      static {
        __name(this, "DeleteDestinationCommand");
      }
    };
    var DeleteIndexPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DeleteIndexPolicy", {}).n("CloudWatchLogsClient", "DeleteIndexPolicyCommand").sc(schemas_0.DeleteIndexPolicy$).build() {
      static {
        __name(this, "DeleteIndexPolicyCommand");
      }
    };
    var DeleteIntegrationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DeleteIntegration", {}).n("CloudWatchLogsClient", "DeleteIntegrationCommand").sc(schemas_0.DeleteIntegration$).build() {
      static {
        __name(this, "DeleteIntegrationCommand");
      }
    };
    var DeleteLogAnomalyDetectorCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DeleteLogAnomalyDetector", {}).n("CloudWatchLogsClient", "DeleteLogAnomalyDetectorCommand").sc(schemas_0.DeleteLogAnomalyDetector$).build() {
      static {
        __name(this, "DeleteLogAnomalyDetectorCommand");
      }
    };
    var DeleteLogGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DeleteLogGroup", {}).n("CloudWatchLogsClient", "DeleteLogGroupCommand").sc(schemas_0.DeleteLogGroup$).build() {
      static {
        __name(this, "DeleteLogGroupCommand");
      }
    };
    var DeleteLogStreamCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DeleteLogStream", {}).n("CloudWatchLogsClient", "DeleteLogStreamCommand").sc(schemas_0.DeleteLogStream$).build() {
      static {
        __name(this, "DeleteLogStreamCommand");
      }
    };
    var DeleteLookupTableCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DeleteLookupTable", {}).n("CloudWatchLogsClient", "DeleteLookupTableCommand").sc(schemas_0.DeleteLookupTable$).build() {
      static {
        __name(this, "DeleteLookupTableCommand");
      }
    };
    var DeleteMetricFilterCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DeleteMetricFilter", {}).n("CloudWatchLogsClient", "DeleteMetricFilterCommand").sc(schemas_0.DeleteMetricFilter$).build() {
      static {
        __name(this, "DeleteMetricFilterCommand");
      }
    };
    var DeleteQueryDefinitionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DeleteQueryDefinition", {}).n("CloudWatchLogsClient", "DeleteQueryDefinitionCommand").sc(schemas_0.DeleteQueryDefinition$).build() {
      static {
        __name(this, "DeleteQueryDefinitionCommand");
      }
    };
    var DeleteResourcePolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DeleteResourcePolicy", {}).n("CloudWatchLogsClient", "DeleteResourcePolicyCommand").sc(schemas_0.DeleteResourcePolicy$).build() {
      static {
        __name(this, "DeleteResourcePolicyCommand");
      }
    };
    var DeleteRetentionPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DeleteRetentionPolicy", {}).n("CloudWatchLogsClient", "DeleteRetentionPolicyCommand").sc(schemas_0.DeleteRetentionPolicy$).build() {
      static {
        __name(this, "DeleteRetentionPolicyCommand");
      }
    };
    var DeleteScheduledQueryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DeleteScheduledQuery", {}).n("CloudWatchLogsClient", "DeleteScheduledQueryCommand").sc(schemas_0.DeleteScheduledQuery$).build() {
      static {
        __name(this, "DeleteScheduledQueryCommand");
      }
    };
    var DeleteSubscriptionFilterCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DeleteSubscriptionFilter", {}).n("CloudWatchLogsClient", "DeleteSubscriptionFilterCommand").sc(schemas_0.DeleteSubscriptionFilter$).build() {
      static {
        __name(this, "DeleteSubscriptionFilterCommand");
      }
    };
    var DeleteTransformerCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DeleteTransformer", {}).n("CloudWatchLogsClient", "DeleteTransformerCommand").sc(schemas_0.DeleteTransformer$).build() {
      static {
        __name(this, "DeleteTransformerCommand");
      }
    };
    var DescribeAccountPoliciesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DescribeAccountPolicies", {}).n("CloudWatchLogsClient", "DescribeAccountPoliciesCommand").sc(schemas_0.DescribeAccountPolicies$).build() {
      static {
        __name(this, "DescribeAccountPoliciesCommand");
      }
    };
    var DescribeConfigurationTemplatesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DescribeConfigurationTemplates", {}).n("CloudWatchLogsClient", "DescribeConfigurationTemplatesCommand").sc(schemas_0.DescribeConfigurationTemplates$).build() {
      static {
        __name(this, "DescribeConfigurationTemplatesCommand");
      }
    };
    var DescribeDeliveriesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DescribeDeliveries", {}).n("CloudWatchLogsClient", "DescribeDeliveriesCommand").sc(schemas_0.DescribeDeliveries$).build() {
      static {
        __name(this, "DescribeDeliveriesCommand");
      }
    };
    var DescribeDeliveryDestinationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DescribeDeliveryDestinations", {}).n("CloudWatchLogsClient", "DescribeDeliveryDestinationsCommand").sc(schemas_0.DescribeDeliveryDestinations$).build() {
      static {
        __name(this, "DescribeDeliveryDestinationsCommand");
      }
    };
    var DescribeDeliverySourcesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DescribeDeliverySources", {}).n("CloudWatchLogsClient", "DescribeDeliverySourcesCommand").sc(schemas_0.DescribeDeliverySources$).build() {
      static {
        __name(this, "DescribeDeliverySourcesCommand");
      }
    };
    var DescribeDestinationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DescribeDestinations", {}).n("CloudWatchLogsClient", "DescribeDestinationsCommand").sc(schemas_0.DescribeDestinations$).build() {
      static {
        __name(this, "DescribeDestinationsCommand");
      }
    };
    var DescribeExportTasksCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DescribeExportTasks", {}).n("CloudWatchLogsClient", "DescribeExportTasksCommand").sc(schemas_0.DescribeExportTasks$).build() {
      static {
        __name(this, "DescribeExportTasksCommand");
      }
    };
    var DescribeFieldIndexesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DescribeFieldIndexes", {}).n("CloudWatchLogsClient", "DescribeFieldIndexesCommand").sc(schemas_0.DescribeFieldIndexes$).build() {
      static {
        __name(this, "DescribeFieldIndexesCommand");
      }
    };
    var DescribeImportTaskBatchesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DescribeImportTaskBatches", {}).n("CloudWatchLogsClient", "DescribeImportTaskBatchesCommand").sc(schemas_0.DescribeImportTaskBatches$).build() {
      static {
        __name(this, "DescribeImportTaskBatchesCommand");
      }
    };
    var DescribeImportTasksCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DescribeImportTasks", {}).n("CloudWatchLogsClient", "DescribeImportTasksCommand").sc(schemas_0.DescribeImportTasks$).build() {
      static {
        __name(this, "DescribeImportTasksCommand");
      }
    };
    var DescribeIndexPoliciesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DescribeIndexPolicies", {}).n("CloudWatchLogsClient", "DescribeIndexPoliciesCommand").sc(schemas_0.DescribeIndexPolicies$).build() {
      static {
        __name(this, "DescribeIndexPoliciesCommand");
      }
    };
    var DescribeLogGroupsCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DescribeLogGroups", {}).n("CloudWatchLogsClient", "DescribeLogGroupsCommand").sc(schemas_0.DescribeLogGroups$).build() {
      static {
        __name(this, "DescribeLogGroupsCommand");
      }
    };
    var DescribeLogStreamsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DescribeLogStreams", {}).n("CloudWatchLogsClient", "DescribeLogStreamsCommand").sc(schemas_0.DescribeLogStreams$).build() {
      static {
        __name(this, "DescribeLogStreamsCommand");
      }
    };
    var DescribeLookupTablesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DescribeLookupTables", {}).n("CloudWatchLogsClient", "DescribeLookupTablesCommand").sc(schemas_0.DescribeLookupTables$).build() {
      static {
        __name(this, "DescribeLookupTablesCommand");
      }
    };
    var DescribeMetricFiltersCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DescribeMetricFilters", {}).n("CloudWatchLogsClient", "DescribeMetricFiltersCommand").sc(schemas_0.DescribeMetricFilters$).build() {
      static {
        __name(this, "DescribeMetricFiltersCommand");
      }
    };
    var DescribeQueriesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DescribeQueries", {}).n("CloudWatchLogsClient", "DescribeQueriesCommand").sc(schemas_0.DescribeQueries$).build() {
      static {
        __name(this, "DescribeQueriesCommand");
      }
    };
    var DescribeQueryDefinitionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DescribeQueryDefinitions", {}).n("CloudWatchLogsClient", "DescribeQueryDefinitionsCommand").sc(schemas_0.DescribeQueryDefinitions$).build() {
      static {
        __name(this, "DescribeQueryDefinitionsCommand");
      }
    };
    var DescribeResourcePoliciesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DescribeResourcePolicies", {}).n("CloudWatchLogsClient", "DescribeResourcePoliciesCommand").sc(schemas_0.DescribeResourcePolicies$).build() {
      static {
        __name(this, "DescribeResourcePoliciesCommand");
      }
    };
    var DescribeSubscriptionFiltersCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DescribeSubscriptionFilters", {}).n("CloudWatchLogsClient", "DescribeSubscriptionFiltersCommand").sc(schemas_0.DescribeSubscriptionFilters$).build() {
      static {
        __name(this, "DescribeSubscriptionFiltersCommand");
      }
    };
    var DisassociateKmsKeyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DisassociateKmsKey", {}).n("CloudWatchLogsClient", "DisassociateKmsKeyCommand").sc(schemas_0.DisassociateKmsKey$).build() {
      static {
        __name(this, "DisassociateKmsKeyCommand");
      }
    };
    var DisassociateSourceFromS3TableIntegrationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "DisassociateSourceFromS3TableIntegration", {}).n("CloudWatchLogsClient", "DisassociateSourceFromS3TableIntegrationCommand").sc(schemas_0.DisassociateSourceFromS3TableIntegration$).build() {
      static {
        __name(this, "DisassociateSourceFromS3TableIntegrationCommand");
      }
    };
    var FilterLogEventsCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "FilterLogEvents", {}).n("CloudWatchLogsClient", "FilterLogEventsCommand").sc(schemas_0.FilterLogEvents$).build() {
      static {
        __name(this, "FilterLogEventsCommand");
      }
    };
    var GetDataProtectionPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "GetDataProtectionPolicy", {}).n("CloudWatchLogsClient", "GetDataProtectionPolicyCommand").sc(schemas_0.GetDataProtectionPolicy$).build() {
      static {
        __name(this, "GetDataProtectionPolicyCommand");
      }
    };
    var GetDeliveryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "GetDelivery", {}).n("CloudWatchLogsClient", "GetDeliveryCommand").sc(schemas_0.GetDelivery$).build() {
      static {
        __name(this, "GetDeliveryCommand");
      }
    };
    var GetDeliveryDestinationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "GetDeliveryDestination", {}).n("CloudWatchLogsClient", "GetDeliveryDestinationCommand").sc(schemas_0.GetDeliveryDestination$).build() {
      static {
        __name(this, "GetDeliveryDestinationCommand");
      }
    };
    var GetDeliveryDestinationPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "GetDeliveryDestinationPolicy", {}).n("CloudWatchLogsClient", "GetDeliveryDestinationPolicyCommand").sc(schemas_0.GetDeliveryDestinationPolicy$).build() {
      static {
        __name(this, "GetDeliveryDestinationPolicyCommand");
      }
    };
    var GetDeliverySourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "GetDeliverySource", {}).n("CloudWatchLogsClient", "GetDeliverySourceCommand").sc(schemas_0.GetDeliverySource$).build() {
      static {
        __name(this, "GetDeliverySourceCommand");
      }
    };
    var GetIntegrationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "GetIntegration", {}).n("CloudWatchLogsClient", "GetIntegrationCommand").sc(schemas_0.GetIntegration$).build() {
      static {
        __name(this, "GetIntegrationCommand");
      }
    };
    var GetLogAnomalyDetectorCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "GetLogAnomalyDetector", {}).n("CloudWatchLogsClient", "GetLogAnomalyDetectorCommand").sc(schemas_0.GetLogAnomalyDetector$).build() {
      static {
        __name(this, "GetLogAnomalyDetectorCommand");
      }
    };
    var GetLogEventsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "GetLogEvents", {}).n("CloudWatchLogsClient", "GetLogEventsCommand").sc(schemas_0.GetLogEvents$).build() {
      static {
        __name(this, "GetLogEventsCommand");
      }
    };
    var GetLogFieldsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "GetLogFields", {}).n("CloudWatchLogsClient", "GetLogFieldsCommand").sc(schemas_0.GetLogFields$).build() {
      static {
        __name(this, "GetLogFieldsCommand");
      }
    };
    var GetLogGroupFieldsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "GetLogGroupFields", {}).n("CloudWatchLogsClient", "GetLogGroupFieldsCommand").sc(schemas_0.GetLogGroupFields$).build() {
      static {
        __name(this, "GetLogGroupFieldsCommand");
      }
    };
    var GetLogObjectCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "GetLogObject", {
      eventStream: {
        output: true
      }
    }).n("CloudWatchLogsClient", "GetLogObjectCommand").sc(schemas_0.GetLogObject$).build() {
      static {
        __name(this, "GetLogObjectCommand");
      }
    };
    var GetLogRecordCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "GetLogRecord", {}).n("CloudWatchLogsClient", "GetLogRecordCommand").sc(schemas_0.GetLogRecord$).build() {
      static {
        __name(this, "GetLogRecordCommand");
      }
    };
    var GetLookupTableCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "GetLookupTable", {}).n("CloudWatchLogsClient", "GetLookupTableCommand").sc(schemas_0.GetLookupTable$).build() {
      static {
        __name(this, "GetLookupTableCommand");
      }
    };
    var GetQueryResultsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "GetQueryResults", {}).n("CloudWatchLogsClient", "GetQueryResultsCommand").sc(schemas_0.GetQueryResults$).build() {
      static {
        __name(this, "GetQueryResultsCommand");
      }
    };
    var GetScheduledQueryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "GetScheduledQuery", {}).n("CloudWatchLogsClient", "GetScheduledQueryCommand").sc(schemas_0.GetScheduledQuery$).build() {
      static {
        __name(this, "GetScheduledQueryCommand");
      }
    };
    var GetScheduledQueryHistoryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "GetScheduledQueryHistory", {}).n("CloudWatchLogsClient", "GetScheduledQueryHistoryCommand").sc(schemas_0.GetScheduledQueryHistory$).build() {
      static {
        __name(this, "GetScheduledQueryHistoryCommand");
      }
    };
    var GetTransformerCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "GetTransformer", {}).n("CloudWatchLogsClient", "GetTransformerCommand").sc(schemas_0.GetTransformer$).build() {
      static {
        __name(this, "GetTransformerCommand");
      }
    };
    var ListAggregateLogGroupSummariesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "ListAggregateLogGroupSummaries", {}).n("CloudWatchLogsClient", "ListAggregateLogGroupSummariesCommand").sc(schemas_0.ListAggregateLogGroupSummaries$).build() {
      static {
        __name(this, "ListAggregateLogGroupSummariesCommand");
      }
    };
    var ListAnomaliesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "ListAnomalies", {}).n("CloudWatchLogsClient", "ListAnomaliesCommand").sc(schemas_0.ListAnomalies$).build() {
      static {
        __name(this, "ListAnomaliesCommand");
      }
    };
    var ListIntegrationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "ListIntegrations", {}).n("CloudWatchLogsClient", "ListIntegrationsCommand").sc(schemas_0.ListIntegrations$).build() {
      static {
        __name(this, "ListIntegrationsCommand");
      }
    };
    var ListLogAnomalyDetectorsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "ListLogAnomalyDetectors", {}).n("CloudWatchLogsClient", "ListLogAnomalyDetectorsCommand").sc(schemas_0.ListLogAnomalyDetectors$).build() {
      static {
        __name(this, "ListLogAnomalyDetectorsCommand");
      }
    };
    var ListLogGroupsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "ListLogGroups", {}).n("CloudWatchLogsClient", "ListLogGroupsCommand").sc(schemas_0.ListLogGroups$).build() {
      static {
        __name(this, "ListLogGroupsCommand");
      }
    };
    var ListLogGroupsForQueryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "ListLogGroupsForQuery", {}).n("CloudWatchLogsClient", "ListLogGroupsForQueryCommand").sc(schemas_0.ListLogGroupsForQuery$).build() {
      static {
        __name(this, "ListLogGroupsForQueryCommand");
      }
    };
    var ListScheduledQueriesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "ListScheduledQueries", {}).n("CloudWatchLogsClient", "ListScheduledQueriesCommand").sc(schemas_0.ListScheduledQueries$).build() {
      static {
        __name(this, "ListScheduledQueriesCommand");
      }
    };
    var ListSourcesForS3TableIntegrationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "ListSourcesForS3TableIntegration", {}).n("CloudWatchLogsClient", "ListSourcesForS3TableIntegrationCommand").sc(schemas_0.ListSourcesForS3TableIntegration$).build() {
      static {
        __name(this, "ListSourcesForS3TableIntegrationCommand");
      }
    };
    var ListTagsForResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "ListTagsForResource", {}).n("CloudWatchLogsClient", "ListTagsForResourceCommand").sc(schemas_0.ListTagsForResource$).build() {
      static {
        __name(this, "ListTagsForResourceCommand");
      }
    };
    var ListTagsLogGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "ListTagsLogGroup", {}).n("CloudWatchLogsClient", "ListTagsLogGroupCommand").sc(schemas_0.ListTagsLogGroup$).build() {
      static {
        __name(this, "ListTagsLogGroupCommand");
      }
    };
    var PutAccountPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "PutAccountPolicy", {}).n("CloudWatchLogsClient", "PutAccountPolicyCommand").sc(schemas_0.PutAccountPolicy$).build() {
      static {
        __name(this, "PutAccountPolicyCommand");
      }
    };
    var PutBearerTokenAuthenticationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "PutBearerTokenAuthentication", {}).n("CloudWatchLogsClient", "PutBearerTokenAuthenticationCommand").sc(schemas_0.PutBearerTokenAuthentication$).build() {
      static {
        __name(this, "PutBearerTokenAuthenticationCommand");
      }
    };
    var PutDataProtectionPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "PutDataProtectionPolicy", {}).n("CloudWatchLogsClient", "PutDataProtectionPolicyCommand").sc(schemas_0.PutDataProtectionPolicy$).build() {
      static {
        __name(this, "PutDataProtectionPolicyCommand");
      }
    };
    var PutDeliveryDestinationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "PutDeliveryDestination", {}).n("CloudWatchLogsClient", "PutDeliveryDestinationCommand").sc(schemas_0.PutDeliveryDestination$).build() {
      static {
        __name(this, "PutDeliveryDestinationCommand");
      }
    };
    var PutDeliveryDestinationPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "PutDeliveryDestinationPolicy", {}).n("CloudWatchLogsClient", "PutDeliveryDestinationPolicyCommand").sc(schemas_0.PutDeliveryDestinationPolicy$).build() {
      static {
        __name(this, "PutDeliveryDestinationPolicyCommand");
      }
    };
    var PutDeliverySourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "PutDeliverySource", {}).n("CloudWatchLogsClient", "PutDeliverySourceCommand").sc(schemas_0.PutDeliverySource$).build() {
      static {
        __name(this, "PutDeliverySourceCommand");
      }
    };
    var PutDestinationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "PutDestination", {}).n("CloudWatchLogsClient", "PutDestinationCommand").sc(schemas_0.PutDestination$).build() {
      static {
        __name(this, "PutDestinationCommand");
      }
    };
    var PutDestinationPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "PutDestinationPolicy", {}).n("CloudWatchLogsClient", "PutDestinationPolicyCommand").sc(schemas_0.PutDestinationPolicy$).build() {
      static {
        __name(this, "PutDestinationPolicyCommand");
      }
    };
    var PutIndexPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "PutIndexPolicy", {}).n("CloudWatchLogsClient", "PutIndexPolicyCommand").sc(schemas_0.PutIndexPolicy$).build() {
      static {
        __name(this, "PutIndexPolicyCommand");
      }
    };
    var PutIntegrationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "PutIntegration", {}).n("CloudWatchLogsClient", "PutIntegrationCommand").sc(schemas_0.PutIntegration$).build() {
      static {
        __name(this, "PutIntegrationCommand");
      }
    };
    var PutLogEventsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "PutLogEvents", {}).n("CloudWatchLogsClient", "PutLogEventsCommand").sc(schemas_0.PutLogEvents$).build() {
      static {
        __name(this, "PutLogEventsCommand");
      }
    };
    var PutLogGroupDeletionProtectionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "PutLogGroupDeletionProtection", {}).n("CloudWatchLogsClient", "PutLogGroupDeletionProtectionCommand").sc(schemas_0.PutLogGroupDeletionProtection$).build() {
      static {
        __name(this, "PutLogGroupDeletionProtectionCommand");
      }
    };
    var PutMetricFilterCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "PutMetricFilter", {}).n("CloudWatchLogsClient", "PutMetricFilterCommand").sc(schemas_0.PutMetricFilter$).build() {
      static {
        __name(this, "PutMetricFilterCommand");
      }
    };
    var PutQueryDefinitionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "PutQueryDefinition", {}).n("CloudWatchLogsClient", "PutQueryDefinitionCommand").sc(schemas_0.PutQueryDefinition$).build() {
      static {
        __name(this, "PutQueryDefinitionCommand");
      }
    };
    var PutResourcePolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "PutResourcePolicy", {}).n("CloudWatchLogsClient", "PutResourcePolicyCommand").sc(schemas_0.PutResourcePolicy$).build() {
      static {
        __name(this, "PutResourcePolicyCommand");
      }
    };
    var PutRetentionPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "PutRetentionPolicy", {}).n("CloudWatchLogsClient", "PutRetentionPolicyCommand").sc(schemas_0.PutRetentionPolicy$).build() {
      static {
        __name(this, "PutRetentionPolicyCommand");
      }
    };
    var PutSubscriptionFilterCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "PutSubscriptionFilter", {}).n("CloudWatchLogsClient", "PutSubscriptionFilterCommand").sc(schemas_0.PutSubscriptionFilter$).build() {
      static {
        __name(this, "PutSubscriptionFilterCommand");
      }
    };
    var PutTransformerCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "PutTransformer", {}).n("CloudWatchLogsClient", "PutTransformerCommand").sc(schemas_0.PutTransformer$).build() {
      static {
        __name(this, "PutTransformerCommand");
      }
    };
    var StartLiveTailCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "StartLiveTail", {
      eventStream: {
        output: true
      }
    }).n("CloudWatchLogsClient", "StartLiveTailCommand").sc(schemas_0.StartLiveTail$).build() {
      static {
        __name(this, "StartLiveTailCommand");
      }
    };
    var StartQueryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "StartQuery", {}).n("CloudWatchLogsClient", "StartQueryCommand").sc(schemas_0.StartQuery$).build() {
      static {
        __name(this, "StartQueryCommand");
      }
    };
    var StopQueryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "StopQuery", {}).n("CloudWatchLogsClient", "StopQueryCommand").sc(schemas_0.StopQuery$).build() {
      static {
        __name(this, "StopQueryCommand");
      }
    };
    var TagLogGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "TagLogGroup", {}).n("CloudWatchLogsClient", "TagLogGroupCommand").sc(schemas_0.TagLogGroup$).build() {
      static {
        __name(this, "TagLogGroupCommand");
      }
    };
    var TagResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "TagResource", {}).n("CloudWatchLogsClient", "TagResourceCommand").sc(schemas_0.TagResource$).build() {
      static {
        __name(this, "TagResourceCommand");
      }
    };
    var TestMetricFilterCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "TestMetricFilter", {}).n("CloudWatchLogsClient", "TestMetricFilterCommand").sc(schemas_0.TestMetricFilter$).build() {
      static {
        __name(this, "TestMetricFilterCommand");
      }
    };
    var TestTransformerCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "TestTransformer", {}).n("CloudWatchLogsClient", "TestTransformerCommand").sc(schemas_0.TestTransformer$).build() {
      static {
        __name(this, "TestTransformerCommand");
      }
    };
    var UntagLogGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "UntagLogGroup", {}).n("CloudWatchLogsClient", "UntagLogGroupCommand").sc(schemas_0.UntagLogGroup$).build() {
      static {
        __name(this, "UntagLogGroupCommand");
      }
    };
    var UntagResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "UntagResource", {}).n("CloudWatchLogsClient", "UntagResourceCommand").sc(schemas_0.UntagResource$).build() {
      static {
        __name(this, "UntagResourceCommand");
      }
    };
    var UpdateAnomalyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "UpdateAnomaly", {}).n("CloudWatchLogsClient", "UpdateAnomalyCommand").sc(schemas_0.UpdateAnomaly$).build() {
      static {
        __name(this, "UpdateAnomalyCommand");
      }
    };
    var UpdateDeliveryConfigurationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "UpdateDeliveryConfiguration", {}).n("CloudWatchLogsClient", "UpdateDeliveryConfigurationCommand").sc(schemas_0.UpdateDeliveryConfiguration$).build() {
      static {
        __name(this, "UpdateDeliveryConfigurationCommand");
      }
    };
    var UpdateLogAnomalyDetectorCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "UpdateLogAnomalyDetector", {}).n("CloudWatchLogsClient", "UpdateLogAnomalyDetectorCommand").sc(schemas_0.UpdateLogAnomalyDetector$).build() {
      static {
        __name(this, "UpdateLogAnomalyDetectorCommand");
      }
    };
    var UpdateLookupTableCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "UpdateLookupTable", {}).n("CloudWatchLogsClient", "UpdateLookupTableCommand").sc(schemas_0.UpdateLookupTable$).build() {
      static {
        __name(this, "UpdateLookupTableCommand");
      }
    };
    var UpdateScheduledQueryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("Logs_20140328", "UpdateScheduledQuery", {}).n("CloudWatchLogsClient", "UpdateScheduledQueryCommand").sc(schemas_0.UpdateScheduledQuery$).build() {
      static {
        __name(this, "UpdateScheduledQueryCommand");
      }
    };
    var paginateDescribeConfigurationTemplates = core.createPaginator(CloudWatchLogsClient2, DescribeConfigurationTemplatesCommand, "nextToken", "nextToken", "limit");
    var paginateDescribeDeliveries = core.createPaginator(CloudWatchLogsClient2, DescribeDeliveriesCommand, "nextToken", "nextToken", "limit");
    var paginateDescribeDeliveryDestinations = core.createPaginator(CloudWatchLogsClient2, DescribeDeliveryDestinationsCommand, "nextToken", "nextToken", "limit");
    var paginateDescribeDeliverySources = core.createPaginator(CloudWatchLogsClient2, DescribeDeliverySourcesCommand, "nextToken", "nextToken", "limit");
    var paginateDescribeDestinations = core.createPaginator(CloudWatchLogsClient2, DescribeDestinationsCommand, "nextToken", "nextToken", "limit");
    var paginateDescribeLogGroups = core.createPaginator(CloudWatchLogsClient2, DescribeLogGroupsCommand2, "nextToken", "nextToken", "limit");
    var paginateDescribeLogStreams = core.createPaginator(CloudWatchLogsClient2, DescribeLogStreamsCommand, "nextToken", "nextToken", "limit");
    var paginateDescribeMetricFilters = core.createPaginator(CloudWatchLogsClient2, DescribeMetricFiltersCommand, "nextToken", "nextToken", "limit");
    var paginateDescribeSubscriptionFilters = core.createPaginator(CloudWatchLogsClient2, DescribeSubscriptionFiltersCommand, "nextToken", "nextToken", "limit");
    var paginateFilterLogEvents = core.createPaginator(CloudWatchLogsClient2, FilterLogEventsCommand2, "nextToken", "nextToken", "limit");
    var paginateGetLogEvents = core.createPaginator(CloudWatchLogsClient2, GetLogEventsCommand, "nextToken", "nextForwardToken", "limit");
    var paginateGetScheduledQueryHistory = core.createPaginator(CloudWatchLogsClient2, GetScheduledQueryHistoryCommand, "nextToken", "nextToken", "maxResults");
    var paginateListAggregateLogGroupSummaries = core.createPaginator(CloudWatchLogsClient2, ListAggregateLogGroupSummariesCommand, "nextToken", "nextToken", "limit");
    var paginateListAnomalies = core.createPaginator(CloudWatchLogsClient2, ListAnomaliesCommand, "nextToken", "nextToken", "limit");
    var paginateListLogAnomalyDetectors = core.createPaginator(CloudWatchLogsClient2, ListLogAnomalyDetectorsCommand, "nextToken", "nextToken", "limit");
    var paginateListLogGroupsForQuery = core.createPaginator(CloudWatchLogsClient2, ListLogGroupsForQueryCommand, "nextToken", "nextToken", "maxResults");
    var paginateListScheduledQueries = core.createPaginator(CloudWatchLogsClient2, ListScheduledQueriesCommand, "nextToken", "nextToken", "maxResults");
    var paginateListSourcesForS3TableIntegration = core.createPaginator(CloudWatchLogsClient2, ListSourcesForS3TableIntegrationCommand, "nextToken", "nextToken", "maxResults");
    var commands32 = {
      AssociateKmsKeyCommand,
      AssociateSourceToS3TableIntegrationCommand,
      CancelExportTaskCommand,
      CancelImportTaskCommand,
      CreateDeliveryCommand,
      CreateExportTaskCommand,
      CreateImportTaskCommand,
      CreateLogAnomalyDetectorCommand,
      CreateLogGroupCommand,
      CreateLogStreamCommand,
      CreateLookupTableCommand,
      CreateScheduledQueryCommand,
      DeleteAccountPolicyCommand,
      DeleteDataProtectionPolicyCommand,
      DeleteDeliveryCommand,
      DeleteDeliveryDestinationCommand,
      DeleteDeliveryDestinationPolicyCommand,
      DeleteDeliverySourceCommand,
      DeleteDestinationCommand,
      DeleteIndexPolicyCommand,
      DeleteIntegrationCommand,
      DeleteLogAnomalyDetectorCommand,
      DeleteLogGroupCommand,
      DeleteLogStreamCommand,
      DeleteLookupTableCommand,
      DeleteMetricFilterCommand,
      DeleteQueryDefinitionCommand,
      DeleteResourcePolicyCommand,
      DeleteRetentionPolicyCommand,
      DeleteScheduledQueryCommand,
      DeleteSubscriptionFilterCommand,
      DeleteTransformerCommand,
      DescribeAccountPoliciesCommand,
      DescribeConfigurationTemplatesCommand,
      DescribeDeliveriesCommand,
      DescribeDeliveryDestinationsCommand,
      DescribeDeliverySourcesCommand,
      DescribeDestinationsCommand,
      DescribeExportTasksCommand,
      DescribeFieldIndexesCommand,
      DescribeImportTaskBatchesCommand,
      DescribeImportTasksCommand,
      DescribeIndexPoliciesCommand,
      DescribeLogGroupsCommand: DescribeLogGroupsCommand2,
      DescribeLogStreamsCommand,
      DescribeLookupTablesCommand,
      DescribeMetricFiltersCommand,
      DescribeQueriesCommand,
      DescribeQueryDefinitionsCommand,
      DescribeResourcePoliciesCommand,
      DescribeSubscriptionFiltersCommand,
      DisassociateKmsKeyCommand,
      DisassociateSourceFromS3TableIntegrationCommand,
      FilterLogEventsCommand: FilterLogEventsCommand2,
      GetDataProtectionPolicyCommand,
      GetDeliveryCommand,
      GetDeliveryDestinationCommand,
      GetDeliveryDestinationPolicyCommand,
      GetDeliverySourceCommand,
      GetIntegrationCommand,
      GetLogAnomalyDetectorCommand,
      GetLogEventsCommand,
      GetLogFieldsCommand,
      GetLogGroupFieldsCommand,
      GetLogObjectCommand,
      GetLogRecordCommand,
      GetLookupTableCommand,
      GetQueryResultsCommand,
      GetScheduledQueryCommand,
      GetScheduledQueryHistoryCommand,
      GetTransformerCommand,
      ListAggregateLogGroupSummariesCommand,
      ListAnomaliesCommand,
      ListIntegrationsCommand,
      ListLogAnomalyDetectorsCommand,
      ListLogGroupsCommand,
      ListLogGroupsForQueryCommand,
      ListScheduledQueriesCommand,
      ListSourcesForS3TableIntegrationCommand,
      ListTagsForResourceCommand,
      ListTagsLogGroupCommand,
      PutAccountPolicyCommand,
      PutBearerTokenAuthenticationCommand,
      PutDataProtectionPolicyCommand,
      PutDeliveryDestinationCommand,
      PutDeliveryDestinationPolicyCommand,
      PutDeliverySourceCommand,
      PutDestinationCommand,
      PutDestinationPolicyCommand,
      PutIndexPolicyCommand,
      PutIntegrationCommand,
      PutLogEventsCommand,
      PutLogGroupDeletionProtectionCommand,
      PutMetricFilterCommand,
      PutQueryDefinitionCommand,
      PutResourcePolicyCommand,
      PutRetentionPolicyCommand,
      PutSubscriptionFilterCommand,
      PutTransformerCommand,
      StartLiveTailCommand,
      StartQueryCommand,
      StopQueryCommand,
      TagLogGroupCommand,
      TagResourceCommand,
      TestMetricFilterCommand,
      TestTransformerCommand,
      UntagLogGroupCommand,
      UntagResourceCommand,
      UpdateAnomalyCommand,
      UpdateDeliveryConfigurationCommand,
      UpdateLogAnomalyDetectorCommand,
      UpdateLookupTableCommand,
      UpdateScheduledQueryCommand
    };
    var paginators = {
      paginateDescribeConfigurationTemplates,
      paginateDescribeDeliveries,
      paginateDescribeDeliveryDestinations,
      paginateDescribeDeliverySources,
      paginateDescribeDestinations,
      paginateDescribeLogGroups,
      paginateDescribeLogStreams,
      paginateDescribeMetricFilters,
      paginateDescribeSubscriptionFilters,
      paginateFilterLogEvents,
      paginateGetLogEvents,
      paginateGetScheduledQueryHistory,
      paginateListAggregateLogGroupSummaries,
      paginateListAnomalies,
      paginateListLogAnomalyDetectors,
      paginateListLogGroupsForQuery,
      paginateListScheduledQueries,
      paginateListSourcesForS3TableIntegration
    };
    var CloudWatchLogs = class extends CloudWatchLogsClient2 {
      static {
        __name(this, "CloudWatchLogs");
      }
    };
    smithyClient.createAggregatedClient(commands32, CloudWatchLogs, { paginators });
    var PolicyType = {
      DATA_PROTECTION_POLICY: "DATA_PROTECTION_POLICY",
      FIELD_INDEX_POLICY: "FIELD_INDEX_POLICY",
      METRIC_EXTRACTION_POLICY: "METRIC_EXTRACTION_POLICY",
      SUBSCRIPTION_FILTER_POLICY: "SUBSCRIPTION_FILTER_POLICY",
      TRANSFORMER_POLICY: "TRANSFORMER_POLICY"
    };
    var Scope = {
      ALL: "ALL"
    };
    var ActionStatus = {
      CLIENT_ERROR: "CLIENT_ERROR",
      COMPLETE: "COMPLETE",
      FAILED: "FAILED",
      IN_PROGRESS: "IN_PROGRESS"
    };
    var State = {
      Active: "Active",
      Baseline: "Baseline",
      Suppressed: "Suppressed"
    };
    var AnomalyDetectorStatus = {
      ANALYZING: "ANALYZING",
      DELETED: "DELETED",
      FAILED: "FAILED",
      INITIALIZING: "INITIALIZING",
      PAUSED: "PAUSED",
      TRAINING: "TRAINING"
    };
    var EvaluationFrequency = {
      FIFTEEN_MIN: "FIFTEEN_MIN",
      FIVE_MIN: "FIVE_MIN",
      ONE_HOUR: "ONE_HOUR",
      ONE_MIN: "ONE_MIN",
      TEN_MIN: "TEN_MIN",
      THIRTY_MIN: "THIRTY_MIN"
    };
    var ImportStatus = {
      CANCELLED: "CANCELLED",
      COMPLETED: "COMPLETED",
      FAILED: "FAILED",
      IN_PROGRESS: "IN_PROGRESS"
    };
    var OutputFormat = {
      JSON: "json",
      PARQUET: "parquet",
      PLAIN: "plain",
      RAW: "raw",
      W3C: "w3c"
    };
    var DeliveryDestinationType = {
      CWL: "CWL",
      FH: "FH",
      S3: "S3",
      XRAY: "XRAY"
    };
    var LogGroupClass = {
      DELIVERY: "DELIVERY",
      INFREQUENT_ACCESS: "INFREQUENT_ACCESS",
      STANDARD: "STANDARD"
    };
    var QueryLanguage = {
      CWLI: "CWLI",
      PPL: "PPL",
      SQL: "SQL"
    };
    var ScheduledQueryState = {
      DISABLED: "DISABLED",
      ENABLED: "ENABLED"
    };
    var DataProtectionStatus = {
      ACTIVATED: "ACTIVATED",
      ARCHIVED: "ARCHIVED",
      DELETED: "DELETED",
      DISABLED: "DISABLED"
    };
    var ExportTaskStatusCode = {
      CANCELLED: "CANCELLED",
      COMPLETED: "COMPLETED",
      FAILED: "FAILED",
      PENDING: "PENDING",
      PENDING_CANCEL: "PENDING_CANCEL",
      RUNNING: "RUNNING"
    };
    var IndexType = {
      FACET: "FACET",
      FIELD_INDEX: "FIELD_INDEX"
    };
    var IndexSource = {
      ACCOUNT: "ACCOUNT",
      LOG_GROUP: "LOG_GROUP"
    };
    var InheritedProperty = {
      ACCOUNT_DATA_PROTECTION: "ACCOUNT_DATA_PROTECTION"
    };
    var OrderBy = {
      LastEventTime: "LastEventTime",
      LogStreamName: "LogStreamName"
    };
    var StandardUnit = {
      Bits: "Bits",
      BitsSecond: "Bits/Second",
      Bytes: "Bytes",
      BytesSecond: "Bytes/Second",
      Count: "Count",
      CountSecond: "Count/Second",
      Gigabits: "Gigabits",
      GigabitsSecond: "Gigabits/Second",
      Gigabytes: "Gigabytes",
      GigabytesSecond: "Gigabytes/Second",
      Kilobits: "Kilobits",
      KilobitsSecond: "Kilobits/Second",
      Kilobytes: "Kilobytes",
      KilobytesSecond: "Kilobytes/Second",
      Megabits: "Megabits",
      MegabitsSecond: "Megabits/Second",
      Megabytes: "Megabytes",
      MegabytesSecond: "Megabytes/Second",
      Microseconds: "Microseconds",
      Milliseconds: "Milliseconds",
      None: "None",
      Percent: "Percent",
      Seconds: "Seconds",
      Terabits: "Terabits",
      TerabitsSecond: "Terabits/Second",
      Terabytes: "Terabytes",
      TerabytesSecond: "Terabytes/Second"
    };
    var QueryStatus = {
      Cancelled: "Cancelled",
      Complete: "Complete",
      Failed: "Failed",
      Running: "Running",
      Scheduled: "Scheduled",
      Timeout: "Timeout",
      Unknown: "Unknown"
    };
    var PolicyScope = {
      ACCOUNT: "ACCOUNT",
      RESOURCE: "RESOURCE"
    };
    var Distribution = {
      ByLogStream: "ByLogStream",
      Random: "Random"
    };
    var EntityRejectionErrorType = {
      ENTITY_SIZE_TOO_LARGE: "EntitySizeTooLarge",
      INVALID_ATTRIBUTES: "InvalidAttributes",
      INVALID_ENTITY: "InvalidEntity",
      INVALID_KEY_ATTRIBUTE: "InvalidKeyAttributes",
      INVALID_TYPE_VALUE: "InvalidTypeValue",
      MISSING_REQUIRED_FIELDS: "MissingRequiredFields",
      UNSUPPORTED_LOG_GROUP_TYPE: "UnsupportedLogGroupType"
    };
    var EventSource = {
      AWSWAF: "AWSWAF",
      CLOUD_TRAIL: "CloudTrail",
      EKS_AUDIT: "EKSAudit",
      ROUTE53_RESOLVER: "Route53Resolver",
      VPC_FLOW: "VPCFlow"
    };
    var ExecutionStatus = {
      Complete: "Complete",
      Failed: "Failed",
      InvalidQuery: "InvalidQuery",
      Running: "Running",
      Timeout: "Timeout"
    };
    var FlattenedElement = {
      FIRST: "first",
      LAST: "last"
    };
    var OpenSearchResourceStatusType = {
      ACTIVE: "ACTIVE",
      ERROR: "ERROR",
      NOT_FOUND: "NOT_FOUND"
    };
    var IntegrationStatus = {
      ACTIVE: "ACTIVE",
      FAILED: "FAILED",
      PROVISIONING: "PROVISIONING"
    };
    var IntegrationType = {
      OPENSEARCH: "OPENSEARCH"
    };
    var ScheduledQueryDestinationType = {
      S3: "S3"
    };
    var OCSFVersion = {
      V1_1: "V1.1",
      V1_5: "V1.5"
    };
    var Type = {
      BOOLEAN: "boolean",
      DOUBLE: "double",
      INTEGER: "integer",
      STRING: "string"
    };
    var ListAggregateLogGroupSummariesGroupBy = {
      DATA_SOURCE_NAME_AND_TYPE: "DATA_SOURCE_NAME_AND_TYPE",
      DATA_SOURCE_NAME_TYPE_AND_FORMAT: "DATA_SOURCE_NAME_TYPE_AND_FORMAT"
    };
    var SuppressionState = {
      SUPPRESSED: "SUPPRESSED",
      UNSUPPRESSED: "UNSUPPRESSED"
    };
    var S3TableIntegrationSourceStatus = {
      ACTIVE: "ACTIVE",
      DATA_SOURCE_DELETE_IN_PROGRESS: "DATA_SOURCE_DELETE_IN_PROGRESS",
      FAILED: "FAILED",
      UNHEALTHY: "UNHEALTHY"
    };
    var SuppressionUnit = {
      HOURS: "HOURS",
      MINUTES: "MINUTES",
      SECONDS: "SECONDS"
    };
    var SuppressionType = {
      INFINITE: "INFINITE",
      LIMITED: "LIMITED"
    };
    exports2.$Command = smithyClient.Command;
    exports2.__Client = smithyClient.Client;
    exports2.CloudWatchLogsServiceException = CloudWatchLogsServiceException.CloudWatchLogsServiceException;
    exports2.ActionStatus = ActionStatus;
    exports2.AnomalyDetectorStatus = AnomalyDetectorStatus;
    exports2.AssociateKmsKeyCommand = AssociateKmsKeyCommand;
    exports2.AssociateSourceToS3TableIntegrationCommand = AssociateSourceToS3TableIntegrationCommand;
    exports2.CancelExportTaskCommand = CancelExportTaskCommand;
    exports2.CancelImportTaskCommand = CancelImportTaskCommand;
    exports2.CloudWatchLogs = CloudWatchLogs;
    exports2.CloudWatchLogsClient = CloudWatchLogsClient2;
    exports2.CreateDeliveryCommand = CreateDeliveryCommand;
    exports2.CreateExportTaskCommand = CreateExportTaskCommand;
    exports2.CreateImportTaskCommand = CreateImportTaskCommand;
    exports2.CreateLogAnomalyDetectorCommand = CreateLogAnomalyDetectorCommand;
    exports2.CreateLogGroupCommand = CreateLogGroupCommand;
    exports2.CreateLogStreamCommand = CreateLogStreamCommand;
    exports2.CreateLookupTableCommand = CreateLookupTableCommand;
    exports2.CreateScheduledQueryCommand = CreateScheduledQueryCommand;
    exports2.DataProtectionStatus = DataProtectionStatus;
    exports2.DeleteAccountPolicyCommand = DeleteAccountPolicyCommand;
    exports2.DeleteDataProtectionPolicyCommand = DeleteDataProtectionPolicyCommand;
    exports2.DeleteDeliveryCommand = DeleteDeliveryCommand;
    exports2.DeleteDeliveryDestinationCommand = DeleteDeliveryDestinationCommand;
    exports2.DeleteDeliveryDestinationPolicyCommand = DeleteDeliveryDestinationPolicyCommand;
    exports2.DeleteDeliverySourceCommand = DeleteDeliverySourceCommand;
    exports2.DeleteDestinationCommand = DeleteDestinationCommand;
    exports2.DeleteIndexPolicyCommand = DeleteIndexPolicyCommand;
    exports2.DeleteIntegrationCommand = DeleteIntegrationCommand;
    exports2.DeleteLogAnomalyDetectorCommand = DeleteLogAnomalyDetectorCommand;
    exports2.DeleteLogGroupCommand = DeleteLogGroupCommand;
    exports2.DeleteLogStreamCommand = DeleteLogStreamCommand;
    exports2.DeleteLookupTableCommand = DeleteLookupTableCommand;
    exports2.DeleteMetricFilterCommand = DeleteMetricFilterCommand;
    exports2.DeleteQueryDefinitionCommand = DeleteQueryDefinitionCommand;
    exports2.DeleteResourcePolicyCommand = DeleteResourcePolicyCommand;
    exports2.DeleteRetentionPolicyCommand = DeleteRetentionPolicyCommand;
    exports2.DeleteScheduledQueryCommand = DeleteScheduledQueryCommand;
    exports2.DeleteSubscriptionFilterCommand = DeleteSubscriptionFilterCommand;
    exports2.DeleteTransformerCommand = DeleteTransformerCommand;
    exports2.DeliveryDestinationType = DeliveryDestinationType;
    exports2.DescribeAccountPoliciesCommand = DescribeAccountPoliciesCommand;
    exports2.DescribeConfigurationTemplatesCommand = DescribeConfigurationTemplatesCommand;
    exports2.DescribeDeliveriesCommand = DescribeDeliveriesCommand;
    exports2.DescribeDeliveryDestinationsCommand = DescribeDeliveryDestinationsCommand;
    exports2.DescribeDeliverySourcesCommand = DescribeDeliverySourcesCommand;
    exports2.DescribeDestinationsCommand = DescribeDestinationsCommand;
    exports2.DescribeExportTasksCommand = DescribeExportTasksCommand;
    exports2.DescribeFieldIndexesCommand = DescribeFieldIndexesCommand;
    exports2.DescribeImportTaskBatchesCommand = DescribeImportTaskBatchesCommand;
    exports2.DescribeImportTasksCommand = DescribeImportTasksCommand;
    exports2.DescribeIndexPoliciesCommand = DescribeIndexPoliciesCommand;
    exports2.DescribeLogGroupsCommand = DescribeLogGroupsCommand2;
    exports2.DescribeLogStreamsCommand = DescribeLogStreamsCommand;
    exports2.DescribeLookupTablesCommand = DescribeLookupTablesCommand;
    exports2.DescribeMetricFiltersCommand = DescribeMetricFiltersCommand;
    exports2.DescribeQueriesCommand = DescribeQueriesCommand;
    exports2.DescribeQueryDefinitionsCommand = DescribeQueryDefinitionsCommand;
    exports2.DescribeResourcePoliciesCommand = DescribeResourcePoliciesCommand;
    exports2.DescribeSubscriptionFiltersCommand = DescribeSubscriptionFiltersCommand;
    exports2.DisassociateKmsKeyCommand = DisassociateKmsKeyCommand;
    exports2.DisassociateSourceFromS3TableIntegrationCommand = DisassociateSourceFromS3TableIntegrationCommand;
    exports2.Distribution = Distribution;
    exports2.EntityRejectionErrorType = EntityRejectionErrorType;
    exports2.EvaluationFrequency = EvaluationFrequency;
    exports2.EventSource = EventSource;
    exports2.ExecutionStatus = ExecutionStatus;
    exports2.ExportTaskStatusCode = ExportTaskStatusCode;
    exports2.FilterLogEventsCommand = FilterLogEventsCommand2;
    exports2.FlattenedElement = FlattenedElement;
    exports2.GetDataProtectionPolicyCommand = GetDataProtectionPolicyCommand;
    exports2.GetDeliveryCommand = GetDeliveryCommand;
    exports2.GetDeliveryDestinationCommand = GetDeliveryDestinationCommand;
    exports2.GetDeliveryDestinationPolicyCommand = GetDeliveryDestinationPolicyCommand;
    exports2.GetDeliverySourceCommand = GetDeliverySourceCommand;
    exports2.GetIntegrationCommand = GetIntegrationCommand;
    exports2.GetLogAnomalyDetectorCommand = GetLogAnomalyDetectorCommand;
    exports2.GetLogEventsCommand = GetLogEventsCommand;
    exports2.GetLogFieldsCommand = GetLogFieldsCommand;
    exports2.GetLogGroupFieldsCommand = GetLogGroupFieldsCommand;
    exports2.GetLogObjectCommand = GetLogObjectCommand;
    exports2.GetLogRecordCommand = GetLogRecordCommand;
    exports2.GetLookupTableCommand = GetLookupTableCommand;
    exports2.GetQueryResultsCommand = GetQueryResultsCommand;
    exports2.GetScheduledQueryCommand = GetScheduledQueryCommand;
    exports2.GetScheduledQueryHistoryCommand = GetScheduledQueryHistoryCommand;
    exports2.GetTransformerCommand = GetTransformerCommand;
    exports2.ImportStatus = ImportStatus;
    exports2.IndexSource = IndexSource;
    exports2.IndexType = IndexType;
    exports2.InheritedProperty = InheritedProperty;
    exports2.IntegrationStatus = IntegrationStatus;
    exports2.IntegrationType = IntegrationType;
    exports2.ListAggregateLogGroupSummariesCommand = ListAggregateLogGroupSummariesCommand;
    exports2.ListAggregateLogGroupSummariesGroupBy = ListAggregateLogGroupSummariesGroupBy;
    exports2.ListAnomaliesCommand = ListAnomaliesCommand;
    exports2.ListIntegrationsCommand = ListIntegrationsCommand;
    exports2.ListLogAnomalyDetectorsCommand = ListLogAnomalyDetectorsCommand;
    exports2.ListLogGroupsCommand = ListLogGroupsCommand;
    exports2.ListLogGroupsForQueryCommand = ListLogGroupsForQueryCommand;
    exports2.ListScheduledQueriesCommand = ListScheduledQueriesCommand;
    exports2.ListSourcesForS3TableIntegrationCommand = ListSourcesForS3TableIntegrationCommand;
    exports2.ListTagsForResourceCommand = ListTagsForResourceCommand;
    exports2.ListTagsLogGroupCommand = ListTagsLogGroupCommand;
    exports2.LogGroupClass = LogGroupClass;
    exports2.OCSFVersion = OCSFVersion;
    exports2.OpenSearchResourceStatusType = OpenSearchResourceStatusType;
    exports2.OrderBy = OrderBy;
    exports2.OutputFormat = OutputFormat;
    exports2.PolicyScope = PolicyScope;
    exports2.PolicyType = PolicyType;
    exports2.PutAccountPolicyCommand = PutAccountPolicyCommand;
    exports2.PutBearerTokenAuthenticationCommand = PutBearerTokenAuthenticationCommand;
    exports2.PutDataProtectionPolicyCommand = PutDataProtectionPolicyCommand;
    exports2.PutDeliveryDestinationCommand = PutDeliveryDestinationCommand;
    exports2.PutDeliveryDestinationPolicyCommand = PutDeliveryDestinationPolicyCommand;
    exports2.PutDeliverySourceCommand = PutDeliverySourceCommand;
    exports2.PutDestinationCommand = PutDestinationCommand;
    exports2.PutDestinationPolicyCommand = PutDestinationPolicyCommand;
    exports2.PutIndexPolicyCommand = PutIndexPolicyCommand;
    exports2.PutIntegrationCommand = PutIntegrationCommand;
    exports2.PutLogEventsCommand = PutLogEventsCommand;
    exports2.PutLogGroupDeletionProtectionCommand = PutLogGroupDeletionProtectionCommand;
    exports2.PutMetricFilterCommand = PutMetricFilterCommand;
    exports2.PutQueryDefinitionCommand = PutQueryDefinitionCommand;
    exports2.PutResourcePolicyCommand = PutResourcePolicyCommand;
    exports2.PutRetentionPolicyCommand = PutRetentionPolicyCommand;
    exports2.PutSubscriptionFilterCommand = PutSubscriptionFilterCommand;
    exports2.PutTransformerCommand = PutTransformerCommand;
    exports2.QueryLanguage = QueryLanguage;
    exports2.QueryStatus = QueryStatus;
    exports2.S3TableIntegrationSourceStatus = S3TableIntegrationSourceStatus;
    exports2.ScheduledQueryDestinationType = ScheduledQueryDestinationType;
    exports2.ScheduledQueryState = ScheduledQueryState;
    exports2.Scope = Scope;
    exports2.StandardUnit = StandardUnit;
    exports2.StartLiveTailCommand = StartLiveTailCommand;
    exports2.StartQueryCommand = StartQueryCommand;
    exports2.State = State;
    exports2.StopQueryCommand = StopQueryCommand;
    exports2.SuppressionState = SuppressionState;
    exports2.SuppressionType = SuppressionType;
    exports2.SuppressionUnit = SuppressionUnit;
    exports2.TagLogGroupCommand = TagLogGroupCommand;
    exports2.TagResourceCommand = TagResourceCommand;
    exports2.TestMetricFilterCommand = TestMetricFilterCommand;
    exports2.TestTransformerCommand = TestTransformerCommand;
    exports2.Type = Type;
    exports2.UntagLogGroupCommand = UntagLogGroupCommand;
    exports2.UntagResourceCommand = UntagResourceCommand;
    exports2.UpdateAnomalyCommand = UpdateAnomalyCommand;
    exports2.UpdateDeliveryConfigurationCommand = UpdateDeliveryConfigurationCommand;
    exports2.UpdateLogAnomalyDetectorCommand = UpdateLogAnomalyDetectorCommand;
    exports2.UpdateLookupTableCommand = UpdateLookupTableCommand;
    exports2.UpdateScheduledQueryCommand = UpdateScheduledQueryCommand;
    exports2.paginateDescribeConfigurationTemplates = paginateDescribeConfigurationTemplates;
    exports2.paginateDescribeDeliveries = paginateDescribeDeliveries;
    exports2.paginateDescribeDeliveryDestinations = paginateDescribeDeliveryDestinations;
    exports2.paginateDescribeDeliverySources = paginateDescribeDeliverySources;
    exports2.paginateDescribeDestinations = paginateDescribeDestinations;
    exports2.paginateDescribeLogGroups = paginateDescribeLogGroups;
    exports2.paginateDescribeLogStreams = paginateDescribeLogStreams;
    exports2.paginateDescribeMetricFilters = paginateDescribeMetricFilters;
    exports2.paginateDescribeSubscriptionFilters = paginateDescribeSubscriptionFilters;
    exports2.paginateFilterLogEvents = paginateFilterLogEvents;
    exports2.paginateGetLogEvents = paginateGetLogEvents;
    exports2.paginateGetScheduledQueryHistory = paginateGetScheduledQueryHistory;
    exports2.paginateListAggregateLogGroupSummaries = paginateListAggregateLogGroupSummaries;
    exports2.paginateListAnomalies = paginateListAnomalies;
    exports2.paginateListLogAnomalyDetectors = paginateListLogAnomalyDetectors;
    exports2.paginateListLogGroupsForQuery = paginateListLogGroupsForQuery;
    exports2.paginateListScheduledQueries = paginateListScheduledQueries;
    exports2.paginateListSourcesForS3TableIntegration = paginateListSourcesForS3TableIntegration;
    Object.prototype.hasOwnProperty.call(schemas_0, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: schemas_0["__proto__"]
    });
    Object.keys(schemas_0).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = schemas_0[k32];
    });
    Object.prototype.hasOwnProperty.call(errors, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: errors["__proto__"]
    });
    Object.keys(errors).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = errors[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-codebuild/dist-cjs/auth/httpAuthSchemeProvider.js
var require_httpAuthSchemeProvider10 = __commonJS({
  "../../node_modules/@aws-sdk/client-codebuild/dist-cjs/auth/httpAuthSchemeProvider.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.resolveHttpAuthSchemeConfig = exports2.defaultCodeBuildHttpAuthSchemeProvider = exports2.defaultCodeBuildHttpAuthSchemeParametersProvider = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var util_middleware_1 = require_dist_cjs6();
    var defaultCodeBuildHttpAuthSchemeParametersProvider = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, util_middleware_1.getSmithyContext)(context).operation,
        region: await (0, util_middleware_1.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultCodeBuildHttpAuthSchemeParametersProvider");
    exports2.defaultCodeBuildHttpAuthSchemeParametersProvider = defaultCodeBuildHttpAuthSchemeParametersProvider;
    function createAwsAuthSigv4HttpAuthOption32(authParameters) {
      return {
        schemeId: "aws.auth#sigv4",
        signingProperties: {
          name: "codebuild",
          region: authParameters.region
        },
        propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
          signingProperties: {
            config: config2,
            context
          }
        }), "propertiesExtractor")
      };
    }
    __name(createAwsAuthSigv4HttpAuthOption32, "createAwsAuthSigv4HttpAuthOption");
    var defaultCodeBuildHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption32(authParameters));
        }
      }
      return options;
    }, "defaultCodeBuildHttpAuthSchemeProvider");
    exports2.defaultCodeBuildHttpAuthSchemeProvider = defaultCodeBuildHttpAuthSchemeProvider;
    var resolveHttpAuthSchemeConfig32 = /* @__PURE__ */ __name((config2) => {
      const config_0 = (0, httpAuthSchemes_1.resolveAwsSdkSigV4Config)(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, util_middleware_1.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
    exports2.resolveHttpAuthSchemeConfig = resolveHttpAuthSchemeConfig32;
  }
});

// ../../node_modules/@aws-sdk/client-codebuild/package.json
var require_package10 = __commonJS({
  "../../node_modules/@aws-sdk/client-codebuild/package.json"(exports2, module2) {
    module2.exports = {
      name: "@aws-sdk/client-codebuild",
      description: "AWS SDK for JavaScript Codebuild Client for Node.js, Browser and React Native",
      version: "3.1036.0",
      scripts: {
        build: "concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline client-codebuild",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        "extract:docs": "api-extractor run --local",
        "generate:client": "node ../../scripts/generate-clients/single-service --solo codebuild",
        "test:index": "tsc --noEmit ./test/index-types.ts && node ./test/index-objects.spec.mjs"
      },
      main: "./dist-cjs/index.js",
      types: "./dist-types/index.d.ts",
      module: "./dist-es/index.js",
      sideEffects: false,
      dependencies: {
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.5",
        "@aws-sdk/credential-provider-node": "^3.972.36",
        "@aws-sdk/middleware-host-header": "^3.972.10",
        "@aws-sdk/middleware-logger": "^3.972.10",
        "@aws-sdk/middleware-recursion-detection": "^3.972.11",
        "@aws-sdk/middleware-user-agent": "^3.972.35",
        "@aws-sdk/region-config-resolver": "^3.972.13",
        "@aws-sdk/types": "^3.973.8",
        "@aws-sdk/util-endpoints": "^3.996.8",
        "@aws-sdk/util-user-agent-browser": "^3.972.10",
        "@aws-sdk/util-user-agent-node": "^3.973.21",
        "@smithy/config-resolver": "^4.4.17",
        "@smithy/core": "^3.23.17",
        "@smithy/fetch-http-handler": "^5.3.17",
        "@smithy/hash-node": "^4.2.14",
        "@smithy/invalid-dependency": "^4.2.14",
        "@smithy/middleware-content-length": "^4.2.14",
        "@smithy/middleware-endpoint": "^4.4.32",
        "@smithy/middleware-retry": "^4.5.5",
        "@smithy/middleware-serde": "^4.2.20",
        "@smithy/middleware-stack": "^4.2.14",
        "@smithy/node-config-provider": "^4.3.14",
        "@smithy/node-http-handler": "^4.6.1",
        "@smithy/protocol-http": "^5.3.14",
        "@smithy/smithy-client": "^4.12.13",
        "@smithy/types": "^4.14.1",
        "@smithy/url-parser": "^4.2.14",
        "@smithy/util-base64": "^4.3.2",
        "@smithy/util-body-length-browser": "^4.2.2",
        "@smithy/util-body-length-node": "^4.2.3",
        "@smithy/util-defaults-mode-browser": "^4.3.49",
        "@smithy/util-defaults-mode-node": "^4.2.54",
        "@smithy/util-endpoints": "^3.4.2",
        "@smithy/util-middleware": "^4.2.14",
        "@smithy/util-retry": "^4.3.4",
        "@smithy/util-utf8": "^4.2.2",
        tslib: "^2.6.2"
      },
      devDependencies: {
        "@tsconfig/node20": "20.1.8",
        "@types/node": "^20.14.8",
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3"
      },
      engines: {
        node: ">=20.0.0"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "dist-*/**"
      ],
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      browser: {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.browser"
      },
      "react-native": {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.native"
      },
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/clients/client-codebuild",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "clients/client-codebuild"
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-codebuild/dist-cjs/endpoint/bdd.js
var require_bdd10 = __commonJS({
  "../../node_modules/@aws-sdk/client-codebuild/dist-cjs/endpoint/bdd.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.bdd = void 0;
    var util_endpoints_1 = require_dist_cjs20();
    var k32 = "ref";
    var a32 = -1;
    var b32 = true;
    var c32 = "isSet";
    var d32 = "PartitionResult";
    var e32 = "booleanEquals";
    var f32 = "getAttr";
    var g32 = { [k32]: "Endpoint" };
    var h32 = { [k32]: d32 };
    var i32 = {};
    var j32 = [{ [k32]: "Region" }];
    var _data32 = {
      conditions: [
        [c32, [g32]],
        [c32, j32],
        ["aws.partition", j32, d32],
        [e32, [{ [k32]: "UseFIPS" }, b32]],
        [e32, [{ [k32]: "UseDualStack" }, b32]],
        [e32, [{ fn: f32, argv: [h32, "supportsDualStack"] }, b32]],
        [e32, [{ fn: f32, argv: [h32, "supportsFIPS"] }, b32]]
      ],
      results: [
        [a32],
        [a32, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a32, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [g32, i32],
        ["https://codebuild-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", i32],
        [a32, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://codebuild-fips.{Region}.{PartitionResult#dnsSuffix}", i32],
        [a32, "FIPS is enabled but this partition does not support FIPS"],
        ["https://codebuild.{Region}.{PartitionResult#dualStackDnsSuffix}", i32],
        [a32, "DualStack is enabled but this partition does not support DualStack"],
        ["https://codebuild.{Region}.{PartitionResult#dnsSuffix}", i32],
        [a32, "Invalid Configuration: Missing Region"]
      ]
    };
    var root32 = 2;
    var r32 = 1e8;
    var nodes32 = new Int32Array([
      -1,
      1,
      -1,
      0,
      12,
      3,
      1,
      4,
      r32 + 11,
      2,
      5,
      r32 + 11,
      3,
      8,
      6,
      4,
      7,
      r32 + 10,
      5,
      r32 + 8,
      r32 + 9,
      4,
      10,
      9,
      6,
      r32 + 6,
      r32 + 7,
      5,
      11,
      r32 + 5,
      6,
      r32 + 4,
      r32 + 5,
      3,
      r32 + 1,
      13,
      4,
      r32 + 2,
      r32 + 3
    ]);
    exports2.bdd = util_endpoints_1.BinaryDecisionDiagram.from(nodes32, root32, _data32.conditions, _data32.results);
  }
});

// ../../node_modules/@aws-sdk/client-codebuild/dist-cjs/endpoint/endpointResolver.js
var require_endpointResolver10 = __commonJS({
  "../../node_modules/@aws-sdk/client-codebuild/dist-cjs/endpoint/endpointResolver.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.defaultEndpointResolver = void 0;
    var util_endpoints_1 = require_dist_cjs21();
    var util_endpoints_2 = require_dist_cjs20();
    var bdd_1 = require_bdd10();
    var cache32 = new util_endpoints_2.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    var defaultEndpointResolver32 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache32.get(endpointParams, () => (0, util_endpoints_2.decideEndpoint)(bdd_1.bdd, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    exports2.defaultEndpointResolver = defaultEndpointResolver32;
    util_endpoints_2.customEndpointFunctions.aws = util_endpoints_1.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-codebuild/dist-cjs/models/CodeBuildServiceException.js
var require_CodeBuildServiceException = __commonJS({
  "../../node_modules/@aws-sdk/client-codebuild/dist-cjs/models/CodeBuildServiceException.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.CodeBuildServiceException = exports2.__ServiceException = void 0;
    var smithy_client_1 = require_dist_cjs34();
    Object.defineProperty(exports2, "__ServiceException", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return smithy_client_1.ServiceException;
    }, "get") });
    var CodeBuildServiceException = class _CodeBuildServiceException extends smithy_client_1.ServiceException {
      static {
        __name(this, "CodeBuildServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _CodeBuildServiceException.prototype);
      }
    };
    exports2.CodeBuildServiceException = CodeBuildServiceException;
  }
});

// ../../node_modules/@aws-sdk/client-codebuild/dist-cjs/models/errors.js
var require_errors10 = __commonJS({
  "../../node_modules/@aws-sdk/client-codebuild/dist-cjs/models/errors.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ResourceNotFoundException = exports2.OAuthProviderException = exports2.ResourceAlreadyExistsException = exports2.InvalidInputException = exports2.AccountSuspendedException = exports2.AccountLimitExceededException = void 0;
    var CodeBuildServiceException_1 = require_CodeBuildServiceException();
    var AccountLimitExceededException = class _AccountLimitExceededException extends CodeBuildServiceException_1.CodeBuildServiceException {
      static {
        __name(this, "AccountLimitExceededException");
      }
      name = "AccountLimitExceededException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "AccountLimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AccountLimitExceededException.prototype);
      }
    };
    exports2.AccountLimitExceededException = AccountLimitExceededException;
    var AccountSuspendedException = class _AccountSuspendedException extends CodeBuildServiceException_1.CodeBuildServiceException {
      static {
        __name(this, "AccountSuspendedException");
      }
      name = "AccountSuspendedException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "AccountSuspendedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AccountSuspendedException.prototype);
      }
    };
    exports2.AccountSuspendedException = AccountSuspendedException;
    var InvalidInputException = class _InvalidInputException extends CodeBuildServiceException_1.CodeBuildServiceException {
      static {
        __name(this, "InvalidInputException");
      }
      name = "InvalidInputException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidInputException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidInputException.prototype);
      }
    };
    exports2.InvalidInputException = InvalidInputException;
    var ResourceAlreadyExistsException = class _ResourceAlreadyExistsException extends CodeBuildServiceException_1.CodeBuildServiceException {
      static {
        __name(this, "ResourceAlreadyExistsException");
      }
      name = "ResourceAlreadyExistsException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ResourceAlreadyExistsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceAlreadyExistsException.prototype);
      }
    };
    exports2.ResourceAlreadyExistsException = ResourceAlreadyExistsException;
    var OAuthProviderException = class _OAuthProviderException extends CodeBuildServiceException_1.CodeBuildServiceException {
      static {
        __name(this, "OAuthProviderException");
      }
      name = "OAuthProviderException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "OAuthProviderException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _OAuthProviderException.prototype);
      }
    };
    exports2.OAuthProviderException = OAuthProviderException;
    var ResourceNotFoundException12 = class _ResourceNotFoundException extends CodeBuildServiceException_1.CodeBuildServiceException {
      static {
        __name(this, "ResourceNotFoundException");
      }
      name = "ResourceNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ResourceNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceNotFoundException.prototype);
      }
    };
    exports2.ResourceNotFoundException = ResourceNotFoundException12;
  }
});

// ../../node_modules/@aws-sdk/client-codebuild/dist-cjs/schemas/schemas_0.js
var require_schemas_010 = __commonJS({
  "../../node_modules/@aws-sdk/client-codebuild/dist-cjs/schemas/schemas_0.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.CreateWebhookInput$ = exports2.CreateReportGroupOutput$ = exports2.CreateReportGroupInput$ = exports2.CreateProjectOutput$ = exports2.CreateProjectInput$ = exports2.CreateFleetOutput$ = exports2.CreateFleetInput$ = exports2.ComputeConfiguration$ = exports2.CommandExecution$ = exports2.CodeCoverageReportSummary$ = exports2.CodeCoverage$ = exports2.CloudWatchLogsConfig$ = exports2.BuildSummary$ = exports2.BuildStatusConfig$ = exports2.BuildPhase$ = exports2.BuildNotDeleted$ = exports2.BuildGroup$ = exports2.BuildBatchPhase$ = exports2.BuildBatchFilter$ = exports2.BuildBatch$ = exports2.BuildArtifacts$ = exports2.Build$ = exports2.BatchRestrictions$ = exports2.BatchGetSandboxesOutput$ = exports2.BatchGetSandboxesInput$ = exports2.BatchGetReportsOutput$ = exports2.BatchGetReportsInput$ = exports2.BatchGetReportGroupsOutput$ = exports2.BatchGetReportGroupsInput$ = exports2.BatchGetProjectsOutput$ = exports2.BatchGetProjectsInput$ = exports2.BatchGetFleetsOutput$ = exports2.BatchGetFleetsInput$ = exports2.BatchGetCommandExecutionsOutput$ = exports2.BatchGetCommandExecutionsInput$ = exports2.BatchGetBuildsOutput$ = exports2.BatchGetBuildsInput$ = exports2.BatchGetBuildBatchesOutput$ = exports2.BatchGetBuildBatchesInput$ = exports2.BatchDeleteBuildsOutput$ = exports2.BatchDeleteBuildsInput$ = exports2.AutoRetryConfig$ = exports2.errorTypeRegistries = exports2.ResourceNotFoundException$ = exports2.ResourceAlreadyExistsException$ = exports2.OAuthProviderException$ = exports2.InvalidInputException$ = exports2.AccountSuspendedException$ = exports2.AccountLimitExceededException$ = exports2.CodeBuildServiceException$ = void 0;
    exports2.ListCommandExecutionsForSandboxInput$ = exports2.ListBuildsOutput$ = exports2.ListBuildsInput$ = exports2.ListBuildsForProjectOutput$ = exports2.ListBuildsForProjectInput$ = exports2.ListBuildBatchesOutput$ = exports2.ListBuildBatchesInput$ = exports2.ListBuildBatchesForProjectOutput$ = exports2.ListBuildBatchesForProjectInput$ = exports2.InvalidateProjectCacheOutput$ = exports2.InvalidateProjectCacheInput$ = exports2.ImportSourceCredentialsOutput$ = exports2.ImportSourceCredentialsInput$ = exports2.GitSubmodulesConfig$ = exports2.GetResourcePolicyOutput$ = exports2.GetResourcePolicyInput$ = exports2.GetReportGroupTrendOutput$ = exports2.GetReportGroupTrendInput$ = exports2.FleetStatus$ = exports2.FleetProxyRule$ = exports2.Fleet$ = exports2.ExportedEnvironmentVariable$ = exports2.EnvironmentVariable$ = exports2.EnvironmentPlatform$ = exports2.EnvironmentLanguage$ = exports2.EnvironmentImage$ = exports2.DockerServerStatus$ = exports2.DockerServer$ = exports2.DescribeTestCasesOutput$ = exports2.DescribeTestCasesInput$ = exports2.DescribeCodeCoveragesOutput$ = exports2.DescribeCodeCoveragesInput$ = exports2.DeleteWebhookOutput$ = exports2.DeleteWebhookInput$ = exports2.DeleteSourceCredentialsOutput$ = exports2.DeleteSourceCredentialsInput$ = exports2.DeleteResourcePolicyOutput$ = exports2.DeleteResourcePolicyInput$ = exports2.DeleteReportOutput$ = exports2.DeleteReportInput$ = exports2.DeleteReportGroupOutput$ = exports2.DeleteReportGroupInput$ = exports2.DeleteProjectOutput$ = exports2.DeleteProjectInput$ = exports2.DeleteFleetOutput$ = exports2.DeleteFleetInput$ = exports2.DeleteBuildBatchOutput$ = exports2.DeleteBuildBatchInput$ = exports2.DebugSession$ = exports2.CreateWebhookOutput$ = void 0;
    exports2.RetryBuildBatchInput$ = exports2.ResolvedArtifact$ = exports2.ReportWithRawData$ = exports2.ReportGroupTrendStats$ = exports2.ReportGroup$ = exports2.ReportFilter$ = exports2.ReportExportConfig$ = exports2.Report$ = exports2.RegistryCredential$ = exports2.PutResourcePolicyOutput$ = exports2.PutResourcePolicyInput$ = exports2.PullRequestBuildPolicy$ = exports2.ProxyConfiguration$ = exports2.ProjectSourceVersion$ = exports2.ProjectSource$ = exports2.ProjectFleet$ = exports2.ProjectFileSystemLocation$ = exports2.ProjectEnvironment$ = exports2.ProjectCache$ = exports2.ProjectBuildBatchConfig$ = exports2.ProjectBadge$ = exports2.ProjectArtifacts$ = exports2.Project$ = exports2.PhaseContext$ = exports2.NetworkInterface$ = exports2.LogsLocation$ = exports2.LogsConfig$ = exports2.ListSourceCredentialsOutput$ = exports2.ListSourceCredentialsInput$ = exports2.ListSharedReportGroupsOutput$ = exports2.ListSharedReportGroupsInput$ = exports2.ListSharedProjectsOutput$ = exports2.ListSharedProjectsInput$ = exports2.ListSandboxesOutput$ = exports2.ListSandboxesInput$ = exports2.ListSandboxesForProjectOutput$ = exports2.ListSandboxesForProjectInput$ = exports2.ListReportsOutput$ = exports2.ListReportsInput$ = exports2.ListReportsForReportGroupOutput$ = exports2.ListReportsForReportGroupInput$ = exports2.ListReportGroupsOutput$ = exports2.ListReportGroupsInput$ = exports2.ListProjectsOutput$ = exports2.ListProjectsInput$ = exports2.ListFleetsOutput$ = exports2.ListFleetsInput$ = exports2.ListCuratedEnvironmentImagesOutput$ = exports2.ListCuratedEnvironmentImagesInput$ = exports2.ListCommandExecutionsForSandboxOutput$ = void 0;
    exports2.BatchGetBuildBatches$ = exports2.BatchDeleteBuilds$ = exports2.WebhookFilter$ = exports2.Webhook$ = exports2.VpcConfig$ = exports2.UpdateWebhookOutput$ = exports2.UpdateWebhookInput$ = exports2.UpdateReportGroupOutput$ = exports2.UpdateReportGroupInput$ = exports2.UpdateProjectVisibilityOutput$ = exports2.UpdateProjectVisibilityInput$ = exports2.UpdateProjectOutput$ = exports2.UpdateProjectInput$ = exports2.UpdateFleetOutput$ = exports2.UpdateFleetInput$ = exports2.TestReportSummary$ = exports2.TestCaseFilter$ = exports2.TestCase$ = exports2.TargetTrackingScalingConfiguration$ = exports2.Tag$ = exports2.StopSandboxOutput$ = exports2.StopSandboxInput$ = exports2.StopBuildOutput$ = exports2.StopBuildInput$ = exports2.StopBuildBatchOutput$ = exports2.StopBuildBatchInput$ = exports2.StartSandboxOutput$ = exports2.StartSandboxInput$ = exports2.StartSandboxConnectionOutput$ = exports2.StartSandboxConnectionInput$ = exports2.StartCommandExecutionOutput$ = exports2.StartCommandExecutionInput$ = exports2.StartBuildOutput$ = exports2.StartBuildInput$ = exports2.StartBuildBatchOutput$ = exports2.StartBuildBatchInput$ = exports2.SSMSession$ = exports2.SourceCredentialsInfo$ = exports2.SourceAuth$ = exports2.ScopeConfiguration$ = exports2.ScalingConfigurationOutput$ = exports2.ScalingConfigurationInput$ = exports2.SandboxSessionPhase$ = exports2.SandboxSession$ = exports2.Sandbox$ = exports2.S3ReportExportConfig$ = exports2.S3LogsConfig$ = exports2.RetryBuildOutput$ = exports2.RetryBuildInput$ = exports2.RetryBuildBatchOutput$ = void 0;
    exports2.StopBuild$ = exports2.StartSandboxConnection$ = exports2.StartSandbox$ = exports2.StartCommandExecution$ = exports2.StartBuildBatch$ = exports2.StartBuild$ = exports2.RetryBuildBatch$ = exports2.RetryBuild$ = exports2.PutResourcePolicy$ = exports2.ListSourceCredentials$ = exports2.ListSharedReportGroups$ = exports2.ListSharedProjects$ = exports2.ListSandboxesForProject$ = exports2.ListSandboxes$ = exports2.ListReportsForReportGroup$ = exports2.ListReports$ = exports2.ListReportGroups$ = exports2.ListProjects$ = exports2.ListFleets$ = exports2.ListCuratedEnvironmentImages$ = exports2.ListCommandExecutionsForSandbox$ = exports2.ListBuildsForProject$ = exports2.ListBuilds$ = exports2.ListBuildBatchesForProject$ = exports2.ListBuildBatches$ = exports2.InvalidateProjectCache$ = exports2.ImportSourceCredentials$ = exports2.GetResourcePolicy$ = exports2.GetReportGroupTrend$ = exports2.DescribeTestCases$ = exports2.DescribeCodeCoverages$ = exports2.DeleteWebhook$ = exports2.DeleteSourceCredentials$ = exports2.DeleteResourcePolicy$ = exports2.DeleteReportGroup$ = exports2.DeleteReport$ = exports2.DeleteProject$ = exports2.DeleteFleet$ = exports2.DeleteBuildBatch$ = exports2.CreateWebhook$ = exports2.CreateReportGroup$ = exports2.CreateProject$ = exports2.CreateFleet$ = exports2.BatchGetSandboxes$ = exports2.BatchGetReports$ = exports2.BatchGetReportGroups$ = exports2.BatchGetProjects$ = exports2.BatchGetFleets$ = exports2.BatchGetCommandExecutions$ = exports2.BatchGetBuilds$ = void 0;
    exports2.UpdateWebhook$ = exports2.UpdateReportGroup$ = exports2.UpdateProjectVisibility$ = exports2.UpdateProject$ = exports2.UpdateFleet$ = exports2.StopSandbox$ = exports2.StopBuildBatch$ = void 0;
    var _ALEE = "AccountLimitExceededException";
    var _ARC = "AutoRetryConfig";
    var _ASE = "AccountSuspendedException";
    var _B = "Build";
    var _BA = "BuildArtifacts";
    var _BAL = "BuildArtifactsList";
    var _BB = "BuildBatch";
    var _BBF = "BuildBatchFilter";
    var _BBP = "BuildBatchPhase";
    var _BBPu = "BuildBatchPhases";
    var _BBu = "BuildBatches";
    var _BDB = "BatchDeleteBuilds";
    var _BDBI = "BatchDeleteBuildsInput";
    var _BDBO = "BatchDeleteBuildsOutput";
    var _BG = "BuildGroup";
    var _BGB = "BatchGetBuilds";
    var _BGBB = "BatchGetBuildBatches";
    var _BGBBI = "BatchGetBuildBatchesInput";
    var _BGBBO = "BatchGetBuildBatchesOutput";
    var _BGBI = "BatchGetBuildsInput";
    var _BGBO = "BatchGetBuildsOutput";
    var _BGCE = "BatchGetCommandExecutions";
    var _BGCEI = "BatchGetCommandExecutionsInput";
    var _BGCEO = "BatchGetCommandExecutionsOutput";
    var _BGF = "BatchGetFleets";
    var _BGFI = "BatchGetFleetsInput";
    var _BGFO = "BatchGetFleetsOutput";
    var _BGP = "BatchGetProjects";
    var _BGPI = "BatchGetProjectsInput";
    var _BGPO = "BatchGetProjectsOutput";
    var _BGR = "BatchGetReports";
    var _BGRG = "BatchGetReportGroups";
    var _BGRGI = "BatchGetReportGroupsInput";
    var _BGRGO = "BatchGetReportGroupsOutput";
    var _BGRI = "BatchGetReportsInput";
    var _BGRO = "BatchGetReportsOutput";
    var _BGS = "BatchGetSandboxes";
    var _BGSI = "BatchGetSandboxesInput";
    var _BGSO = "BatchGetSandboxesOutput";
    var _BGu = "BuildGroups";
    var _BND = "BuildNotDeleted";
    var _BNDu = "BuildsNotDeleted";
    var _BP = "BuildPhase";
    var _BPu = "BuildPhases";
    var _BR = "BatchRestrictions";
    var _BS = "BuildSummary";
    var _BSC = "BuildStatusConfig";
    var _BSu = "BuildSummaries";
    var _Bu = "Builds";
    var _CC = "CodeCoverage";
    var _CCRS = "CodeCoverageReportSummary";
    var _CCo = "ComputeConfiguration";
    var _CCod = "CodeCoverages";
    var _CE = "CommandExecution";
    var _CEo = "CommandExecutions";
    var _CF = "CreateFleet";
    var _CFI = "CreateFleetInput";
    var _CFO = "CreateFleetOutput";
    var _CP = "CreateProject";
    var _CPI = "CreateProjectInput";
    var _CPO = "CreateProjectOutput";
    var _CRG = "CreateReportGroup";
    var _CRGI = "CreateReportGroupInput";
    var _CRGO = "CreateReportGroupOutput";
    var _CW = "CreateWebhook";
    var _CWI = "CreateWebhookInput";
    var _CWLC = "CloudWatchLogsConfig";
    var _CWO = "CreateWebhookOutput";
    var _DBB = "DeleteBuildBatch";
    var _DBBI = "DeleteBuildBatchInput";
    var _DBBO = "DeleteBuildBatchOutput";
    var _DCC = "DescribeCodeCoverages";
    var _DCCI = "DescribeCodeCoveragesInput";
    var _DCCO = "DescribeCodeCoveragesOutput";
    var _DF = "DeleteFleet";
    var _DFI = "DeleteFleetInput";
    var _DFO = "DeleteFleetOutput";
    var _DP = "DeleteProject";
    var _DPI = "DeleteProjectInput";
    var _DPO = "DeleteProjectOutput";
    var _DR = "DeleteReport";
    var _DRG = "DeleteReportGroup";
    var _DRGI = "DeleteReportGroupInput";
    var _DRGO = "DeleteReportGroupOutput";
    var _DRI = "DeleteReportInput";
    var _DRO = "DeleteReportOutput";
    var _DRP = "DeleteResourcePolicy";
    var _DRPI = "DeleteResourcePolicyInput";
    var _DRPO = "DeleteResourcePolicyOutput";
    var _DS10 = "DebugSession";
    var _DSC = "DeleteSourceCredentials";
    var _DSCI = "DeleteSourceCredentialsInput";
    var _DSCO = "DeleteSourceCredentialsOutput";
    var _DSS = "DockerServerStatus";
    var _DSo = "DockerServer";
    var _DTC = "DescribeTestCases";
    var _DTCI = "DescribeTestCasesInput";
    var _DTCO = "DescribeTestCasesOutput";
    var _DW = "DeleteWebhook";
    var _DWI = "DeleteWebhookInput";
    var _DWO = "DeleteWebhookOutput";
    var _EEV = "ExportedEnvironmentVariable";
    var _EEVx = "ExportedEnvironmentVariables";
    var _EI10 = "EnvironmentImage";
    var _EIn = "EnvironmentImages";
    var _EL = "EnvironmentLanguage";
    var _ELn = "EnvironmentLanguages";
    var _EP = "EnvironmentPlatform";
    var _EPn = "EnvironmentPlatforms";
    var _EV = "EnvironmentVariable";
    var _EVn = "EnvironmentVariables";
    var _F = "Fleet";
    var _FG = "FilterGroups";
    var _FGi = "FilterGroup";
    var _FPR = "FleetProxyRule";
    var _FPRl = "FleetProxyRules";
    var _FS = "FleetStatus";
    var _Fl = "Fleets";
    var _GRGT = "GetReportGroupTrend";
    var _GRGTI = "GetReportGroupTrendInput";
    var _GRGTO = "GetReportGroupTrendOutput";
    var _GRP = "GetResourcePolicy";
    var _GRPI = "GetResourcePolicyInput";
    var _GRPO = "GetResourcePolicyOutput";
    var _GSC = "GitSubmodulesConfig";
    var _IIE = "InvalidInputException";
    var _IPC = "InvalidateProjectCache";
    var _IPCI = "InvalidateProjectCacheInput";
    var _IPCO = "InvalidateProjectCacheOutput";
    var _ISC = "ImportSourceCredentials";
    var _ISCI = "ImportSourceCredentialsInput";
    var _ISCO = "ImportSourceCredentialsOutput";
    var _LB = "ListBuilds";
    var _LBB = "ListBuildBatches";
    var _LBBFP = "ListBuildBatchesForProject";
    var _LBBFPI = "ListBuildBatchesForProjectInput";
    var _LBBFPO = "ListBuildBatchesForProjectOutput";
    var _LBBI = "ListBuildBatchesInput";
    var _LBBO = "ListBuildBatchesOutput";
    var _LBFP = "ListBuildsForProject";
    var _LBFPI = "ListBuildsForProjectInput";
    var _LBFPO = "ListBuildsForProjectOutput";
    var _LBI = "ListBuildsInput";
    var _LBO = "ListBuildsOutput";
    var _LC = "LogsConfig";
    var _LCEFS = "ListCommandExecutionsForSandbox";
    var _LCEFSI = "ListCommandExecutionsForSandboxInput";
    var _LCEFSO = "ListCommandExecutionsForSandboxOutput";
    var _LCEI = "ListCuratedEnvironmentImages";
    var _LCEII = "ListCuratedEnvironmentImagesInput";
    var _LCEIO = "ListCuratedEnvironmentImagesOutput";
    var _LF = "ListFleets";
    var _LFI = "ListFleetsInput";
    var _LFO = "ListFleetsOutput";
    var _LL = "LogsLocation";
    var _LP = "ListProjects";
    var _LPI = "ListProjectsInput";
    var _LPO = "ListProjectsOutput";
    var _LR = "ListReports";
    var _LRFRG = "ListReportsForReportGroup";
    var _LRFRGI = "ListReportsForReportGroupInput";
    var _LRFRGO = "ListReportsForReportGroupOutput";
    var _LRG = "ListReportGroups";
    var _LRGI = "ListReportGroupsInput";
    var _LRGO = "ListReportGroupsOutput";
    var _LRI = "ListReportsInput";
    var _LRO = "ListReportsOutput";
    var _LS = "ListSandboxes";
    var _LSC = "ListSourceCredentials";
    var _LSCI = "ListSourceCredentialsInput";
    var _LSCO = "ListSourceCredentialsOutput";
    var _LSFP = "ListSandboxesForProject";
    var _LSFPI = "ListSandboxesForProjectInput";
    var _LSFPO = "ListSandboxesForProjectOutput";
    var _LSI = "ListSandboxesInput";
    var _LSO = "ListSandboxesOutput";
    var _LSP = "ListSharedProjects";
    var _LSPI = "ListSharedProjectsInput";
    var _LSPO = "ListSharedProjectsOutput";
    var _LSRG = "ListSharedReportGroups";
    var _LSRGI = "ListSharedReportGroupsInput";
    var _LSRGO = "ListSharedReportGroupsOutput";
    var _NI = "NetworkInterface";
    var _OAPE = "OAuthProviderException";
    var _P10 = "Project";
    var _PA10 = "ProjectArtifacts";
    var _PAL = "ProjectArtifactsList";
    var _PB = "ProjectBadge";
    var _PBBC = "ProjectBuildBatchConfig";
    var _PC10 = "PhaseContext";
    var _PCh = "PhaseContexts";
    var _PCr10 = "ProjectCache";
    var _PCro = "ProxyConfiguration";
    var _PE = "ProjectEnvironment";
    var _PF = "ProjectFleet";
    var _PFSL = "ProjectFileSystemLocation";
    var _PFSLr = "ProjectFileSystemLocations";
    var _PRBP = "PullRequestBuildPolicy";
    var _PRP = "PutResourcePolicy";
    var _PRPI = "PutResourcePolicyInput";
    var _PRPO = "PutResourcePolicyOutput";
    var _PS = "ProjectSource";
    var _PSSV = "ProjectSecondarySourceVersions";
    var _PSV = "ProjectSourceVersion";
    var _PSr = "ProjectSources";
    var _Pr10 = "Projects";
    var _R = "Report";
    var _RA10 = "ResolvedArtifact";
    var _RAEE = "ResourceAlreadyExistsException";
    var _RB = "RetryBuild";
    var _RBB = "RetryBuildBatch";
    var _RBBI = "RetryBuildBatchInput";
    var _RBBO = "RetryBuildBatchOutput";
    var _RBI = "RetryBuildInput";
    var _RBO = "RetryBuildOutput";
    var _RC10 = "RegistryCredential";
    var _REC = "ReportExportConfig";
    var _RF = "ReportFilter";
    var _RG = "ReportGroup";
    var _RGTRDL = "ReportGroupTrendRawDataList";
    var _RGTS = "ReportGroupTrendStats";
    var _RGe = "ReportGroups";
    var _RNFE11 = "ResourceNotFoundException";
    var _RSA = "ResolvedSecondaryArtifacts";
    var _RWRD = "ReportWithRawData";
    var _Re = "Reports";
    var _S = "Sandbox";
    var _SA = "SourceAuth";
    var _SB = "StartBuild";
    var _SBB = "StartBuildBatch";
    var _SBBI = "StartBuildBatchInput";
    var _SBBIt = "StopBuildBatchInput";
    var _SBBO = "StartBuildBatchOutput";
    var _SBBOt = "StopBuildBatchOutput";
    var _SBBt = "StopBuildBatch";
    var _SBI = "StartBuildInput";
    var _SBIt = "StopBuildInput";
    var _SBO = "StartBuildOutput";
    var _SBOt = "StopBuildOutput";
    var _SBt = "StopBuild";
    var _SC = "ScopeConfiguration";
    var _SCE = "StartCommandExecution";
    var _SCEI = "StartCommandExecutionInput";
    var _SCEO = "StartCommandExecutionOutput";
    var _SCI = "ScalingConfigurationInput";
    var _SCIo = "SourceCredentialsInfo";
    var _SCIou = "SourceCredentialsInfos";
    var _SCO = "ScalingConfigurationOutput";
    var _SLC = "S3LogsConfig";
    var _SNES = "SensitiveNonEmptyString";
    var _SREC = "S3ReportExportConfig";
    var _SS = "SensitiveString";
    var _SSC = "StartSandboxConnection";
    var _SSCI = "StartSandboxConnectionInput";
    var _SSCO = "StartSandboxConnectionOutput";
    var _SSI = "StartSandboxInput";
    var _SSIt = "StopSandboxInput";
    var _SSMS = "SSMSession";
    var _SSO = "StartSandboxOutput";
    var _SSOt = "StopSandboxOutput";
    var _SSP = "SandboxSessionPhase";
    var _SSPa = "SandboxSessionPhases";
    var _SSa = "SandboxSession";
    var _SSt = "StartSandbox";
    var _SSto = "StopSandbox";
    var _Sa = "Sandboxes";
    var _T10 = "Tag";
    var _TC10 = "TestCase";
    var _TCF = "TestCaseFilter";
    var _TCe = "TestCases";
    var _TL = "TagList";
    var _TRS = "TestReportSummary";
    var _TTSC = "TargetTrackingScalingConfiguration";
    var _TTSCa = "TargetTrackingScalingConfigurations";
    var _UF = "UpdateFleet";
    var _UFI = "UpdateFleetInput";
    var _UFO = "UpdateFleetOutput";
    var _UP = "UpdateProject";
    var _UPI = "UpdateProjectInput";
    var _UPO = "UpdateProjectOutput";
    var _UPV = "UpdateProjectVisibility";
    var _UPVI = "UpdateProjectVisibilityInput";
    var _UPVO = "UpdateProjectVisibilityOutput";
    var _URG = "UpdateReportGroup";
    var _URGI = "UpdateReportGroupInput";
    var _URGO = "UpdateReportGroupOutput";
    var _UW = "UpdateWebhook";
    var _UWI = "UpdateWebhookInput";
    var _UWO = "UpdateWebhookOutput";
    var _VC = "VpcConfig";
    var _W = "Webhook";
    var _WF = "WebhookFilter";
    var _a10 = "arn";
    var _aI10 = "artifactIdentifier";
    var _aO = "artifactsOverride";
    var _aR = "approverRoles";
    var _aRC = "autoRetryConfig";
    var _aRL = "autoRetryLimit";
    var _aRLO = "autoRetryLimitOverride";
    var _aRN = "autoRetryNumber";
    var _aT22 = "authType";
    var _ar = "artifacts";
    var _au = "auth";
    var _av = "average";
    var _b = "builds";
    var _bB = "buildBatches";
    var _bBA = "buildBatchArn";
    var _bBC = "buildBatchConfig";
    var _bBCO = "buildBatchConfigOverride";
    var _bBN = "buildBatchNumber";
    var _bBNF = "buildBatchesNotFound";
    var _bBS = "buildBatchStatus";
    var _bBu = "buildBatch";
    var _bC = "buildComplete";
    var _bCP = "branchCoveragePercentage";
    var _bCa = "baseCapacity";
    var _bCr = "branchesCovered";
    var _bD = "buildsDeleted";
    var _bE = "badgeEnabled";
    var _bF = "branchFilter";
    var _bG = "buildGroups";
    var _bM = "branchesMissed";
    var _bN = "buildNumber";
    var _bND = "buildsNotDeleted";
    var _bNF = "buildsNotFound";
    var _bO = "bucketOwner";
    var _bOA = "bucketOwnerAccess";
    var _bOu = "buildspecOverride";
    var _bRM = "batchReportMode";
    var _bRU = "badgeRequestUrl";
    var _bS = "buildStatus";
    var _bSC = "buildStatusConfig";
    var _bSCO = "buildStatusConfigOverride";
    var _bT = "buildType";
    var _bTIM = "buildTimeoutInMinutes";
    var _bTIMO = "buildTimeoutInMinutesOverride";
    var _ba = "badge";
    var _bu = "buildspec";
    var _buc = "bucket";
    var _bui = "build";
    var _c32 = "client";
    var _cA = "combineArtifacts";
    var _cBL = "concurrentBuildLimit";
    var _cBS = "currentBuildSummary";
    var _cC = "computeConfiguration";
    var _cCS = "codeCoverageSummary";
    var _cCo = "codeCoverages";
    var _cE = "commandExecutions";
    var _cEI = "commandExecutionIds";
    var _cENF = "commandExecutionsNotFound";
    var _cEo = "commandExecution";
    var _cN = "cacheNamespace";
    var _cO = "certificateOverride";
    var _cOa = "cacheOverride";
    var _cP = "currentPhase";
    var _cPr = "credentialProvider";
    var _cS4 = "currentSession";
    var _cT = "computeType";
    var _cTA = "computeTypesAllowed";
    var _cTO = "computeTypeOverride";
    var _cWL = "cloudWatchLogs";
    var _cWLA = "cloudWatchLogsArn";
    var _ca = "cache";
    var _ce = "certificate";
    var _co13 = "complete";
    var _com = "command";
    var _con = "contexts";
    var _cont = "context";
    var _cr = "created";
    var _cre = "credential";
    var _d = "disk";
    var _dB = "defaultBehavior";
    var _dC4 = "desiredCapacity";
    var _dINS = "durationInNanoSeconds";
    var _dIS = "durationInSeconds";
    var _dL = "deepLink";
    var _dO = "dependsOn";
    var _dR = "deleteReports";
    var _dS = "debugSession";
    var _dSE = "debugSessionEnabled";
    var _dSo = "dockerServer";
    var _da = "data";
    var _de = "description";
    var _do = "domain";
    var _e32 = "error";
    var _eC = "exitCode";
    var _eCT = "exportConfigType";
    var _eCx = "exportConfig";
    var _eD = "encryptionDisabled";
    var _eEV = "exportedEnvironmentVariables";
    var _eI13 = "executionId";
    var _eK = "encryptionKey";
    var _eKO = "encryptionKeyOverride";
    var _eMP = "excludeMatchedPattern";
    var _eT = "endTime";
    var _eTO = "environmentTypeOverride";
    var _eTn = "environmentType";
    var _eV = "environmentVariables";
    var _eVO = "environmentVariablesOverride";
    var _ef = "effect";
    var _en = "environment";
    var _ent = "entities";
    var _ex10 = "expired";
    var _f = "fleets";
    var _fA = "fleetsAllowed";
    var _fAl = "fleetArn";
    var _fG = "filterGroups";
    var _fNF = "fleetsNotFound";
    var _fO = "fleetOverride";
    var _fP = "filePath";
    var _fS = "fetchSubmodules";
    var _fSL = "fileSystemLocations";
    var _fSR = "fleetServiceRole";
    var _fi = "filter";
    var _fl = "fleet";
    var _gCD = "gitCloneDepth";
    var _gCDO = "gitCloneDepthOverride";
    var _gN = "groupName";
    var _gSC = "gitSubmodulesConfig";
    var _gSCO = "gitSubmodulesConfigOverride";
    var _i = "ids";
    var _iF = "ignoreFailure";
    var _iI = "imageId";
    var _iO = "imageOverride";
    var _iPCT = "imagePullCredentialsType";
    var _iPCTO = "imagePullCredentialsTypeOverride";
    var _iS = "insecureSsl";
    var _iSO = "insecureSslOverride";
    var _iT13 = "instanceType";
    var _iTd = "idempotencyToken";
    var _id = "id";
    var _ide = "identifier";
    var _im = "images";
    var _ima = "image";
    var _in = "initiator";
    var _k = "key";
    var _ke = "keyword";
    var _l = "logs";
    var _lC = "logConfig";
    var _lCO = "logsConfigOverride";
    var _lCP = "lineCoveragePercentage";
    var _lCi = "linesCovered";
    var _lCo = "logsConfig";
    var _lM = "linesMissed";
    var _lMS = "lastModifiedSecret";
    var _lMa = "lastModified";
    var _la = "language";
    var _lan = "languages";
    var _lo = "location";
    var _m29 = "message";
    var _mBA = "maximumBuildsAllowed";
    var _mC = "manualCreation";
    var _mCa = "maxCapacity";
    var _mLCP = "minLineCoveragePercentage";
    var _mLCPa = "maxLineCoveragePercentage";
    var _mO = "mountOptions";
    var _mP = "mountPoint";
    var _mR = "maxResults";
    var _mT = "machineType";
    var _mTe = "metricType";
    var _ma = "max";
    var _md = "md5sum";
    var _me = "memory";
    var _mi = "min";
    var _mo = "modes";
    var _n = "names";
    var _nAR = "nextAutoRetry";
    var _nI = "networkInterface";
    var _nII = "networkInterfaceId";
    var _nOR = "numOfReports";
    var _nT = "nextToken";
    var _nTa = "namespaceType";
    var _na = "name";
    var _oAN = "overrideArtifactName";
    var _oB = "overflowBehavior";
    var _oPR = "orderedProxyRules";
    var _p = "projects";
    var _pA = "primaryArtifact";
    var _pAR = "previousAutoRetry";
    var _pAr = "projectArn";
    var _pBSL = "priorBuildSummaryList";
    var _pC = "proxyConfiguration";
    var _pM = "privilegedMode";
    var _pMO = "privilegedModeOverride";
    var _pN = "projectName";
    var _pNF = "projectsNotFound";
    var _pPA = "publicProjectAlias";
    var _pRBP = "pullRequestBuildPolicy";
    var _pS = "phaseStatus";
    var _pT = "phaseType";
    var _pU = "payloadUrl";
    var _pV = "projectVisibility";
    var _pa = "path";
    var _pac = "packaging";
    var _pat = "pattern";
    var _ph = "phases";
    var _pl = "platform";
    var _pla = "platforms";
    var _po = "policy";
    var _pr = "project";
    var _pre = "prefix";
    var _qTIM = "queuedTimeoutInMinutes";
    var _qTIMO = "queuedTimeoutInMinutesOverride";
    var _r4 = "reports";
    var _rA = "reportArns";
    var _rAR = "resourceAccessRole";
    var _rARN = "reportARN";
    var _rAe = "resourceArn";
    var _rAep = "reportArn";
    var _rBBSO = "reportBuildBatchStatusOverride";
    var _rBS = "reportBuildStatus";
    var _rBSO = "reportBuildStatusOverride";
    var _rC10 = "registryCredential";
    var _rCA = "requiresCommentApproval";
    var _rCO = "registryCredentialOverride";
    var _rD = "rawData";
    var _rG = "reportGroups";
    var _rGA = "reportGroupArns";
    var _rGAe = "reportGroupArn";
    var _rGNF = "reportGroupsNotFound";
    var _rGe = "reportGroup";
    var _rNF = "reportsNotFound";
    var _rO = "requestedOn";
    var _rS = "rotateSecret";
    var _rSV = "resolvedSourceVersion";
    var _rT13 = "retryType";
    var _rTe = "requestTime";
    var _re = "restrictions";
    var _res = "resource";
    var _s32 = "smithy.ts.sdk.synthetic.com.amazonaws.codebuild";
    var _sA = "secondaryArtifacts";
    var _sAO = "secondaryArtifactsOverride";
    var _sAOo = "sourceAuthOverride";
    var _sAa = "sandboxArn";
    var _sB = "sortBy";
    var _sC = "statusCode";
    var _sCI = "sourceCredentialsInfos";
    var _sCc = "scalingConfiguration";
    var _sCco = "scopeConfiguration";
    var _sCt = "statusCounts";
    var _sD = "s3Destination";
    var _sDL = "s3DeepLink";
    var _sE = "sessionEnabled";
    var _sEC = "standardErrContent";
    var _sGI = "securityGroupIds";
    var _sI = "sandboxId";
    var _sIe = "sessionId";
    var _sIo = "sourceIdentifier";
    var _sIu = "subnetId";
    var _sL = "s3Logs";
    var _sLA = "s3LogsArn";
    var _sLO = "sourceLocationOverride";
    var _sM = "statusMessage";
    var _sN = "streamName";
    var _sNF = "sandboxesNotFound";
    var _sO = "sortOrder";
    var _sOC = "standardOutputContent";
    var _sOh = "shouldOverwrite";
    var _sR = "serviceRole";
    var _sRO = "serviceRoleOverride";
    var _sS = "secondarySources";
    var _sSO = "secondarySourcesOverride";
    var _sSV = "secondarySourceVersions";
    var _sSVO = "secondarySourcesVersionOverride";
    var _sSs = "ssmSession";
    var _sT19 = "startTime";
    var _sTO = "sourceTypeOverride";
    var _sTc = "scalingType";
    var _sTe = "sessionTarget";
    var _sTer = "serverType";
    var _sTu = "submitTime";
    var _sU = "streamUrl";
    var _sV = "sourceVersion";
    var _sa = "sandboxes";
    var _san = "sandbox";
    var _sc4 = "scope";
    var _se14 = "secret";
    var _sh = "sha256sum";
    var _so = "source";
    var _st = "status";
    var _sta = "stats";
    var _su = "subnets";
    var _t = "type";
    var _tC = "testCases";
    var _tF = "trendField";
    var _tIM = "timeoutInMinutes";
    var _tIMO = "timeoutInMinutesOverride";
    var _tIMi = "timeoutInMins";
    var _tRDP = "testRawDataPath";
    var _tS = "testSummary";
    var _tSN = "testSuiteName";
    var _tTSC = "targetTrackingScalingConfigs";
    var _tU = "targetUrl";
    var _tV = "tokenValue";
    var _tVa = "targetValue";
    var _ta = "tags";
    var _to = "token";
    var _tot = "total";
    var _tr = "truncated";
    var _u = "username";
    var _ur = "url";
    var _v = "versions";
    var _vC = "vpcConfig";
    var _vCp = "vCpu";
    var _vI = "vpcId";
    var _va = "value";
    var _w = "webhook";
    var n032 = "com.amazonaws.codebuild";
    var schema_1 = (init_schema4(), __toCommonJS(schema_exports));
    var CodeBuildServiceException_1 = require_CodeBuildServiceException();
    var errors_1 = require_errors10();
    var _s_registry32 = schema_1.TypeRegistry.for(_s32);
    exports2.CodeBuildServiceException$ = [-3, _s32, "CodeBuildServiceException", 0, [], []];
    _s_registry32.registerError(exports2.CodeBuildServiceException$, CodeBuildServiceException_1.CodeBuildServiceException);
    var n0_registry32 = schema_1.TypeRegistry.for(n032);
    exports2.AccountLimitExceededException$ = [
      -3,
      n032,
      _ALEE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.AccountLimitExceededException$, errors_1.AccountLimitExceededException);
    exports2.AccountSuspendedException$ = [
      -3,
      n032,
      _ASE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.AccountSuspendedException$, errors_1.AccountSuspendedException);
    exports2.InvalidInputException$ = [
      -3,
      n032,
      _IIE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidInputException$, errors_1.InvalidInputException);
    exports2.OAuthProviderException$ = [
      -3,
      n032,
      _OAPE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.OAuthProviderException$, errors_1.OAuthProviderException);
    exports2.ResourceAlreadyExistsException$ = [
      -3,
      n032,
      _RAEE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ResourceAlreadyExistsException$, errors_1.ResourceAlreadyExistsException);
    exports2.ResourceNotFoundException$ = [
      -3,
      n032,
      _RNFE11,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ResourceNotFoundException$, errors_1.ResourceNotFoundException);
    exports2.errorTypeRegistries = [
      _s_registry32,
      n0_registry32
    ];
    var SensitiveNonEmptyString = [0, n032, _SNES, 8, 0];
    var SensitiveString = [0, n032, _SS, 8, 0];
    exports2.AutoRetryConfig$ = [
      3,
      n032,
      _ARC,
      0,
      [_aRL, _aRN, _nAR, _pAR],
      [1, 1, 0, 0]
    ];
    exports2.BatchDeleteBuildsInput$ = [
      3,
      n032,
      _BDBI,
      0,
      [_i],
      [64 | 0],
      1
    ];
    exports2.BatchDeleteBuildsOutput$ = [
      3,
      n032,
      _BDBO,
      0,
      [_bD, _bND],
      [64 | 0, () => BuildsNotDeleted]
    ];
    exports2.BatchGetBuildBatchesInput$ = [
      3,
      n032,
      _BGBBI,
      0,
      [_i],
      [64 | 0],
      1
    ];
    exports2.BatchGetBuildBatchesOutput$ = [
      3,
      n032,
      _BGBBO,
      0,
      [_bB, _bBNF],
      [() => BuildBatches, 64 | 0]
    ];
    exports2.BatchGetBuildsInput$ = [
      3,
      n032,
      _BGBI,
      0,
      [_i],
      [64 | 0],
      1
    ];
    exports2.BatchGetBuildsOutput$ = [
      3,
      n032,
      _BGBO,
      0,
      [_b, _bNF],
      [() => Builds, 64 | 0]
    ];
    exports2.BatchGetCommandExecutionsInput$ = [
      3,
      n032,
      _BGCEI,
      0,
      [_sI, _cEI],
      [0, 64 | 0],
      2
    ];
    exports2.BatchGetCommandExecutionsOutput$ = [
      3,
      n032,
      _BGCEO,
      0,
      [_cE, _cENF],
      [[() => CommandExecutions, 0], 64 | 0]
    ];
    exports2.BatchGetFleetsInput$ = [
      3,
      n032,
      _BGFI,
      0,
      [_n],
      [64 | 0],
      1
    ];
    exports2.BatchGetFleetsOutput$ = [
      3,
      n032,
      _BGFO,
      0,
      [_f, _fNF],
      [() => Fleets, 64 | 0]
    ];
    exports2.BatchGetProjectsInput$ = [
      3,
      n032,
      _BGPI,
      0,
      [_n],
      [64 | 0],
      1
    ];
    exports2.BatchGetProjectsOutput$ = [
      3,
      n032,
      _BGPO,
      0,
      [_p, _pNF],
      [() => Projects, 64 | 0]
    ];
    exports2.BatchGetReportGroupsInput$ = [
      3,
      n032,
      _BGRGI,
      0,
      [_rGA],
      [64 | 0],
      1
    ];
    exports2.BatchGetReportGroupsOutput$ = [
      3,
      n032,
      _BGRGO,
      0,
      [_rG, _rGNF],
      [() => ReportGroups, 64 | 0]
    ];
    exports2.BatchGetReportsInput$ = [
      3,
      n032,
      _BGRI,
      0,
      [_rA],
      [64 | 0],
      1
    ];
    exports2.BatchGetReportsOutput$ = [
      3,
      n032,
      _BGRO,
      0,
      [_r4, _rNF],
      [() => Reports, 64 | 0]
    ];
    exports2.BatchGetSandboxesInput$ = [
      3,
      n032,
      _BGSI,
      0,
      [_i],
      [64 | 0],
      1
    ];
    exports2.BatchGetSandboxesOutput$ = [
      3,
      n032,
      _BGSO,
      0,
      [_sa, _sNF],
      [() => Sandboxes, 64 | 0]
    ];
    exports2.BatchRestrictions$ = [
      3,
      n032,
      _BR,
      0,
      [_mBA, _cTA, _fA],
      [1, 64 | 0, 64 | 0]
    ];
    exports2.Build$ = [
      3,
      n032,
      _B,
      0,
      [_id, _a10, _bN, _sT19, _eT, _cP, _bS, _sV, _rSV, _pN, _ph, _so, _sS, _sSV, _ar, _sA, _ca, _en, _sR, _l, _tIM, _qTIM, _bC, _in, _vC, _nI, _eK, _eEV, _rA, _fSL, _dS, _bBA, _aRC],
      [0, 0, 1, 4, 4, 0, 0, 0, 0, 0, () => BuildPhases, () => exports2.ProjectSource$, () => ProjectSources, () => ProjectSecondarySourceVersions, () => exports2.BuildArtifacts$, () => BuildArtifactsList, () => exports2.ProjectCache$, () => exports2.ProjectEnvironment$, 0, () => exports2.LogsLocation$, 1, 1, 2, 0, () => exports2.VpcConfig$, () => exports2.NetworkInterface$, 0, () => ExportedEnvironmentVariables, 64 | 0, () => ProjectFileSystemLocations, () => exports2.DebugSession$, 0, () => exports2.AutoRetryConfig$]
    ];
    exports2.BuildArtifacts$ = [
      3,
      n032,
      _BA,
      0,
      [_lo, _sh, _md, _oAN, _eD, _aI10, _bOA],
      [0, 0, 0, 2, 2, 0, 0]
    ];
    exports2.BuildBatch$ = [
      3,
      n032,
      _BB,
      0,
      [_id, _a10, _sT19, _eT, _cP, _bBS, _sV, _rSV, _pN, _ph, _so, _sS, _sSV, _ar, _sA, _ca, _en, _sR, _lC, _bTIM, _qTIM, _co13, _in, _vC, _eK, _bBN, _fSL, _bBC, _bG, _dSE, _rA],
      [0, 0, 4, 4, 0, 0, 0, 0, 0, () => BuildBatchPhases, () => exports2.ProjectSource$, () => ProjectSources, () => ProjectSecondarySourceVersions, () => exports2.BuildArtifacts$, () => BuildArtifactsList, () => exports2.ProjectCache$, () => exports2.ProjectEnvironment$, 0, () => exports2.LogsConfig$, 1, 1, 2, 0, () => exports2.VpcConfig$, 0, 1, () => ProjectFileSystemLocations, () => exports2.ProjectBuildBatchConfig$, () => BuildGroups, 2, 64 | 0]
    ];
    exports2.BuildBatchFilter$ = [
      3,
      n032,
      _BBF,
      0,
      [_st],
      [0]
    ];
    exports2.BuildBatchPhase$ = [
      3,
      n032,
      _BBP,
      0,
      [_pT, _pS, _sT19, _eT, _dIS, _con],
      [0, 0, 4, 4, 1, () => PhaseContexts]
    ];
    exports2.BuildGroup$ = [
      3,
      n032,
      _BG,
      0,
      [_ide, _dO, _iF, _cBS, _pBSL],
      [0, 64 | 0, 2, () => exports2.BuildSummary$, () => BuildSummaries]
    ];
    exports2.BuildNotDeleted$ = [
      3,
      n032,
      _BND,
      0,
      [_id, _sC],
      [0, 0]
    ];
    exports2.BuildPhase$ = [
      3,
      n032,
      _BP,
      0,
      [_pT, _pS, _sT19, _eT, _dIS, _con],
      [0, 0, 4, 4, 1, () => PhaseContexts]
    ];
    exports2.BuildStatusConfig$ = [
      3,
      n032,
      _BSC,
      0,
      [_cont, _tU],
      [0, 0]
    ];
    exports2.BuildSummary$ = [
      3,
      n032,
      _BS,
      0,
      [_a10, _rO, _bS, _pA, _sA],
      [0, 4, 0, () => exports2.ResolvedArtifact$, () => ResolvedSecondaryArtifacts]
    ];
    exports2.CloudWatchLogsConfig$ = [
      3,
      n032,
      _CWLC,
      0,
      [_st, _gN, _sN],
      [0, 0, 0],
      1
    ];
    exports2.CodeCoverage$ = [
      3,
      n032,
      _CC,
      0,
      [_id, _rARN, _fP, _lCP, _lCi, _lM, _bCP, _bCr, _bM, _ex10],
      [0, 0, 0, 1, 1, 1, 1, 1, 1, 4]
    ];
    exports2.CodeCoverageReportSummary$ = [
      3,
      n032,
      _CCRS,
      0,
      [_lCP, _lCi, _lM, _bCP, _bCr, _bM],
      [1, 1, 1, 1, 1, 1]
    ];
    exports2.CommandExecution$ = [
      3,
      n032,
      _CE,
      0,
      [_id, _sI, _sTu, _sT19, _eT, _st, _com, _t, _eC, _sOC, _sEC, _l, _sAa],
      [0, 0, 4, 4, 4, 0, [() => SensitiveNonEmptyString, 0], 0, 0, [() => SensitiveNonEmptyString, 0], [() => SensitiveNonEmptyString, 0], () => exports2.LogsLocation$, 0]
    ];
    exports2.ComputeConfiguration$ = [
      3,
      n032,
      _CCo,
      0,
      [_vCp, _me, _d, _mT, _iT13],
      [1, 1, 1, 0, 0]
    ];
    exports2.CreateFleetInput$ = [
      3,
      n032,
      _CFI,
      0,
      [_na, _bCa, _eTn, _cT, _cC, _sCc, _oB, _vC, _pC, _iI, _fSR, _ta],
      [0, 1, 0, 0, () => exports2.ComputeConfiguration$, () => exports2.ScalingConfigurationInput$, 0, () => exports2.VpcConfig$, () => exports2.ProxyConfiguration$, 0, 0, () => TagList],
      4
    ];
    exports2.CreateFleetOutput$ = [
      3,
      n032,
      _CFO,
      0,
      [_fl],
      [() => exports2.Fleet$]
    ];
    exports2.CreateProjectInput$ = [
      3,
      n032,
      _CPI,
      0,
      [_na, _so, _ar, _en, _sR, _de, _sS, _sV, _sSV, _sA, _ca, _tIM, _qTIM, _eK, _ta, _vC, _bE, _lCo, _fSL, _bBC, _cBL, _aRL],
      [0, () => exports2.ProjectSource$, () => exports2.ProjectArtifacts$, () => exports2.ProjectEnvironment$, 0, 0, () => ProjectSources, 0, () => ProjectSecondarySourceVersions, () => ProjectArtifactsList, () => exports2.ProjectCache$, 1, 1, 0, () => TagList, () => exports2.VpcConfig$, 2, () => exports2.LogsConfig$, () => ProjectFileSystemLocations, () => exports2.ProjectBuildBatchConfig$, 1, 1],
      5
    ];
    exports2.CreateProjectOutput$ = [
      3,
      n032,
      _CPO,
      0,
      [_pr],
      [() => exports2.Project$]
    ];
    exports2.CreateReportGroupInput$ = [
      3,
      n032,
      _CRGI,
      0,
      [_na, _t, _eCx, _ta],
      [0, 0, () => exports2.ReportExportConfig$, () => TagList],
      3
    ];
    exports2.CreateReportGroupOutput$ = [
      3,
      n032,
      _CRGO,
      0,
      [_rGe],
      [() => exports2.ReportGroup$]
    ];
    exports2.CreateWebhookInput$ = [
      3,
      n032,
      _CWI,
      0,
      [_pN, _bF, _fG, _bT, _mC, _sCco, _pRBP],
      [0, 0, () => FilterGroups, 0, 2, () => exports2.ScopeConfiguration$, () => exports2.PullRequestBuildPolicy$],
      1
    ];
    exports2.CreateWebhookOutput$ = [
      3,
      n032,
      _CWO,
      0,
      [_w],
      [() => exports2.Webhook$]
    ];
    exports2.DebugSession$ = [
      3,
      n032,
      _DS10,
      0,
      [_sE, _sTe],
      [2, 0]
    ];
    exports2.DeleteBuildBatchInput$ = [
      3,
      n032,
      _DBBI,
      0,
      [_id],
      [0],
      1
    ];
    exports2.DeleteBuildBatchOutput$ = [
      3,
      n032,
      _DBBO,
      0,
      [_sC, _bD, _bND],
      [0, 64 | 0, () => BuildsNotDeleted]
    ];
    exports2.DeleteFleetInput$ = [
      3,
      n032,
      _DFI,
      0,
      [_a10],
      [0],
      1
    ];
    exports2.DeleteFleetOutput$ = [
      3,
      n032,
      _DFO,
      0,
      [],
      []
    ];
    exports2.DeleteProjectInput$ = [
      3,
      n032,
      _DPI,
      0,
      [_na],
      [0],
      1
    ];
    exports2.DeleteProjectOutput$ = [
      3,
      n032,
      _DPO,
      0,
      [],
      []
    ];
    exports2.DeleteReportGroupInput$ = [
      3,
      n032,
      _DRGI,
      0,
      [_a10, _dR],
      [0, 2],
      1
    ];
    exports2.DeleteReportGroupOutput$ = [
      3,
      n032,
      _DRGO,
      0,
      [],
      []
    ];
    exports2.DeleteReportInput$ = [
      3,
      n032,
      _DRI,
      0,
      [_a10],
      [0],
      1
    ];
    exports2.DeleteReportOutput$ = [
      3,
      n032,
      _DRO,
      0,
      [],
      []
    ];
    exports2.DeleteResourcePolicyInput$ = [
      3,
      n032,
      _DRPI,
      0,
      [_rAe],
      [0],
      1
    ];
    exports2.DeleteResourcePolicyOutput$ = [
      3,
      n032,
      _DRPO,
      0,
      [],
      []
    ];
    exports2.DeleteSourceCredentialsInput$ = [
      3,
      n032,
      _DSCI,
      0,
      [_a10],
      [0],
      1
    ];
    exports2.DeleteSourceCredentialsOutput$ = [
      3,
      n032,
      _DSCO,
      0,
      [_a10],
      [0]
    ];
    exports2.DeleteWebhookInput$ = [
      3,
      n032,
      _DWI,
      0,
      [_pN],
      [0],
      1
    ];
    exports2.DeleteWebhookOutput$ = [
      3,
      n032,
      _DWO,
      0,
      [],
      []
    ];
    exports2.DescribeCodeCoveragesInput$ = [
      3,
      n032,
      _DCCI,
      0,
      [_rAep, _nT, _mR, _sO, _sB, _mLCP, _mLCPa],
      [0, 0, 1, 0, 0, 1, 1],
      1
    ];
    exports2.DescribeCodeCoveragesOutput$ = [
      3,
      n032,
      _DCCO,
      0,
      [_nT, _cCo],
      [0, () => CodeCoverages]
    ];
    exports2.DescribeTestCasesInput$ = [
      3,
      n032,
      _DTCI,
      0,
      [_rAep, _nT, _mR, _fi],
      [0, 0, 1, () => exports2.TestCaseFilter$],
      1
    ];
    exports2.DescribeTestCasesOutput$ = [
      3,
      n032,
      _DTCO,
      0,
      [_nT, _tC],
      [0, () => TestCases]
    ];
    exports2.DockerServer$ = [
      3,
      n032,
      _DSo,
      0,
      [_cT, _sGI, _st],
      [0, 64 | 0, () => exports2.DockerServerStatus$],
      1
    ];
    exports2.DockerServerStatus$ = [
      3,
      n032,
      _DSS,
      0,
      [_st, _m29],
      [0, 0]
    ];
    exports2.EnvironmentImage$ = [
      3,
      n032,
      _EI10,
      0,
      [_na, _de, _v],
      [0, 0, 64 | 0]
    ];
    exports2.EnvironmentLanguage$ = [
      3,
      n032,
      _EL,
      0,
      [_la, _im],
      [0, () => EnvironmentImages]
    ];
    exports2.EnvironmentPlatform$ = [
      3,
      n032,
      _EP,
      0,
      [_pl, _lan],
      [0, () => EnvironmentLanguages]
    ];
    exports2.EnvironmentVariable$ = [
      3,
      n032,
      _EV,
      0,
      [_na, _va, _t],
      [0, 0, 0],
      2
    ];
    exports2.ExportedEnvironmentVariable$ = [
      3,
      n032,
      _EEV,
      0,
      [_na, _va],
      [0, 0]
    ];
    exports2.Fleet$ = [
      3,
      n032,
      _F,
      0,
      [_a10, _na, _id, _cr, _lMa, _st, _bCa, _eTn, _cT, _cC, _sCc, _oB, _vC, _pC, _iI, _fSR, _ta],
      [0, 0, 0, 4, 4, () => exports2.FleetStatus$, 1, 0, 0, () => exports2.ComputeConfiguration$, () => exports2.ScalingConfigurationOutput$, 0, () => exports2.VpcConfig$, () => exports2.ProxyConfiguration$, 0, 0, () => TagList]
    ];
    exports2.FleetProxyRule$ = [
      3,
      n032,
      _FPR,
      0,
      [_t, _ef, _ent],
      [0, 0, 64 | 0],
      3
    ];
    exports2.FleetStatus$ = [
      3,
      n032,
      _FS,
      0,
      [_sC, _cont, _m29],
      [0, 0, 0]
    ];
    exports2.GetReportGroupTrendInput$ = [
      3,
      n032,
      _GRGTI,
      0,
      [_rGAe, _tF, _nOR],
      [0, 0, 1],
      2
    ];
    exports2.GetReportGroupTrendOutput$ = [
      3,
      n032,
      _GRGTO,
      0,
      [_sta, _rD],
      [() => exports2.ReportGroupTrendStats$, () => ReportGroupTrendRawDataList]
    ];
    exports2.GetResourcePolicyInput$ = [
      3,
      n032,
      _GRPI,
      0,
      [_rAe],
      [0],
      1
    ];
    exports2.GetResourcePolicyOutput$ = [
      3,
      n032,
      _GRPO,
      0,
      [_po],
      [0]
    ];
    exports2.GitSubmodulesConfig$ = [
      3,
      n032,
      _GSC,
      0,
      [_fS],
      [2],
      1
    ];
    exports2.ImportSourceCredentialsInput$ = [
      3,
      n032,
      _ISCI,
      0,
      [_to, _sTer, _aT22, _u, _sOh],
      [[() => SensitiveNonEmptyString, 0], 0, 0, 0, 2],
      3
    ];
    exports2.ImportSourceCredentialsOutput$ = [
      3,
      n032,
      _ISCO,
      0,
      [_a10],
      [0]
    ];
    exports2.InvalidateProjectCacheInput$ = [
      3,
      n032,
      _IPCI,
      0,
      [_pN],
      [0],
      1
    ];
    exports2.InvalidateProjectCacheOutput$ = [
      3,
      n032,
      _IPCO,
      0,
      [],
      []
    ];
    exports2.ListBuildBatchesForProjectInput$ = [
      3,
      n032,
      _LBBFPI,
      0,
      [_pN, _fi, _mR, _sO, _nT],
      [0, () => exports2.BuildBatchFilter$, 1, 0, 0]
    ];
    exports2.ListBuildBatchesForProjectOutput$ = [
      3,
      n032,
      _LBBFPO,
      0,
      [_i, _nT],
      [64 | 0, 0]
    ];
    exports2.ListBuildBatchesInput$ = [
      3,
      n032,
      _LBBI,
      0,
      [_fi, _mR, _sO, _nT],
      [() => exports2.BuildBatchFilter$, 1, 0, 0]
    ];
    exports2.ListBuildBatchesOutput$ = [
      3,
      n032,
      _LBBO,
      0,
      [_i, _nT],
      [64 | 0, 0]
    ];
    exports2.ListBuildsForProjectInput$ = [
      3,
      n032,
      _LBFPI,
      0,
      [_pN, _sO, _nT],
      [0, 0, 0],
      1
    ];
    exports2.ListBuildsForProjectOutput$ = [
      3,
      n032,
      _LBFPO,
      0,
      [_i, _nT],
      [64 | 0, 0]
    ];
    exports2.ListBuildsInput$ = [
      3,
      n032,
      _LBI,
      0,
      [_sO, _nT],
      [0, 0]
    ];
    exports2.ListBuildsOutput$ = [
      3,
      n032,
      _LBO,
      0,
      [_i, _nT],
      [64 | 0, 0]
    ];
    exports2.ListCommandExecutionsForSandboxInput$ = [
      3,
      n032,
      _LCEFSI,
      0,
      [_sI, _mR, _sO, _nT],
      [0, 1, 0, [() => SensitiveString, 0]],
      1
    ];
    exports2.ListCommandExecutionsForSandboxOutput$ = [
      3,
      n032,
      _LCEFSO,
      0,
      [_cE, _nT],
      [[() => CommandExecutions, 0], 0]
    ];
    exports2.ListCuratedEnvironmentImagesInput$ = [
      3,
      n032,
      _LCEII,
      0,
      [],
      []
    ];
    exports2.ListCuratedEnvironmentImagesOutput$ = [
      3,
      n032,
      _LCEIO,
      0,
      [_pla],
      [() => EnvironmentPlatforms]
    ];
    exports2.ListFleetsInput$ = [
      3,
      n032,
      _LFI,
      0,
      [_nT, _mR, _sO, _sB],
      [[() => SensitiveString, 0], 1, 0, 0]
    ];
    exports2.ListFleetsOutput$ = [
      3,
      n032,
      _LFO,
      0,
      [_nT, _f],
      [0, 64 | 0]
    ];
    exports2.ListProjectsInput$ = [
      3,
      n032,
      _LPI,
      0,
      [_sB, _sO, _nT],
      [0, 0, 0]
    ];
    exports2.ListProjectsOutput$ = [
      3,
      n032,
      _LPO,
      0,
      [_nT, _p],
      [0, 64 | 0]
    ];
    exports2.ListReportGroupsInput$ = [
      3,
      n032,
      _LRGI,
      0,
      [_sO, _sB, _nT, _mR],
      [0, 0, 0, 1]
    ];
    exports2.ListReportGroupsOutput$ = [
      3,
      n032,
      _LRGO,
      0,
      [_nT, _rG],
      [0, 64 | 0]
    ];
    exports2.ListReportsForReportGroupInput$ = [
      3,
      n032,
      _LRFRGI,
      0,
      [_rGAe, _nT, _sO, _mR, _fi],
      [0, 0, 0, 1, () => exports2.ReportFilter$],
      1
    ];
    exports2.ListReportsForReportGroupOutput$ = [
      3,
      n032,
      _LRFRGO,
      0,
      [_nT, _r4],
      [0, 64 | 0]
    ];
    exports2.ListReportsInput$ = [
      3,
      n032,
      _LRI,
      0,
      [_sO, _nT, _mR, _fi],
      [0, 0, 1, () => exports2.ReportFilter$]
    ];
    exports2.ListReportsOutput$ = [
      3,
      n032,
      _LRO,
      0,
      [_nT, _r4],
      [0, 64 | 0]
    ];
    exports2.ListSandboxesForProjectInput$ = [
      3,
      n032,
      _LSFPI,
      0,
      [_pN, _mR, _sO, _nT],
      [0, 1, 0, [() => SensitiveString, 0]],
      1
    ];
    exports2.ListSandboxesForProjectOutput$ = [
      3,
      n032,
      _LSFPO,
      0,
      [_i, _nT],
      [64 | 0, 0]
    ];
    exports2.ListSandboxesInput$ = [
      3,
      n032,
      _LSI,
      0,
      [_mR, _sO, _nT],
      [1, 0, 0]
    ];
    exports2.ListSandboxesOutput$ = [
      3,
      n032,
      _LSO,
      0,
      [_i, _nT],
      [64 | 0, 0]
    ];
    exports2.ListSharedProjectsInput$ = [
      3,
      n032,
      _LSPI,
      0,
      [_sB, _sO, _mR, _nT],
      [0, 0, 1, 0]
    ];
    exports2.ListSharedProjectsOutput$ = [
      3,
      n032,
      _LSPO,
      0,
      [_nT, _p],
      [0, 64 | 0]
    ];
    exports2.ListSharedReportGroupsInput$ = [
      3,
      n032,
      _LSRGI,
      0,
      [_sO, _sB, _nT, _mR],
      [0, 0, 0, 1]
    ];
    exports2.ListSharedReportGroupsOutput$ = [
      3,
      n032,
      _LSRGO,
      0,
      [_nT, _rG],
      [0, 64 | 0]
    ];
    exports2.ListSourceCredentialsInput$ = [
      3,
      n032,
      _LSCI,
      0,
      [],
      []
    ];
    exports2.ListSourceCredentialsOutput$ = [
      3,
      n032,
      _LSCO,
      0,
      [_sCI],
      [() => SourceCredentialsInfos]
    ];
    exports2.LogsConfig$ = [
      3,
      n032,
      _LC,
      0,
      [_cWL, _sL],
      [() => exports2.CloudWatchLogsConfig$, () => exports2.S3LogsConfig$]
    ];
    exports2.LogsLocation$ = [
      3,
      n032,
      _LL,
      0,
      [_gN, _sN, _dL, _sDL, _cWLA, _sLA, _cWL, _sL],
      [0, 0, 0, 0, 0, 0, () => exports2.CloudWatchLogsConfig$, () => exports2.S3LogsConfig$]
    ];
    exports2.NetworkInterface$ = [
      3,
      n032,
      _NI,
      0,
      [_sIu, _nII],
      [0, 0]
    ];
    exports2.PhaseContext$ = [
      3,
      n032,
      _PC10,
      0,
      [_sC, _m29],
      [0, 0]
    ];
    exports2.Project$ = [
      3,
      n032,
      _P10,
      0,
      [_na, _a10, _de, _so, _sS, _sV, _sSV, _ar, _sA, _ca, _en, _sR, _tIM, _qTIM, _eK, _ta, _cr, _lMa, _w, _vC, _ba, _lCo, _fSL, _bBC, _cBL, _pV, _pPA, _rAR, _aRL],
      [0, 0, 0, () => exports2.ProjectSource$, () => ProjectSources, 0, () => ProjectSecondarySourceVersions, () => exports2.ProjectArtifacts$, () => ProjectArtifactsList, () => exports2.ProjectCache$, () => exports2.ProjectEnvironment$, 0, 1, 1, 0, () => TagList, 4, 4, () => exports2.Webhook$, () => exports2.VpcConfig$, () => exports2.ProjectBadge$, () => exports2.LogsConfig$, () => ProjectFileSystemLocations, () => exports2.ProjectBuildBatchConfig$, 1, 0, 0, 0, 1]
    ];
    exports2.ProjectArtifacts$ = [
      3,
      n032,
      _PA10,
      0,
      [_t, _lo, _pa, _nTa, _na, _pac, _oAN, _eD, _aI10, _bOA],
      [0, 0, 0, 0, 0, 0, 2, 2, 0, 0],
      1
    ];
    exports2.ProjectBadge$ = [
      3,
      n032,
      _PB,
      0,
      [_bE, _bRU],
      [2, 0]
    ];
    exports2.ProjectBuildBatchConfig$ = [
      3,
      n032,
      _PBBC,
      0,
      [_sR, _cA, _re, _tIMi, _bRM],
      [0, 2, () => exports2.BatchRestrictions$, 1, 0]
    ];
    exports2.ProjectCache$ = [
      3,
      n032,
      _PCr10,
      0,
      [_t, _lo, _mo, _cN],
      [0, 0, 64 | 0, 0],
      1
    ];
    exports2.ProjectEnvironment$ = [
      3,
      n032,
      _PE,
      0,
      [_t, _ima, _cT, _cC, _fl, _eV, _pM, _ce, _rC10, _iPCT, _dSo],
      [0, 0, 0, () => exports2.ComputeConfiguration$, () => exports2.ProjectFleet$, () => EnvironmentVariables, 2, 0, () => exports2.RegistryCredential$, 0, () => exports2.DockerServer$],
      3
    ];
    exports2.ProjectFileSystemLocation$ = [
      3,
      n032,
      _PFSL,
      0,
      [_t, _lo, _mP, _ide, _mO],
      [0, 0, 0, 0, 0]
    ];
    exports2.ProjectFleet$ = [
      3,
      n032,
      _PF,
      0,
      [_fAl],
      [0]
    ];
    exports2.ProjectSource$ = [
      3,
      n032,
      _PS,
      0,
      [_t, _lo, _gCD, _gSC, _bu, _au, _rBS, _bSC, _iS, _sIo],
      [0, 0, 1, () => exports2.GitSubmodulesConfig$, 0, () => exports2.SourceAuth$, 2, () => exports2.BuildStatusConfig$, 2, 0],
      1
    ];
    exports2.ProjectSourceVersion$ = [
      3,
      n032,
      _PSV,
      0,
      [_sIo, _sV],
      [0, 0],
      2
    ];
    exports2.ProxyConfiguration$ = [
      3,
      n032,
      _PCro,
      0,
      [_dB, _oPR],
      [0, () => FleetProxyRules]
    ];
    exports2.PullRequestBuildPolicy$ = [
      3,
      n032,
      _PRBP,
      0,
      [_rCA, _aR],
      [0, 64 | 0],
      1
    ];
    exports2.PutResourcePolicyInput$ = [
      3,
      n032,
      _PRPI,
      0,
      [_po, _rAe],
      [0, 0],
      2
    ];
    exports2.PutResourcePolicyOutput$ = [
      3,
      n032,
      _PRPO,
      0,
      [_rAe],
      [0]
    ];
    exports2.RegistryCredential$ = [
      3,
      n032,
      _RC10,
      0,
      [_cre, _cPr],
      [0, 0],
      2
    ];
    exports2.Report$ = [
      3,
      n032,
      _R,
      0,
      [_a10, _t, _na, _rGAe, _eI13, _st, _cr, _ex10, _eCx, _tr, _tS, _cCS],
      [0, 0, 0, 0, 0, 0, 4, 4, () => exports2.ReportExportConfig$, 2, () => exports2.TestReportSummary$, () => exports2.CodeCoverageReportSummary$]
    ];
    exports2.ReportExportConfig$ = [
      3,
      n032,
      _REC,
      0,
      [_eCT, _sD],
      [0, () => exports2.S3ReportExportConfig$]
    ];
    exports2.ReportFilter$ = [
      3,
      n032,
      _RF,
      0,
      [_st],
      [0]
    ];
    exports2.ReportGroup$ = [
      3,
      n032,
      _RG,
      0,
      [_a10, _na, _t, _eCx, _cr, _lMa, _ta, _st],
      [0, 0, 0, () => exports2.ReportExportConfig$, 4, 4, () => TagList, 0]
    ];
    exports2.ReportGroupTrendStats$ = [
      3,
      n032,
      _RGTS,
      0,
      [_av, _ma, _mi],
      [0, 0, 0]
    ];
    exports2.ReportWithRawData$ = [
      3,
      n032,
      _RWRD,
      0,
      [_rAep, _da],
      [0, 0]
    ];
    exports2.ResolvedArtifact$ = [
      3,
      n032,
      _RA10,
      0,
      [_t, _lo, _ide],
      [0, 0, 0]
    ];
    exports2.RetryBuildBatchInput$ = [
      3,
      n032,
      _RBBI,
      0,
      [_id, _iTd, _rT13],
      [0, 0, 0]
    ];
    exports2.RetryBuildBatchOutput$ = [
      3,
      n032,
      _RBBO,
      0,
      [_bBu],
      [() => exports2.BuildBatch$]
    ];
    exports2.RetryBuildInput$ = [
      3,
      n032,
      _RBI,
      0,
      [_id, _iTd],
      [0, 0]
    ];
    exports2.RetryBuildOutput$ = [
      3,
      n032,
      _RBO,
      0,
      [_bui],
      [() => exports2.Build$]
    ];
    exports2.S3LogsConfig$ = [
      3,
      n032,
      _SLC,
      0,
      [_st, _lo, _eD, _bOA],
      [0, 0, 2, 0],
      1
    ];
    exports2.S3ReportExportConfig$ = [
      3,
      n032,
      _SREC,
      0,
      [_buc, _bO, _pa, _pac, _eK, _eD],
      [0, 0, 0, 0, 0, 2]
    ];
    exports2.Sandbox$ = [
      3,
      n032,
      _S,
      0,
      [_id, _a10, _pN, _rTe, _sT19, _eT, _st, _so, _sV, _sS, _sSV, _en, _fSL, _tIM, _qTIM, _vC, _lC, _eK, _sR, _cS4],
      [0, 0, 0, 4, 4, 4, 0, () => exports2.ProjectSource$, 0, () => ProjectSources, () => ProjectSecondarySourceVersions, () => exports2.ProjectEnvironment$, () => ProjectFileSystemLocations, 1, 1, () => exports2.VpcConfig$, () => exports2.LogsConfig$, 0, 0, () => exports2.SandboxSession$]
    ];
    exports2.SandboxSession$ = [
      3,
      n032,
      _SSa,
      0,
      [_id, _st, _sT19, _eT, _cP, _ph, _rSV, _l, _nI],
      [0, 0, 4, 4, 0, () => SandboxSessionPhases, 0, () => exports2.LogsLocation$, () => exports2.NetworkInterface$]
    ];
    exports2.SandboxSessionPhase$ = [
      3,
      n032,
      _SSP,
      0,
      [_pT, _pS, _sT19, _eT, _dIS, _con],
      [0, 0, 4, 4, 1, () => PhaseContexts]
    ];
    exports2.ScalingConfigurationInput$ = [
      3,
      n032,
      _SCI,
      0,
      [_sTc, _tTSC, _mCa],
      [0, () => TargetTrackingScalingConfigurations, 1]
    ];
    exports2.ScalingConfigurationOutput$ = [
      3,
      n032,
      _SCO,
      0,
      [_sTc, _tTSC, _mCa, _dC4],
      [0, () => TargetTrackingScalingConfigurations, 1, 1]
    ];
    exports2.ScopeConfiguration$ = [
      3,
      n032,
      _SC,
      0,
      [_na, _sc4, _do],
      [0, 0, 0],
      2
    ];
    exports2.SourceAuth$ = [
      3,
      n032,
      _SA,
      0,
      [_t, _res],
      [0, 0],
      1
    ];
    exports2.SourceCredentialsInfo$ = [
      3,
      n032,
      _SCIo,
      0,
      [_a10, _sTer, _aT22, _res],
      [0, 0, 0, 0]
    ];
    exports2.SSMSession$ = [
      3,
      n032,
      _SSMS,
      0,
      [_sIe, _tV, _sU],
      [0, 0, 0]
    ];
    exports2.StartBuildBatchInput$ = [
      3,
      n032,
      _SBBI,
      0,
      [_pN, _sSO, _sSVO, _sV, _aO, _sAO, _eVO, _sTO, _sLO, _sAOo, _gCDO, _gSCO, _bOu, _iSO, _rBBSO, _eTO, _iO, _cTO, _cO, _cOa, _sRO, _pMO, _bTIMO, _qTIMO, _eKO, _iTd, _lCO, _rCO, _iPCTO, _bBCO, _dSE],
      [0, () => ProjectSources, () => ProjectSecondarySourceVersions, 0, () => exports2.ProjectArtifacts$, () => ProjectArtifactsList, () => EnvironmentVariables, 0, 0, () => exports2.SourceAuth$, 1, () => exports2.GitSubmodulesConfig$, 0, 2, 2, 0, 0, 0, 0, () => exports2.ProjectCache$, 0, 2, 1, 1, 0, 0, () => exports2.LogsConfig$, () => exports2.RegistryCredential$, 0, () => exports2.ProjectBuildBatchConfig$, 2],
      1
    ];
    exports2.StartBuildBatchOutput$ = [
      3,
      n032,
      _SBBO,
      0,
      [_bBu],
      [() => exports2.BuildBatch$]
    ];
    exports2.StartBuildInput$ = [
      3,
      n032,
      _SBI,
      0,
      [_pN, _sSO, _sSVO, _sV, _aO, _sAO, _eVO, _sTO, _sLO, _sAOo, _gCDO, _gSCO, _bOu, _iSO, _rBSO, _bSCO, _eTO, _iO, _cTO, _cO, _cOa, _sRO, _pMO, _tIMO, _qTIMO, _eKO, _iTd, _lCO, _rCO, _iPCTO, _dSE, _fO, _aRLO],
      [0, () => ProjectSources, () => ProjectSecondarySourceVersions, 0, () => exports2.ProjectArtifacts$, () => ProjectArtifactsList, () => EnvironmentVariables, 0, 0, () => exports2.SourceAuth$, 1, () => exports2.GitSubmodulesConfig$, 0, 2, 2, () => exports2.BuildStatusConfig$, 0, 0, 0, 0, () => exports2.ProjectCache$, 0, 2, 1, 1, 0, 0, () => exports2.LogsConfig$, () => exports2.RegistryCredential$, 0, 2, () => exports2.ProjectFleet$, 1],
      1
    ];
    exports2.StartBuildOutput$ = [
      3,
      n032,
      _SBO,
      0,
      [_bui],
      [() => exports2.Build$]
    ];
    exports2.StartCommandExecutionInput$ = [
      3,
      n032,
      _SCEI,
      0,
      [_sI, _com, _t],
      [0, [() => SensitiveNonEmptyString, 0], 0],
      2
    ];
    exports2.StartCommandExecutionOutput$ = [
      3,
      n032,
      _SCEO,
      0,
      [_cEo],
      [[() => exports2.CommandExecution$, 0]]
    ];
    exports2.StartSandboxConnectionInput$ = [
      3,
      n032,
      _SSCI,
      0,
      [_sI],
      [0],
      1
    ];
    exports2.StartSandboxConnectionOutput$ = [
      3,
      n032,
      _SSCO,
      0,
      [_sSs],
      [() => exports2.SSMSession$]
    ];
    exports2.StartSandboxInput$ = [
      3,
      n032,
      _SSI,
      0,
      [_pN, _iTd],
      [0, [() => SensitiveString, 0]]
    ];
    exports2.StartSandboxOutput$ = [
      3,
      n032,
      _SSO,
      0,
      [_san],
      [() => exports2.Sandbox$]
    ];
    exports2.StopBuildBatchInput$ = [
      3,
      n032,
      _SBBIt,
      0,
      [_id],
      [0],
      1
    ];
    exports2.StopBuildBatchOutput$ = [
      3,
      n032,
      _SBBOt,
      0,
      [_bBu],
      [() => exports2.BuildBatch$]
    ];
    exports2.StopBuildInput$ = [
      3,
      n032,
      _SBIt,
      0,
      [_id],
      [0],
      1
    ];
    exports2.StopBuildOutput$ = [
      3,
      n032,
      _SBOt,
      0,
      [_bui],
      [() => exports2.Build$]
    ];
    exports2.StopSandboxInput$ = [
      3,
      n032,
      _SSIt,
      0,
      [_id],
      [0],
      1
    ];
    exports2.StopSandboxOutput$ = [
      3,
      n032,
      _SSOt,
      0,
      [_san],
      [() => exports2.Sandbox$]
    ];
    exports2.Tag$ = [
      3,
      n032,
      _T10,
      0,
      [_k, _va],
      [0, 0]
    ];
    exports2.TargetTrackingScalingConfiguration$ = [
      3,
      n032,
      _TTSC,
      0,
      [_mTe, _tVa],
      [0, 1]
    ];
    exports2.TestCase$ = [
      3,
      n032,
      _TC10,
      0,
      [_rAep, _tRDP, _pre, _na, _st, _dINS, _m29, _ex10, _tSN],
      [0, 0, 0, 0, 0, 1, 0, 4, 0]
    ];
    exports2.TestCaseFilter$ = [
      3,
      n032,
      _TCF,
      0,
      [_st, _ke],
      [0, 0]
    ];
    exports2.TestReportSummary$ = [
      3,
      n032,
      _TRS,
      0,
      [_tot, _sCt, _dINS],
      [1, 128 | 1, 1],
      3
    ];
    exports2.UpdateFleetInput$ = [
      3,
      n032,
      _UFI,
      0,
      [_a10, _bCa, _eTn, _cT, _cC, _sCc, _oB, _vC, _pC, _iI, _fSR, _ta],
      [0, 1, 0, 0, () => exports2.ComputeConfiguration$, () => exports2.ScalingConfigurationInput$, 0, () => exports2.VpcConfig$, () => exports2.ProxyConfiguration$, 0, 0, () => TagList],
      1
    ];
    exports2.UpdateFleetOutput$ = [
      3,
      n032,
      _UFO,
      0,
      [_fl],
      [() => exports2.Fleet$]
    ];
    exports2.UpdateProjectInput$ = [
      3,
      n032,
      _UPI,
      0,
      [_na, _de, _so, _sS, _sV, _sSV, _ar, _sA, _ca, _en, _sR, _tIM, _qTIM, _eK, _ta, _vC, _bE, _lCo, _fSL, _bBC, _cBL, _aRL],
      [0, 0, () => exports2.ProjectSource$, () => ProjectSources, 0, () => ProjectSecondarySourceVersions, () => exports2.ProjectArtifacts$, () => ProjectArtifactsList, () => exports2.ProjectCache$, () => exports2.ProjectEnvironment$, 0, 1, 1, 0, () => TagList, () => exports2.VpcConfig$, 2, () => exports2.LogsConfig$, () => ProjectFileSystemLocations, () => exports2.ProjectBuildBatchConfig$, 1, 1],
      1
    ];
    exports2.UpdateProjectOutput$ = [
      3,
      n032,
      _UPO,
      0,
      [_pr],
      [() => exports2.Project$]
    ];
    exports2.UpdateProjectVisibilityInput$ = [
      3,
      n032,
      _UPVI,
      0,
      [_pAr, _pV, _rAR],
      [0, 0, 0],
      2
    ];
    exports2.UpdateProjectVisibilityOutput$ = [
      3,
      n032,
      _UPVO,
      0,
      [_pAr, _pPA, _pV],
      [0, 0, 0]
    ];
    exports2.UpdateReportGroupInput$ = [
      3,
      n032,
      _URGI,
      0,
      [_a10, _eCx, _ta],
      [0, () => exports2.ReportExportConfig$, () => TagList],
      1
    ];
    exports2.UpdateReportGroupOutput$ = [
      3,
      n032,
      _URGO,
      0,
      [_rGe],
      [() => exports2.ReportGroup$]
    ];
    exports2.UpdateWebhookInput$ = [
      3,
      n032,
      _UWI,
      0,
      [_pN, _bF, _rS, _fG, _bT, _pRBP],
      [0, 0, 2, () => FilterGroups, 0, () => exports2.PullRequestBuildPolicy$],
      1
    ];
    exports2.UpdateWebhookOutput$ = [
      3,
      n032,
      _UWO,
      0,
      [_w],
      [() => exports2.Webhook$]
    ];
    exports2.VpcConfig$ = [
      3,
      n032,
      _VC,
      0,
      [_vI, _su, _sGI],
      [0, 64 | 0, 64 | 0]
    ];
    exports2.Webhook$ = [
      3,
      n032,
      _W,
      0,
      [_ur, _pU, _se14, _bF, _fG, _bT, _mC, _lMS, _sCco, _st, _sM, _pRBP],
      [0, 0, 0, 0, () => FilterGroups, 0, 2, 4, () => exports2.ScopeConfiguration$, 0, 0, () => exports2.PullRequestBuildPolicy$]
    ];
    exports2.WebhookFilter$ = [
      3,
      n032,
      _WF,
      0,
      [_t, _pat, _eMP],
      [0, 0, 2],
      2
    ];
    var BuildArtifactsList = [
      1,
      n032,
      _BAL,
      0,
      () => exports2.BuildArtifacts$
    ];
    var BuildBatches = [
      1,
      n032,
      _BBu,
      0,
      () => exports2.BuildBatch$
    ];
    var BuildBatchIds = 64 | 0;
    var BuildBatchPhases = [
      1,
      n032,
      _BBPu,
      0,
      () => exports2.BuildBatchPhase$
    ];
    var BuildGroups = [
      1,
      n032,
      _BGu,
      0,
      () => exports2.BuildGroup$
    ];
    var BuildIds = 64 | 0;
    var BuildPhases = [
      1,
      n032,
      _BPu,
      0,
      () => exports2.BuildPhase$
    ];
    var BuildReportArns = 64 | 0;
    var Builds = [
      1,
      n032,
      _Bu,
      0,
      () => exports2.Build$
    ];
    var BuildsNotDeleted = [
      1,
      n032,
      _BNDu,
      0,
      () => exports2.BuildNotDeleted$
    ];
    var BuildSummaries = [
      1,
      n032,
      _BSu,
      0,
      () => exports2.BuildSummary$
    ];
    var CodeCoverages = [
      1,
      n032,
      _CCod,
      0,
      () => exports2.CodeCoverage$
    ];
    var CommandExecutionIds = 64 | 0;
    var CommandExecutions = [
      1,
      n032,
      _CEo,
      0,
      [
        () => exports2.CommandExecution$,
        0
      ]
    ];
    var ComputeTypesAllowed = 64 | 0;
    var EnvironmentImages = [
      1,
      n032,
      _EIn,
      0,
      () => exports2.EnvironmentImage$
    ];
    var EnvironmentLanguages = [
      1,
      n032,
      _ELn,
      0,
      () => exports2.EnvironmentLanguage$
    ];
    var EnvironmentPlatforms = [
      1,
      n032,
      _EPn,
      0,
      () => exports2.EnvironmentPlatform$
    ];
    var EnvironmentVariables = [
      1,
      n032,
      _EVn,
      0,
      () => exports2.EnvironmentVariable$
    ];
    var ExportedEnvironmentVariables = [
      1,
      n032,
      _EEVx,
      0,
      () => exports2.ExportedEnvironmentVariable$
    ];
    var FilterGroup = [
      1,
      n032,
      _FGi,
      0,
      () => exports2.WebhookFilter$
    ];
    var FilterGroups = [
      1,
      n032,
      _FG,
      0,
      () => FilterGroup
    ];
    var FleetArns = 64 | 0;
    var FleetNames = 64 | 0;
    var FleetProxyRuleEntities = 64 | 0;
    var FleetProxyRules = [
      1,
      n032,
      _FPRl,
      0,
      () => exports2.FleetProxyRule$
    ];
    var Fleets = [
      1,
      n032,
      _Fl,
      0,
      () => exports2.Fleet$
    ];
    var FleetsAllowed = 64 | 0;
    var Identifiers = 64 | 0;
    var ImageVersions = 64 | 0;
    var PhaseContexts = [
      1,
      n032,
      _PCh,
      0,
      () => exports2.PhaseContext$
    ];
    var ProjectArns = 64 | 0;
    var ProjectArtifactsList = [
      1,
      n032,
      _PAL,
      0,
      () => exports2.ProjectArtifacts$
    ];
    var ProjectCacheModes = 64 | 0;
    var ProjectFileSystemLocations = [
      1,
      n032,
      _PFSLr,
      0,
      () => exports2.ProjectFileSystemLocation$
    ];
    var ProjectNames = 64 | 0;
    var Projects = [
      1,
      n032,
      _Pr10,
      0,
      () => exports2.Project$
    ];
    var ProjectSecondarySourceVersions = [
      1,
      n032,
      _PSSV,
      0,
      () => exports2.ProjectSourceVersion$
    ];
    var ProjectSources = [
      1,
      n032,
      _PSr,
      0,
      () => exports2.ProjectSource$
    ];
    var PullRequestBuildApproverRoles = 64 | 0;
    var ReportArns = 64 | 0;
    var ReportGroupArns = 64 | 0;
    var ReportGroups = [
      1,
      n032,
      _RGe,
      0,
      () => exports2.ReportGroup$
    ];
    var ReportGroupTrendRawDataList = [
      1,
      n032,
      _RGTRDL,
      0,
      () => exports2.ReportWithRawData$
    ];
    var Reports = [
      1,
      n032,
      _Re,
      0,
      () => exports2.Report$
    ];
    var ResolvedSecondaryArtifacts = [
      1,
      n032,
      _RSA,
      0,
      () => exports2.ResolvedArtifact$
    ];
    var Sandboxes = [
      1,
      n032,
      _Sa,
      0,
      () => exports2.Sandbox$
    ];
    var SandboxIds = 64 | 0;
    var SandboxSessionPhases = [
      1,
      n032,
      _SSPa,
      0,
      () => exports2.SandboxSessionPhase$
    ];
    var SecurityGroupIds = 64 | 0;
    var SourceCredentialsInfos = [
      1,
      n032,
      _SCIou,
      0,
      () => exports2.SourceCredentialsInfo$
    ];
    var Subnets = 64 | 0;
    var TagList = [
      1,
      n032,
      _TL,
      0,
      () => exports2.Tag$
    ];
    var TargetTrackingScalingConfigurations = [
      1,
      n032,
      _TTSCa,
      0,
      () => exports2.TargetTrackingScalingConfiguration$
    ];
    var TestCases = [
      1,
      n032,
      _TCe,
      0,
      () => exports2.TestCase$
    ];
    var ReportStatusCounts = 128 | 1;
    exports2.BatchDeleteBuilds$ = [
      9,
      n032,
      _BDB,
      0,
      () => exports2.BatchDeleteBuildsInput$,
      () => exports2.BatchDeleteBuildsOutput$
    ];
    exports2.BatchGetBuildBatches$ = [
      9,
      n032,
      _BGBB,
      0,
      () => exports2.BatchGetBuildBatchesInput$,
      () => exports2.BatchGetBuildBatchesOutput$
    ];
    exports2.BatchGetBuilds$ = [
      9,
      n032,
      _BGB,
      0,
      () => exports2.BatchGetBuildsInput$,
      () => exports2.BatchGetBuildsOutput$
    ];
    exports2.BatchGetCommandExecutions$ = [
      9,
      n032,
      _BGCE,
      0,
      () => exports2.BatchGetCommandExecutionsInput$,
      () => exports2.BatchGetCommandExecutionsOutput$
    ];
    exports2.BatchGetFleets$ = [
      9,
      n032,
      _BGF,
      0,
      () => exports2.BatchGetFleetsInput$,
      () => exports2.BatchGetFleetsOutput$
    ];
    exports2.BatchGetProjects$ = [
      9,
      n032,
      _BGP,
      0,
      () => exports2.BatchGetProjectsInput$,
      () => exports2.BatchGetProjectsOutput$
    ];
    exports2.BatchGetReportGroups$ = [
      9,
      n032,
      _BGRG,
      0,
      () => exports2.BatchGetReportGroupsInput$,
      () => exports2.BatchGetReportGroupsOutput$
    ];
    exports2.BatchGetReports$ = [
      9,
      n032,
      _BGR,
      0,
      () => exports2.BatchGetReportsInput$,
      () => exports2.BatchGetReportsOutput$
    ];
    exports2.BatchGetSandboxes$ = [
      9,
      n032,
      _BGS,
      0,
      () => exports2.BatchGetSandboxesInput$,
      () => exports2.BatchGetSandboxesOutput$
    ];
    exports2.CreateFleet$ = [
      9,
      n032,
      _CF,
      0,
      () => exports2.CreateFleetInput$,
      () => exports2.CreateFleetOutput$
    ];
    exports2.CreateProject$ = [
      9,
      n032,
      _CP,
      0,
      () => exports2.CreateProjectInput$,
      () => exports2.CreateProjectOutput$
    ];
    exports2.CreateReportGroup$ = [
      9,
      n032,
      _CRG,
      0,
      () => exports2.CreateReportGroupInput$,
      () => exports2.CreateReportGroupOutput$
    ];
    exports2.CreateWebhook$ = [
      9,
      n032,
      _CW,
      0,
      () => exports2.CreateWebhookInput$,
      () => exports2.CreateWebhookOutput$
    ];
    exports2.DeleteBuildBatch$ = [
      9,
      n032,
      _DBB,
      0,
      () => exports2.DeleteBuildBatchInput$,
      () => exports2.DeleteBuildBatchOutput$
    ];
    exports2.DeleteFleet$ = [
      9,
      n032,
      _DF,
      0,
      () => exports2.DeleteFleetInput$,
      () => exports2.DeleteFleetOutput$
    ];
    exports2.DeleteProject$ = [
      9,
      n032,
      _DP,
      0,
      () => exports2.DeleteProjectInput$,
      () => exports2.DeleteProjectOutput$
    ];
    exports2.DeleteReport$ = [
      9,
      n032,
      _DR,
      0,
      () => exports2.DeleteReportInput$,
      () => exports2.DeleteReportOutput$
    ];
    exports2.DeleteReportGroup$ = [
      9,
      n032,
      _DRG,
      0,
      () => exports2.DeleteReportGroupInput$,
      () => exports2.DeleteReportGroupOutput$
    ];
    exports2.DeleteResourcePolicy$ = [
      9,
      n032,
      _DRP,
      0,
      () => exports2.DeleteResourcePolicyInput$,
      () => exports2.DeleteResourcePolicyOutput$
    ];
    exports2.DeleteSourceCredentials$ = [
      9,
      n032,
      _DSC,
      0,
      () => exports2.DeleteSourceCredentialsInput$,
      () => exports2.DeleteSourceCredentialsOutput$
    ];
    exports2.DeleteWebhook$ = [
      9,
      n032,
      _DW,
      0,
      () => exports2.DeleteWebhookInput$,
      () => exports2.DeleteWebhookOutput$
    ];
    exports2.DescribeCodeCoverages$ = [
      9,
      n032,
      _DCC,
      0,
      () => exports2.DescribeCodeCoveragesInput$,
      () => exports2.DescribeCodeCoveragesOutput$
    ];
    exports2.DescribeTestCases$ = [
      9,
      n032,
      _DTC,
      0,
      () => exports2.DescribeTestCasesInput$,
      () => exports2.DescribeTestCasesOutput$
    ];
    exports2.GetReportGroupTrend$ = [
      9,
      n032,
      _GRGT,
      0,
      () => exports2.GetReportGroupTrendInput$,
      () => exports2.GetReportGroupTrendOutput$
    ];
    exports2.GetResourcePolicy$ = [
      9,
      n032,
      _GRP,
      0,
      () => exports2.GetResourcePolicyInput$,
      () => exports2.GetResourcePolicyOutput$
    ];
    exports2.ImportSourceCredentials$ = [
      9,
      n032,
      _ISC,
      0,
      () => exports2.ImportSourceCredentialsInput$,
      () => exports2.ImportSourceCredentialsOutput$
    ];
    exports2.InvalidateProjectCache$ = [
      9,
      n032,
      _IPC,
      0,
      () => exports2.InvalidateProjectCacheInput$,
      () => exports2.InvalidateProjectCacheOutput$
    ];
    exports2.ListBuildBatches$ = [
      9,
      n032,
      _LBB,
      0,
      () => exports2.ListBuildBatchesInput$,
      () => exports2.ListBuildBatchesOutput$
    ];
    exports2.ListBuildBatchesForProject$ = [
      9,
      n032,
      _LBBFP,
      0,
      () => exports2.ListBuildBatchesForProjectInput$,
      () => exports2.ListBuildBatchesForProjectOutput$
    ];
    exports2.ListBuilds$ = [
      9,
      n032,
      _LB,
      0,
      () => exports2.ListBuildsInput$,
      () => exports2.ListBuildsOutput$
    ];
    exports2.ListBuildsForProject$ = [
      9,
      n032,
      _LBFP,
      0,
      () => exports2.ListBuildsForProjectInput$,
      () => exports2.ListBuildsForProjectOutput$
    ];
    exports2.ListCommandExecutionsForSandbox$ = [
      9,
      n032,
      _LCEFS,
      0,
      () => exports2.ListCommandExecutionsForSandboxInput$,
      () => exports2.ListCommandExecutionsForSandboxOutput$
    ];
    exports2.ListCuratedEnvironmentImages$ = [
      9,
      n032,
      _LCEI,
      0,
      () => exports2.ListCuratedEnvironmentImagesInput$,
      () => exports2.ListCuratedEnvironmentImagesOutput$
    ];
    exports2.ListFleets$ = [
      9,
      n032,
      _LF,
      0,
      () => exports2.ListFleetsInput$,
      () => exports2.ListFleetsOutput$
    ];
    exports2.ListProjects$ = [
      9,
      n032,
      _LP,
      0,
      () => exports2.ListProjectsInput$,
      () => exports2.ListProjectsOutput$
    ];
    exports2.ListReportGroups$ = [
      9,
      n032,
      _LRG,
      0,
      () => exports2.ListReportGroupsInput$,
      () => exports2.ListReportGroupsOutput$
    ];
    exports2.ListReports$ = [
      9,
      n032,
      _LR,
      0,
      () => exports2.ListReportsInput$,
      () => exports2.ListReportsOutput$
    ];
    exports2.ListReportsForReportGroup$ = [
      9,
      n032,
      _LRFRG,
      0,
      () => exports2.ListReportsForReportGroupInput$,
      () => exports2.ListReportsForReportGroupOutput$
    ];
    exports2.ListSandboxes$ = [
      9,
      n032,
      _LS,
      0,
      () => exports2.ListSandboxesInput$,
      () => exports2.ListSandboxesOutput$
    ];
    exports2.ListSandboxesForProject$ = [
      9,
      n032,
      _LSFP,
      0,
      () => exports2.ListSandboxesForProjectInput$,
      () => exports2.ListSandboxesForProjectOutput$
    ];
    exports2.ListSharedProjects$ = [
      9,
      n032,
      _LSP,
      0,
      () => exports2.ListSharedProjectsInput$,
      () => exports2.ListSharedProjectsOutput$
    ];
    exports2.ListSharedReportGroups$ = [
      9,
      n032,
      _LSRG,
      0,
      () => exports2.ListSharedReportGroupsInput$,
      () => exports2.ListSharedReportGroupsOutput$
    ];
    exports2.ListSourceCredentials$ = [
      9,
      n032,
      _LSC,
      0,
      () => exports2.ListSourceCredentialsInput$,
      () => exports2.ListSourceCredentialsOutput$
    ];
    exports2.PutResourcePolicy$ = [
      9,
      n032,
      _PRP,
      0,
      () => exports2.PutResourcePolicyInput$,
      () => exports2.PutResourcePolicyOutput$
    ];
    exports2.RetryBuild$ = [
      9,
      n032,
      _RB,
      0,
      () => exports2.RetryBuildInput$,
      () => exports2.RetryBuildOutput$
    ];
    exports2.RetryBuildBatch$ = [
      9,
      n032,
      _RBB,
      0,
      () => exports2.RetryBuildBatchInput$,
      () => exports2.RetryBuildBatchOutput$
    ];
    exports2.StartBuild$ = [
      9,
      n032,
      _SB,
      0,
      () => exports2.StartBuildInput$,
      () => exports2.StartBuildOutput$
    ];
    exports2.StartBuildBatch$ = [
      9,
      n032,
      _SBB,
      0,
      () => exports2.StartBuildBatchInput$,
      () => exports2.StartBuildBatchOutput$
    ];
    exports2.StartCommandExecution$ = [
      9,
      n032,
      _SCE,
      0,
      () => exports2.StartCommandExecutionInput$,
      () => exports2.StartCommandExecutionOutput$
    ];
    exports2.StartSandbox$ = [
      9,
      n032,
      _SSt,
      0,
      () => exports2.StartSandboxInput$,
      () => exports2.StartSandboxOutput$
    ];
    exports2.StartSandboxConnection$ = [
      9,
      n032,
      _SSC,
      0,
      () => exports2.StartSandboxConnectionInput$,
      () => exports2.StartSandboxConnectionOutput$
    ];
    exports2.StopBuild$ = [
      9,
      n032,
      _SBt,
      0,
      () => exports2.StopBuildInput$,
      () => exports2.StopBuildOutput$
    ];
    exports2.StopBuildBatch$ = [
      9,
      n032,
      _SBBt,
      0,
      () => exports2.StopBuildBatchInput$,
      () => exports2.StopBuildBatchOutput$
    ];
    exports2.StopSandbox$ = [
      9,
      n032,
      _SSto,
      0,
      () => exports2.StopSandboxInput$,
      () => exports2.StopSandboxOutput$
    ];
    exports2.UpdateFleet$ = [
      9,
      n032,
      _UF,
      0,
      () => exports2.UpdateFleetInput$,
      () => exports2.UpdateFleetOutput$
    ];
    exports2.UpdateProject$ = [
      9,
      n032,
      _UP,
      0,
      () => exports2.UpdateProjectInput$,
      () => exports2.UpdateProjectOutput$
    ];
    exports2.UpdateProjectVisibility$ = [
      9,
      n032,
      _UPV,
      0,
      () => exports2.UpdateProjectVisibilityInput$,
      () => exports2.UpdateProjectVisibilityOutput$
    ];
    exports2.UpdateReportGroup$ = [
      9,
      n032,
      _URG,
      0,
      () => exports2.UpdateReportGroupInput$,
      () => exports2.UpdateReportGroupOutput$
    ];
    exports2.UpdateWebhook$ = [
      9,
      n032,
      _UW,
      0,
      () => exports2.UpdateWebhookInput$,
      () => exports2.UpdateWebhookOutput$
    ];
  }
});

// ../../node_modules/@aws-sdk/client-codebuild/dist-cjs/runtimeConfig.shared.js
var require_runtimeConfig_shared11 = __commonJS({
  "../../node_modules/@aws-sdk/client-codebuild/dist-cjs/runtimeConfig.shared.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var protocols_1 = (init_protocols8(), __toCommonJS(protocols_exports5));
    var smithy_client_1 = require_dist_cjs34();
    var url_parser_1 = require_dist_cjs18();
    var util_base64_1 = require_dist_cjs10();
    var util_utf8_1 = require_dist_cjs9();
    var httpAuthSchemeProvider_1 = require_httpAuthSchemeProvider10();
    var endpointResolver_1 = require_endpointResolver10();
    var schemas_0_1 = require_schemas_010();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2016-10-06",
        base64Decoder: config2?.base64Decoder ?? util_base64_1.fromBase64,
        base64Encoder: config2?.base64Encoder ?? util_base64_1.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? endpointResolver_1.defaultEndpointResolver,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? httpAuthSchemeProvider_1.defaultCodeBuildHttpAuthSchemeProvider,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new httpAuthSchemes_1.AwsSdkSigV4Signer()
          }
        ],
        logger: config2?.logger ?? new smithy_client_1.NoOpLogger(),
        protocol: config2?.protocol ?? protocols_1.AwsJson1_1Protocol,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.codebuild",
          errorTypeRegistries: schemas_0_1.errorTypeRegistries,
          version: "2016-10-06",
          serviceTarget: "CodeBuild_20161006"
        },
        serviceId: config2?.serviceId ?? "CodeBuild",
        urlParser: config2?.urlParser ?? url_parser_1.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? util_utf8_1.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? util_utf8_1.toUtf8
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-codebuild/dist-cjs/runtimeConfig.js
var require_runtimeConfig11 = __commonJS({
  "../../node_modules/@aws-sdk/client-codebuild/dist-cjs/runtimeConfig.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var package_json_1 = tslib_1.__importDefault(require_package10());
    var client_1 = (init_client8(), __toCommonJS(client_exports7));
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var credential_provider_node_1 = require_dist_cjs122();
    var util_user_agent_node_1 = require_dist_cjs113();
    var config_resolver_1 = require_dist_cjs25();
    var hash_node_1 = require_dist_cjs44();
    var middleware_retry_1 = require_dist_cjs106();
    var node_config_provider_1 = require_dist_cjs29();
    var node_http_handler_1 = require_dist_cjs13();
    var smithy_client_1 = require_dist_cjs34();
    var util_body_length_node_1 = require_dist_cjs45();
    var util_defaults_mode_node_1 = require_dist_cjs46();
    var util_retry_1 = require_dist_cjs22();
    var runtimeConfig_shared_1 = require_runtimeConfig_shared11();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      (0, smithy_client_1.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, util_defaults_mode_node_1.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(smithy_client_1.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = (0, runtimeConfig_shared_1.getRuntimeConfig)(config2);
      (0, client_1.emitWarningIfUnsupportedVersion)(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, node_config_provider_1.loadConfig)(httpAuthSchemes_1.NODE_AUTH_SCHEME_PREFERENCE_OPTIONS, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? util_body_length_node_1.calculateBodyLength,
        credentialDefaultProvider: config2?.credentialDefaultProvider ?? credential_provider_node_1.defaultProvider,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, util_user_agent_node_1.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_json_1.default.version }),
        maxAttempts: config2?.maxAttempts ?? (0, node_config_provider_1.loadConfig)(middleware_retry_1.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_REGION_CONFIG_OPTIONS, { ...config_resolver_1.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: node_http_handler_1.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, node_config_provider_1.loadConfig)({
          ...middleware_retry_1.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || util_retry_1.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? hash_node_1.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? node_http_handler_1.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, node_config_provider_1.loadConfig)(util_user_agent_node_1.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-codebuild/dist-cjs/index.js
var require_dist_cjs160 = __commonJS({
  "../../node_modules/@aws-sdk/client-codebuild/dist-cjs/index.js"(exports2) {
    "use strict";
    var middlewareHostHeader = require_dist_cjs3();
    var middlewareLogger = require_dist_cjs4();
    var middlewareRecursionDetection = require_dist_cjs5();
    var middlewareUserAgent = require_dist_cjs104();
    var configResolver = require_dist_cjs25();
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var schema = (init_schema4(), __toCommonJS(schema_exports));
    var middlewareContentLength = require_dist_cjs26();
    var middlewareEndpoint = require_dist_cjs31();
    var middlewareRetry = require_dist_cjs106();
    var smithyClient = require_dist_cjs34();
    var httpAuthSchemeProvider = require_httpAuthSchemeProvider10();
    var runtimeConfig = require_runtimeConfig11();
    var regionConfigResolver = require_dist_cjs48();
    var protocolHttp = require_dist_cjs2();
    var schemas_0 = require_schemas_010();
    var errors = require_errors10();
    var CodeBuildServiceException = require_CodeBuildServiceException();
    var resolveClientEndpointParameters32 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "codebuild"
      });
    }, "resolveClientEndpointParameters");
    var commonParams32 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
    var getHttpAuthExtensionConfiguration32 = /* @__PURE__ */ __name((runtimeConfig2) => {
      const _httpAuthSchemes = runtimeConfig2.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig2.httpAuthSchemeProvider;
      let _credentials = runtimeConfig2.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider2) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider2;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    var resolveHttpAuthRuntimeConfig32 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
    var resolveRuntimeExtensions32 = /* @__PURE__ */ __name((runtimeConfig2, extensions) => {
      const extensionConfiguration = Object.assign(regionConfigResolver.getAwsRegionExtensionConfiguration(runtimeConfig2), smithyClient.getDefaultExtensionConfiguration(runtimeConfig2), protocolHttp.getHttpHandlerExtensionConfiguration(runtimeConfig2), getHttpAuthExtensionConfiguration32(runtimeConfig2));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig2, regionConfigResolver.resolveAwsRegionExtensionConfiguration(extensionConfiguration), smithyClient.resolveDefaultRuntimeConfig(extensionConfiguration), protocolHttp.resolveHttpHandlerRuntimeConfig(extensionConfiguration), resolveHttpAuthRuntimeConfig32(extensionConfiguration));
    }, "resolveRuntimeExtensions");
    var CodeBuildClient2 = class extends smithyClient.Client {
      static {
        __name(this, "CodeBuildClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = runtimeConfig.getRuntimeConfig(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters32(_config_0);
        const _config_2 = middlewareUserAgent.resolveUserAgentConfig(_config_1);
        const _config_3 = middlewareRetry.resolveRetryConfig(_config_2);
        const _config_4 = configResolver.resolveRegionConfig(_config_3);
        const _config_5 = middlewareHostHeader.resolveHostHeaderConfig(_config_4);
        const _config_6 = middlewareEndpoint.resolveEndpointConfig(_config_5);
        const _config_7 = httpAuthSchemeProvider.resolveHttpAuthSchemeConfig(_config_6);
        const _config_8 = resolveRuntimeExtensions32(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(schema.getSchemaSerdePlugin(this.config));
        this.middlewareStack.use(middlewareUserAgent.getUserAgentPlugin(this.config));
        this.middlewareStack.use(middlewareRetry.getRetryPlugin(this.config));
        this.middlewareStack.use(middlewareContentLength.getContentLengthPlugin(this.config));
        this.middlewareStack.use(middlewareHostHeader.getHostHeaderPlugin(this.config));
        this.middlewareStack.use(middlewareLogger.getLoggerPlugin(this.config));
        this.middlewareStack.use(middlewareRecursionDetection.getRecursionDetectionPlugin(this.config));
        this.middlewareStack.use(core.getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: httpAuthSchemeProvider.defaultCodeBuildHttpAuthSchemeParametersProvider,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new core.DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(core.getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
    var BatchDeleteBuildsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "BatchDeleteBuilds", {}).n("CodeBuildClient", "BatchDeleteBuildsCommand").sc(schemas_0.BatchDeleteBuilds$).build() {
      static {
        __name(this, "BatchDeleteBuildsCommand");
      }
    };
    var BatchGetBuildBatchesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "BatchGetBuildBatches", {}).n("CodeBuildClient", "BatchGetBuildBatchesCommand").sc(schemas_0.BatchGetBuildBatches$).build() {
      static {
        __name(this, "BatchGetBuildBatchesCommand");
      }
    };
    var BatchGetBuildsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "BatchGetBuilds", {}).n("CodeBuildClient", "BatchGetBuildsCommand").sc(schemas_0.BatchGetBuilds$).build() {
      static {
        __name(this, "BatchGetBuildsCommand");
      }
    };
    var BatchGetCommandExecutionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "BatchGetCommandExecutions", {}).n("CodeBuildClient", "BatchGetCommandExecutionsCommand").sc(schemas_0.BatchGetCommandExecutions$).build() {
      static {
        __name(this, "BatchGetCommandExecutionsCommand");
      }
    };
    var BatchGetFleetsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "BatchGetFleets", {}).n("CodeBuildClient", "BatchGetFleetsCommand").sc(schemas_0.BatchGetFleets$).build() {
      static {
        __name(this, "BatchGetFleetsCommand");
      }
    };
    var BatchGetProjectsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "BatchGetProjects", {}).n("CodeBuildClient", "BatchGetProjectsCommand").sc(schemas_0.BatchGetProjects$).build() {
      static {
        __name(this, "BatchGetProjectsCommand");
      }
    };
    var BatchGetReportGroupsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "BatchGetReportGroups", {}).n("CodeBuildClient", "BatchGetReportGroupsCommand").sc(schemas_0.BatchGetReportGroups$).build() {
      static {
        __name(this, "BatchGetReportGroupsCommand");
      }
    };
    var BatchGetReportsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "BatchGetReports", {}).n("CodeBuildClient", "BatchGetReportsCommand").sc(schemas_0.BatchGetReports$).build() {
      static {
        __name(this, "BatchGetReportsCommand");
      }
    };
    var BatchGetSandboxesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "BatchGetSandboxes", {}).n("CodeBuildClient", "BatchGetSandboxesCommand").sc(schemas_0.BatchGetSandboxes$).build() {
      static {
        __name(this, "BatchGetSandboxesCommand");
      }
    };
    var CreateFleetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "CreateFleet", {}).n("CodeBuildClient", "CreateFleetCommand").sc(schemas_0.CreateFleet$).build() {
      static {
        __name(this, "CreateFleetCommand");
      }
    };
    var CreateProjectCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "CreateProject", {}).n("CodeBuildClient", "CreateProjectCommand").sc(schemas_0.CreateProject$).build() {
      static {
        __name(this, "CreateProjectCommand");
      }
    };
    var CreateReportGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "CreateReportGroup", {}).n("CodeBuildClient", "CreateReportGroupCommand").sc(schemas_0.CreateReportGroup$).build() {
      static {
        __name(this, "CreateReportGroupCommand");
      }
    };
    var CreateWebhookCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "CreateWebhook", {}).n("CodeBuildClient", "CreateWebhookCommand").sc(schemas_0.CreateWebhook$).build() {
      static {
        __name(this, "CreateWebhookCommand");
      }
    };
    var DeleteBuildBatchCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "DeleteBuildBatch", {}).n("CodeBuildClient", "DeleteBuildBatchCommand").sc(schemas_0.DeleteBuildBatch$).build() {
      static {
        __name(this, "DeleteBuildBatchCommand");
      }
    };
    var DeleteFleetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "DeleteFleet", {}).n("CodeBuildClient", "DeleteFleetCommand").sc(schemas_0.DeleteFleet$).build() {
      static {
        __name(this, "DeleteFleetCommand");
      }
    };
    var DeleteProjectCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "DeleteProject", {}).n("CodeBuildClient", "DeleteProjectCommand").sc(schemas_0.DeleteProject$).build() {
      static {
        __name(this, "DeleteProjectCommand");
      }
    };
    var DeleteReportCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "DeleteReport", {}).n("CodeBuildClient", "DeleteReportCommand").sc(schemas_0.DeleteReport$).build() {
      static {
        __name(this, "DeleteReportCommand");
      }
    };
    var DeleteReportGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "DeleteReportGroup", {}).n("CodeBuildClient", "DeleteReportGroupCommand").sc(schemas_0.DeleteReportGroup$).build() {
      static {
        __name(this, "DeleteReportGroupCommand");
      }
    };
    var DeleteResourcePolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "DeleteResourcePolicy", {}).n("CodeBuildClient", "DeleteResourcePolicyCommand").sc(schemas_0.DeleteResourcePolicy$).build() {
      static {
        __name(this, "DeleteResourcePolicyCommand");
      }
    };
    var DeleteSourceCredentialsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "DeleteSourceCredentials", {}).n("CodeBuildClient", "DeleteSourceCredentialsCommand").sc(schemas_0.DeleteSourceCredentials$).build() {
      static {
        __name(this, "DeleteSourceCredentialsCommand");
      }
    };
    var DeleteWebhookCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "DeleteWebhook", {}).n("CodeBuildClient", "DeleteWebhookCommand").sc(schemas_0.DeleteWebhook$).build() {
      static {
        __name(this, "DeleteWebhookCommand");
      }
    };
    var DescribeCodeCoveragesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "DescribeCodeCoverages", {}).n("CodeBuildClient", "DescribeCodeCoveragesCommand").sc(schemas_0.DescribeCodeCoverages$).build() {
      static {
        __name(this, "DescribeCodeCoveragesCommand");
      }
    };
    var DescribeTestCasesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "DescribeTestCases", {}).n("CodeBuildClient", "DescribeTestCasesCommand").sc(schemas_0.DescribeTestCases$).build() {
      static {
        __name(this, "DescribeTestCasesCommand");
      }
    };
    var GetReportGroupTrendCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "GetReportGroupTrend", {}).n("CodeBuildClient", "GetReportGroupTrendCommand").sc(schemas_0.GetReportGroupTrend$).build() {
      static {
        __name(this, "GetReportGroupTrendCommand");
      }
    };
    var GetResourcePolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "GetResourcePolicy", {}).n("CodeBuildClient", "GetResourcePolicyCommand").sc(schemas_0.GetResourcePolicy$).build() {
      static {
        __name(this, "GetResourcePolicyCommand");
      }
    };
    var ImportSourceCredentialsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "ImportSourceCredentials", {}).n("CodeBuildClient", "ImportSourceCredentialsCommand").sc(schemas_0.ImportSourceCredentials$).build() {
      static {
        __name(this, "ImportSourceCredentialsCommand");
      }
    };
    var InvalidateProjectCacheCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "InvalidateProjectCache", {}).n("CodeBuildClient", "InvalidateProjectCacheCommand").sc(schemas_0.InvalidateProjectCache$).build() {
      static {
        __name(this, "InvalidateProjectCacheCommand");
      }
    };
    var ListBuildBatchesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "ListBuildBatches", {}).n("CodeBuildClient", "ListBuildBatchesCommand").sc(schemas_0.ListBuildBatches$).build() {
      static {
        __name(this, "ListBuildBatchesCommand");
      }
    };
    var ListBuildBatchesForProjectCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "ListBuildBatchesForProject", {}).n("CodeBuildClient", "ListBuildBatchesForProjectCommand").sc(schemas_0.ListBuildBatchesForProject$).build() {
      static {
        __name(this, "ListBuildBatchesForProjectCommand");
      }
    };
    var ListBuildsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "ListBuilds", {}).n("CodeBuildClient", "ListBuildsCommand").sc(schemas_0.ListBuilds$).build() {
      static {
        __name(this, "ListBuildsCommand");
      }
    };
    var ListBuildsForProjectCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "ListBuildsForProject", {}).n("CodeBuildClient", "ListBuildsForProjectCommand").sc(schemas_0.ListBuildsForProject$).build() {
      static {
        __name(this, "ListBuildsForProjectCommand");
      }
    };
    var ListCommandExecutionsForSandboxCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "ListCommandExecutionsForSandbox", {}).n("CodeBuildClient", "ListCommandExecutionsForSandboxCommand").sc(schemas_0.ListCommandExecutionsForSandbox$).build() {
      static {
        __name(this, "ListCommandExecutionsForSandboxCommand");
      }
    };
    var ListCuratedEnvironmentImagesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "ListCuratedEnvironmentImages", {}).n("CodeBuildClient", "ListCuratedEnvironmentImagesCommand").sc(schemas_0.ListCuratedEnvironmentImages$).build() {
      static {
        __name(this, "ListCuratedEnvironmentImagesCommand");
      }
    };
    var ListFleetsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "ListFleets", {}).n("CodeBuildClient", "ListFleetsCommand").sc(schemas_0.ListFleets$).build() {
      static {
        __name(this, "ListFleetsCommand");
      }
    };
    var ListProjectsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "ListProjects", {}).n("CodeBuildClient", "ListProjectsCommand").sc(schemas_0.ListProjects$).build() {
      static {
        __name(this, "ListProjectsCommand");
      }
    };
    var ListReportGroupsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "ListReportGroups", {}).n("CodeBuildClient", "ListReportGroupsCommand").sc(schemas_0.ListReportGroups$).build() {
      static {
        __name(this, "ListReportGroupsCommand");
      }
    };
    var ListReportsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "ListReports", {}).n("CodeBuildClient", "ListReportsCommand").sc(schemas_0.ListReports$).build() {
      static {
        __name(this, "ListReportsCommand");
      }
    };
    var ListReportsForReportGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "ListReportsForReportGroup", {}).n("CodeBuildClient", "ListReportsForReportGroupCommand").sc(schemas_0.ListReportsForReportGroup$).build() {
      static {
        __name(this, "ListReportsForReportGroupCommand");
      }
    };
    var ListSandboxesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "ListSandboxes", {}).n("CodeBuildClient", "ListSandboxesCommand").sc(schemas_0.ListSandboxes$).build() {
      static {
        __name(this, "ListSandboxesCommand");
      }
    };
    var ListSandboxesForProjectCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "ListSandboxesForProject", {}).n("CodeBuildClient", "ListSandboxesForProjectCommand").sc(schemas_0.ListSandboxesForProject$).build() {
      static {
        __name(this, "ListSandboxesForProjectCommand");
      }
    };
    var ListSharedProjectsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "ListSharedProjects", {}).n("CodeBuildClient", "ListSharedProjectsCommand").sc(schemas_0.ListSharedProjects$).build() {
      static {
        __name(this, "ListSharedProjectsCommand");
      }
    };
    var ListSharedReportGroupsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "ListSharedReportGroups", {}).n("CodeBuildClient", "ListSharedReportGroupsCommand").sc(schemas_0.ListSharedReportGroups$).build() {
      static {
        __name(this, "ListSharedReportGroupsCommand");
      }
    };
    var ListSourceCredentialsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "ListSourceCredentials", {}).n("CodeBuildClient", "ListSourceCredentialsCommand").sc(schemas_0.ListSourceCredentials$).build() {
      static {
        __name(this, "ListSourceCredentialsCommand");
      }
    };
    var PutResourcePolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "PutResourcePolicy", {}).n("CodeBuildClient", "PutResourcePolicyCommand").sc(schemas_0.PutResourcePolicy$).build() {
      static {
        __name(this, "PutResourcePolicyCommand");
      }
    };
    var RetryBuildBatchCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "RetryBuildBatch", {}).n("CodeBuildClient", "RetryBuildBatchCommand").sc(schemas_0.RetryBuildBatch$).build() {
      static {
        __name(this, "RetryBuildBatchCommand");
      }
    };
    var RetryBuildCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "RetryBuild", {}).n("CodeBuildClient", "RetryBuildCommand").sc(schemas_0.RetryBuild$).build() {
      static {
        __name(this, "RetryBuildCommand");
      }
    };
    var StartBuildBatchCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "StartBuildBatch", {}).n("CodeBuildClient", "StartBuildBatchCommand").sc(schemas_0.StartBuildBatch$).build() {
      static {
        __name(this, "StartBuildBatchCommand");
      }
    };
    var StartBuildCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "StartBuild", {}).n("CodeBuildClient", "StartBuildCommand").sc(schemas_0.StartBuild$).build() {
      static {
        __name(this, "StartBuildCommand");
      }
    };
    var StartCommandExecutionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "StartCommandExecution", {}).n("CodeBuildClient", "StartCommandExecutionCommand").sc(schemas_0.StartCommandExecution$).build() {
      static {
        __name(this, "StartCommandExecutionCommand");
      }
    };
    var StartSandboxCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "StartSandbox", {}).n("CodeBuildClient", "StartSandboxCommand").sc(schemas_0.StartSandbox$).build() {
      static {
        __name(this, "StartSandboxCommand");
      }
    };
    var StartSandboxConnectionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "StartSandboxConnection", {}).n("CodeBuildClient", "StartSandboxConnectionCommand").sc(schemas_0.StartSandboxConnection$).build() {
      static {
        __name(this, "StartSandboxConnectionCommand");
      }
    };
    var StopBuildBatchCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "StopBuildBatch", {}).n("CodeBuildClient", "StopBuildBatchCommand").sc(schemas_0.StopBuildBatch$).build() {
      static {
        __name(this, "StopBuildBatchCommand");
      }
    };
    var StopBuildCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "StopBuild", {}).n("CodeBuildClient", "StopBuildCommand").sc(schemas_0.StopBuild$).build() {
      static {
        __name(this, "StopBuildCommand");
      }
    };
    var StopSandboxCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "StopSandbox", {}).n("CodeBuildClient", "StopSandboxCommand").sc(schemas_0.StopSandbox$).build() {
      static {
        __name(this, "StopSandboxCommand");
      }
    };
    var UpdateFleetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "UpdateFleet", {}).n("CodeBuildClient", "UpdateFleetCommand").sc(schemas_0.UpdateFleet$).build() {
      static {
        __name(this, "UpdateFleetCommand");
      }
    };
    var UpdateProjectCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "UpdateProject", {}).n("CodeBuildClient", "UpdateProjectCommand").sc(schemas_0.UpdateProject$).build() {
      static {
        __name(this, "UpdateProjectCommand");
      }
    };
    var UpdateProjectVisibilityCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "UpdateProjectVisibility", {}).n("CodeBuildClient", "UpdateProjectVisibilityCommand").sc(schemas_0.UpdateProjectVisibility$).build() {
      static {
        __name(this, "UpdateProjectVisibilityCommand");
      }
    };
    var UpdateReportGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "UpdateReportGroup", {}).n("CodeBuildClient", "UpdateReportGroupCommand").sc(schemas_0.UpdateReportGroup$).build() {
      static {
        __name(this, "UpdateReportGroupCommand");
      }
    };
    var UpdateWebhookCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("CodeBuild_20161006", "UpdateWebhook", {}).n("CodeBuildClient", "UpdateWebhookCommand").sc(schemas_0.UpdateWebhook$).build() {
      static {
        __name(this, "UpdateWebhookCommand");
      }
    };
    var paginateDescribeCodeCoverages = core.createPaginator(CodeBuildClient2, DescribeCodeCoveragesCommand, "nextToken", "nextToken", "maxResults");
    var paginateDescribeTestCases = core.createPaginator(CodeBuildClient2, DescribeTestCasesCommand, "nextToken", "nextToken", "maxResults");
    var paginateListBuildBatchesForProject = core.createPaginator(CodeBuildClient2, ListBuildBatchesForProjectCommand, "nextToken", "nextToken", "maxResults");
    var paginateListBuildBatches = core.createPaginator(CodeBuildClient2, ListBuildBatchesCommand, "nextToken", "nextToken", "maxResults");
    var paginateListBuildsForProject = core.createPaginator(CodeBuildClient2, ListBuildsForProjectCommand, "nextToken", "nextToken", "");
    var paginateListBuilds = core.createPaginator(CodeBuildClient2, ListBuildsCommand, "nextToken", "nextToken", "");
    var paginateListCommandExecutionsForSandbox = core.createPaginator(CodeBuildClient2, ListCommandExecutionsForSandboxCommand, "nextToken", "nextToken", "maxResults");
    var paginateListFleets = core.createPaginator(CodeBuildClient2, ListFleetsCommand, "nextToken", "nextToken", "maxResults");
    var paginateListProjects = core.createPaginator(CodeBuildClient2, ListProjectsCommand, "nextToken", "nextToken", "");
    var paginateListReportGroups = core.createPaginator(CodeBuildClient2, ListReportGroupsCommand, "nextToken", "nextToken", "maxResults");
    var paginateListReportsForReportGroup = core.createPaginator(CodeBuildClient2, ListReportsForReportGroupCommand, "nextToken", "nextToken", "maxResults");
    var paginateListReports = core.createPaginator(CodeBuildClient2, ListReportsCommand, "nextToken", "nextToken", "maxResults");
    var paginateListSandboxesForProject = core.createPaginator(CodeBuildClient2, ListSandboxesForProjectCommand, "nextToken", "nextToken", "maxResults");
    var paginateListSandboxes = core.createPaginator(CodeBuildClient2, ListSandboxesCommand, "nextToken", "nextToken", "maxResults");
    var paginateListSharedProjects = core.createPaginator(CodeBuildClient2, ListSharedProjectsCommand, "nextToken", "nextToken", "maxResults");
    var paginateListSharedReportGroups = core.createPaginator(CodeBuildClient2, ListSharedReportGroupsCommand, "nextToken", "nextToken", "maxResults");
    var commands32 = {
      BatchDeleteBuildsCommand,
      BatchGetBuildBatchesCommand,
      BatchGetBuildsCommand,
      BatchGetCommandExecutionsCommand,
      BatchGetFleetsCommand,
      BatchGetProjectsCommand,
      BatchGetReportGroupsCommand,
      BatchGetReportsCommand,
      BatchGetSandboxesCommand,
      CreateFleetCommand,
      CreateProjectCommand,
      CreateReportGroupCommand,
      CreateWebhookCommand,
      DeleteBuildBatchCommand,
      DeleteFleetCommand,
      DeleteProjectCommand,
      DeleteReportCommand,
      DeleteReportGroupCommand,
      DeleteResourcePolicyCommand,
      DeleteSourceCredentialsCommand,
      DeleteWebhookCommand,
      DescribeCodeCoveragesCommand,
      DescribeTestCasesCommand,
      GetReportGroupTrendCommand,
      GetResourcePolicyCommand,
      ImportSourceCredentialsCommand,
      InvalidateProjectCacheCommand,
      ListBuildBatchesCommand,
      ListBuildBatchesForProjectCommand,
      ListBuildsCommand,
      ListBuildsForProjectCommand,
      ListCommandExecutionsForSandboxCommand,
      ListCuratedEnvironmentImagesCommand,
      ListFleetsCommand,
      ListProjectsCommand,
      ListReportGroupsCommand,
      ListReportsCommand,
      ListReportsForReportGroupCommand,
      ListSandboxesCommand,
      ListSandboxesForProjectCommand,
      ListSharedProjectsCommand,
      ListSharedReportGroupsCommand,
      ListSourceCredentialsCommand,
      PutResourcePolicyCommand,
      RetryBuildCommand,
      RetryBuildBatchCommand,
      StartBuildCommand,
      StartBuildBatchCommand,
      StartCommandExecutionCommand,
      StartSandboxCommand,
      StartSandboxConnectionCommand,
      StopBuildCommand,
      StopBuildBatchCommand,
      StopSandboxCommand,
      UpdateFleetCommand,
      UpdateProjectCommand: UpdateProjectCommand2,
      UpdateProjectVisibilityCommand,
      UpdateReportGroupCommand,
      UpdateWebhookCommand
    };
    var paginators = {
      paginateDescribeCodeCoverages,
      paginateDescribeTestCases,
      paginateListBuildBatches,
      paginateListBuildBatchesForProject,
      paginateListBuilds,
      paginateListBuildsForProject,
      paginateListCommandExecutionsForSandbox,
      paginateListFleets,
      paginateListProjects,
      paginateListReportGroups,
      paginateListReports,
      paginateListReportsForReportGroup,
      paginateListSandboxes,
      paginateListSandboxesForProject,
      paginateListSharedProjects,
      paginateListSharedReportGroups
    };
    var CodeBuild = class extends CodeBuildClient2 {
      static {
        __name(this, "CodeBuild");
      }
    };
    smithyClient.createAggregatedClient(commands32, CodeBuild, { paginators });
    var ArtifactNamespace = {
      BUILD_ID: "BUILD_ID",
      NONE: "NONE"
    };
    var ArtifactPackaging = {
      NONE: "NONE",
      ZIP: "ZIP"
    };
    var ArtifactsType = {
      CODEPIPELINE: "CODEPIPELINE",
      NO_ARTIFACTS: "NO_ARTIFACTS",
      S3: "S3"
    };
    var AuthType = {
      BASIC_AUTH: "BASIC_AUTH",
      CODECONNECTIONS: "CODECONNECTIONS",
      OAUTH: "OAUTH",
      PERSONAL_ACCESS_TOKEN: "PERSONAL_ACCESS_TOKEN",
      SECRETS_MANAGER: "SECRETS_MANAGER"
    };
    var BucketOwnerAccess = {
      FULL: "FULL",
      NONE: "NONE",
      READ_ONLY: "READ_ONLY"
    };
    var BatchReportModeType = {
      REPORT_AGGREGATED_BATCH: "REPORT_AGGREGATED_BATCH",
      REPORT_INDIVIDUAL_BUILDS: "REPORT_INDIVIDUAL_BUILDS"
    };
    var StatusType = {
      FAILED: "FAILED",
      FAULT: "FAULT",
      IN_PROGRESS: "IN_PROGRESS",
      STOPPED: "STOPPED",
      SUCCEEDED: "SUCCEEDED",
      TIMED_OUT: "TIMED_OUT"
    };
    var CacheMode = {
      LOCAL_CUSTOM_CACHE: "LOCAL_CUSTOM_CACHE",
      LOCAL_DOCKER_LAYER_CACHE: "LOCAL_DOCKER_LAYER_CACHE",
      LOCAL_SOURCE_CACHE: "LOCAL_SOURCE_CACHE"
    };
    var CacheType = {
      LOCAL: "LOCAL",
      NO_CACHE: "NO_CACHE",
      S3: "S3"
    };
    var MachineType = {
      GENERAL: "GENERAL",
      NVME: "NVME"
    };
    var ComputeType = {
      ATTRIBUTE_BASED_COMPUTE: "ATTRIBUTE_BASED_COMPUTE",
      BUILD_GENERAL1_2XLARGE: "BUILD_GENERAL1_2XLARGE",
      BUILD_GENERAL1_LARGE: "BUILD_GENERAL1_LARGE",
      BUILD_GENERAL1_MEDIUM: "BUILD_GENERAL1_MEDIUM",
      BUILD_GENERAL1_SMALL: "BUILD_GENERAL1_SMALL",
      BUILD_GENERAL1_XLARGE: "BUILD_GENERAL1_XLARGE",
      BUILD_LAMBDA_10GB: "BUILD_LAMBDA_10GB",
      BUILD_LAMBDA_1GB: "BUILD_LAMBDA_1GB",
      BUILD_LAMBDA_2GB: "BUILD_LAMBDA_2GB",
      BUILD_LAMBDA_4GB: "BUILD_LAMBDA_4GB",
      BUILD_LAMBDA_8GB: "BUILD_LAMBDA_8GB",
      CUSTOM_INSTANCE_TYPE: "CUSTOM_INSTANCE_TYPE"
    };
    var EnvironmentVariableType = {
      PARAMETER_STORE: "PARAMETER_STORE",
      PLAINTEXT: "PLAINTEXT",
      SECRETS_MANAGER: "SECRETS_MANAGER"
    };
    var ImagePullCredentialsType = {
      CODEBUILD: "CODEBUILD",
      SERVICE_ROLE: "SERVICE_ROLE"
    };
    var CredentialProviderType = {
      SECRETS_MANAGER: "SECRETS_MANAGER"
    };
    var EnvironmentType = {
      ARM_CONTAINER: "ARM_CONTAINER",
      ARM_EC2: "ARM_EC2",
      ARM_LAMBDA_CONTAINER: "ARM_LAMBDA_CONTAINER",
      LINUX_CONTAINER: "LINUX_CONTAINER",
      LINUX_EC2: "LINUX_EC2",
      LINUX_GPU_CONTAINER: "LINUX_GPU_CONTAINER",
      LINUX_LAMBDA_CONTAINER: "LINUX_LAMBDA_CONTAINER",
      MAC_ARM: "MAC_ARM",
      WINDOWS_CONTAINER: "WINDOWS_CONTAINER",
      WINDOWS_EC2: "WINDOWS_EC2",
      WINDOWS_SERVER_2019_CONTAINER: "WINDOWS_SERVER_2019_CONTAINER",
      WINDOWS_SERVER_2022_CONTAINER: "WINDOWS_SERVER_2022_CONTAINER"
    };
    var FileSystemType = {
      EFS: "EFS"
    };
    var LogsConfigStatusType = {
      DISABLED: "DISABLED",
      ENABLED: "ENABLED"
    };
    var BuildBatchPhaseType = {
      COMBINE_ARTIFACTS: "COMBINE_ARTIFACTS",
      DOWNLOAD_BATCHSPEC: "DOWNLOAD_BATCHSPEC",
      FAILED: "FAILED",
      IN_PROGRESS: "IN_PROGRESS",
      STOPPED: "STOPPED",
      SUBMITTED: "SUBMITTED",
      SUCCEEDED: "SUCCEEDED"
    };
    var SourceAuthType = {
      CODECONNECTIONS: "CODECONNECTIONS",
      OAUTH: "OAUTH",
      SECRETS_MANAGER: "SECRETS_MANAGER"
    };
    var SourceType = {
      BITBUCKET: "BITBUCKET",
      CODECOMMIT: "CODECOMMIT",
      CODEPIPELINE: "CODEPIPELINE",
      GITHUB: "GITHUB",
      GITHUB_ENTERPRISE: "GITHUB_ENTERPRISE",
      GITLAB: "GITLAB",
      GITLAB_SELF_MANAGED: "GITLAB_SELF_MANAGED",
      NO_SOURCE: "NO_SOURCE",
      S3: "S3"
    };
    var BuildPhaseType = {
      BUILD: "BUILD",
      COMPLETED: "COMPLETED",
      DOWNLOAD_SOURCE: "DOWNLOAD_SOURCE",
      FINALIZING: "FINALIZING",
      INSTALL: "INSTALL",
      POST_BUILD: "POST_BUILD",
      PRE_BUILD: "PRE_BUILD",
      PROVISIONING: "PROVISIONING",
      QUEUED: "QUEUED",
      SUBMITTED: "SUBMITTED",
      UPLOAD_ARTIFACTS: "UPLOAD_ARTIFACTS"
    };
    var CommandType = {
      SHELL: "SHELL"
    };
    var FleetOverflowBehavior = {
      ON_DEMAND: "ON_DEMAND",
      QUEUE: "QUEUE"
    };
    var FleetProxyRuleBehavior = {
      ALLOW_ALL: "ALLOW_ALL",
      DENY_ALL: "DENY_ALL"
    };
    var FleetProxyRuleEffectType = {
      ALLOW: "ALLOW",
      DENY: "DENY"
    };
    var FleetProxyRuleType = {
      DOMAIN: "DOMAIN",
      IP: "IP"
    };
    var FleetScalingType = {
      TARGET_TRACKING_SCALING: "TARGET_TRACKING_SCALING"
    };
    var FleetScalingMetricType = {
      FLEET_UTILIZATION_RATE: "FLEET_UTILIZATION_RATE"
    };
    var FleetContextCode = {
      ACTION_REQUIRED: "ACTION_REQUIRED",
      CREATE_FAILED: "CREATE_FAILED",
      INSUFFICIENT_CAPACITY: "INSUFFICIENT_CAPACITY",
      PENDING_DELETION: "PENDING_DELETION",
      UPDATE_FAILED: "UPDATE_FAILED"
    };
    var FleetStatusCode = {
      ACTIVE: "ACTIVE",
      CREATE_FAILED: "CREATE_FAILED",
      CREATING: "CREATING",
      DELETING: "DELETING",
      PENDING_DELETION: "PENDING_DELETION",
      ROTATING: "ROTATING",
      UPDATE_ROLLBACK_FAILED: "UPDATE_ROLLBACK_FAILED",
      UPDATING: "UPDATING"
    };
    var ProjectVisibilityType = {
      PRIVATE: "PRIVATE",
      PUBLIC_READ: "PUBLIC_READ"
    };
    var WebhookBuildType = {
      BUILD: "BUILD",
      BUILD_BATCH: "BUILD_BATCH",
      RUNNER_BUILDKITE_BUILD: "RUNNER_BUILDKITE_BUILD"
    };
    var WebhookFilterType = {
      ACTOR_ACCOUNT_ID: "ACTOR_ACCOUNT_ID",
      BASE_REF: "BASE_REF",
      COMMIT_MESSAGE: "COMMIT_MESSAGE",
      EVENT: "EVENT",
      FILE_PATH: "FILE_PATH",
      HEAD_REF: "HEAD_REF",
      ORGANIZATION_NAME: "ORGANIZATION_NAME",
      RELEASE_NAME: "RELEASE_NAME",
      REPOSITORY_NAME: "REPOSITORY_NAME",
      TAG_NAME: "TAG_NAME",
      WORKFLOW_NAME: "WORKFLOW_NAME"
    };
    var PullRequestBuildApproverRole = {
      BITBUCKET_ADMIN: "BITBUCKET_ADMIN",
      BITBUCKET_READ: "BITBUCKET_READ",
      BITBUCKET_WRITE: "BITBUCKET_WRITE",
      GITHUB_ADMIN: "GITHUB_ADMIN",
      GITHUB_MAINTAIN: "GITHUB_MAINTAIN",
      GITHUB_READ: "GITHUB_READ",
      GITHUB_TRIAGE: "GITHUB_TRIAGE",
      GITHUB_WRITE: "GITHUB_WRITE",
      GITLAB_DEVELOPER: "GITLAB_DEVELOPER",
      GITLAB_GUEST: "GITLAB_GUEST",
      GITLAB_MAINTAINER: "GITLAB_MAINTAINER",
      GITLAB_OWNER: "GITLAB_OWNER",
      GITLAB_PLANNER: "GITLAB_PLANNER",
      GITLAB_REPORTER: "GITLAB_REPORTER"
    };
    var PullRequestBuildCommentApproval = {
      ALL_PULL_REQUESTS: "ALL_PULL_REQUESTS",
      DISABLED: "DISABLED",
      FORK_PULL_REQUESTS: "FORK_PULL_REQUESTS"
    };
    var WebhookScopeType = {
      GITHUB_GLOBAL: "GITHUB_GLOBAL",
      GITHUB_ORGANIZATION: "GITHUB_ORGANIZATION",
      GITLAB_GROUP: "GITLAB_GROUP"
    };
    var WebhookStatus = {
      ACTIVE: "ACTIVE",
      CREATE_FAILED: "CREATE_FAILED",
      CREATING: "CREATING",
      DELETING: "DELETING"
    };
    var ReportExportConfigType = {
      NO_EXPORT: "NO_EXPORT",
      S3: "S3"
    };
    var ReportPackagingType = {
      NONE: "NONE",
      ZIP: "ZIP"
    };
    var ReportGroupStatusType = {
      ACTIVE: "ACTIVE",
      DELETING: "DELETING"
    };
    var ReportType = {
      CODE_COVERAGE: "CODE_COVERAGE",
      TEST: "TEST"
    };
    var ReportStatusType = {
      DELETING: "DELETING",
      FAILED: "FAILED",
      GENERATING: "GENERATING",
      INCOMPLETE: "INCOMPLETE",
      SUCCEEDED: "SUCCEEDED"
    };
    var ReportCodeCoverageSortByType = {
      FILE_PATH: "FILE_PATH",
      LINE_COVERAGE_PERCENTAGE: "LINE_COVERAGE_PERCENTAGE"
    };
    var SortOrderType = {
      ASCENDING: "ASCENDING",
      DESCENDING: "DESCENDING"
    };
    var ReportGroupTrendFieldType = {
      BRANCHES_COVERED: "BRANCHES_COVERED",
      BRANCHES_MISSED: "BRANCHES_MISSED",
      BRANCH_COVERAGE: "BRANCH_COVERAGE",
      DURATION: "DURATION",
      LINES_COVERED: "LINES_COVERED",
      LINES_MISSED: "LINES_MISSED",
      LINE_COVERAGE: "LINE_COVERAGE",
      PASS_RATE: "PASS_RATE",
      TOTAL: "TOTAL"
    };
    var ServerType = {
      BITBUCKET: "BITBUCKET",
      GITHUB: "GITHUB",
      GITHUB_ENTERPRISE: "GITHUB_ENTERPRISE",
      GITLAB: "GITLAB",
      GITLAB_SELF_MANAGED: "GITLAB_SELF_MANAGED"
    };
    var LanguageType = {
      ANDROID: "ANDROID",
      BASE: "BASE",
      DOCKER: "DOCKER",
      DOTNET: "DOTNET",
      GOLANG: "GOLANG",
      JAVA: "JAVA",
      NODE_JS: "NODE_JS",
      PHP: "PHP",
      PYTHON: "PYTHON",
      RUBY: "RUBY"
    };
    var PlatformType = {
      AMAZON_LINUX: "AMAZON_LINUX",
      DEBIAN: "DEBIAN",
      UBUNTU: "UBUNTU",
      WINDOWS_SERVER: "WINDOWS_SERVER"
    };
    var FleetSortByType = {
      CREATED_TIME: "CREATED_TIME",
      LAST_MODIFIED_TIME: "LAST_MODIFIED_TIME",
      NAME: "NAME"
    };
    var ProjectSortByType = {
      CREATED_TIME: "CREATED_TIME",
      LAST_MODIFIED_TIME: "LAST_MODIFIED_TIME",
      NAME: "NAME"
    };
    var ReportGroupSortByType = {
      CREATED_TIME: "CREATED_TIME",
      LAST_MODIFIED_TIME: "LAST_MODIFIED_TIME",
      NAME: "NAME"
    };
    var SharedResourceSortByType = {
      ARN: "ARN",
      MODIFIED_TIME: "MODIFIED_TIME"
    };
    var RetryBuildBatchType = {
      RETRY_ALL_BUILDS: "RETRY_ALL_BUILDS",
      RETRY_FAILED_BUILDS: "RETRY_FAILED_BUILDS"
    };
    exports2.$Command = smithyClient.Command;
    exports2.__Client = smithyClient.Client;
    exports2.CodeBuildServiceException = CodeBuildServiceException.CodeBuildServiceException;
    exports2.ArtifactNamespace = ArtifactNamespace;
    exports2.ArtifactPackaging = ArtifactPackaging;
    exports2.ArtifactsType = ArtifactsType;
    exports2.AuthType = AuthType;
    exports2.BatchDeleteBuildsCommand = BatchDeleteBuildsCommand;
    exports2.BatchGetBuildBatchesCommand = BatchGetBuildBatchesCommand;
    exports2.BatchGetBuildsCommand = BatchGetBuildsCommand;
    exports2.BatchGetCommandExecutionsCommand = BatchGetCommandExecutionsCommand;
    exports2.BatchGetFleetsCommand = BatchGetFleetsCommand;
    exports2.BatchGetProjectsCommand = BatchGetProjectsCommand;
    exports2.BatchGetReportGroupsCommand = BatchGetReportGroupsCommand;
    exports2.BatchGetReportsCommand = BatchGetReportsCommand;
    exports2.BatchGetSandboxesCommand = BatchGetSandboxesCommand;
    exports2.BatchReportModeType = BatchReportModeType;
    exports2.BucketOwnerAccess = BucketOwnerAccess;
    exports2.BuildBatchPhaseType = BuildBatchPhaseType;
    exports2.BuildPhaseType = BuildPhaseType;
    exports2.CacheMode = CacheMode;
    exports2.CacheType = CacheType;
    exports2.CodeBuild = CodeBuild;
    exports2.CodeBuildClient = CodeBuildClient2;
    exports2.CommandType = CommandType;
    exports2.ComputeType = ComputeType;
    exports2.CreateFleetCommand = CreateFleetCommand;
    exports2.CreateProjectCommand = CreateProjectCommand;
    exports2.CreateReportGroupCommand = CreateReportGroupCommand;
    exports2.CreateWebhookCommand = CreateWebhookCommand;
    exports2.CredentialProviderType = CredentialProviderType;
    exports2.DeleteBuildBatchCommand = DeleteBuildBatchCommand;
    exports2.DeleteFleetCommand = DeleteFleetCommand;
    exports2.DeleteProjectCommand = DeleteProjectCommand;
    exports2.DeleteReportCommand = DeleteReportCommand;
    exports2.DeleteReportGroupCommand = DeleteReportGroupCommand;
    exports2.DeleteResourcePolicyCommand = DeleteResourcePolicyCommand;
    exports2.DeleteSourceCredentialsCommand = DeleteSourceCredentialsCommand;
    exports2.DeleteWebhookCommand = DeleteWebhookCommand;
    exports2.DescribeCodeCoveragesCommand = DescribeCodeCoveragesCommand;
    exports2.DescribeTestCasesCommand = DescribeTestCasesCommand;
    exports2.EnvironmentType = EnvironmentType;
    exports2.EnvironmentVariableType = EnvironmentVariableType;
    exports2.FileSystemType = FileSystemType;
    exports2.FleetContextCode = FleetContextCode;
    exports2.FleetOverflowBehavior = FleetOverflowBehavior;
    exports2.FleetProxyRuleBehavior = FleetProxyRuleBehavior;
    exports2.FleetProxyRuleEffectType = FleetProxyRuleEffectType;
    exports2.FleetProxyRuleType = FleetProxyRuleType;
    exports2.FleetScalingMetricType = FleetScalingMetricType;
    exports2.FleetScalingType = FleetScalingType;
    exports2.FleetSortByType = FleetSortByType;
    exports2.FleetStatusCode = FleetStatusCode;
    exports2.GetReportGroupTrendCommand = GetReportGroupTrendCommand;
    exports2.GetResourcePolicyCommand = GetResourcePolicyCommand;
    exports2.ImagePullCredentialsType = ImagePullCredentialsType;
    exports2.ImportSourceCredentialsCommand = ImportSourceCredentialsCommand;
    exports2.InvalidateProjectCacheCommand = InvalidateProjectCacheCommand;
    exports2.LanguageType = LanguageType;
    exports2.ListBuildBatchesCommand = ListBuildBatchesCommand;
    exports2.ListBuildBatchesForProjectCommand = ListBuildBatchesForProjectCommand;
    exports2.ListBuildsCommand = ListBuildsCommand;
    exports2.ListBuildsForProjectCommand = ListBuildsForProjectCommand;
    exports2.ListCommandExecutionsForSandboxCommand = ListCommandExecutionsForSandboxCommand;
    exports2.ListCuratedEnvironmentImagesCommand = ListCuratedEnvironmentImagesCommand;
    exports2.ListFleetsCommand = ListFleetsCommand;
    exports2.ListProjectsCommand = ListProjectsCommand;
    exports2.ListReportGroupsCommand = ListReportGroupsCommand;
    exports2.ListReportsCommand = ListReportsCommand;
    exports2.ListReportsForReportGroupCommand = ListReportsForReportGroupCommand;
    exports2.ListSandboxesCommand = ListSandboxesCommand;
    exports2.ListSandboxesForProjectCommand = ListSandboxesForProjectCommand;
    exports2.ListSharedProjectsCommand = ListSharedProjectsCommand;
    exports2.ListSharedReportGroupsCommand = ListSharedReportGroupsCommand;
    exports2.ListSourceCredentialsCommand = ListSourceCredentialsCommand;
    exports2.LogsConfigStatusType = LogsConfigStatusType;
    exports2.MachineType = MachineType;
    exports2.PlatformType = PlatformType;
    exports2.ProjectSortByType = ProjectSortByType;
    exports2.ProjectVisibilityType = ProjectVisibilityType;
    exports2.PullRequestBuildApproverRole = PullRequestBuildApproverRole;
    exports2.PullRequestBuildCommentApproval = PullRequestBuildCommentApproval;
    exports2.PutResourcePolicyCommand = PutResourcePolicyCommand;
    exports2.ReportCodeCoverageSortByType = ReportCodeCoverageSortByType;
    exports2.ReportExportConfigType = ReportExportConfigType;
    exports2.ReportGroupSortByType = ReportGroupSortByType;
    exports2.ReportGroupStatusType = ReportGroupStatusType;
    exports2.ReportGroupTrendFieldType = ReportGroupTrendFieldType;
    exports2.ReportPackagingType = ReportPackagingType;
    exports2.ReportStatusType = ReportStatusType;
    exports2.ReportType = ReportType;
    exports2.RetryBuildBatchCommand = RetryBuildBatchCommand;
    exports2.RetryBuildBatchType = RetryBuildBatchType;
    exports2.RetryBuildCommand = RetryBuildCommand;
    exports2.ServerType = ServerType;
    exports2.SharedResourceSortByType = SharedResourceSortByType;
    exports2.SortOrderType = SortOrderType;
    exports2.SourceAuthType = SourceAuthType;
    exports2.SourceType = SourceType;
    exports2.StartBuildBatchCommand = StartBuildBatchCommand;
    exports2.StartBuildCommand = StartBuildCommand;
    exports2.StartCommandExecutionCommand = StartCommandExecutionCommand;
    exports2.StartSandboxCommand = StartSandboxCommand;
    exports2.StartSandboxConnectionCommand = StartSandboxConnectionCommand;
    exports2.StatusType = StatusType;
    exports2.StopBuildBatchCommand = StopBuildBatchCommand;
    exports2.StopBuildCommand = StopBuildCommand;
    exports2.StopSandboxCommand = StopSandboxCommand;
    exports2.UpdateFleetCommand = UpdateFleetCommand;
    exports2.UpdateProjectCommand = UpdateProjectCommand2;
    exports2.UpdateProjectVisibilityCommand = UpdateProjectVisibilityCommand;
    exports2.UpdateReportGroupCommand = UpdateReportGroupCommand;
    exports2.UpdateWebhookCommand = UpdateWebhookCommand;
    exports2.WebhookBuildType = WebhookBuildType;
    exports2.WebhookFilterType = WebhookFilterType;
    exports2.WebhookScopeType = WebhookScopeType;
    exports2.WebhookStatus = WebhookStatus;
    exports2.paginateDescribeCodeCoverages = paginateDescribeCodeCoverages;
    exports2.paginateDescribeTestCases = paginateDescribeTestCases;
    exports2.paginateListBuildBatches = paginateListBuildBatches;
    exports2.paginateListBuildBatchesForProject = paginateListBuildBatchesForProject;
    exports2.paginateListBuilds = paginateListBuilds;
    exports2.paginateListBuildsForProject = paginateListBuildsForProject;
    exports2.paginateListCommandExecutionsForSandbox = paginateListCommandExecutionsForSandbox;
    exports2.paginateListFleets = paginateListFleets;
    exports2.paginateListProjects = paginateListProjects;
    exports2.paginateListReportGroups = paginateListReportGroups;
    exports2.paginateListReports = paginateListReports;
    exports2.paginateListReportsForReportGroup = paginateListReportsForReportGroup;
    exports2.paginateListSandboxes = paginateListSandboxes;
    exports2.paginateListSandboxesForProject = paginateListSandboxesForProject;
    exports2.paginateListSharedProjects = paginateListSharedProjects;
    exports2.paginateListSharedReportGroups = paginateListSharedReportGroups;
    Object.prototype.hasOwnProperty.call(schemas_0, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: schemas_0["__proto__"]
    });
    Object.keys(schemas_0).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = schemas_0[k32];
    });
    Object.prototype.hasOwnProperty.call(errors, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: errors["__proto__"]
    });
    Object.keys(errors).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = errors[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-ec2/dist-cjs/auth/httpAuthSchemeProvider.js
var require_httpAuthSchemeProvider11 = __commonJS({
  "../../node_modules/@aws-sdk/client-ec2/dist-cjs/auth/httpAuthSchemeProvider.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.resolveHttpAuthSchemeConfig = exports2.defaultEC2HttpAuthSchemeProvider = exports2.defaultEC2HttpAuthSchemeParametersProvider = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var util_middleware_1 = require_dist_cjs6();
    var defaultEC2HttpAuthSchemeParametersProvider = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, util_middleware_1.getSmithyContext)(context).operation,
        region: await (0, util_middleware_1.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultEC2HttpAuthSchemeParametersProvider");
    exports2.defaultEC2HttpAuthSchemeParametersProvider = defaultEC2HttpAuthSchemeParametersProvider;
    function createAwsAuthSigv4HttpAuthOption32(authParameters) {
      return {
        schemeId: "aws.auth#sigv4",
        signingProperties: {
          name: "ec2",
          region: authParameters.region
        },
        propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
          signingProperties: {
            config: config2,
            context
          }
        }), "propertiesExtractor")
      };
    }
    __name(createAwsAuthSigv4HttpAuthOption32, "createAwsAuthSigv4HttpAuthOption");
    var defaultEC2HttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption32(authParameters));
        }
      }
      return options;
    }, "defaultEC2HttpAuthSchemeProvider");
    exports2.defaultEC2HttpAuthSchemeProvider = defaultEC2HttpAuthSchemeProvider;
    var resolveHttpAuthSchemeConfig32 = /* @__PURE__ */ __name((config2) => {
      const config_0 = (0, httpAuthSchemes_1.resolveAwsSdkSigV4Config)(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, util_middleware_1.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
    exports2.resolveHttpAuthSchemeConfig = resolveHttpAuthSchemeConfig32;
  }
});

// ../../node_modules/@aws-sdk/client-ec2/package.json
var require_package11 = __commonJS({
  "../../node_modules/@aws-sdk/client-ec2/package.json"(exports2, module2) {
    module2.exports = {
      name: "@aws-sdk/client-ec2",
      description: "AWS SDK for JavaScript Ec2 Client for Node.js, Browser and React Native",
      version: "3.1036.0",
      scripts: {
        build: "concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline client-ec2",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        "extract:docs": "api-extractor run --local",
        "generate:client": "node ../../scripts/generate-clients/single-service --solo ec2",
        test: "yarn g:vitest run --passWithNoTests",
        "test:index": "tsc --noEmit ./test/index-types.ts && node ./test/index-objects.spec.mjs",
        "test:integration": "yarn g:vitest run --passWithNoTests -c vitest.config.integ.mts",
        "test:integration:watch": "yarn g:vitest run --passWithNoTests -c vitest.config.integ.mts",
        "test:watch": "yarn g:vitest watch --passWithNoTests"
      },
      main: "./dist-cjs/index.js",
      types: "./dist-types/index.d.ts",
      module: "./dist-es/index.js",
      sideEffects: false,
      dependencies: {
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.5",
        "@aws-sdk/credential-provider-node": "^3.972.36",
        "@aws-sdk/middleware-host-header": "^3.972.10",
        "@aws-sdk/middleware-logger": "^3.972.10",
        "@aws-sdk/middleware-recursion-detection": "^3.972.11",
        "@aws-sdk/middleware-sdk-ec2": "^3.972.22",
        "@aws-sdk/middleware-user-agent": "^3.972.35",
        "@aws-sdk/region-config-resolver": "^3.972.13",
        "@aws-sdk/types": "^3.973.8",
        "@aws-sdk/util-endpoints": "^3.996.8",
        "@aws-sdk/util-user-agent-browser": "^3.972.10",
        "@aws-sdk/util-user-agent-node": "^3.973.21",
        "@smithy/config-resolver": "^4.4.17",
        "@smithy/core": "^3.23.17",
        "@smithy/fetch-http-handler": "^5.3.17",
        "@smithy/hash-node": "^4.2.14",
        "@smithy/invalid-dependency": "^4.2.14",
        "@smithy/middleware-content-length": "^4.2.14",
        "@smithy/middleware-endpoint": "^4.4.32",
        "@smithy/middleware-retry": "^4.5.5",
        "@smithy/middleware-serde": "^4.2.20",
        "@smithy/middleware-stack": "^4.2.14",
        "@smithy/node-config-provider": "^4.3.14",
        "@smithy/node-http-handler": "^4.6.1",
        "@smithy/protocol-http": "^5.3.14",
        "@smithy/smithy-client": "^4.12.13",
        "@smithy/types": "^4.14.1",
        "@smithy/url-parser": "^4.2.14",
        "@smithy/util-base64": "^4.3.2",
        "@smithy/util-body-length-browser": "^4.2.2",
        "@smithy/util-body-length-node": "^4.2.3",
        "@smithy/util-defaults-mode-browser": "^4.3.49",
        "@smithy/util-defaults-mode-node": "^4.2.54",
        "@smithy/util-endpoints": "^3.4.2",
        "@smithy/util-middleware": "^4.2.14",
        "@smithy/util-retry": "^4.3.4",
        "@smithy/util-utf8": "^4.2.2",
        "@smithy/util-waiter": "^4.2.16",
        tslib: "^2.6.2"
      },
      devDependencies: {
        "@smithy/snapshot-testing": "^2.0.8",
        "@tsconfig/node20": "20.1.8",
        "@types/node": "^20.14.8",
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3",
        vitest: "^4.0.17"
      },
      engines: {
        node: ">=20.0.0"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "dist-*/**"
      ],
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      browser: {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.browser"
      },
      "react-native": {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.native"
      },
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/clients/client-ec2",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "clients/client-ec2"
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ec2/dist-cjs/endpoint/bdd.js
var require_bdd11 = __commonJS({
  "../../node_modules/@aws-sdk/client-ec2/dist-cjs/endpoint/bdd.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.bdd = void 0;
    var util_endpoints_1 = require_dist_cjs20();
    var k32 = "ref";
    var a32 = -1;
    var b32 = true;
    var c32 = "isSet";
    var d32 = "PartitionResult";
    var e32 = "booleanEquals";
    var f32 = "getAttr";
    var g32 = { [k32]: "Endpoint" };
    var h32 = { [k32]: d32 };
    var i32 = {};
    var j32 = [{ [k32]: "Region" }];
    var _data32 = {
      conditions: [
        [c32, [g32]],
        [c32, j32],
        ["aws.partition", j32, d32],
        [e32, [{ [k32]: "UseFIPS" }, b32]],
        [e32, [{ [k32]: "UseDualStack" }, b32]],
        [e32, [{ fn: f32, argv: [h32, "supportsDualStack"] }, b32]],
        [e32, [{ fn: f32, argv: [h32, "supportsFIPS"] }, b32]],
        ["stringEquals", [{ fn: f32, argv: [h32, "name"] }, "aws-us-gov"]]
      ],
      results: [
        [a32],
        [a32, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a32, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [g32, i32],
        ["https://ec2-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", i32],
        [a32, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://ec2.{Region}.amazonaws.com", i32],
        ["https://ec2-fips.{Region}.{PartitionResult#dnsSuffix}", i32],
        [a32, "FIPS is enabled but this partition does not support FIPS"],
        ["https://ec2.{Region}.{PartitionResult#dualStackDnsSuffix}", i32],
        [a32, "DualStack is enabled but this partition does not support DualStack"],
        ["https://ec2.{Region}.{PartitionResult#dnsSuffix}", i32],
        [a32, "Invalid Configuration: Missing Region"]
      ]
    };
    var root32 = 2;
    var r32 = 1e8;
    var nodes32 = new Int32Array([
      -1,
      1,
      -1,
      0,
      13,
      3,
      1,
      4,
      r32 + 12,
      2,
      5,
      r32 + 12,
      3,
      8,
      6,
      4,
      7,
      r32 + 11,
      5,
      r32 + 9,
      r32 + 10,
      4,
      11,
      9,
      6,
      10,
      r32 + 8,
      7,
      r32 + 6,
      r32 + 7,
      5,
      12,
      r32 + 5,
      6,
      r32 + 4,
      r32 + 5,
      3,
      r32 + 1,
      14,
      4,
      r32 + 2,
      r32 + 3
    ]);
    exports2.bdd = util_endpoints_1.BinaryDecisionDiagram.from(nodes32, root32, _data32.conditions, _data32.results);
  }
});

// ../../node_modules/@aws-sdk/client-ec2/dist-cjs/endpoint/endpointResolver.js
var require_endpointResolver11 = __commonJS({
  "../../node_modules/@aws-sdk/client-ec2/dist-cjs/endpoint/endpointResolver.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.defaultEndpointResolver = void 0;
    var util_endpoints_1 = require_dist_cjs21();
    var util_endpoints_2 = require_dist_cjs20();
    var bdd_1 = require_bdd11();
    var cache32 = new util_endpoints_2.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    var defaultEndpointResolver32 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache32.get(endpointParams, () => (0, util_endpoints_2.decideEndpoint)(bdd_1.bdd, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    exports2.defaultEndpointResolver = defaultEndpointResolver32;
    util_endpoints_2.customEndpointFunctions.aws = util_endpoints_1.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-ec2/dist-cjs/models/EC2ServiceException.js
var require_EC2ServiceException = __commonJS({
  "../../node_modules/@aws-sdk/client-ec2/dist-cjs/models/EC2ServiceException.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.EC2ServiceException = exports2.__ServiceException = void 0;
    var smithy_client_1 = require_dist_cjs34();
    Object.defineProperty(exports2, "__ServiceException", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return smithy_client_1.ServiceException;
    }, "get") });
    var EC2ServiceException = class _EC2ServiceException extends smithy_client_1.ServiceException {
      static {
        __name(this, "EC2ServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _EC2ServiceException.prototype);
      }
    };
    exports2.EC2ServiceException = EC2ServiceException;
  }
});

// ../../node_modules/@aws-sdk/client-ec2/dist-cjs/schemas/schemas_0.js
var require_schemas_011 = __commonJS({
  "../../node_modules/@aws-sdk/client-ec2/dist-cjs/schemas/schemas_0.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.AnalysisAclRule$ = exports2.AlternatePathHint$ = exports2.AllowedPrincipal$ = exports2.AllocateIpamPoolCidrResult$ = exports2.AllocateIpamPoolCidrRequest$ = exports2.AllocateHostsResult$ = exports2.AllocateHostsRequest$ = exports2.AllocateAddressResult$ = exports2.AllocateAddressRequest$ = exports2.AdvertiseByoipCidrResult$ = exports2.AdvertiseByoipCidrRequest$ = exports2.AddressTransfer$ = exports2.AddressAttribute$ = exports2.Address$ = exports2.AddPrefixListEntry$ = exports2.AdditionalDetail$ = exports2.AddIpamOrganizationalUnitExclusion$ = exports2.AddIpamOperatingRegion$ = exports2.AddedPrincipal$ = exports2.ActiveVpnTunnelStatus$ = exports2.ActiveInstance$ = exports2.AccountAttributeValue$ = exports2.AccountAttribute$ = exports2.AccessScopePathRequest$ = exports2.AccessScopePath$ = exports2.AccessScopeAnalysisFinding$ = exports2.AcceptVpcPeeringConnectionResult$ = exports2.AcceptVpcPeeringConnectionRequest$ = exports2.AcceptVpcEndpointConnectionsResult$ = exports2.AcceptVpcEndpointConnectionsRequest$ = exports2.AcceptTransitGatewayVpcAttachmentResult$ = exports2.AcceptTransitGatewayVpcAttachmentRequest$ = exports2.AcceptTransitGatewayPeeringAttachmentResult$ = exports2.AcceptTransitGatewayPeeringAttachmentRequest$ = exports2.AcceptTransitGatewayMulticastDomainAssociationsResult$ = exports2.AcceptTransitGatewayMulticastDomainAssociationsRequest$ = exports2.AcceptTransitGatewayClientVpnAttachmentResult$ = exports2.AcceptTransitGatewayClientVpnAttachmentRequest$ = exports2.AcceptReservedInstancesExchangeQuoteResult$ = exports2.AcceptReservedInstancesExchangeQuoteRequest$ = exports2.AcceptCapacityReservationBillingOwnershipResult$ = exports2.AcceptCapacityReservationBillingOwnershipRequest$ = exports2.AcceptAddressTransferResult$ = exports2.AcceptAddressTransferRequest$ = exports2.AcceleratorTotalMemoryMiBRequest$ = exports2.AcceleratorTotalMemoryMiB$ = exports2.AcceleratorCountRequest$ = exports2.AcceleratorCount$ = exports2.errorTypeRegistries = exports2.EC2ServiceException$ = void 0;
    exports2.AssociateTransitGatewayPolicyTableResult$ = exports2.AssociateTransitGatewayPolicyTableRequest$ = exports2.AssociateTransitGatewayMulticastDomainResult$ = exports2.AssociateTransitGatewayMulticastDomainRequest$ = exports2.AssociateSubnetCidrBlockResult$ = exports2.AssociateSubnetCidrBlockRequest$ = exports2.AssociateSecurityGroupVpcResult$ = exports2.AssociateSecurityGroupVpcRequest$ = exports2.AssociateRouteTableResult$ = exports2.AssociateRouteTableRequest$ = exports2.AssociateRouteServerResult$ = exports2.AssociateRouteServerRequest$ = exports2.AssociateNatGatewayAddressResult$ = exports2.AssociateNatGatewayAddressRequest$ = exports2.AssociateIpamResourceDiscoveryResult$ = exports2.AssociateIpamResourceDiscoveryRequest$ = exports2.AssociateIpamByoasnResult$ = exports2.AssociateIpamByoasnRequest$ = exports2.AssociateInstanceEventWindowResult$ = exports2.AssociateInstanceEventWindowRequest$ = exports2.AssociateIamInstanceProfileResult$ = exports2.AssociateIamInstanceProfileRequest$ = exports2.AssociateEnclaveCertificateIamRoleResult$ = exports2.AssociateEnclaveCertificateIamRoleRequest$ = exports2.AssociatedTargetNetwork$ = exports2.AssociatedRole$ = exports2.AssociateDhcpOptionsRequest$ = exports2.AssociateClientVpnTargetNetworkResult$ = exports2.AssociateClientVpnTargetNetworkRequest$ = exports2.AssociateCapacityReservationBillingOwnerResult$ = exports2.AssociateCapacityReservationBillingOwnerRequest$ = exports2.AssociateAddressResult$ = exports2.AssociateAddressRequest$ = exports2.AssignPrivateNatGatewayAddressResult$ = exports2.AssignPrivateNatGatewayAddressRequest$ = exports2.AssignPrivateIpAddressesResult$ = exports2.AssignPrivateIpAddressesRequest$ = exports2.AssignIpv6AddressesResult$ = exports2.AssignIpv6AddressesRequest$ = exports2.AssignedPrivateIpAddress$ = exports2.AsnAuthorizationContext$ = exports2.AsnAssociation$ = exports2.ApplySecurityGroupsToClientVpnTargetNetworkResult$ = exports2.ApplySecurityGroupsToClientVpnTargetNetworkRequest$ = exports2.AnalysisSecurityGroupRule$ = exports2.AnalysisRouteTableRoute$ = exports2.AnalysisPacketHeader$ = exports2.AnalysisLoadBalancerTarget$ = exports2.AnalysisLoadBalancerListener$ = exports2.AnalysisComponent$ = void 0;
    exports2.ByoipCidr$ = exports2.Byoasn$ = exports2.BundleTaskError$ = exports2.BundleTask$ = exports2.BundleInstanceResult$ = exports2.BundleInstanceRequest$ = exports2.BlockPublicAccessStates$ = exports2.BlockDeviceMappingResponse$ = exports2.BlockDeviceMapping$ = exports2.BlobAttributeValue$ = exports2.BaselinePerformanceFactorsRequest$ = exports2.BaselinePerformanceFactors$ = exports2.BaselineEbsBandwidthMbpsRequest$ = exports2.BaselineEbsBandwidthMbps$ = exports2.AvailableCapacity$ = exports2.AvailabilityZoneSubGeography$ = exports2.AvailabilityZoneMessage$ = exports2.AvailabilityZoneGeography$ = exports2.AvailabilityZoneAddress$ = exports2.AvailabilityZone$ = exports2.AuthorizeSecurityGroupIngressResult$ = exports2.AuthorizeSecurityGroupIngressRequest$ = exports2.AuthorizeSecurityGroupEgressResult$ = exports2.AuthorizeSecurityGroupEgressRequest$ = exports2.AuthorizeClientVpnIngressResult$ = exports2.AuthorizeClientVpnIngressRequest$ = exports2.AuthorizationRule$ = exports2.AttributeValue$ = exports2.AttributeSummary$ = exports2.AttributeBooleanValue$ = exports2.AttachVpnGatewayResult$ = exports2.AttachVpnGatewayRequest$ = exports2.AttachVolumeRequest$ = exports2.AttachVerifiedAccessTrustProviderResult$ = exports2.AttachVerifiedAccessTrustProviderRequest$ = exports2.AttachNetworkInterfaceResult$ = exports2.AttachNetworkInterfaceRequest$ = exports2.AttachmentEnaSrdUdpSpecification$ = exports2.AttachmentEnaSrdSpecification$ = exports2.AttachInternetGatewayRequest$ = exports2.AttachClassicLinkVpcResult$ = exports2.AttachClassicLinkVpcRequest$ = exports2.AthenaIntegration$ = exports2.AssociationStatus$ = exports2.AssociateVpcCidrBlockResult$ = exports2.AssociateVpcCidrBlockRequest$ = exports2.AssociateTrunkInterfaceResult$ = exports2.AssociateTrunkInterfaceRequest$ = exports2.AssociateTransitGatewayRouteTableResult$ = exports2.AssociateTransitGatewayRouteTableRequest$ = void 0;
    exports2.CapacityReservationTarget$ = exports2.CapacityReservationStatus$ = exports2.CapacityReservationSpecificationResponse$ = exports2.CapacityReservationSpecification$ = exports2.CapacityReservationOptionsRequest$ = exports2.CapacityReservationOptions$ = exports2.CapacityReservationInfo$ = exports2.CapacityReservationGroup$ = exports2.CapacityReservationFleetCancellationState$ = exports2.CapacityReservationFleet$ = exports2.CapacityReservationCommitmentInfo$ = exports2.CapacityReservationBillingRequest$ = exports2.CapacityReservation$ = exports2.CapacityManagerTagDimension$ = exports2.CapacityManagerMonitoredTagKey$ = exports2.CapacityManagerDimension$ = exports2.CapacityManagerDataExportResponse$ = exports2.CapacityManagerCondition$ = exports2.CapacityBlockStatus$ = exports2.CapacityBlockOffering$ = exports2.CapacityBlockExtensionOffering$ = exports2.CapacityBlockExtension$ = exports2.CapacityBlock$ = exports2.CapacityAllocationMetadataEntry$ = exports2.CapacityAllocation$ = exports2.CancelSpotInstanceRequestsResult$ = exports2.CancelSpotInstanceRequestsRequest$ = exports2.CancelSpotFleetRequestsSuccessItem$ = exports2.CancelSpotFleetRequestsResponse$ = exports2.CancelSpotFleetRequestsRequest$ = exports2.CancelSpotFleetRequestsErrorItem$ = exports2.CancelSpotFleetRequestsError$ = exports2.CancelReservedInstancesListingResult$ = exports2.CancelReservedInstancesListingRequest$ = exports2.CancelledSpotInstanceRequest$ = exports2.CancelImportTaskResult$ = exports2.CancelImportTaskRequest$ = exports2.CancelImageLaunchPermissionResult$ = exports2.CancelImageLaunchPermissionRequest$ = exports2.CancelExportTaskRequest$ = exports2.CancelDeclarativePoliciesReportResult$ = exports2.CancelDeclarativePoliciesReportRequest$ = exports2.CancelConversionRequest$ = exports2.CancelCapacityReservationResult$ = exports2.CancelCapacityReservationRequest$ = exports2.CancelCapacityReservationFleetsResult$ = exports2.CancelCapacityReservationFleetsRequest$ = exports2.CancelCapacityReservationFleetError$ = exports2.CancelBundleTaskResult$ = exports2.CancelBundleTaskRequest$ = void 0;
    exports2.CopySnapshotResult$ = exports2.CopySnapshotRequest$ = exports2.CopyImageResult$ = exports2.CopyImageRequest$ = exports2.CopyFpgaImageResult$ = exports2.CopyFpgaImageRequest$ = exports2.ConversionTask$ = exports2.ConnectionTrackingSpecificationResponse$ = exports2.ConnectionTrackingSpecificationRequest$ = exports2.ConnectionTrackingSpecification$ = exports2.ConnectionTrackingConfiguration$ = exports2.ConnectionNotification$ = exports2.ConnectionLogResponseOptions$ = exports2.ConnectionLogOptions$ = exports2.ConfirmProductInstanceResult$ = exports2.ConfirmProductInstanceRequest$ = exports2.CoipPool$ = exports2.CoipCidr$ = exports2.CoipAddressUsage$ = exports2.CloudWatchLogOptionsSpecification$ = exports2.CloudWatchLogOptions$ = exports2.ClientVpnRouteStatus$ = exports2.ClientVpnRoute$ = exports2.ClientVpnEndpointStatus$ = exports2.ClientVpnEndpointAttributeStatus$ = exports2.ClientVpnEndpoint$ = exports2.ClientVpnConnectionStatus$ = exports2.ClientVpnConnection$ = exports2.ClientVpnAuthorizationRuleStatus$ = exports2.ClientVpnAuthenticationRequest$ = exports2.ClientVpnAuthentication$ = exports2.ClientRouteEnforcementResponseOptions$ = exports2.ClientRouteEnforcementOptions$ = exports2.ClientLoginBannerResponseOptions$ = exports2.ClientLoginBannerOptions$ = exports2.ClientData$ = exports2.ClientConnectResponseOptions$ = exports2.ClientConnectOptions$ = exports2.ClientCertificateRevocationListStatus$ = exports2.ClassicLoadBalancersConfig$ = exports2.ClassicLoadBalancer$ = exports2.ClassicLinkInstance$ = exports2.ClassicLinkDnsSupport$ = exports2.CidrBlock$ = exports2.CidrAuthorizationContext$ = exports2.CertificateAuthenticationRequest$ = exports2.CertificateAuthentication$ = exports2.CarrierGateway$ = exports2.CapacityReservationTopology$ = exports2.CapacityReservationTargetResponse$ = void 0;
    exports2.CreateInstanceConnectEndpointResult$ = exports2.CreateInstanceConnectEndpointRequest$ = exports2.CreateImageUsageReportResult$ = exports2.CreateImageUsageReportRequest$ = exports2.CreateImageResult$ = exports2.CreateImageRequest$ = exports2.CreateFpgaImageResult$ = exports2.CreateFpgaImageRequest$ = exports2.CreateFlowLogsResult$ = exports2.CreateFlowLogsRequest$ = exports2.CreateFleetResult$ = exports2.CreateFleetRequest$ = exports2.CreateFleetInstance$ = exports2.CreateFleetError$ = exports2.CreateEgressOnlyInternetGatewayResult$ = exports2.CreateEgressOnlyInternetGatewayRequest$ = exports2.CreateDhcpOptionsResult$ = exports2.CreateDhcpOptionsRequest$ = exports2.CreateDelegateMacVolumeOwnershipTaskResult$ = exports2.CreateDelegateMacVolumeOwnershipTaskRequest$ = exports2.CreateDefaultVpcResult$ = exports2.CreateDefaultVpcRequest$ = exports2.CreateDefaultSubnetResult$ = exports2.CreateDefaultSubnetRequest$ = exports2.CreateCustomerGatewayResult$ = exports2.CreateCustomerGatewayRequest$ = exports2.CreateCoipPoolResult$ = exports2.CreateCoipPoolRequest$ = exports2.CreateCoipCidrResult$ = exports2.CreateCoipCidrRequest$ = exports2.CreateClientVpnRouteResult$ = exports2.CreateClientVpnRouteRequest$ = exports2.CreateClientVpnEndpointResult$ = exports2.CreateClientVpnEndpointRequest$ = exports2.CreateCarrierGatewayResult$ = exports2.CreateCarrierGatewayRequest$ = exports2.CreateCapacityReservationResult$ = exports2.CreateCapacityReservationRequest$ = exports2.CreateCapacityReservationFleetResult$ = exports2.CreateCapacityReservationFleetRequest$ = exports2.CreateCapacityReservationBySplittingResult$ = exports2.CreateCapacityReservationBySplittingRequest$ = exports2.CreateCapacityManagerDataExportResult$ = exports2.CreateCapacityManagerDataExportRequest$ = exports2.CpuPerformanceFactorRequest$ = exports2.CpuPerformanceFactor$ = exports2.CpuOptionsRequest$ = exports2.CpuOptions$ = exports2.CopyVolumesResult$ = exports2.CopyVolumesRequest$ = void 0;
    exports2.CreateNetworkAclResult$ = exports2.CreateNetworkAclRequest$ = exports2.CreateNetworkAclEntryRequest$ = exports2.CreateNatGatewayResult$ = exports2.CreateNatGatewayRequest$ = exports2.CreateManagedPrefixListResult$ = exports2.CreateManagedPrefixListRequest$ = exports2.CreateMacSystemIntegrityProtectionModificationTaskResult$ = exports2.CreateMacSystemIntegrityProtectionModificationTaskRequest$ = exports2.CreateLocalGatewayVirtualInterfaceResult$ = exports2.CreateLocalGatewayVirtualInterfaceRequest$ = exports2.CreateLocalGatewayVirtualInterfaceGroupResult$ = exports2.CreateLocalGatewayVirtualInterfaceGroupRequest$ = exports2.CreateLocalGatewayRouteTableVpcAssociationResult$ = exports2.CreateLocalGatewayRouteTableVpcAssociationRequest$ = exports2.CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationResult$ = exports2.CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest$ = exports2.CreateLocalGatewayRouteTableResult$ = exports2.CreateLocalGatewayRouteTableRequest$ = exports2.CreateLocalGatewayRouteResult$ = exports2.CreateLocalGatewayRouteRequest$ = exports2.CreateLaunchTemplateVersionResult$ = exports2.CreateLaunchTemplateVersionRequest$ = exports2.CreateLaunchTemplateResult$ = exports2.CreateLaunchTemplateRequest$ = exports2.CreateKeyPairRequest$ = exports2.CreateIpamScopeResult$ = exports2.CreateIpamScopeRequest$ = exports2.CreateIpamResult$ = exports2.CreateIpamResourceDiscoveryResult$ = exports2.CreateIpamResourceDiscoveryRequest$ = exports2.CreateIpamRequest$ = exports2.CreateIpamPrefixListResolverTargetResult$ = exports2.CreateIpamPrefixListResolverTargetRequest$ = exports2.CreateIpamPrefixListResolverResult$ = exports2.CreateIpamPrefixListResolverRequest$ = exports2.CreateIpamPoolResult$ = exports2.CreateIpamPoolRequest$ = exports2.CreateIpamPolicyResult$ = exports2.CreateIpamPolicyRequest$ = exports2.CreateIpamExternalResourceVerificationTokenResult$ = exports2.CreateIpamExternalResourceVerificationTokenRequest$ = exports2.CreateInterruptibleCapacityReservationAllocationResult$ = exports2.CreateInterruptibleCapacityReservationAllocationRequest$ = exports2.CreateInternetGatewayResult$ = exports2.CreateInternetGatewayRequest$ = exports2.CreateInstanceExportTaskResult$ = exports2.CreateInstanceExportTaskRequest$ = exports2.CreateInstanceEventWindowResult$ = exports2.CreateInstanceEventWindowRequest$ = void 0;
    exports2.CreateTrafficMirrorFilterRuleResult$ = exports2.CreateTrafficMirrorFilterRuleRequest$ = exports2.CreateTrafficMirrorFilterResult$ = exports2.CreateTrafficMirrorFilterRequest$ = exports2.CreateTagsRequest$ = exports2.CreateSubnetResult$ = exports2.CreateSubnetRequest$ = exports2.CreateSubnetCidrReservationResult$ = exports2.CreateSubnetCidrReservationRequest$ = exports2.CreateStoreImageTaskResult$ = exports2.CreateStoreImageTaskRequest$ = exports2.CreateSpotDatafeedSubscriptionResult$ = exports2.CreateSpotDatafeedSubscriptionRequest$ = exports2.CreateSnapshotsResult$ = exports2.CreateSnapshotsRequest$ = exports2.CreateSnapshotRequest$ = exports2.CreateSecurityGroupResult$ = exports2.CreateSecurityGroupRequest$ = exports2.CreateSecondarySubnetResult$ = exports2.CreateSecondarySubnetRequest$ = exports2.CreateSecondaryNetworkResult$ = exports2.CreateSecondaryNetworkRequest$ = exports2.CreateRouteTableResult$ = exports2.CreateRouteTableRequest$ = exports2.CreateRouteServerResult$ = exports2.CreateRouteServerRequest$ = exports2.CreateRouteServerPeerResult$ = exports2.CreateRouteServerPeerRequest$ = exports2.CreateRouteServerEndpointResult$ = exports2.CreateRouteServerEndpointRequest$ = exports2.CreateRouteResult$ = exports2.CreateRouteRequest$ = exports2.CreateRestoreImageTaskResult$ = exports2.CreateRestoreImageTaskRequest$ = exports2.CreateReservedInstancesListingResult$ = exports2.CreateReservedInstancesListingRequest$ = exports2.CreateReplaceRootVolumeTaskResult$ = exports2.CreateReplaceRootVolumeTaskRequest$ = exports2.CreatePublicIpv4PoolResult$ = exports2.CreatePublicIpv4PoolRequest$ = exports2.CreatePlacementGroupResult$ = exports2.CreatePlacementGroupRequest$ = exports2.CreateNetworkInterfaceResult$ = exports2.CreateNetworkInterfaceRequest$ = exports2.CreateNetworkInterfacePermissionResult$ = exports2.CreateNetworkInterfacePermissionRequest$ = exports2.CreateNetworkInsightsPathResult$ = exports2.CreateNetworkInsightsPathRequest$ = exports2.CreateNetworkInsightsAccessScopeResult$ = exports2.CreateNetworkInsightsAccessScopeRequest$ = void 0;
    exports2.CreateVerifiedAccessTrustProviderResult$ = exports2.CreateVerifiedAccessTrustProviderRequest$ = exports2.CreateVerifiedAccessTrustProviderOidcOptions$ = exports2.CreateVerifiedAccessTrustProviderDeviceOptions$ = exports2.CreateVerifiedAccessNativeApplicationOidcOptions$ = exports2.CreateVerifiedAccessInstanceResult$ = exports2.CreateVerifiedAccessInstanceRequest$ = exports2.CreateVerifiedAccessGroupResult$ = exports2.CreateVerifiedAccessGroupRequest$ = exports2.CreateVerifiedAccessEndpointResult$ = exports2.CreateVerifiedAccessEndpointRequest$ = exports2.CreateVerifiedAccessEndpointRdsOptions$ = exports2.CreateVerifiedAccessEndpointPortRange$ = exports2.CreateVerifiedAccessEndpointLoadBalancerOptions$ = exports2.CreateVerifiedAccessEndpointEniOptions$ = exports2.CreateVerifiedAccessEndpointCidrOptions$ = exports2.CreateTransitGatewayVpcAttachmentResult$ = exports2.CreateTransitGatewayVpcAttachmentRequestOptions$ = exports2.CreateTransitGatewayVpcAttachmentRequest$ = exports2.CreateTransitGatewayRouteTableResult$ = exports2.CreateTransitGatewayRouteTableRequest$ = exports2.CreateTransitGatewayRouteTableAnnouncementResult$ = exports2.CreateTransitGatewayRouteTableAnnouncementRequest$ = exports2.CreateTransitGatewayRouteResult$ = exports2.CreateTransitGatewayRouteRequest$ = exports2.CreateTransitGatewayResult$ = exports2.CreateTransitGatewayRequest$ = exports2.CreateTransitGatewayPrefixListReferenceResult$ = exports2.CreateTransitGatewayPrefixListReferenceRequest$ = exports2.CreateTransitGatewayPolicyTableResult$ = exports2.CreateTransitGatewayPolicyTableRequest$ = exports2.CreateTransitGatewayPeeringAttachmentResult$ = exports2.CreateTransitGatewayPeeringAttachmentRequestOptions$ = exports2.CreateTransitGatewayPeeringAttachmentRequest$ = exports2.CreateTransitGatewayMulticastDomainResult$ = exports2.CreateTransitGatewayMulticastDomainRequestOptions$ = exports2.CreateTransitGatewayMulticastDomainRequest$ = exports2.CreateTransitGatewayMeteringPolicyResult$ = exports2.CreateTransitGatewayMeteringPolicyRequest$ = exports2.CreateTransitGatewayMeteringPolicyEntryResult$ = exports2.CreateTransitGatewayMeteringPolicyEntryRequest$ = exports2.CreateTransitGatewayConnectResult$ = exports2.CreateTransitGatewayConnectRequestOptions$ = exports2.CreateTransitGatewayConnectRequest$ = exports2.CreateTransitGatewayConnectPeerResult$ = exports2.CreateTransitGatewayConnectPeerRequest$ = exports2.CreateTrafficMirrorTargetResult$ = exports2.CreateTrafficMirrorTargetRequest$ = exports2.CreateTrafficMirrorSessionResult$ = exports2.CreateTrafficMirrorSessionRequest$ = void 0;
    exports2.DeleteFleetError$ = exports2.DeleteEgressOnlyInternetGatewayResult$ = exports2.DeleteEgressOnlyInternetGatewayRequest$ = exports2.DeleteDhcpOptionsRequest$ = exports2.DeleteCustomerGatewayRequest$ = exports2.DeleteCoipPoolResult$ = exports2.DeleteCoipPoolRequest$ = exports2.DeleteCoipCidrResult$ = exports2.DeleteCoipCidrRequest$ = exports2.DeleteClientVpnRouteResult$ = exports2.DeleteClientVpnRouteRequest$ = exports2.DeleteClientVpnEndpointResult$ = exports2.DeleteClientVpnEndpointRequest$ = exports2.DeleteCarrierGatewayResult$ = exports2.DeleteCarrierGatewayRequest$ = exports2.DeleteCapacityManagerDataExportResult$ = exports2.DeleteCapacityManagerDataExportRequest$ = exports2.DefaultConnectionTrackingConfiguration$ = exports2.DeclarativePoliciesReport$ = exports2.DataResponse$ = exports2.DataQuery$ = exports2.CustomerGateway$ = exports2.CreditSpecificationRequest$ = exports2.CreditSpecification$ = exports2.CreationDateConditionRequest$ = exports2.CreationDateCondition$ = exports2.CreateVpnGatewayResult$ = exports2.CreateVpnGatewayRequest$ = exports2.CreateVpnConnectionRouteRequest$ = exports2.CreateVpnConnectionResult$ = exports2.CreateVpnConnectionRequest$ = exports2.CreateVpnConcentratorResult$ = exports2.CreateVpnConcentratorRequest$ = exports2.CreateVpcResult$ = exports2.CreateVpcRequest$ = exports2.CreateVpcPeeringConnectionResult$ = exports2.CreateVpcPeeringConnectionRequest$ = exports2.CreateVpcEndpointServiceConfigurationResult$ = exports2.CreateVpcEndpointServiceConfigurationRequest$ = exports2.CreateVpcEndpointResult$ = exports2.CreateVpcEndpointRequest$ = exports2.CreateVpcEndpointConnectionNotificationResult$ = exports2.CreateVpcEndpointConnectionNotificationRequest$ = exports2.CreateVpcEncryptionControlResult$ = exports2.CreateVpcEncryptionControlRequest$ = exports2.CreateVpcBlockPublicAccessExclusionResult$ = exports2.CreateVpcBlockPublicAccessExclusionRequest$ = exports2.CreateVolumeRequest$ = exports2.CreateVolumePermissionModifications$ = exports2.CreateVolumePermission$ = void 0;
    exports2.DeleteLocalGatewayVirtualInterfaceRequest$ = exports2.DeleteLocalGatewayVirtualInterfaceGroupResult$ = exports2.DeleteLocalGatewayVirtualInterfaceGroupRequest$ = exports2.DeleteLocalGatewayRouteTableVpcAssociationResult$ = exports2.DeleteLocalGatewayRouteTableVpcAssociationRequest$ = exports2.DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociationResult$ = exports2.DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest$ = exports2.DeleteLocalGatewayRouteTableResult$ = exports2.DeleteLocalGatewayRouteTableRequest$ = exports2.DeleteLocalGatewayRouteResult$ = exports2.DeleteLocalGatewayRouteRequest$ = exports2.DeleteLaunchTemplateVersionsResult$ = exports2.DeleteLaunchTemplateVersionsResponseSuccessItem$ = exports2.DeleteLaunchTemplateVersionsResponseErrorItem$ = exports2.DeleteLaunchTemplateVersionsRequest$ = exports2.DeleteLaunchTemplateResult$ = exports2.DeleteLaunchTemplateRequest$ = exports2.DeleteKeyPairResult$ = exports2.DeleteKeyPairRequest$ = exports2.DeleteIpamScopeResult$ = exports2.DeleteIpamScopeRequest$ = exports2.DeleteIpamResult$ = exports2.DeleteIpamResourceDiscoveryResult$ = exports2.DeleteIpamResourceDiscoveryRequest$ = exports2.DeleteIpamRequest$ = exports2.DeleteIpamPrefixListResolverTargetResult$ = exports2.DeleteIpamPrefixListResolverTargetRequest$ = exports2.DeleteIpamPrefixListResolverResult$ = exports2.DeleteIpamPrefixListResolverRequest$ = exports2.DeleteIpamPoolResult$ = exports2.DeleteIpamPoolRequest$ = exports2.DeleteIpamPolicyResult$ = exports2.DeleteIpamPolicyRequest$ = exports2.DeleteIpamExternalResourceVerificationTokenResult$ = exports2.DeleteIpamExternalResourceVerificationTokenRequest$ = exports2.DeleteInternetGatewayRequest$ = exports2.DeleteInstanceEventWindowResult$ = exports2.DeleteInstanceEventWindowRequest$ = exports2.DeleteInstanceConnectEndpointResult$ = exports2.DeleteInstanceConnectEndpointRequest$ = exports2.DeleteImageUsageReportResult$ = exports2.DeleteImageUsageReportRequest$ = exports2.DeleteFpgaImageResult$ = exports2.DeleteFpgaImageRequest$ = exports2.DeleteFlowLogsResult$ = exports2.DeleteFlowLogsRequest$ = exports2.DeleteFleetSuccessItem$ = exports2.DeleteFleetsResult$ = exports2.DeleteFleetsRequest$ = exports2.DeleteFleetErrorItem$ = void 0;
    exports2.DeleteTrafficMirrorSessionRequest$ = exports2.DeleteTrafficMirrorFilterRuleResult$ = exports2.DeleteTrafficMirrorFilterRuleRequest$ = exports2.DeleteTrafficMirrorFilterResult$ = exports2.DeleteTrafficMirrorFilterRequest$ = exports2.DeleteTagsRequest$ = exports2.DeleteSubnetRequest$ = exports2.DeleteSubnetCidrReservationResult$ = exports2.DeleteSubnetCidrReservationRequest$ = exports2.DeleteSpotDatafeedSubscriptionRequest$ = exports2.DeleteSnapshotReturnCode$ = exports2.DeleteSnapshotRequest$ = exports2.DeleteSecurityGroupResult$ = exports2.DeleteSecurityGroupRequest$ = exports2.DeleteSecondarySubnetResult$ = exports2.DeleteSecondarySubnetRequest$ = exports2.DeleteSecondaryNetworkResult$ = exports2.DeleteSecondaryNetworkRequest$ = exports2.DeleteRouteTableRequest$ = exports2.DeleteRouteServerResult$ = exports2.DeleteRouteServerRequest$ = exports2.DeleteRouteServerPeerResult$ = exports2.DeleteRouteServerPeerRequest$ = exports2.DeleteRouteServerEndpointResult$ = exports2.DeleteRouteServerEndpointRequest$ = exports2.DeleteRouteRequest$ = exports2.DeleteQueuedReservedInstancesResult$ = exports2.DeleteQueuedReservedInstancesRequest$ = exports2.DeleteQueuedReservedInstancesError$ = exports2.DeletePublicIpv4PoolResult$ = exports2.DeletePublicIpv4PoolRequest$ = exports2.DeletePlacementGroupRequest$ = exports2.DeleteNetworkInterfaceRequest$ = exports2.DeleteNetworkInterfacePermissionResult$ = exports2.DeleteNetworkInterfacePermissionRequest$ = exports2.DeleteNetworkInsightsPathResult$ = exports2.DeleteNetworkInsightsPathRequest$ = exports2.DeleteNetworkInsightsAnalysisResult$ = exports2.DeleteNetworkInsightsAnalysisRequest$ = exports2.DeleteNetworkInsightsAccessScopeResult$ = exports2.DeleteNetworkInsightsAccessScopeRequest$ = exports2.DeleteNetworkInsightsAccessScopeAnalysisResult$ = exports2.DeleteNetworkInsightsAccessScopeAnalysisRequest$ = exports2.DeleteNetworkAclRequest$ = exports2.DeleteNetworkAclEntryRequest$ = exports2.DeleteNatGatewayResult$ = exports2.DeleteNatGatewayRequest$ = exports2.DeleteManagedPrefixListResult$ = exports2.DeleteManagedPrefixListRequest$ = exports2.DeleteLocalGatewayVirtualInterfaceResult$ = void 0;
    exports2.DeleteVpcEndpointsResult$ = exports2.DeleteVpcEndpointsRequest$ = exports2.DeleteVpcEndpointServiceConfigurationsResult$ = exports2.DeleteVpcEndpointServiceConfigurationsRequest$ = exports2.DeleteVpcEndpointConnectionNotificationsResult$ = exports2.DeleteVpcEndpointConnectionNotificationsRequest$ = exports2.DeleteVpcEncryptionControlResult$ = exports2.DeleteVpcEncryptionControlRequest$ = exports2.DeleteVpcBlockPublicAccessExclusionResult$ = exports2.DeleteVpcBlockPublicAccessExclusionRequest$ = exports2.DeleteVolumeRequest$ = exports2.DeleteVerifiedAccessTrustProviderResult$ = exports2.DeleteVerifiedAccessTrustProviderRequest$ = exports2.DeleteVerifiedAccessInstanceResult$ = exports2.DeleteVerifiedAccessInstanceRequest$ = exports2.DeleteVerifiedAccessGroupResult$ = exports2.DeleteVerifiedAccessGroupRequest$ = exports2.DeleteVerifiedAccessEndpointResult$ = exports2.DeleteVerifiedAccessEndpointRequest$ = exports2.DeleteTransitGatewayVpcAttachmentResult$ = exports2.DeleteTransitGatewayVpcAttachmentRequest$ = exports2.DeleteTransitGatewayRouteTableResult$ = exports2.DeleteTransitGatewayRouteTableRequest$ = exports2.DeleteTransitGatewayRouteTableAnnouncementResult$ = exports2.DeleteTransitGatewayRouteTableAnnouncementRequest$ = exports2.DeleteTransitGatewayRouteResult$ = exports2.DeleteTransitGatewayRouteRequest$ = exports2.DeleteTransitGatewayResult$ = exports2.DeleteTransitGatewayRequest$ = exports2.DeleteTransitGatewayPrefixListReferenceResult$ = exports2.DeleteTransitGatewayPrefixListReferenceRequest$ = exports2.DeleteTransitGatewayPolicyTableResult$ = exports2.DeleteTransitGatewayPolicyTableRequest$ = exports2.DeleteTransitGatewayPeeringAttachmentResult$ = exports2.DeleteTransitGatewayPeeringAttachmentRequest$ = exports2.DeleteTransitGatewayMulticastDomainResult$ = exports2.DeleteTransitGatewayMulticastDomainRequest$ = exports2.DeleteTransitGatewayMeteringPolicyResult$ = exports2.DeleteTransitGatewayMeteringPolicyRequest$ = exports2.DeleteTransitGatewayMeteringPolicyEntryResult$ = exports2.DeleteTransitGatewayMeteringPolicyEntryRequest$ = exports2.DeleteTransitGatewayConnectResult$ = exports2.DeleteTransitGatewayConnectRequest$ = exports2.DeleteTransitGatewayConnectPeerResult$ = exports2.DeleteTransitGatewayConnectPeerRequest$ = exports2.DeleteTransitGatewayClientVpnAttachmentResult$ = exports2.DeleteTransitGatewayClientVpnAttachmentRequest$ = exports2.DeleteTrafficMirrorTargetResult$ = exports2.DeleteTrafficMirrorTargetRequest$ = exports2.DeleteTrafficMirrorSessionResult$ = void 0;
    exports2.DescribeCapacityBlockOfferingsRequest$ = exports2.DescribeCapacityBlockExtensionOfferingsResult$ = exports2.DescribeCapacityBlockExtensionOfferingsRequest$ = exports2.DescribeCapacityBlockExtensionHistoryResult$ = exports2.DescribeCapacityBlockExtensionHistoryRequest$ = exports2.DescribeByoipCidrsResult$ = exports2.DescribeByoipCidrsRequest$ = exports2.DescribeBundleTasksResult$ = exports2.DescribeBundleTasksRequest$ = exports2.DescribeAwsNetworkPerformanceMetricSubscriptionsResult$ = exports2.DescribeAwsNetworkPerformanceMetricSubscriptionsRequest$ = exports2.DescribeAvailabilityZonesResult$ = exports2.DescribeAvailabilityZonesRequest$ = exports2.DescribeAggregateIdFormatResult$ = exports2.DescribeAggregateIdFormatRequest$ = exports2.DescribeAddressTransfersResult$ = exports2.DescribeAddressTransfersRequest$ = exports2.DescribeAddressesResult$ = exports2.DescribeAddressesRequest$ = exports2.DescribeAddressesAttributeResult$ = exports2.DescribeAddressesAttributeRequest$ = exports2.DescribeAccountAttributesResult$ = exports2.DescribeAccountAttributesRequest$ = exports2.DeregisterTransitGatewayMulticastGroupSourcesResult$ = exports2.DeregisterTransitGatewayMulticastGroupSourcesRequest$ = exports2.DeregisterTransitGatewayMulticastGroupMembersResult$ = exports2.DeregisterTransitGatewayMulticastGroupMembersRequest$ = exports2.DeregisterInstanceTagAttributeRequest$ = exports2.DeregisterInstanceEventNotificationAttributesResult$ = exports2.DeregisterInstanceEventNotificationAttributesRequest$ = exports2.DeregisterImageResult$ = exports2.DeregisterImageRequest$ = exports2.DeprovisionPublicIpv4PoolCidrResult$ = exports2.DeprovisionPublicIpv4PoolCidrRequest$ = exports2.DeprovisionIpamPoolCidrResult$ = exports2.DeprovisionIpamPoolCidrRequest$ = exports2.DeprovisionIpamByoasnResult$ = exports2.DeprovisionIpamByoasnRequest$ = exports2.DeprovisionByoipCidrResult$ = exports2.DeprovisionByoipCidrRequest$ = exports2.DeprecationTimeConditionRequest$ = exports2.DeprecationTimeCondition$ = exports2.DeleteVpnGatewayRequest$ = exports2.DeleteVpnConnectionRouteRequest$ = exports2.DeleteVpnConnectionRequest$ = exports2.DeleteVpnConcentratorResult$ = exports2.DeleteVpnConcentratorRequest$ = exports2.DeleteVpcRequest$ = exports2.DeleteVpcPeeringConnectionResult$ = exports2.DeleteVpcPeeringConnectionRequest$ = void 0;
    exports2.DescribeFastLaunchImagesSuccessItem$ = exports2.DescribeFastLaunchImagesResult$ = exports2.DescribeFastLaunchImagesRequest$ = exports2.DescribeExportTasksResult$ = exports2.DescribeExportTasksRequest$ = exports2.DescribeExportImageTasksResult$ = exports2.DescribeExportImageTasksRequest$ = exports2.DescribeElasticGpusResult$ = exports2.DescribeElasticGpusRequest$ = exports2.DescribeEgressOnlyInternetGatewaysResult$ = exports2.DescribeEgressOnlyInternetGatewaysRequest$ = exports2.DescribeDhcpOptionsResult$ = exports2.DescribeDhcpOptionsRequest$ = exports2.DescribeDeclarativePoliciesReportsResult$ = exports2.DescribeDeclarativePoliciesReportsRequest$ = exports2.DescribeCustomerGatewaysResult$ = exports2.DescribeCustomerGatewaysRequest$ = exports2.DescribeConversionTasksResult$ = exports2.DescribeConversionTasksRequest$ = exports2.DescribeCoipPoolsResult$ = exports2.DescribeCoipPoolsRequest$ = exports2.DescribeClientVpnTargetNetworksResult$ = exports2.DescribeClientVpnTargetNetworksRequest$ = exports2.DescribeClientVpnRoutesResult$ = exports2.DescribeClientVpnRoutesRequest$ = exports2.DescribeClientVpnEndpointsResult$ = exports2.DescribeClientVpnEndpointsRequest$ = exports2.DescribeClientVpnConnectionsResult$ = exports2.DescribeClientVpnConnectionsRequest$ = exports2.DescribeClientVpnAuthorizationRulesResult$ = exports2.DescribeClientVpnAuthorizationRulesRequest$ = exports2.DescribeClassicLinkInstancesResult$ = exports2.DescribeClassicLinkInstancesRequest$ = exports2.DescribeCarrierGatewaysResult$ = exports2.DescribeCarrierGatewaysRequest$ = exports2.DescribeCapacityReservationTopologyResult$ = exports2.DescribeCapacityReservationTopologyRequest$ = exports2.DescribeCapacityReservationsResult$ = exports2.DescribeCapacityReservationsRequest$ = exports2.DescribeCapacityReservationFleetsResult$ = exports2.DescribeCapacityReservationFleetsRequest$ = exports2.DescribeCapacityReservationBillingRequestsResult$ = exports2.DescribeCapacityReservationBillingRequestsRequest$ = exports2.DescribeCapacityManagerDataExportsResult$ = exports2.DescribeCapacityManagerDataExportsRequest$ = exports2.DescribeCapacityBlockStatusResult$ = exports2.DescribeCapacityBlockStatusRequest$ = exports2.DescribeCapacityBlocksResult$ = exports2.DescribeCapacityBlocksRequest$ = exports2.DescribeCapacityBlockOfferingsResult$ = void 0;
    exports2.DescribeInstanceEventWindowsRequest$ = exports2.DescribeInstanceEventNotificationAttributesResult$ = exports2.DescribeInstanceEventNotificationAttributesRequest$ = exports2.DescribeInstanceCreditSpecificationsResult$ = exports2.DescribeInstanceCreditSpecificationsRequest$ = exports2.DescribeInstanceConnectEndpointsResult$ = exports2.DescribeInstanceConnectEndpointsRequest$ = exports2.DescribeInstanceAttributeRequest$ = exports2.DescribeImportSnapshotTasksResult$ = exports2.DescribeImportSnapshotTasksRequest$ = exports2.DescribeImportImageTasksResult$ = exports2.DescribeImportImageTasksRequest$ = exports2.DescribeImageUsageReportsResult$ = exports2.DescribeImageUsageReportsRequest$ = exports2.DescribeImageUsageReportEntriesResult$ = exports2.DescribeImageUsageReportEntriesRequest$ = exports2.DescribeImagesResult$ = exports2.DescribeImagesRequest$ = exports2.DescribeImageReferencesResult$ = exports2.DescribeImageReferencesRequest$ = exports2.DescribeImageAttributeRequest$ = exports2.DescribeIdFormatResult$ = exports2.DescribeIdFormatRequest$ = exports2.DescribeIdentityIdFormatResult$ = exports2.DescribeIdentityIdFormatRequest$ = exports2.DescribeIamInstanceProfileAssociationsResult$ = exports2.DescribeIamInstanceProfileAssociationsRequest$ = exports2.DescribeHostsResult$ = exports2.DescribeHostsRequest$ = exports2.DescribeHostReservationsResult$ = exports2.DescribeHostReservationsRequest$ = exports2.DescribeHostReservationOfferingsResult$ = exports2.DescribeHostReservationOfferingsRequest$ = exports2.DescribeFpgaImagesResult$ = exports2.DescribeFpgaImagesRequest$ = exports2.DescribeFpgaImageAttributeResult$ = exports2.DescribeFpgaImageAttributeRequest$ = exports2.DescribeFlowLogsResult$ = exports2.DescribeFlowLogsRequest$ = exports2.DescribeFleetsResult$ = exports2.DescribeFleetsRequest$ = exports2.DescribeFleetsInstances$ = exports2.DescribeFleetInstancesResult$ = exports2.DescribeFleetInstancesRequest$ = exports2.DescribeFleetHistoryResult$ = exports2.DescribeFleetHistoryRequest$ = exports2.DescribeFleetError$ = exports2.DescribeFastSnapshotRestoreSuccessItem$ = exports2.DescribeFastSnapshotRestoresResult$ = exports2.DescribeFastSnapshotRestoresRequest$ = void 0;
    exports2.DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociationsRequest$ = exports2.DescribeLocalGatewayRouteTablesResult$ = exports2.DescribeLocalGatewayRouteTablesRequest$ = exports2.DescribeLaunchTemplateVersionsResult$ = exports2.DescribeLaunchTemplateVersionsRequest$ = exports2.DescribeLaunchTemplatesResult$ = exports2.DescribeLaunchTemplatesRequest$ = exports2.DescribeKeyPairsResult$ = exports2.DescribeKeyPairsRequest$ = exports2.DescribeIpv6PoolsResult$ = exports2.DescribeIpv6PoolsRequest$ = exports2.DescribeIpamsResult$ = exports2.DescribeIpamsRequest$ = exports2.DescribeIpamScopesResult$ = exports2.DescribeIpamScopesRequest$ = exports2.DescribeIpamResourceDiscoveryAssociationsResult$ = exports2.DescribeIpamResourceDiscoveryAssociationsRequest$ = exports2.DescribeIpamResourceDiscoveriesResult$ = exports2.DescribeIpamResourceDiscoveriesRequest$ = exports2.DescribeIpamPrefixListResolverTargetsResult$ = exports2.DescribeIpamPrefixListResolverTargetsRequest$ = exports2.DescribeIpamPrefixListResolversResult$ = exports2.DescribeIpamPrefixListResolversRequest$ = exports2.DescribeIpamPoolsResult$ = exports2.DescribeIpamPoolsRequest$ = exports2.DescribeIpamPoliciesResult$ = exports2.DescribeIpamPoliciesRequest$ = exports2.DescribeIpamExternalResourceVerificationTokensResult$ = exports2.DescribeIpamExternalResourceVerificationTokensRequest$ = exports2.DescribeIpamByoasnResult$ = exports2.DescribeIpamByoasnRequest$ = exports2.DescribeInternetGatewaysResult$ = exports2.DescribeInternetGatewaysRequest$ = exports2.DescribeInstanceTypesResult$ = exports2.DescribeInstanceTypesRequest$ = exports2.DescribeInstanceTypeOfferingsResult$ = exports2.DescribeInstanceTypeOfferingsRequest$ = exports2.DescribeInstanceTopologyResult$ = exports2.DescribeInstanceTopologyRequest$ = exports2.DescribeInstanceStatusResult$ = exports2.DescribeInstanceStatusRequest$ = exports2.DescribeInstancesResult$ = exports2.DescribeInstancesRequest$ = exports2.DescribeInstanceSqlHaStatesResult$ = exports2.DescribeInstanceSqlHaStatesRequest$ = exports2.DescribeInstanceSqlHaHistoryStatesResult$ = exports2.DescribeInstanceSqlHaHistoryStatesRequest$ = exports2.DescribeInstanceImageMetadataResult$ = exports2.DescribeInstanceImageMetadataRequest$ = exports2.DescribeInstanceEventWindowsResult$ = void 0;
    exports2.DescribeReplaceRootVolumeTasksRequest$ = exports2.DescribeRegionsResult$ = exports2.DescribeRegionsRequest$ = exports2.DescribePublicIpv4PoolsResult$ = exports2.DescribePublicIpv4PoolsRequest$ = exports2.DescribePrincipalIdFormatResult$ = exports2.DescribePrincipalIdFormatRequest$ = exports2.DescribePrefixListsResult$ = exports2.DescribePrefixListsRequest$ = exports2.DescribePlacementGroupsResult$ = exports2.DescribePlacementGroupsRequest$ = exports2.DescribeOutpostLagsResult$ = exports2.DescribeOutpostLagsRequest$ = exports2.DescribeNetworkInterfacesResult$ = exports2.DescribeNetworkInterfacesRequest$ = exports2.DescribeNetworkInterfacePermissionsResult$ = exports2.DescribeNetworkInterfacePermissionsRequest$ = exports2.DescribeNetworkInterfaceAttributeResult$ = exports2.DescribeNetworkInterfaceAttributeRequest$ = exports2.DescribeNetworkInsightsPathsResult$ = exports2.DescribeNetworkInsightsPathsRequest$ = exports2.DescribeNetworkInsightsAnalysesResult$ = exports2.DescribeNetworkInsightsAnalysesRequest$ = exports2.DescribeNetworkInsightsAccessScopesResult$ = exports2.DescribeNetworkInsightsAccessScopesRequest$ = exports2.DescribeNetworkInsightsAccessScopeAnalysesResult$ = exports2.DescribeNetworkInsightsAccessScopeAnalysesRequest$ = exports2.DescribeNetworkAclsResult$ = exports2.DescribeNetworkAclsRequest$ = exports2.DescribeNatGatewaysResult$ = exports2.DescribeNatGatewaysRequest$ = exports2.DescribeMovingAddressesResult$ = exports2.DescribeMovingAddressesRequest$ = exports2.DescribeManagedPrefixListsResult$ = exports2.DescribeManagedPrefixListsRequest$ = exports2.DescribeMacModificationTasksResult$ = exports2.DescribeMacModificationTasksRequest$ = exports2.DescribeMacHostsResult$ = exports2.DescribeMacHostsRequest$ = exports2.DescribeLockedSnapshotsResult$ = exports2.DescribeLockedSnapshotsRequest$ = exports2.DescribeLocalGatewayVirtualInterfacesResult$ = exports2.DescribeLocalGatewayVirtualInterfacesRequest$ = exports2.DescribeLocalGatewayVirtualInterfaceGroupsResult$ = exports2.DescribeLocalGatewayVirtualInterfaceGroupsRequest$ = exports2.DescribeLocalGatewaysResult$ = exports2.DescribeLocalGatewaysRequest$ = exports2.DescribeLocalGatewayRouteTableVpcAssociationsResult$ = exports2.DescribeLocalGatewayRouteTableVpcAssociationsRequest$ = exports2.DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociationsResult$ = void 0;
    exports2.DescribeSpotFleetRequestsRequest$ = exports2.DescribeSpotFleetRequestHistoryResponse$ = exports2.DescribeSpotFleetRequestHistoryRequest$ = exports2.DescribeSpotFleetInstancesResponse$ = exports2.DescribeSpotFleetInstancesRequest$ = exports2.DescribeSpotDatafeedSubscriptionResult$ = exports2.DescribeSpotDatafeedSubscriptionRequest$ = exports2.DescribeSnapshotTierStatusResult$ = exports2.DescribeSnapshotTierStatusRequest$ = exports2.DescribeSnapshotsResult$ = exports2.DescribeSnapshotsRequest$ = exports2.DescribeSnapshotAttributeResult$ = exports2.DescribeSnapshotAttributeRequest$ = exports2.DescribeServiceLinkVirtualInterfacesResult$ = exports2.DescribeServiceLinkVirtualInterfacesRequest$ = exports2.DescribeSecurityGroupVpcAssociationsResult$ = exports2.DescribeSecurityGroupVpcAssociationsRequest$ = exports2.DescribeSecurityGroupsResult$ = exports2.DescribeSecurityGroupsRequest$ = exports2.DescribeSecurityGroupRulesResult$ = exports2.DescribeSecurityGroupRulesRequest$ = exports2.DescribeSecurityGroupReferencesResult$ = exports2.DescribeSecurityGroupReferencesRequest$ = exports2.DescribeSecondarySubnetsResult$ = exports2.DescribeSecondarySubnetsRequest$ = exports2.DescribeSecondaryNetworksResult$ = exports2.DescribeSecondaryNetworksRequest$ = exports2.DescribeSecondaryInterfacesResult$ = exports2.DescribeSecondaryInterfacesRequest$ = exports2.DescribeScheduledInstancesResult$ = exports2.DescribeScheduledInstancesRequest$ = exports2.DescribeScheduledInstanceAvailabilityResult$ = exports2.DescribeScheduledInstanceAvailabilityRequest$ = exports2.DescribeRouteTablesResult$ = exports2.DescribeRouteTablesRequest$ = exports2.DescribeRouteServersResult$ = exports2.DescribeRouteServersRequest$ = exports2.DescribeRouteServerPeersResult$ = exports2.DescribeRouteServerPeersRequest$ = exports2.DescribeRouteServerEndpointsResult$ = exports2.DescribeRouteServerEndpointsRequest$ = exports2.DescribeReservedInstancesResult$ = exports2.DescribeReservedInstancesRequest$ = exports2.DescribeReservedInstancesOfferingsResult$ = exports2.DescribeReservedInstancesOfferingsRequest$ = exports2.DescribeReservedInstancesModificationsResult$ = exports2.DescribeReservedInstancesModificationsRequest$ = exports2.DescribeReservedInstancesListingsResult$ = exports2.DescribeReservedInstancesListingsRequest$ = exports2.DescribeReplaceRootVolumeTasksResult$ = void 0;
    exports2.DescribeVerifiedAccessInstanceLoggingConfigurationsRequest$ = exports2.DescribeVerifiedAccessGroupsResult$ = exports2.DescribeVerifiedAccessGroupsRequest$ = exports2.DescribeVerifiedAccessEndpointsResult$ = exports2.DescribeVerifiedAccessEndpointsRequest$ = exports2.DescribeTrunkInterfaceAssociationsResult$ = exports2.DescribeTrunkInterfaceAssociationsRequest$ = exports2.DescribeTransitGatewayVpcAttachmentsResult$ = exports2.DescribeTransitGatewayVpcAttachmentsRequest$ = exports2.DescribeTransitGatewaysResult$ = exports2.DescribeTransitGatewaysRequest$ = exports2.DescribeTransitGatewayRouteTablesResult$ = exports2.DescribeTransitGatewayRouteTablesRequest$ = exports2.DescribeTransitGatewayRouteTableAnnouncementsResult$ = exports2.DescribeTransitGatewayRouteTableAnnouncementsRequest$ = exports2.DescribeTransitGatewayPolicyTablesResult$ = exports2.DescribeTransitGatewayPolicyTablesRequest$ = exports2.DescribeTransitGatewayPeeringAttachmentsResult$ = exports2.DescribeTransitGatewayPeeringAttachmentsRequest$ = exports2.DescribeTransitGatewayMulticastDomainsResult$ = exports2.DescribeTransitGatewayMulticastDomainsRequest$ = exports2.DescribeTransitGatewayMeteringPoliciesResult$ = exports2.DescribeTransitGatewayMeteringPoliciesRequest$ = exports2.DescribeTransitGatewayConnectsResult$ = exports2.DescribeTransitGatewayConnectsRequest$ = exports2.DescribeTransitGatewayConnectPeersResult$ = exports2.DescribeTransitGatewayConnectPeersRequest$ = exports2.DescribeTransitGatewayAttachmentsResult$ = exports2.DescribeTransitGatewayAttachmentsRequest$ = exports2.DescribeTrafficMirrorTargetsResult$ = exports2.DescribeTrafficMirrorTargetsRequest$ = exports2.DescribeTrafficMirrorSessionsResult$ = exports2.DescribeTrafficMirrorSessionsRequest$ = exports2.DescribeTrafficMirrorFiltersResult$ = exports2.DescribeTrafficMirrorFiltersRequest$ = exports2.DescribeTrafficMirrorFilterRulesResult$ = exports2.DescribeTrafficMirrorFilterRulesRequest$ = exports2.DescribeTagsResult$ = exports2.DescribeTagsRequest$ = exports2.DescribeSubnetsResult$ = exports2.DescribeSubnetsRequest$ = exports2.DescribeStoreImageTasksResult$ = exports2.DescribeStoreImageTasksRequest$ = exports2.DescribeStaleSecurityGroupsResult$ = exports2.DescribeStaleSecurityGroupsRequest$ = exports2.DescribeSpotPriceHistoryResult$ = exports2.DescribeSpotPriceHistoryRequest$ = exports2.DescribeSpotInstanceRequestsResult$ = exports2.DescribeSpotInstanceRequestsRequest$ = exports2.DescribeSpotFleetRequestsResponse$ = void 0;
    exports2.DestinationOptionsRequest$ = exports2.DescribeVpnGatewaysResult$ = exports2.DescribeVpnGatewaysRequest$ = exports2.DescribeVpnConnectionsResult$ = exports2.DescribeVpnConnectionsRequest$ = exports2.DescribeVpnConcentratorsResult$ = exports2.DescribeVpnConcentratorsRequest$ = exports2.DescribeVpcsResult$ = exports2.DescribeVpcsRequest$ = exports2.DescribeVpcPeeringConnectionsResult$ = exports2.DescribeVpcPeeringConnectionsRequest$ = exports2.DescribeVpcEndpointsResult$ = exports2.DescribeVpcEndpointsRequest$ = exports2.DescribeVpcEndpointServicesResult$ = exports2.DescribeVpcEndpointServicesRequest$ = exports2.DescribeVpcEndpointServicePermissionsResult$ = exports2.DescribeVpcEndpointServicePermissionsRequest$ = exports2.DescribeVpcEndpointServiceConfigurationsResult$ = exports2.DescribeVpcEndpointServiceConfigurationsRequest$ = exports2.DescribeVpcEndpointConnectionsResult$ = exports2.DescribeVpcEndpointConnectionsRequest$ = exports2.DescribeVpcEndpointConnectionNotificationsResult$ = exports2.DescribeVpcEndpointConnectionNotificationsRequest$ = exports2.DescribeVpcEndpointAssociationsResult$ = exports2.DescribeVpcEndpointAssociationsRequest$ = exports2.DescribeVpcEncryptionControlsResult$ = exports2.DescribeVpcEncryptionControlsRequest$ = exports2.DescribeVpcClassicLinkResult$ = exports2.DescribeVpcClassicLinkRequest$ = exports2.DescribeVpcClassicLinkDnsSupportResult$ = exports2.DescribeVpcClassicLinkDnsSupportRequest$ = exports2.DescribeVpcBlockPublicAccessOptionsResult$ = exports2.DescribeVpcBlockPublicAccessOptionsRequest$ = exports2.DescribeVpcBlockPublicAccessExclusionsResult$ = exports2.DescribeVpcBlockPublicAccessExclusionsRequest$ = exports2.DescribeVpcAttributeResult$ = exports2.DescribeVpcAttributeRequest$ = exports2.DescribeVolumeStatusResult$ = exports2.DescribeVolumeStatusRequest$ = exports2.DescribeVolumesResult$ = exports2.DescribeVolumesRequest$ = exports2.DescribeVolumesModificationsResult$ = exports2.DescribeVolumesModificationsRequest$ = exports2.DescribeVolumeAttributeResult$ = exports2.DescribeVolumeAttributeRequest$ = exports2.DescribeVerifiedAccessTrustProvidersResult$ = exports2.DescribeVerifiedAccessTrustProvidersRequest$ = exports2.DescribeVerifiedAccessInstancesResult$ = exports2.DescribeVerifiedAccessInstancesRequest$ = exports2.DescribeVerifiedAccessInstanceLoggingConfigurationsResult$ = void 0;
    exports2.DisableSerialConsoleAccessRequest$ = exports2.DisableRouteServerPropagationResult$ = exports2.DisableRouteServerPropagationRequest$ = exports2.DisableIpamPolicyResult$ = exports2.DisableIpamPolicyRequest$ = exports2.DisableIpamOrganizationAdminAccountResult$ = exports2.DisableIpamOrganizationAdminAccountRequest$ = exports2.DisableInstanceSqlHaStandbyDetectionsResult$ = exports2.DisableInstanceSqlHaStandbyDetectionsRequest$ = exports2.DisableImageResult$ = exports2.DisableImageRequest$ = exports2.DisableImageDeregistrationProtectionResult$ = exports2.DisableImageDeregistrationProtectionRequest$ = exports2.DisableImageDeprecationResult$ = exports2.DisableImageDeprecationRequest$ = exports2.DisableImageBlockPublicAccessResult$ = exports2.DisableImageBlockPublicAccessRequest$ = exports2.DisableFastSnapshotRestoreSuccessItem$ = exports2.DisableFastSnapshotRestoreStateErrorItem$ = exports2.DisableFastSnapshotRestoreStateError$ = exports2.DisableFastSnapshotRestoresResult$ = exports2.DisableFastSnapshotRestoresRequest$ = exports2.DisableFastSnapshotRestoreErrorItem$ = exports2.DisableFastLaunchResult$ = exports2.DisableFastLaunchRequest$ = exports2.DisableEbsEncryptionByDefaultResult$ = exports2.DisableEbsEncryptionByDefaultRequest$ = exports2.DisableCapacityManagerResult$ = exports2.DisableCapacityManagerRequest$ = exports2.DisableAwsNetworkPerformanceMetricSubscriptionResult$ = exports2.DisableAwsNetworkPerformanceMetricSubscriptionRequest$ = exports2.DisableAllowedImagesSettingsResult$ = exports2.DisableAllowedImagesSettingsRequest$ = exports2.DisableAddressTransferResult$ = exports2.DisableAddressTransferRequest$ = exports2.DirectoryServiceAuthenticationRequest$ = exports2.DirectoryServiceAuthentication$ = exports2.DimensionCondition$ = exports2.DhcpOptions$ = exports2.DhcpConfiguration$ = exports2.DeviceOptions$ = exports2.DetachVpnGatewayRequest$ = exports2.DetachVolumeRequest$ = exports2.DetachVerifiedAccessTrustProviderResult$ = exports2.DetachVerifiedAccessTrustProviderRequest$ = exports2.DetachNetworkInterfaceRequest$ = exports2.DetachInternetGatewayRequest$ = exports2.DetachClassicLinkVpcResult$ = exports2.DetachClassicLinkVpcRequest$ = exports2.DestinationOptionsResponse$ = void 0;
    exports2.DnsEntry$ = exports2.DiskInfo$ = exports2.DiskImageVolumeDescription$ = exports2.DiskImageDetail$ = exports2.DiskImageDescription$ = exports2.DiskImage$ = exports2.DisassociateVpcCidrBlockResult$ = exports2.DisassociateVpcCidrBlockRequest$ = exports2.DisassociateTrunkInterfaceResult$ = exports2.DisassociateTrunkInterfaceRequest$ = exports2.DisassociateTransitGatewayRouteTableResult$ = exports2.DisassociateTransitGatewayRouteTableRequest$ = exports2.DisassociateTransitGatewayPolicyTableResult$ = exports2.DisassociateTransitGatewayPolicyTableRequest$ = exports2.DisassociateTransitGatewayMulticastDomainResult$ = exports2.DisassociateTransitGatewayMulticastDomainRequest$ = exports2.DisassociateSubnetCidrBlockResult$ = exports2.DisassociateSubnetCidrBlockRequest$ = exports2.DisassociateSecurityGroupVpcResult$ = exports2.DisassociateSecurityGroupVpcRequest$ = exports2.DisassociateRouteTableRequest$ = exports2.DisassociateRouteServerResult$ = exports2.DisassociateRouteServerRequest$ = exports2.DisassociateNatGatewayAddressResult$ = exports2.DisassociateNatGatewayAddressRequest$ = exports2.DisassociateIpamResourceDiscoveryResult$ = exports2.DisassociateIpamResourceDiscoveryRequest$ = exports2.DisassociateIpamByoasnResult$ = exports2.DisassociateIpamByoasnRequest$ = exports2.DisassociateInstanceEventWindowResult$ = exports2.DisassociateInstanceEventWindowRequest$ = exports2.DisassociateIamInstanceProfileResult$ = exports2.DisassociateIamInstanceProfileRequest$ = exports2.DisassociateEnclaveCertificateIamRoleResult$ = exports2.DisassociateEnclaveCertificateIamRoleRequest$ = exports2.DisassociateClientVpnTargetNetworkResult$ = exports2.DisassociateClientVpnTargetNetworkRequest$ = exports2.DisassociateCapacityReservationBillingOwnerResult$ = exports2.DisassociateCapacityReservationBillingOwnerRequest$ = exports2.DisassociateAddressRequest$ = exports2.DisableVpcClassicLinkResult$ = exports2.DisableVpcClassicLinkRequest$ = exports2.DisableVpcClassicLinkDnsSupportResult$ = exports2.DisableVpcClassicLinkDnsSupportRequest$ = exports2.DisableVgwRoutePropagationRequest$ = exports2.DisableTransitGatewayRouteTablePropagationResult$ = exports2.DisableTransitGatewayRouteTablePropagationRequest$ = exports2.DisableSnapshotBlockPublicAccessResult$ = exports2.DisableSnapshotBlockPublicAccessRequest$ = exports2.DisableSerialConsoleAccessResult$ = void 0;
    exports2.EnableInstanceSqlHaStandbyDetectionsResult$ = exports2.EnableInstanceSqlHaStandbyDetectionsRequest$ = exports2.EnableImageResult$ = exports2.EnableImageRequest$ = exports2.EnableImageDeregistrationProtectionResult$ = exports2.EnableImageDeregistrationProtectionRequest$ = exports2.EnableImageDeprecationResult$ = exports2.EnableImageDeprecationRequest$ = exports2.EnableImageBlockPublicAccessResult$ = exports2.EnableImageBlockPublicAccessRequest$ = exports2.EnableFastSnapshotRestoreSuccessItem$ = exports2.EnableFastSnapshotRestoreStateErrorItem$ = exports2.EnableFastSnapshotRestoreStateError$ = exports2.EnableFastSnapshotRestoresResult$ = exports2.EnableFastSnapshotRestoresRequest$ = exports2.EnableFastSnapshotRestoreErrorItem$ = exports2.EnableFastLaunchResult$ = exports2.EnableFastLaunchRequest$ = exports2.EnableEbsEncryptionByDefaultResult$ = exports2.EnableEbsEncryptionByDefaultRequest$ = exports2.EnableCapacityManagerResult$ = exports2.EnableCapacityManagerRequest$ = exports2.EnableAwsNetworkPerformanceMetricSubscriptionResult$ = exports2.EnableAwsNetworkPerformanceMetricSubscriptionRequest$ = exports2.EnableAllowedImagesSettingsResult$ = exports2.EnableAllowedImagesSettingsRequest$ = exports2.EnableAddressTransferResult$ = exports2.EnableAddressTransferRequest$ = exports2.ElasticInferenceAcceleratorAssociation$ = exports2.ElasticInferenceAccelerator$ = exports2.ElasticGpuSpecificationResponse$ = exports2.ElasticGpuSpecification$ = exports2.ElasticGpus$ = exports2.ElasticGpuHealth$ = exports2.ElasticGpuAssociation$ = exports2.EgressOnlyInternetGateway$ = exports2.EfaInfo$ = exports2.Ec2InstanceConnectEndpoint$ = exports2.EbsStatusSummary$ = exports2.EbsStatusDetails$ = exports2.EbsOptimizedInfo$ = exports2.EbsInstanceBlockDeviceSpecification$ = exports2.EbsInstanceBlockDevice$ = exports2.EbsInfo$ = exports2.EbsCardInfo$ = exports2.EbsBlockDeviceResponse$ = exports2.EbsBlockDevice$ = exports2.DnsServersOptionsModifyStructure$ = exports2.DnsOptionsSpecification$ = exports2.DnsOptions$ = void 0;
    exports2.FastLaunchLaunchTemplateSpecificationResponse$ = exports2.FastLaunchLaunchTemplateSpecificationRequest$ = exports2.FailedQueuedPurchaseDeletion$ = exports2.FailedCapacityReservationFleetCancellationResult$ = exports2.ExternalAuthorityConfiguration$ = exports2.ExportVerifiedAccessInstanceClientConfigurationResult$ = exports2.ExportVerifiedAccessInstanceClientConfigurationRequest$ = exports2.ExportTransitGatewayRoutesResult$ = exports2.ExportTransitGatewayRoutesRequest$ = exports2.ExportToS3TaskSpecification$ = exports2.ExportToS3Task$ = exports2.ExportTaskS3LocationRequest$ = exports2.ExportTaskS3Location$ = exports2.ExportTask$ = exports2.ExportImageTask$ = exports2.ExportImageResult$ = exports2.ExportImageRequest$ = exports2.ExportClientVpnClientConfigurationResult$ = exports2.ExportClientVpnClientConfigurationRequest$ = exports2.ExportClientVpnClientCertificateRevocationListResult$ = exports2.ExportClientVpnClientCertificateRevocationListRequest$ = exports2.Explanation$ = exports2.EventInformation$ = exports2.EncryptionSupport$ = exports2.EnclaveOptionsRequest$ = exports2.EnclaveOptions$ = exports2.EnaSrdUdpSpecificationRequest$ = exports2.EnaSrdUdpSpecification$ = exports2.EnaSrdSpecificationRequest$ = exports2.EnaSrdSpecification$ = exports2.EnableVpcClassicLinkResult$ = exports2.EnableVpcClassicLinkRequest$ = exports2.EnableVpcClassicLinkDnsSupportResult$ = exports2.EnableVpcClassicLinkDnsSupportRequest$ = exports2.EnableVolumeIORequest$ = exports2.EnableVgwRoutePropagationRequest$ = exports2.EnableTransitGatewayRouteTablePropagationResult$ = exports2.EnableTransitGatewayRouteTablePropagationRequest$ = exports2.EnableSnapshotBlockPublicAccessResult$ = exports2.EnableSnapshotBlockPublicAccessRequest$ = exports2.EnableSerialConsoleAccessResult$ = exports2.EnableSerialConsoleAccessRequest$ = exports2.EnableRouteServerPropagationResult$ = exports2.EnableRouteServerPropagationRequest$ = exports2.EnableReachabilityAnalyzerOrganizationSharingResult$ = exports2.EnableReachabilityAnalyzerOrganizationSharingRequest$ = exports2.EnableIpamPolicyResult$ = exports2.EnableIpamPolicyRequest$ = exports2.EnableIpamOrganizationAdminAccountResult$ = exports2.EnableIpamOrganizationAdminAccountRequest$ = void 0;
    exports2.GetCoipPoolUsageRequest$ = exports2.GetCapacityReservationUsageResult$ = exports2.GetCapacityReservationUsageRequest$ = exports2.GetCapacityManagerMonitoredTagKeysResult$ = exports2.GetCapacityManagerMonitoredTagKeysRequest$ = exports2.GetCapacityManagerMetricDimensionsResult$ = exports2.GetCapacityManagerMetricDimensionsRequest$ = exports2.GetCapacityManagerMetricDataResult$ = exports2.GetCapacityManagerMetricDataRequest$ = exports2.GetCapacityManagerAttributesResult$ = exports2.GetCapacityManagerAttributesRequest$ = exports2.GetAwsNetworkPerformanceDataResult$ = exports2.GetAwsNetworkPerformanceDataRequest$ = exports2.GetAssociatedIpv6PoolCidrsResult$ = exports2.GetAssociatedIpv6PoolCidrsRequest$ = exports2.GetAssociatedEnclaveCertificateIamRolesResult$ = exports2.GetAssociatedEnclaveCertificateIamRolesRequest$ = exports2.GetAllowedImagesSettingsResult$ = exports2.GetAllowedImagesSettingsRequest$ = exports2.GetActiveVpnTunnelStatusResult$ = exports2.GetActiveVpnTunnelStatusRequest$ = exports2.FpgaInfo$ = exports2.FpgaImageState$ = exports2.FpgaImageAttribute$ = exports2.FpgaImage$ = exports2.FpgaDeviceMemoryInfo$ = exports2.FpgaDeviceInfo$ = exports2.FlowLog$ = exports2.FleetSpotMaintenanceStrategiesRequest$ = exports2.FleetSpotMaintenanceStrategies$ = exports2.FleetSpotCapacityRebalanceRequest$ = exports2.FleetSpotCapacityRebalance$ = exports2.FleetLaunchTemplateSpecificationRequest$ = exports2.FleetLaunchTemplateSpecification$ = exports2.FleetLaunchTemplateOverridesRequest$ = exports2.FleetLaunchTemplateOverrides$ = exports2.FleetLaunchTemplateConfigRequest$ = exports2.FleetLaunchTemplateConfig$ = exports2.FleetEbsBlockDeviceRequest$ = exports2.FleetData$ = exports2.FleetCapacityReservation$ = exports2.FleetBlockDeviceMappingRequest$ = exports2.FirewallStatelessRule$ = exports2.FirewallStatefulRule$ = exports2.FilterPortRange$ = exports2.Filter$ = exports2.FederatedAuthenticationRequest$ = exports2.FederatedAuthentication$ = exports2.FastLaunchSnapshotConfigurationResponse$ = exports2.FastLaunchSnapshotConfigurationRequest$ = void 0;
    exports2.GetIpamPrefixListResolverRulesRequest$ = exports2.GetIpamPoolCidrsResult$ = exports2.GetIpamPoolCidrsRequest$ = exports2.GetIpamPoolAllocationsResult$ = exports2.GetIpamPoolAllocationsRequest$ = exports2.GetIpamPolicyOrganizationTargetsResult$ = exports2.GetIpamPolicyOrganizationTargetsRequest$ = exports2.GetIpamPolicyAllocationRulesResult$ = exports2.GetIpamPolicyAllocationRulesRequest$ = exports2.GetIpamDiscoveredResourceCidrsResult$ = exports2.GetIpamDiscoveredResourceCidrsRequest$ = exports2.GetIpamDiscoveredPublicAddressesResult$ = exports2.GetIpamDiscoveredPublicAddressesRequest$ = exports2.GetIpamDiscoveredAccountsResult$ = exports2.GetIpamDiscoveredAccountsRequest$ = exports2.GetIpamAddressHistoryResult$ = exports2.GetIpamAddressHistoryRequest$ = exports2.GetInstanceUefiDataResult$ = exports2.GetInstanceUefiDataRequest$ = exports2.GetInstanceTypesFromInstanceRequirementsResult$ = exports2.GetInstanceTypesFromInstanceRequirementsRequest$ = exports2.GetInstanceTpmEkPubResult$ = exports2.GetInstanceTpmEkPubRequest$ = exports2.GetInstanceMetadataDefaultsResult$ = exports2.GetInstanceMetadataDefaultsRequest$ = exports2.GetImageBlockPublicAccessStateResult$ = exports2.GetImageBlockPublicAccessStateRequest$ = exports2.GetImageAncestryResult$ = exports2.GetImageAncestryRequest$ = exports2.GetHostReservationPurchasePreviewResult$ = exports2.GetHostReservationPurchasePreviewRequest$ = exports2.GetGroupsForCapacityReservationResult$ = exports2.GetGroupsForCapacityReservationRequest$ = exports2.GetFlowLogsIntegrationTemplateResult$ = exports2.GetFlowLogsIntegrationTemplateRequest$ = exports2.GetEnabledIpamPolicyResult$ = exports2.GetEnabledIpamPolicyRequest$ = exports2.GetEbsEncryptionByDefaultResult$ = exports2.GetEbsEncryptionByDefaultRequest$ = exports2.GetEbsDefaultKmsKeyIdResult$ = exports2.GetEbsDefaultKmsKeyIdRequest$ = exports2.GetDefaultCreditSpecificationResult$ = exports2.GetDefaultCreditSpecificationRequest$ = exports2.GetDeclarativePoliciesReportSummaryResult$ = exports2.GetDeclarativePoliciesReportSummaryRequest$ = exports2.GetConsoleScreenshotResult$ = exports2.GetConsoleScreenshotRequest$ = exports2.GetConsoleOutputResult$ = exports2.GetConsoleOutputRequest$ = exports2.GetCoipPoolUsageResult$ = void 0;
    exports2.GetTransitGatewayPrefixListReferencesRequest$ = exports2.GetTransitGatewayPolicyTableEntriesResult$ = exports2.GetTransitGatewayPolicyTableEntriesRequest$ = exports2.GetTransitGatewayPolicyTableAssociationsResult$ = exports2.GetTransitGatewayPolicyTableAssociationsRequest$ = exports2.GetTransitGatewayMulticastDomainAssociationsResult$ = exports2.GetTransitGatewayMulticastDomainAssociationsRequest$ = exports2.GetTransitGatewayMeteringPolicyEntriesResult$ = exports2.GetTransitGatewayMeteringPolicyEntriesRequest$ = exports2.GetTransitGatewayAttachmentPropagationsResult$ = exports2.GetTransitGatewayAttachmentPropagationsRequest$ = exports2.GetSubnetCidrReservationsResult$ = exports2.GetSubnetCidrReservationsRequest$ = exports2.GetSpotPlacementScoresResult$ = exports2.GetSpotPlacementScoresRequest$ = exports2.GetSnapshotBlockPublicAccessStateResult$ = exports2.GetSnapshotBlockPublicAccessStateRequest$ = exports2.GetSerialConsoleAccessStatusResult$ = exports2.GetSerialConsoleAccessStatusRequest$ = exports2.GetSecurityGroupsForVpcResult$ = exports2.GetSecurityGroupsForVpcRequest$ = exports2.GetRouteServerRoutingDatabaseResult$ = exports2.GetRouteServerRoutingDatabaseRequest$ = exports2.GetRouteServerPropagationsResult$ = exports2.GetRouteServerPropagationsRequest$ = exports2.GetRouteServerAssociationsResult$ = exports2.GetRouteServerAssociationsRequest$ = exports2.GetReservedInstancesExchangeQuoteResult$ = exports2.GetReservedInstancesExchangeQuoteRequest$ = exports2.GetPasswordDataResult$ = exports2.GetPasswordDataRequest$ = exports2.GetNetworkInsightsAccessScopeContentResult$ = exports2.GetNetworkInsightsAccessScopeContentRequest$ = exports2.GetNetworkInsightsAccessScopeAnalysisFindingsResult$ = exports2.GetNetworkInsightsAccessScopeAnalysisFindingsRequest$ = exports2.GetManagedResourceVisibilityResult$ = exports2.GetManagedResourceVisibilityRequest$ = exports2.GetManagedPrefixListEntriesResult$ = exports2.GetManagedPrefixListEntriesRequest$ = exports2.GetManagedPrefixListAssociationsResult$ = exports2.GetManagedPrefixListAssociationsRequest$ = exports2.GetLaunchTemplateDataResult$ = exports2.GetLaunchTemplateDataRequest$ = exports2.GetIpamResourceCidrsResult$ = exports2.GetIpamResourceCidrsRequest$ = exports2.GetIpamPrefixListResolverVersionsResult$ = exports2.GetIpamPrefixListResolverVersionsRequest$ = exports2.GetIpamPrefixListResolverVersionEntriesResult$ = exports2.GetIpamPrefixListResolverVersionEntriesRequest$ = exports2.GetIpamPrefixListResolverRulesResult$ = void 0;
    exports2.ImageUsageReportEntry$ = exports2.ImageUsageReport$ = exports2.ImageReference$ = exports2.ImageRecycleBinInfo$ = exports2.ImageMetadata$ = exports2.ImageDiskContainer$ = exports2.ImageCriterionRequest$ = exports2.ImageCriterion$ = exports2.ImageAttribute$ = exports2.ImageAncestryEntry$ = exports2.Image$ = exports2.IKEVersionsRequestListValue$ = exports2.IKEVersionsListValue$ = exports2.IdFormat$ = exports2.IcmpTypeCode$ = exports2.IamInstanceProfileSpecification$ = exports2.IamInstanceProfileAssociation$ = exports2.IamInstanceProfile$ = exports2.HostReservation$ = exports2.HostProperties$ = exports2.HostOffering$ = exports2.HostInstance$ = exports2.Host$ = exports2.HistoryRecordEntry$ = exports2.HistoryRecord$ = exports2.HibernationOptionsRequest$ = exports2.HibernationOptions$ = exports2.GroupIdentifier$ = exports2.GpuInfo$ = exports2.GpuDeviceMemoryInfo$ = exports2.GpuDeviceInfo$ = exports2.GetVpnTunnelReplacementStatusResult$ = exports2.GetVpnTunnelReplacementStatusRequest$ = exports2.GetVpnConnectionDeviceTypesResult$ = exports2.GetVpnConnectionDeviceTypesRequest$ = exports2.GetVpnConnectionDeviceSampleConfigurationResult$ = exports2.GetVpnConnectionDeviceSampleConfigurationRequest$ = exports2.GetVpcResourcesBlockingEncryptionEnforcementResult$ = exports2.GetVpcResourcesBlockingEncryptionEnforcementRequest$ = exports2.GetVerifiedAccessGroupPolicyResult$ = exports2.GetVerifiedAccessGroupPolicyRequest$ = exports2.GetVerifiedAccessEndpointTargetsResult$ = exports2.GetVerifiedAccessEndpointTargetsRequest$ = exports2.GetVerifiedAccessEndpointPolicyResult$ = exports2.GetVerifiedAccessEndpointPolicyRequest$ = exports2.GetTransitGatewayRouteTablePropagationsResult$ = exports2.GetTransitGatewayRouteTablePropagationsRequest$ = exports2.GetTransitGatewayRouteTableAssociationsResult$ = exports2.GetTransitGatewayRouteTableAssociationsRequest$ = exports2.GetTransitGatewayPrefixListReferencesResult$ = void 0;
    exports2.InstanceImageMetadata$ = exports2.InstanceFamilyCreditSpecification$ = exports2.InstanceExportDetails$ = exports2.InstanceEventWindowTimeRangeRequest$ = exports2.InstanceEventWindowTimeRange$ = exports2.InstanceEventWindowStateChange$ = exports2.InstanceEventWindowDisassociationRequest$ = exports2.InstanceEventWindowAssociationTarget$ = exports2.InstanceEventWindowAssociationRequest$ = exports2.InstanceEventWindow$ = exports2.InstanceCreditSpecificationRequest$ = exports2.InstanceCreditSpecification$ = exports2.InstanceCount$ = exports2.InstanceConnectEndpointPublicDnsNames$ = exports2.InstanceConnectEndpointDnsNames$ = exports2.InstanceCapacity$ = exports2.InstanceBlockDeviceMappingSpecification$ = exports2.InstanceBlockDeviceMapping$ = exports2.InstanceAttribute$ = exports2.InstanceAttachmentEnaSrdUdpSpecification$ = exports2.InstanceAttachmentEnaSrdSpecification$ = exports2.Instance$ = exports2.InitializationStatusDetails$ = exports2.InferenceDeviceMemoryInfo$ = exports2.InferenceDeviceInfo$ = exports2.InferenceAcceleratorInfo$ = exports2.ImportVolumeTaskDetails$ = exports2.ImportVolumeResult$ = exports2.ImportVolumeRequest$ = exports2.ImportSnapshotTask$ = exports2.ImportSnapshotResult$ = exports2.ImportSnapshotRequest$ = exports2.ImportKeyPairResult$ = exports2.ImportKeyPairRequest$ = exports2.ImportInstanceVolumeDetailItem$ = exports2.ImportInstanceTaskDetails$ = exports2.ImportInstanceResult$ = exports2.ImportInstanceRequest$ = exports2.ImportInstanceLaunchSpecification$ = exports2.ImportImageTask$ = exports2.ImportImageResult$ = exports2.ImportImageRequest$ = exports2.ImportImageLicenseConfigurationResponse$ = exports2.ImportImageLicenseConfigurationRequest$ = exports2.ImportClientVpnClientCertificateRevocationListResult$ = exports2.ImportClientVpnClientCertificateRevocationListRequest$ = exports2.ImageUsageResourceTypeRequest$ = exports2.ImageUsageResourceTypeOptionRequest$ = exports2.ImageUsageResourceTypeOption$ = exports2.ImageUsageResourceType$ = void 0;
    exports2.IpamDiscoveredPublicAddress$ = exports2.IpamDiscoveredAccount$ = exports2.IpamCidrAuthorizationContext$ = exports2.IpamAddressHistoryRecord$ = exports2.Ipam$ = exports2.InterruptionInfo$ = exports2.InterruptibleCapacityAllocation$ = exports2.InternetGatewayAttachment$ = exports2.InternetGateway$ = exports2.IntegrateServices$ = exports2.InstanceUsage$ = exports2.InstanceTypeOffering$ = exports2.InstanceTypeInfoFromInstanceRequirements$ = exports2.InstanceTypeInfo$ = exports2.InstanceTopology$ = exports2.InstanceTagNotificationAttribute$ = exports2.InstanceStorageInfo$ = exports2.InstanceStatusSummary$ = exports2.InstanceStatusEvent$ = exports2.InstanceStatusDetails$ = exports2.InstanceStatus$ = exports2.InstanceStateChange$ = exports2.InstanceState$ = exports2.InstanceSpecification$ = exports2.InstanceSecondaryInterfaceSpecificationRequest$ = exports2.InstanceSecondaryInterfacePrivateIpAddressRequest$ = exports2.InstanceSecondaryInterfacePrivateIpAddress$ = exports2.InstanceSecondaryInterfaceAttachment$ = exports2.InstanceSecondaryInterface$ = exports2.InstanceRequirementsWithMetadataRequest$ = exports2.InstanceRequirementsRequest$ = exports2.InstanceRequirements$ = exports2.InstancePrivateIpAddress$ = exports2.InstanceNetworkPerformanceOptionsRequest$ = exports2.InstanceNetworkPerformanceOptions$ = exports2.InstanceNetworkInterfaceSpecification$ = exports2.InstanceNetworkInterfaceAttachment$ = exports2.InstanceNetworkInterfaceAssociation$ = exports2.InstanceNetworkInterface$ = exports2.InstanceMonitoring$ = exports2.InstanceMetadataOptionsResponse$ = exports2.InstanceMetadataOptionsRequest$ = exports2.InstanceMetadataDefaultsResponse$ = exports2.InstanceMarketOptionsRequest$ = exports2.InstanceMaintenanceOptionsRequest$ = exports2.InstanceMaintenanceOptions$ = exports2.InstanceIpv6Prefix$ = exports2.InstanceIpv6AddressRequest$ = exports2.InstanceIpv6Address$ = exports2.InstanceIpv4Prefix$ = void 0;
    exports2.LaunchPermissionModifications$ = exports2.LaunchPermission$ = exports2.LastError$ = exports2.KeyPairInfo$ = exports2.KeyPair$ = exports2.Ipv6Range$ = exports2.Ipv6PrefixSpecificationResponse$ = exports2.Ipv6PrefixSpecificationRequest$ = exports2.Ipv6PrefixSpecification$ = exports2.Ipv6Pool$ = exports2.Ipv6CidrBlock$ = exports2.Ipv6CidrAssociation$ = exports2.Ipv4PrefixSpecificationResponse$ = exports2.Ipv4PrefixSpecificationRequest$ = exports2.Ipv4PrefixSpecification$ = exports2.IpRange$ = exports2.IpPermission$ = exports2.IpamScopeExternalAuthorityConfiguration$ = exports2.IpamScope$ = exports2.IpamResourceTag$ = exports2.IpamResourceDiscoveryAssociation$ = exports2.IpamResourceDiscovery$ = exports2.IpamResourceCidr$ = exports2.IpamPublicAddressTags$ = exports2.IpamPublicAddressTag$ = exports2.IpamPublicAddressSecurityGroup$ = exports2.IpamPrefixListResolverVersionEntry$ = exports2.IpamPrefixListResolverVersion$ = exports2.IpamPrefixListResolverTarget$ = exports2.IpamPrefixListResolverRuleRequest$ = exports2.IpamPrefixListResolverRuleConditionRequest$ = exports2.IpamPrefixListResolverRuleCondition$ = exports2.IpamPrefixListResolverRule$ = exports2.IpamPrefixListResolver$ = exports2.IpamPoolSourceResourceRequest$ = exports2.IpamPoolSourceResource$ = exports2.IpamPoolCidrFailureReason$ = exports2.IpamPoolCidr$ = exports2.IpamPoolAllocation$ = exports2.IpamPool$ = exports2.IpamPolicyOrganizationTarget$ = exports2.IpamPolicyDocument$ = exports2.IpamPolicyAllocationRuleRequest$ = exports2.IpamPolicyAllocationRule$ = exports2.IpamPolicy$ = exports2.IpamOrganizationalUnitExclusion$ = exports2.IpamOperatingRegion$ = exports2.IpamExternalResourceVerificationToken$ = exports2.IpamDiscoveryFailureReason$ = exports2.IpamDiscoveredResourceCidr$ = void 0;
    exports2.LicenseConfiguration$ = exports2.LaunchTemplateVersion$ = exports2.LaunchTemplateTagSpecificationRequest$ = exports2.LaunchTemplateTagSpecification$ = exports2.LaunchTemplateSpotMarketOptionsRequest$ = exports2.LaunchTemplateSpotMarketOptions$ = exports2.LaunchTemplateSpecification$ = exports2.LaunchTemplatesMonitoringRequest$ = exports2.LaunchTemplatesMonitoring$ = exports2.LaunchTemplatePrivateDnsNameOptionsRequest$ = exports2.LaunchTemplatePrivateDnsNameOptions$ = exports2.LaunchTemplatePlacementRequest$ = exports2.LaunchTemplatePlacement$ = exports2.LaunchTemplateOverrides$ = exports2.LaunchTemplateNetworkPerformanceOptionsRequest$ = exports2.LaunchTemplateNetworkPerformanceOptions$ = exports2.LaunchTemplateLicenseConfigurationRequest$ = exports2.LaunchTemplateLicenseConfiguration$ = exports2.LaunchTemplateInstanceSecondaryInterfaceSpecificationRequest$ = exports2.LaunchTemplateInstanceSecondaryInterfaceSpecification$ = exports2.LaunchTemplateInstanceNetworkInterfaceSpecificationRequest$ = exports2.LaunchTemplateInstanceNetworkInterfaceSpecification$ = exports2.LaunchTemplateInstanceMetadataOptionsRequest$ = exports2.LaunchTemplateInstanceMetadataOptions$ = exports2.LaunchTemplateInstanceMarketOptionsRequest$ = exports2.LaunchTemplateInstanceMarketOptions$ = exports2.LaunchTemplateInstanceMaintenanceOptionsRequest$ = exports2.LaunchTemplateInstanceMaintenanceOptions$ = exports2.LaunchTemplateIamInstanceProfileSpecificationRequest$ = exports2.LaunchTemplateIamInstanceProfileSpecification$ = exports2.LaunchTemplateHibernationOptionsRequest$ = exports2.LaunchTemplateHibernationOptions$ = exports2.LaunchTemplateEnclaveOptionsRequest$ = exports2.LaunchTemplateEnclaveOptions$ = exports2.LaunchTemplateEnaSrdUdpSpecification$ = exports2.LaunchTemplateEnaSrdSpecification$ = exports2.LaunchTemplateElasticInferenceAcceleratorResponse$ = exports2.LaunchTemplateElasticInferenceAccelerator$ = exports2.LaunchTemplateEbsBlockDeviceRequest$ = exports2.LaunchTemplateEbsBlockDevice$ = exports2.LaunchTemplateCpuOptionsRequest$ = exports2.LaunchTemplateCpuOptions$ = exports2.LaunchTemplateConfig$ = exports2.LaunchTemplateCapacityReservationSpecificationResponse$ = exports2.LaunchTemplateCapacityReservationSpecificationRequest$ = exports2.LaunchTemplateBlockDeviceMappingRequest$ = exports2.LaunchTemplateBlockDeviceMapping$ = exports2.LaunchTemplateAndOverridesResponse$ = exports2.LaunchTemplate$ = exports2.LaunchSpecification$ = void 0;
    exports2.ModifyDefaultCreditSpecificationRequest$ = exports2.ModifyClientVpnEndpointResult$ = exports2.ModifyClientVpnEndpointRequest$ = exports2.ModifyCapacityReservationResult$ = exports2.ModifyCapacityReservationRequest$ = exports2.ModifyCapacityReservationFleetResult$ = exports2.ModifyCapacityReservationFleetRequest$ = exports2.ModifyAvailabilityZoneGroupResult$ = exports2.ModifyAvailabilityZoneGroupRequest$ = exports2.ModifyAddressAttributeResult$ = exports2.ModifyAddressAttributeRequest$ = exports2.MetricValue$ = exports2.MetricPoint$ = exports2.MetricDataResult$ = exports2.MemoryMiBRequest$ = exports2.MemoryMiB$ = exports2.MemoryInfo$ = exports2.MemoryGiBPerVCpuRequest$ = exports2.MemoryGiBPerVCpu$ = exports2.MediaDeviceMemoryInfo$ = exports2.MediaDeviceInfo$ = exports2.MediaAcceleratorInfo$ = exports2.ManagedResourceVisibilitySettings$ = exports2.ManagedPrefixList$ = exports2.MaintenanceDetails$ = exports2.MacSystemIntegrityProtectionConfigurationRequest$ = exports2.MacSystemIntegrityProtectionConfiguration$ = exports2.MacModificationTask$ = exports2.MacHost$ = exports2.LockSnapshotResult$ = exports2.LockSnapshotRequest$ = exports2.LockedSnapshotsInfo$ = exports2.LocalGatewayVirtualInterfaceGroup$ = exports2.LocalGatewayVirtualInterface$ = exports2.LocalGatewayRouteTableVpcAssociation$ = exports2.LocalGatewayRouteTableVirtualInterfaceGroupAssociation$ = exports2.LocalGatewayRouteTable$ = exports2.LocalGatewayRoute$ = exports2.LocalGateway$ = exports2.LoadPermissionRequest$ = exports2.LoadPermissionModifications$ = exports2.LoadPermission$ = exports2.LoadBalancersConfig$ = exports2.ListVolumesInRecycleBinResult$ = exports2.ListVolumesInRecycleBinRequest$ = exports2.ListSnapshotsInRecycleBinResult$ = exports2.ListSnapshotsInRecycleBinRequest$ = exports2.ListImagesInRecycleBinResult$ = exports2.ListImagesInRecycleBinRequest$ = exports2.LicenseConfigurationRequest$ = void 0;
    exports2.ModifyIpamScopeRequest$ = exports2.ModifyIpamResult$ = exports2.ModifyIpamResourceDiscoveryResult$ = exports2.ModifyIpamResourceDiscoveryRequest$ = exports2.ModifyIpamResourceCidrResult$ = exports2.ModifyIpamResourceCidrRequest$ = exports2.ModifyIpamRequest$ = exports2.ModifyIpamPrefixListResolverTargetResult$ = exports2.ModifyIpamPrefixListResolverTargetRequest$ = exports2.ModifyIpamPrefixListResolverResult$ = exports2.ModifyIpamPrefixListResolverRequest$ = exports2.ModifyIpamPoolResult$ = exports2.ModifyIpamPoolRequest$ = exports2.ModifyIpamPolicyAllocationRulesResult$ = exports2.ModifyIpamPolicyAllocationRulesRequest$ = exports2.ModifyInstancePlacementResult$ = exports2.ModifyInstancePlacementRequest$ = exports2.ModifyInstanceNetworkPerformanceResult$ = exports2.ModifyInstanceNetworkPerformanceRequest$ = exports2.ModifyInstanceMetadataOptionsResult$ = exports2.ModifyInstanceMetadataOptionsRequest$ = exports2.ModifyInstanceMetadataDefaultsResult$ = exports2.ModifyInstanceMetadataDefaultsRequest$ = exports2.ModifyInstanceMaintenanceOptionsResult$ = exports2.ModifyInstanceMaintenanceOptionsRequest$ = exports2.ModifyInstanceEventWindowResult$ = exports2.ModifyInstanceEventWindowRequest$ = exports2.ModifyInstanceEventStartTimeResult$ = exports2.ModifyInstanceEventStartTimeRequest$ = exports2.ModifyInstanceCreditSpecificationResult$ = exports2.ModifyInstanceCreditSpecificationRequest$ = exports2.ModifyInstanceCpuOptionsResult$ = exports2.ModifyInstanceCpuOptionsRequest$ = exports2.ModifyInstanceConnectEndpointResult$ = exports2.ModifyInstanceConnectEndpointRequest$ = exports2.ModifyInstanceCapacityReservationAttributesResult$ = exports2.ModifyInstanceCapacityReservationAttributesRequest$ = exports2.ModifyInstanceAttributeRequest$ = exports2.ModifyImageAttributeRequest$ = exports2.ModifyIdFormatRequest$ = exports2.ModifyIdentityIdFormatRequest$ = exports2.ModifyHostsResult$ = exports2.ModifyHostsRequest$ = exports2.ModifyFpgaImageAttributeResult$ = exports2.ModifyFpgaImageAttributeRequest$ = exports2.ModifyFleetResult$ = exports2.ModifyFleetRequest$ = exports2.ModifyEbsDefaultKmsKeyIdResult$ = exports2.ModifyEbsDefaultKmsKeyIdRequest$ = exports2.ModifyDefaultCreditSpecificationResult$ = void 0;
    exports2.ModifyVerifiedAccessEndpointRequest$ = exports2.ModifyVerifiedAccessEndpointRdsOptions$ = exports2.ModifyVerifiedAccessEndpointPortRange$ = exports2.ModifyVerifiedAccessEndpointPolicyResult$ = exports2.ModifyVerifiedAccessEndpointPolicyRequest$ = exports2.ModifyVerifiedAccessEndpointLoadBalancerOptions$ = exports2.ModifyVerifiedAccessEndpointEniOptions$ = exports2.ModifyVerifiedAccessEndpointCidrOptions$ = exports2.ModifyTransitGatewayVpcAttachmentResult$ = exports2.ModifyTransitGatewayVpcAttachmentRequestOptions$ = exports2.ModifyTransitGatewayVpcAttachmentRequest$ = exports2.ModifyTransitGatewayResult$ = exports2.ModifyTransitGatewayRequest$ = exports2.ModifyTransitGatewayPrefixListReferenceResult$ = exports2.ModifyTransitGatewayPrefixListReferenceRequest$ = exports2.ModifyTransitGatewayOptions$ = exports2.ModifyTransitGatewayMeteringPolicyResult$ = exports2.ModifyTransitGatewayMeteringPolicyRequest$ = exports2.ModifyTrafficMirrorSessionResult$ = exports2.ModifyTrafficMirrorSessionRequest$ = exports2.ModifyTrafficMirrorFilterRuleResult$ = exports2.ModifyTrafficMirrorFilterRuleRequest$ = exports2.ModifyTrafficMirrorFilterNetworkServicesResult$ = exports2.ModifyTrafficMirrorFilterNetworkServicesRequest$ = exports2.ModifySubnetAttributeRequest$ = exports2.ModifySpotFleetRequestResponse$ = exports2.ModifySpotFleetRequestRequest$ = exports2.ModifySnapshotTierResult$ = exports2.ModifySnapshotTierRequest$ = exports2.ModifySnapshotAttributeRequest$ = exports2.ModifySecurityGroupRulesResult$ = exports2.ModifySecurityGroupRulesRequest$ = exports2.ModifyRouteServerResult$ = exports2.ModifyRouteServerRequest$ = exports2.ModifyReservedInstancesResult$ = exports2.ModifyReservedInstancesRequest$ = exports2.ModifyPublicIpDnsNameOptionsResult$ = exports2.ModifyPublicIpDnsNameOptionsRequest$ = exports2.ModifyPrivateDnsNameOptionsResult$ = exports2.ModifyPrivateDnsNameOptionsRequest$ = exports2.ModifyNetworkInterfaceAttributeRequest$ = exports2.ModifyManagedResourceVisibilityResult$ = exports2.ModifyManagedResourceVisibilityRequest$ = exports2.ModifyManagedPrefixListResult$ = exports2.ModifyManagedPrefixListRequest$ = exports2.ModifyLocalGatewayRouteResult$ = exports2.ModifyLocalGatewayRouteRequest$ = exports2.ModifyLaunchTemplateResult$ = exports2.ModifyLaunchTemplateRequest$ = exports2.ModifyIpamScopeResult$ = void 0;
    exports2.MonitorInstancesResult$ = exports2.MonitorInstancesRequest$ = exports2.Monitoring$ = exports2.ModifyVpnTunnelOptionsSpecification$ = exports2.ModifyVpnTunnelOptionsResult$ = exports2.ModifyVpnTunnelOptionsRequest$ = exports2.ModifyVpnTunnelCertificateResult$ = exports2.ModifyVpnTunnelCertificateRequest$ = exports2.ModifyVpnConnectionResult$ = exports2.ModifyVpnConnectionRequest$ = exports2.ModifyVpnConnectionOptionsResult$ = exports2.ModifyVpnConnectionOptionsRequest$ = exports2.ModifyVpcTenancyResult$ = exports2.ModifyVpcTenancyRequest$ = exports2.ModifyVpcPeeringConnectionOptionsResult$ = exports2.ModifyVpcPeeringConnectionOptionsRequest$ = exports2.ModifyVpcEndpointServicePermissionsResult$ = exports2.ModifyVpcEndpointServicePermissionsRequest$ = exports2.ModifyVpcEndpointServicePayerResponsibilityResult$ = exports2.ModifyVpcEndpointServicePayerResponsibilityRequest$ = exports2.ModifyVpcEndpointServiceConfigurationResult$ = exports2.ModifyVpcEndpointServiceConfigurationRequest$ = exports2.ModifyVpcEndpointResult$ = exports2.ModifyVpcEndpointRequest$ = exports2.ModifyVpcEndpointConnectionNotificationResult$ = exports2.ModifyVpcEndpointConnectionNotificationRequest$ = exports2.ModifyVpcEncryptionControlResult$ = exports2.ModifyVpcEncryptionControlRequest$ = exports2.ModifyVpcBlockPublicAccessOptionsResult$ = exports2.ModifyVpcBlockPublicAccessOptionsRequest$ = exports2.ModifyVpcBlockPublicAccessExclusionResult$ = exports2.ModifyVpcBlockPublicAccessExclusionRequest$ = exports2.ModifyVpcAttributeRequest$ = exports2.ModifyVolumeResult$ = exports2.ModifyVolumeRequest$ = exports2.ModifyVolumeAttributeRequest$ = exports2.ModifyVerifiedAccessTrustProviderResult$ = exports2.ModifyVerifiedAccessTrustProviderRequest$ = exports2.ModifyVerifiedAccessTrustProviderOidcOptions$ = exports2.ModifyVerifiedAccessTrustProviderDeviceOptions$ = exports2.ModifyVerifiedAccessNativeApplicationOidcOptions$ = exports2.ModifyVerifiedAccessInstanceResult$ = exports2.ModifyVerifiedAccessInstanceRequest$ = exports2.ModifyVerifiedAccessInstanceLoggingConfigurationResult$ = exports2.ModifyVerifiedAccessInstanceLoggingConfigurationRequest$ = exports2.ModifyVerifiedAccessGroupResult$ = exports2.ModifyVerifiedAccessGroupRequest$ = exports2.ModifyVerifiedAccessGroupPolicyResult$ = exports2.ModifyVerifiedAccessGroupPolicyRequest$ = exports2.ModifyVerifiedAccessEndpointResult$ = void 0;
    exports2.PathRequestFilter$ = exports2.PathFilter$ = exports2.PathComponent$ = exports2.PacketHeaderStatementRequest$ = exports2.PacketHeaderStatement$ = exports2.OutpostLag$ = exports2.OperatorResponse$ = exports2.OperatorRequest$ = exports2.OnDemandOptionsRequest$ = exports2.OnDemandOptions$ = exports2.OidcOptions$ = exports2.NitroTpmInfo$ = exports2.NewDhcpConfiguration$ = exports2.NeuronInfo$ = exports2.NeuronDeviceMemoryInfo$ = exports2.NeuronDeviceInfo$ = exports2.NeuronDeviceCoreInfo$ = exports2.NetworkInterfacePrivateIpAddress$ = exports2.NetworkInterfacePermissionState$ = exports2.NetworkInterfacePermission$ = exports2.NetworkInterfaceIpv6Address$ = exports2.NetworkInterfaceCountRequest$ = exports2.NetworkInterfaceCount$ = exports2.NetworkInterfaceAttachmentChanges$ = exports2.NetworkInterfaceAttachment$ = exports2.NetworkInterfaceAssociation$ = exports2.NetworkInterface$ = exports2.NetworkInsightsPath$ = exports2.NetworkInsightsAnalysis$ = exports2.NetworkInsightsAccessScopeContent$ = exports2.NetworkInsightsAccessScopeAnalysis$ = exports2.NetworkInsightsAccessScope$ = exports2.NetworkInfo$ = exports2.NetworkCardInfo$ = exports2.NetworkBandwidthGbpsRequest$ = exports2.NetworkBandwidthGbps$ = exports2.NetworkAclEntry$ = exports2.NetworkAclAssociation$ = exports2.NetworkAcl$ = exports2.NativeApplicationOidcOptions$ = exports2.NatGatewayAttachedAppliance$ = exports2.NatGatewayAddress$ = exports2.NatGateway$ = exports2.MovingAddressStatus$ = exports2.MoveCapacityReservationInstancesResult$ = exports2.MoveCapacityReservationInstancesRequest$ = exports2.MoveByoipCidrToIpamResult$ = exports2.MoveByoipCidrToIpamRequest$ = exports2.MoveAddressToVpcResult$ = exports2.MoveAddressToVpcRequest$ = void 0;
    exports2.ProvisionIpamPoolCidrRequest$ = exports2.ProvisionIpamByoasnResult$ = exports2.ProvisionIpamByoasnRequest$ = exports2.ProvisionedBandwidth$ = exports2.ProvisionByoipCidrResult$ = exports2.ProvisionByoipCidrRequest$ = exports2.PropagatingVgw$ = exports2.ProductCode$ = exports2.ProcessorInfo$ = exports2.PrivateIpAddressSpecification$ = exports2.PrivateDnsNameOptionsResponse$ = exports2.PrivateDnsNameOptionsRequest$ = exports2.PrivateDnsNameOptionsOnLaunch$ = exports2.PrivateDnsNameConfiguration$ = exports2.PrivateDnsDetails$ = exports2.PrincipalIdFormat$ = exports2.PricingDetail$ = exports2.PriceScheduleSpecification$ = exports2.PriceSchedule$ = exports2.PrefixListId$ = exports2.PrefixListEntry$ = exports2.PrefixListAssociation$ = exports2.PrefixList$ = exports2.PortRange$ = exports2.PoolCidrBlock$ = exports2.PlacementResponse$ = exports2.PlacementGroupInfo$ = exports2.PlacementGroup$ = exports2.Placement$ = exports2.Phase2IntegrityAlgorithmsRequestListValue$ = exports2.Phase2IntegrityAlgorithmsListValue$ = exports2.Phase2EncryptionAlgorithmsRequestListValue$ = exports2.Phase2EncryptionAlgorithmsListValue$ = exports2.Phase2DHGroupNumbersRequestListValue$ = exports2.Phase2DHGroupNumbersListValue$ = exports2.Phase1IntegrityAlgorithmsRequestListValue$ = exports2.Phase1IntegrityAlgorithmsListValue$ = exports2.Phase1EncryptionAlgorithmsRequestListValue$ = exports2.Phase1EncryptionAlgorithmsListValue$ = exports2.Phase1DHGroupNumbersRequestListValue$ = exports2.Phase1DHGroupNumbersListValue$ = exports2.PerformanceFactorReferenceRequest$ = exports2.PerformanceFactorReference$ = exports2.PeeringTgwInfo$ = exports2.PeeringConnectionOptionsRequest$ = exports2.PeeringConnectionOptions$ = exports2.PeeringAttachmentStatus$ = exports2.PciId$ = exports2.PathStatementRequest$ = exports2.PathStatement$ = void 0;
    exports2.ReleaseAddressRequest$ = exports2.RejectVpcPeeringConnectionResult$ = exports2.RejectVpcPeeringConnectionRequest$ = exports2.RejectVpcEndpointConnectionsResult$ = exports2.RejectVpcEndpointConnectionsRequest$ = exports2.RejectTransitGatewayVpcAttachmentResult$ = exports2.RejectTransitGatewayVpcAttachmentRequest$ = exports2.RejectTransitGatewayPeeringAttachmentResult$ = exports2.RejectTransitGatewayPeeringAttachmentRequest$ = exports2.RejectTransitGatewayMulticastDomainAssociationsResult$ = exports2.RejectTransitGatewayMulticastDomainAssociationsRequest$ = exports2.RejectTransitGatewayClientVpnAttachmentResult$ = exports2.RejectTransitGatewayClientVpnAttachmentRequest$ = exports2.RejectCapacityReservationBillingOwnershipResult$ = exports2.RejectCapacityReservationBillingOwnershipRequest$ = exports2.RegisterTransitGatewayMulticastGroupSourcesResult$ = exports2.RegisterTransitGatewayMulticastGroupSourcesRequest$ = exports2.RegisterTransitGatewayMulticastGroupMembersResult$ = exports2.RegisterTransitGatewayMulticastGroupMembersRequest$ = exports2.RegisterInstanceTagAttributeRequest$ = exports2.RegisterInstanceEventNotificationAttributesResult$ = exports2.RegisterInstanceEventNotificationAttributesRequest$ = exports2.RegisterImageResult$ = exports2.RegisterImageRequest$ = exports2.RegisteredInstance$ = exports2.RegionGeography$ = exports2.RegionalSummary$ = exports2.Region$ = exports2.ReferencedSecurityGroup$ = exports2.RecurringCharge$ = exports2.RebootInstancesRequest$ = exports2.PurchaseScheduledInstancesResult$ = exports2.PurchaseScheduledInstancesRequest$ = exports2.PurchaseReservedInstancesOfferingResult$ = exports2.PurchaseReservedInstancesOfferingRequest$ = exports2.PurchaseRequest$ = exports2.PurchaseHostReservationResult$ = exports2.PurchaseHostReservationRequest$ = exports2.PurchaseCapacityBlockResult$ = exports2.PurchaseCapacityBlockRequest$ = exports2.PurchaseCapacityBlockExtensionResult$ = exports2.PurchaseCapacityBlockExtensionRequest$ = exports2.Purchase$ = exports2.PublicIpv4PoolRange$ = exports2.PublicIpv4Pool$ = exports2.PublicIpDnsNameOptions$ = exports2.PtrUpdateStatus$ = exports2.ProvisionPublicIpv4PoolCidrResult$ = exports2.ProvisionPublicIpv4PoolCidrRequest$ = exports2.ProvisionIpamPoolCidrResult$ = void 0;
    exports2.ResetFpgaImageAttributeRequest$ = exports2.ResetEbsDefaultKmsKeyIdResult$ = exports2.ResetEbsDefaultKmsKeyIdRequest$ = exports2.ResetAddressAttributeResult$ = exports2.ResetAddressAttributeRequest$ = exports2.ReservedInstancesOffering$ = exports2.ReservedInstancesModificationResult$ = exports2.ReservedInstancesModification$ = exports2.ReservedInstancesListing$ = exports2.ReservedInstancesId$ = exports2.ReservedInstancesConfiguration$ = exports2.ReservedInstances$ = exports2.ReservedInstanceReservationValue$ = exports2.ReservedInstanceLimitPrice$ = exports2.ReservedCapacityOptionsRequest$ = exports2.ReservedCapacityOptions$ = exports2.ReservationValue$ = exports2.ReservationFleetInstanceSpecification$ = exports2.Reservation$ = exports2.RequestSpotLaunchSpecification$ = exports2.RequestSpotInstancesResult$ = exports2.RequestSpotInstancesRequest$ = exports2.RequestSpotFleetResponse$ = exports2.RequestSpotFleetRequest$ = exports2.RequestLaunchTemplateData$ = exports2.RequestIpamResourceTag$ = exports2.RequestFilterPortRange$ = exports2.ReportInstanceStatusRequest$ = exports2.ReplaceVpnTunnelResult$ = exports2.ReplaceVpnTunnelRequest$ = exports2.ReplaceTransitGatewayRouteResult$ = exports2.ReplaceTransitGatewayRouteRequest$ = exports2.ReplaceRouteTableAssociationResult$ = exports2.ReplaceRouteTableAssociationRequest$ = exports2.ReplaceRouteRequest$ = exports2.ReplaceRootVolumeTask$ = exports2.ReplaceNetworkAclEntryRequest$ = exports2.ReplaceNetworkAclAssociationResult$ = exports2.ReplaceNetworkAclAssociationRequest$ = exports2.ReplaceImageCriteriaInAllowedImagesSettingsResult$ = exports2.ReplaceImageCriteriaInAllowedImagesSettingsRequest$ = exports2.ReplaceIamInstanceProfileAssociationResult$ = exports2.ReplaceIamInstanceProfileAssociationRequest$ = exports2.RemovePrefixListEntry$ = exports2.RemoveIpamOrganizationalUnitExclusion$ = exports2.RemoveIpamOperatingRegion$ = exports2.ReleaseIpamPoolAllocationResult$ = exports2.ReleaseIpamPoolAllocationRequest$ = exports2.ReleaseHostsResult$ = exports2.ReleaseHostsRequest$ = void 0;
    exports2.RunInstancesRequest$ = exports2.RunInstancesMonitoringEnabled$ = exports2.RuleOption$ = exports2.RuleGroupTypePair$ = exports2.RuleGroupRuleOptionsPair$ = exports2.RouteTableAssociationState$ = exports2.RouteTableAssociation$ = exports2.RouteTable$ = exports2.RouteServerRouteInstallationDetail$ = exports2.RouteServerRoute$ = exports2.RouteServerPropagation$ = exports2.RouteServerPeer$ = exports2.RouteServerEndpoint$ = exports2.RouteServerBgpStatus$ = exports2.RouteServerBgpOptionsRequest$ = exports2.RouteServerBgpOptions$ = exports2.RouteServerBfdStatus$ = exports2.RouteServerAssociation$ = exports2.RouteServer$ = exports2.Route$ = exports2.RevokeSecurityGroupIngressResult$ = exports2.RevokeSecurityGroupIngressRequest$ = exports2.RevokeSecurityGroupEgressResult$ = exports2.RevokeSecurityGroupEgressRequest$ = exports2.RevokedSecurityGroupRule$ = exports2.RevokeClientVpnIngressResult$ = exports2.RevokeClientVpnIngressRequest$ = exports2.RestoreVolumeFromRecycleBinResult$ = exports2.RestoreVolumeFromRecycleBinRequest$ = exports2.RestoreSnapshotTierResult$ = exports2.RestoreSnapshotTierRequest$ = exports2.RestoreSnapshotFromRecycleBinResult$ = exports2.RestoreSnapshotFromRecycleBinRequest$ = exports2.RestoreManagedPrefixListVersionResult$ = exports2.RestoreManagedPrefixListVersionRequest$ = exports2.RestoreImageFromRecycleBinResult$ = exports2.RestoreImageFromRecycleBinRequest$ = exports2.RestoreAddressToClassicResult$ = exports2.RestoreAddressToClassicRequest$ = exports2.ResponseLaunchTemplateData$ = exports2.ResponseError$ = exports2.ResourceTypeRequest$ = exports2.ResourceTypeOption$ = exports2.ResourceStatementRequest$ = exports2.ResourceStatement$ = exports2.ResetSnapshotAttributeRequest$ = exports2.ResetNetworkInterfaceAttributeRequest$ = exports2.ResetInstanceAttributeRequest$ = exports2.ResetImageAttributeRequest$ = exports2.ResetFpgaImageAttributeResult$ = void 0;
    exports2.SnapshotDetail$ = exports2.Snapshot$ = exports2.SlotStartTimeRangeRequest$ = exports2.SlotDateTimeRangeRequest$ = exports2.ServiceTypeDetail$ = exports2.ServiceLinkVirtualInterface$ = exports2.ServiceDetail$ = exports2.ServiceConfiguration$ = exports2.SendDiagnosticInterruptRequest$ = exports2.SecurityGroupVpcAssociation$ = exports2.SecurityGroupRuleUpdate$ = exports2.SecurityGroupRuleRequest$ = exports2.SecurityGroupRuleDescription$ = exports2.SecurityGroupRule$ = exports2.SecurityGroupReference$ = exports2.SecurityGroupIdentifier$ = exports2.SecurityGroupForVpc$ = exports2.SecurityGroup$ = exports2.SecondarySubnetIpv4CidrBlockAssociation$ = exports2.SecondarySubnet$ = exports2.SecondaryNetworkIpv4CidrBlockAssociation$ = exports2.SecondaryNetwork$ = exports2.SecondaryInterfacePrivateIpAddressSpecificationRequest$ = exports2.SecondaryInterfacePrivateIpAddressSpecification$ = exports2.SecondaryInterfaceIpv4Address$ = exports2.SecondaryInterfaceAttachment$ = exports2.SecondaryInterface$ = exports2.SearchTransitGatewayRoutesResult$ = exports2.SearchTransitGatewayRoutesRequest$ = exports2.SearchTransitGatewayMulticastGroupsResult$ = exports2.SearchTransitGatewayMulticastGroupsRequest$ = exports2.SearchLocalGatewayRoutesResult$ = exports2.SearchLocalGatewayRoutesRequest$ = exports2.ScheduledInstancesPrivateIpAddressConfig$ = exports2.ScheduledInstancesPlacement$ = exports2.ScheduledInstancesNetworkInterface$ = exports2.ScheduledInstancesMonitoring$ = exports2.ScheduledInstancesLaunchSpecification$ = exports2.ScheduledInstancesIpv6Address$ = exports2.ScheduledInstancesIamInstanceProfile$ = exports2.ScheduledInstancesEbs$ = exports2.ScheduledInstancesBlockDeviceMapping$ = exports2.ScheduledInstanceRecurrenceRequest$ = exports2.ScheduledInstanceRecurrence$ = exports2.ScheduledInstanceAvailability$ = exports2.ScheduledInstance$ = exports2.S3Storage$ = exports2.S3ObjectTag$ = exports2.RunScheduledInstancesResult$ = exports2.RunScheduledInstancesRequest$ = void 0;
    exports2.SuccessfulQueuedPurchaseDeletion$ = exports2.SuccessfulInstanceCreditSpecificationItem$ = exports2.Subscription$ = exports2.SubnetIpv6CidrBlockAssociation$ = exports2.SubnetIpPrefixes$ = exports2.SubnetConfiguration$ = exports2.SubnetCidrReservation$ = exports2.SubnetCidrBlockState$ = exports2.SubnetAssociation$ = exports2.Subnet$ = exports2.StoreImageTaskResult$ = exports2.StorageLocation$ = exports2.Storage$ = exports2.StopInstancesResult$ = exports2.StopInstancesRequest$ = exports2.StateReason$ = exports2.StartVpcEndpointServicePrivateDnsVerificationResult$ = exports2.StartVpcEndpointServicePrivateDnsVerificationRequest$ = exports2.StartNetworkInsightsAnalysisResult$ = exports2.StartNetworkInsightsAnalysisRequest$ = exports2.StartNetworkInsightsAccessScopeAnalysisResult$ = exports2.StartNetworkInsightsAccessScopeAnalysisRequest$ = exports2.StartInstancesResult$ = exports2.StartInstancesRequest$ = exports2.StartDeclarativePoliciesReportResult$ = exports2.StartDeclarativePoliciesReportRequest$ = exports2.StaleSecurityGroup$ = exports2.StaleIpPermission$ = exports2.SpotPrice$ = exports2.SpotPlacementScore$ = exports2.SpotPlacement$ = exports2.SpotOptionsRequest$ = exports2.SpotOptions$ = exports2.SpotMarketOptions$ = exports2.SpotMaintenanceStrategies$ = exports2.SpotInstanceStatus$ = exports2.SpotInstanceStateFault$ = exports2.SpotInstanceRequest$ = exports2.SpotFleetTagSpecification$ = exports2.SpotFleetRequestConfigData$ = exports2.SpotFleetRequestConfig$ = exports2.SpotFleetMonitoring$ = exports2.SpotFleetLaunchSpecification$ = exports2.SpotDatafeedSubscription$ = exports2.SpotCapacityRebalance$ = exports2.SnapshotTierStatus$ = exports2.SnapshotTaskDetail$ = exports2.SnapshotRecycleBinInfo$ = exports2.SnapshotInfo$ = exports2.SnapshotDiskContainer$ = void 0;
    exports2.TransitGatewayMulticastDomainOptions$ = exports2.TransitGatewayMulticastDomainAssociations$ = exports2.TransitGatewayMulticastDomainAssociation$ = exports2.TransitGatewayMulticastDomain$ = exports2.TransitGatewayMulticastDeregisteredGroupSources$ = exports2.TransitGatewayMulticastDeregisteredGroupMembers$ = exports2.TransitGatewayMeteringPolicyRule$ = exports2.TransitGatewayMeteringPolicyEntry$ = exports2.TransitGatewayMeteringPolicy$ = exports2.TransitGatewayConnectRequestBgpOptions$ = exports2.TransitGatewayConnectPeerConfiguration$ = exports2.TransitGatewayConnectPeer$ = exports2.TransitGatewayConnectOptions$ = exports2.TransitGatewayConnect$ = exports2.TransitGatewayConfigurationInputStructure$ = exports2.TransitGatewayConfigurationDescribeEndpointStructure$ = exports2.TransitGatewayClientVpnAttachment$ = exports2.TransitGatewayAttachmentPropagation$ = exports2.TransitGatewayAttachmentBgpConfiguration$ = exports2.TransitGatewayAttachmentAssociation$ = exports2.TransitGatewayAttachment$ = exports2.TransitGatewayAssociation$ = exports2.TransitGateway$ = exports2.TrafficMirrorTarget$ = exports2.TrafficMirrorSession$ = exports2.TrafficMirrorPortRangeRequest$ = exports2.TrafficMirrorPortRange$ = exports2.TrafficMirrorFilterRule$ = exports2.TrafficMirrorFilter$ = exports2.TotalLocalStorageGBRequest$ = exports2.TotalLocalStorageGB$ = exports2.ThroughResourcesStatementRequest$ = exports2.ThroughResourcesStatement$ = exports2.TerminateInstancesResult$ = exports2.TerminateInstancesRequest$ = exports2.TerminateConnectionStatus$ = exports2.TerminateClientVpnConnectionsResult$ = exports2.TerminateClientVpnConnectionsRequest$ = exports2.TargetReservationValue$ = exports2.TargetNetwork$ = exports2.TargetGroupsConfig$ = exports2.TargetGroup$ = exports2.TargetConfigurationRequest$ = exports2.TargetConfiguration$ = exports2.TargetCapacitySpecificationRequest$ = exports2.TargetCapacitySpecification$ = exports2.TagSpecification$ = exports2.TagDescription$ = exports2.Tag$ = exports2.SupportedRegionDetail$ = void 0;
    exports2.UserBucket$ = exports2.UpdateSecurityGroupRuleDescriptionsIngressResult$ = exports2.UpdateSecurityGroupRuleDescriptionsIngressRequest$ = exports2.UpdateSecurityGroupRuleDescriptionsEgressResult$ = exports2.UpdateSecurityGroupRuleDescriptionsEgressRequest$ = exports2.UpdateInterruptibleCapacityReservationAllocationResult$ = exports2.UpdateInterruptibleCapacityReservationAllocationRequest$ = exports2.UpdateCapacityManagerOrganizationsAccessResult$ = exports2.UpdateCapacityManagerOrganizationsAccessRequest$ = exports2.UpdateCapacityManagerMonitoredTagKeysResult$ = exports2.UpdateCapacityManagerMonitoredTagKeysRequest$ = exports2.UnsuccessfulItemError$ = exports2.UnsuccessfulItem$ = exports2.UnsuccessfulInstanceCreditSpecificationItemError$ = exports2.UnsuccessfulInstanceCreditSpecificationItem$ = exports2.UnmonitorInstancesResult$ = exports2.UnmonitorInstancesRequest$ = exports2.UnlockSnapshotResult$ = exports2.UnlockSnapshotRequest$ = exports2.UnassignPrivateNatGatewayAddressResult$ = exports2.UnassignPrivateNatGatewayAddressRequest$ = exports2.UnassignPrivateIpAddressesRequest$ = exports2.UnassignIpv6AddressesResult$ = exports2.UnassignIpv6AddressesRequest$ = exports2.TunnelOption$ = exports2.TrunkInterfaceAssociation$ = exports2.TransitGatewayVpcAttachmentOptions$ = exports2.TransitGatewayVpcAttachment$ = exports2.TransitGatewayRouteTableRoute$ = exports2.TransitGatewayRouteTablePropagation$ = exports2.TransitGatewayRouteTableAssociation$ = exports2.TransitGatewayRouteTableAnnouncement$ = exports2.TransitGatewayRouteTable$ = exports2.TransitGatewayRouteAttachment$ = exports2.TransitGatewayRoute$ = exports2.TransitGatewayRequestOptions$ = exports2.TransitGatewayPropagation$ = exports2.TransitGatewayPrefixListReference$ = exports2.TransitGatewayPrefixListAttachment$ = exports2.TransitGatewayPolicyTableEntry$ = exports2.TransitGatewayPolicyTableAssociation$ = exports2.TransitGatewayPolicyTable$ = exports2.TransitGatewayPolicyRuleMetaData$ = exports2.TransitGatewayPolicyRule$ = exports2.TransitGatewayPeeringAttachmentOptions$ = exports2.TransitGatewayPeeringAttachment$ = exports2.TransitGatewayOptions$ = exports2.TransitGatewayMulticastRegisteredGroupSources$ = exports2.TransitGatewayMulticastRegisteredGroupMembers$ = exports2.TransitGatewayMulticastGroup$ = void 0;
    exports2.VpcAttachment$ = exports2.Vpc$ = exports2.VolumeStatusItem$ = exports2.VolumeStatusInfo$ = exports2.VolumeStatusEvent$ = exports2.VolumeStatusDetails$ = exports2.VolumeStatusAttachmentStatus$ = exports2.VolumeStatusAction$ = exports2.VolumeRecycleBinInfo$ = exports2.VolumeModification$ = exports2.VolumeDetail$ = exports2.VolumeAttachment$ = exports2.Volume$ = exports2.VgwTelemetry$ = exports2.VerifiedAccessTrustProviderCondensed$ = exports2.VerifiedAccessTrustProvider$ = exports2.VerifiedAccessSseSpecificationResponse$ = exports2.VerifiedAccessSseSpecificationRequest$ = exports2.VerifiedAccessLogS3DestinationOptions$ = exports2.VerifiedAccessLogS3Destination$ = exports2.VerifiedAccessLogs$ = exports2.VerifiedAccessLogOptions$ = exports2.VerifiedAccessLogKinesisDataFirehoseDestinationOptions$ = exports2.VerifiedAccessLogKinesisDataFirehoseDestination$ = exports2.VerifiedAccessLogDeliveryStatus$ = exports2.VerifiedAccessLogCloudWatchLogsDestinationOptions$ = exports2.VerifiedAccessLogCloudWatchLogsDestination$ = exports2.VerifiedAccessInstanceUserTrustProviderClientConfiguration$ = exports2.VerifiedAccessInstanceOpenVpnClientConfigurationRoute$ = exports2.VerifiedAccessInstanceOpenVpnClientConfiguration$ = exports2.VerifiedAccessInstanceLoggingConfiguration$ = exports2.VerifiedAccessInstanceCustomSubDomain$ = exports2.VerifiedAccessInstance$ = exports2.VerifiedAccessGroup$ = exports2.VerifiedAccessEndpointTarget$ = exports2.VerifiedAccessEndpointStatus$ = exports2.VerifiedAccessEndpointRdsOptions$ = exports2.VerifiedAccessEndpointPortRange$ = exports2.VerifiedAccessEndpointLoadBalancerOptions$ = exports2.VerifiedAccessEndpointEniOptions$ = exports2.VerifiedAccessEndpointCidrOptions$ = exports2.VerifiedAccessEndpoint$ = exports2.VCpuInfo$ = exports2.VCpuCountRangeRequest$ = exports2.VCpuCountRange$ = exports2.ValidationWarning$ = exports2.ValidationError$ = exports2.UserIdGroupPair$ = exports2.UserData$ = exports2.UserBucketDetails$ = void 0;
    exports2.AssociateClientVpnTargetNetwork$ = exports2.AssociateCapacityReservationBillingOwner$ = exports2.AssociateAddress$ = exports2.AssignPrivateNatGatewayAddress$ = exports2.AssignPrivateIpAddresses$ = exports2.AssignIpv6Addresses$ = exports2.ApplySecurityGroupsToClientVpnTargetNetwork$ = exports2.AllocateIpamPoolCidr$ = exports2.AllocateHosts$ = exports2.AllocateAddress$ = exports2.AdvertiseByoipCidr$ = exports2.AcceptVpcPeeringConnection$ = exports2.AcceptVpcEndpointConnections$ = exports2.AcceptTransitGatewayVpcAttachment$ = exports2.AcceptTransitGatewayPeeringAttachment$ = exports2.AcceptTransitGatewayMulticastDomainAssociations$ = exports2.AcceptTransitGatewayClientVpnAttachment$ = exports2.AcceptReservedInstancesExchangeQuote$ = exports2.AcceptCapacityReservationBillingOwnership$ = exports2.AcceptAddressTransfer$ = exports2.WithdrawByoipCidrResult$ = exports2.WithdrawByoipCidrRequest$ = exports2.VpnTunnelOptionsSpecification$ = exports2.VpnTunnelLogOptionsSpecification$ = exports2.VpnTunnelLogOptions$ = exports2.VpnStaticRoute$ = exports2.VpnGateway$ = exports2.VpnConnectionOptionsSpecification$ = exports2.VpnConnectionOptions$ = exports2.VpnConnectionDeviceType$ = exports2.VpnConnection$ = exports2.VpnConcentrator$ = exports2.VpcPeeringConnectionVpcInfo$ = exports2.VpcPeeringConnectionStateReason$ = exports2.VpcPeeringConnectionOptionsDescription$ = exports2.VpcPeeringConnection$ = exports2.VpcIpv6CidrBlockAssociation$ = exports2.VpcEndpointConnection$ = exports2.VpcEndpointAssociation$ = exports2.VpcEndpoint$ = exports2.VpcEncryptionNonCompliantResource$ = exports2.VpcEncryptionControlExclusions$ = exports2.VpcEncryptionControlExclusion$ = exports2.VpcEncryptionControlConfiguration$ = exports2.VpcEncryptionControl$ = exports2.VpcClassicLink$ = exports2.VpcCidrBlockState$ = exports2.VpcCidrBlockAssociation$ = exports2.VpcBlockPublicAccessOptions$ = exports2.VpcBlockPublicAccessExclusion$ = void 0;
    exports2.CreateCoipCidr$ = exports2.CreateClientVpnRoute$ = exports2.CreateClientVpnEndpoint$ = exports2.CreateCarrierGateway$ = exports2.CreateCapacityReservationFleet$ = exports2.CreateCapacityReservationBySplitting$ = exports2.CreateCapacityReservation$ = exports2.CreateCapacityManagerDataExport$ = exports2.CopyVolumes$ = exports2.CopySnapshot$ = exports2.CopyImage$ = exports2.CopyFpgaImage$ = exports2.ConfirmProductInstance$ = exports2.CancelSpotInstanceRequests$ = exports2.CancelSpotFleetRequests$ = exports2.CancelReservedInstancesListing$ = exports2.CancelImportTask$ = exports2.CancelImageLaunchPermission$ = exports2.CancelExportTask$ = exports2.CancelDeclarativePoliciesReport$ = exports2.CancelConversionTask$ = exports2.CancelCapacityReservationFleets$ = exports2.CancelCapacityReservation$ = exports2.CancelBundleTask$ = exports2.BundleInstance$ = exports2.AuthorizeSecurityGroupIngress$ = exports2.AuthorizeSecurityGroupEgress$ = exports2.AuthorizeClientVpnIngress$ = exports2.AttachVpnGateway$ = exports2.AttachVolume$ = exports2.AttachVerifiedAccessTrustProvider$ = exports2.AttachNetworkInterface$ = exports2.AttachInternetGateway$ = exports2.AttachClassicLinkVpc$ = exports2.AssociateVpcCidrBlock$ = exports2.AssociateTrunkInterface$ = exports2.AssociateTransitGatewayRouteTable$ = exports2.AssociateTransitGatewayPolicyTable$ = exports2.AssociateTransitGatewayMulticastDomain$ = exports2.AssociateSubnetCidrBlock$ = exports2.AssociateSecurityGroupVpc$ = exports2.AssociateRouteTable$ = exports2.AssociateRouteServer$ = exports2.AssociateNatGatewayAddress$ = exports2.AssociateIpamResourceDiscovery$ = exports2.AssociateIpamByoasn$ = exports2.AssociateInstanceEventWindow$ = exports2.AssociateIamInstanceProfile$ = exports2.AssociateEnclaveCertificateIamRole$ = exports2.AssociateDhcpOptions$ = void 0;
    exports2.CreateRouteServer$ = exports2.CreateRoute$ = exports2.CreateRestoreImageTask$ = exports2.CreateReservedInstancesListing$ = exports2.CreateReplaceRootVolumeTask$ = exports2.CreatePublicIpv4Pool$ = exports2.CreatePlacementGroup$ = exports2.CreateNetworkInterfacePermission$ = exports2.CreateNetworkInterface$ = exports2.CreateNetworkInsightsPath$ = exports2.CreateNetworkInsightsAccessScope$ = exports2.CreateNetworkAclEntry$ = exports2.CreateNetworkAcl$ = exports2.CreateNatGateway$ = exports2.CreateManagedPrefixList$ = exports2.CreateMacSystemIntegrityProtectionModificationTask$ = exports2.CreateLocalGatewayVirtualInterfaceGroup$ = exports2.CreateLocalGatewayVirtualInterface$ = exports2.CreateLocalGatewayRouteTableVpcAssociation$ = exports2.CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociation$ = exports2.CreateLocalGatewayRouteTable$ = exports2.CreateLocalGatewayRoute$ = exports2.CreateLaunchTemplateVersion$ = exports2.CreateLaunchTemplate$ = exports2.CreateKeyPair$ = exports2.CreateIpamScope$ = exports2.CreateIpamResourceDiscovery$ = exports2.CreateIpamPrefixListResolverTarget$ = exports2.CreateIpamPrefixListResolver$ = exports2.CreateIpamPool$ = exports2.CreateIpamPolicy$ = exports2.CreateIpamExternalResourceVerificationToken$ = exports2.CreateIpam$ = exports2.CreateInterruptibleCapacityReservationAllocation$ = exports2.CreateInternetGateway$ = exports2.CreateInstanceExportTask$ = exports2.CreateInstanceEventWindow$ = exports2.CreateInstanceConnectEndpoint$ = exports2.CreateImageUsageReport$ = exports2.CreateImage$ = exports2.CreateFpgaImage$ = exports2.CreateFlowLogs$ = exports2.CreateFleet$ = exports2.CreateEgressOnlyInternetGateway$ = exports2.CreateDhcpOptions$ = exports2.CreateDelegateMacVolumeOwnershipTask$ = exports2.CreateDefaultVpc$ = exports2.CreateDefaultSubnet$ = exports2.CreateCustomerGateway$ = exports2.CreateCoipPool$ = void 0;
    exports2.DeleteClientVpnRoute$ = exports2.DeleteClientVpnEndpoint$ = exports2.DeleteCarrierGateway$ = exports2.DeleteCapacityManagerDataExport$ = exports2.CreateVpnGateway$ = exports2.CreateVpnConnectionRoute$ = exports2.CreateVpnConnection$ = exports2.CreateVpnConcentrator$ = exports2.CreateVpcPeeringConnection$ = exports2.CreateVpcEndpointServiceConfiguration$ = exports2.CreateVpcEndpointConnectionNotification$ = exports2.CreateVpcEndpoint$ = exports2.CreateVpcEncryptionControl$ = exports2.CreateVpcBlockPublicAccessExclusion$ = exports2.CreateVpc$ = exports2.CreateVolume$ = exports2.CreateVerifiedAccessTrustProvider$ = exports2.CreateVerifiedAccessInstance$ = exports2.CreateVerifiedAccessGroup$ = exports2.CreateVerifiedAccessEndpoint$ = exports2.CreateTransitGatewayVpcAttachment$ = exports2.CreateTransitGatewayRouteTableAnnouncement$ = exports2.CreateTransitGatewayRouteTable$ = exports2.CreateTransitGatewayRoute$ = exports2.CreateTransitGatewayPrefixListReference$ = exports2.CreateTransitGatewayPolicyTable$ = exports2.CreateTransitGatewayPeeringAttachment$ = exports2.CreateTransitGatewayMulticastDomain$ = exports2.CreateTransitGatewayMeteringPolicyEntry$ = exports2.CreateTransitGatewayMeteringPolicy$ = exports2.CreateTransitGatewayConnectPeer$ = exports2.CreateTransitGatewayConnect$ = exports2.CreateTransitGateway$ = exports2.CreateTrafficMirrorTarget$ = exports2.CreateTrafficMirrorSession$ = exports2.CreateTrafficMirrorFilterRule$ = exports2.CreateTrafficMirrorFilter$ = exports2.CreateTags$ = exports2.CreateSubnetCidrReservation$ = exports2.CreateSubnet$ = exports2.CreateStoreImageTask$ = exports2.CreateSpotDatafeedSubscription$ = exports2.CreateSnapshots$ = exports2.CreateSnapshot$ = exports2.CreateSecurityGroup$ = exports2.CreateSecondarySubnet$ = exports2.CreateSecondaryNetwork$ = exports2.CreateRouteTable$ = exports2.CreateRouteServerPeer$ = exports2.CreateRouteServerEndpoint$ = void 0;
    exports2.DeleteSecurityGroup$ = exports2.DeleteSecondarySubnet$ = exports2.DeleteSecondaryNetwork$ = exports2.DeleteRouteTable$ = exports2.DeleteRouteServerPeer$ = exports2.DeleteRouteServerEndpoint$ = exports2.DeleteRouteServer$ = exports2.DeleteRoute$ = exports2.DeleteQueuedReservedInstances$ = exports2.DeletePublicIpv4Pool$ = exports2.DeletePlacementGroup$ = exports2.DeleteNetworkInterfacePermission$ = exports2.DeleteNetworkInterface$ = exports2.DeleteNetworkInsightsPath$ = exports2.DeleteNetworkInsightsAnalysis$ = exports2.DeleteNetworkInsightsAccessScopeAnalysis$ = exports2.DeleteNetworkInsightsAccessScope$ = exports2.DeleteNetworkAclEntry$ = exports2.DeleteNetworkAcl$ = exports2.DeleteNatGateway$ = exports2.DeleteManagedPrefixList$ = exports2.DeleteLocalGatewayVirtualInterfaceGroup$ = exports2.DeleteLocalGatewayVirtualInterface$ = exports2.DeleteLocalGatewayRouteTableVpcAssociation$ = exports2.DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociation$ = exports2.DeleteLocalGatewayRouteTable$ = exports2.DeleteLocalGatewayRoute$ = exports2.DeleteLaunchTemplateVersions$ = exports2.DeleteLaunchTemplate$ = exports2.DeleteKeyPair$ = exports2.DeleteIpamScope$ = exports2.DeleteIpamResourceDiscovery$ = exports2.DeleteIpamPrefixListResolverTarget$ = exports2.DeleteIpamPrefixListResolver$ = exports2.DeleteIpamPool$ = exports2.DeleteIpamPolicy$ = exports2.DeleteIpamExternalResourceVerificationToken$ = exports2.DeleteIpam$ = exports2.DeleteInternetGateway$ = exports2.DeleteInstanceEventWindow$ = exports2.DeleteInstanceConnectEndpoint$ = exports2.DeleteImageUsageReport$ = exports2.DeleteFpgaImage$ = exports2.DeleteFlowLogs$ = exports2.DeleteFleets$ = exports2.DeleteEgressOnlyInternetGateway$ = exports2.DeleteDhcpOptions$ = exports2.DeleteCustomerGateway$ = exports2.DeleteCoipPool$ = exports2.DeleteCoipCidr$ = void 0;
    exports2.DescribeAddressesAttribute$ = exports2.DescribeAddresses$ = exports2.DescribeAccountAttributes$ = exports2.DeregisterTransitGatewayMulticastGroupSources$ = exports2.DeregisterTransitGatewayMulticastGroupMembers$ = exports2.DeregisterInstanceEventNotificationAttributes$ = exports2.DeregisterImage$ = exports2.DeprovisionPublicIpv4PoolCidr$ = exports2.DeprovisionIpamPoolCidr$ = exports2.DeprovisionIpamByoasn$ = exports2.DeprovisionByoipCidr$ = exports2.DeleteVpnGateway$ = exports2.DeleteVpnConnectionRoute$ = exports2.DeleteVpnConnection$ = exports2.DeleteVpnConcentrator$ = exports2.DeleteVpcPeeringConnection$ = exports2.DeleteVpcEndpointServiceConfigurations$ = exports2.DeleteVpcEndpoints$ = exports2.DeleteVpcEndpointConnectionNotifications$ = exports2.DeleteVpcEncryptionControl$ = exports2.DeleteVpcBlockPublicAccessExclusion$ = exports2.DeleteVpc$ = exports2.DeleteVolume$ = exports2.DeleteVerifiedAccessTrustProvider$ = exports2.DeleteVerifiedAccessInstance$ = exports2.DeleteVerifiedAccessGroup$ = exports2.DeleteVerifiedAccessEndpoint$ = exports2.DeleteTransitGatewayVpcAttachment$ = exports2.DeleteTransitGatewayRouteTableAnnouncement$ = exports2.DeleteTransitGatewayRouteTable$ = exports2.DeleteTransitGatewayRoute$ = exports2.DeleteTransitGatewayPrefixListReference$ = exports2.DeleteTransitGatewayPolicyTable$ = exports2.DeleteTransitGatewayPeeringAttachment$ = exports2.DeleteTransitGatewayMulticastDomain$ = exports2.DeleteTransitGatewayMeteringPolicyEntry$ = exports2.DeleteTransitGatewayMeteringPolicy$ = exports2.DeleteTransitGatewayConnectPeer$ = exports2.DeleteTransitGatewayConnect$ = exports2.DeleteTransitGatewayClientVpnAttachment$ = exports2.DeleteTransitGateway$ = exports2.DeleteTrafficMirrorTarget$ = exports2.DeleteTrafficMirrorSession$ = exports2.DeleteTrafficMirrorFilterRule$ = exports2.DeleteTrafficMirrorFilter$ = exports2.DeleteTags$ = exports2.DeleteSubnetCidrReservation$ = exports2.DeleteSubnet$ = exports2.DeleteSpotDatafeedSubscription$ = exports2.DeleteSnapshot$ = void 0;
    exports2.DescribeImageUsageReportEntries$ = exports2.DescribeImages$ = exports2.DescribeImageReferences$ = exports2.DescribeImageAttribute$ = exports2.DescribeIdFormat$ = exports2.DescribeIdentityIdFormat$ = exports2.DescribeIamInstanceProfileAssociations$ = exports2.DescribeHosts$ = exports2.DescribeHostReservations$ = exports2.DescribeHostReservationOfferings$ = exports2.DescribeFpgaImages$ = exports2.DescribeFpgaImageAttribute$ = exports2.DescribeFlowLogs$ = exports2.DescribeFleets$ = exports2.DescribeFleetInstances$ = exports2.DescribeFleetHistory$ = exports2.DescribeFastSnapshotRestores$ = exports2.DescribeFastLaunchImages$ = exports2.DescribeExportTasks$ = exports2.DescribeExportImageTasks$ = exports2.DescribeElasticGpus$ = exports2.DescribeEgressOnlyInternetGateways$ = exports2.DescribeDhcpOptions$ = exports2.DescribeDeclarativePoliciesReports$ = exports2.DescribeCustomerGateways$ = exports2.DescribeConversionTasks$ = exports2.DescribeCoipPools$ = exports2.DescribeClientVpnTargetNetworks$ = exports2.DescribeClientVpnRoutes$ = exports2.DescribeClientVpnEndpoints$ = exports2.DescribeClientVpnConnections$ = exports2.DescribeClientVpnAuthorizationRules$ = exports2.DescribeClassicLinkInstances$ = exports2.DescribeCarrierGateways$ = exports2.DescribeCapacityReservationTopology$ = exports2.DescribeCapacityReservations$ = exports2.DescribeCapacityReservationFleets$ = exports2.DescribeCapacityReservationBillingRequests$ = exports2.DescribeCapacityManagerDataExports$ = exports2.DescribeCapacityBlockStatus$ = exports2.DescribeCapacityBlocks$ = exports2.DescribeCapacityBlockOfferings$ = exports2.DescribeCapacityBlockExtensionOfferings$ = exports2.DescribeCapacityBlockExtensionHistory$ = exports2.DescribeByoipCidrs$ = exports2.DescribeBundleTasks$ = exports2.DescribeAwsNetworkPerformanceMetricSubscriptions$ = exports2.DescribeAvailabilityZones$ = exports2.DescribeAggregateIdFormat$ = exports2.DescribeAddressTransfers$ = void 0;
    exports2.DescribeNetworkInterfacePermissions$ = exports2.DescribeNetworkInterfaceAttribute$ = exports2.DescribeNetworkInsightsPaths$ = exports2.DescribeNetworkInsightsAnalyses$ = exports2.DescribeNetworkInsightsAccessScopes$ = exports2.DescribeNetworkInsightsAccessScopeAnalyses$ = exports2.DescribeNetworkAcls$ = exports2.DescribeNatGateways$ = exports2.DescribeMovingAddresses$ = exports2.DescribeManagedPrefixLists$ = exports2.DescribeMacModificationTasks$ = exports2.DescribeMacHosts$ = exports2.DescribeLockedSnapshots$ = exports2.DescribeLocalGatewayVirtualInterfaces$ = exports2.DescribeLocalGatewayVirtualInterfaceGroups$ = exports2.DescribeLocalGateways$ = exports2.DescribeLocalGatewayRouteTableVpcAssociations$ = exports2.DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociations$ = exports2.DescribeLocalGatewayRouteTables$ = exports2.DescribeLaunchTemplateVersions$ = exports2.DescribeLaunchTemplates$ = exports2.DescribeKeyPairs$ = exports2.DescribeIpv6Pools$ = exports2.DescribeIpamScopes$ = exports2.DescribeIpams$ = exports2.DescribeIpamResourceDiscoveryAssociations$ = exports2.DescribeIpamResourceDiscoveries$ = exports2.DescribeIpamPrefixListResolverTargets$ = exports2.DescribeIpamPrefixListResolvers$ = exports2.DescribeIpamPools$ = exports2.DescribeIpamPolicies$ = exports2.DescribeIpamExternalResourceVerificationTokens$ = exports2.DescribeIpamByoasn$ = exports2.DescribeInternetGateways$ = exports2.DescribeInstanceTypes$ = exports2.DescribeInstanceTypeOfferings$ = exports2.DescribeInstanceTopology$ = exports2.DescribeInstanceStatus$ = exports2.DescribeInstanceSqlHaStates$ = exports2.DescribeInstanceSqlHaHistoryStates$ = exports2.DescribeInstances$ = exports2.DescribeInstanceImageMetadata$ = exports2.DescribeInstanceEventWindows$ = exports2.DescribeInstanceEventNotificationAttributes$ = exports2.DescribeInstanceCreditSpecifications$ = exports2.DescribeInstanceConnectEndpoints$ = exports2.DescribeInstanceAttribute$ = exports2.DescribeImportSnapshotTasks$ = exports2.DescribeImportImageTasks$ = exports2.DescribeImageUsageReports$ = void 0;
    exports2.DescribeTransitGatewayPolicyTables$ = exports2.DescribeTransitGatewayPeeringAttachments$ = exports2.DescribeTransitGatewayMulticastDomains$ = exports2.DescribeTransitGatewayMeteringPolicies$ = exports2.DescribeTransitGatewayConnects$ = exports2.DescribeTransitGatewayConnectPeers$ = exports2.DescribeTransitGatewayAttachments$ = exports2.DescribeTrafficMirrorTargets$ = exports2.DescribeTrafficMirrorSessions$ = exports2.DescribeTrafficMirrorFilters$ = exports2.DescribeTrafficMirrorFilterRules$ = exports2.DescribeTags$ = exports2.DescribeSubnets$ = exports2.DescribeStoreImageTasks$ = exports2.DescribeStaleSecurityGroups$ = exports2.DescribeSpotPriceHistory$ = exports2.DescribeSpotInstanceRequests$ = exports2.DescribeSpotFleetRequests$ = exports2.DescribeSpotFleetRequestHistory$ = exports2.DescribeSpotFleetInstances$ = exports2.DescribeSpotDatafeedSubscription$ = exports2.DescribeSnapshotTierStatus$ = exports2.DescribeSnapshots$ = exports2.DescribeSnapshotAttribute$ = exports2.DescribeServiceLinkVirtualInterfaces$ = exports2.DescribeSecurityGroupVpcAssociations$ = exports2.DescribeSecurityGroups$ = exports2.DescribeSecurityGroupRules$ = exports2.DescribeSecurityGroupReferences$ = exports2.DescribeSecondarySubnets$ = exports2.DescribeSecondaryNetworks$ = exports2.DescribeSecondaryInterfaces$ = exports2.DescribeScheduledInstances$ = exports2.DescribeScheduledInstanceAvailability$ = exports2.DescribeRouteTables$ = exports2.DescribeRouteServers$ = exports2.DescribeRouteServerPeers$ = exports2.DescribeRouteServerEndpoints$ = exports2.DescribeReservedInstancesOfferings$ = exports2.DescribeReservedInstancesModifications$ = exports2.DescribeReservedInstancesListings$ = exports2.DescribeReservedInstances$ = exports2.DescribeReplaceRootVolumeTasks$ = exports2.DescribeRegions$ = exports2.DescribePublicIpv4Pools$ = exports2.DescribePrincipalIdFormat$ = exports2.DescribePrefixLists$ = exports2.DescribePlacementGroups$ = exports2.DescribeOutpostLags$ = exports2.DescribeNetworkInterfaces$ = void 0;
    exports2.DisableInstanceSqlHaStandbyDetections$ = exports2.DisableImageDeregistrationProtection$ = exports2.DisableImageDeprecation$ = exports2.DisableImageBlockPublicAccess$ = exports2.DisableImage$ = exports2.DisableFastSnapshotRestores$ = exports2.DisableFastLaunch$ = exports2.DisableEbsEncryptionByDefault$ = exports2.DisableCapacityManager$ = exports2.DisableAwsNetworkPerformanceMetricSubscription$ = exports2.DisableAllowedImagesSettings$ = exports2.DisableAddressTransfer$ = exports2.DetachVpnGateway$ = exports2.DetachVolume$ = exports2.DetachVerifiedAccessTrustProvider$ = exports2.DetachNetworkInterface$ = exports2.DetachInternetGateway$ = exports2.DetachClassicLinkVpc$ = exports2.DescribeVpnGateways$ = exports2.DescribeVpnConnections$ = exports2.DescribeVpnConcentrators$ = exports2.DescribeVpcs$ = exports2.DescribeVpcPeeringConnections$ = exports2.DescribeVpcEndpointServices$ = exports2.DescribeVpcEndpointServicePermissions$ = exports2.DescribeVpcEndpointServiceConfigurations$ = exports2.DescribeVpcEndpoints$ = exports2.DescribeVpcEndpointConnections$ = exports2.DescribeVpcEndpointConnectionNotifications$ = exports2.DescribeVpcEndpointAssociations$ = exports2.DescribeVpcEncryptionControls$ = exports2.DescribeVpcClassicLinkDnsSupport$ = exports2.DescribeVpcClassicLink$ = exports2.DescribeVpcBlockPublicAccessOptions$ = exports2.DescribeVpcBlockPublicAccessExclusions$ = exports2.DescribeVpcAttribute$ = exports2.DescribeVolumeStatus$ = exports2.DescribeVolumesModifications$ = exports2.DescribeVolumes$ = exports2.DescribeVolumeAttribute$ = exports2.DescribeVerifiedAccessTrustProviders$ = exports2.DescribeVerifiedAccessInstances$ = exports2.DescribeVerifiedAccessInstanceLoggingConfigurations$ = exports2.DescribeVerifiedAccessGroups$ = exports2.DescribeVerifiedAccessEndpoints$ = exports2.DescribeTrunkInterfaceAssociations$ = exports2.DescribeTransitGatewayVpcAttachments$ = exports2.DescribeTransitGateways$ = exports2.DescribeTransitGatewayRouteTables$ = exports2.DescribeTransitGatewayRouteTableAnnouncements$ = void 0;
    exports2.EnableVpcClassicLinkDnsSupport$ = exports2.EnableVpcClassicLink$ = exports2.EnableVolumeIO$ = exports2.EnableVgwRoutePropagation$ = exports2.EnableTransitGatewayRouteTablePropagation$ = exports2.EnableSnapshotBlockPublicAccess$ = exports2.EnableSerialConsoleAccess$ = exports2.EnableRouteServerPropagation$ = exports2.EnableReachabilityAnalyzerOrganizationSharing$ = exports2.EnableIpamPolicy$ = exports2.EnableIpamOrganizationAdminAccount$ = exports2.EnableInstanceSqlHaStandbyDetections$ = exports2.EnableImageDeregistrationProtection$ = exports2.EnableImageDeprecation$ = exports2.EnableImageBlockPublicAccess$ = exports2.EnableImage$ = exports2.EnableFastSnapshotRestores$ = exports2.EnableFastLaunch$ = exports2.EnableEbsEncryptionByDefault$ = exports2.EnableCapacityManager$ = exports2.EnableAwsNetworkPerformanceMetricSubscription$ = exports2.EnableAllowedImagesSettings$ = exports2.EnableAddressTransfer$ = exports2.DisassociateVpcCidrBlock$ = exports2.DisassociateTrunkInterface$ = exports2.DisassociateTransitGatewayRouteTable$ = exports2.DisassociateTransitGatewayPolicyTable$ = exports2.DisassociateTransitGatewayMulticastDomain$ = exports2.DisassociateSubnetCidrBlock$ = exports2.DisassociateSecurityGroupVpc$ = exports2.DisassociateRouteTable$ = exports2.DisassociateRouteServer$ = exports2.DisassociateNatGatewayAddress$ = exports2.DisassociateIpamResourceDiscovery$ = exports2.DisassociateIpamByoasn$ = exports2.DisassociateInstanceEventWindow$ = exports2.DisassociateIamInstanceProfile$ = exports2.DisassociateEnclaveCertificateIamRole$ = exports2.DisassociateClientVpnTargetNetwork$ = exports2.DisassociateCapacityReservationBillingOwner$ = exports2.DisassociateAddress$ = exports2.DisableVpcClassicLinkDnsSupport$ = exports2.DisableVpcClassicLink$ = exports2.DisableVgwRoutePropagation$ = exports2.DisableTransitGatewayRouteTablePropagation$ = exports2.DisableSnapshotBlockPublicAccess$ = exports2.DisableSerialConsoleAccess$ = exports2.DisableRouteServerPropagation$ = exports2.DisableIpamPolicy$ = exports2.DisableIpamOrganizationAdminAccount$ = void 0;
    exports2.GetNetworkInsightsAccessScopeContent$ = exports2.GetNetworkInsightsAccessScopeAnalysisFindings$ = exports2.GetManagedResourceVisibility$ = exports2.GetManagedPrefixListEntries$ = exports2.GetManagedPrefixListAssociations$ = exports2.GetLaunchTemplateData$ = exports2.GetIpamResourceCidrs$ = exports2.GetIpamPrefixListResolverVersions$ = exports2.GetIpamPrefixListResolverVersionEntries$ = exports2.GetIpamPrefixListResolverRules$ = exports2.GetIpamPoolCidrs$ = exports2.GetIpamPoolAllocations$ = exports2.GetIpamPolicyOrganizationTargets$ = exports2.GetIpamPolicyAllocationRules$ = exports2.GetIpamDiscoveredResourceCidrs$ = exports2.GetIpamDiscoveredPublicAddresses$ = exports2.GetIpamDiscoveredAccounts$ = exports2.GetIpamAddressHistory$ = exports2.GetInstanceUefiData$ = exports2.GetInstanceTypesFromInstanceRequirements$ = exports2.GetInstanceTpmEkPub$ = exports2.GetInstanceMetadataDefaults$ = exports2.GetImageBlockPublicAccessState$ = exports2.GetImageAncestry$ = exports2.GetHostReservationPurchasePreview$ = exports2.GetGroupsForCapacityReservation$ = exports2.GetFlowLogsIntegrationTemplate$ = exports2.GetEnabledIpamPolicy$ = exports2.GetEbsEncryptionByDefault$ = exports2.GetEbsDefaultKmsKeyId$ = exports2.GetDefaultCreditSpecification$ = exports2.GetDeclarativePoliciesReportSummary$ = exports2.GetConsoleScreenshot$ = exports2.GetConsoleOutput$ = exports2.GetCoipPoolUsage$ = exports2.GetCapacityReservationUsage$ = exports2.GetCapacityManagerMonitoredTagKeys$ = exports2.GetCapacityManagerMetricDimensions$ = exports2.GetCapacityManagerMetricData$ = exports2.GetCapacityManagerAttributes$ = exports2.GetAwsNetworkPerformanceData$ = exports2.GetAssociatedIpv6PoolCidrs$ = exports2.GetAssociatedEnclaveCertificateIamRoles$ = exports2.GetAllowedImagesSettings$ = exports2.GetActiveVpnTunnelStatus$ = exports2.ExportVerifiedAccessInstanceClientConfiguration$ = exports2.ExportTransitGatewayRoutes$ = exports2.ExportImage$ = exports2.ExportClientVpnClientConfiguration$ = exports2.ExportClientVpnClientCertificateRevocationList$ = void 0;
    exports2.ModifyInstanceCapacityReservationAttributes$ = exports2.ModifyInstanceAttribute$ = exports2.ModifyImageAttribute$ = exports2.ModifyIdFormat$ = exports2.ModifyIdentityIdFormat$ = exports2.ModifyHosts$ = exports2.ModifyFpgaImageAttribute$ = exports2.ModifyFleet$ = exports2.ModifyEbsDefaultKmsKeyId$ = exports2.ModifyDefaultCreditSpecification$ = exports2.ModifyClientVpnEndpoint$ = exports2.ModifyCapacityReservationFleet$ = exports2.ModifyCapacityReservation$ = exports2.ModifyAvailabilityZoneGroup$ = exports2.ModifyAddressAttribute$ = exports2.LockSnapshot$ = exports2.ListVolumesInRecycleBin$ = exports2.ListSnapshotsInRecycleBin$ = exports2.ListImagesInRecycleBin$ = exports2.ImportVolume$ = exports2.ImportSnapshot$ = exports2.ImportKeyPair$ = exports2.ImportInstance$ = exports2.ImportImage$ = exports2.ImportClientVpnClientCertificateRevocationList$ = exports2.GetVpnTunnelReplacementStatus$ = exports2.GetVpnConnectionDeviceTypes$ = exports2.GetVpnConnectionDeviceSampleConfiguration$ = exports2.GetVpcResourcesBlockingEncryptionEnforcement$ = exports2.GetVerifiedAccessGroupPolicy$ = exports2.GetVerifiedAccessEndpointTargets$ = exports2.GetVerifiedAccessEndpointPolicy$ = exports2.GetTransitGatewayRouteTablePropagations$ = exports2.GetTransitGatewayRouteTableAssociations$ = exports2.GetTransitGatewayPrefixListReferences$ = exports2.GetTransitGatewayPolicyTableEntries$ = exports2.GetTransitGatewayPolicyTableAssociations$ = exports2.GetTransitGatewayMulticastDomainAssociations$ = exports2.GetTransitGatewayMeteringPolicyEntries$ = exports2.GetTransitGatewayAttachmentPropagations$ = exports2.GetSubnetCidrReservations$ = exports2.GetSpotPlacementScores$ = exports2.GetSnapshotBlockPublicAccessState$ = exports2.GetSerialConsoleAccessStatus$ = exports2.GetSecurityGroupsForVpc$ = exports2.GetRouteServerRoutingDatabase$ = exports2.GetRouteServerPropagations$ = exports2.GetRouteServerAssociations$ = exports2.GetReservedInstancesExchangeQuote$ = exports2.GetPasswordData$ = void 0;
    exports2.ModifyVpcBlockPublicAccessExclusion$ = exports2.ModifyVpcAttribute$ = exports2.ModifyVolumeAttribute$ = exports2.ModifyVolume$ = exports2.ModifyVerifiedAccessTrustProvider$ = exports2.ModifyVerifiedAccessInstanceLoggingConfiguration$ = exports2.ModifyVerifiedAccessInstance$ = exports2.ModifyVerifiedAccessGroupPolicy$ = exports2.ModifyVerifiedAccessGroup$ = exports2.ModifyVerifiedAccessEndpointPolicy$ = exports2.ModifyVerifiedAccessEndpoint$ = exports2.ModifyTransitGatewayVpcAttachment$ = exports2.ModifyTransitGatewayPrefixListReference$ = exports2.ModifyTransitGatewayMeteringPolicy$ = exports2.ModifyTransitGateway$ = exports2.ModifyTrafficMirrorSession$ = exports2.ModifyTrafficMirrorFilterRule$ = exports2.ModifyTrafficMirrorFilterNetworkServices$ = exports2.ModifySubnetAttribute$ = exports2.ModifySpotFleetRequest$ = exports2.ModifySnapshotTier$ = exports2.ModifySnapshotAttribute$ = exports2.ModifySecurityGroupRules$ = exports2.ModifyRouteServer$ = exports2.ModifyReservedInstances$ = exports2.ModifyPublicIpDnsNameOptions$ = exports2.ModifyPrivateDnsNameOptions$ = exports2.ModifyNetworkInterfaceAttribute$ = exports2.ModifyManagedResourceVisibility$ = exports2.ModifyManagedPrefixList$ = exports2.ModifyLocalGatewayRoute$ = exports2.ModifyLaunchTemplate$ = exports2.ModifyIpamScope$ = exports2.ModifyIpamResourceDiscovery$ = exports2.ModifyIpamResourceCidr$ = exports2.ModifyIpamPrefixListResolverTarget$ = exports2.ModifyIpamPrefixListResolver$ = exports2.ModifyIpamPool$ = exports2.ModifyIpamPolicyAllocationRules$ = exports2.ModifyIpam$ = exports2.ModifyInstancePlacement$ = exports2.ModifyInstanceNetworkPerformanceOptions$ = exports2.ModifyInstanceMetadataOptions$ = exports2.ModifyInstanceMetadataDefaults$ = exports2.ModifyInstanceMaintenanceOptions$ = exports2.ModifyInstanceEventWindow$ = exports2.ModifyInstanceEventStartTime$ = exports2.ModifyInstanceCreditSpecification$ = exports2.ModifyInstanceCpuOptions$ = exports2.ModifyInstanceConnectEndpoint$ = void 0;
    exports2.ReportInstanceStatus$ = exports2.ReplaceVpnTunnel$ = exports2.ReplaceTransitGatewayRoute$ = exports2.ReplaceRouteTableAssociation$ = exports2.ReplaceRoute$ = exports2.ReplaceNetworkAclEntry$ = exports2.ReplaceNetworkAclAssociation$ = exports2.ReplaceImageCriteriaInAllowedImagesSettings$ = exports2.ReplaceIamInstanceProfileAssociation$ = exports2.ReleaseIpamPoolAllocation$ = exports2.ReleaseHosts$ = exports2.ReleaseAddress$ = exports2.RejectVpcPeeringConnection$ = exports2.RejectVpcEndpointConnections$ = exports2.RejectTransitGatewayVpcAttachment$ = exports2.RejectTransitGatewayPeeringAttachment$ = exports2.RejectTransitGatewayMulticastDomainAssociations$ = exports2.RejectTransitGatewayClientVpnAttachment$ = exports2.RejectCapacityReservationBillingOwnership$ = exports2.RegisterTransitGatewayMulticastGroupSources$ = exports2.RegisterTransitGatewayMulticastGroupMembers$ = exports2.RegisterInstanceEventNotificationAttributes$ = exports2.RegisterImage$ = exports2.RebootInstances$ = exports2.PurchaseScheduledInstances$ = exports2.PurchaseReservedInstancesOffering$ = exports2.PurchaseHostReservation$ = exports2.PurchaseCapacityBlockExtension$ = exports2.PurchaseCapacityBlock$ = exports2.ProvisionPublicIpv4PoolCidr$ = exports2.ProvisionIpamPoolCidr$ = exports2.ProvisionIpamByoasn$ = exports2.ProvisionByoipCidr$ = exports2.MoveCapacityReservationInstances$ = exports2.MoveByoipCidrToIpam$ = exports2.MoveAddressToVpc$ = exports2.MonitorInstances$ = exports2.ModifyVpnTunnelOptions$ = exports2.ModifyVpnTunnelCertificate$ = exports2.ModifyVpnConnectionOptions$ = exports2.ModifyVpnConnection$ = exports2.ModifyVpcTenancy$ = exports2.ModifyVpcPeeringConnectionOptions$ = exports2.ModifyVpcEndpointServicePermissions$ = exports2.ModifyVpcEndpointServicePayerResponsibility$ = exports2.ModifyVpcEndpointServiceConfiguration$ = exports2.ModifyVpcEndpointConnectionNotification$ = exports2.ModifyVpcEndpoint$ = exports2.ModifyVpcEncryptionControl$ = exports2.ModifyVpcBlockPublicAccessOptions$ = void 0;
    exports2.WithdrawByoipCidr$ = exports2.UpdateSecurityGroupRuleDescriptionsIngress$ = exports2.UpdateSecurityGroupRuleDescriptionsEgress$ = exports2.UpdateInterruptibleCapacityReservationAllocation$ = exports2.UpdateCapacityManagerOrganizationsAccess$ = exports2.UpdateCapacityManagerMonitoredTagKeys$ = exports2.UnmonitorInstances$ = exports2.UnlockSnapshot$ = exports2.UnassignPrivateNatGatewayAddress$ = exports2.UnassignPrivateIpAddresses$ = exports2.UnassignIpv6Addresses$ = exports2.TerminateInstances$ = exports2.TerminateClientVpnConnections$ = exports2.StopInstances$ = exports2.StartVpcEndpointServicePrivateDnsVerification$ = exports2.StartNetworkInsightsAnalysis$ = exports2.StartNetworkInsightsAccessScopeAnalysis$ = exports2.StartInstances$ = exports2.StartDeclarativePoliciesReport$ = exports2.SendDiagnosticInterrupt$ = exports2.SearchTransitGatewayRoutes$ = exports2.SearchTransitGatewayMulticastGroups$ = exports2.SearchLocalGatewayRoutes$ = exports2.RunScheduledInstances$ = exports2.RunInstances$ = exports2.RevokeSecurityGroupIngress$ = exports2.RevokeSecurityGroupEgress$ = exports2.RevokeClientVpnIngress$ = exports2.RestoreVolumeFromRecycleBin$ = exports2.RestoreSnapshotTier$ = exports2.RestoreSnapshotFromRecycleBin$ = exports2.RestoreManagedPrefixListVersion$ = exports2.RestoreImageFromRecycleBin$ = exports2.RestoreAddressToClassic$ = exports2.ResetSnapshotAttribute$ = exports2.ResetNetworkInterfaceAttribute$ = exports2.ResetInstanceAttribute$ = exports2.ResetImageAttribute$ = exports2.ResetFpgaImageAttribute$ = exports2.ResetEbsDefaultKmsKeyId$ = exports2.ResetAddressAttribute$ = exports2.RequestSpotInstances$ = exports2.RequestSpotFleet$ = void 0;
    var _A10 = "Address";
    var _AA = "AccountAttribute";
    var _AAC = "AsnAuthorizationContext";
    var _AACv = "AvailableAddressCount";
    var _AAG = "AuthorizeAllGroups";
    var _AAI = "AwsAccountId";
    var _AAId = "AddressAllocationId";
    var _AAL = "AccountAttributeList";
    var _AANSL = "AccountAttributeNameStringList";
    var _AAP = "AddAllowedPrincipals";
    var _AAR = "AllocateAddressRequest";
    var _AART = "AddAllocationResourceTags";
    var _AARTd = "AddAllocationResourceTag";
    var _AARl = "AllocateAddressResult";
    var _AARn = "AnalysisAclRule";
    var _AARs = "AssociateAddressRequest";
    var _AARss = "AssociateAddressResult";
    var _AAS = "AsnAssociationSet";
    var _AASA = "AutoAcceptSharedAssociations";
    var _AASAu = "AutoAcceptSharedAttachments";
    var _AAT = "AcceptAddressTransfer";
    var _AATR = "AcceptAddressTransferRequest";
    var _AATRc = "AcceptAddressTransferResult";
    var _AAV = "AccountAttributeValue";
    var _AAVL = "AccountAttributeValueList";
    var _AAZ = "AllAvailabilityZones";
    var _AAc = "AccessAll";
    var _AAcc = "AccountAttributes";
    var _AAd = "AddressAttribute";
    var _AAdd = "AdditionalAccounts";
    var _AAddi = "AdditionalAccount";
    var _AAl = "AllocateAddress";
    var _AAp = "ApplianceArn";
    var _AAs = "AsnAssociation";
    var _AAsn = "AsnAssociations";
    var _AAss = "AssociateAddress";
    var _AAt = "AttachedAppliances";
    var _ABC = "AdvertiseByoipCidr";
    var _ABCR = "AdvertiseByoipCidrRequest";
    var _ABCRd = "AdvertiseByoipCidrResult";
    var _ABHP = "ActualBlockHourlyPrice";
    var _ABV = "AttributeBooleanValue";
    var _AC = "AcceleratorCount";
    var _ACIA = "AssociateCarrierIpAddress";
    var _ACL = "AnalysisComponentList";
    var _ACLV = "AttachClassicLinkVpc";
    var _ACLVR = "AttachClassicLinkVpcRequest";
    var _ACLVRt = "AttachClassicLinkVpcResult";
    var _ACR = "AcceleratorCountRequest";
    var _ACRBO = "AcceptCapacityReservationBillingOwnership";
    var _ACRBOR = "AcceptCapacityReservationBillingOwnershipRequest";
    var _ACRBORc = "AcceptCapacityReservationBillingOwnershipResult";
    var _ACRBORs = "AssociateCapacityReservationBillingOwnerRequest";
    var _ACRBORss = "AssociateCapacityReservationBillingOwnerResult";
    var _ACRBOs = "AssociateCapacityReservationBillingOwner";
    var _ACT = "ArchivalCompleteTime";
    var _ACVI = "AuthorizeClientVpnIngress";
    var _ACVIR = "AuthorizeClientVpnIngressRequest";
    var _ACVIRu = "AuthorizeClientVpnIngressResult";
    var _ACVTN = "AssociateClientVpnTargetNetwork";
    var _ACVTNR = "AssociateClientVpnTargetNetworkRequest";
    var _ACVTNRs = "AssociateClientVpnTargetNetworkResult";
    var _ACd = "AddressCount";
    var _ACl = "AllowedCidrs";
    var _ACll = "AllowedCidr";
    var _ACn = "AnalysisComponent";
    var _ACv = "AvailableCapacity";
    var _AD = "AdditionalDetail";
    var _ADL = "AdditionalDetailList";
    var _ADNL = "AllocationDefaultNetmaskLength";
    var _ADO = "AssociateDhcpOptions";
    var _ADOR = "AssociateDhcpOptionsRequest";
    var _ADRFRV = "AllowDnsResolutionFromRemoteVpc";
    var _ADRTI = "AssociationDefaultRouteTableId";
    var _ADT = "AdditionalDetailType";
    var _ADc = "ActiveDirectory";
    var _ADd = "AdditionalDetails";
    var _ADn = "AnnouncementDirection";
    var _ADp = "ApplicationDomain";
    var _AE = "AuthorizationEndpoint";
    var _AEC = "AnalyzedEniCount";
    var _AECIR = "AssociateEnclaveCertificateIamRole";
    var _AECIRR = "AssociateEnclaveCertificateIamRoleRequest";
    var _AECIRRs = "AssociateEnclaveCertificateIamRoleResult";
    var _AEFLCLTRV = "AllowEgressFromLocalClassicLinkToRemoteVpc";
    var _AEFLVTRCL = "AllowEgressFromLocalVpcToRemoteClassicLink";
    var _AEIO = "AutoEnableIO";
    var _AES = "AttachedEbsStatus";
    var _AESS = "AttachmentEnaSrdSpecification";
    var _AESUS = "AttachmentEnaSrdUdpSpecification";
    var _AET = "AnalysisEndTime";
    var _AEd = "AddEntries";
    var _AEdd = "AddEntry";
    var _AF = "AddressFamily";
    var _AFNI = "AdditionalFlexibleNetworkInterfaces";
    var _AFn = "AnalysisFindings";
    var _AGI = "AccessGroupId";
    var _AGLBA = "AddGatewayLoadBalancerArns";
    var _AGLBAd = "AddGatewayLoadBalancerArn";
    var _AH = "AllocateHosts";
    var _AHR = "AllocateHostsRequest";
    var _AHRl = "AllocateHostsResult";
    var _AI2 = "ActiveInstance";
    var _AIA = "AssignedIpv6Addresses";
    var _AIAC = "AvailableIpAddressCount";
    var _AIAOC = "AssignIpv6AddressOnCreation";
    var _AIAR = "AssignIpv6AddressesRequest";
    var _AIARs = "AssignIpv6AddressesResult";
    var _AIAs = "AssignIpv6Addresses";
    var _AIB = "AssociateIpamByoasn";
    var _AIBR = "AssociateIpamByoasnRequest";
    var _AIBRs = "AssociateIpamByoasnResult";
    var _AIC = "AvailableInstanceCapacity";
    var _AICL = "AvailableInstanceCapacityList";
    var _AICv = "AvailableInstanceCount";
    var _AIEW = "AssociateInstanceEventWindow";
    var _AIEWR = "AssociateInstanceEventWindowRequest";
    var _AIEWRs = "AssociateInstanceEventWindowResult";
    var _AIG = "AttachInternetGateway";
    var _AIGR = "AttachInternetGatewayRequest";
    var _AIIP = "AssociateIamInstanceProfile";
    var _AIIPR = "AssociateIamInstanceProfileRequest";
    var _AIIPRs = "AssociateIamInstanceProfileResult";
    var _AIL = "AllocationIdList";
    var _AILs = "AssociationIdList";
    var _AIOR = "AddIpamOperatingRegion";
    var _AIORS = "AddIpamOperatingRegionSet";
    var _AIOUE = "AddIpamOrganizationalUnitExclusion";
    var _AIOUES = "AddIpamOrganizationalUnitExclusionSet";
    var _AIP = "AssignedIpv6Prefixes";
    var _AIPC = "AllocateIpamPoolCidr";
    var _AIPCR = "AllocateIpamPoolCidrRequest";
    var _AIPCRl = "AllocateIpamPoolCidrResult";
    var _AIPs = "AssignedIpv4Prefixes";
    var _AIRD = "AssociateIpamResourceDiscovery";
    var _AIRDR = "AssociateIpamResourceDiscoveryRequest";
    var _AIRDRs = "AssociateIpamResourceDiscoveryResult";
    var _AIS = "ActiveInstanceSet";
    var _AISS = "AllowedImagesSettingsState";
    var _AISt = "AthenaIntegrationsSet";
    var _AIT = "AllowedInstanceTypes";
    var _AITS = "AllowedInstanceTypeSet";
    var _AITl = "AllowedInstanceType";
    var _AIc = "AccountId";
    var _AIcc = "AccountIds";
    var _AIct = "ActiveInstances";
    var _AId = "AdditionalInfo";
    var _AIl = "AllocationId";
    var _AIll = "AllocationIds";
    var _AIm = "AmiId";
    var _AIp = "AppleInternal";
    var _AIs = "AssociationId";
    var _AIss = "AssetIds";
    var _AIsse = "AssetId";
    var _AIsso = "AssociationIds";
    var _AIt = "AthenaIntegration";
    var _AIth = "AthenaIntegrations";
    var _AItt = "AttachmentId";
    var _AIu = "AutoImport";
    var _AL = "AccountLevel";
    var _ALBL = "AnalysisLoadBalancerListener";
    var _ALBT = "AnalysisLoadBalancerTarget";
    var _ALI = "AmiLaunchIndex";
    var _ALT = "AttachmentLimitType";
    var _ALc = "AccessLogs";
    var _ALd = "AddressList";
    var _ALr = "ArnList";
    var _AM = "AllocationMetadata";
    var _AMAI = "AddMiddleboxAttachmentIds";
    var _AMAId = "AddMiddleboxAttachmentId";
    var _AMIT = "AllowsMultipleInstanceTypes";
    var _AMNL = "AllocationMinNetmaskLength";
    var _AMNLl = "AllocationMaxNetmaskLength";
    var _AMS = "ApplianceModeSupport";
    var _AMSc = "AcceleratorManufacturerSet";
    var _AMc = "AcceleratorManufacturers";
    var _AMcc = "AcceleratorManufacturer";
    var _AMv = "AvailabilityMode";
    var _AN = "AttributeName";
    var _ANGA = "AssociateNatGatewayAddress";
    var _ANGAR = "AssociateNatGatewayAddressRequest";
    var _ANGARs = "AssociateNatGatewayAddressResult";
    var _ANI = "AttachNetworkInterface";
    var _ANIR = "AttachNetworkInterfaceRequest";
    var _ANIRt = "AttachNetworkInterfaceResult";
    var _ANLBA = "AddNetworkLoadBalancerArns";
    var _ANLBAd = "AddNetworkLoadBalancerArn";
    var _ANS = "AddNetworkServices";
    var _ANSc = "AcceleratorNameSet";
    var _ANSd = "AddNetworkService";
    var _ANc = "AccountName";
    var _ANcc = "AcceleratorNames";
    var _ANcce = "AcceleratorName";
    var _ANt = "AttributeNames";
    var _AO = "AuthenticationOptions";
    var _AOI = "AddressOwnerId";
    var _AOR = "AddOperatingRegions";
    var _AORd = "AddOperatingRegion";
    var _AOUE = "AddOrganizationalUnitExclusions";
    var _AOUEd = "AddOrganizationalUnitExclusion";
    var _AP = "AddedPrincipal";
    var _APCO = "AccepterPeeringConnectionOptions";
    var _APH = "AlternatePathHint";
    var _APHL = "AlternatePathHintList";
    var _APHl = "AlternatePathHints";
    var _APHn = "AnalysisPacketHeader";
    var _APIA = "AssignedPrivateIpAddress";
    var _APIAL = "AssignedPrivateIpAddressList";
    var _APIAR = "AssignPrivateIpAddressesRequest";
    var _APIARs = "AssignPrivateIpAddressesResult";
    var _APIAs = "AssignedPrivateIpAddresses";
    var _APIAss = "AssociatePublicIpAddress";
    var _APIAssi = "AssignPrivateIpAddresses";
    var _APICB = "AmazonProvidedIpv6CidrBlock";
    var _APLE = "AddPrefixListEntry";
    var _APLEd = "AddPrefixListEntries";
    var _APM = "ApplyPendingMaintenance";
    var _APNGA = "AssignPrivateNatGatewayAddress";
    var _APNGAR = "AssignPrivateNatGatewayAddressRequest";
    var _APNGARs = "AssignPrivateNatGatewayAddressResult";
    var _APS = "AddedPrincipalSet";
    var _APSl = "AllowedPrincipalSet";
    var _APZ = "AutoProvisionZones";
    var _APd = "AddedPrincipals";
    var _APl = "AllowedPrincipal";
    var _APll = "AllowedPrincipals";
    var _APs = "AsPaths";
    var _APsa = "AsPath";
    var _APu = "AutoPlacement";
    var _AR10 = "AllowReassignment";
    var _ARA = "AssociatedRoleArn";
    var _ARAd = "AdditionalRoutesAvailable";
    var _ARAs = "AssociatedResourceAccessibility";
    var _ARAss = "AssociatedResourceArn";
    var _ARC = "AcceptedRouteCount";
    var _ARIEQ = "AcceptReservedInstancesExchangeQuote";
    var _ARIEQR = "AcceptReservedInstancesExchangeQuoteRequest";
    var _ARIEQRc = "AcceptReservedInstancesExchangeQuoteResult";
    var _ARL = "AssociatedRolesList";
    var _ARP = "AreRoutesPersisted";
    var _ARS = "AutoRecoverySupported";
    var _ARSR = "AssociateRouteServerRequest";
    var _ARSRs = "AssociateRouteServerResult";
    var _ARSs = "AssociateRouteServer";
    var _ARSu = "AuthorizationRuleSet";
    var _ART = "AllocationResourceTags";
    var _ARTI = "AddRouteTableIds";
    var _ARTId = "AddRouteTableId";
    var _ARTR = "AnalysisRouteTableRoute";
    var _ARTRs = "AssociateRouteTableRequest";
    var _ARTRss = "AssociateRouteTableResult";
    var _ARTl = "AllocationResourceTag";
    var _ARTs = "AssociateRouteTable";
    var _ARc = "AcceptanceRequired";
    var _ARcl = "AclRule";
    var _ARd = "AddressRegion";
    var _ARl = "AllowReassociation";
    var _ARll = "AllRegions";
    var _ARllo = "AllocationRules";
    var _ARlloc = "AllocationRule";
    var _ARs = "AssociatedRole";
    var _ARss = "AssociatedResource";
    var _ARsso = "AssociatedRoles";
    var _ARu = "AuthorizationRule";
    var _ARut = "AuthorizationRules";
    var _ARuto = "AutoRecovery";
    var _ARw = "AwsRegion";
    var _AS = "AssociationState";
    var _ASA = "AmazonSideAsn";
    var _ASAF = "AccessScopeAnalysisFinding";
    var _ASAFL = "AccessScopeAnalysisFindingList";
    var _ASCB = "AssociateSubnetCidrBlock";
    var _ASCBR = "AssociateSubnetCidrBlockRequest";
    var _ASCBRs = "AssociateSubnetCidrBlockResult";
    var _ASGE = "AuthorizeSecurityGroupEgress";
    var _ASGER = "AuthorizeSecurityGroupEgressRequest";
    var _ASGERu = "AuthorizeSecurityGroupEgressResult";
    var _ASGI = "AddSecurityGroupIds";
    var _ASGIR = "AuthorizeSecurityGroupIngressRequest";
    var _ASGIRu = "AuthorizeSecurityGroupIngressResult";
    var _ASGId = "AddSecurityGroupId";
    var _ASGIu = "AuthorizeSecurityGroupIngress";
    var _ASGR = "AnalysisSecurityGroupRule";
    var _ASGTCVTN = "ApplySecurityGroupsToClientVpnTargetNetwork";
    var _ASGTCVTNR = "ApplySecurityGroupsToClientVpnTargetNetworkRequest";
    var _ASGTCVTNRp = "ApplySecurityGroupsToClientVpnTargetNetworkResult";
    var _ASGV = "AssociateSecurityGroupVpc";
    var _ASGVR = "AssociateSecurityGroupVpcRequest";
    var _ASGVRs = "AssociateSecurityGroupVpcResult";
    var _ASI = "AssociatedSubnetIds";
    var _ASIAT = "AddSupportedIpAddressTypes";
    var _ASIATd = "AddSupportedIpAddressType";
    var _ASId = "AddSubnetIds";
    var _ASIdd = "AddSubnetId";
    var _ASIs = "AssociatedSubnetId";
    var _ASIu = "AutoScalingIps";
    var _ASL = "AssociatedSubnetList";
    var _ASLt = "AttributeSummaryList";
    var _ASP = "AccessScopePath";
    var _ASPL = "AccessScopePathList";
    var _ASPLR = "AccessScopePathListRequest";
    var _ASPR = "AccessScopePathRequest";
    var _ASR = "AddSupportedRegions";
    var _ASRd = "AddSupportedRegion";
    var _ASS = "AmdSevSnp";
    var _AST = "AnalysisStartTime";
    var _ASTB = "AnalysisStartTimeBegin";
    var _ASTE = "AnalysisStartTimeEnd";
    var _ASc = "ActivityStatus";
    var _ASd = "AddressSet";
    var _ASl = "AllocationStrategy";
    var _ASn = "AnalysisStatus";
    var _ASs = "AssociationStatus";
    var _ASss = "AssociatedSubnets";
    var _ASt = "AttributeSummary";
    var _AStt = "AttributeSummaries";
    var _AStta = "AttachmentState";
    var _ASttac = "AttachmentStatuses";
    var _ASw = "AwsService";
    var _AT13 = "AddressTransfer";
    var _ATGAI = "AccepterTransitGatewayAttachmentId";
    var _ATGCB = "AddTransitGatewayCidrBlocks";
    var _ATGCVA = "AcceptTransitGatewayClientVpnAttachment";
    var _ATGCVAR = "AcceptTransitGatewayClientVpnAttachmentRequest";
    var _ATGCVARc = "AcceptTransitGatewayClientVpnAttachmentResult";
    var _ATGMD = "AssociateTransitGatewayMulticastDomain";
    var _ATGMDA = "AcceptTransitGatewayMulticastDomainAssociations";
    var _ATGMDAR = "AcceptTransitGatewayMulticastDomainAssociationsRequest";
    var _ATGMDARc = "AcceptTransitGatewayMulticastDomainAssociationsResult";
    var _ATGMDR = "AssociateTransitGatewayMulticastDomainRequest";
    var _ATGMDRs = "AssociateTransitGatewayMulticastDomainResult";
    var _ATGPA = "AcceptTransitGatewayPeeringAttachment";
    var _ATGPAR = "AcceptTransitGatewayPeeringAttachmentRequest";
    var _ATGPARc = "AcceptTransitGatewayPeeringAttachmentResult";
    var _ATGPT = "AssociateTransitGatewayPolicyTable";
    var _ATGPTR = "AssociateTransitGatewayPolicyTableRequest";
    var _ATGPTRs = "AssociateTransitGatewayPolicyTableResult";
    var _ATGRT = "AssociateTransitGatewayRouteTable";
    var _ATGRTR = "AssociateTransitGatewayRouteTableRequest";
    var _ATGRTRs = "AssociateTransitGatewayRouteTableResult";
    var _ATGVA = "AcceptTransitGatewayVpcAttachment";
    var _ATGVAR = "AcceptTransitGatewayVpcAttachmentRequest";
    var _ATGVARc = "AcceptTransitGatewayVpcAttachmentResult";
    var _ATI = "AccepterTgwInfo";
    var _ATIR = "AssociateTrunkInterfaceRequest";
    var _ATIRs = "AssociateTrunkInterfaceResult";
    var _ATIs = "AssociateTrunkInterface";
    var _ATK = "ActivateTagKeys";
    var _ATKc = "ActivateTagKey";
    var _ATL = "AddressTransferList";
    var _ATLr = "ArchitectureTypeList";
    var _ATMMB = "AcceleratorTotalMemoryMiB";
    var _ATMMBR = "AcceleratorTotalMemoryMiBRequest";
    var _ATN = "AssociatedTargetNetwork";
    var _ATNS = "AssociatedTargetNetworkSet";
    var _ATNs = "AssociatedTargetNetworks";
    var _ATS = "AddressTransferStatus";
    var _ATSc = "AcceleratorTypeSet";
    var _ATSr = "ArchitectureTypeSet";
    var _ATc = "AcceleratorTypes";
    var _ATcc = "AcceleratorType";
    var _ATd = "AdvertisementType";
    var _ATdd = "AddressTransfers";
    var _ATddr = "AddressType";
    var _ATddre = "AddressingType";
    var _ATl = "AllocationType";
    var _ATll = "AllocationTime";
    var _ATr = "ArchitectureTypes";
    var _ATrc = "ArchitectureType";
    var _ATs = "AssociationTarget";
    var _ATt = "AttachmentType";
    var _ATtt = "AttachTime";
    var _ATtta = "AttachedTo";
    var _AV = "AttributeValues";
    var _AVATP = "AttachVerifiedAccessTrustProvider";
    var _AVATPR = "AttachVerifiedAccessTrustProviderRequest";
    var _AVATPRt = "AttachVerifiedAccessTrustProviderResult";
    var _AVC = "AvailableVCpus";
    var _AVCB = "AssociateVpcCidrBlock";
    var _AVCBR = "AssociateVpcCidrBlockRequest";
    var _AVCBRs = "AssociateVpcCidrBlockResult";
    var _AVEC = "AcceptVpcEndpointConnections";
    var _AVECR = "AcceptVpcEndpointConnectionsRequest";
    var _AVECRc = "AcceptVpcEndpointConnectionsResult";
    var _AVG = "AttachVpnGateway";
    var _AVGR = "AttachVpnGatewayRequest";
    var _AVGRt = "AttachVpnGatewayResult";
    var _AVI = "AccepterVpcInfo";
    var _AVPC = "AcceptVpcPeeringConnection";
    var _AVPCR = "AcceptVpcPeeringConnectionRequest";
    var _AVPCRc = "AcceptVpcPeeringConnectionResult";
    var _AVR = "AttachVolumeRequest";
    var _AVTS = "ActiveVpnTunnelStatus";
    var _AVt = "AttributeValue";
    var _AVtt = "AttachVolume";
    var _AWSAKI = "AWSAccessKeyId";
    var _AZ = "AvailabilityZone";
    var _AZA = "AvailabilityZoneAddress";
    var _AZAv = "AvailabilityZoneAddresses";
    var _AZG = "AvailabilityZoneGeography";
    var _AZGL = "AvailabilityZoneGeographyList";
    var _AZGv = "AvailabilityZoneGroup";
    var _AZI = "AvailabilityZoneId";
    var _AZISL = "AvailabilityZoneIdStringList";
    var _AZIv = "AvailabilityZoneIds";
    var _AZL = "AvailabilityZoneList";
    var _AZM = "AvailabilityZoneMessage";
    var _AZML = "AvailabilityZoneMessageList";
    var _AZSG = "AvailabilityZoneSubGeography";
    var _AZSGL = "AvailabilityZoneSubGeographyList";
    var _AZSL = "AvailabilityZoneStringList";
    var _AZv = "AvailabilityZones";
    var _Ac = "Acl";
    var _Acc = "Accelerators";
    var _Acce = "Accept";
    var _Act = "Active";
    var _Acti = "Actions";
    var _Ad = "Add";
    var _Add = "Addresses";
    var _Af = "Affinity";
    var _Am = "Amount";
    var _Ar = "Arn";
    var _Arc = "Architecture";
    var _As = "Associations";
    var _Asn = "Asn";
    var _Ass = "Association";
    var _At = "Attribute";
    var _Att = "Attachment";
    var _Atta = "Attachments";
    var _Au10 = "Authentication";
    var _B = "Byoasn";
    var _BA = "BgpAsn";
    var _BAE = "BgpAsnExtended";
    var _BAV = "BlobAttributeValue";
    var _BBIG = "BaselineBandwidthInGbps";
    var _BBIM = "BaselineBandwidthInMbps";
    var _BC = "ByoipCidr";
    var _BCS = "ByoipCidrSet";
    var _BCg = "BgpConfigurations";
    var _BCy = "ByoipCidrs";
    var _BCyt = "BytesConverted";
    var _BDM = "BlockDeviceMapping";
    var _BDML = "BlockDeviceMappingList";
    var _BDMR = "BlockDeviceMappingResponse";
    var _BDMRL = "BlockDeviceMappingRequestList";
    var _BDMRLl = "BlockDeviceMappingResponseList";
    var _BDMl = "BlockDeviceMappings";
    var _BDMlo = "BlockDurationMinutes";
    var _BEBM = "BaselineEbsBandwidthMbps";
    var _BEBMR = "BaselineEbsBandwidthMbpsRequest";
    var _BEDN = "BaseEndpointDnsNames";
    var _BI = "BundleId";
    var _BII = "BranchInterfaceId";
    var _BIR = "BundleInstanceRequest";
    var _BIRu = "BundleInstanceResult";
    var _BISL = "BundleIdStringList";
    var _BIa = "BaselineIops";
    var _BIu = "BundleIds";
    var _BIun = "BundleInstance";
    var _BLE = "BgpLogEnabled";
    var _BLGA = "BgpLogGroupArn";
    var _BLOF = "BgpLogOutputFormat";
    var _BM = "BootMode";
    var _BMTL = "BootModeTypeList";
    var _BMa = "BareMetal";
    var _BN = "BucketName";
    var _BO = "BgpOptions";
    var _BOu = "BucketOwner";
    var _BP = "BurstablePerformance";
    var _BPAS = "BlockPublicAccessStates";
    var _BPF = "BaselinePerformanceFactors";
    var _BPFR = "BaselinePerformanceFactorsRequest";
    var _BPL = "BillingProductList";
    var _BPS = "BurstablePerformanceSupported";
    var _BPi = "BillingProducts";
    var _BPil = "BillingProduct";
    var _BS = "BaseSystem";
    var _BSf = "BfdStatus";
    var _BSg = "BgpStatus";
    var _BSy = "ByoasnSet";
    var _BT = "BundleTask";
    var _BTE = "BundleTaskError";
    var _BTIMB = "BaselineThroughputInMBps";
    var _BTL = "BundleTaskList";
    var _BTa = "BannerText";
    var _BTu = "BundleTasks";
    var _BW = "BandwidthWeighting";
    var _BWTL = "BandwidthWeightingTypeList";
    var _BWa = "BandwidthWeightings";
    var _Bl = "Blackhole";
    var _Bu = "Bucket";
    var _By = "Byoasns";
    var _Byt = "Bytes";
    var _C11 = "Component";
    var _CA10 = "ComponentArn";
    var _CAC = "CidrAuthorizationContext";
    var _CADNL = "ClearAllocationDefaultNetmaskLength";
    var _CAME = "CapacityAllocationMetadataEntry";
    var _CAML = "CapacityAllocationMetadataList";
    var _CAR = "CertificateAuthenticationRequest";
    var _CAU = "CoipAddressUsage";
    var _CAUS = "CoipAddressUsageSet";
    var _CAUo = "CoipAddressUsages";
    var _CAa = "CapacityAllocation";
    var _CAap = "CapacityAllocations";
    var _CAe = "CertificateArn";
    var _CAer = "CertificateAuthentication";
    var _CAo = "ComponentAccount";
    var _CAr = "CreatedAt";
    var _CB = "CidrBlock";
    var _CBA = "CidrBlockAssociation";
    var _CBAS = "CidrBlockAssociationSet";
    var _CBDH = "CapacityBlockDurationHours";
    var _CBDM = "CapacityBlockDurationMinutes";
    var _CBE = "CapacityBlockExtension";
    var _CBEDH = "CapacityBlockExtensionDurationHours";
    var _CBEED = "CapacityBlockExtensionEndDate";
    var _CBEO = "CapacityBlockExtensionOffering";
    var _CBEOI = "CapacityBlockExtensionOfferingId";
    var _CBEOS = "CapacityBlockExtensionOfferingSet";
    var _CBEOa = "CapacityBlockExtensionOfferings";
    var _CBEPD = "CapacityBlockExtensionPurchaseDate";
    var _CBES = "CapacityBlockExtensionStatus";
    var _CBESD = "CapacityBlockExtensionStartDate";
    var _CBESa = "CapacityBlockExtensionSet";
    var _CBEa = "CapacityBlockExtensions";
    var _CBI = "CapacityBlockId";
    var _CBIa = "CapacityBlockIds";
    var _CBO = "CapacityBlockOffering";
    var _CBOI = "CapacityBlockOfferingId";
    var _CBOS = "CapacityBlockOfferingSet";
    var _CBOa = "CapacityBlockOfferings";
    var _CBS = "CapacityBlockStatus";
    var _CBSS = "CapacityBlockStatusSet";
    var _CBSa = "CapacityBlockStatuses";
    var _CBSap = "CapacityBlockSet";
    var _CBSi = "CidrBlockState";
    var _CBSid = "CidrBlockSet";
    var _CBT = "CancelBundleTask";
    var _CBTR = "CancelBundleTaskRequest";
    var _CBTRa = "CancelBundleTaskResult";
    var _CBa = "CapacityBlock";
    var _CBap = "CapacityBlocks";
    var _CBr = "CreatedBy";
    var _CC = "CurrencyCode";
    var _CCB = "ClientCidrBlock";
    var _CCC = "CreateCoipCidr";
    var _CCCR = "CreateCoipCidrRequest";
    var _CCCRr = "CreateCoipCidrResult";
    var _CCG = "CreateCarrierGateway";
    var _CCGR = "CreateCarrierGatewayRequest";
    var _CCGRr = "CreateCarrierGatewayResult";
    var _CCGRre = "CreateCustomerGatewayRequest";
    var _CCGRrea = "CreateCustomerGatewayResult";
    var _CCGr = "CreateCustomerGateway";
    var _CCL = "CoreCountList";
    var _CCMDE = "CreateCapacityManagerDataExport";
    var _CCMDER = "CreateCapacityManagerDataExportRequest";
    var _CCMDERr = "CreateCapacityManagerDataExportResult";
    var _CCO = "ClientConnectOptions";
    var _CCP = "CreateCoipPool";
    var _CCPR = "CreateCoipPoolRequest";
    var _CCPRr = "CreateCoipPoolResult";
    var _CCR = "CancelConversionRequest";
    var _CCRBS = "CreateCapacityReservationBySplitting";
    var _CCRBSR = "CreateCapacityReservationBySplittingRequest";
    var _CCRBSRr = "CreateCapacityReservationBySplittingResult";
    var _CCRF = "CancelCapacityReservationFleets";
    var _CCRFE = "CancelCapacityReservationFleetError";
    var _CCRFR = "CancelCapacityReservationFleetsRequest";
    var _CCRFRa = "CancelCapacityReservationFleetsResult";
    var _CCRFRr = "CreateCapacityReservationFleetRequest";
    var _CCRFRre = "CreateCapacityReservationFleetResult";
    var _CCRFr = "CreateCapacityReservationFleet";
    var _CCRLS = "ClientCertificateRevocationListStatus";
    var _CCRO = "ClientConnectResponseOptions";
    var _CCRR = "CancelCapacityReservationRequest";
    var _CCRRa = "CancelCapacityReservationResult";
    var _CCRRr = "CreateCapacityReservationRequest";
    var _CCRRre = "CreateCapacityReservationResult";
    var _CCRa = "CancelCapacityReservation";
    var _CCRr = "CreateCapacityReservation";
    var _CCT = "CancelConversionTask";
    var _CCVE = "CreateClientVpnEndpoint";
    var _CCVER = "CreateClientVpnEndpointRequest";
    var _CCVERr = "CreateClientVpnEndpointResult";
    var _CCVR = "CreateClientVpnRoute";
    var _CCVRR = "CreateClientVpnRouteRequest";
    var _CCVRRr = "CreateClientVpnRouteResult";
    var _CCl = "ClientConfiguration";
    var _CCo = "CoipCidr";
    var _CCor = "CoreCount";
    var _CCp = "CpuCredits";
    var _CD = "CreateDate";
    var _CDC = "CreationDateCondition";
    var _CDCR = "CreationDateConditionRequest";
    var _CDH = "CapacityDurationHours";
    var _CDM = "CompletionDurationMinutes";
    var _CDMVOT = "CreateDelegateMacVolumeOwnershipTask";
    var _CDMVOTR = "CreateDelegateMacVolumeOwnershipTaskRequest";
    var _CDMVOTRr = "CreateDelegateMacVolumeOwnershipTaskResult";
    var _CDO = "CreateDhcpOptions";
    var _CDOR = "CreateDhcpOptionsRequest";
    var _CDORr = "CreateDhcpOptionsResult";
    var _CDPR = "CancelDeclarativePoliciesReport";
    var _CDPRR = "CancelDeclarativePoliciesReportRequest";
    var _CDPRRa = "CancelDeclarativePoliciesReportResult";
    var _CDS = "CustomDnsServers";
    var _CDSDA = "ConfigDeliveryS3DestinationArn";
    var _CDSR = "CreateDefaultSubnetRequest";
    var _CDSRr = "CreateDefaultSubnetResult";
    var _CDSr = "CreateDefaultSubnet";
    var _CDV = "CreateDefaultVpc";
    var _CDVR = "CreateDefaultVpcRequest";
    var _CDVRr = "CreateDefaultVpcResult";
    var _CDl = "ClientData";
    var _CDo = "CommitmentDuration";
    var _CDr = "CreationDate";
    var _CDre = "CreatedDate";
    var _CE = "ConnectionEvents";
    var _CECSD = "CidrEndpointsCustomSubDomain";
    var _CED = "CommitmentEndDate";
    var _CEOIG = "CreateEgressOnlyInternetGateway";
    var _CEOIGR = "CreateEgressOnlyInternetGatewayRequest";
    var _CEOIGRr = "CreateEgressOnlyInternetGatewayResult";
    var _CET = "ConnectionEstablishedTime";
    var _CETR = "CancelExportTaskRequest";
    var _CETa = "CancelExportTask";
    var _CETo = "ConnectionEndTime";
    var _CEr = "CronExpression";
    var _CF = "ContainerFormat";
    var _CFE = "CreateFleetError";
    var _CFES = "CreateFleetErrorsSet";
    var _CFI = "CreateFleetInstance";
    var _CFIR = "CopyFpgaImageRequest";
    var _CFIRo = "CopyFpgaImageResult";
    var _CFIRr = "CreateFpgaImageRequest";
    var _CFIRre = "CreateFpgaImageResult";
    var _CFIS = "CreateFleetInstancesSet";
    var _CFIo = "CopyFpgaImage";
    var _CFIr = "CreateFpgaImage";
    var _CFL = "CreateFlowLogs";
    var _CFLR = "CreateFlowLogsRequest";
    var _CFLRr = "CreateFlowLogsResult";
    var _CFR = "CreateFleetRequest";
    var _CFRr = "CreateFleetResult";
    var _CFS = "CurrentFleetState";
    var _CFr = "CreateFleet";
    var _CG = "CarrierGateway";
    var _CGC = "CustomerGatewayConfiguration";
    var _CGI = "CarrierGatewayId";
    var _CGISL = "CustomerGatewayIdStringList";
    var _CGIa = "CarrierGatewayIds";
    var _CGIu = "CustomerGatewayId";
    var _CGIus = "CustomerGatewayIds";
    var _CGL = "CustomerGatewayList";
    var _CGS = "CarrierGatewaySet";
    var _CGa = "CarrierGateways";
    var _CGu = "CustomerGateway";
    var _CGur = "CurrentGeneration";
    var _CGus = "CustomerGateways";
    var _CI = "CarrierIp";
    var _CIA = "ClientIpv6Address";
    var _CIBM = "CurrentInstanceBootMode";
    var _CIC = "CommittedInstanceCount";
    var _CICE = "CreateInstanceConnectEndpoint";
    var _CICER = "CreateInstanceConnectEndpointRequest";
    var _CICERr = "CreateInstanceConnectEndpointResult";
    var _CICRA = "CreateInterruptibleCapacityReservationAllocation";
    var _CICRAR = "CreateInterruptibleCapacityReservationAllocationRequest";
    var _CICRARr = "CreateInterruptibleCapacityReservationAllocationResult";
    var _CIERVT = "CreateIpamExternalResourceVerificationToken";
    var _CIERVTR = "CreateIpamExternalResourceVerificationTokenRequest";
    var _CIERVTRr = "CreateIpamExternalResourceVerificationTokenResult";
    var _CIET = "CreateInstanceExportTask";
    var _CIETR = "CreateInstanceExportTaskRequest";
    var _CIETRr = "CreateInstanceExportTaskResult";
    var _CIEW = "CreateInstanceEventWindow";
    var _CIEWR = "CreateInstanceEventWindowRequest";
    var _CIEWRr = "CreateInstanceEventWindowResult";
    var _CIG = "CreateInternetGateway";
    var _CIGR = "CreateInternetGatewayRequest";
    var _CIGRr = "CreateInternetGatewayResult";
    var _CILP = "CancelImageLaunchPermission";
    var _CILPR = "CancelImageLaunchPermissionRequest";
    var _CILPRa = "CancelImageLaunchPermissionResult";
    var _CIP = "CreateIpamPolicy";
    var _CIPLR = "CreateIpamPrefixListResolver";
    var _CIPLRR = "CreateIpamPrefixListResolverRequest";
    var _CIPLRRr = "CreateIpamPrefixListResolverResult";
    var _CIPLRT = "CreateIpamPrefixListResolverTarget";
    var _CIPLRTR = "CreateIpamPrefixListResolverTargetRequest";
    var _CIPLRTRr = "CreateIpamPrefixListResolverTargetResult";
    var _CIPR = "CreateIpamPolicyRequest";
    var _CIPRr = "CreateIpamPolicyResult";
    var _CIPRre = "CreateIpamPoolRequest";
    var _CIPRrea = "CreateIpamPoolResult";
    var _CIPr = "CreateIpamPool";
    var _CIR = "CopyImageRequest";
    var _CIRD = "CreateIpamResourceDiscovery";
    var _CIRDR = "CreateIpamResourceDiscoveryRequest";
    var _CIRDRr = "CreateIpamResourceDiscoveryResult";
    var _CIRo = "CopyImageResult";
    var _CIRr = "CreateImageRequest";
    var _CIRre = "CreateImageResult";
    var _CIRrea = "CreateIpamRequest";
    var _CIRreat = "CreateIpamResult";
    var _CIS = "CreateIpamScope";
    var _CISI = "CurrentIpamScopeId";
    var _CISL = "ConversionIdStringList";
    var _CISR = "CreateIpamScopeRequest";
    var _CISRr = "CreateIpamScopeResult";
    var _CIT = "CopyImageTags";
    var _CITR = "CancelImportTaskRequest";
    var _CITRa = "CancelImportTaskResult";
    var _CITa = "CancelImportTask";
    var _CIUR = "CreateImageUsageReport";
    var _CIURR = "CreateImageUsageReportRequest";
    var _CIURRr = "CreateImageUsageReportResult";
    var _CIi = "CidrIp";
    var _CIid = "CidrIpv6";
    var _CIidr = "CidrIpv4";
    var _CIl = "ClientIp";
    var _CIli = "ClientId";
    var _CIo = "ComponentId";
    var _CIom = "CommitmentInfo";
    var _CIon = "ConnectionId";
    var _CIop = "CoIp";
    var _CIopy = "CopyImage";
    var _CIor = "CoreInfo";
    var _CIr = "CreateImage";
    var _CIre = "CreateIpam";
    var _CKP = "CreateKeyPair";
    var _CKPR = "CreateKeyPairRequest";
    var _CLB = "ClassicLoadBalancer";
    var _CLBC = "ClassicLoadBalancersConfig";
    var _CLBL = "ClassicLoadBalancerListener";
    var _CLBO = "ClientLoginBannerOptions";
    var _CLBRO = "ClientLoginBannerResponseOptions";
    var _CLBl = "ClassicLoadBalancers";
    var _CLDS = "ClassicLinkDnsSupport";
    var _CLDSL = "ClassicLinkDnsSupportList";
    var _CLDSl = "ClassicLinkDnsSupported";
    var _CLE = "ClassicLinkEnabled";
    var _CLG = "CloudwatchLogGroup";
    var _CLGR = "CreateLocalGatewayRoute";
    var _CLGRR = "CreateLocalGatewayRouteRequest";
    var _CLGRRr = "CreateLocalGatewayRouteResult";
    var _CLGRT = "CreateLocalGatewayRouteTable";
    var _CLGRTR = "CreateLocalGatewayRouteTableRequest";
    var _CLGRTRr = "CreateLocalGatewayRouteTableResult";
    var _CLGRTVA = "CreateLocalGatewayRouteTableVpcAssociation";
    var _CLGRTVAR = "CreateLocalGatewayRouteTableVpcAssociationRequest";
    var _CLGRTVARr = "CreateLocalGatewayRouteTableVpcAssociationResult";
    var _CLGRTVIGA = "CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociation";
    var _CLGRTVIGAR = "CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest";
    var _CLGRTVIGARr = "CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationResult";
    var _CLGVI = "CreateLocalGatewayVirtualInterface";
    var _CLGVIG = "CreateLocalGatewayVirtualInterfaceGroup";
    var _CLGVIGR = "CreateLocalGatewayVirtualInterfaceGroupRequest";
    var _CLGVIGRr = "CreateLocalGatewayVirtualInterfaceGroupResult";
    var _CLGVIR = "CreateLocalGatewayVirtualInterfaceRequest";
    var _CLGVIRr = "CreateLocalGatewayVirtualInterfaceResult";
    var _CLI = "ClassicLinkInstance";
    var _CLIL = "ClassicLinkInstanceList";
    var _CLO = "ConnectionLogOptions";
    var _CLRO = "ConnectionLogResponseOptions";
    var _CLS = "CloudwatchLogStream";
    var _CLT = "CreateLaunchTemplate";
    var _CLTR = "CreateLaunchTemplateRequest";
    var _CLTRr = "CreateLaunchTemplateResult";
    var _CLTV = "CreateLaunchTemplateVersion";
    var _CLTVR = "CreateLaunchTemplateVersionRequest";
    var _CLTVRr = "CreateLaunchTemplateVersionResult";
    var _CM = "CpuManufacturers";
    var _CMC = "CapacityManagerCondition";
    var _CMCS = "CapacityManagerConditionSet";
    var _CMD = "CapacityManagerDimension";
    var _CMDE = "CapacityManagerDataExports";
    var _CMDEI = "CapacityManagerDataExportId";
    var _CMDEIS = "CapacityManagerDataExportIdSet";
    var _CMDEIa = "CapacityManagerDataExportIds";
    var _CMDER = "CapacityManagerDataExportResponse";
    var _CMDERS = "CapacityManagerDataExportResponseSet";
    var _CMKE = "CustomerManagedKeyEnabled";
    var _CMMTK = "CapacityManagerMonitoredTagKey";
    var _CMMTKL = "CapacityManagerMonitoredTagKeyList";
    var _CMP = "CapacityManagerProvided";
    var _CMPL = "CreateManagedPrefixList";
    var _CMPLR = "CreateManagedPrefixListRequest";
    var _CMPLRr = "CreateManagedPrefixListResult";
    var _CMS = "CapacityManagerStatus";
    var _CMSIPMT = "CreateMacSystemIntegrityProtectionModificationTask";
    var _CMSIPMTR = "CreateMacSystemIntegrityProtectionModificationTaskRequest";
    var _CMSIPMTRr = "CreateMacSystemIntegrityProtectionModificationTaskResult";
    var _CMSp = "CpuManufacturerSet";
    var _CMTD = "CapacityManagerTagDimension";
    var _CMTDS = "CapacityManagerTagDimensionSet";
    var _CMTK = "CapacityManagerTagKeys";
    var _CMp = "CpuManufacturer";
    var _CN = "CommonName";
    var _CNA = "CoreNetworkArn";
    var _CNAA = "CoreNetworkAttachmentArn";
    var _CNAE = "CreateNetworkAclEntry";
    var _CNAER = "CreateNetworkAclEntryRequest";
    var _CNAR = "CreateNetworkAclRequest";
    var _CNARr = "CreateNetworkAclResult";
    var _CNAo = "ConnectionNotificationArn";
    var _CNAr = "CreateNetworkAcl";
    var _CNG = "CreateNatGateway";
    var _CNGR = "CreateNatGatewayRequest";
    var _CNGRr = "CreateNatGatewayResult";
    var _CNI = "ConnectionNotificationId";
    var _CNIAS = "CreateNetworkInsightsAccessScope";
    var _CNIASR = "CreateNetworkInsightsAccessScopeRequest";
    var _CNIASRr = "CreateNetworkInsightsAccessScopeResult";
    var _CNIL = "ConnectionNotificationIdsList";
    var _CNIP = "CreateNetworkInsightsPath";
    var _CNIPR = "CreateNetworkInsightsPathRequest";
    var _CNIPRr = "CreateNetworkInsightsPathResult";
    var _CNIPRre = "CreateNetworkInterfacePermissionRequest";
    var _CNIPRrea = "CreateNetworkInterfacePermissionResult";
    var _CNIPr = "CreateNetworkInterfacePermission";
    var _CNIR = "CreateNetworkInterfaceRequest";
    var _CNIRr = "CreateNetworkInterfaceResult";
    var _CNIo = "ConnectionNotificationIds";
    var _CNIor = "CoreNetworkId";
    var _CNIr = "CreateNetworkInterface";
    var _CNS = "ConnectionNotificationState";
    var _CNSo = "ConnectionNotificationSet";
    var _CNT = "ConnectionNotificationType";
    var _CNo = "ConnectionNotification";
    var _CO = "CpuOptions";
    var _COI = "CustomerOwnedIp";
    var _COIP = "CustomerOwnedIpv4Pool";
    var _COP = "CoolOffPeriod";
    var _COPEO = "CoolOffPeriodExpiresOn";
    var _COR = "CpuOptionsRequest";
    var _COi = "CidrOptions";
    var _CP = "CoipPool";
    var _CPC = "ConnectPeerConfiguration";
    var _CPF = "CpuPerformanceFactor";
    var _CPFR = "CpuPerformanceFactorRequest";
    var _CPG = "CreatePlacementGroup";
    var _CPGR = "CreatePlacementGroupRequest";
    var _CPGRr = "CreatePlacementGroupResult";
    var _CPI = "CoipPoolId";
    var _CPIP = "CreatePublicIpv4Pool";
    var _CPIPR = "CreatePublicIpv4PoolRequest";
    var _CPIPRr = "CreatePublicIpv4PoolResult";
    var _CPIR = "ConfirmProductInstanceRequest";
    var _CPIRo = "ConfirmProductInstanceResult";
    var _CPIS = "CoipPoolIdSet";
    var _CPIo = "ConfirmProductInstance";
    var _CPS = "CoipPoolSet";
    var _CPo = "CoipPools";
    var _CR = "CancelReason";
    var _CRA2 = "CapacityReservationArn";
    var _CRBR = "CapacityReservationBillingRequest";
    var _CRBRS = "CapacityReservationBillingRequestSet";
    var _CRBRa = "CapacityReservationBillingRequests";
    var _CRCC = "ClientRootCertificateChain";
    var _CRCCA = "ClientRootCertificateChainArn";
    var _CRCI = "CapacityReservationCommitmentInfo";
    var _CREO = "ClientRouteEnforcementOptions";
    var _CRERO = "ClientRouteEnforcementResponseOptions";
    var _CRF = "CapacityReservationFleet";
    var _CRFA = "CapacityReservationFleetArn";
    var _CRFCS = "CapacityReservationFleetCancellationState";
    var _CRFCSS = "CapacityReservationFleetCancellationStateSet";
    var _CRFI = "CapacityReservationFleetIds";
    var _CRFIS = "CapacityReservationFleetIdSet";
    var _CRFIa = "CapacityReservationFleetId";
    var _CRFS = "CapacityReservationFleetSet";
    var _CRFa = "CapacityReservationFleets";
    var _CRG = "CapacityReservationGroup";
    var _CRGS = "CapacityReservationGroupSet";
    var _CRGa = "CapacityReservationGroups";
    var _CRI = "CapacityReservationId";
    var _CRIL = "CancelReservedInstancesListing";
    var _CRILR = "CancelReservedInstancesListingRequest";
    var _CRILRa = "CancelReservedInstancesListingResult";
    var _CRILRr = "CreateReservedInstancesListingRequest";
    var _CRILRre = "CreateReservedInstancesListingResult";
    var _CRILr = "CreateReservedInstancesListing";
    var _CRIS = "CapacityReservationIdSet";
    var _CRIT = "CreateRestoreImageTask";
    var _CRITR = "CreateRestoreImageTaskRequest";
    var _CRITRr = "CreateRestoreImageTaskResult";
    var _CRIa = "CapacityReservationIds";
    var _CRIap = "CapacityReservationInfo";
    var _CRL = "CertificateRevocationList";
    var _CRO = "CapacityReservationOptions";
    var _CROR = "CapacityReservationOptionsRequest";
    var _CRP = "CapacityReservationPreference";
    var _CRR = "CreateRouteRequest";
    var _CRRGA = "CapacityReservationResourceGroupArn";
    var _CRRVT = "CreateReplaceRootVolumeTask";
    var _CRRVTR = "CreateReplaceRootVolumeTaskRequest";
    var _CRRVTRr = "CreateReplaceRootVolumeTaskResult";
    var _CRRr = "CreateRouteResult";
    var _CRS = "CapacityReservationStatuses";
    var _CRSE = "CreateRouteServerEndpoint";
    var _CRSER = "CreateRouteServerEndpointRequest";
    var _CRSERr = "CreateRouteServerEndpointResult";
    var _CRSP = "CreateRouteServerPeer";
    var _CRSPR = "CreateRouteServerPeerRequest";
    var _CRSPRr = "CreateRouteServerPeerResult";
    var _CRSR = "CapacityReservationSpecificationResponse";
    var _CRSRr = "CreateRouteServerRequest";
    var _CRSRre = "CreateRouteServerResult";
    var _CRSS = "CapacityReservationStatusSet";
    var _CRSa = "CapacityReservationSpecification";
    var _CRSap = "CapacityReservationStatus";
    var _CRSapa = "CapacityReservationSet";
    var _CRSr = "CreateRouteServer";
    var _CRT = "CapacityReservationTarget";
    var _CRTR = "CapacityReservationTargetResponse";
    var _CRTRr = "CreateRouteTableRequest";
    var _CRTRre = "CreateRouteTableResult";
    var _CRTS = "CapacityReservationTopologySet";
    var _CRTa = "CapacityReservationTopology";
    var _CRTr = "CreateRouteTable";
    var _CRa = "CapacityReservation";
    var _CRap = "CapacityReservations";
    var _CRapa = "CapacityRebalance";
    var _CRo = "ComponentRegion";
    var _CRr = "CreateRoute";
    var _CS4 = "ClientSecret";
    var _CSBN = "CertificateS3BucketName";
    var _CSCR = "CreateSubnetCidrReservation";
    var _CSCRR = "CreateSubnetCidrReservationRequest";
    var _CSCRRr = "CreateSubnetCidrReservationResult";
    var _CSDS = "CreateSpotDatafeedSubscription";
    var _CSDSR = "CreateSpotDatafeedSubscriptionRequest";
    var _CSDSRr = "CreateSpotDatafeedSubscriptionResult";
    var _CSFR = "CancelSpotFleetRequests";
    var _CSFRE = "CancelSpotFleetRequestsError";
    var _CSFREI = "CancelSpotFleetRequestsErrorItem";
    var _CSFRES = "CancelSpotFleetRequestsErrorSet";
    var _CSFRR = "CancelSpotFleetRequestsRequest";
    var _CSFRRa = "CancelSpotFleetRequestsResponse";
    var _CSFRS = "CurrentSpotFleetRequestState";
    var _CSFRSI = "CancelSpotFleetRequestsSuccessItem";
    var _CSFRSS = "CancelSpotFleetRequestsSuccessSet";
    var _CSG = "CreateSecurityGroup";
    var _CSGR = "CreateSecurityGroupRequest";
    var _CSGRr = "CreateSecurityGroupResult";
    var _CSIR = "CancelledSpotInstanceRequest";
    var _CSIRL = "CancelledSpotInstanceRequestList";
    var _CSIRR = "CancelSpotInstanceRequestsRequest";
    var _CSIRRa = "CancelSpotInstanceRequestsResult";
    var _CSIRa = "CancelledSpotInstanceRequests";
    var _CSIRan = "CancelSpotInstanceRequests";
    var _CSIT = "CreateStoreImageTask";
    var _CSITR = "CreateStoreImageTaskRequest";
    var _CSITRr = "CreateStoreImageTaskResult";
    var _CSN = "CreateSecondaryNetwork";
    var _CSNR = "CreateSecondaryNetworkRequest";
    var _CSNRr = "CreateSecondaryNetworkResult";
    var _CSOK = "CertificateS3ObjectKey";
    var _CSR = "CopySnapshotRequest";
    var _CSRPSU = "CopySnapshotRequestPSU";
    var _CSRo = "CopySnapshotResult";
    var _CSRr = "CreateSnapshotRequest";
    var _CSRre = "CreateSnapshotsRequest";
    var _CSRrea = "CreateSnapshotsResult";
    var _CSRreat = "CreateSubnetRequest";
    var _CSRreate = "CreateSubnetResult";
    var _CSRred = "CreditSpecificationRequest";
    var _CSS = "CreateSecondarySubnet";
    var _CSSR = "CreateSecondarySubnetRequest";
    var _CSSRr = "CreateSecondarySubnetResult";
    var _CST = "ClientSecretType";
    var _CSo = "ComplianceStatus";
    var _CSon = "ConfigurationState";
    var _CSonn = "ConnectionStatuses";
    var _CSop = "CopySnapshot";
    var _CSr = "CreditSpecification";
    var _CSre = "CreateSnapshot";
    var _CSrea = "CreateSnapshots";
    var _CSreat = "CreateSubnet";
    var _CSu = "CurrentState";
    var _CSur = "CurrentStatus";
    var _CT4 = "ClientToken";
    var _CTC = "ConnectionTrackingConfiguration";
    var _CTFS = "CopyTagsFromSource";
    var _CTG = "CreateTransitGateway";
    var _CTGC = "CreateTransitGatewayConnect";
    var _CTGCP = "CreateTransitGatewayConnectPeer";
    var _CTGCPR = "CreateTransitGatewayConnectPeerRequest";
    var _CTGCPRr = "CreateTransitGatewayConnectPeerResult";
    var _CTGCR = "CreateTransitGatewayConnectRequest";
    var _CTGCRO = "CreateTransitGatewayConnectRequestOptions";
    var _CTGCRr = "CreateTransitGatewayConnectResult";
    var _CTGMD = "CreateTransitGatewayMulticastDomain";
    var _CTGMDR = "CreateTransitGatewayMulticastDomainRequest";
    var _CTGMDRO = "CreateTransitGatewayMulticastDomainRequestOptions";
    var _CTGMDRr = "CreateTransitGatewayMulticastDomainResult";
    var _CTGMP = "CreateTransitGatewayMeteringPolicy";
    var _CTGMPE = "CreateTransitGatewayMeteringPolicyEntry";
    var _CTGMPER = "CreateTransitGatewayMeteringPolicyEntryRequest";
    var _CTGMPERr = "CreateTransitGatewayMeteringPolicyEntryResult";
    var _CTGMPR = "CreateTransitGatewayMeteringPolicyRequest";
    var _CTGMPRr = "CreateTransitGatewayMeteringPolicyResult";
    var _CTGPA = "CreateTransitGatewayPeeringAttachment";
    var _CTGPAR = "CreateTransitGatewayPeeringAttachmentRequest";
    var _CTGPARO = "CreateTransitGatewayPeeringAttachmentRequestOptions";
    var _CTGPARr = "CreateTransitGatewayPeeringAttachmentResult";
    var _CTGPLR = "CreateTransitGatewayPrefixListReference";
    var _CTGPLRR = "CreateTransitGatewayPrefixListReferenceRequest";
    var _CTGPLRRr = "CreateTransitGatewayPrefixListReferenceResult";
    var _CTGPT = "CreateTransitGatewayPolicyTable";
    var _CTGPTR = "CreateTransitGatewayPolicyTableRequest";
    var _CTGPTRr = "CreateTransitGatewayPolicyTableResult";
    var _CTGR = "CreateTransitGatewayRequest";
    var _CTGRR = "CreateTransitGatewayRouteRequest";
    var _CTGRRr = "CreateTransitGatewayRouteResult";
    var _CTGRT = "CreateTransitGatewayRouteTable";
    var _CTGRTA = "CreateTransitGatewayRouteTableAnnouncement";
    var _CTGRTAR = "CreateTransitGatewayRouteTableAnnouncementRequest";
    var _CTGRTARr = "CreateTransitGatewayRouteTableAnnouncementResult";
    var _CTGRTR = "CreateTransitGatewayRouteTableRequest";
    var _CTGRTRr = "CreateTransitGatewayRouteTableResult";
    var _CTGRr = "CreateTransitGatewayResult";
    var _CTGRre = "CreateTransitGatewayRoute";
    var _CTGVA = "CreateTransitGatewayVpcAttachment";
    var _CTGVAR = "CreateTransitGatewayVpcAttachmentRequest";
    var _CTGVARO = "CreateTransitGatewayVpcAttachmentRequestOptions";
    var _CTGVARr = "CreateTransitGatewayVpcAttachmentResult";
    var _CTI = "ConversionTaskId";
    var _CTIo = "ConversionTaskIds";
    var _CTMF = "CreateTrafficMirrorFilter";
    var _CTMFR = "CreateTrafficMirrorFilterRequest";
    var _CTMFRR = "CreateTrafficMirrorFilterRuleRequest";
    var _CTMFRRr = "CreateTrafficMirrorFilterRuleResult";
    var _CTMFRr = "CreateTrafficMirrorFilterResult";
    var _CTMFRre = "CreateTrafficMirrorFilterRule";
    var _CTMS = "CreateTrafficMirrorSession";
    var _CTMSR = "CreateTrafficMirrorSessionRequest";
    var _CTMSRr = "CreateTrafficMirrorSessionResult";
    var _CTMT = "CreateTrafficMirrorTarget";
    var _CTMTR = "CreateTrafficMirrorTargetRequest";
    var _CTMTRr = "CreateTrafficMirrorTargetResult";
    var _CTR4 = "CreateTagsRequest";
    var _CTS = "ConnectionTrackingSpecification";
    var _CTSR = "ConnectionTrackingSpecificationRequest";
    var _CTSRo = "ConnectionTrackingSpecificationResponse";
    var _CTo = "ConversionTask";
    var _CTom = "CompleteTime";
    var _CTomp = "CompletionTime";
    var _CTon = "ConnectivityType";
    var _CTonv = "ConversionTasks";
    var _CTr = "CreateTime";
    var _CTre = "CreationTime";
    var _CTrea = "CreationTimestamp";
    var _CTreat = "CreateTags";
    var _CV4 = "CurrentVersion";
    var _CVA = "ClientVpnAuthentication";
    var _CVAE = "CreateVerifiedAccessEndpoint";
    var _CVAECO = "CreateVerifiedAccessEndpointCidrOptions";
    var _CVAEEO = "CreateVerifiedAccessEndpointEniOptions";
    var _CVAELBO = "CreateVerifiedAccessEndpointLoadBalancerOptions";
    var _CVAEPR = "CreateVerifiedAccessEndpointPortRange";
    var _CVAEPRL = "CreateVerifiedAccessEndpointPortRangeList";
    var _CVAER = "CreateVerifiedAccessEndpointRequest";
    var _CVAERO = "CreateVerifiedAccessEndpointRdsOptions";
    var _CVAERr = "CreateVerifiedAccessEndpointResult";
    var _CVAESIL = "CreateVerifiedAccessEndpointSubnetIdList";
    var _CVAG = "CreateVerifiedAccessGroup";
    var _CVAGR = "CreateVerifiedAccessGroupRequest";
    var _CVAGRr = "CreateVerifiedAccessGroupResult";
    var _CVAI = "CreateVerifiedAccessInstance";
    var _CVAIR = "CreateVerifiedAccessInstanceRequest";
    var _CVAIRr = "CreateVerifiedAccessInstanceResult";
    var _CVAL = "ClientVpnAuthenticationList";
    var _CVANAOO = "CreateVerifiedAccessNativeApplicationOidcOptions";
    var _CVAR = "ClientVpnAuthenticationRequest";
    var _CVARL = "ClientVpnAuthenticationRequestList";
    var _CVARS = "ClientVpnAuthorizationRuleStatus";
    var _CVATP = "CreateVerifiedAccessTrustProvider";
    var _CVATPDO = "CreateVerifiedAccessTrustProviderDeviceOptions";
    var _CVATPOO = "CreateVerifiedAccessTrustProviderOidcOptions";
    var _CVATPR = "CreateVerifiedAccessTrustProviderRequest";
    var _CVATPRr = "CreateVerifiedAccessTrustProviderResult";
    var _CVAZIS = "ClientVpnAvailabilityZoneIdSet";
    var _CVAZS = "ClientVpnAvailabilityZoneSet";
    var _CVBPAE = "CreateVpcBlockPublicAccessExclusion";
    var _CVBPAER = "CreateVpcBlockPublicAccessExclusionRequest";
    var _CVBPAERr = "CreateVpcBlockPublicAccessExclusionResult";
    var _CVC = "ClientVpnConnection";
    var _CVCR = "CreateVpnConcentratorRequest";
    var _CVCRR = "CreateVpnConnectionRouteRequest";
    var _CVCRr = "CreateVpnConcentratorResult";
    var _CVCRre = "CreateVpnConnectionRequest";
    var _CVCRrea = "CreateVpnConnectionResult";
    var _CVCRreat = "CreateVpnConnectionRoute";
    var _CVCS = "ClientVpnConnectionStatus";
    var _CVCSl = "ClientVpnConnectionSet";
    var _CVCr = "CreateVpnConcentrator";
    var _CVCre = "CreateVpnConnection";
    var _CVE = "ClientVpnEndpoint";
    var _CVEAS = "ClientVpnEndpointAttributeStatus";
    var _CVEC = "CreateVpcEncryptionControl";
    var _CVECN = "CreateVpcEndpointConnectionNotification";
    var _CVECNR = "CreateVpcEndpointConnectionNotificationRequest";
    var _CVECNRr = "CreateVpcEndpointConnectionNotificationResult";
    var _CVECR = "CreateVpcEncryptionControlRequest";
    var _CVECRr = "CreateVpcEncryptionControlResult";
    var _CVEI = "ClientVpnEndpointId";
    var _CVEIL = "ClientVpnEndpointIdList";
    var _CVEIl = "ClientVpnEndpointIds";
    var _CVER = "CreateVpcEndpointRequest";
    var _CVERr = "CreateVpcEndpointResult";
    var _CVES = "ClientVpnEndpointStatus";
    var _CVESC = "CreateVpcEndpointServiceConfiguration";
    var _CVESCR = "CreateVpcEndpointServiceConfigurationRequest";
    var _CVESCRr = "CreateVpcEndpointServiceConfigurationResult";
    var _CVEl = "ClientVpnEndpoints";
    var _CVEr = "CreateVpcEndpoint";
    var _CVG = "CreateVpnGateway";
    var _CVGR = "CreateVpnGatewayRequest";
    var _CVGRr = "CreateVpnGatewayResult";
    var _CVL = "ConditionValueList";
    var _CVOI = "ClientVpnOwnerId";
    var _CVP = "CreateVolumePermission";
    var _CVPC = "CreateVpcPeeringConnection";
    var _CVPCR = "CreateVpcPeeringConnectionRequest";
    var _CVPCRr = "CreateVpcPeeringConnectionResult";
    var _CVPL = "CreateVolumePermissionList";
    var _CVPM = "CreateVolumePermissionModifications";
    var _CVPr = "CreateVolumePermissions";
    var _CVR = "ClientVpnRoute";
    var _CVRS = "ClientVpnRouteStatus";
    var _CVRSl = "ClientVpnRouteSet";
    var _CVRo = "CopyVolumesRequest";
    var _CVRop = "CopyVolumesResult";
    var _CVRr = "CreateVolumeRequest";
    var _CVRre = "CreateVpcRequest";
    var _CVRrea = "CreateVpcResult";
    var _CVSGIS = "ClientVpnSecurityGroupIdSet";
    var _CVTN = "ClientVpnTargetNetworks";
    var _CVo = "CopyVolumes";
    var _CVr = "CreateVolume";
    var _CVre = "CreateVpc";
    var _CWL = "CloudWatchLogs";
    var _CWLO = "CloudWatchLogOptions";
    var _CWLOS = "CloudWatchLogOptionsSpecification";
    var _Ca = "Cascade";
    var _Cat = "Category";
    var _Ch = "Checksum";
    var _Ci = "Cidr";
    var _Cid = "Cidrs";
    var _Co = "Code";
    var _Com = "Comment";
    var _Comp = "Comparison";
    var _Con = "Context";
    var _Cond = "Conditions";
    var _Condi = "Condition";
    var _Conf = "Configured";
    var _Confi = "Config";
    var _Conn = "Connections";
    var _Cor = "Cores";
    var _Cou = "Count";
    var _Cp = "Cpu";
    var _D = "Destination";
    var _DA = "DestinationAddresses";
    var _DAA = "DescribeAccountAttributes";
    var _DAAI = "DelegatedAdminAccountId";
    var _DAAR = "DescribeAccountAttributesRequest";
    var _DAARe = "DescribeAccountAttributesResult";
    var _DAARes = "DescribeAddressesAttributeRequest";
    var _DAAResc = "DescribeAddressesAttributeResult";
    var _DAAe = "DescribeAddressesAttribute";
    var _DAIF = "DescribeAggregateIdFormat";
    var _DAIFR = "DescribeAggregateIdFormatRequest";
    var _DAIFRe = "DescribeAggregateIdFormatResult";
    var _DAIS = "DisableAllowedImagesSettings";
    var _DAISR = "DisableAllowedImagesSettingsRequest";
    var _DAISRi = "DisableAllowedImagesSettingsResult";
    var _DAIT = "DenyAllIgwTraffic";
    var _DANPMS = "DescribeAwsNetworkPerformanceMetricSubscriptions";
    var _DANPMSR = "DescribeAwsNetworkPerformanceMetricSubscriptionsRequest";
    var _DANPMSRe = "DescribeAwsNetworkPerformanceMetricSubscriptionsResult";
    var _DANPMSRi = "DisableAwsNetworkPerformanceMetricSubscriptionRequest";
    var _DANPMSRis = "DisableAwsNetworkPerformanceMetricSubscriptionResult";
    var _DANPMSi = "DisableAwsNetworkPerformanceMetricSubscription";
    var _DAR = "DescribeAddressesRequest";
    var _DART = "DefaultAssociationRouteTable";
    var _DARe = "DescribeAddressesResult";
    var _DARi = "DisassociateAddressRequest";
    var _DAS = "DeleteAssociatedSnapshots";
    var _DASe = "DeprovisionedAddressSet";
    var _DASi = "DisableApiStop";
    var _DAT = "DisableApiTermination";
    var _DATR = "DescribeAddressTransfersRequest";
    var _DATRe = "DescribeAddressTransfersResult";
    var _DATRi = "DisableAddressTransferRequest";
    var _DATRis = "DisableAddressTransferResult";
    var _DATe = "DescribeAddressTransfers";
    var _DATi = "DisableAddressTransfer";
    var _DAZ = "DestinationAvailabilityZone";
    var _DAZI = "DestinationAvailabilityZoneId";
    var _DAZR = "DescribeAvailabilityZonesRequest";
    var _DAZRe = "DescribeAvailabilityZonesResult";
    var _DAZe = "DescribeAvailabilityZones";
    var _DAe = "DeprovisionedAddresses";
    var _DAep = "DeprecateAt";
    var _DAes = "DestinationArn";
    var _DAesc = "DescribeAddresses";
    var _DAest = "DestinationAddress";
    var _DAi = "DisassociateAddress";
    var _DBC = "DeprovisionByoipCidr";
    var _DBCR = "DeprovisionByoipCidrRequest";
    var _DBCRe = "DeprovisionByoipCidrResult";
    var _DBCRes = "DescribeByoipCidrsRequest";
    var _DBCResc = "DescribeByoipCidrsResult";
    var _DBCe = "DescribeByoipCidrs";
    var _DBT = "DescribeBundleTasks";
    var _DBTR = "DescribeBundleTasksRequest";
    var _DBTRe = "DescribeBundleTasksResult";
    var _DC = "DisallowedCidrs";
    var _DCA = "DomainCertificateArn";
    var _DCAR = "DeliverCrossAccountRole";
    var _DCB = "DestinationCidrBlock";
    var _DCBEH = "DescribeCapacityBlockExtensionHistory";
    var _DCBEHR = "DescribeCapacityBlockExtensionHistoryRequest";
    var _DCBEHRe = "DescribeCapacityBlockExtensionHistoryResult";
    var _DCBEO = "DescribeCapacityBlockExtensionOfferings";
    var _DCBEOR = "DescribeCapacityBlockExtensionOfferingsRequest";
    var _DCBEORe = "DescribeCapacityBlockExtensionOfferingsResult";
    var _DCBO = "DescribeCapacityBlockOfferings";
    var _DCBOR = "DescribeCapacityBlockOfferingsRequest";
    var _DCBORe = "DescribeCapacityBlockOfferingsResult";
    var _DCBR = "DescribeCapacityBlocksRequest";
    var _DCBRe = "DescribeCapacityBlocksResult";
    var _DCBS = "DescribeCapacityBlockStatus";
    var _DCBSR = "DescribeCapacityBlockStatusRequest";
    var _DCBSRe = "DescribeCapacityBlockStatusResult";
    var _DCBe = "DescribeCapacityBlocks";
    var _DCC = "DeleteCoipCidr";
    var _DCCR = "DeleteCoipCidrRequest";
    var _DCCRe = "DeleteCoipCidrResult";
    var _DCG = "DeleteCarrierGateway";
    var _DCGR = "DeleteCarrierGatewayRequest";
    var _DCGRe = "DeleteCarrierGatewayResult";
    var _DCGRel = "DeleteCustomerGatewayRequest";
    var _DCGRes = "DescribeCarrierGatewaysRequest";
    var _DCGResc = "DescribeCarrierGatewaysResult";
    var _DCGRescr = "DescribeCustomerGatewaysRequest";
    var _DCGRescri = "DescribeCustomerGatewaysResult";
    var _DCGe = "DeleteCustomerGateway";
    var _DCGes = "DescribeCarrierGateways";
    var _DCGesc = "DescribeCustomerGateways";
    var _DCL = "DhcpConfigurationList";
    var _DCLI = "DescribeClassicLinkInstances";
    var _DCLIR = "DescribeClassicLinkInstancesRequest";
    var _DCLIRe = "DescribeClassicLinkInstancesResult";
    var _DCLV = "DetachClassicLinkVpc";
    var _DCLVR = "DetachClassicLinkVpcRequest";
    var _DCLVRe = "DetachClassicLinkVpcResult";
    var _DCM = "DisableCapacityManager";
    var _DCMDE = "DeleteCapacityManagerDataExport";
    var _DCMDER = "DeleteCapacityManagerDataExportRequest";
    var _DCMDERe = "DeleteCapacityManagerDataExportResult";
    var _DCMDERes = "DescribeCapacityManagerDataExportsRequest";
    var _DCMDEResc = "DescribeCapacityManagerDataExportsResult";
    var _DCMDEe = "DescribeCapacityManagerDataExports";
    var _DCMR = "DisableCapacityManagerRequest";
    var _DCMRi = "DisableCapacityManagerResult";
    var _DCP = "DeleteCoipPool";
    var _DCPR = "DeleteCoipPoolRequest";
    var _DCPRe = "DeleteCoipPoolResult";
    var _DCPRes = "DescribeCoipPoolsRequest";
    var _DCPResc = "DescribeCoipPoolsResult";
    var _DCPe = "DescribeCoipPools";
    var _DCR = "DestinationCapacityReservation";
    var _DCRBO = "DisassociateCapacityReservationBillingOwner";
    var _DCRBOR = "DisassociateCapacityReservationBillingOwnerRequest";
    var _DCRBORi = "DisassociateCapacityReservationBillingOwnerResult";
    var _DCRBR = "DescribeCapacityReservationBillingRequests";
    var _DCRBRR = "DescribeCapacityReservationBillingRequestsRequest";
    var _DCRBRRe = "DescribeCapacityReservationBillingRequestsResult";
    var _DCRF = "DescribeCapacityReservationFleets";
    var _DCRFR = "DescribeCapacityReservationFleetsRequest";
    var _DCRFRe = "DescribeCapacityReservationFleetsResult";
    var _DCRI = "DestinationCapacityReservationId";
    var _DCRR = "DescribeCapacityReservationsRequest";
    var _DCRRe = "DescribeCapacityReservationsResult";
    var _DCRT = "DescribeCapacityReservationTopology";
    var _DCRTR = "DescribeCapacityReservationTopologyRequest";
    var _DCRTRe = "DescribeCapacityReservationTopologyResult";
    var _DCRe = "DescribeCapacityReservations";
    var _DCT = "DescribeConversionTasks";
    var _DCTC = "DefaultConnectionTrackingConfiguration";
    var _DCTL = "DescribeConversionTaskList";
    var _DCTR = "DescribeConversionTasksRequest";
    var _DCTRe = "DescribeConversionTasksResult";
    var _DCVAR = "DescribeClientVpnAuthorizationRules";
    var _DCVARR = "DescribeClientVpnAuthorizationRulesRequest";
    var _DCVARRe = "DescribeClientVpnAuthorizationRulesResult";
    var _DCVC = "DescribeClientVpnConnections";
    var _DCVCR = "DescribeClientVpnConnectionsRequest";
    var _DCVCRe = "DescribeClientVpnConnectionsResult";
    var _DCVE = "DeleteClientVpnEndpoint";
    var _DCVER = "DeleteClientVpnEndpointRequest";
    var _DCVERe = "DeleteClientVpnEndpointResult";
    var _DCVERes = "DescribeClientVpnEndpointsRequest";
    var _DCVEResc = "DescribeClientVpnEndpointsResult";
    var _DCVEe = "DescribeClientVpnEndpoints";
    var _DCVL = "DhcpConfigurationValueList";
    var _DCVR = "DeleteClientVpnRoute";
    var _DCVRR = "DeleteClientVpnRouteRequest";
    var _DCVRRe = "DeleteClientVpnRouteResult";
    var _DCVRRes = "DescribeClientVpnRoutesRequest";
    var _DCVRResc = "DescribeClientVpnRoutesResult";
    var _DCVRe = "DescribeClientVpnRoutes";
    var _DCVTN = "DescribeClientVpnTargetNetworks";
    var _DCVTNR = "DescribeClientVpnTargetNetworksRequest";
    var _DCVTNRe = "DescribeClientVpnTargetNetworksResult";
    var _DCVTNRi = "DisassociateClientVpnTargetNetworkRequest";
    var _DCVTNRis = "DisassociateClientVpnTargetNetworkResult";
    var _DCVTNi = "DisassociateClientVpnTargetNetwork";
    var _DCe = "DestinationCidr";
    var _DCef = "DefaultCores";
    var _DCh = "DhcpConfigurations";
    var _DChc = "DhcpConfiguration";
    var _DCi = "DisallowedCidr";
    var _DCim = "DimensionCondition";
    var _DCis = "DiskContainers";
    var _DCisk = "DiskContainer";
    var _DDO = "DeleteDhcpOptions";
    var _DDOR = "DeleteDhcpOptionsRequest";
    var _DDORe = "DescribeDhcpOptionsRequest";
    var _DDORes = "DescribeDhcpOptionsResult";
    var _DDOe = "DescribeDhcpOptions";
    var _DDPR = "DescribeDeclarativePoliciesReports";
    var _DDPRR = "DescribeDeclarativePoliciesReportsRequest";
    var _DDPRRe = "DescribeDeclarativePoliciesReportsResult";
    var _DE = "DnsEntry";
    var _DEC = "DataExportCount";
    var _DECIR = "DisassociateEnclaveCertificateIamRole";
    var _DECIRR = "DisassociateEnclaveCertificateIamRoleRequest";
    var _DECIRRi = "DisassociateEnclaveCertificateIamRoleResult";
    var _DEEBD = "DisableEbsEncryptionByDefault";
    var _DEEBDR = "DisableEbsEncryptionByDefaultRequest";
    var _DEEBDRi = "DisableEbsEncryptionByDefaultResult";
    var _DEG = "DescribeElasticGpus";
    var _DEGR = "DescribeElasticGpusRequest";
    var _DEGRe = "DescribeElasticGpusResult";
    var _DEIT = "DescribeExportImageTasks";
    var _DEITR = "DescribeExportImageTasksRequest";
    var _DEITRe = "DescribeExportImageTasksResult";
    var _DEKI = "DataEncryptionKeyId";
    var _DEOIG = "DeleteEgressOnlyInternetGateway";
    var _DEOIGR = "DeleteEgressOnlyInternetGatewayRequest";
    var _DEOIGRe = "DeleteEgressOnlyInternetGatewayResult";
    var _DEOIGRes = "DescribeEgressOnlyInternetGatewaysRequest";
    var _DEOIGResc = "DescribeEgressOnlyInternetGatewaysResult";
    var _DEOIGe = "DescribeEgressOnlyInternetGateways";
    var _DEQC = "DefaultEnaQueueCount";
    var _DEQCPI = "DefaultEnaQueueCountPerInterface";
    var _DES = "DnsEntrySet";
    var _DET = "DescribeExportTasks";
    var _DETR = "DescribeExportTasksRequest";
    var _DETRe = "DescribeExportTasksResult";
    var _DEn = "DnsEntries";
    var _DF = "DeleteFleets";
    var _DFA = "DefaultForAz";
    var _DFE = "DeleteFleetError";
    var _DFEI = "DeleteFleetErrorItem";
    var _DFES = "DeleteFleetErrorSet";
    var _DFESe = "DescribeFleetsErrorSet";
    var _DFEe = "DescribeFleetError";
    var _DFH = "DescribeFleetHistory";
    var _DFHR = "DescribeFleetHistoryRequest";
    var _DFHRe = "DescribeFleetHistoryResult";
    var _DFI = "DescribeFleetsInstances";
    var _DFIA = "DescribeFpgaImageAttribute";
    var _DFIAR = "DescribeFpgaImageAttributeRequest";
    var _DFIARe = "DescribeFpgaImageAttributeResult";
    var _DFIR = "DeleteFpgaImageRequest";
    var _DFIRe = "DeleteFpgaImageResult";
    var _DFIRes = "DescribeFleetInstancesRequest";
    var _DFIResc = "DescribeFleetInstancesResult";
    var _DFIRescr = "DescribeFpgaImagesRequest";
    var _DFIRescri = "DescribeFpgaImagesResult";
    var _DFIS = "DescribeFleetsInstancesSet";
    var _DFIe = "DeleteFpgaImage";
    var _DFIes = "DescribeFleetInstances";
    var _DFIesc = "DescribeFpgaImages";
    var _DFL = "DeleteFlowLogs";
    var _DFLI = "DescribeFastLaunchImages";
    var _DFLIR = "DescribeFastLaunchImagesRequest";
    var _DFLIRe = "DescribeFastLaunchImagesResult";
    var _DFLISI = "DescribeFastLaunchImagesSuccessItem";
    var _DFLISS = "DescribeFastLaunchImagesSuccessSet";
    var _DFLR = "DeleteFlowLogsRequest";
    var _DFLRe = "DeleteFlowLogsResult";
    var _DFLRes = "DescribeFlowLogsRequest";
    var _DFLResc = "DescribeFlowLogsResult";
    var _DFLRi = "DisableFastLaunchRequest";
    var _DFLRis = "DisableFastLaunchResult";
    var _DFLe = "DescribeFlowLogs";
    var _DFLi = "DisableFastLaunch";
    var _DFR = "DeleteFleetsRequest";
    var _DFRe = "DeleteFleetsResult";
    var _DFRes = "DescribeFleetsRequest";
    var _DFResc = "DescribeFleetsResult";
    var _DFSI = "DeleteFleetSuccessItem";
    var _DFSR = "DescribeFastSnapshotRestores";
    var _DFSREI = "DisableFastSnapshotRestoreErrorItem";
    var _DFSRES = "DisableFastSnapshotRestoreErrorSet";
    var _DFSRR = "DescribeFastSnapshotRestoresRequest";
    var _DFSRRe = "DescribeFastSnapshotRestoresResult";
    var _DFSRRi = "DisableFastSnapshotRestoresRequest";
    var _DFSRRis = "DisableFastSnapshotRestoresResult";
    var _DFSRSE = "DisableFastSnapshotRestoreStateError";
    var _DFSRSEI = "DisableFastSnapshotRestoreStateErrorItem";
    var _DFSRSES = "DisableFastSnapshotRestoreStateErrorSet";
    var _DFSRSI = "DescribeFastSnapshotRestoreSuccessItem";
    var _DFSRSIi = "DisableFastSnapshotRestoreSuccessItem";
    var _DFSRSS = "DescribeFastSnapshotRestoreSuccessSet";
    var _DFSRSSi = "DisableFastSnapshotRestoreSuccessSet";
    var _DFSRi = "DisableFastSnapshotRestores";
    var _DFSS = "DeleteFleetSuccessSet";
    var _DFe = "DescribeFleets";
    var _DH = "DescribeHosts";
    var _DHI = "DedicatedHostIds";
    var _DHIL = "DedicatedHostIdList";
    var _DHIe = "DedicatedHostId";
    var _DHR = "DescribeHostsRequest";
    var _DHRO = "DescribeHostReservationOfferings";
    var _DHROR = "DescribeHostReservationOfferingsRequest";
    var _DHRORe = "DescribeHostReservationOfferingsResult";
    var _DHRR = "DescribeHostReservationsRequest";
    var _DHRRe = "DescribeHostReservationsResult";
    var _DHRe = "DescribeHostsResult";
    var _DHRes = "DescribeHostReservations";
    var _DHS = "DedicatedHostsSupported";
    var _DHT = "DnsHostnameType";
    var _DI = "DeviceIndex";
    var _DIA = "DescribeImageAttribute";
    var _DIAR = "DescribeImageAttributeRequest";
    var _DIARe = "DescribeInstanceAttributeRequest";
    var _DIAe = "DescribeInstanceAttribute";
    var _DIB = "DeprovisionIpamByoasn";
    var _DIBPA = "DisableImageBlockPublicAccess";
    var _DIBPAR = "DisableImageBlockPublicAccessRequest";
    var _DIBPARi = "DisableImageBlockPublicAccessResult";
    var _DIBR = "DeprovisionIpamByoasnRequest";
    var _DIBRe = "DeprovisionIpamByoasnResult";
    var _DIBRes = "DescribeIpamByoasnRequest";
    var _DIBResc = "DescribeIpamByoasnResult";
    var _DIBRi = "DisassociateIpamByoasnRequest";
    var _DIBRis = "DisassociateIpamByoasnResult";
    var _DIBe = "DescribeIpamByoasn";
    var _DIBi = "DisassociateIpamByoasn";
    var _DICB = "DestinationIpv6CidrBlock";
    var _DICE = "DeleteInstanceConnectEndpoint";
    var _DICER = "DeleteInstanceConnectEndpointRequest";
    var _DICERe = "DeleteInstanceConnectEndpointResult";
    var _DICERes = "DescribeInstanceConnectEndpointsRequest";
    var _DICEResc = "DescribeInstanceConnectEndpointsResult";
    var _DICEe = "DescribeInstanceConnectEndpoints";
    var _DICS = "DescribeInstanceCreditSpecifications";
    var _DICSR = "DescribeInstanceCreditSpecificationsRequest";
    var _DICSRe = "DescribeInstanceCreditSpecificationsResult";
    var _DID = "DiskImageDescription";
    var _DIDP = "DisableImageDeregistrationProtection";
    var _DIDPR = "DisableImageDeregistrationProtectionRequest";
    var _DIDPRi = "DisableImageDeregistrationProtectionResult";
    var _DIDR = "DisableImageDeprecationRequest";
    var _DIDRi = "DisableImageDeprecationResult";
    var _DIDi = "DiskImageDetail";
    var _DIDis = "DisableImageDeprecation";
    var _DIENA = "DeregisterInstanceEventNotificationAttributes";
    var _DIENAR = "DeregisterInstanceEventNotificationAttributesRequest";
    var _DIENARe = "DeregisterInstanceEventNotificationAttributesResult";
    var _DIENARes = "DescribeInstanceEventNotificationAttributesRequest";
    var _DIENAResc = "DescribeInstanceEventNotificationAttributesResult";
    var _DIENAe = "DescribeInstanceEventNotificationAttributes";
    var _DIERVT = "DeleteIpamExternalResourceVerificationToken";
    var _DIERVTR = "DeleteIpamExternalResourceVerificationTokenRequest";
    var _DIERVTRe = "DeleteIpamExternalResourceVerificationTokenResult";
    var _DIERVTRes = "DescribeIpamExternalResourceVerificationTokensRequest";
    var _DIERVTResc = "DescribeIpamExternalResourceVerificationTokensResult";
    var _DIERVTe = "DescribeIpamExternalResourceVerificationTokens";
    var _DIEW = "DeleteInstanceEventWindow";
    var _DIEWR = "DeleteInstanceEventWindowRequest";
    var _DIEWRe = "DeleteInstanceEventWindowResult";
    var _DIEWRes = "DescribeInstanceEventWindowsRequest";
    var _DIEWResc = "DescribeInstanceEventWindowsResult";
    var _DIEWRi = "DisassociateInstanceEventWindowRequest";
    var _DIEWRis = "DisassociateInstanceEventWindowResult";
    var _DIEWe = "DescribeInstanceEventWindows";
    var _DIEWi = "DisassociateInstanceEventWindow";
    var _DIF = "DiskImageFormat";
    var _DIFR = "DescribeIdFormatRequest";
    var _DIFRe = "DescribeIdFormatResult";
    var _DIFe = "DescribeIdFormat";
    var _DIG = "DeleteInternetGateway";
    var _DIGR = "DeleteInternetGatewayRequest";
    var _DIGRe = "DescribeInternetGatewaysRequest";
    var _DIGRes = "DescribeInternetGatewaysResult";
    var _DIGRet = "DetachInternetGatewayRequest";
    var _DIGe = "DescribeInternetGateways";
    var _DIGet = "DetachInternetGateway";
    var _DIIF = "DescribeIdentityIdFormat";
    var _DIIFR = "DescribeIdentityIdFormatRequest";
    var _DIIFRe = "DescribeIdentityIdFormatResult";
    var _DIIM = "DescribeInstanceImageMetadata";
    var _DIIMR = "DescribeInstanceImageMetadataRequest";
    var _DIIMRe = "DescribeInstanceImageMetadataResult";
    var _DIIP = "DisassociateIamInstanceProfile";
    var _DIIPA = "DescribeIamInstanceProfileAssociations";
    var _DIIPAR = "DescribeIamInstanceProfileAssociationsRequest";
    var _DIIPARe = "DescribeIamInstanceProfileAssociationsResult";
    var _DIIPR = "DisassociateIamInstanceProfileRequest";
    var _DIIPRi = "DisassociateIamInstanceProfileResult";
    var _DIIT = "DescribeImportImageTasks";
    var _DIITR = "DescribeImportImageTasksRequest";
    var _DIITRe = "DescribeImportImageTasksResult";
    var _DIL = "DiskImageList";
    var _DILi = "DiskInfoList";
    var _DIOAA = "DisableIpamOrganizationAdminAccount";
    var _DIOAAR = "DisableIpamOrganizationAdminAccountRequest";
    var _DIOAARi = "DisableIpamOrganizationAdminAccountResult";
    var _DIP = "DeleteIpamPolicy";
    var _DIPC = "DeprovisionIpamPoolCidr";
    var _DIPCR = "DeprovisionIpamPoolCidrRequest";
    var _DIPCRe = "DeprovisionIpamPoolCidrResult";
    var _DIPLR = "DeleteIpamPrefixListResolver";
    var _DIPLRR = "DeleteIpamPrefixListResolverRequest";
    var _DIPLRRe = "DeleteIpamPrefixListResolverResult";
    var _DIPLRRes = "DescribeIpamPrefixListResolversRequest";
    var _DIPLRResc = "DescribeIpamPrefixListResolversResult";
    var _DIPLRT = "DeleteIpamPrefixListResolverTarget";
    var _DIPLRTR = "DeleteIpamPrefixListResolverTargetRequest";
    var _DIPLRTRe = "DeleteIpamPrefixListResolverTargetResult";
    var _DIPLRTRes = "DescribeIpamPrefixListResolverTargetsRequest";
    var _DIPLRTResc = "DescribeIpamPrefixListResolverTargetsResult";
    var _DIPLRTe = "DescribeIpamPrefixListResolverTargets";
    var _DIPLRe = "DescribeIpamPrefixListResolvers";
    var _DIPR = "DeleteIpamPolicyRequest";
    var _DIPRe = "DeleteIpamPolicyResult";
    var _DIPRel = "DeleteIpamPoolRequest";
    var _DIPRele = "DeleteIpamPoolResult";
    var _DIPRes = "DescribeIpamPoliciesRequest";
    var _DIPResc = "DescribeIpamPoliciesResult";
    var _DIPRescr = "DescribeIpamPoolsRequest";
    var _DIPRescri = "DescribeIpamPoolsResult";
    var _DIPRescrib = "DescribeIpv6PoolsRequest";
    var _DIPRescribe = "DescribeIpv6PoolsResult";
    var _DIPRi = "DisableIpamPolicyRequest";
    var _DIPRis = "DisableIpamPolicyResult";
    var _DIPe = "DeleteIpamPool";
    var _DIPes = "DescribeIpamPolicies";
    var _DIPesc = "DescribeIpamPools";
    var _DIPescr = "DescribeIpv6Pools";
    var _DIPi = "DisableIpamPolicy";
    var _DIR = "DeleteIpamRequest";
    var _DIRD = "DeleteIpamResourceDiscovery";
    var _DIRDA = "DescribeIpamResourceDiscoveryAssociations";
    var _DIRDAR = "DescribeIpamResourceDiscoveryAssociationsRequest";
    var _DIRDARe = "DescribeIpamResourceDiscoveryAssociationsResult";
    var _DIRDR = "DeleteIpamResourceDiscoveryRequest";
    var _DIRDRe = "DeleteIpamResourceDiscoveryResult";
    var _DIRDRes = "DescribeIpamResourceDiscoveriesRequest";
    var _DIRDResc = "DescribeIpamResourceDiscoveriesResult";
    var _DIRDRi = "DisassociateIpamResourceDiscoveryRequest";
    var _DIRDRis = "DisassociateIpamResourceDiscoveryResult";
    var _DIRDe = "DescribeIpamResourceDiscoveries";
    var _DIRDi = "DisassociateIpamResourceDiscovery";
    var _DIRR = "DescribeImageReferencesRequest";
    var _DIRRe = "DescribeImageReferencesResult";
    var _DIRe = "DeleteIpamResult";
    var _DIRer = "DeregisterImageRequest";
    var _DIRere = "DeregisterImageResult";
    var _DIRes = "DescribeImagesRequest";
    var _DIResc = "DescribeImagesResult";
    var _DIRescr = "DescribeInstancesRequest";
    var _DIRescri = "DescribeInstancesResult";
    var _DIRescrib = "DescribeIpamsRequest";
    var _DIRescribe = "DescribeIpamsResult";
    var _DIRescribem = "DescribeImageReferences";
    var _DIRi = "DisableImageRequest";
    var _DIRis = "DisableImageResult";
    var _DIS = "DiskImageSize";
    var _DISHHS = "DescribeInstanceSqlHaHistoryStates";
    var _DISHHSR = "DescribeInstanceSqlHaHistoryStatesRequest";
    var _DISHHSRe = "DescribeInstanceSqlHaHistoryStatesResult";
    var _DISHS = "DescribeInstanceSqlHaStates";
    var _DISHSD = "DisableInstanceSqlHaStandbyDetections";
    var _DISHSDR = "DisableInstanceSqlHaStandbyDetectionsRequest";
    var _DISHSDRi = "DisableInstanceSqlHaStandbyDetectionsResult";
    var _DISHSR = "DescribeInstanceSqlHaStatesRequest";
    var _DISHSRe = "DescribeInstanceSqlHaStatesResult";
    var _DISI = "DestinationIpamScopeId";
    var _DISR = "DeleteIpamScopeRequest";
    var _DISRe = "DeleteIpamScopeResult";
    var _DISRes = "DescribeInstanceStatusRequest";
    var _DISResc = "DescribeInstanceStatusResult";
    var _DISRescr = "DescribeIpamScopesRequest";
    var _DISRescri = "DescribeIpamScopesResult";
    var _DIST = "DescribeImportSnapshotTasks";
    var _DISTR = "DescribeImportSnapshotTasksRequest";
    var _DISTRe = "DescribeImportSnapshotTasksResult";
    var _DISe = "DeleteIpamScope";
    var _DISes = "DescribeInstanceStatus";
    var _DISesc = "DescribeIpamScopes";
    var _DIT = "DescribeInstanceTopology";
    var _DITAR = "DeregisterInstanceTagAttributeRequest";
    var _DITO = "DescribeInstanceTypeOfferings";
    var _DITOR = "DescribeInstanceTypeOfferingsRequest";
    var _DITORe = "DescribeInstanceTypeOfferingsResult";
    var _DITR = "DescribeInstanceTopologyRequest";
    var _DITRe = "DescribeInstanceTopologyResult";
    var _DITRes = "DescribeInstanceTypesRequest";
    var _DITResc = "DescribeInstanceTypesResult";
    var _DITe = "DescribeInstanceTypes";
    var _DIUR = "DeleteImageUsageReport";
    var _DIURE = "DescribeImageUsageReportEntries";
    var _DIURER = "DescribeImageUsageReportEntriesRequest";
    var _DIURERe = "DescribeImageUsageReportEntriesResult";
    var _DIURR = "DeleteImageUsageReportRequest";
    var _DIURRe = "DeleteImageUsageReportResult";
    var _DIURRes = "DescribeImageUsageReportsRequest";
    var _DIURResc = "DescribeImageUsageReportsResult";
    var _DIURe = "DescribeImageUsageReports";
    var _DIVD = "DiskImageVolumeDescription";
    var _DIe = "DestinationIp";
    var _DIel = "DeleteIpam";
    var _DIer = "DeregisterImage";
    var _DIes = "DescribeImages";
    var _DIesc = "DescribeInstances";
    var _DIescr = "DescribeIpams";
    var _DIev = "DeviceId";
    var _DIi = "DirectoryId";
    var _DIis = "DiskImage";
    var _DIisa = "DisableImage";
    var _DIisk = "DiskInfo";
    var _DIiskm = "DiskImages";
    var _DKP = "DeleteKeyPair";
    var _DKPR = "DeleteKeyPairRequest";
    var _DKPRe = "DeleteKeyPairResult";
    var _DKPRes = "DescribeKeyPairsRequest";
    var _DKPResc = "DescribeKeyPairsResult";
    var _DKPe = "DescribeKeyPairs";
    var _DLADI = "DisableLniAtDeviceIndex";
    var _DLEM = "DeliverLogsErrorMessage";
    var _DLG = "DescribeLocalGateways";
    var _DLGR = "DescribeLocalGatewaysRequest";
    var _DLGRR = "DeleteLocalGatewayRouteRequest";
    var _DLGRRe = "DeleteLocalGatewayRouteResult";
    var _DLGRT = "DeleteLocalGatewayRouteTable";
    var _DLGRTR = "DeleteLocalGatewayRouteTableRequest";
    var _DLGRTRe = "DeleteLocalGatewayRouteTableResult";
    var _DLGRTRes = "DescribeLocalGatewayRouteTablesRequest";
    var _DLGRTResc = "DescribeLocalGatewayRouteTablesResult";
    var _DLGRTVA = "DeleteLocalGatewayRouteTableVpcAssociation";
    var _DLGRTVAR = "DeleteLocalGatewayRouteTableVpcAssociationRequest";
    var _DLGRTVARe = "DeleteLocalGatewayRouteTableVpcAssociationResult";
    var _DLGRTVARes = "DescribeLocalGatewayRouteTableVpcAssociationsRequest";
    var _DLGRTVAResc = "DescribeLocalGatewayRouteTableVpcAssociationsResult";
    var _DLGRTVAe = "DescribeLocalGatewayRouteTableVpcAssociations";
    var _DLGRTVIGA = "DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociation";
    var _DLGRTVIGAR = "DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest";
    var _DLGRTVIGARe = "DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociationResult";
    var _DLGRTVIGARes = "DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociationsRequest";
    var _DLGRTVIGAResc = "DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociationsResult";
    var _DLGRTVIGAe = "DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociations";
    var _DLGRTe = "DescribeLocalGatewayRouteTables";
    var _DLGRe = "DescribeLocalGatewaysResult";
    var _DLGRel = "DeleteLocalGatewayRoute";
    var _DLGVI = "DeleteLocalGatewayVirtualInterface";
    var _DLGVIG = "DeleteLocalGatewayVirtualInterfaceGroup";
    var _DLGVIGR = "DeleteLocalGatewayVirtualInterfaceGroupRequest";
    var _DLGVIGRe = "DeleteLocalGatewayVirtualInterfaceGroupResult";
    var _DLGVIGRes = "DescribeLocalGatewayVirtualInterfaceGroupsRequest";
    var _DLGVIGResc = "DescribeLocalGatewayVirtualInterfaceGroupsResult";
    var _DLGVIGe = "DescribeLocalGatewayVirtualInterfaceGroups";
    var _DLGVIR = "DeleteLocalGatewayVirtualInterfaceRequest";
    var _DLGVIRe = "DeleteLocalGatewayVirtualInterfaceResult";
    var _DLGVIRes = "DescribeLocalGatewayVirtualInterfacesRequest";
    var _DLGVIResc = "DescribeLocalGatewayVirtualInterfacesResult";
    var _DLGVIe = "DescribeLocalGatewayVirtualInterfaces";
    var _DLPA = "DeliverLogsPermissionArn";
    var _DLS = "DeliverLogsStatus";
    var _DLSR = "DescribeLockedSnapshotsRequest";
    var _DLSRe = "DescribeLockedSnapshotsResult";
    var _DLSe = "DescribeLockedSnapshots";
    var _DLT = "DeleteLaunchTemplate";
    var _DLTR = "DeleteLaunchTemplateRequest";
    var _DLTRe = "DeleteLaunchTemplateResult";
    var _DLTRes = "DescribeLaunchTemplatesRequest";
    var _DLTResc = "DescribeLaunchTemplatesResult";
    var _DLTV = "DeleteLaunchTemplateVersions";
    var _DLTVR = "DeleteLaunchTemplateVersionsRequest";
    var _DLTVREI = "DeleteLaunchTemplateVersionsResponseErrorItem";
    var _DLTVRES = "DeleteLaunchTemplateVersionsResponseErrorSet";
    var _DLTVRSI = "DeleteLaunchTemplateVersionsResponseSuccessItem";
    var _DLTVRSS = "DeleteLaunchTemplateVersionsResponseSuccessSet";
    var _DLTVRe = "DeleteLaunchTemplateVersionsResult";
    var _DLTVRes = "DescribeLaunchTemplateVersionsRequest";
    var _DLTVResc = "DescribeLaunchTemplateVersionsResult";
    var _DLTVe = "DescribeLaunchTemplateVersions";
    var _DLTe = "DescribeLaunchTemplates";
    var _DMA = "DescribeMovingAddresses";
    var _DMAR = "DescribeMovingAddressesRequest";
    var _DMARe = "DescribeMovingAddressesResult";
    var _DMGM = "DeregisteredMulticastGroupMembers";
    var _DMGS = "DeregisteredMulticastGroupSources";
    var _DMH = "DescribeMacHosts";
    var _DMHR = "DescribeMacHostsRequest";
    var _DMHRe = "DescribeMacHostsResult";
    var _DMMT = "DescribeMacModificationTasks";
    var _DMMTR = "DescribeMacModificationTasksRequest";
    var _DMMTRe = "DescribeMacModificationTasksResult";
    var _DMPL = "DeleteManagedPrefixList";
    var _DMPLR = "DeleteManagedPrefixListRequest";
    var _DMPLRe = "DeleteManagedPrefixListResult";
    var _DMPLRes = "DescribeManagedPrefixListsRequest";
    var _DMPLResc = "DescribeManagedPrefixListsResult";
    var _DMPLe = "DescribeManagedPrefixLists";
    var _DN = "DeviceName";
    var _DNA = "DeleteNetworkAcl";
    var _DNAE = "DeleteNetworkAclEntry";
    var _DNAER = "DeleteNetworkAclEntryRequest";
    var _DNAR = "DeleteNetworkAclRequest";
    var _DNARe = "DescribeNetworkAclsRequest";
    var _DNARes = "DescribeNetworkAclsResult";
    var _DNAe = "DescribeNetworkAcls";
    var _DNCI = "DefaultNetworkCardIndex";
    var _DNG = "DeleteNatGateway";
    var _DNGA = "DisassociateNatGatewayAddress";
    var _DNGAR = "DisassociateNatGatewayAddressRequest";
    var _DNGARi = "DisassociateNatGatewayAddressResult";
    var _DNGR = "DeleteNatGatewayRequest";
    var _DNGRe = "DeleteNatGatewayResult";
    var _DNGRes = "DescribeNatGatewaysRequest";
    var _DNGResc = "DescribeNatGatewaysResult";
    var _DNGe = "DescribeNatGateways";
    var _DNI = "DeleteNetworkInterface";
    var _DNIA = "DeleteNetworkInsightsAnalysis";
    var _DNIAR = "DeleteNetworkInsightsAnalysisRequest";
    var _DNIARe = "DeleteNetworkInsightsAnalysisResult";
    var _DNIARes = "DescribeNetworkInsightsAnalysesRequest";
    var _DNIAResc = "DescribeNetworkInsightsAnalysesResult";
    var _DNIARescr = "DescribeNetworkInterfaceAttributeRequest";
    var _DNIARescri = "DescribeNetworkInterfaceAttributeResult";
    var _DNIAS = "DeleteNetworkInsightsAccessScope";
    var _DNIASA = "DeleteNetworkInsightsAccessScopeAnalysis";
    var _DNIASAR = "DeleteNetworkInsightsAccessScopeAnalysisRequest";
    var _DNIASARe = "DeleteNetworkInsightsAccessScopeAnalysisResult";
    var _DNIASARes = "DescribeNetworkInsightsAccessScopeAnalysesRequest";
    var _DNIASAResc = "DescribeNetworkInsightsAccessScopeAnalysesResult";
    var _DNIASAe = "DescribeNetworkInsightsAccessScopeAnalyses";
    var _DNIASR = "DeleteNetworkInsightsAccessScopeRequest";
    var _DNIASRe = "DeleteNetworkInsightsAccessScopeResult";
    var _DNIASRes = "DescribeNetworkInsightsAccessScopesRequest";
    var _DNIASResc = "DescribeNetworkInsightsAccessScopesResult";
    var _DNIASe = "DescribeNetworkInsightsAccessScopes";
    var _DNIAe = "DescribeNetworkInsightsAnalyses";
    var _DNIAes = "DescribeNetworkInterfaceAttribute";
    var _DNII = "DeregisteredNetworkInterfaceIds";
    var _DNIP = "DeleteNetworkInsightsPath";
    var _DNIPR = "DeleteNetworkInsightsPathRequest";
    var _DNIPRe = "DeleteNetworkInsightsPathResult";
    var _DNIPRel = "DeleteNetworkInterfacePermissionRequest";
    var _DNIPRele = "DeleteNetworkInterfacePermissionResult";
    var _DNIPRes = "DescribeNetworkInsightsPathsRequest";
    var _DNIPResc = "DescribeNetworkInsightsPathsResult";
    var _DNIPRescr = "DescribeNetworkInterfacePermissionsRequest";
    var _DNIPRescri = "DescribeNetworkInterfacePermissionsResult";
    var _DNIPe = "DeleteNetworkInterfacePermission";
    var _DNIPes = "DescribeNetworkInsightsPaths";
    var _DNIPesc = "DescribeNetworkInterfacePermissions";
    var _DNIR = "DeleteNetworkInterfaceRequest";
    var _DNIRe = "DescribeNetworkInterfacesRequest";
    var _DNIRes = "DescribeNetworkInterfacesResult";
    var _DNIRet = "DetachNetworkInterfaceRequest";
    var _DNIe = "DescribeNetworkInterfaces";
    var _DNIet = "DetachNetworkInterface";
    var _DNn = "DnsName";
    var _DNo = "DomainName";
    var _DO = "DhcpOptions";
    var _DOA = "DestinationOutpostArn";
    var _DOI = "DhcpOptionsId";
    var _DOISL = "DhcpOptionsIdStringList";
    var _DOIh = "DhcpOptionsIds";
    var _DOL = "DhcpOptionsList";
    var _DOLR = "DescribeOutpostLagsRequest";
    var _DOLRe = "DescribeOutpostLagsResult";
    var _DOLe = "DescribeOutpostLags";
    var _DOR = "DestinationOptionsRequest";
    var _DORe = "DestinationOptionsResponse";
    var _DOS = "DnsOptionsSpecification";
    var _DOST = "DisconnectOnSessionTimeout";
    var _DOT = "DeleteOnTermination";
    var _DOe = "DestinationOptions";
    var _DOev = "DeviceOptions";
    var _DOn = "DnsOptions";
    var _DP = "DeliveryPreference";
    var _DPDTA = "DPDTimeoutAction";
    var _DPDTS = "DPDTimeoutSeconds";
    var _DPG = "DeletePlacementGroup";
    var _DPGR = "DeletePlacementGroupRequest";
    var _DPGRe = "DescribePlacementGroupsRequest";
    var _DPGRes = "DescribePlacementGroupsResult";
    var _DPGe = "DescribePlacementGroups";
    var _DPIF = "DescribePrincipalIdFormat";
    var _DPIFR = "DescribePrincipalIdFormatRequest";
    var _DPIFRe = "DescribePrincipalIdFormatResult";
    var _DPIP = "DeletePublicIpv4Pool";
    var _DPIPC = "DeprovisionPublicIpv4PoolCidr";
    var _DPIPCR = "DeprovisionPublicIpv4PoolCidrRequest";
    var _DPIPCRe = "DeprovisionPublicIpv4PoolCidrResult";
    var _DPIPR = "DeletePublicIpv4PoolRequest";
    var _DPIPRe = "DeletePublicIpv4PoolResult";
    var _DPIPRes = "DescribePublicIpv4PoolsRequest";
    var _DPIPResc = "DescribePublicIpv4PoolsResult";
    var _DPIPe = "DescribePublicIpv4Pools";
    var _DPL = "DestinationPrefixLists";
    var _DPLI = "DestinationPrefixListId";
    var _DPLR = "DescribePrefixListsRequest";
    var _DPLRe = "DescribePrefixListsResult";
    var _DPLe = "DestinationPrefixList";
    var _DPLes = "DescribePrefixLists";
    var _DPR = "DestinationPortRanges";
    var _DPRL = "DeclarativePoliciesReportList";
    var _DPRT = "DefaultPropagationRouteTable";
    var _DPRe = "DestinationPortRange";
    var _DPRec = "DeclarativePoliciesReport";
    var _DPe = "DestinationPort";
    var _DPer = "DeregistrationProtection";
    var _DPes = "DestinationPorts";
    var _DQ = "DataQuery";
    var _DQRI = "DeleteQueuedReservedInstances";
    var _DQRIE = "DeleteQueuedReservedInstancesError";
    var _DQRIIL = "DeleteQueuedReservedInstancesIdList";
    var _DQRIR = "DeleteQueuedReservedInstancesRequest";
    var _DQRIRe = "DeleteQueuedReservedInstancesResult";
    var _DQa = "DataQueries";
    var _DR = "DryRun";
    var _DRDAI = "DefaultResourceDiscoveryAssociationId";
    var _DRDI = "DefaultResourceDiscoveryId";
    var _DRI = "DescribeReservedInstances";
    var _DRIL = "DescribeReservedInstancesListings";
    var _DRILR = "DescribeReservedInstancesListingsRequest";
    var _DRILRe = "DescribeReservedInstancesListingsResult";
    var _DRIM = "DescribeReservedInstancesModifications";
    var _DRIMR = "DescribeReservedInstancesModificationsRequest";
    var _DRIMRe = "DescribeReservedInstancesModificationsResult";
    var _DRIO = "DescribeReservedInstancesOfferings";
    var _DRIOR = "DescribeReservedInstancesOfferingsRequest";
    var _DRIORe = "DescribeReservedInstancesOfferingsResult";
    var _DRIR = "DescribeReservedInstancesRequest";
    var _DRIRe = "DescribeReservedInstancesResult";
    var _DRIT = "DnsRecordIpType";
    var _DRR = "DeleteRouteRequest";
    var _DRRV = "DeleteReplacedRootVolume";
    var _DRRVT = "DescribeReplaceRootVolumeTasks";
    var _DRRVTR = "DescribeReplaceRootVolumeTasksRequest";
    var _DRRVTRe = "DescribeReplaceRootVolumeTasksResult";
    var _DRRe = "DescribeRegionsRequest";
    var _DRRes = "DescribeRegionsResult";
    var _DRS = "DataRetentionSupport";
    var _DRSE = "DeleteRouteServerEndpoint";
    var _DRSER = "DeleteRouteServerEndpointRequest";
    var _DRSERe = "DeleteRouteServerEndpointResult";
    var _DRSERes = "DescribeRouteServerEndpointsRequest";
    var _DRSEResc = "DescribeRouteServerEndpointsResult";
    var _DRSEe = "DescribeRouteServerEndpoints";
    var _DRSP = "DeleteRouteServerPeer";
    var _DRSPR = "DeleteRouteServerPeerRequest";
    var _DRSPRe = "DeleteRouteServerPeerResult";
    var _DRSPRes = "DescribeRouteServerPeersRequest";
    var _DRSPResc = "DescribeRouteServerPeersResult";
    var _DRSPRi = "DisableRouteServerPropagationRequest";
    var _DRSPRis = "DisableRouteServerPropagationResult";
    var _DRSPe = "DescribeRouteServerPeers";
    var _DRSPi = "DisableRouteServerPropagation";
    var _DRSR = "DeleteRouteServerRequest";
    var _DRSRe = "DeleteRouteServerResult";
    var _DRSRes = "DescribeRouteServersRequest";
    var _DRSResc = "DescribeRouteServersResult";
    var _DRSRi = "DisassociateRouteServerRequest";
    var _DRSRis = "DisassociateRouteServerResult";
    var _DRSe = "DeleteRouteServer";
    var _DRSes = "DescribeRouteServers";
    var _DRSi = "DisassociateRouteServer";
    var _DRT = "DeleteRouteTable";
    var _DRTA = "DefaultRouteTableAssociation";
    var _DRTP = "DefaultRouteTablePropagation";
    var _DRTR = "DeleteRouteTableRequest";
    var _DRTRe = "DescribeRouteTablesRequest";
    var _DRTRes = "DescribeRouteTablesResult";
    var _DRTRi = "DisassociateRouteTableRequest";
    var _DRTe = "DescribeRouteTables";
    var _DRTi = "DisassociateRouteTable";
    var _DRa = "DataResponse";
    var _DRat = "DataResponses";
    var _DRe = "DestinationRegion";
    var _DReb = "DebuggingRestrictions";
    var _DRel = "DeleteRoute";
    var _DRes = "DescribeRegions";
    var _DRi = "DiscoveryRegion";
    var _DRy = "DynamicRouting";
    var _DS10 = "DnsServers";
    var _DSA = "DirectoryServiceAuthentication";
    var _DSAR = "DescribeSnapshotAttributeRequest";
    var _DSARe = "DescribeSnapshotAttributeResult";
    var _DSARi = "DirectoryServiceAuthenticationRequest";
    var _DSAe = "DescribeSnapshotAttribute";
    var _DSBPA = "DisableSnapshotBlockPublicAccess";
    var _DSBPAR = "DisableSnapshotBlockPublicAccessRequest";
    var _DSBPARi = "DisableSnapshotBlockPublicAccessResult";
    var _DSCA = "DisableSerialConsoleAccess";
    var _DSCAR = "DisableSerialConsoleAccessRequest";
    var _DSCARi = "DisableSerialConsoleAccessResult";
    var _DSCB = "DisassociateSubnetCidrBlock";
    var _DSCBR = "DisassociateSubnetCidrBlockRequest";
    var _DSCBRi = "DisassociateSubnetCidrBlockResult";
    var _DSCR = "DeletedSubnetCidrReservation";
    var _DSCRR = "DeleteSubnetCidrReservationRequest";
    var _DSCRRe = "DeleteSubnetCidrReservationResult";
    var _DSCRe = "DeleteSubnetCidrReservation";
    var _DSDS = "DeleteSpotDatafeedSubscription";
    var _DSDSR = "DeleteSpotDatafeedSubscriptionRequest";
    var _DSDSRe = "DescribeSpotDatafeedSubscriptionRequest";
    var _DSDSRes = "DescribeSpotDatafeedSubscriptionResult";
    var _DSDSe = "DescribeSpotDatafeedSubscription";
    var _DSFI = "DescribeSpotFleetInstances";
    var _DSFIR = "DescribeSpotFleetInstancesRequest";
    var _DSFIRe = "DescribeSpotFleetInstancesResponse";
    var _DSFR = "DescribeSpotFleetRequests";
    var _DSFRH = "DescribeSpotFleetRequestHistory";
    var _DSFRHR = "DescribeSpotFleetRequestHistoryRequest";
    var _DSFRHRe = "DescribeSpotFleetRequestHistoryResponse";
    var _DSFRR = "DescribeSpotFleetRequestsRequest";
    var _DSFRRe = "DescribeSpotFleetRequestsResponse";
    var _DSG = "DeleteSecurityGroup";
    var _DSGR = "DeleteSecurityGroupRequest";
    var _DSGRR = "DescribeSecurityGroupReferencesRequest";
    var _DSGRRe = "DescribeSecurityGroupReferencesResult";
    var _DSGRRes = "DescribeSecurityGroupRulesRequest";
    var _DSGRResc = "DescribeSecurityGroupRulesResult";
    var _DSGRe = "DeleteSecurityGroupResult";
    var _DSGRes = "DescribeSecurityGroupsRequest";
    var _DSGResc = "DescribeSecurityGroupsResult";
    var _DSGRescr = "DescribeSecurityGroupReferences";
    var _DSGRescri = "DescribeSecurityGroupRules";
    var _DSGV = "DisassociateSecurityGroupVpc";
    var _DSGVA = "DescribeSecurityGroupVpcAssociations";
    var _DSGVAR = "DescribeSecurityGroupVpcAssociationsRequest";
    var _DSGVARe = "DescribeSecurityGroupVpcAssociationsResult";
    var _DSGVR = "DisassociateSecurityGroupVpcRequest";
    var _DSGVRi = "DisassociateSecurityGroupVpcResult";
    var _DSGe = "DescribeSecurityGroups";
    var _DSI = "DescribeScheduledInstances";
    var _DSIA = "DescribeScheduledInstanceAvailability";
    var _DSIAR = "DescribeScheduledInstanceAvailabilityRequest";
    var _DSIARe = "DescribeScheduledInstanceAvailabilityResult";
    var _DSIR = "DescribeScheduledInstancesRequest";
    var _DSIRR = "DescribeSpotInstanceRequestsRequest";
    var _DSIRRe = "DescribeSpotInstanceRequestsResult";
    var _DSIRe = "DescribeScheduledInstancesResult";
    var _DSIRes = "DescribeSecondaryInterfacesRequest";
    var _DSIResc = "DescribeSecondaryInterfacesResult";
    var _DSIRescr = "DescribeSpotInstanceRequests";
    var _DSIT = "DescribeStoreImageTasks";
    var _DSITR = "DescribeStoreImageTasksRequest";
    var _DSITRe = "DescribeStoreImageTasksResult";
    var _DSIe = "DescribeSecondaryInterfaces";
    var _DSLVI = "DescribeServiceLinkVirtualInterfaces";
    var _DSLVIR = "DescribeServiceLinkVirtualInterfacesRequest";
    var _DSLVIRe = "DescribeServiceLinkVirtualInterfacesResult";
    var _DSN = "DeleteSecondaryNetwork";
    var _DSNR = "DeleteSecondaryNetworkRequest";
    var _DSNRe = "DeleteSecondaryNetworkResult";
    var _DSNRes = "DescribeSecondaryNetworksRequest";
    var _DSNResc = "DescribeSecondaryNetworksResult";
    var _DSNe = "DescribeSecondaryNetworks";
    var _DSOMS = "DnsServersOptionsModifyStructure";
    var _DSPH = "DescribeSpotPriceHistory";
    var _DSPHR = "DescribeSpotPriceHistoryRequest";
    var _DSPHRe = "DescribeSpotPriceHistoryResult";
    var _DSR = "DeleteSnapshotRequest";
    var _DSRC = "DeleteSnapshotReturnCode";
    var _DSRS = "DeleteSnapshotResultSet";
    var _DSRe = "DeleteSubnetRequest";
    var _DSRel = "DeleteSnapshotResults";
    var _DSRes = "DescribeSnapshotsRequest";
    var _DSResc = "DescribeSnapshotsResult";
    var _DSRescr = "DescribeSubnetsRequest";
    var _DSRescri = "DescribeSubnetsResult";
    var _DSS = "DeleteSecondarySubnet";
    var _DSSG = "DescribeStaleSecurityGroups";
    var _DSSGR = "DescribeStaleSecurityGroupsRequest";
    var _DSSGRe = "DescribeStaleSecurityGroupsResult";
    var _DSSR = "DeleteSecondarySubnetRequest";
    var _DSSRe = "DeleteSecondarySubnetResult";
    var _DSSRes = "DescribeSecondarySubnetsRequest";
    var _DSSResc = "DescribeSecondarySubnetsResult";
    var _DSSe = "DescribeSecondarySubnets";
    var _DSTS = "DescribeSnapshotTierStatus";
    var _DSTSR = "DescribeSnapshotTierStatusRequest";
    var _DSTSRe = "DescribeSnapshotTierStatusResult";
    var _DSe = "DeliveryStatus";
    var _DSel = "DeliveryStream";
    var _DSele = "DeleteSnapshot";
    var _DSelet = "DeleteSubnet";
    var _DSes = "DescribeSnapshots";
    var _DSesc = "DescribeSubnets";
    var _DSn = "DnsSupport";
    var _DT = "DeletionTime";
    var _DTA = "DpdTimeoutAction";
    var _DTC = "DeprecationTimeCondition";
    var _DTCR = "DeprecationTimeConditionRequest";
    var _DTCT = "DefaultTargetCapacityType";
    var _DTET = "DefaultTcpEstablishedTimeout";
    var _DTG = "DeleteTransitGateway";
    var _DTGA = "DescribeTransitGatewayAttachments";
    var _DTGAI = "DestinationTransitGatewayAttachmentId";
    var _DTGAR = "DescribeTransitGatewayAttachmentsRequest";
    var _DTGARe = "DescribeTransitGatewayAttachmentsResult";
    var _DTGAT = "DestinationTransitGatewayAttachmentType";
    var _DTGC = "DeleteTransitGatewayConnect";
    var _DTGCP = "DeleteTransitGatewayConnectPeer";
    var _DTGCPR = "DeleteTransitGatewayConnectPeerRequest";
    var _DTGCPRe = "DeleteTransitGatewayConnectPeerResult";
    var _DTGCPRes = "DescribeTransitGatewayConnectPeersRequest";
    var _DTGCPResc = "DescribeTransitGatewayConnectPeersResult";
    var _DTGCPe = "DescribeTransitGatewayConnectPeers";
    var _DTGCR = "DeleteTransitGatewayConnectRequest";
    var _DTGCRe = "DeleteTransitGatewayConnectResult";
    var _DTGCRes = "DescribeTransitGatewayConnectsRequest";
    var _DTGCResc = "DescribeTransitGatewayConnectsResult";
    var _DTGCVA = "DeleteTransitGatewayClientVpnAttachment";
    var _DTGCVAR = "DeleteTransitGatewayClientVpnAttachmentRequest";
    var _DTGCVARe = "DeleteTransitGatewayClientVpnAttachmentResult";
    var _DTGCe = "DescribeTransitGatewayConnects";
    var _DTGMD = "DeleteTransitGatewayMulticastDomain";
    var _DTGMDR = "DeleteTransitGatewayMulticastDomainRequest";
    var _DTGMDRe = "DeleteTransitGatewayMulticastDomainResult";
    var _DTGMDRes = "DescribeTransitGatewayMulticastDomainsRequest";
    var _DTGMDResc = "DescribeTransitGatewayMulticastDomainsResult";
    var _DTGMDRi = "DisassociateTransitGatewayMulticastDomainRequest";
    var _DTGMDRis = "DisassociateTransitGatewayMulticastDomainResult";
    var _DTGMDe = "DescribeTransitGatewayMulticastDomains";
    var _DTGMDi = "DisassociateTransitGatewayMulticastDomain";
    var _DTGMGM = "DeregisterTransitGatewayMulticastGroupMembers";
    var _DTGMGMR = "DeregisterTransitGatewayMulticastGroupMembersRequest";
    var _DTGMGMRe = "DeregisterTransitGatewayMulticastGroupMembersResult";
    var _DTGMGS = "DeregisterTransitGatewayMulticastGroupSources";
    var _DTGMGSR = "DeregisterTransitGatewayMulticastGroupSourcesRequest";
    var _DTGMGSRe = "DeregisterTransitGatewayMulticastGroupSourcesResult";
    var _DTGMP = "DeleteTransitGatewayMeteringPolicy";
    var _DTGMPE = "DeleteTransitGatewayMeteringPolicyEntry";
    var _DTGMPER = "DeleteTransitGatewayMeteringPolicyEntryRequest";
    var _DTGMPERe = "DeleteTransitGatewayMeteringPolicyEntryResult";
    var _DTGMPR = "DeleteTransitGatewayMeteringPolicyRequest";
    var _DTGMPRe = "DeleteTransitGatewayMeteringPolicyResult";
    var _DTGMPRes = "DescribeTransitGatewayMeteringPoliciesRequest";
    var _DTGMPResc = "DescribeTransitGatewayMeteringPoliciesResult";
    var _DTGMPe = "DescribeTransitGatewayMeteringPolicies";
    var _DTGPA = "DeleteTransitGatewayPeeringAttachment";
    var _DTGPAR = "DeleteTransitGatewayPeeringAttachmentRequest";
    var _DTGPARe = "DeleteTransitGatewayPeeringAttachmentResult";
    var _DTGPARes = "DescribeTransitGatewayPeeringAttachmentsRequest";
    var _DTGPAResc = "DescribeTransitGatewayPeeringAttachmentsResult";
    var _DTGPAe = "DescribeTransitGatewayPeeringAttachments";
    var _DTGPLR = "DeleteTransitGatewayPrefixListReference";
    var _DTGPLRR = "DeleteTransitGatewayPrefixListReferenceRequest";
    var _DTGPLRRe = "DeleteTransitGatewayPrefixListReferenceResult";
    var _DTGPT = "DeleteTransitGatewayPolicyTable";
    var _DTGPTR = "DeleteTransitGatewayPolicyTableRequest";
    var _DTGPTRe = "DeleteTransitGatewayPolicyTableResult";
    var _DTGPTRes = "DescribeTransitGatewayPolicyTablesRequest";
    var _DTGPTResc = "DescribeTransitGatewayPolicyTablesResult";
    var _DTGPTRi = "DisassociateTransitGatewayPolicyTableRequest";
    var _DTGPTRis = "DisassociateTransitGatewayPolicyTableResult";
    var _DTGPTe = "DescribeTransitGatewayPolicyTables";
    var _DTGPTi = "DisassociateTransitGatewayPolicyTable";
    var _DTGR = "DeleteTransitGatewayRequest";
    var _DTGRR = "DeleteTransitGatewayRouteRequest";
    var _DTGRRe = "DeleteTransitGatewayRouteResult";
    var _DTGRT = "DeleteTransitGatewayRouteTable";
    var _DTGRTA = "DeleteTransitGatewayRouteTableAnnouncement";
    var _DTGRTAR = "DeleteTransitGatewayRouteTableAnnouncementRequest";
    var _DTGRTARe = "DeleteTransitGatewayRouteTableAnnouncementResult";
    var _DTGRTARes = "DescribeTransitGatewayRouteTableAnnouncementsRequest";
    var _DTGRTAResc = "DescribeTransitGatewayRouteTableAnnouncementsResult";
    var _DTGRTAe = "DescribeTransitGatewayRouteTableAnnouncements";
    var _DTGRTP = "DisableTransitGatewayRouteTablePropagation";
    var _DTGRTPR = "DisableTransitGatewayRouteTablePropagationRequest";
    var _DTGRTPRi = "DisableTransitGatewayRouteTablePropagationResult";
    var _DTGRTR = "DeleteTransitGatewayRouteTableRequest";
    var _DTGRTRe = "DeleteTransitGatewayRouteTableResult";
    var _DTGRTRes = "DescribeTransitGatewayRouteTablesRequest";
    var _DTGRTResc = "DescribeTransitGatewayRouteTablesResult";
    var _DTGRTRi = "DisassociateTransitGatewayRouteTableRequest";
    var _DTGRTRis = "DisassociateTransitGatewayRouteTableResult";
    var _DTGRTe = "DescribeTransitGatewayRouteTables";
    var _DTGRTi = "DisassociateTransitGatewayRouteTable";
    var _DTGRe = "DeleteTransitGatewayResult";
    var _DTGRel = "DeleteTransitGatewayRoute";
    var _DTGRes = "DescribeTransitGatewaysRequest";
    var _DTGResc = "DescribeTransitGatewaysResult";
    var _DTGVA = "DeleteTransitGatewayVpcAttachment";
    var _DTGVAR = "DeleteTransitGatewayVpcAttachmentRequest";
    var _DTGVARe = "DeleteTransitGatewayVpcAttachmentResult";
    var _DTGVARes = "DescribeTransitGatewayVpcAttachmentsRequest";
    var _DTGVAResc = "DescribeTransitGatewayVpcAttachmentsResult";
    var _DTGVAe = "DescribeTransitGatewayVpcAttachments";
    var _DTGe = "DescribeTransitGateways";
    var _DTI = "DisassociateTrunkInterface";
    var _DTIA = "DescribeTrunkInterfaceAssociations";
    var _DTIAR = "DescribeTrunkInterfaceAssociationsRequest";
    var _DTIARe = "DescribeTrunkInterfaceAssociationsResult";
    var _DTIR = "DisassociateTrunkInterfaceRequest";
    var _DTIRi = "DisassociateTrunkInterfaceResult";
    var _DTK = "DeactivateTagKeys";
    var _DTKe = "DeactivateTagKey";
    var _DTMF = "DeleteTrafficMirrorFilter";
    var _DTMFR = "DeleteTrafficMirrorFilterRequest";
    var _DTMFRR = "DeleteTrafficMirrorFilterRuleRequest";
    var _DTMFRRe = "DeleteTrafficMirrorFilterRuleResult";
    var _DTMFRRes = "DescribeTrafficMirrorFilterRulesRequest";
    var _DTMFRResc = "DescribeTrafficMirrorFilterRulesResult";
    var _DTMFRe = "DeleteTrafficMirrorFilterResult";
    var _DTMFRel = "DeleteTrafficMirrorFilterRule";
    var _DTMFRes = "DescribeTrafficMirrorFiltersRequest";
    var _DTMFResc = "DescribeTrafficMirrorFiltersResult";
    var _DTMFRescr = "DescribeTrafficMirrorFilterRules";
    var _DTMFe = "DescribeTrafficMirrorFilters";
    var _DTMS = "DeleteTrafficMirrorSession";
    var _DTMSR = "DeleteTrafficMirrorSessionRequest";
    var _DTMSRe = "DeleteTrafficMirrorSessionResult";
    var _DTMSRes = "DescribeTrafficMirrorSessionsRequest";
    var _DTMSResc = "DescribeTrafficMirrorSessionsResult";
    var _DTMSe = "DescribeTrafficMirrorSessions";
    var _DTMT = "DeleteTrafficMirrorTarget";
    var _DTMTR = "DeleteTrafficMirrorTargetRequest";
    var _DTMTRe = "DeleteTrafficMirrorTargetResult";
    var _DTMTRes = "DescribeTrafficMirrorTargetsRequest";
    var _DTMTResc = "DescribeTrafficMirrorTargetsResult";
    var _DTMTe = "DescribeTrafficMirrorTargets";
    var _DTP = "DeviceTrustProviders";
    var _DTPC = "DefaultThreadsPerCore";
    var _DTPT = "DeviceTrustProviderType";
    var _DTPTL = "DeviceTrustProviderTypeList";
    var _DTR = "DeleteTagsRequest";
    var _DTRe = "DescribeTagsRequest";
    var _DTRes = "DescribeTagsResult";
    var _DTRr = "DTraceRestrictions";
    var _DTS = "DpdTimeoutSeconds";
    var _DTe = "DeprecationTime";
    var _DTel = "DeleteTime";
    var _DTele = "DeletionTimestamp";
    var _DTelet = "DeleteTags";
    var _DTes = "DescribeTags";
    var _DTi = "DisablingTime";
    var _DTis = "DisabledTime";
    var _DUST = "DefaultUdpStreamTimeout";
    var _DUT = "DefaultUdpTimeout";
    var _DV = "DesiredVersion";
    var _DVA = "DescribeVolumeAttribute";
    var _DVAE = "DeleteVerifiedAccessEndpoint";
    var _DVAER = "DeleteVerifiedAccessEndpointRequest";
    var _DVAERe = "DeleteVerifiedAccessEndpointResult";
    var _DVAERes = "DescribeVerifiedAccessEndpointsRequest";
    var _DVAEResc = "DescribeVerifiedAccessEndpointsResult";
    var _DVAEe = "DescribeVerifiedAccessEndpoints";
    var _DVAG = "DeleteVerifiedAccessGroup";
    var _DVAGR = "DeleteVerifiedAccessGroupRequest";
    var _DVAGRe = "DeleteVerifiedAccessGroupResult";
    var _DVAGRes = "DescribeVerifiedAccessGroupsRequest";
    var _DVAGResc = "DescribeVerifiedAccessGroupsResult";
    var _DVAGe = "DescribeVerifiedAccessGroups";
    var _DVAI = "DeleteVerifiedAccessInstance";
    var _DVAILC = "DescribeVerifiedAccessInstanceLoggingConfigurations";
    var _DVAILCR = "DescribeVerifiedAccessInstanceLoggingConfigurationsRequest";
    var _DVAILCRe = "DescribeVerifiedAccessInstanceLoggingConfigurationsResult";
    var _DVAIR = "DeleteVerifiedAccessInstanceRequest";
    var _DVAIRe = "DeleteVerifiedAccessInstanceResult";
    var _DVAIRes = "DescribeVerifiedAccessInstancesRequest";
    var _DVAIResc = "DescribeVerifiedAccessInstancesResult";
    var _DVAIe = "DescribeVerifiedAccessInstances";
    var _DVAR = "DescribeVolumeAttributeRequest";
    var _DVARe = "DescribeVolumeAttributeResult";
    var _DVARes = "DescribeVpcAttributeRequest";
    var _DVAResc = "DescribeVpcAttributeResult";
    var _DVATP = "DeleteVerifiedAccessTrustProvider";
    var _DVATPR = "DeleteVerifiedAccessTrustProviderRequest";
    var _DVATPRe = "DeleteVerifiedAccessTrustProviderResult";
    var _DVATPRes = "DescribeVerifiedAccessTrustProvidersRequest";
    var _DVATPResc = "DescribeVerifiedAccessTrustProvidersResult";
    var _DVATPRet = "DetachVerifiedAccessTrustProviderRequest";
    var _DVATPReta = "DetachVerifiedAccessTrustProviderResult";
    var _DVATPe = "DescribeVerifiedAccessTrustProviders";
    var _DVATPet = "DetachVerifiedAccessTrustProvider";
    var _DVAe = "DescribeVpcAttribute";
    var _DVBPAE = "DeleteVpcBlockPublicAccessExclusion";
    var _DVBPAER = "DeleteVpcBlockPublicAccessExclusionRequest";
    var _DVBPAERe = "DeleteVpcBlockPublicAccessExclusionResult";
    var _DVBPAERes = "DescribeVpcBlockPublicAccessExclusionsRequest";
    var _DVBPAEResc = "DescribeVpcBlockPublicAccessExclusionsResult";
    var _DVBPAEe = "DescribeVpcBlockPublicAccessExclusions";
    var _DVBPAO = "DescribeVpcBlockPublicAccessOptions";
    var _DVBPAOR = "DescribeVpcBlockPublicAccessOptionsRequest";
    var _DVBPAORe = "DescribeVpcBlockPublicAccessOptionsResult";
    var _DVC = "DefaultVCpus";
    var _DVCB = "DisassociateVpcCidrBlock";
    var _DVCBR = "DisassociateVpcCidrBlockRequest";
    var _DVCBRi = "DisassociateVpcCidrBlockResult";
    var _DVCL = "DescribeVpcClassicLink";
    var _DVCLDS = "DescribeVpcClassicLinkDnsSupport";
    var _DVCLDSR = "DescribeVpcClassicLinkDnsSupportRequest";
    var _DVCLDSRe = "DescribeVpcClassicLinkDnsSupportResult";
    var _DVCLDSRi = "DisableVpcClassicLinkDnsSupportRequest";
    var _DVCLDSRis = "DisableVpcClassicLinkDnsSupportResult";
    var _DVCLDSi = "DisableVpcClassicLinkDnsSupport";
    var _DVCLR = "DescribeVpcClassicLinkRequest";
    var _DVCLRe = "DescribeVpcClassicLinkResult";
    var _DVCLRi = "DisableVpcClassicLinkRequest";
    var _DVCLRis = "DisableVpcClassicLinkResult";
    var _DVCLi = "DisableVpcClassicLink";
    var _DVCR = "DeleteVpnConcentratorRequest";
    var _DVCRR = "DeleteVpnConnectionRouteRequest";
    var _DVCRe = "DeleteVpnConcentratorResult";
    var _DVCRel = "DeleteVpnConnectionRequest";
    var _DVCRele = "DeleteVpnConnectionRoute";
    var _DVCRes = "DescribeVpnConcentratorsRequest";
    var _DVCResc = "DescribeVpnConcentratorsResult";
    var _DVCRescr = "DescribeVpnConnectionsRequest";
    var _DVCRescri = "DescribeVpnConnectionsResult";
    var _DVCe = "DeleteVpnConcentrator";
    var _DVCel = "DeleteVpnConnection";
    var _DVCes = "DescribeVpnConcentrators";
    var _DVCesc = "DescribeVpnConnections";
    var _DVD = "DeviceValidationDomain";
    var _DVE = "DeleteVpcEndpoints";
    var _DVEA = "DescribeVpcEndpointAssociations";
    var _DVEAR = "DescribeVpcEndpointAssociationsRequest";
    var _DVEARe = "DescribeVpcEndpointAssociationsResult";
    var _DVEC = "DeleteVpcEncryptionControl";
    var _DVECN = "DeleteVpcEndpointConnectionNotifications";
    var _DVECNR = "DeleteVpcEndpointConnectionNotificationsRequest";
    var _DVECNRe = "DeleteVpcEndpointConnectionNotificationsResult";
    var _DVECNRes = "DescribeVpcEndpointConnectionNotificationsRequest";
    var _DVECNResc = "DescribeVpcEndpointConnectionNotificationsResult";
    var _DVECNe = "DescribeVpcEndpointConnectionNotifications";
    var _DVECR = "DeleteVpcEncryptionControlRequest";
    var _DVECRe = "DeleteVpcEncryptionControlResult";
    var _DVECRes = "DescribeVpcEncryptionControlsRequest";
    var _DVECResc = "DescribeVpcEncryptionControlsResult";
    var _DVECRescr = "DescribeVpcEndpointConnectionsRequest";
    var _DVECRescri = "DescribeVpcEndpointConnectionsResult";
    var _DVECe = "DescribeVpcEncryptionControls";
    var _DVECes = "DescribeVpcEndpointConnections";
    var _DVER = "DeleteVpcEndpointsRequest";
    var _DVERe = "DeleteVpcEndpointsResult";
    var _DVERes = "DescribeVpcEndpointsRequest";
    var _DVEResc = "DescribeVpcEndpointsResult";
    var _DVES = "DescribeVpcEndpointServices";
    var _DVESC = "DeleteVpcEndpointServiceConfigurations";
    var _DVESCR = "DeleteVpcEndpointServiceConfigurationsRequest";
    var _DVESCRe = "DeleteVpcEndpointServiceConfigurationsResult";
    var _DVESCRes = "DescribeVpcEndpointServiceConfigurationsRequest";
    var _DVESCResc = "DescribeVpcEndpointServiceConfigurationsResult";
    var _DVESCe = "DescribeVpcEndpointServiceConfigurations";
    var _DVESP = "DescribeVpcEndpointServicePermissions";
    var _DVESPR = "DescribeVpcEndpointServicePermissionsRequest";
    var _DVESPRe = "DescribeVpcEndpointServicePermissionsResult";
    var _DVESR = "DescribeVpcEndpointServicesRequest";
    var _DVESRe = "DescribeVpcEndpointServicesResult";
    var _DVEe = "DescribeVpcEndpoints";
    var _DVG = "DeleteVpnGateway";
    var _DVGR = "DeleteVpnGatewayRequest";
    var _DVGRe = "DescribeVpnGatewaysRequest";
    var _DVGRes = "DescribeVpnGatewaysResult";
    var _DVGRet = "DetachVpnGatewayRequest";
    var _DVGe = "DescribeVpnGateways";
    var _DVGet = "DetachVpnGateway";
    var _DVM = "DescribeVolumesModifications";
    var _DVMR = "DescribeVolumesModificationsRequest";
    var _DVMRe = "DescribeVolumesModificationsResult";
    var _DVN = "DefaultVersionNumber";
    var _DVPC = "DeleteVpcPeeringConnection";
    var _DVPCR = "DeleteVpcPeeringConnectionRequest";
    var _DVPCRe = "DeleteVpcPeeringConnectionResult";
    var _DVPCRes = "DescribeVpcPeeringConnectionsRequest";
    var _DVPCResc = "DescribeVpcPeeringConnectionsResult";
    var _DVPCe = "DescribeVpcPeeringConnections";
    var _DVR = "DeleteVolumeRequest";
    var _DVRP = "DisableVgwRoutePropagation";
    var _DVRPR = "DisableVgwRoutePropagationRequest";
    var _DVRe = "DeleteVpcRequest";
    var _DVRes = "DescribeVolumesRequest";
    var _DVResc = "DescribeVolumesResult";
    var _DVRescr = "DescribeVpcsRequest";
    var _DVRescri = "DescribeVpcsResult";
    var _DVRet = "DetachVolumeRequest";
    var _DVS = "DescribeVolumeStatus";
    var _DVSR = "DescribeVolumeStatusRequest";
    var _DVSRe = "DescribeVolumeStatusResult";
    var _DVe = "DestinationVpc";
    var _DVef = "DefaultVersion";
    var _DVefa = "DefaultVisibility";
    var _DVel = "DeleteVolume";
    var _DVele = "DeleteVpc";
    var _DVes = "DescribeVolumes";
    var _DVesc = "DescribeVpcs";
    var _DVet = "DetachVolume";
    var _Da = "Data";
    var _De = "Description";
    var _Dea = "Deadline";
    var _Des = "Destinations";
    var _Det = "Details";
    var _Dev = "Device";
    var _Di = "Direction";
    var _Dim = "Dimension";
    var _Dis = "Disks";
    var _Do = "Domain";
    var _Du = "Duration";
    var _Dua = "Dualstack";
    var _E11 = "Egress";
    var _EA = "EniAddress";
    var _EAC = "ExternalAuthorityConfiguration";
    var _EAIL = "EipAssociationIdList";
    var _EAIS = "EnableAllowedImagesSettings";
    var _EAISR = "EnableAllowedImagesSettingsRequest";
    var _EAISRn = "EnableAllowedImagesSettingsResult";
    var _EANPMS = "EnableAwsNetworkPerformanceMetricSubscription";
    var _EANPMSR = "EnableAwsNetworkPerformanceMetricSubscriptionRequest";
    var _EANPMSRn = "EnableAwsNetworkPerformanceMetricSubscriptionResult";
    var _EAT = "EnableAddressTransfer";
    var _EATR = "EnableAddressTransferRequest";
    var _EATRn = "EnableAddressTransferResult";
    var _EAn = "EnableAcceleration";
    var _EAx = "ExclusionsAllowed";
    var _EB = "EgressBytes";
    var _EBD = "EbsBlockDevice";
    var _EBDR = "EbsBlockDeviceResponse";
    var _EBSL = "ExecutableByStringList";
    var _EBV = "ExcludeBootVolume";
    var _EBx = "ExecutableBy";
    var _EC = "ErrorCode";
    var _ECI = "EbsCardIndex";
    var _ECIL = "EbsCardInfoList";
    var _ECIb = "EbsCardInfo";
    var _ECM = "EnableCapacityManager";
    var _ECMR = "EnableCapacityManagerRequest";
    var _ECMRn = "EnableCapacityManagerResult";
    var _ECTP = "ExcessCapacityTerminationPolicy";
    var _ECVCC = "ExportClientVpnClientConfiguration";
    var _ECVCCR = "ExportClientVpnClientConfigurationRequest";
    var _ECVCCRL = "ExportClientVpnClientCertificateRevocationList";
    var _ECVCCRLR = "ExportClientVpnClientCertificateRevocationListRequest";
    var _ECVCCRLRx = "ExportClientVpnClientCertificateRevocationListResult";
    var _ECVCCRx = "ExportClientVpnClientConfigurationResult";
    var _ECb = "EbsCards";
    var _ECn = "EncryptionControl";
    var _ECx = "ExplanationCode";
    var _ED = "EndDate";
    var _EDH = "EnableDnsHostnames";
    var _EDP = "EndpointDomainPrefix";
    var _EDR = "EndDateRange";
    var _EDS = "EnableDnsSupport";
    var _EDT = "EarliestDatapointTimestamp";
    var _EDTn = "EndDateType";
    var _EDVI = "ExcludeDataVolumeIds";
    var _EDVIx = "ExcludeDataVolumeId";
    var _EDf = "EffectiveDate";
    var _EDn = "EnableDns64";
    var _EDnd = "EndpointDomain";
    var _EDv = "EventDescription";
    var _EDx = "ExpirationDate";
    var _EEA = "EndpointEniAddress";
    var _EEBD = "EbsEncryptionByDefault";
    var _EEEBD = "EnableEbsEncryptionByDefault";
    var _EEEBDR = "EnableEbsEncryptionByDefaultRequest";
    var _EEEBDRn = "EnableEbsEncryptionByDefaultResult";
    var _EEI = "EndpointEniId";
    var _EFL = "EnableFastLaunch";
    var _EFLR = "EnableFastLaunchRequest";
    var _EFLRn = "EnableFastLaunchResult";
    var _EFR = "EgressFilterRules";
    var _EFS = "ElasticFileSystem";
    var _EFSE = "ElasticFileSystemExclusion";
    var _EFSR = "EnableFastSnapshotRestores";
    var _EFSREI = "EnableFastSnapshotRestoreErrorItem";
    var _EFSRES = "EnableFastSnapshotRestoreErrorSet";
    var _EFSRR = "EnableFastSnapshotRestoresRequest";
    var _EFSRRn = "EnableFastSnapshotRestoresResult";
    var _EFSRSE = "EnableFastSnapshotRestoreStateError";
    var _EFSRSEI = "EnableFastSnapshotRestoreStateErrorItem";
    var _EFSRSES = "EnableFastSnapshotRestoreStateErrorSet";
    var _EFSRSI = "EnableFastSnapshotRestoreSuccessItem";
    var _EFSRSS = "EnableFastSnapshotRestoreSuccessSet";
    var _EG = "ElasticGpus";
    var _EGA = "ElasticGpuAssociation";
    var _EGAI = "ElasticGpuAssociationId";
    var _EGAL = "ElasticGpuAssociationList";
    var _EGAS = "ElasticGpuAssociationState";
    var _EGAT = "ElasticGpuAssociationTime";
    var _EGAl = "ElasticGpuAssociations";
    var _EGH = "ElasticGpuHealth";
    var _EGI = "ElasticGpuIds";
    var _EGIS = "ElasticGpuIdSet";
    var _EGIl = "ElasticGpuId";
    var _EGS = "ElasticGpuSet";
    var _EGSL = "ElasticGpuSpecificationList";
    var _EGSR = "ElasticGpuSpecificationResponse";
    var _EGSRL = "ElasticGpuSpecificationResponseList";
    var _EGSl = "ElasticGpuState";
    var _EGSla = "ElasticGpuSpecification";
    var _EGSlas = "ElasticGpuSpecifications";
    var _EGT = "ElasticGpuType";
    var _EH = "EndHour";
    var _EI10 = "ExchangeId";
    var _EIA = "ElasticInferenceAccelerator";
    var _EIAA = "ElasticInferenceAcceleratorAssociation";
    var _EIAAI = "ElasticInferenceAcceleratorAssociationId";
    var _EIAAL = "ElasticInferenceAcceleratorAssociationList";
    var _EIAAS = "ElasticInferenceAcceleratorAssociationState";
    var _EIAAT = "ElasticInferenceAcceleratorAssociationTime";
    var _EIAAl = "ElasticInferenceAcceleratorArn";
    var _EIAAla = "ElasticInferenceAcceleratorAssociations";
    var _EIAT = "EndpointIpAddressType";
    var _EIAl = "ElasticInferenceAccelerators";
    var _EIBD = "EbsInstanceBlockDevice";
    var _EIBDS = "EbsInstanceBlockDeviceSpecification";
    var _EIBPA = "EnableImageBlockPublicAccess";
    var _EIBPAR = "EnableImageBlockPublicAccessRequest";
    var _EIBPARn = "EnableImageBlockPublicAccessResult";
    var _EICE = "Ec2InstanceConnectEndpoint";
    var _EID = "EnableImageDeprecation";
    var _EIDP = "EnableImageDeregistrationProtection";
    var _EIDPR = "EnableImageDeregistrationProtectionRequest";
    var _EIDPRn = "EnableImageDeregistrationProtectionResult";
    var _EIDR = "EnableImageDeprecationRequest";
    var _EIDRn = "EnableImageDeprecationResult";
    var _EIOAA = "EnableIpamOrganizationAdminAccount";
    var _EIOAAR = "EnableIpamOrganizationAdminAccountRequest";
    var _EIOAARn = "EnableIpamOrganizationAdminAccountResult";
    var _EIP = "EnableIpamPolicy";
    var _EIPR = "EnableIpamPolicyRequest";
    var _EIPRn = "EnableIpamPolicyResult";
    var _EIR = "EnableImageRequest";
    var _EIRn = "EnableImageResult";
    var _EIRx = "ExportImageRequest";
    var _EIRxp = "ExportImageResult";
    var _EISHSD = "EnableInstanceSqlHaStandbyDetections";
    var _EISHSDR = "EnableInstanceSqlHaStandbyDetectionsRequest";
    var _EISHSDRn = "EnableInstanceSqlHaStandbyDetectionsResult";
    var _EIT = "ExportImageTasks";
    var _EITI = "ExportImageTaskIds";
    var _EITIL = "ExportImageTaskIdList";
    var _EITIx = "ExportImageTaskId";
    var _EITL = "ExportImageTaskList";
    var _EITS = "EncryptionInTransitSupported";
    var _EITSx = "ExcludedInstanceTypeSet";
    var _EITx = "ExportImageTask";
    var _EITxc = "ExcludedInstanceTypes";
    var _EITxcl = "ExcludedInstanceType";
    var _EIb = "EbsInfo";
    var _EIf = "EfaInfo";
    var _EIn = "EniId";
    var _EIna = "EnableImage";
    var _EIv = "EventInformation";
    var _EIve = "EventId";
    var _EIx = "ExclusionId";
    var _EIxc = "ExclusionIds";
    var _EIxp = "ExportImage";
    var _EKKI = "EncryptionKmsKeyId";
    var _EL = "ExplanationList";
    var _ELADI = "EnableLniAtDeviceIndex";
    var _ELBL = "ElasticLoadBalancerListener";
    var _EM = "ErrorMessage";
    var _ENAUM = "EnableNetworkAddressUsageMetrics";
    var _EO = "EbsOptimized";
    var _EOI = "EbsOptimizedInfo";
    var _EOIG = "EgressOnlyInternetGateway";
    var _EOIGE = "EgressOnlyInternetGatewayExclusion";
    var _EOIGI = "EgressOnlyInternetGatewayId";
    var _EOIGIL = "EgressOnlyInternetGatewayIdList";
    var _EOIGIg = "EgressOnlyInternetGatewayIds";
    var _EOIGL = "EgressOnlyInternetGatewayList";
    var _EOIGg = "EgressOnlyInternetGateways";
    var _EOR = "EnclaveOptionsRequest";
    var _EOS = "EbsOptimizedSupport";
    var _EOn = "EnclaveOptions";
    var _EP = "EgressPackets";
    var _EPG = "EnablePrivateGua";
    var _EPI = "EnablePrimaryIpv6";
    var _EPKV = "EkPubKeyValue";
    var _EPx = "ExcludePaths";
    var _EPxc = "ExcludePath";
    var _EQC = "EnaQueueCount";
    var _ERAOS = "EnableReachabilityAnalyzerOrganizationSharing";
    var _ERAOSR = "EnableReachabilityAnalyzerOrganizationSharingRequest";
    var _ERAOSRn = "EnableReachabilityAnalyzerOrganizationSharingResult";
    var _ERI = "ExternalResourceIdentifier";
    var _ERNDAAAAR = "EnableResourceNameDnsAAAARecord";
    var _ERNDAAAAROL = "EnableResourceNameDnsAAAARecordOnLaunch";
    var _ERNDAR = "EnableResourceNameDnsARecord";
    var _ERNDAROL = "EnableResourceNameDnsARecordOnLaunch";
    var _ERSP = "EnableRouteServerPropagation";
    var _ERSPR = "EnableRouteServerPropagationRequest";
    var _ERSPRn = "EnableRouteServerPropagationResult";
    var _ES = "EphemeralStorage";
    var _ESBPA = "EnableSnapshotBlockPublicAccess";
    var _ESBPAR = "EnableSnapshotBlockPublicAccessRequest";
    var _ESBPARn = "EnableSnapshotBlockPublicAccessResult";
    var _ESCA = "EnableSerialConsoleAccess";
    var _ESCAR = "EnableSerialConsoleAccessRequest";
    var _ESCARn = "EnableSerialConsoleAccessResult";
    var _ESD = "EbsStatusDetails";
    var _ESDL = "EbsStatusDetailsList";
    var _ESE2 = "EnaSrdEnabled";
    var _ESS = "EnaSrdSpecification";
    var _ESSR = "EnaSrdSpecificationRequest";
    var _ESSb = "EbsStatusSummary";
    var _ESSn = "EnaSrdSupported";
    var _EST = "EventSubType";
    var _ESUE = "EnaSrdUdpEnabled";
    var _ESUS = "EnaSrdUdpSpecification";
    var _ESUSR = "EnaSrdUdpSpecificationRequest";
    var _ESf = "EfaSupported";
    var _ESn = "EncryptionSupport";
    var _ESna = "EnaSupport";
    var _ESnc = "EncryptionState";
    var _ESnd = "EndpointSet";
    var _ESr = "ErrorSet";
    var _ET = "ExpirationTime";
    var _ETGR = "ExportTransitGatewayRoutes";
    var _ETGRR = "ExportTransitGatewayRoutesRequest";
    var _ETGRRx = "ExportTransitGatewayRoutesResult";
    var _ETGRTP = "EnableTransitGatewayRouteTablePropagation";
    var _ETGRTPR = "EnableTransitGatewayRouteTablePropagationRequest";
    var _ETGRTPRn = "EnableTransitGatewayRouteTablePropagationResult";
    var _ETI = "ExportTaskId";
    var _ETISL = "ExportTaskIdStringList";
    var _ETIx = "ExportTaskIds";
    var _ETL = "ExportTaskList";
    var _ETLC = "EnableTunnelLifecycleControl";
    var _ETSL = "ExportTaskS3Location";
    var _ETSLR = "ExportTaskS3LocationRequest";
    var _ETST = "ExportToS3Task";
    var _ETSTS = "ExportToS3TaskSpecification";
    var _ETTCIS = "EstimatedTimeToCompleteInSeconds";
    var _ETa = "EarliestTime";
    var _ETi = "EipTags";
    var _ETn = "EndpointType";
    var _ETna = "EnablingTime";
    var _ETnab = "EnabledTime";
    var _ETnd = "EndTime";
    var _ETv = "EventType";
    var _ETx = "ExportTask";
    var _ETxp = "ExportTasks";
    var _EU = "ExecutableUsers";
    var _EVAICC = "ExportVerifiedAccessInstanceClientConfiguration";
    var _EVAICCR = "ExportVerifiedAccessInstanceClientConfigurationRequest";
    var _EVAICCRx = "ExportVerifiedAccessInstanceClientConfigurationResult";
    var _EVCL = "EnableVpcClassicLink";
    var _EVCLDS = "EnableVpcClassicLinkDnsSupport";
    var _EVCLDSR = "EnableVpcClassicLinkDnsSupportRequest";
    var _EVCLDSRn = "EnableVpcClassicLinkDnsSupportResult";
    var _EVCLR = "EnableVpcClassicLinkRequest";
    var _EVCLRn = "EnableVpcClassicLinkResult";
    var _EVIO = "EnableVolumeIO";
    var _EVIOR = "EnableVolumeIORequest";
    var _EVRP = "EnableVgwRoutePropagation";
    var _EVRPR = "EnableVgwRoutePropagationRequest";
    var _EWD = "EndWeekDay";
    var _Eb = "Ebs";
    var _En = "Enabled";
    var _Enc = "Encrypted";
    var _End = "End";
    var _Endp = "Endpoint";
    var _Enf = "Enforced";
    var _Ent = "Entries";
    var _Entr = "Entry";
    var _Er = "Error";
    var _Err = "Errors";
    var _Ev = "Events";
    var _Eve = "Event";
    var _Ex = "Explanation";
    var _Exp = "Explanations";
    var _F = "Force";
    var _FA = "FederatedAuthentication";
    var _FAD = "FilterAtDestination";
    var _FAR = "FederatedAuthenticationRequest";
    var _FAS = "FilterAtSource";
    var _FAi = "FirstAddress";
    var _FB = "FilterBy";
    var _FBDMR = "FleetBlockDeviceMappingRequest";
    var _FBDMRL = "FleetBlockDeviceMappingRequestList";
    var _FC = "FindingComponents";
    var _FCR = "FleetCapacityReservations";
    var _FCRFCR = "FailedCapacityReservationFleetCancellationResult";
    var _FCRFCRS = "FailedCapacityReservationFleetCancellationResultSet";
    var _FCRS = "FleetCapacityReservationSet";
    var _FCRl = "FleetCapacityReservation";
    var _FCa = "FailureCode";
    var _FCu = "FulfilledCapacity";
    var _FD = "ForceDelete";
    var _FDI = "FpgaDeviceInfo";
    var _FDIL = "FpgaDeviceInfoList";
    var _FDMI = "FpgaDeviceMemoryInfo";
    var _FDN = "FipsDnsName";
    var _FDl = "FleetData";
    var _FE = "FipsEnabled";
    var _FEBDR = "FleetEbsBlockDeviceRequest";
    var _FEQS = "FlexibleEnaQueuesSupport";
    var _FF = "FileFormat";
    var _FFC = "FailedFleetCancellations";
    var _FFi = "FindingsFound";
    var _FI = "FindingId";
    var _FIA = "FpgaImageAttribute";
    var _FIAi = "FilterInArns";
    var _FIAil = "FilterInArn";
    var _FIGI = "FpgaImageGlobalId";
    var _FII = "FpgaImageId";
    var _FIIL = "FpgaImageIdList";
    var _FIIp = "FpgaImageIds";
    var _FIL = "FpgaImageList";
    var _FIPSE = "FIPSEnabled";
    var _FIS = "FpgaImageState";
    var _FIl = "FleetId";
    var _FIle = "FleetIds";
    var _FIp = "FpgaImages";
    var _FIpg = "FpgaImage";
    var _FIpga = "FpgaInfo";
    var _FL = "FlowLogs";
    var _FLI = "FlowLogIds";
    var _FLIIL = "FastLaunchImageIdList";
    var _FLIL = "FlowLogIdList";
    var _FLIa = "FastLaunchImages";
    var _FLIl = "FlowLogId";
    var _FLLTSR = "FastLaunchLaunchTemplateSpecificationRequest";
    var _FLLTSRa = "FastLaunchLaunchTemplateSpecificationResponse";
    var _FLRI = "FlowLogResourceIds";
    var _FLS = "FlowLogStatus";
    var _FLSCR = "FastLaunchSnapshotConfigurationRequest";
    var _FLSCRa = "FastLaunchSnapshotConfigurationResponse";
    var _FLSl = "FlowLogSet";
    var _FLTC = "FleetLaunchTemplateConfig";
    var _FLTCL = "FleetLaunchTemplateConfigList";
    var _FLTCLR = "FleetLaunchTemplateConfigListRequest";
    var _FLTCR = "FleetLaunchTemplateConfigRequest";
    var _FLTO = "FleetLaunchTemplateOverrides";
    var _FLTOL = "FleetLaunchTemplateOverridesList";
    var _FLTOLR = "FleetLaunchTemplateOverridesListRequest";
    var _FLTOR = "FleetLaunchTemplateOverridesRequest";
    var _FLTS = "FleetLaunchTemplateSpecification";
    var _FLTSR = "FleetLaunchTemplateSpecificationRequest";
    var _FLi = "FilterList";
    var _FLl = "FlowLog";
    var _FM = "FailureMessage";
    var _FOA = "FilterOutArns";
    var _FOAi = "FilterOutArn";
    var _FODC = "FulfilledOnDemandCapacity";
    var _FP = "FromPort";
    var _FPC = "ForwardPathComponents";
    var _FPR = "FilterPortRange";
    var _FPi = "FilesystemProtections";
    var _FPix = "FixedPrice";
    var _FQPD = "FailedQueuedPurchaseDeletions";
    var _FQPDS = "FailedQueuedPurchaseDeletionSet";
    var _FQPDa = "FailedQueuedPurchaseDeletion";
    var _FR = "FailureReason";
    var _FRa = "FastRestored";
    var _FS = "FleetState";
    var _FSCR = "FleetSpotCapacityRebalance";
    var _FSCRR = "FleetSpotCapacityRebalanceRequest";
    var _FSMS = "FleetSpotMaintenanceStrategies";
    var _FSMSR = "FleetSpotMaintenanceStrategiesRequest";
    var _FSR = "FastSnapshotRestores";
    var _FSRSE = "FastSnapshotRestoreStateErrors";
    var _FSRi = "FirewallStatelessRule";
    var _FSRir = "FirewallStatefulRule";
    var _FSSIB = "FullSnapshotSizeInBytes";
    var _FSST = "FirstSlotStartTime";
    var _FSSTR = "FirstSlotStartTimeRange";
    var _FSl = "FleetSet";
    var _FTE = "FreeTierEligible";
    var _Fa = "Fault";
    var _Fi = "Filters";
    var _Fil = "Filter";
    var _Fl = "Fleets";
    var _Fo = "Format";
    var _Fp = "Fpgas";
    var _Fr = "From";
    var _Fre = "Frequency";
    var _G = "Groups";
    var _GA = "GroupArn";
    var _GAECIR = "GetAssociatedEnclaveCertificateIamRoles";
    var _GAECIRR = "GetAssociatedEnclaveCertificateIamRolesRequest";
    var _GAECIRRe = "GetAssociatedEnclaveCertificateIamRolesResult";
    var _GAIPC = "GetAssociatedIpv6PoolCidrs";
    var _GAIPCR = "GetAssociatedIpv6PoolCidrsRequest";
    var _GAIPCRe = "GetAssociatedIpv6PoolCidrsResult";
    var _GAIS = "GetAllowedImagesSettings";
    var _GAISR = "GetAllowedImagesSettingsRequest";
    var _GAISRe = "GetAllowedImagesSettingsResult";
    var _GANPD = "GetAwsNetworkPerformanceData";
    var _GANPDR = "GetAwsNetworkPerformanceDataRequest";
    var _GANPDRe = "GetAwsNetworkPerformanceDataResult";
    var _GAS = "GatewayAssociationState";
    var _GAVTS = "GetActiveVpnTunnelStatus";
    var _GAVTSR = "GetActiveVpnTunnelStatusRequest";
    var _GAVTSRe = "GetActiveVpnTunnelStatusResult";
    var _GB = "GroupBy";
    var _GBS = "GroupBySet";
    var _GCMA = "GetCapacityManagerAttributes";
    var _GCMAR = "GetCapacityManagerAttributesRequest";
    var _GCMARe = "GetCapacityManagerAttributesResult";
    var _GCMMD = "GetCapacityManagerMetricData";
    var _GCMMDR = "GetCapacityManagerMetricDataRequest";
    var _GCMMDRe = "GetCapacityManagerMetricDataResult";
    var _GCMMDRet = "GetCapacityManagerMetricDimensionsRequest";
    var _GCMMDReta = "GetCapacityManagerMetricDimensionsResult";
    var _GCMMDe = "GetCapacityManagerMetricDimensions";
    var _GCMMTK = "GetCapacityManagerMonitoredTagKeys";
    var _GCMMTKR = "GetCapacityManagerMonitoredTagKeysRequest";
    var _GCMMTKRe = "GetCapacityManagerMonitoredTagKeysResult";
    var _GCO = "GetConsoleOutput";
    var _GCOR = "GetConsoleOutputRequest";
    var _GCORe = "GetConsoleOutputResult";
    var _GCPU = "GetCoipPoolUsage";
    var _GCPUR = "GetCoipPoolUsageRequest";
    var _GCPURe = "GetCoipPoolUsageResult";
    var _GCRU = "GetCapacityReservationUsage";
    var _GCRUR = "GetCapacityReservationUsageRequest";
    var _GCRURe = "GetCapacityReservationUsageResult";
    var _GCS = "GetConsoleScreenshot";
    var _GCSR = "GetConsoleScreenshotRequest";
    var _GCSRe = "GetConsoleScreenshotResult";
    var _GD = "GroupDescription";
    var _GDCS = "GetDefaultCreditSpecification";
    var _GDCSR = "GetDefaultCreditSpecificationRequest";
    var _GDCSRe = "GetDefaultCreditSpecificationResult";
    var _GDI = "GpuDeviceInfo";
    var _GDIL = "GpuDeviceInfoList";
    var _GDMI = "GpuDeviceMemoryInfo";
    var _GDPRS = "GetDeclarativePoliciesReportSummary";
    var _GDPRSR = "GetDeclarativePoliciesReportSummaryRequest";
    var _GDPRSRe = "GetDeclarativePoliciesReportSummaryResult";
    var _GEDKKI = "GetEbsDefaultKmsKeyId";
    var _GEDKKIR = "GetEbsDefaultKmsKeyIdRequest";
    var _GEDKKIRe = "GetEbsDefaultKmsKeyIdResult";
    var _GEEBD = "GetEbsEncryptionByDefault";
    var _GEEBDR = "GetEbsEncryptionByDefaultRequest";
    var _GEEBDRe = "GetEbsEncryptionByDefaultResult";
    var _GEIP = "GetEnabledIpamPolicy";
    var _GEIPR = "GetEnabledIpamPolicyRequest";
    var _GEIPRe = "GetEnabledIpamPolicyResult";
    var _GFLIT = "GetFlowLogsIntegrationTemplate";
    var _GFLITR = "GetFlowLogsIntegrationTemplateRequest";
    var _GFLITRe = "GetFlowLogsIntegrationTemplateResult";
    var _GGFCR = "GetGroupsForCapacityReservation";
    var _GGFCRR = "GetGroupsForCapacityReservationRequest";
    var _GGFCRRe = "GetGroupsForCapacityReservationResult";
    var _GHRPP = "GetHostReservationPurchasePreview";
    var _GHRPPR = "GetHostReservationPurchasePreviewRequest";
    var _GHRPPRe = "GetHostReservationPurchasePreviewResult";
    var _GI2 = "GatewayId";
    var _GIA = "GroupIpAddress";
    var _GIAH = "GetIpamAddressHistory";
    var _GIAHR = "GetIpamAddressHistoryRequest";
    var _GIAHRe = "GetIpamAddressHistoryResult";
    var _GIAR = "GetImageAncestryRequest";
    var _GIARe = "GetImageAncestryResult";
    var _GIAe = "GetImageAncestry";
    var _GIBPAS = "GetImageBlockPublicAccessState";
    var _GIBPASR = "GetImageBlockPublicAccessStateRequest";
    var _GIBPASRe = "GetImageBlockPublicAccessStateResult";
    var _GIDA = "GetIpamDiscoveredAccounts";
    var _GIDAR = "GetIpamDiscoveredAccountsRequest";
    var _GIDARe = "GetIpamDiscoveredAccountsResult";
    var _GIDPA = "GetIpamDiscoveredPublicAddresses";
    var _GIDPAR = "GetIpamDiscoveredPublicAddressesRequest";
    var _GIDPARe = "GetIpamDiscoveredPublicAddressesResult";
    var _GIDRC = "GetIpamDiscoveredResourceCidrs";
    var _GIDRCR = "GetIpamDiscoveredResourceCidrsRequest";
    var _GIDRCRe = "GetIpamDiscoveredResourceCidrsResult";
    var _GIL = "GroupIdentifierList";
    var _GIMD = "GetInstanceMetadataDefaults";
    var _GIMDR = "GetInstanceMetadataDefaultsRequest";
    var _GIMDRe = "GetInstanceMetadataDefaultsResult";
    var _GIPA = "GetIpamPoolAllocations";
    var _GIPAR = "GetIpamPoolAllocationsRequest";
    var _GIPARR = "GetIpamPolicyAllocationRulesRequest";
    var _GIPARRe = "GetIpamPolicyAllocationRulesResult";
    var _GIPARe = "GetIpamPoolAllocationsResult";
    var _GIPARet = "GetIpamPolicyAllocationRules";
    var _GIPC = "GetIpamPoolCidrs";
    var _GIPCR = "GetIpamPoolCidrsRequest";
    var _GIPCRe = "GetIpamPoolCidrsResult";
    var _GIPLRR = "GetIpamPrefixListResolverRules";
    var _GIPLRRR = "GetIpamPrefixListResolverRulesRequest";
    var _GIPLRRRe = "GetIpamPrefixListResolverRulesResult";
    var _GIPLRV = "GetIpamPrefixListResolverVersions";
    var _GIPLRVE = "GetIpamPrefixListResolverVersionEntries";
    var _GIPLRVER = "GetIpamPrefixListResolverVersionEntriesRequest";
    var _GIPLRVERe = "GetIpamPrefixListResolverVersionEntriesResult";
    var _GIPLRVR = "GetIpamPrefixListResolverVersionsRequest";
    var _GIPLRVRe = "GetIpamPrefixListResolverVersionsResult";
    var _GIPOT = "GetIpamPolicyOrganizationTargets";
    var _GIPOTR = "GetIpamPolicyOrganizationTargetsRequest";
    var _GIPOTRe = "GetIpamPolicyOrganizationTargetsResult";
    var _GIRC = "GetIpamResourceCidrs";
    var _GIRCR = "GetIpamResourceCidrsRequest";
    var _GIRCRe = "GetIpamResourceCidrsResult";
    var _GIS = "GroupIdentifierSet";
    var _GISL = "GroupIdStringList";
    var _GITEP = "GetInstanceTpmEkPub";
    var _GITEPR = "GetInstanceTpmEkPubRequest";
    var _GITEPRe = "GetInstanceTpmEkPubResult";
    var _GITFIR = "GetInstanceTypesFromInstanceRequirements";
    var _GITFIRR = "GetInstanceTypesFromInstanceRequirementsRequest";
    var _GITFIRRe = "GetInstanceTypesFromInstanceRequirementsResult";
    var _GIUD = "GetInstanceUefiData";
    var _GIUDR = "GetInstanceUefiDataRequest";
    var _GIUDRe = "GetInstanceUefiDataResult";
    var _GIp = "GpuInfo";
    var _GIr = "GroupId";
    var _GIro = "GroupIds";
    var _GIrou = "GroupIdentifier";
    var _GK = "GreKey";
    var _GLBA = "GatewayLoadBalancerArns";
    var _GLBAa = "GatewayLoadBalancerArn";
    var _GLBEI = "GatewayLoadBalancerEndpointId";
    var _GLN = "GroupLongName";
    var _GLTD = "GetLaunchTemplateData";
    var _GLTDR = "GetLaunchTemplateDataRequest";
    var _GLTDRe = "GetLaunchTemplateDataResult";
    var _GM = "GroupMember";
    var _GMPLA = "GetManagedPrefixListAssociations";
    var _GMPLAR = "GetManagedPrefixListAssociationsRequest";
    var _GMPLARe = "GetManagedPrefixListAssociationsResult";
    var _GMPLE = "GetManagedPrefixListEntries";
    var _GMPLER = "GetManagedPrefixListEntriesRequest";
    var _GMPLERe = "GetManagedPrefixListEntriesResult";
    var _GMRV = "GetManagedResourceVisibility";
    var _GMRVR = "GetManagedResourceVisibilityRequest";
    var _GMRVRe = "GetManagedResourceVisibilityResult";
    var _GN = "GroupName";
    var _GNIASAF = "GetNetworkInsightsAccessScopeAnalysisFindings";
    var _GNIASAFR = "GetNetworkInsightsAccessScopeAnalysisFindingsRequest";
    var _GNIASAFRe = "GetNetworkInsightsAccessScopeAnalysisFindingsResult";
    var _GNIASC = "GetNetworkInsightsAccessScopeContent";
    var _GNIASCR = "GetNetworkInsightsAccessScopeContentRequest";
    var _GNIASCRe = "GetNetworkInsightsAccessScopeContentResult";
    var _GNSL = "GroupNameStringList";
    var _GNr = "GroupNames";
    var _GOI = "GroupOwnerId";
    var _GPD = "GetPasswordData";
    var _GPDR = "GetPasswordDataRequest";
    var _GPDRe = "GetPasswordDataResult";
    var _GPS = "GpuPartitionSize";
    var _GRIEQ = "GetReservedInstancesExchangeQuote";
    var _GRIEQR = "GetReservedInstancesExchangeQuoteRequest";
    var _GRIEQRe = "GetReservedInstancesExchangeQuoteResult";
    var _GRSA = "GetRouteServerAssociations";
    var _GRSAR = "GetRouteServerAssociationsRequest";
    var _GRSARe = "GetRouteServerAssociationsResult";
    var _GRSP = "GetRouteServerPropagations";
    var _GRSPR = "GetRouteServerPropagationsRequest";
    var _GRSPRe = "GetRouteServerPropagationsResult";
    var _GRSRD = "GetRouteServerRoutingDatabase";
    var _GRSRDR = "GetRouteServerRoutingDatabaseRequest";
    var _GRSRDRe = "GetRouteServerRoutingDatabaseResult";
    var _GS = "GroupSource";
    var _GSBPAS = "GetSnapshotBlockPublicAccessState";
    var _GSBPASR = "GetSnapshotBlockPublicAccessStateRequest";
    var _GSBPASRe = "GetSnapshotBlockPublicAccessStateResult";
    var _GSCAS = "GetSerialConsoleAccessStatus";
    var _GSCASR = "GetSerialConsoleAccessStatusRequest";
    var _GSCASRe = "GetSerialConsoleAccessStatusResult";
    var _GSCR = "GetSubnetCidrReservations";
    var _GSCRR = "GetSubnetCidrReservationsRequest";
    var _GSCRRe = "GetSubnetCidrReservationsResult";
    var _GSGFV = "GetSecurityGroupsForVpc";
    var _GSGFVR = "GetSecurityGroupsForVpcRequest";
    var _GSGFVRe = "GetSecurityGroupsForVpcResult";
    var _GSPS = "GetSpotPlacementScores";
    var _GSPSR = "GetSpotPlacementScoresRequest";
    var _GSPSRe = "GetSpotPlacementScoresResult";
    var _GTGAP = "GetTransitGatewayAttachmentPropagations";
    var _GTGAPR = "GetTransitGatewayAttachmentPropagationsRequest";
    var _GTGAPRe = "GetTransitGatewayAttachmentPropagationsResult";
    var _GTGMDA = "GetTransitGatewayMulticastDomainAssociations";
    var _GTGMDAR = "GetTransitGatewayMulticastDomainAssociationsRequest";
    var _GTGMDARe = "GetTransitGatewayMulticastDomainAssociationsResult";
    var _GTGMPE = "GetTransitGatewayMeteringPolicyEntries";
    var _GTGMPER = "GetTransitGatewayMeteringPolicyEntriesRequest";
    var _GTGMPERe = "GetTransitGatewayMeteringPolicyEntriesResult";
    var _GTGPLR = "GetTransitGatewayPrefixListReferences";
    var _GTGPLRR = "GetTransitGatewayPrefixListReferencesRequest";
    var _GTGPLRRe = "GetTransitGatewayPrefixListReferencesResult";
    var _GTGPTA = "GetTransitGatewayPolicyTableAssociations";
    var _GTGPTAR = "GetTransitGatewayPolicyTableAssociationsRequest";
    var _GTGPTARe = "GetTransitGatewayPolicyTableAssociationsResult";
    var _GTGPTE = "GetTransitGatewayPolicyTableEntries";
    var _GTGPTER = "GetTransitGatewayPolicyTableEntriesRequest";
    var _GTGPTERe = "GetTransitGatewayPolicyTableEntriesResult";
    var _GTGRTA = "GetTransitGatewayRouteTableAssociations";
    var _GTGRTAR = "GetTransitGatewayRouteTableAssociationsRequest";
    var _GTGRTARe = "GetTransitGatewayRouteTableAssociationsResult";
    var _GTGRTP = "GetTransitGatewayRouteTablePropagations";
    var _GTGRTPR = "GetTransitGatewayRouteTablePropagationsRequest";
    var _GTGRTPRe = "GetTransitGatewayRouteTablePropagationsResult";
    var _GVAEP = "GetVerifiedAccessEndpointPolicy";
    var _GVAEPR = "GetVerifiedAccessEndpointPolicyRequest";
    var _GVAEPRe = "GetVerifiedAccessEndpointPolicyResult";
    var _GVAET = "GetVerifiedAccessEndpointTargets";
    var _GVAETR = "GetVerifiedAccessEndpointTargetsRequest";
    var _GVAETRe = "GetVerifiedAccessEndpointTargetsResult";
    var _GVAGP = "GetVerifiedAccessGroupPolicy";
    var _GVAGPR = "GetVerifiedAccessGroupPolicyRequest";
    var _GVAGPRe = "GetVerifiedAccessGroupPolicyResult";
    var _GVCDSC = "GetVpnConnectionDeviceSampleConfiguration";
    var _GVCDSCR = "GetVpnConnectionDeviceSampleConfigurationRequest";
    var _GVCDSCRe = "GetVpnConnectionDeviceSampleConfigurationResult";
    var _GVCDT = "GetVpnConnectionDeviceTypes";
    var _GVCDTR = "GetVpnConnectionDeviceTypesRequest";
    var _GVCDTRe = "GetVpnConnectionDeviceTypesResult";
    var _GVRBEE = "GetVpcResourcesBlockingEncryptionEnforcement";
    var _GVRBEER = "GetVpcResourcesBlockingEncryptionEnforcementRequest";
    var _GVRBEERe = "GetVpcResourcesBlockingEncryptionEnforcementResult";
    var _GVTRS = "GetVpnTunnelReplacementStatus";
    var _GVTRSR = "GetVpnTunnelReplacementStatusRequest";
    var _GVTRSRe = "GetVpnTunnelReplacementStatusResult";
    var _Ge = "Geography";
    var _Gp = "Gpus";
    var _Gr = "Group";
    var _H = "Hosts";
    var _HBD = "HiddenByDefault";
    var _HCP = "HiveCompatiblePartitions";
    var _HE = "HttpEndpoint";
    var _HI = "HostIds";
    var _HIL = "HostInstanceList";
    var _HIS = "HostIdSet";
    var _HIo = "HostId";
    var _HIos = "HostInstance";
    var _HL = "HostList";
    var _HM = "HostMaintenance";
    var _HO = "HibernationOptions";
    var _HOR = "HibernationOptionsRequest";
    var _HOS = "HostOfferingSet";
    var _HOo = "HostOffering";
    var _HP = "HostProperties";
    var _HPI = "HttpProtocolIpv6";
    var _HPRHL = "HttpPutResponseHopLimit";
    var _HPo = "HourlyPrice";
    var _HR = "HostRecovery";
    var _HRE = "HistoryRecordEntry";
    var _HRGA = "HostResourceGroupArn";
    var _HRI = "HostReservationId";
    var _HRIS = "HostReservationIdSet";
    var _HRS = "HostReservationSet";
    var _HRSi = "HistoryRecordSet";
    var _HRi = "HistoryRecords";
    var _HRis = "HistoryRecord";
    var _HRo = "HostReservation";
    var _HS = "HibernationSupported";
    var _HSa = "HaStatus";
    var _HT = "HttpTokens";
    var _HTE = "HttpTokensEnforced";
    var _HTo = "HostnameType";
    var _HZI = "HostedZoneId";
    var _Hi = "Hibernate";
    var _Ho = "Host";
    var _Hy = "Hypervisor";
    var _I = "Id";
    var _IA = "Ipv6Addresses";
    var _IAA = "Ipv6AddressAttribute";
    var _IAC = "Ipv6AddressCount";
    var _IAE = "ImageAncestryEntries";
    var _IAEL = "ImageAncestryEntryList";
    var _IAESS = "InstanceAttachmentEnaSrdSpecification";
    var _IAESUS = "InstanceAttachmentEnaSrdUdpSpecification";
    var _IAEm = "ImageAncestryEntry";
    var _IAHR = "IpamAddressHistoryRecord";
    var _IAHRS = "IpamAddressHistoryRecordSet";
    var _IAI = "IncludeAllInstances";
    var _IAIn = "InferenceAcceleratorInfo";
    var _IAL = "IpAddressList";
    var _IALp = "Ipv6AddressList";
    var _IAPI = "Ipv4AddressesPerInterface";
    var _IAPIp = "Ipv6AddressesPerInterface";
    var _IAPSI = "Ipv4AddressesPerSecondaryInterface";
    var _IART = "IncludeAllResourceTypes";
    var _IAT = "IpAddressType";
    var _IATOI = "IncludeAllTagsOfInstance";
    var _IAm = "ImageAllowed";
    var _IAma = "ImageAttribute";
    var _IAn = "InterfaceAssociation";
    var _IAns = "InstanceAttribute";
    var _IAnt = "InterfaceAssociations";
    var _IAp = "IpAddress";
    var _IApa = "IpamArn";
    var _IApv = "Ipv6Address";
    var _IB = "IngressBytes";
    var _IBDM = "InstanceBlockDeviceMapping";
    var _IBDML = "InstanceBlockDeviceMappingList";
    var _IBDMS = "InstanceBlockDeviceMappingSpecification";
    var _IBDMSL = "InstanceBlockDeviceMappingSpecificationList";
    var _IBPAS = "ImageBlockPublicAccessState";
    var _IC = "InstanceCount";
    var _ICA = "InterruptibleCapacityAllocation";
    var _ICAC = "IpamCidrAuthorizationContext";
    var _ICAS = "Ipv6CidrAssociationSet";
    var _ICAp = "Ipv6CidrAssociations";
    var _ICApv = "Ipv6CidrAssociation";
    var _ICB = "Ipv6CidrBlock";
    var _ICBA = "Ipv6CidrBlockAssociation";
    var _ICBAS = "Ipv6CidrBlockAssociationSet";
    var _ICBAp = "Ipv4CidrBlockAssociations";
    var _ICBNBG = "Ipv6CidrBlockNetworkBorderGroup";
    var _ICBS = "Ipv6CidrBlockState";
    var _ICBSL = "InsideCidrBlocksStringList";
    var _ICBSp = "Ipv6CidrBlockSet";
    var _ICBn = "InsideCidrBlocks";
    var _ICBp = "Ipv4CidrBlock";
    var _ICE4 = "InstanceConnectEndpoint";
    var _ICEA = "InstanceConnectEndpointArn";
    var _ICEDN = "InstanceConnectEndpointDnsNames";
    var _ICEI = "InstanceConnectEndpointId";
    var _ICEIn = "InstanceConnectEndpointIds";
    var _ICEPDN = "InstanceConnectEndpointPublicDnsNames";
    var _ICES = "InstanceConnectEndpointSet";
    var _ICEn = "InstanceConnectEndpoints";
    var _ICL = "ImageCriterionList";
    var _ICLn = "InstanceCountList";
    var _ICR = "ImageCriterionRequest";
    var _ICRI = "InterruptibleCapacityReservationId";
    var _ICRL = "ImageCriterionRequestList";
    var _ICS = "InstanceCreditSpecifications";
    var _ICSL = "InstanceCreditSpecificationList";
    var _ICSLR = "InstanceCreditSpecificationListRequest";
    var _ICSR = "InstanceCreditSpecificationRequest";
    var _ICSn = "InstanceCreditSpecification";
    var _ICVCCRL = "ImportClientVpnClientCertificateRevocationList";
    var _ICVCCRLR = "ImportClientVpnClientCertificateRevocationListRequest";
    var _ICVCCRLRm = "ImportClientVpnClientCertificateRevocationListResult";
    var _ICm = "ImageCriteria";
    var _ICma = "ImageCriterion";
    var _ICn = "InstanceCapacity";
    var _ICns = "InstanceCounts";
    var _ICp = "Ipv6Cidr";
    var _ID = "IncludeDeprecated";
    var _IDA = "IpamDiscoveredAccounts";
    var _IDAS = "IpamDiscoveredAccountSet";
    var _IDAp = "IpamDiscoveredAccount";
    var _IDC = "ImageDiskContainer";
    var _IDCL = "ImageDiskContainerList";
    var _IDFR = "IpamDiscoveryFailureReason";
    var _IDI = "InferenceDeviceInfo";
    var _IDIL = "InferenceDeviceInfoList";
    var _IDMI = "InferenceDeviceMemoryInfo";
    var _IDPA = "IpamDiscoveredPublicAddresses";
    var _IDPAS = "IpamDiscoveredPublicAddressSet";
    var _IDPAp = "IpamDiscoveredPublicAddress";
    var _IDRC = "IpamDiscoveredResourceCidrs";
    var _IDRCS = "IpamDiscoveredResourceCidrSet";
    var _IDRCp = "IpamDiscoveredResourceCidr";
    var _IDm = "ImageData";
    var _IDn = "IncludeDisabled";
    var _IDs = "IsDefault";
    var _IE = "IsEgress";
    var _IED = "InstanceExportDetails";
    var _IEI = "InstanceEventId";
    var _IERVT = "IpamExternalResourceVerificationToken";
    var _IERVTA = "IpamExternalResourceVerificationTokenArn";
    var _IERVTI = "IpamExternalResourceVerificationTokenId";
    var _IERVTIp = "IpamExternalResourceVerificationTokenIds";
    var _IERVTS = "IpamExternalResourceVerificationTokenSet";
    var _IERVTp = "IpamExternalResourceVerificationTokens";
    var _IEW = "InstanceEventWindow";
    var _IEWAR = "InstanceEventWindowAssociationRequest";
    var _IEWAT = "InstanceEventWindowAssociationTarget";
    var _IEWDR = "InstanceEventWindowDisassociationRequest";
    var _IEWI = "InstanceEventWindowId";
    var _IEWIS = "InstanceEventWindowIdSet";
    var _IEWIn = "InstanceEventWindowIds";
    var _IEWS = "InstanceEventWindowState";
    var _IEWSC = "InstanceEventWindowStateChange";
    var _IEWSn = "InstanceEventWindowSet";
    var _IEWTR = "InstanceEventWindowTimeRange";
    var _IEWTRL = "InstanceEventWindowTimeRangeList";
    var _IEWTRR = "InstanceEventWindowTimeRangeRequest";
    var _IEWTRRS = "InstanceEventWindowTimeRangeRequestSet";
    var _IEWn = "InstanceEventWindows";
    var _IEs = "IsExcludable";
    var _IF = "InstanceFamily";
    var _IFCS = "InstanceFamilyCreditSpecification";
    var _IFL = "IdFormatList";
    var _IFR = "IamFleetRole";
    var _IFRn = "IngressFilterRules";
    var _IFd = "IdFormat";
    var _IG = "InternetGateway";
    var _IGA = "InternetGatewayAttachment";
    var _IGAL = "InternetGatewayAttachmentList";
    var _IGBM = "InternetGatewayBlockMode";
    var _IGE4 = "InternetGatewayExclusion";
    var _IGEM = "InternetGatewayExclusionMode";
    var _IGI = "InternetGatewayId";
    var _IGIL = "InternetGatewayIdList";
    var _IGIn = "InternetGatewayIds";
    var _IGL = "InternetGatewayList";
    var _IGS = "InstanceGenerationSet";
    var _IGn = "InternetGateways";
    var _IGns = "InstanceGenerations";
    var _IGnst = "InstanceGeneration";
    var _IH = "InstanceHealth";
    var _IHn = "InboundHeader";
    var _II2 = "InstanceId";
    var _IIA = "InstanceIpv6Address";
    var _IIAL = "InstanceIpv6AddressList";
    var _IIALR = "InstanceIpv6AddressListRequest";
    var _IIAR = "InstanceIpv6AddressRequest";
    var _IIB = "InstanceInterruptionBehavior";
    var _IIL = "ImageIdList";
    var _IILCR = "ImportImageLicenseConfigurationRequest";
    var _IILCRm = "ImportImageLicenseConfigurationResponse";
    var _IILS = "ImportInstanceLaunchSpecification";
    var _IILSLR = "ImportImageLicenseSpecificationListRequest";
    var _IILSLRm = "ImportImageLicenseSpecificationListResponse";
    var _IILn = "InstanceIdList";
    var _IIM = "InstanceImageMetadata";
    var _IIML = "InstanceImageMetadataList";
    var _IIP = "IamInstanceProfile";
    var _IIPA = "IamInstanceProfileAssociation";
    var _IIPAS = "IamInstanceProfileAssociationSet";
    var _IIPAa = "IamInstanceProfileAssociations";
    var _IIPI = "Ipv6IpamPoolId";
    var _IIPIp = "Ipv4IpamPoolId";
    var _IIPL = "InstanceIpv4PrefixList";
    var _IIPLn = "InstanceIpv6PrefixList";
    var _IIPS = "IamInstanceProfileSpecification";
    var _IIPn = "InstanceIpv4Prefix";
    var _IIPns = "InstanceIpv6Prefix";
    var _IIR = "ImportImageRequest";
    var _IIRm = "ImportImageResult";
    var _IIRmp = "ImportInstanceRequest";
    var _IIRmpo = "ImportInstanceResult";
    var _IIS = "InstanceIdSet";
    var _IISB = "InstanceInitiatedShutdownBehavior";
    var _IISL = "ImageIdStringList";
    var _IISLn = "InstanceIdStringList";
    var _IISn = "InstanceIdsSet";
    var _IIT = "ImportImageTasks";
    var _IITD = "ImportInstanceTaskDetails";
    var _IITL = "ImportImageTaskList";
    var _IITm = "ImportImageTask";
    var _IIUSL = "InstanceIdUpdateStringList";
    var _IIVDI = "ImportInstanceVolumeDetailItem";
    var _IIVDS = "ImportInstanceVolumeDetailSet";
    var _IIm = "ImageId";
    var _IIma = "ImageIds";
    var _IImp = "ImportInstance";
    var _IImpo = "ImportImage";
    var _IIn = "InterruptionInfo";
    var _IIns = "InstanceIds";
    var _IIp = "IpamId";
    var _IIpa = "IpamIds";
    var _IKEV = "InternetKeyExchangeVersion";
    var _IKEVL = "IKEVersionsList";
    var _IKEVLV = "IKEVersionsListValue";
    var _IKEVRL = "IKEVersionsRequestList";
    var _IKEVRLV = "IKEVersionsRequestListValue";
    var _IKEVe = "IKEVersions";
    var _IKEVer = "IKEVersion";
    var _IKP = "ImportKeyPair";
    var _IKPR = "ImportKeyPairRequest";
    var _IKPRm = "ImportKeyPairResult";
    var _IL = "ImageLocation";
    var _ILm = "ImageList";
    var _ILn = "InstanceLifecycle";
    var _ILns = "InstanceList";
    var _ILp = "IpList";
    var _IM = "IncludeMarketplace";
    var _IMC = "InstanceMatchCriteria";
    var _IMDR = "InstanceMetadataDefaultsResponse";
    var _IML = "InstanceMonitoringList";
    var _IMO = "InstanceMaintenanceOptions";
    var _IMOR = "InstanceMaintenanceOptionsRequest";
    var _IMORn = "InstanceMarketOptionsRequest";
    var _IMORns = "InstanceMetadataOptionsRequest";
    var _IMORnst = "InstanceMetadataOptionsResponse";
    var _IMOn = "InstanceMetadataOptions";
    var _IMOns = "InstanceMarketOptions";
    var _IMR = "IncludeManagedResources";
    var _IMT = "InstanceMetadataTags";
    var _IMU = "ImportManifestUrl";
    var _IMm = "ImageMetadata";
    var _IMn = "InstanceMonitoring";
    var _IMns = "InstanceMonitorings";
    var _IN = "Ipv6Native";
    var _INI = "InstanceNetworkInterface";
    var _INIA = "InstanceNetworkInterfaceAssociation";
    var _INIAn = "InstanceNetworkInterfaceAttachment";
    var _INIL = "InstanceNetworkInterfaceList";
    var _INIS = "InstanceNetworkInterfaceSpecification";
    var _INISL = "InstanceNetworkInterfaceSpecificationList";
    var _INL = "Ipv6NetmaskLength";
    var _INLm = "ImageNameList";
    var _INLp = "Ipv4NetmaskLength";
    var _INPO = "InstanceNetworkPerformanceOptions";
    var _INPOR = "InstanceNetworkPerformanceOptionsRequest";
    var _INRL = "ImageNameRequestList";
    var _INm = "ImageNames";
    var _INma = "ImageName";
    var _IOA = "ImageOwnerAlias";
    var _IOI = "IpOwnerId";
    var _IOIn = "InstanceOwnerId";
    var _IOR = "IpamOperatingRegion";
    var _IORS = "IpamOperatingRegionSet";
    var _IOS = "InstanceOwningService";
    var _IOUE = "IpamOrganizationalUnitExclusion";
    var _IOUES = "IpamOrganizationalUnitExclusionSet";
    var _IP = "InstancePort";
    var _IPA = "IpamPoolAllocation";
    var _IPAAC = "IpamPoolAllocationAllowedCidrs";
    var _IPADC = "IpamPoolAllocationDisallowedCidrs";
    var _IPAI = "IpamPoolAllocationId";
    var _IPAR = "IpamPolicyAllocationRule";
    var _IPARL = "IpamPolicyAllocationRuleList";
    var _IPARLR = "IpamPolicyAllocationRuleListRequest";
    var _IPARR = "IpamPolicyAllocationRuleRequest";
    var _IPAS = "IpamPoolAllocationSet";
    var _IPASG = "IpamPublicAddressSecurityGroup";
    var _IPASGL = "IpamPublicAddressSecurityGroupList";
    var _IPAT = "IpamPublicAddressTag";
    var _IPATL = "IpamPublicAddressTagList";
    var _IPATp = "IpamPublicAddressTags";
    var _IPAp = "IpamPoolAllocations";
    var _IPApa = "IpamPolicyArn";
    var _IPApam = "IpamPoolArn";
    var _IPC = "Ipv6PrefixCount";
    var _IPCFR = "IpamPoolCidrFailureReason";
    var _IPCI = "IpamPoolCidrId";
    var _IPCS = "IpamPoolCidrSet";
    var _IPCp = "Ipv4PrefixCount";
    var _IPCpa = "IpamPoolCidr";
    var _IPCpam = "IpamPoolCidrs";
    var _IPD = "IpamPolicyDocuments";
    var _IPDS = "IpamPolicyDocumentSet";
    var _IPDp = "IpamPolicyDocument";
    var _IPE2 = "IpamPolicyEnabled";
    var _IPEp = "IpPermissionsEgress";
    var _IPI2 = "IpamPoolId";
    var _IPIA = "InstancePrivateIpAddress";
    var _IPIAL = "InstancePrivateIpAddressList";
    var _IPIL = "Ipv6PoolIdList";
    var _IPIp = "IpamPolicyId";
    var _IPIpa = "IpamPolicyIds";
    var _IPIpam = "IpamPoolIds";
    var _IPIs = "IsPrimaryIpv6";
    var _IPK = "IncludePublicKey";
    var _IPL = "ImageProviderList";
    var _IPLR = "IpamPrefixListResolver";
    var _IPLRA = "IpamPrefixListResolverArn";
    var _IPLRI = "IpamPrefixListResolverId";
    var _IPLRIp = "IpamPrefixListResolverIds";
    var _IPLRR = "IpamPrefixListResolverRule";
    var _IPLRRC = "IpamPrefixListResolverRuleCondition";
    var _IPLRRCR = "IpamPrefixListResolverRuleConditionRequest";
    var _IPLRRCRS = "IpamPrefixListResolverRuleConditionRequestSet";
    var _IPLRRCS = "IpamPrefixListResolverRuleConditionSet";
    var _IPLRRR = "IpamPrefixListResolverRuleRequest";
    var _IPLRRRS = "IpamPrefixListResolverRuleRequestSet";
    var _IPLRRS = "IpamPrefixListResolverRuleSet";
    var _IPLRS = "IpamPrefixListResolverSet";
    var _IPLRSE = "IpamPrefixListResolverSyncEnabled";
    var _IPLRT = "IpamPrefixListResolverTarget";
    var _IPLRTA = "IpamPrefixListResolverTargetArn";
    var _IPLRTI = "IpamPrefixListResolverTargetId";
    var _IPLRTIp = "IpamPrefixListResolverTargetIds";
    var _IPLRTS = "IpamPrefixListResolverTargetSet";
    var _IPLRTp = "IpamPrefixListResolverTargets";
    var _IPLRV = "IpamPrefixListResolverVersion";
    var _IPLRVE = "IpamPrefixListResolverVersionEntry";
    var _IPLRVES = "IpamPrefixListResolverVersionEntrySet";
    var _IPLRVNS = "IpamPrefixListResolverVersionNumberSet";
    var _IPLRVS = "IpamPrefixListResolverVersionSet";
    var _IPLRVp = "IpamPrefixListResolverVersions";
    var _IPLRp = "IpamPrefixListResolvers";
    var _IPLRpv = "Ipv4PrefixListResponse";
    var _IPLRpvr = "Ipv6PrefixListResponse";
    var _IPLp = "IpPermissionList";
    var _IPLpr = "IpPrefixList";
    var _IPLpv = "Ipv4PrefixesList";
    var _IPLpvr = "Ipv4PrefixList";
    var _IPLpvre = "Ipv6PrefixesList";
    var _IPLpvref = "Ipv6PrefixList";
    var _IPO = "IpamPoolOwner";
    var _IPOT = "IpamPolicyOrganizationTarget";
    var _IPOTS = "IpamPolicyOrganizationTargetSet";
    var _IPR = "IpamPolicyRegion";
    var _IPRL = "ImageProviderRequestList";
    var _IPRs = "IsPermanentRestore";
    var _IPS = "Ipv4PrefixSpecification";
    var _IPSR = "IpamPoolSourceResource";
    var _IPSRR = "IpamPoolSourceResourceRequest";
    var _IPSRp = "Ipv4PrefixSpecificationRequest";
    var _IPSRpv = "Ipv4PrefixSpecificationResponse";
    var _IPSRpvr = "Ipv6PrefixSpecificationRequest";
    var _IPSRpvre = "Ipv6PrefixSpecificationResponse";
    var _IPSp = "Ipv6PrefixSpecification";
    var _IPSpa = "IpamPolicySet";
    var _IPSpam = "IpamPoolSet";
    var _IPSpv = "Ipv6PoolSet";
    var _IPTUC = "InstancePoolsToUseCount";
    var _IPm = "ImageProviders";
    var _IPma = "ImageProvider";
    var _IPn = "InstancePlatform";
    var _IPng = "IngressPackets";
    var _IPnt = "InterfacePermission";
    var _IPnte = "InterfaceProtocol";
    var _IPo = "IoPerformance";
    var _IPp = "Ipv6Prefixes";
    var _IPpa = "IpamPolicy";
    var _IPpam = "IpamPool";
    var _IPpamo = "IpamPolicies";
    var _IPpamoo = "IpamPools";
    var _IPpe = "IpPermissions";
    var _IPper = "IpPermission";
    var _IPpr = "IpProtocol";
    var _IPpre = "IpPrefixes";
    var _IPpv = "Ipv6Prefix";
    var _IPpvo = "Ipv6Pool";
    var _IPpvoo = "Ipv6Pools";
    var _IPpvr = "Ipv4Prefixes";
    var _IPpvre = "Ipv4Prefix";
    var _IPs = "IsPublic";
    var _IPsr = "IsPrimary";
    var _IR = "ImageReferences";
    var _IRBI = "ImageRecycleBinInfo";
    var _IRBIL = "ImageRecycleBinInfoList";
    var _IRC = "IpamResourceCidrs";
    var _IRCS = "IpamResourceCidrSet";
    var _IRCp = "IpamResourceCidr";
    var _IRD = "IpamResourceDiscovery";
    var _IRDA = "IpamResourceDiscoveryAssociation";
    var _IRDAA = "IpamResourceDiscoveryAssociationArn";
    var _IRDAI = "IpamResourceDiscoveryAssociationIds";
    var _IRDAIp = "IpamResourceDiscoveryAssociationId";
    var _IRDAS = "IpamResourceDiscoveryAssociationSet";
    var _IRDAp = "IpamResourceDiscoveryAssociations";
    var _IRDApa = "IpamResourceDiscoveryArn";
    var _IRDI = "IpamResourceDiscoveryId";
    var _IRDIp = "IpamResourceDiscoveryIds";
    var _IRDR = "IpamResourceDiscoveryRegion";
    var _IRDS = "IpamResourceDiscoverySet";
    var _IRDp = "IpamResourceDiscoveries";
    var _IRL = "ImageReferenceList";
    var _IRLp = "IpRangeList";
    var _IRLpv = "Ipv6RangeList";
    var _IRR = "InstanceRequirementsRequest";
    var _IRSDA = "IntegrationResultS3DestinationArn";
    var _IRT = "IngressRouteTable";
    var _IRTL = "IpamResourceTagList";
    var _IRTp = "IpamResourceTag";
    var _IRWM = "InstanceRequirementsWithMetadata";
    var _IRWMR = "InstanceRequirementsWithMetadataRequest";
    var _IRm = "ImageReference";
    var _IRn = "InstanceRequirements";
    var _IRp = "IpamRegion";
    var _IRpa = "IpRanges";
    var _IRpan = "IpRange";
    var _IRpv = "Ipv6Ranges";
    var _IRpva = "Ipv6Range";
    var _IS = "InterconnectStatus";
    var _ISA = "IpamScopeArn";
    var _ISC = "InstanceStateChange";
    var _ISCL = "InstanceStateChangeList";
    var _ISD = "InitializationStatusDetails";
    var _ISDL = "InstanceStatusDetailsList";
    var _ISDn = "InstanceStatusDetails";
    var _ISE13 = "InstanceStatusEvent";
    var _ISEAC = "IpamScopeExternalAuthorityConfiguration";
    var _ISEL = "InstanceStatusEventList";
    var _ISI = "IpamScopeId";
    var _ISIA = "InstanceSecondaryInterfaceAttachment";
    var _ISIL = "InstanceSecondaryInterfaceList";
    var _ISIPIA = "InstanceSecondaryInterfacePrivateIpAddress";
    var _ISIPIAL = "InstanceSecondaryInterfacePrivateIpAddressList";
    var _ISIPIALR = "InstanceSecondaryInterfacePrivateIpAddressListRequest";
    var _ISIPIAR = "InstanceSecondaryInterfacePrivateIpAddressRequest";
    var _ISIS = "InstanceSecondaryInterfaceSpecification";
    var _ISISLR = "InstanceSecondaryInterfaceSpecificationListRequest";
    var _ISISR = "InstanceSecondaryInterfaceSpecificationRequest";
    var _ISIn = "InstanceSecondaryInterface";
    var _ISIns = "InstanceStorageInfo";
    var _ISIp = "IpamScopeIds";
    var _ISL = "InputStorageLocation";
    var _ISLn = "InstanceStatusList";
    var _ISM = "IngestionStatusMessage";
    var _ISR = "ImportSnapshotRequest";
    var _ISRm = "ImportSnapshotResult";
    var _ISS = "InstanceStatusSummary";
    var _ISSn = "InstanceStorageSupported";
    var _ISSp = "IpamScopeSet";
    var _IST = "ImportSnapshotTasks";
    var _ISTIL = "ImportSnapshotTaskIdList";
    var _ISTL = "ImportSnapshotTaskList";
    var _ISTm = "ImportSnapshotTask";
    var _ISTp = "IpamScopeType";
    var _ISg = "Igmpv2Support";
    var _ISm = "ImpairedSince";
    var _ISmd = "ImdsSupport";
    var _ISmp = "ImportSnapshot";
    var _ISn = "InstanceSpecification";
    var _ISng = "IngestionStatus";
    var _ISns = "InstanceStatuses";
    var _ISnst = "InstanceState";
    var _ISnsta = "InstanceStatus";
    var _ISnstan = "InstanceSet";
    var _ISnt = "IntegrateServices";
    var _ISnte = "IntegrateService";
    var _ISp = "IpamScope";
    var _ISpa = "IpamScopes";
    var _ISpam = "IpamSet";
    var _ISpo = "IpSource";
    var _ISpv = "Ipv6Support";
    var _ISpvu = "Ipv6Supported";
    var _IT4 = "InstanceType";
    var _ITA = "InstanceTagAttribute";
    var _ITC = "IcmpTypeCode";
    var _ITCn = "IncludeTrustContext";
    var _ITI = "ImportTaskId";
    var _ITIFIR = "InstanceTypeInfoFromInstanceRequirements";
    var _ITIFIRS = "InstanceTypeInfoFromInstanceRequirementsSet";
    var _ITIL = "ImportTaskIdList";
    var _ITILn = "InstanceTypeInfoList";
    var _ITIm = "ImportTaskIds";
    var _ITIn = "InstanceTypeInfo";
    var _ITK = "InstanceTagKeys";
    var _ITKS = "InstanceTagKeySet";
    var _ITKn = "InstanceTagKey";
    var _ITL = "InstanceTypesList";
    var _ITNA = "InstanceTagNotificationAttribute";
    var _ITO = "InstanceTypeOfferings";
    var _ITOL = "InstanceTypeOfferingsList";
    var _ITOn = "InstanceTypeOffering";
    var _ITS = "InstanceTypeSpecifications";
    var _ITSn = "InstanceTypeSpecification";
    var _ITm = "ImageType";
    var _ITn = "InterruptionType";
    var _ITni = "InitializationType";
    var _ITns = "InstanceTenancy";
    var _ITnst = "InstanceTypes";
    var _ITnsta = "InstanceTags";
    var _ITnstan = "InstanceTag";
    var _ITnstanc = "InstanceTopology";
    var _ITnt = "InterfaceType";
    var _IU = "InstanceUsages";
    var _IUR = "ImageUsageReports";
    var _IURE = "ImageUsageReportEntries";
    var _IUREL = "ImageUsageReportEntryList";
    var _IUREm = "ImageUsageReportEntry";
    var _IURL = "ImageUsageReportList";
    var _IURT = "ImageUsageResourceType";
    var _IURTL = "ImageUsageResourceTypeList";
    var _IURTO = "ImageUsageResourceTypeOption";
    var _IURTOL = "ImageUsageResourceTypeOptionList";
    var _IURTOR = "ImageUsageResourceTypeOptionRequest";
    var _IURTORL = "ImageUsageResourceTypeOptionRequestList";
    var _IURTOVL = "ImageUsageResourceTypeOptionValuesList";
    var _IURTR = "ImageUsageResourceTypeRequest";
    var _IURTRL = "ImageUsageResourceTypeRequestList";
    var _IURUISL = "ImageUsageReportUserIdStringList";
    var _IURm = "ImageUsageReport";
    var _IUS = "InstanceUsageSet";
    var _IUn = "InstanceUsage";
    var _IUp = "IpUsage";
    var _IV = "IkeVersion";
    var _IVE = "IsValidExchange";
    var _IVR = "ImportVolumeRequest";
    var _IVRm = "ImportVolumeResult";
    var _IVTD = "ImportVolumeTaskDetails";
    var _IVk = "IkeVersions";
    var _IVm = "ImportVolume";
    var _Ic = "Icmp";
    var _Im = "Images";
    var _Ima = "Image";
    var _In = "Instance";
    var _Ins = "Instances";
    var _Int = "Interruptible";
    var _Inte = "Interval";
    var _Io = "Iops";
    var _Ip = "Ipam";
    var _Ipa = "Ipams";
    var _Ipv = "Ipv4";
    var _Ipv_ = "Ipv6";
    var _Is = "Issuer";
    var _K10 = "Key";
    var _KDF = "KinesisDataFirehose";
    var _KF = "KeyFormat";
    var _KFe = "KeyFingerprint";
    var _KI = "KernelId";
    var _KKA = "KmsKeyArn";
    var _KKI = "KmsKeyId";
    var _KM = "KeyMaterial";
    var _KN = "KeyName";
    var _KNSL = "KeyNameStringList";
    var _KNe = "KeyNames";
    var _KP = "KeyPairs";
    var _KPI = "KeyPairId";
    var _KPISL = "KeyPairIdStringList";
    var _KPIe = "KeyPairIds";
    var _KPIey = "KeyPairInfo";
    var _KPL = "KeyPairList";
    var _KPe = "KeyPair";
    var _KS = "KextSigning";
    var _KT = "KeyType";
    var _KV = "KeyValue";
    var _Ke = "Kernel";
    var _Key = "Keyword";
    var _L2 = "Lifecycle";
    var _LA = "LocalAddress";
    var _LADT = "LastAttemptedDiscoveryTime";
    var _LAZ = "LaunchedAvailabilityZone";
    var _LAZI = "LaunchedAvailabilityZoneId";
    var _LAa = "LastAddress";
    var _LB = "LoadBalancers";
    var _LBA = "LocalBgpAsn";
    var _LBAE = "LocalBgpAsnExtended";
    var _LBAo = "LoadBalancerArn";
    var _LBC = "LoadBalancersConfig";
    var _LBLP = "LoadBalancerListenerPort";
    var _LBO = "LoadBalancerOptions";
    var _LBP = "LoadBalancerPort";
    var _LBT = "LoadBalancerTarget";
    var _LBTG = "LoadBalancerTargetGroup";
    var _LBTGo = "LoadBalancerTargetGroups";
    var _LBTP = "LoadBalancerTargetPort";
    var _LC = "LoggingConfigurations";
    var _LCA = "LicenseConfigurationArn";
    var _LCO = "LockCreatedOn";
    var _LCR = "LicenseConfigurationRequest";
    var _LCi = "LicenseConfiguration";
    var _LCo = "LoggingConfiguration";
    var _LD = "LogDestination";
    var _LDS = "LatestDeliveryStatus";
    var _LDSLU = "LatestDeliveryS3LocationUri";
    var _LDSM = "LatestDeliveryStatusMessage";
    var _LDST = "LockDurationStartTime";
    var _LDT = "LatestDeliveryTime";
    var _LDTa = "LatestDatapointTimestamp";
    var _LDTo = "LogDestinationType";
    var _LDo = "LockDuration";
    var _LE = "LogEnabled";
    var _LEO = "LockExpiresOn";
    var _LET = "LastEvaluatedTime";
    var _LEa = "LastError";
    var _LEam = "LambdaExclusion";
    var _LF = "LogFormat";
    var _LFA = "LambdaFunctionArn";
    var _LG = "LocalGateways";
    var _LGA = "LogGroupArn";
    var _LGC = "LogicalGpuCount";
    var _LGI = "LocalGatewayId";
    var _LGIS = "LocalGatewayIdSet";
    var _LGIi = "LinkedGroupId";
    var _LGIo = "LocalGatewayIds";
    var _LGN = "LogGroupName";
    var _LGR = "LocalGatewayRoute";
    var _LGRL = "LocalGatewayRouteList";
    var _LGRT = "LocalGatewayRouteTable";
    var _LGRTA = "LocalGatewayRouteTableArn";
    var _LGRTI = "LocalGatewayRouteTableId";
    var _LGRTIS = "LocalGatewayRouteTableIdSet";
    var _LGRTIo = "LocalGatewayRouteTableIds";
    var _LGRTS = "LocalGatewayRouteTableSet";
    var _LGRTVA = "LocalGatewayRouteTableVpcAssociation";
    var _LGRTVAI = "LocalGatewayRouteTableVpcAssociationId";
    var _LGRTVAIS = "LocalGatewayRouteTableVpcAssociationIdSet";
    var _LGRTVAIo = "LocalGatewayRouteTableVpcAssociationIds";
    var _LGRTVAS = "LocalGatewayRouteTableVpcAssociationSet";
    var _LGRTVAo = "LocalGatewayRouteTableVpcAssociations";
    var _LGRTVIGA = "LocalGatewayRouteTableVirtualInterfaceGroupAssociation";
    var _LGRTVIGAI = "LocalGatewayRouteTableVirtualInterfaceGroupAssociationId";
    var _LGRTVIGAIS = "LocalGatewayRouteTableVirtualInterfaceGroupAssociationIdSet";
    var _LGRTVIGAIo = "LocalGatewayRouteTableVirtualInterfaceGroupAssociationIds";
    var _LGRTVIGAS = "LocalGatewayRouteTableVirtualInterfaceGroupAssociationSet";
    var _LGRTVIGAo = "LocalGatewayRouteTableVirtualInterfaceGroupAssociations";
    var _LGRTo = "LocalGatewayRouteTables";
    var _LGS = "LocalGatewaySet";
    var _LGVI = "LocalGatewayVirtualInterface";
    var _LGVIA = "LocalGatewayVirtualInterfaceArn";
    var _LGVIG = "LocalGatewayVirtualInterfaceGroup";
    var _LGVIGA = "LocalGatewayVirtualInterfaceGroupArn";
    var _LGVIGI = "LocalGatewayVirtualInterfaceGroupId";
    var _LGVIGIS = "LocalGatewayVirtualInterfaceGroupIdSet";
    var _LGVIGIo = "LocalGatewayVirtualInterfaceGroupIds";
    var _LGVIGS = "LocalGatewayVirtualInterfaceGroupSet";
    var _LGVIGo = "LocalGatewayVirtualInterfaceGroups";
    var _LGVII = "LocalGatewayVirtualInterfaceId";
    var _LGVIIS = "LocalGatewayVirtualInterfaceIdSet";
    var _LGVIIo = "LocalGatewayVirtualInterfaceIds";
    var _LGVIS = "LocalGatewayVirtualInterfaceSet";
    var _LGVIo = "LocalGatewayVirtualInterfaces";
    var _LGa = "LaunchGroup";
    var _LGo = "LocalGateway";
    var _LGog = "LogGroup";
    var _LIIRB = "ListImagesInRecycleBin";
    var _LIIRBR = "ListImagesInRecycleBinRequest";
    var _LIIRBRi = "ListImagesInRecycleBinResult";
    var _LINC = "LocalIpv4NetworkCidr";
    var _LINCo = "LocalIpv6NetworkCidr";
    var _LL = "LicenseList";
    var _LLT = "LastLaunchedTime";
    var _LM2 = "LockMode";
    var _LMA = "LastMaintenanceApplied";
    var _LO = "LogOptions";
    var _LOF = "LogOutputFormat";
    var _LP = "LoadPermissions";
    var _LPL = "LaunchPermissionList";
    var _LPLR = "LoadPermissionListRequest";
    var _LPLo = "LoadPermissionList";
    var _LPM = "LaunchPermissionModifications";
    var _LPMo = "LoadPermissionModifications";
    var _LPR = "LoadPermissionRequest";
    var _LPa = "LaunchPermissions";
    var _LPau = "LaunchPermission";
    var _LPi = "LimitPrice";
    var _LPo = "LoadPermission";
    var _LS = "LicenseSpecifications";
    var _LSC = "LastStatusChange";
    var _LSDT = "LastSuccessfulDiscoveryTime";
    var _LSI = "LockedSnapshotsInfo";
    var _LSIL = "LockedSnapshotsInfoList";
    var _LSIRB = "ListSnapshotsInRecycleBin";
    var _LSIRBR = "ListSnapshotsInRecycleBinRequest";
    var _LSIRBRi = "ListSnapshotsInRecycleBinResult";
    var _LSL = "LogsStorageLocation";
    var _LSLR = "LicenseSpecificationListRequest";
    var _LSLa = "LaunchSpecsList";
    var _LSR = "LockSnapshotRequest";
    var _LSRo = "LockSnapshotResult";
    var _LST = "LocalStorageTypes";
    var _LSTS = "LocalStorageTypeSet";
    var _LSTo = "LocalStorageType";
    var _LSV = "LastSyncedVersion";
    var _LSa = "LaunchSpecification";
    var _LSau = "LaunchSpecifications";
    var _LSi = "LicenseSpecification";
    var _LSo = "LocalStorage";
    var _LSoc = "LockState";
    var _LSock = "LockSnapshot";
    var _LT = "LaunchTemplate";
    var _LTAO = "LaunchTemplateAndOverrides";
    var _LTAOR = "LaunchTemplateAndOverridesResponse";
    var _LTBDM = "LaunchTemplateBlockDeviceMapping";
    var _LTBDML = "LaunchTemplateBlockDeviceMappingList";
    var _LTBDMR = "LaunchTemplateBlockDeviceMappingRequest";
    var _LTBDMRL = "LaunchTemplateBlockDeviceMappingRequestList";
    var _LTC = "LaunchTemplateConfigs";
    var _LTCL = "LaunchTemplateConfigList";
    var _LTCO = "LaunchTemplateCpuOptions";
    var _LTCOR = "LaunchTemplateCpuOptionsRequest";
    var _LTCRSR = "LaunchTemplateCapacityReservationSpecificationRequest";
    var _LTCRSRa = "LaunchTemplateCapacityReservationSpecificationResponse";
    var _LTCa = "LaunchTemplateConfig";
    var _LTD = "LaunchTemplateData";
    var _LTEBD = "LaunchTemplateEbsBlockDevice";
    var _LTEBDR = "LaunchTemplateEbsBlockDeviceRequest";
    var _LTEIA = "LaunchTemplateElasticInferenceAccelerator";
    var _LTEIAL = "LaunchTemplateElasticInferenceAcceleratorList";
    var _LTEIAR = "LaunchTemplateElasticInferenceAcceleratorResponse";
    var _LTEIARL = "LaunchTemplateElasticInferenceAcceleratorResponseList";
    var _LTEO = "LaunchTemplateEnclaveOptions";
    var _LTEOR = "LaunchTemplateEnclaveOptionsRequest";
    var _LTESS = "LaunchTemplateEnaSrdSpecification";
    var _LTESUS = "LaunchTemplateEnaSrdUdpSpecification";
    var _LTHO = "LaunchTemplateHibernationOptions";
    var _LTHOR = "LaunchTemplateHibernationOptionsRequest";
    var _LTI = "LaunchTemplateId";
    var _LTIIPS = "LaunchTemplateIamInstanceProfileSpecification";
    var _LTIIPSR = "LaunchTemplateIamInstanceProfileSpecificationRequest";
    var _LTIMO = "LaunchTemplateInstanceMaintenanceOptions";
    var _LTIMOR = "LaunchTemplateInstanceMaintenanceOptionsRequest";
    var _LTIMORa = "LaunchTemplateInstanceMarketOptionsRequest";
    var _LTIMORau = "LaunchTemplateInstanceMetadataOptionsRequest";
    var _LTIMOa = "LaunchTemplateInstanceMarketOptions";
    var _LTIMOau = "LaunchTemplateInstanceMetadataOptions";
    var _LTINIS = "LaunchTemplateInstanceNetworkInterfaceSpecification";
    var _LTINISL = "LaunchTemplateInstanceNetworkInterfaceSpecificationList";
    var _LTINISR = "LaunchTemplateInstanceNetworkInterfaceSpecificationRequest";
    var _LTINISRL = "LaunchTemplateInstanceNetworkInterfaceSpecificationRequestList";
    var _LTISIS = "LaunchTemplateInstanceSecondaryInterfaceSpecification";
    var _LTISISL = "LaunchTemplateInstanceSecondaryInterfaceSpecificationList";
    var _LTISISR = "LaunchTemplateInstanceSecondaryInterfaceSpecificationRequest";
    var _LTISISRL = "LaunchTemplateInstanceSecondaryInterfaceSpecificationRequestList";
    var _LTISL = "LaunchTemplateIdStringList";
    var _LTIa = "LaunchTemplateIds";
    var _LTLC = "LaunchTemplateLicenseConfiguration";
    var _LTLCR = "LaunchTemplateLicenseConfigurationRequest";
    var _LTLL = "LaunchTemplateLicenseList";
    var _LTLSLR = "LaunchTemplateLicenseSpecificationListRequest";
    var _LTM = "LaunchTemplatesMonitoring";
    var _LTMR = "LaunchTemplatesMonitoringRequest";
    var _LTN = "LaunchTemplateName";
    var _LTNPO = "LaunchTemplateNetworkPerformanceOptions";
    var _LTNPOR = "LaunchTemplateNetworkPerformanceOptionsRequest";
    var _LTNSL = "LaunchTemplateNameStringList";
    var _LTNa = "LaunchTemplateNames";
    var _LTO = "LaunchTemplateOverrides";
    var _LTOL = "LaunchTemplateOverridesList";
    var _LTOS = "LastTieringOperationStatus";
    var _LTOSD = "LastTieringOperationStatusDetail";
    var _LTP = "LaunchTemplatePlacement";
    var _LTPDNO = "LaunchTemplatePrivateDnsNameOptions";
    var _LTPDNOR = "LaunchTemplatePrivateDnsNameOptionsRequest";
    var _LTPR = "LaunchTemplatePlacementRequest";
    var _LTPa = "LastTieringProgress";
    var _LTS = "LaunchTemplateSpecification";
    var _LTSMO = "LaunchTemplateSpotMarketOptions";
    var _LTSMOR = "LaunchTemplateSpotMarketOptionsRequest";
    var _LTST = "LastTieringStartTime";
    var _LTSa = "LaunchTemplateSet";
    var _LTTS = "LaunchTemplateTagSpecification";
    var _LTTSL = "LaunchTemplateTagSpecificationList";
    var _LTTSR = "LaunchTemplateTagSpecificationRequest";
    var _LTTSRL = "LaunchTemplateTagSpecificationRequestList";
    var _LTV = "LaunchTemplateVersion";
    var _LTVS = "LaunchTemplateVersionSet";
    var _LTVa = "LaunchTemplateVersions";
    var _LTa = "LaunchTemplates";
    var _LTat = "LatestTime";
    var _LTau = "LaunchTime";
    var _LTi = "LicenseType";
    var _LTo = "LocationType";
    var _LToc = "LocalTarget";
    var _LUT = "LastUpdateTime";
    var _LUTa = "LastUpdatedTime";
    var _LUTas = "LastUpdateTimestamp";
    var _LV = "LogVersion";
    var _LVCS = "LastVersionCreationStatus";
    var _LVCSM = "LastVersionCreationStatusMessage";
    var _LVIRB = "ListVolumesInRecycleBin";
    var _LVIRBR = "ListVolumesInRecycleBinRequest";
    var _LVIRBRi = "ListVolumesInRecycleBinResult";
    var _LVN = "LatestVersionNumber";
    var _La = "Latest";
    var _Lam = "Lambda";
    var _Li = "Licenses";
    var _Lo = "Locale";
    var _Loc = "Location";
    var _M = "Min";
    var _MA = "MutualAuthentication";
    var _MAA = "ModifyAddressAttribute";
    var _MAAA = "MaintenanceAutoAppliedAfter";
    var _MAAR = "ModifyAddressAttributeRequest";
    var _MAARo = "ModifyAddressAttributeResult";
    var _MAE = "MultiAttachEnabled";
    var _MAI = "MaxAggregationInterval";
    var _MAIe = "MediaAcceleratorInfo";
    var _MAIi = "MiddleboxAttachmentIds";
    var _MAIid = "MiddleboxAttachmentId";
    var _MAS = "MovingAddressStatuses";
    var _MASS = "MovingAddressStatusSet";
    var _MASo = "MovingAddressStatus";
    var _MATV = "MoveAddressToVpc";
    var _MATVR = "MoveAddressToVpcRequest";
    var _MATVRo = "MoveAddressToVpcResult";
    var _MAZG = "ModifyAvailabilityZoneGroup";
    var _MAZGR = "ModifyAvailabilityZoneGroupRequest";
    var _MAZGRo = "ModifyAvailabilityZoneGroupResult";
    var _MAa = "MacAddress";
    var _MAe = "MeteredAccount";
    var _MB = "ManagedBy";
    var _MBCTI = "MoveByoipCidrToIpam";
    var _MBCTIR = "MoveByoipCidrToIpamRequest";
    var _MBCTIRo = "MoveByoipCidrToIpamResult";
    var _MBIM = "MaximumBandwidthInMbps";
    var _MC = "MacCredentials";
    var _MCOIOL = "MapCustomerOwnedIpOnLaunch";
    var _MCR = "ModifyCapacityReservation";
    var _MCRF = "ModifyCapacityReservationFleet";
    var _MCRFR = "ModifyCapacityReservationFleetRequest";
    var _MCRFRo = "ModifyCapacityReservationFleetResult";
    var _MCRI = "MoveCapacityReservationInstances";
    var _MCRIR = "MoveCapacityReservationInstancesRequest";
    var _MCRIRo = "MoveCapacityReservationInstancesResult";
    var _MCRR = "ModifyCapacityReservationRequest";
    var _MCRRo = "ModifyCapacityReservationResult";
    var _MCVE = "ModifyClientVpnEndpoint";
    var _MCVER = "ModifyClientVpnEndpointRequest";
    var _MCVERo = "ModifyClientVpnEndpointResult";
    var _MCa = "MaxCount";
    var _MCi = "MissingComponent";
    var _MCin = "MinCount";
    var _MD = "MaxDuration";
    var _MDA = "MulticastDomainAssociations";
    var _MDCS = "ModifyDefaultCreditSpecification";
    var _MDCSR = "ModifyDefaultCreditSpecificationRequest";
    var _MDCSRo = "ModifyDefaultCreditSpecificationResult";
    var _MDDS = "MaxDrainDurationSeconds";
    var _MDI = "MediaDeviceInfo";
    var _MDIL = "MediaDeviceInfoList";
    var _MDK = "MetaDataKey";
    var _MDMI = "MediaDeviceMemoryInfo";
    var _MDR = "MetricDataResults";
    var _MDRS = "MetricDataResultSet";
    var _MDRSe = "MetricDimensionResultSet";
    var _MDRe = "MetricDimensionResults";
    var _MDRet = "MetricDataResult";
    var _MDSC = "MaximumDaysSinceCreated";
    var _MDSD = "MaximumDaysSinceDeprecated";
    var _MDV = "MetaDataValue";
    var _MDa = "MaintenanceDetails";
    var _MDe = "MetaData";
    var _MDi = "MinDuration";
    var _ME = "MaxEntries";
    var _MEA = "MaximumEbsAttachments";
    var _MEC = "MaximumEbsCards";
    var _MEDKKI = "ModifyEbsDefaultKmsKeyId";
    var _MEDKKIR = "ModifyEbsDefaultKmsKeyIdRequest";
    var _MEDKKIRo = "ModifyEbsDefaultKmsKeyIdResult";
    var _MEI = "MaximumEfaInterfaces";
    var _MEM = "ManagedExceptionMessage";
    var _MEQC = "MaximumEnaQueueCount";
    var _MEQCPI = "MaximumEnaQueueCountPerInterface";
    var _MF = "ModifyFleet";
    var _MFIA = "ModifyFpgaImageAttribute";
    var _MFIAR = "ModifyFpgaImageAttributeRequest";
    var _MFIARo = "ModifyFpgaImageAttributeResult";
    var _MFR = "ModifyFleetRequest";
    var _MFRo = "ModifyFleetResult";
    var _MFV = "MostFrequentValue";
    var _MG = "MulticastGroups";
    var _MGBPVC = "MemoryGiBPerVCpu";
    var _MGBPVCR = "MemoryGiBPerVCpuRequest";
    var _MH = "MacHosts";
    var _MHL = "MacHostList";
    var _MHR = "ModifyHostsRequest";
    var _MHRo = "ModifyHostsResult";
    var _MHa = "MacHost";
    var _MHo = "ModifyHosts";
    var _MI = "MaximumIops";
    var _MIA = "ModifyImageAttribute";
    var _MIAR = "ModifyImageAttributeRequest";
    var _MIARo = "ModifyInstanceAttributeRequest";
    var _MIAV = "ModifyInstanceAttributeValue";
    var _MIAo = "ModifyInstanceAttribute";
    var _MIC = "MaxInstanceCount";
    var _MICE = "ModifyInstanceConnectEndpoint";
    var _MICER = "ModifyInstanceConnectEndpointRequest";
    var _MICERo = "ModifyInstanceConnectEndpointResult";
    var _MICO = "ModifyInstanceCpuOptions";
    var _MICOR = "ModifyInstanceCpuOptionsRequest";
    var _MICORo = "ModifyInstanceCpuOptionsResult";
    var _MICRA = "ModifyInstanceCapacityReservationAttributes";
    var _MICRAR = "ModifyInstanceCapacityReservationAttributesRequest";
    var _MICRARo = "ModifyInstanceCapacityReservationAttributesResult";
    var _MICS = "ModifyInstanceCreditSpecification";
    var _MICSR = "ModifyInstanceCreditSpecificationRequest";
    var _MICSRo = "ModifyInstanceCreditSpecificationResult";
    var _MIEST = "ModifyInstanceEventStartTime";
    var _MIESTR = "ModifyInstanceEventStartTimeRequest";
    var _MIESTRo = "ModifyInstanceEventStartTimeResult";
    var _MIEW = "ModifyInstanceEventWindow";
    var _MIEWR = "ModifyInstanceEventWindowRequest";
    var _MIEWRo = "ModifyInstanceEventWindowResult";
    var _MIF = "ModifyIdFormat";
    var _MIFR = "ModifyIdFormatRequest";
    var _MIIF = "ModifyIdentityIdFormat";
    var _MIIFR = "ModifyIdentityIdFormatRequest";
    var _MIMD = "ModifyInstanceMetadataDefaults";
    var _MIMDR = "ModifyInstanceMetadataDefaultsRequest";
    var _MIMDRo = "ModifyInstanceMetadataDefaultsResult";
    var _MIMO = "ModifyInstanceMaintenanceOptions";
    var _MIMOR = "ModifyInstanceMaintenanceOptionsRequest";
    var _MIMORo = "ModifyInstanceMaintenanceOptionsResult";
    var _MIMORod = "ModifyInstanceMetadataOptionsRequest";
    var _MIMORodi = "ModifyInstanceMetadataOptionsResult";
    var _MIMOo = "ModifyInstanceMetadataOptions";
    var _MINPO = "ModifyInstanceNetworkPerformanceOptions";
    var _MINPR = "ModifyInstanceNetworkPerformanceRequest";
    var _MINPRo = "ModifyInstanceNetworkPerformanceResult";
    var _MIP = "ModifyInstancePlacement";
    var _MIPAR = "ModifyIpamPolicyAllocationRules";
    var _MIPARR = "ModifyIpamPolicyAllocationRulesRequest";
    var _MIPARRo = "ModifyIpamPolicyAllocationRulesResult";
    var _MIPLR = "ModifyIpamPrefixListResolver";
    var _MIPLRR = "ModifyIpamPrefixListResolverRequest";
    var _MIPLRRo = "ModifyIpamPrefixListResolverResult";
    var _MIPLRT = "ModifyIpamPrefixListResolverTarget";
    var _MIPLRTR = "ModifyIpamPrefixListResolverTargetRequest";
    var _MIPLRTRo = "ModifyIpamPrefixListResolverTargetResult";
    var _MIPR = "ModifyInstancePlacementRequest";
    var _MIPRo = "ModifyInstancePlacementResult";
    var _MIPRod = "ModifyIpamPoolRequest";
    var _MIPRodi = "ModifyIpamPoolResult";
    var _MIPo = "ModifyIpamPool";
    var _MIR = "ModifyIpamRequest";
    var _MIRC = "ModifyIpamResourceCidr";
    var _MIRCR = "ModifyIpamResourceCidrRequest";
    var _MIRCRo = "ModifyIpamResourceCidrResult";
    var _MIRD = "ModifyIpamResourceDiscovery";
    var _MIRDR = "ModifyIpamResourceDiscoveryRequest";
    var _MIRDRo = "ModifyIpamResourceDiscoveryResult";
    var _MIRo = "ModifyIpamResult";
    var _MIRon = "MonitorInstancesRequest";
    var _MIRoni = "MonitorInstancesResult";
    var _MIS = "ModifyIpamScope";
    var _MISR = "ModifyIpamScopeRequest";
    var _MISRo = "ModifyIpamScopeResult";
    var _MIe = "MemoryInfo";
    var _MIo = "ModifyIpam";
    var _MIon = "MonitorInstances";
    var _MLGR = "ModifyLocalGatewayRoute";
    var _MLGRR = "ModifyLocalGatewayRouteRequest";
    var _MLGRRo = "ModifyLocalGatewayRouteResult";
    var _MLT = "ModifyLaunchTemplate";
    var _MLTR = "ModifyLaunchTemplateRequest";
    var _MLTRo = "ModifyLaunchTemplateResult";
    var _MMB = "MemoryMiB";
    var _MMBR = "MemoryMiBRequest";
    var _MMPL = "ModifyManagedPrefixList";
    var _MMPLR = "ModifyManagedPrefixListRequest";
    var _MMPLRo = "ModifyManagedPrefixListResult";
    var _MMRV = "ModifyManagedResourceVisibility";
    var _MMRVR = "ModifyManagedResourceVisibilityRequest";
    var _MMRVRo = "ModifyManagedResourceVisibilityResult";
    var _MMT = "MacModificationTask";
    var _MMTI = "MacModificationTaskIds";
    var _MMTIL = "MacModificationTaskIdList";
    var _MMTIa = "MacModificationTaskId";
    var _MMTL = "MacModificationTaskList";
    var _MMTa = "MacModificationTasks";
    var _MN = "MetricNames";
    var _MNC = "MaximumNetworkCards";
    var _MNI = "MaximumNetworkInterfaces";
    var _MNIA = "ModifyNetworkInterfaceAttribute";
    var _MNIAR = "ModifyNetworkInterfaceAttributeRequest";
    var _MNe = "MetricName";
    var _MO = "MetadataOptions";
    var _MOSLRG = "MemberOfServiceLinkedResourceGroup";
    var _MOSLSV = "MacOSLatestSupportedVersions";
    var _MOSVSL = "MacOSVersionStringList";
    var _MOa = "MaintenanceOptions";
    var _MP = "MatchPaths";
    var _MPC = "MarketplaceProductCodes";
    var _MPCL = "MarketplaceProductCodeList";
    var _MPCRL = "MarketplaceProductCodeRequestList";
    var _MPCa = "MarketplaceProductCode";
    var _MPDNO = "ModifyPrivateDnsNameOptions";
    var _MPDNOR = "ModifyPrivateDnsNameOptionsRequest";
    var _MPDNORo = "ModifyPrivateDnsNameOptionsResult";
    var _MPIDNO = "ModifyPublicIpDnsNameOptions";
    var _MPIDNOR = "ModifyPublicIpDnsNameOptionsRequest";
    var _MPIDNORo = "ModifyPublicIpDnsNameOptionsResult";
    var _MPIOL = "MapPublicIpOnLaunch";
    var _MPL = "MaxParallelLaunches";
    var _MPLS = "ManagedPrefixListSet";
    var _MPLa = "ManagedPrefixList";
    var _MPR = "MeteringPolicyRule";
    var _MPa = "MatchPath";
    var _MPax = "MaxPrice";
    var _MPe = "MetricPoints";
    var _MPet = "MetricPoint";
    var _MR = "MaxResults";
    var _MRI = "ModifyReservedInstances";
    var _MRIR = "ModifyReservedInstancesRequest";
    var _MRIRo = "ModifyReservedInstancesResult";
    var _MRS = "ModifyRouteServer";
    var _MRSR = "ModifyRouteServerRequest";
    var _MRSRo = "ModifyRouteServerResult";
    var _MRVS = "ManagedResourceVisibilitySettings";
    var _MRo = "ModificationResults";
    var _MRu = "MultiRegion";
    var _MS = "ManagementState";
    var _MSA = "ModifySnapshotAttribute";
    var _MSAR = "ModifySnapshotAttributeRequest";
    var _MSARo = "ModifySubnetAttributeRequest";
    var _MSAo = "ModifySubnetAttribute";
    var _MSDIH = "MaxSlotDurationInHours";
    var _MSDIHi = "MinSlotDurationInHours";
    var _MSFR = "ModifySpotFleetRequest";
    var _MSFRR = "ModifySpotFleetRequestRequest";
    var _MSFRRo = "ModifySpotFleetRequestResponse";
    var _MSGR = "ModifySecurityGroupRules";
    var _MSGRR = "ModifySecurityGroupRulesRequest";
    var _MSGRRo = "ModifySecurityGroupRulesResult";
    var _MSIPC = "MacSystemIntegrityProtectionConfiguration";
    var _MSIPCR = "MacSystemIntegrityProtectionConfigurationRequest";
    var _MSIPCa = "MacSystemIntegrityProtectionConfig";
    var _MSIPS = "MacSystemIntegrityProtectionStatus";
    var _MSNI = "MaximumSecondaryNetworkInterfaces";
    var _MSPAPOOODP = "MaxSpotPriceAsPercentageOfOptimalOnDemandPrice";
    var _MST = "ModifySnapshotTier";
    var _MSTR = "ModifySnapshotTierRequest";
    var _MSTRo = "ModifySnapshotTierResult";
    var _MSa = "MaintenanceStrategies";
    var _MSe = "MetricSet";
    var _MSo = "MoveStatus";
    var _MSod = "ModificationState";
    var _MSu = "MulticastSupport";
    var _MT = "MarketType";
    var _MTC = "MinTargetCapacity";
    var _MTDID = "MaxTermDurationInDays";
    var _MTDIDi = "MinTermDurationInDays";
    var _MTG = "ModifyTransitGateway";
    var _MTGMP = "ModifyTransitGatewayMeteringPolicy";
    var _MTGMPR = "ModifyTransitGatewayMeteringPolicyRequest";
    var _MTGMPRo = "ModifyTransitGatewayMeteringPolicyResult";
    var _MTGO = "ModifyTransitGatewayOptions";
    var _MTGPLR = "ModifyTransitGatewayPrefixListReference";
    var _MTGPLRR = "ModifyTransitGatewayPrefixListReferenceRequest";
    var _MTGPLRRo = "ModifyTransitGatewayPrefixListReferenceResult";
    var _MTGR = "ModifyTransitGatewayRequest";
    var _MTGRo = "ModifyTransitGatewayResult";
    var _MTGVA = "ModifyTransitGatewayVpcAttachment";
    var _MTGVAR = "ModifyTransitGatewayVpcAttachmentRequest";
    var _MTGVARO = "ModifyTransitGatewayVpcAttachmentRequestOptions";
    var _MTGVARo = "ModifyTransitGatewayVpcAttachmentResult";
    var _MTIMB = "MaximumThroughputInMBps";
    var _MTMFNS = "ModifyTrafficMirrorFilterNetworkServices";
    var _MTMFNSR = "ModifyTrafficMirrorFilterNetworkServicesRequest";
    var _MTMFNSRo = "ModifyTrafficMirrorFilterNetworkServicesResult";
    var _MTMFR = "ModifyTrafficMirrorFilterRule";
    var _MTMFRR = "ModifyTrafficMirrorFilterRuleRequest";
    var _MTMFRRo = "ModifyTrafficMirrorFilterRuleResult";
    var _MTMS = "ModifyTrafficMirrorSession";
    var _MTMSR = "ModifyTrafficMirrorSessionRequest";
    var _MTMSRo = "ModifyTrafficMirrorSessionResult";
    var _MTP = "MaxTotalPrice";
    var _MTe = "MemberType";
    var _MV = "MinVersion";
    var _MVA = "ModifyVolumeAttribute";
    var _MVAE = "ModifyVerifiedAccessEndpoint";
    var _MVAECO = "ModifyVerifiedAccessEndpointCidrOptions";
    var _MVAEEO = "ModifyVerifiedAccessEndpointEniOptions";
    var _MVAELBO = "ModifyVerifiedAccessEndpointLoadBalancerOptions";
    var _MVAEP = "ModifyVerifiedAccessEndpointPolicy";
    var _MVAEPR = "ModifyVerifiedAccessEndpointPolicyRequest";
    var _MVAEPRL = "ModifyVerifiedAccessEndpointPortRangeList";
    var _MVAEPRo = "ModifyVerifiedAccessEndpointPolicyResult";
    var _MVAEPRod = "ModifyVerifiedAccessEndpointPortRange";
    var _MVAER = "ModifyVerifiedAccessEndpointRequest";
    var _MVAERO = "ModifyVerifiedAccessEndpointRdsOptions";
    var _MVAERo = "ModifyVerifiedAccessEndpointResult";
    var _MVAESIL = "ModifyVerifiedAccessEndpointSubnetIdList";
    var _MVAG = "ModifyVerifiedAccessGroup";
    var _MVAGP = "ModifyVerifiedAccessGroupPolicy";
    var _MVAGPR = "ModifyVerifiedAccessGroupPolicyRequest";
    var _MVAGPRo = "ModifyVerifiedAccessGroupPolicyResult";
    var _MVAGR = "ModifyVerifiedAccessGroupRequest";
    var _MVAGRo = "ModifyVerifiedAccessGroupResult";
    var _MVAI = "ModifyVerifiedAccessInstance";
    var _MVAILC = "ModifyVerifiedAccessInstanceLoggingConfiguration";
    var _MVAILCR = "ModifyVerifiedAccessInstanceLoggingConfigurationRequest";
    var _MVAILCRo = "ModifyVerifiedAccessInstanceLoggingConfigurationResult";
    var _MVAIR = "ModifyVerifiedAccessInstanceRequest";
    var _MVAIRo = "ModifyVerifiedAccessInstanceResult";
    var _MVANAOO = "ModifyVerifiedAccessNativeApplicationOidcOptions";
    var _MVAR = "ModifyVolumeAttributeRequest";
    var _MVARo = "ModifyVpcAttributeRequest";
    var _MVATP = "ModifyVerifiedAccessTrustProvider";
    var _MVATPDO = "ModifyVerifiedAccessTrustProviderDeviceOptions";
    var _MVATPOO = "ModifyVerifiedAccessTrustProviderOidcOptions";
    var _MVATPR = "ModifyVerifiedAccessTrustProviderRequest";
    var _MVATPRo = "ModifyVerifiedAccessTrustProviderResult";
    var _MVAo = "ModifyVpcAttribute";
    var _MVBPAE = "ModifyVpcBlockPublicAccessExclusion";
    var _MVBPAER = "ModifyVpcBlockPublicAccessExclusionRequest";
    var _MVBPAERo = "ModifyVpcBlockPublicAccessExclusionResult";
    var _MVBPAO = "ModifyVpcBlockPublicAccessOptions";
    var _MVBPAOR = "ModifyVpcBlockPublicAccessOptionsRequest";
    var _MVBPAORo = "ModifyVpcBlockPublicAccessOptionsResult";
    var _MVC = "ModifyVpnConnection";
    var _MVCO = "ModifyVpnConnectionOptions";
    var _MVCOR = "ModifyVpnConnectionOptionsRequest";
    var _MVCORo = "ModifyVpnConnectionOptionsResult";
    var _MVCR = "ModifyVpnConnectionRequest";
    var _MVCRo = "ModifyVpnConnectionResult";
    var _MVE = "ManagesVpcEndpoints";
    var _MVEC = "ModifyVpcEncryptionControl";
    var _MVECN = "ModifyVpcEndpointConnectionNotification";
    var _MVECNR = "ModifyVpcEndpointConnectionNotificationRequest";
    var _MVECNRo = "ModifyVpcEndpointConnectionNotificationResult";
    var _MVECR = "ModifyVpcEncryptionControlRequest";
    var _MVECRo = "ModifyVpcEncryptionControlResult";
    var _MVER = "ModifyVpcEndpointRequest";
    var _MVERo = "ModifyVpcEndpointResult";
    var _MVESC = "ModifyVpcEndpointServiceConfiguration";
    var _MVESCR = "ModifyVpcEndpointServiceConfigurationRequest";
    var _MVESCRo = "ModifyVpcEndpointServiceConfigurationResult";
    var _MVESP = "ModifyVpcEndpointServicePermissions";
    var _MVESPR = "ModifyVpcEndpointServicePermissionsRequest";
    var _MVESPRR = "ModifyVpcEndpointServicePayerResponsibilityRequest";
    var _MVESPRRo = "ModifyVpcEndpointServicePayerResponsibilityResult";
    var _MVESPRo = "ModifyVpcEndpointServicePermissionsResult";
    var _MVESPRod = "ModifyVpcEndpointServicePayerResponsibility";
    var _MVEo = "ModifyVpcEndpoint";
    var _MVPCO = "ModifyVpcPeeringConnectionOptions";
    var _MVPCOR = "ModifyVpcPeeringConnectionOptionsRequest";
    var _MVPCORo = "ModifyVpcPeeringConnectionOptionsResult";
    var _MVR = "ModifyVolumeRequest";
    var _MVRo = "ModifyVolumeResult";
    var _MVS = "MetricValueSet";
    var _MVT = "ModifyVpcTenancy";
    var _MVTC = "ModifyVpnTunnelCertificate";
    var _MVTCR = "ModifyVpnTunnelCertificateRequest";
    var _MVTCRo = "ModifyVpnTunnelCertificateResult";
    var _MVTO = "ModifyVpnTunnelOptions";
    var _MVTOR = "ModifyVpnTunnelOptionsRequest";
    var _MVTORo = "ModifyVpnTunnelOptionsResult";
    var _MVTOS = "ModifyVpnTunnelOptionsSpecification";
    var _MVTR = "ModifyVpcTenancyRequest";
    var _MVTRo = "ModifyVpcTenancyResult";
    var _MVa = "MaxVersion";
    var _MVe = "MetricValues";
    var _MVet = "MetricValue";
    var _MVo = "ModifyVolume";
    var _Ma = "Max";
    var _Mai = "Main";
    var _Man = "Manufacturer";
    var _Mana = "Managed";
    var _Mar = "Marketplace";
    var _Me = "Message";
    var _Med = "Med";
    var _Mes = "Messages";
    var _Met = "Metric";
    var _Mo = "Mode";
    var _Mon = "Monitoring";
    var _Moni = "Monitored";
    var _N = "Name";
    var _NA = "NetworkAcl";
    var _NAA = "NetworkAclAssociation";
    var _NAAI = "NetworkAclAssociationId";
    var _NAAL = "NetworkAclAssociationList";
    var _NAE2 = "NetworkAclEntry";
    var _NAEL = "NetworkAclEntryList";
    var _NAI = "NetworkAclId";
    var _NAISL = "NetworkAclIdStringList";
    var _NAIe = "NetworkAclIds";
    var _NAIew = "NewAssociationId";
    var _NAL = "NetworkAclList";
    var _NAOO = "NativeApplicationOidcOptions";
    var _NAe = "NetworkAcls";
    var _NAo = "NotAfter";
    var _NB = "NotBefore";
    var _NBD = "NotBeforeDeadline";
    var _NBG = "NetworkBorderGroup";
    var _NBGR = "NetworkBandwidthGbpsRequest";
    var _NBGe = "NetworkBandwidthGbps";
    var _NC = "NetworkCards";
    var _NCI = "NetworkCardIndex";
    var _NCIL = "NetworkCardInfoList";
    var _NCIe = "NetworkCardInfo";
    var _NCR = "NonCompliantResources";
    var _ND = "NoDevice";
    var _NDC = "NewDhcpConfiguration";
    var _NDCI = "NeuronDeviceCoreInfo";
    var _NDCL = "NewDhcpConfigurationList";
    var _NDI = "NeuronDeviceInfo";
    var _NDIL = "NeuronDeviceInfoList";
    var _NDMI = "NeuronDeviceMemoryInfo";
    var _NDe = "NeuronDevices";
    var _NES = "NitroEnclavesSupport";
    var _NG = "NatGateway";
    var _NGA = "NatGatewayAddresses";
    var _NGAA = "NatGatewayAttachedAppliance";
    var _NGAAL = "NatGatewayAttachedApplianceList";
    var _NGAL = "NatGatewayAddressList";
    var _NGAa = "NatGatewayAddress";
    var _NGE = "NatGatewayExclusion";
    var _NGI = "NatGatewayId";
    var _NGISL = "NatGatewayIdStringList";
    var _NGIa = "NatGatewayIds";
    var _NGL = "NatGatewayList";
    var _NGa = "NatGateways";
    var _NHI = "NextHopIp";
    var _NI = "NetworkId";
    var _NIA = "NetworkInsightsAnalyses";
    var _NIAA = "NetworkInsightsAnalysisArn";
    var _NIAC = "NetworkInterfaceAttachmentChanges";
    var _NIAI = "NetworkInsightsAnalysisId";
    var _NIAIL = "NetworkInsightsAnalysisIdList";
    var _NIAIe = "NetworkInsightsAnalysisIds";
    var _NIAL = "NetworkInsightsAnalysisList";
    var _NIAS = "NetworkInsightsAccessScope";
    var _NIASA = "NetworkInsightsAccessScopeAnalyses";
    var _NIASAA = "NetworkInsightsAccessScopeAnalysisArn";
    var _NIASAI = "NetworkInsightsAccessScopeAnalysisId";
    var _NIASAIL = "NetworkInsightsAccessScopeAnalysisIdList";
    var _NIASAIe = "NetworkInsightsAccessScopeAnalysisIds";
    var _NIASAL = "NetworkInsightsAccessScopeAnalysisList";
    var _NIASAe = "NetworkInsightsAccessScopeArn";
    var _NIASAet = "NetworkInsightsAccessScopeAnalysis";
    var _NIASC = "NetworkInsightsAccessScopeContent";
    var _NIASI = "NetworkInsightsAccessScopeId";
    var _NIASIL = "NetworkInsightsAccessScopeIdList";
    var _NIASIe = "NetworkInsightsAccessScopeIds";
    var _NIASL = "NetworkInsightsAccessScopeList";
    var _NIASe = "NetworkInsightsAccessScopes";
    var _NIASet = "NetworkInterfaceAttachmentStatus";
    var _NIAe = "NetworkInsightsAnalysis";
    var _NIAet = "NetworkInterfaceAssociation";
    var _NIAetw = "NetworkInterfaceAttachment";
    var _NIC = "NetworkInterfaceCount";
    var _NICR = "NetworkInterfaceCountRequest";
    var _NID = "NetworkInterfaceDescription";
    var _NII = "NetworkInterfaceId";
    var _NIIA = "NetworkInterfaceIpv6Address";
    var _NIIAL = "NetworkInterfaceIpv6AddressesList";
    var _NIIL = "NetworkInterfaceIdList";
    var _NIIS = "NetworkInterfaceIdSet";
    var _NIIe = "NetworkInterfaceIds";
    var _NIL = "NetworkInterfaceList";
    var _NIO = "NetworkInterfaceOptions";
    var _NIOI = "NetworkInterfaceOwnerId";
    var _NIP = "NetworkInsightsPath";
    var _NIPA = "NetworkInsightsPathArn";
    var _NIPI = "NetworkInsightsPathId";
    var _NIPIA = "NetworkInterfacePrivateIpAddress";
    var _NIPIAL = "NetworkInterfacePrivateIpAddressList";
    var _NIPIL = "NetworkInsightsPathIdList";
    var _NIPIe = "NetworkInterfacePermissionId";
    var _NIPIet = "NetworkInsightsPathIds";
    var _NIPIetw = "NetworkInterfacePermissionIds";
    var _NIPL = "NetworkInsightsPathList";
    var _NIPLe = "NetworkInterfacePermissionList";
    var _NIPS = "NetworkInterfacePermissionState";
    var _NIPe = "NetworkInsightsPaths";
    var _NIPet = "NetworkInterfacePermissions";
    var _NIPetw = "NetworkInterfacePermission";
    var _NIe = "NetworkInterface";
    var _NIet = "NetworkInterfaces";
    var _NIetw = "NetworkInfo";
    var _NIeu = "NeuronInfo";
    var _NL = "NetmaskLength";
    var _NLBA = "NetworkLoadBalancerArn";
    var _NLBAe = "NetworkLoadBalancerArns";
    var _NN = "NetworkNodes";
    var _NNL = "NetworkNodesList";
    var _NNS = "NetworkNodeSet";
    var _NOA = "NumberOfAccounts";
    var _NOFA = "NumberOfFailedAccounts";
    var _NOMA = "NumberOfMatchedAccounts";
    var _NOUA = "NumberOfUnmatchedAccounts";
    var _NP = "NvramProtections";
    var _NPF = "NetworkPathFound";
    var _NPO = "NetworkPerformanceOptions";
    var _NPe = "NetworkPerformance";
    var _NPet = "NetworkPlatform";
    var _NR = "NoReboot";
    var _NS = "NvmeSupport";
    var _NSST = "NextSlotStartTime";
    var _NSe = "NetworkServices";
    var _NT = "NetworkType";
    var _NTI = "NitroTpmInfo";
    var _NTS = "NitroTpmSupport";
    var _NTSVL = "NitroTpmSupportedVersionsList";
    var _NTe = "NextToken";
    var _NV = "NestedVirtualization";
    var _Na = "Nameservers";
    var _O = "Origin";
    var _OA = "OutpostArn";
    var _OASL = "OrganizationArnStringList";
    var _OAr = "OrganizationsAccess";
    var _OArg = "OrganizationArn";
    var _OArga = "OrganizationArns";
    var _OAw = "OwnerAlias";
    var _OC = "OfferingClass";
    var _OD = "OccurrenceDays";
    var _ODAS = "OnDemandAllocationStrategy";
    var _ODFC = "OnDemandFulfilledCapacity";
    var _ODMPPOLP = "OnDemandMaxPricePercentageOverLowestPrice";
    var _ODMTP = "OnDemandMaxTotalPrice";
    var _ODO = "OnDemandOptions";
    var _ODOR = "OnDemandOptionsRequest";
    var _ODRS = "OccurrenceDayRequestSet";
    var _ODS = "OccurrenceDaySet";
    var _ODTC = "OnDemandTargetCapacity";
    var _ODc = "OccurrenceDay";
    var _ODcc = "OccurenceDay";
    var _OEP = "OrganizationsEntityPath";
    var _OF = "OutputFormat";
    var _OH = "OutboundHeader";
    var _OI = "OwnerId";
    var _OIA = "OutsideIpAddress";
    var _OIAT = "OutsideIpAddressType";
    var _OIS = "OptInStatus";
    var _OIf = "OfferingId";
    var _OIr = "OriginalIops";
    var _OIu = "OutpostId";
    var _OIw = "OwnerIds";
    var _OK = "ObjectKey";
    var _OL = "OutpostLags";
    var _OLI = "OutpostLagId";
    var _OLIS = "OutpostLagIdSet";
    var _OLIu = "OutpostLagIds";
    var _OLS = "OutpostLagSet";
    var _OLu = "OutpostLag";
    var _OMAE = "OriginalMultiAttachEnabled";
    var _ON = "OptionName";
    var _ONA = "OdbNetworkArn";
    var _OO = "OidcOptions";
    var _OR = "OperatingRegions";
    var _ORIWEA = "OutputReservedInstancesWillExpireAt";
    var _ORTE = "OccurrenceRelativeToEnd";
    var _ORp = "OperatingRegion";
    var _ORpe = "OperatorRequest";
    var _ORper = "OperatorResponse";
    var _OS = "OfferingSet";
    var _OSL = "OwnerStringList";
    var _OST = "OldestSampleTime";
    var _OSr = "OriginalSize";
    var _OSv = "OverlapStatus";
    var _OT = "OptimizingTime";
    var _OTI = "OrganizationTargetId";
    var _OTf = "OfferingType";
    var _OTp = "OperationType";
    var _OTr = "OrganizationTargets";
    var _OTri = "OriginalThroughput";
    var _OU = "OccurrenceUnit";
    var _OUA = "OrganizationalUnitArn";
    var _OUASL = "OrganizationalUnitArnStringList";
    var _OUAr = "OrganizationalUnitArns";
    var _OUE = "OrganizationalUnitExclusions";
    var _OUI = "OrganizationalUnitId";
    var _OV = "OptionValues";
    var _OVC = "OpenVpnConfigurations";
    var _OVT = "OriginalVolumeType";
    var _OVp = "OptionValue";
    var _Op = "Operator";
    var _Ope = "Operation";
    var _Opt = "Options";
    var _Ou = "Output";
    var _Ov = "Overrides";
    var _Ow = "Owners";
    var _Own = "Owner";
    var _P10 = "Principal";
    var _PA10 = "PoolArn";
    var _PAI = "PeerAccountId";
    var _PAIe = "PeeringAttachmentId";
    var _PAR = "PoolAddressRange";
    var _PARo = "PoolAddressRanges";
    var _PAS = "PeeringAttachmentStatus";
    var _PAe = "PeerAddress";
    var _PAee = "PeerAsn";
    var _PAr10 = "PrincipalArn";
    var _PAu = "PubliclyAdvertisable";
    var _PB = "ProvisionedBandwidth";
    var _PBA = "PeerBgpAsn";
    var _PBAE = "PeerBgpAsnExtended";
    var _PBC = "ProvisionByoipCidr";
    var _PBCR = "ProvisionByoipCidrRequest";
    var _PBCRr = "ProvisionByoipCidrResult";
    var _PBIG = "PeakBandwidthInGbps";
    var _PC10 = "PoolCidrs";
    var _PCB = "PoolCidrBlocks";
    var _PCBE = "PurchaseCapacityBlockExtension";
    var _PCBER = "PurchaseCapacityBlockExtensionRequest";
    var _PCBERu = "PurchaseCapacityBlockExtensionResult";
    var _PCBR = "PurchaseCapacityBlockRequest";
    var _PCBRu = "PurchaseCapacityBlockResult";
    var _PCBS = "PoolCidrBlocksSet";
    var _PCBo = "PoolCidrBlock";
    var _PCBu = "PurchaseCapacityBlock";
    var _PCI = "PreserveClientIp";
    var _PCIr = "ProductCodeId";
    var _PCL = "PathComponentList";
    var _PCLr = "ProductCodeList";
    var _PCNI = "PeerCoreNetworkId";
    var _PCO = "PeeringConnectionOptions";
    var _PCOR = "PeeringConnectionOptionsRequest";
    var _PCS = "PostureComplianceStatuses";
    var _PCSL = "ProductCodeStringList";
    var _PCT = "ProductCodeType";
    var _PCa = "PartitionCount";
    var _PCat = "PathComponent";
    var _PCo = "PoolCount";
    var _PCr10 = "ProductCode";
    var _PCro = "ProductCodes";
    var _PD = "PasswordData";
    var _PDD = "PrivateDnsDetails";
    var _PDDS = "PrivateDnsDetailsSet";
    var _PDE = "PrivateDnsEnabled";
    var _PDEr = "PrivateDnsEntry";
    var _PDHG = "Phase1DHGroup";
    var _PDHGN = "Phase1DHGroupNumbers";
    var _PDHGNL = "Phase1DHGroupNumbersList";
    var _PDHGNLV = "Phase1DHGroupNumbersListValue";
    var _PDHGNLVh = "Phase2DHGroupNumbersListValue";
    var _PDHGNLh = "Phase2DHGroupNumbersList";
    var _PDHGNRL = "Phase1DHGroupNumbersRequestList";
    var _PDHGNRLV = "Phase1DHGroupNumbersRequestListValue";
    var _PDHGNRLVh = "Phase2DHGroupNumbersRequestListValue";
    var _PDHGNRLh = "Phase2DHGroupNumbersRequestList";
    var _PDHGNh = "Phase2DHGroupNumbers";
    var _PDHGNha = "Phase1DHGroupNumber";
    var _PDHGNhas = "Phase2DHGroupNumber";
    var _PDHGh = "Phase2DHGroup";
    var _PDHT = "PrivateDnsHostnameType";
    var _PDHTOL = "PrivateDnsHostnameTypeOnLaunch";
    var _PDL = "PricingDetailsList";
    var _PDN = "PrivateDnsName";
    var _PDNC = "PrivateDnsNameConfiguration";
    var _PDNO = "PrivateDnsNameOptions";
    var _PDNOOL = "PrivateDnsNameOptionsOnLaunch";
    var _PDNOR = "PrivateDnsNameOptionsRequest";
    var _PDNORr = "PrivateDnsNameOptionsResponse";
    var _PDNVS = "PrivateDnsNameVerificationState";
    var _PDNr = "PrivateDnsNames";
    var _PDNu = "PublicDnsNames";
    var _PDNub = "PublicDnsName";
    var _PDOFIRE = "PrivateDnsOnlyForInboundResolverEndpoint";
    var _PDP = "PrivateDnsPreference";
    var _PDRTI = "PropagationDefaultRouteTableId";
    var _PDSD = "PrivateDnsSpecifiedDomains";
    var _PDSDN = "PublicDualStackDnsName";
    var _PDSDS = "PrivateDnsSpecifiedDomainSet";
    var _PDSDr = "PrivateDnsSpecifiedDomain";
    var _PDSI = "PublicDefaultScopeId";
    var _PDSIr = "PrivateDefaultScopeId";
    var _PDa = "PaymentDue";
    var _PDl = "PlatformDetails";
    var _PDo = "PolicyDocument";
    var _PDoo = "PoolDepth";
    var _PDr = "ProductDescription";
    var _PDri = "PricingDetail";
    var _PDric = "PricingDetails";
    var _PDro = "ProductDescriptions";
    var _PE = "PolicyEnabled";
    var _PEA = "Phase1EncryptionAlgorithm";
    var _PEAL = "Phase1EncryptionAlgorithmsList";
    var _PEALV = "Phase1EncryptionAlgorithmsListValue";
    var _PEALVh = "Phase2EncryptionAlgorithmsListValue";
    var _PEALh = "Phase2EncryptionAlgorithmsList";
    var _PEARL = "Phase1EncryptionAlgorithmsRequestList";
    var _PEARLV = "Phase1EncryptionAlgorithmsRequestListValue";
    var _PEARLVh = "Phase2EncryptionAlgorithmsRequestListValue";
    var _PEARLh = "Phase2EncryptionAlgorithmsRequestList";
    var _PEAh = "Phase2EncryptionAlgorithm";
    var _PEAha = "Phase1EncryptionAlgorithms";
    var _PEAhas = "Phase2EncryptionAlgorithms";
    var _PED = "PartitionEndDate";
    var _PEk = "PkceEnabled";
    var _PF = "PacketField";
    var _PFR = "PerformanceFactorReference";
    var _PFRR = "PerformanceFactorReferenceRequest";
    var _PFRS = "PerformanceFactorReferenceSet";
    var _PFRSR = "PerformanceFactorReferenceSetRequest";
    var _PFS = "PreviousFleetState";
    var _PFa = "PathFilter";
    var _PG = "PlacementGroup";
    var _PGA = "PlacementGroupArn";
    var _PGI = "PlacementGroupInfo";
    var _PGISL = "PlacementGroupIdStringList";
    var _PGL = "PlacementGroupList";
    var _PGSL = "PlacementGroupStrategyList";
    var _PGl = "PlacementGroups";
    var _PHP = "PerHourPartition";
    var _PHR = "PurchaseHostReservation";
    var _PHRR = "PurchaseHostReservationRequest";
    var _PHRRu = "PurchaseHostReservationResult";
    var _PHS = "PacketHeaderStatement";
    var _PHSR = "PacketHeaderStatementRequest";
    var _PI10 = "PublicIp";
    var _PIA = "Phase1IntegrityAlgorithm";
    var _PIAC = "PrivateIpAddressCount";
    var _PIACS = "PrivateIpAddressConfigSet";
    var _PIACr = "PrivateIpAddressConfigs";
    var _PIACri = "PrivateIpAddressConfig";
    var _PIAL = "Phase1IntegrityAlgorithmsList";
    var _PIALV = "Phase1IntegrityAlgorithmsListValue";
    var _PIALVh = "Phase2IntegrityAlgorithmsListValue";
    var _PIALh = "Phase2IntegrityAlgorithmsList";
    var _PIARL = "Phase1IntegrityAlgorithmsRequestList";
    var _PIARLV = "Phase1IntegrityAlgorithmsRequestListValue";
    var _PIARLVh = "Phase2IntegrityAlgorithmsRequestListValue";
    var _PIARLh = "Phase2IntegrityAlgorithmsRequestList";
    var _PIAS = "PrivateIpAddressSpecification";
    var _PIASL = "PrivateIpAddressSpecificationList";
    var _PIASLr = "PrivateIpAddressStringList";
    var _PIAh = "Phase2IntegrityAlgorithm";
    var _PIAha = "Phase1IntegrityAlgorithms";
    var _PIAhas = "Phase2IntegrityAlgorithms";
    var _PIAr = "PrivateIpAddress";
    var _PIAri = "PrivateIpAddresses";
    var _PIAriv = "PrivateIpv4Addresses";
    var _PIAu = "PublicIpAddress";
    var _PIB = "ProvisionIpamByoasn";
    var _PIBR = "ProvisionIpamByoasnRequest";
    var _PIBRr = "ProvisionIpamByoasnResult";
    var _PIDN = "PublicIpv6DnsName";
    var _PIDNO = "PublicIpDnsNameOptions";
    var _PIDNu = "PublicIpv4DnsName";
    var _PIF = "PrincipalIdFormat";
    var _PIFL = "PrincipalIdFormatList";
    var _PIL = "ProtocolIntList";
    var _PIP = "PublicIpv4Pool";
    var _PIPC = "ProvisionIpamPoolCidr";
    var _PIPCR = "ProvisionIpamPoolCidrRequest";
    var _PIPCRr = "ProvisionIpamPoolCidrResult";
    var _PIPI = "PublicIpv4PoolId";
    var _PIPISL = "PublicIpv4PoolIdStringList";
    var _PIPR = "PublicIpv4PoolRange";
    var _PIPRS = "PublicIpv4PoolRangeSet";
    var _PIPS = "PublicIpv4PoolSet";
    var _PIPu = "PublicIpv4Pools";
    var _PIS = "PublicIpSource";
    var _PISL = "PublicIpStringList";
    var _PIc = "PciId";
    var _PIo = "PoolId";
    var _PIoo = "PoolIds";
    var _PIr = "PrimaryIpv6";
    var _PIri = "PrivateIp";
    var _PIro = "ProcessorInfo";
    var _PIu = "PublicIps";
    var _PK = "PublicKey";
    var _PKM = "PublicKeyMaterial";
    var _PL = "PrefixList";
    var _PLA = "PrefixListAssociations";
    var _PLAS = "PrefixListAssociationSet";
    var _PLAr = "PrefixListArn";
    var _PLAre = "PrefixListAssociation";
    var _PLD = "PeerLivenessDetection";
    var _PLE = "PrefixListEntry";
    var _PLES = "PrefixListEntrySet";
    var _PLF = "PartitionLoadFrequency";
    var _PLI = "PrefixListId";
    var _PLIL = "PrefixListIdList";
    var _PLIS = "PrefixListIdSet";
    var _PLIr = "PrefixListIds";
    var _PLN = "PrefixListName";
    var _PLOI = "PrefixListOwnerId";
    var _PLR = "PrefixListRegion";
    var _PLRISL = "PrefixListResourceIdStringList";
    var _PLS = "Phase1LifetimeSeconds";
    var _PLSh = "Phase2LifetimeSeconds";
    var _PLSr = "PrefixListSet";
    var _PLa = "PacketLength";
    var _PLr = "PrefixLists";
    var _PLro = "ProtocolList";
    var _PM = "PendingMaintenance";
    var _PN = "PartitionNumber";
    var _PNC = "PreviewNextCidr";
    var _PO = "PaymentOption";
    var _POI = "PeerOwnerId";
    var _POe = "PeeringOptions";
    var _PP = "ProgressPercentage";
    var _PPIPC = "ProvisionPublicIpv4PoolCidr";
    var _PPIPCR = "ProvisionPublicIpv4PoolCidrRequest";
    var _PPIPCRr = "ProvisionPublicIpv4PoolCidrResult";
    var _PR = "PtrRecord";
    var _PRD = "PersistRoutesDuration";
    var _PRF = "PathRequestFilter";
    var _PRIO = "PurchaseReservedInstancesOffering";
    var _PRIOR = "PurchaseReservedInstancesOfferingRequest";
    var _PRIORu = "PurchaseReservedInstancesOfferingResult";
    var _PRL = "PortRangeList";
    var _PRN = "PolicyRuleNumber";
    var _PRNo = "PolicyReferenceName";
    var _PRS = "PersistRoutesState";
    var _PRSu = "PurchaseRequestSet";
    var _PRU = "PtrRecordUpdate";
    var _PRa = "PayerResponsibility";
    var _PRe = "PersistRoutes";
    var _PRee = "PeerRegion";
    var _PRer = "PermanentRestore";
    var _PRl = "PlacementResponse";
    var _PRo = "PortRange";
    var _PRol = "PolicyRule";
    var _PRor = "PortRanges";
    var _PRu = "PurchaseRequest";
    var _PRur = "PurchaseRequests";
    var _PS = "ProvisioningStatus";
    var _PSD = "PartitionStartDate";
    var _PSET = "PreviousSlotEndTime";
    var _PSFRS = "PreviousSpotFleetRequestState";
    var _PSI = "PurchaseScheduledInstances";
    var _PSIR = "PurchaseScheduledInstancesRequest";
    var _PSIRu = "PurchaseScheduledInstancesResult";
    var _PSIS = "PurchasedScheduledInstanceSet";
    var _PSK = "PreSharedKey";
    var _PSKA = "PreSharedKeyArn";
    var _PSKE = "PublicSigningKeyEndpoint";
    var _PSKS = "PreSharedKeyStorage";
    var _PSKU = "PublicSigningKeyUrl";
    var _PSL = "PriceScheduleList";
    var _PSR = "ProvisioningStatusReason";
    var _PSRa = "PathStatementRequest";
    var _PSS = "PriceScheduleSpecification";
    var _PSSL = "PriceScheduleSpecificationList";
    var _PSa = "PathStatement";
    var _PSe = "PermissionState";
    var _PSee = "PeeringStatus";
    var _PSh = "PhcSupport";
    var _PSr = "PreviousState";
    var _PSre = "PreviousStatus";
    var _PSri = "PriceSchedules";
    var _PSric = "PriceSchedule";
    var _PSro = "ProcessingStatus";
    var _PSu = "PurchaseSet";
    var _PT = "PrincipalType";
    var _PTGI = "PeerTransitGatewayId";
    var _PTI = "PeeringTgwInfo";
    var _PTS = "PoolTagSpecifications";
    var _PTSo = "PoolTagSpecification";
    var _PTr = "ProvisionTime";
    var _PTu = "PurchaseToken";
    var _PTur = "PurchaseTime";
    var _PU = "PresignedUrl";
    var _PUS = "PtrUpdateStatus";
    var _PV = "PropagatingVgw";
    var _PVI = "PeerVpcId";
    var _PVIr = "PrimaryVpcId";
    var _PVL = "PropagatingVgwList";
    var _PVr = "PreviousVersion";
    var _PVro = "PropagatingVgws";
    var _PZI = "ParentZoneId";
    var _PZN = "ParentZoneName";
    var _Pe = "Permission";
    var _Per = "Period";
    var _Pl = "Platform";
    var _Pla = "Placement";
    var _Po = "Port";
    var _Pr10 = "Protocol";
    var _Pre = "Prefix";
    var _Pri = "Principals";
    var _Pric = "Price";
    var _Prim = "Primary";
    var _Prio = "Priority";
    var _Pro = "Progress";
    var _Prop = "Propagation";
    var _Prot = "Protocols";
    var _Prov = "Provisioned";
    var _Pu = "Public";
    var _Pur = "Purchase";
    var _Q = "Quantity";
    var _R = "Return";
    var _RA10 = "RuleAction";
    var _RAA = "ResetAddressAttribute";
    var _RAAR = "ResetAddressAttributeRequest";
    var _RAARe = "ResetAddressAttributeResult";
    var _RAE = "RemoteAccessEnabled";
    var _RAG = "RevokeAllGroups";
    var _RAP = "RemoveAllowedPrincipals";
    var _RAR = "ReleaseAddressRequest";
    var _RART = "RemoveAllocationResourceTags";
    var _RARTe = "RemoveAllocationResourceTag";
    var _RATC = "RestoreAddressToClassic";
    var _RATCR = "RestoreAddressToClassicRequest";
    var _RATCRe = "RestoreAddressToClassicResult";
    var _RAe = "ReservationArn";
    var _RAel = "ReleaseAddress";
    var _RAes = "ResolveAlias";
    var _RAeso = "ResourceArn";
    var _RAo = "RoleArn";
    var _RB = "RequestedBy";
    var _RBET = "RecycleBinEnterTime";
    var _RBETe = "RecycleBinExitTime";
    var _RBUI = "RestorableByUserIds";
    var _RBe = "RestorableBy";
    var _RC10 = "ReturnCode";
    var _RCA = "ResourceConfigurationArn";
    var _RCGA = "ResourceConfigurationGroupArn";
    var _RCL = "ReasonCodesList";
    var _RCLe = "RecurringChargesList";
    var _RCO = "ReservedCapacityOptions";
    var _RCOR = "ReservedCapacityOptionsRequest";
    var _RCRBO = "RejectCapacityReservationBillingOwnership";
    var _RCRBOR = "RejectCapacityReservationBillingOwnershipRequest";
    var _RCRBORe = "RejectCapacityReservationBillingOwnershipResult";
    var _RCS = "ResourceComplianceStatus";
    var _RCT = "ReservationCreateTimestamp";
    var _RCTe = "ReportCreationTime";
    var _RCVI = "RevokeClientVpnIngress";
    var _RCVIR = "RevokeClientVpnIngressRequest";
    var _RCVIRe = "RevokeClientVpnIngressResult";
    var _RCe = "ResourceCidr";
    var _RCea = "ReasonCodes";
    var _RCec = "RecurringCharge";
    var _RCecu = "RecurringCharges";
    var _RD = "RestoreDuration";
    var _RDAC = "ResourceDiscoveryAssociationCount";
    var _RDCA = "RdsDbClusterArn";
    var _RDI = "RamDiskId";
    var _RDIA = "RdsDbInstanceArn";
    var _RDN = "RootDeviceName";
    var _RDPA = "RdsDbProxyArn";
    var _RDS = "ResourceDiscoveryStatus";
    var _RDT = "RootDeviceType";
    var _RDTL = "RootDeviceTypeList";
    var _RE = "RdsEndpoint";
    var _REAC = "RemoveExternalAuthorityConfiguration";
    var _RED = "RemoveEndDate";
    var _REDKKI = "ResetEbsDefaultKmsKeyId";
    var _REDKKIR = "ResetEbsDefaultKmsKeyIdRequest";
    var _REDKKIRe = "ResetEbsDefaultKmsKeyIdResult";
    var _REDT = "ReservationEndDateType";
    var _REIT = "RequireEncryptionInTransit";
    var _RET = "ReservationEndTimestamp";
    var _RETe = "RestoreExpiryTime";
    var _REe = "ResponseError";
    var _REem = "RemoveEntries";
    var _REemo = "RemoveEntry";
    var _REes = "ResourceExclusions";
    var _RF = "RemoveFields";
    var _RFIA = "ResetFpgaImageAttribute";
    var _RFIAR = "ResetFpgaImageAttributeRequest";
    var _RFIARe = "ResetFpgaImageAttributeResult";
    var _RFIS = "ReservationFleetInstanceSpecification";
    var _RFISL = "ReservationFleetInstanceSpecificationList";
    var _RFP = "RekeyFuzzPercentage";
    var _RFPR = "RequestFilterPortRange";
    var _RFe = "RemoveField";
    var _RG = "RegionGeography";
    var _RGA = "RuleGroupArn";
    var _RGI = "ReferencedGroupId";
    var _RGIe = "ReferencedGroupInfo";
    var _RGL = "RegionGeographyList";
    var _RGLBA = "RemoveGatewayLoadBalancerArns";
    var _RGLBAe = "RemoveGatewayLoadBalancerArn";
    var _RGROP = "RuleGroupRuleOptionsPairs";
    var _RGROPL = "RuleGroupRuleOptionsPairList";
    var _RGROPu = "RuleGroupRuleOptionsPair";
    var _RGT = "RuleGroupType";
    var _RGTP = "RuleGroupTypePairs";
    var _RGTPL = "RuleGroupTypePairList";
    var _RGTPu = "RuleGroupTypePair";
    var _RH = "ReleaseHosts";
    var _RHIL = "RequestHostIdList";
    var _RHILe = "ResponseHostIdList";
    var _RHIS = "RequestHostIdSet";
    var _RHISe = "ResponseHostIdSet";
    var _RHR = "ReleaseHostsRequest";
    var _RHRe = "ReleaseHostsResult";
    var _RHS = "RequireHibernateSupport";
    var _RI = "ReportId";
    var _RIA = "ResetImageAttribute";
    var _RIAR = "ResetImageAttributeRequest";
    var _RIARe = "ResetInstanceAttributeRequest";
    var _RIAe = "ResetInstanceAttribute";
    var _RIC = "ReservedInstancesConfiguration";
    var _RICIAIS = "ReplaceImageCriteriaInAllowedImagesSettings";
    var _RICIAISR = "ReplaceImageCriteriaInAllowedImagesSettingsRequest";
    var _RICIAISRe = "ReplaceImageCriteriaInAllowedImagesSettingsResult";
    var _RICL = "ReservedInstancesConfigurationList";
    var _RICSIT = "ReservedInstancesConfigurationSetItemType";
    var _RID = "RouteInstallationDetails";
    var _RIENA = "RegisterInstanceEventNotificationAttributes";
    var _RIENAR = "RegisterInstanceEventNotificationAttributesRequest";
    var _RIENARe = "RegisterInstanceEventNotificationAttributesResult";
    var _RIFRB = "RestoreImageFromRecycleBin";
    var _RIFRBR = "RestoreImageFromRecycleBinRequest";
    var _RIFRBRe = "RestoreImageFromRecycleBinResult";
    var _RII = "ReservedInstanceIds";
    var _RIIPA = "ReplaceIamInstanceProfileAssociation";
    var _RIIPAR = "ReplaceIamInstanceProfileAssociationRequest";
    var _RIIPARe = "ReplaceIamInstanceProfileAssociationResult";
    var _RIIS = "ReservedInstanceIdSet";
    var _RIISL = "ReservedInstancesIdStringList";
    var _RIIe = "ReservedInstanceId";
    var _RIIes = "ReservedInstancesId";
    var _RIIese = "ReservedInstancesIds";
    var _RIIeser = "ReservedIntancesIds";
    var _RIL = "ReservedInstancesListings";
    var _RILI = "ReservedInstancesListingId";
    var _RILL = "ReservedInstancesListingList";
    var _RILP = "ReservedInstanceLimitPrice";
    var _RILe = "ReservedInstancesListing";
    var _RILeg = "RegisteredInstanceList";
    var _RILes = "ReservedInstancesList";
    var _RIM = "ReservedInstancesModifications";
    var _RIMC = "ReservationInstanceMatchCriteria";
    var _RIME = "RunInstancesMonitoringEnabled";
    var _RIMI = "ReservedInstancesModificationIds";
    var _RIMISL = "ReservedInstancesModificationIdStringList";
    var _RIMIe = "ReservedInstancesModificationId";
    var _RIML = "ReservedInstancesModificationList";
    var _RIMR = "ReservedInstancesModificationResult";
    var _RIMRL = "ReservedInstancesModificationResultList";
    var _RIMe = "ReservedInstancesModification";
    var _RINC = "RemoteIpv4NetworkCidr";
    var _RINCe = "RemoteIpv6NetworkCidr";
    var _RIO = "ReservedInstancesOfferings";
    var _RIOI = "ReservedInstancesOfferingIds";
    var _RIOIe = "ReservedInstancesOfferingId";
    var _RIOL = "ReservedInstancesOfferingList";
    var _RIOR = "RemoveIpamOperatingRegion";
    var _RIORS = "RemoveIpamOperatingRegionSet";
    var _RIOUE = "RemoveIpamOrganizationalUnitExclusion";
    var _RIOUES = "RemoveIpamOrganizationalUnitExclusionSet";
    var _RIOe = "ReservedInstancesOffering";
    var _RIPA = "ReleaseIpamPoolAllocation";
    var _RIPAR = "ReleaseIpamPoolAllocationRequest";
    var _RIPARe = "ReleaseIpamPoolAllocationResult";
    var _RIR = "RebootInstancesRequest";
    var _RIRT = "RequestIpamResourceTag";
    var _RIRTL = "RequestIpamResourceTagList";
    var _RIRV = "ReservedInstanceReservationValue";
    var _RIRVS = "ReservedInstanceReservationValueSet";
    var _RIRe = "RegisterImageRequest";
    var _RIReg = "RegisterImageResult";
    var _RIRu = "RunInstancesRequest";
    var _RIS = "RouteInstallationStatus";
    var _RISR = "ReportInstanceStatusRequest";
    var _RISRD = "ReportInstanceStatusRequestDescription";
    var _RISRo = "RouteInstallationStatusReason";
    var _RISe = "ReportInstanceStatus";
    var _RITAR = "RegisterInstanceTagAttributeRequest";
    var _RIUD = "RunInstancesUserData";
    var _RIVR = "ReservedInstanceValueRollup";
    var _RIVS = "ReservedInstanceValueSet";
    var _RIa = "RamdiskId";
    var _RIe = "ReservationId";
    var _RIeb = "RebootInstances";
    var _RIeg = "RegisteredInstance";
    var _RIegi = "RegisterImage";
    var _RIep = "ReportIds";
    var _RIeq = "RequesterId";
    var _RIes = "ResourceIds";
    var _RIese = "ReservedInstances";
    var _RIeso = "ResourceId";
    var _RIu = "RunInstances";
    var _RL = "RegionList";
    var _RLTD = "RequestLaunchTemplateData";
    var _RLTDe = "ResponseLaunchTemplateData";
    var _RLe = "ReservationList";
    var _RLes = "ResourceList";
    var _RLo = "RouteList";
    var _RM = "ReasonMessage";
    var _RMAI = "RemoveMiddleboxAttachmentIds";
    var _RMAIe = "RemoveMiddleboxAttachmentId";
    var _RMGM = "RegisteredMulticastGroupMembers";
    var _RMGS = "RegisteredMulticastGroupSources";
    var _RMPLV = "RestoreManagedPrefixListVersion";
    var _RMPLVR = "RestoreManagedPrefixListVersionRequest";
    var _RMPLVRe = "RestoreManagedPrefixListVersionResult";
    var _RMS = "RebootMigrationSupport";
    var _RMTS = "RekeyMarginTimeSeconds";
    var _RMe = "RebootMigration";
    var _RMeq = "RequesterManaged";
    var _RN = "RegionName";
    var _RNAA = "ReplaceNetworkAclAssociation";
    var _RNAAR = "ReplaceNetworkAclAssociationRequest";
    var _RNAARe = "ReplaceNetworkAclAssociationResult";
    var _RNAE = "ReplaceNetworkAclEntry";
    var _RNAER = "ReplaceNetworkAclEntryRequest";
    var _RNIA = "ResetNetworkInterfaceAttribute";
    var _RNIAR = "ResetNetworkInterfaceAttributeRequest";
    var _RNII = "RegisteredNetworkInterfaceIds";
    var _RNLBA = "RemoveNetworkLoadBalancerArns";
    var _RNLBAe = "RemoveNetworkLoadBalancerArn";
    var _RNS = "RemoveNetworkServices";
    var _RNSL = "RegionNameStringList";
    var _RNSe = "RemoveNetworkService";
    var _RNe = "RegionNames";
    var _RNes = "ResourceName";
    var _RNo = "RoleName";
    var _RNu = "RuleNumber";
    var _RO = "RuleOptions";
    var _ROI = "ResourceOwnerId";
    var _ROL = "RuleOptionList";
    var _ROR = "RemoveOperatingRegions";
    var _RORe = "RemoveOperatingRegion";
    var _ROS = "ResourceOverlapStatus";
    var _ROUE = "RemoveOrganizationalUnitExclusions";
    var _ROUEe = "RemoveOrganizationalUnitExclusion";
    var _ROd = "RdsOptions";
    var _ROe = "ResourceOwner";
    var _ROo = "RouteOrigin";
    var _ROu = "RuleOption";
    var _RP = "ResetPolicy";
    var _RPC = "ReturnPathComponents";
    var _RPCO = "RequesterPeeringConnectionOptions";
    var _RPDN = "RemovePrivateDnsName";
    var _RPLE = "RemovePrefixListEntry";
    var _RPLEe = "RemovePrefixListEntries";
    var _RR = "ResourceRegion";
    var _RRR = "ReplaceRouteRequest";
    var _RRTA = "ReplaceRouteTableAssociation";
    var _RRTAR = "ReplaceRouteTableAssociationRequest";
    var _RRTARe = "ReplaceRouteTableAssociationResult";
    var _RRTI = "RemoveRouteTableIds";
    var _RRTIe = "RemoveRouteTableId";
    var _RRVT = "ReplaceRootVolumeTask";
    var _RRVTI = "ReplaceRootVolumeTaskIds";
    var _RRVTIe = "ReplaceRootVolumeTaskId";
    var _RRVTe = "ReplaceRootVolumeTasks";
    var _RRe = "ReplaceRoute";
    var _RS = "RegionalSummaries";
    var _RSA = "RouteServerAssociation";
    var _RSAL = "RouteServerAssociationsList";
    var _RSAR = "ResetSnapshotAttributeRequest";
    var _RSAe = "ResetSnapshotAttribute";
    var _RSAo = "RouteServerAssociations";
    var _RSBO = "RouteServerBgpOptions";
    var _RSBOR = "RouteServerBgpOptionsRequest";
    var _RSBS = "RouteServerBfdStatus";
    var _RSBSo = "RouteServerBgpStatus";
    var _RSE = "RouteServerEndpoint";
    var _RSEI = "RouteServerEndpointId";
    var _RSEIo = "RouteServerEndpointIds";
    var _RSEL = "RouteServerEndpointsList";
    var _RSEo = "RouteServerEndpoints";
    var _RSF = "RequestSpotFleet";
    var _RSFR = "RequestSpotFleetRequest";
    var _RSFRB = "RestoreSnapshotFromRecycleBin";
    var _RSFRBR = "RestoreSnapshotFromRecycleBinRequest";
    var _RSFRBRe = "RestoreSnapshotFromRecycleBinResult";
    var _RSFRe = "RequestSpotFleetResponse";
    var _RSG = "ReferencedSecurityGroup";
    var _RSGE = "RevokeSecurityGroupEgress";
    var _RSGER = "RevokeSecurityGroupEgressRequest";
    var _RSGERe = "RevokeSecurityGroupEgressResult";
    var _RSGI = "RemoveSecurityGroupIds";
    var _RSGIR = "RevokeSecurityGroupIngressRequest";
    var _RSGIRe = "RevokeSecurityGroupIngressResult";
    var _RSGIe = "RemoveSecurityGroupId";
    var _RSGIev = "RevokeSecurityGroupIngress";
    var _RSGR = "RevokedSecurityGroupRule";
    var _RSGRL = "RevokedSecurityGroupRuleList";
    var _RSGRe = "RevokedSecurityGroupRules";
    var _RSI = "RouteServerId";
    var _RSIAT = "RemoveSupportedIpAddressTypes";
    var _RSIATe = "RemoveSupportedIpAddressType";
    var _RSIR = "RequestSpotInstancesRequest";
    var _RSIRe = "RequestSpotInstancesResult";
    var _RSIRu = "RunScheduledInstancesRequest";
    var _RSIRun = "RunScheduledInstancesResult";
    var _RSIe = "RemoveSubnetIds";
    var _RSIem = "RemoveSubnetId";
    var _RSIeq = "RequestSpotInstances";
    var _RSIo = "RouteServerIds";
    var _RSIu = "RunScheduledInstances";
    var _RSL = "RegionalSummaryList";
    var _RSLS = "RequestSpotLaunchSpecification";
    var _RSLSSGIL = "RequestSpotLaunchSpecificationSecurityGroupIdList";
    var _RSLSSGL = "RequestSpotLaunchSpecificationSecurityGroupList";
    var _RSLo = "RouteServersList";
    var _RSP = "RouteServerPeer";
    var _RSPI = "RouteServerPeerId";
    var _RSPIo = "RouteServerPeerIds";
    var _RSPL = "RouteServerPeersList";
    var _RSPLo = "RouteServerPropagationsList";
    var _RSPo = "RouteServerPeers";
    var _RSPou = "RouteServerPropagation";
    var _RSPout = "RouteServerPropagations";
    var _RSR = "RemoveSupportedRegions";
    var _RSRID = "RouteServerRouteInstallationDetail";
    var _RSRIDo = "RouteServerRouteInstallationDetails";
    var _RSRL = "RouteServerRouteList";
    var _RSRe = "RemoveSupportedRegion";
    var _RSRes = "ResourceStatementRequest";
    var _RSRo = "RouteServerRoute";
    var _RST = "ReservationStartTimestamp";
    var _RSTR = "RestoreSnapshotTierRequest";
    var _RSTRe = "RestoreSnapshotTierResult";
    var _RSTe = "RestoreStartTime";
    var _RSTes = "RestoreSnapshotTier";
    var _RSe = "ReservationState";
    var _RSeg = "RegionalSummary";
    var _RSep = "ReplacementStrategy";
    var _RSes = "ResourceStatement";
    var _RSo = "RouteServer";
    var _RSou = "RouteServers";
    var _RSout = "RouteStatus";
    var _RT13 = "ReservationType";
    var _RTA = "RouteTableAssociation";
    var _RTAI = "RouteTableAssociationId";
    var _RTAL = "RouteTableAssociationList";
    var _RTAS = "RouteTableAssociationState";
    var _RTGCB = "RemoveTransitGatewayCidrBlocks";
    var _RTGCVA = "RejectTransitGatewayClientVpnAttachment";
    var _RTGCVAR = "RejectTransitGatewayClientVpnAttachmentRequest";
    var _RTGCVARe = "RejectTransitGatewayClientVpnAttachmentResult";
    var _RTGMDA = "RejectTransitGatewayMulticastDomainAssociations";
    var _RTGMDAR = "RejectTransitGatewayMulticastDomainAssociationsRequest";
    var _RTGMDARe = "RejectTransitGatewayMulticastDomainAssociationsResult";
    var _RTGMGM = "RegisterTransitGatewayMulticastGroupMembers";
    var _RTGMGMR = "RegisterTransitGatewayMulticastGroupMembersRequest";
    var _RTGMGMRe = "RegisterTransitGatewayMulticastGroupMembersResult";
    var _RTGMGS = "RegisterTransitGatewayMulticastGroupSources";
    var _RTGMGSR = "RegisterTransitGatewayMulticastGroupSourcesRequest";
    var _RTGMGSRe = "RegisterTransitGatewayMulticastGroupSourcesResult";
    var _RTGPA = "RejectTransitGatewayPeeringAttachment";
    var _RTGPAR = "RejectTransitGatewayPeeringAttachmentRequest";
    var _RTGPARe = "RejectTransitGatewayPeeringAttachmentResult";
    var _RTGR = "ReplaceTransitGatewayRoute";
    var _RTGRR = "ReplaceTransitGatewayRouteRequest";
    var _RTGRRe = "ReplaceTransitGatewayRouteResult";
    var _RTGVA = "RejectTransitGatewayVpcAttachment";
    var _RTGVAR = "RejectTransitGatewayVpcAttachmentRequest";
    var _RTGVARe = "RejectTransitGatewayVpcAttachmentResult";
    var _RTI = "RouteTableId";
    var _RTISL = "RouteTableIdStringList";
    var _RTIe = "RequesterTgwInfo";
    var _RTIo = "RouteTableIds";
    var _RTL = "ReservationTypeList";
    var _RTLR = "ReservationTypeListRequest";
    var _RTLo = "RouteTableList";
    var _RTO = "ResourceTypeOptions";
    var _RTOL = "ResourceTypeOptionList";
    var _RTOe = "ResourceTypeOption";
    var _RTR = "RouteTableRoute";
    var _RTRL = "ResourceTypeRequestList";
    var _RTRe = "ResourceTypeRequest";
    var _RTV = "RemainingTotalValue";
    var _RTe = "ResourceType";
    var _RTel = "ReleaseTime";
    var _RTeq = "RequestTime";
    var _RTes = "ResourceTypes";
    var _RTese = "ReservationTypes";
    var _RTeso = "ResourceTag";
    var _RTesou = "ResourceTags";
    var _RTo = "RouteTable";
    var _RTou = "RouteTables";
    var _RTu = "RuleType";
    var _RUFO = "ReservationUnusedFinancialOwner";
    var _RUI = "ReplaceUnhealthyInstances";
    var _RUV = "RemainingUpfrontValue";
    var _RV = "ReturnValue";
    var _RVEC = "RejectVpcEndpointConnections";
    var _RVECR = "RejectVpcEndpointConnectionsRequest";
    var _RVECRe = "RejectVpcEndpointConnectionsResult";
    var _RVFRB = "RestoreVolumeFromRecycleBin";
    var _RVFRBR = "RestoreVolumeFromRecycleBinRequest";
    var _RVFRBRe = "RestoreVolumeFromRecycleBinResult";
    var _RVI = "ReferencingVpcId";
    var _RVIe = "RequesterVpcInfo";
    var _RVPC = "RejectVpcPeeringConnection";
    var _RVPCR = "RejectVpcPeeringConnectionRequest";
    var _RVPCRe = "RejectVpcPeeringConnectionResult";
    var _RVT = "ReplaceVpnTunnel";
    var _RVTR = "ReplaceVpnTunnelRequest";
    var _RVTRe = "ReplaceVpnTunnelResult";
    var _RVe = "ReservationValue";
    var _RWS = "ReplayWindowSize";
    var _Ra = "Ramdisk";
    var _Re = "References";
    var _Rea = "Reason";
    var _Rec = "Recurrence";
    var _Ref = "Reference";
    var _Reg = "Regions";
    var _Regi = "Region";
    var _Rem = "Remove";
    var _Rep = "Reports";
    var _Req = "Requested";
    var _Res = "Resources";
    var _Rese = "Reservations";
    var _Reser = "Reservation";
    var _Reso = "Resource";
    var _Resu = "Result";
    var _Ro = "Route";
    var _Rol = "Role";
    var _Rou = "Routes";
    var _Ru = "Rules";
    var _Rul = "Rule";
    var _S = "Source";
    var _SA = "SourceAddresses";
    var _SAI = "SecondaryAllocationIds";
    var _SAIe = "SecondaryAllocationId";
    var _SAL = "SubnetAssociationList";
    var _SAMLPA = "SAMLProviderArn";
    var _SAPFL = "SupportedAdditionalProcessorFeatureList";
    var _SAZ = "SingleAvailabilityZone";
    var _SAo = "SourceArn";
    var _SAou = "SourceAddress";
    var _SAt = "StartupAction";
    var _SAu = "SuggestedAccounts";
    var _SAub = "SubnetArn";
    var _SAubn = "SubnetAssociation";
    var _SAup = "SupportedArchitectures";
    var _SB = "S3Bucket";
    var _SBM = "SupportedBootModes";
    var _SBN = "S3BucketName";
    var _SBP = "S3BucketPrefix";
    var _SC = "SubnetConfigurations";
    var _SCA = "ServerCertificateArn";
    var _SCAE = "SerialConsoleAccessEnabled";
    var _SCB = "SourceCidrBlock";
    var _SCBS = "SubnetCidrBlockState";
    var _SCCDM = "SnapshotCopyCompletionDurationMinutes";
    var _SCL = "SubnetConfigurationsList";
    var _SCR = "SourceCapacityReservation";
    var _SCRI = "SourceCapacityReservationId";
    var _SCRIu = "SubnetCidrReservationId";
    var _SCRL = "SubnetCidrReservationList";
    var _SCRp = "SpotCapacityRebalance";
    var _SCRu = "SubnetCidrReservation";
    var _SCS = "ServiceConfigurationSet";
    var _SCSIG = "SustainedClockSpeedInGhz";
    var _SCc = "ScopeCount";
    var _SCe = "ServiceConfiguration";
    var _SCer = "ServiceConfigurations";
    var _SCn = "SnapshotConfiguration";
    var _SCt = "StaticCidr";
    var _SCu = "SubnetConfiguration";
    var _SD = "StartDate";
    var _SDC = "SourceDestCheck";
    var _SDCn = "SnapshotDiskContainer";
    var _SDI = "SendDiagnosticInterrupt";
    var _SDIH = "SlotDurationInHours";
    var _SDIR = "SendDiagnosticInterruptRequest";
    var _SDL = "SnapshotDetailList";
    var _SDLTV = "SuccessfullyDeletedLaunchTemplateVersions";
    var _SDPR = "StartDeclarativePoliciesReport";
    var _SDPRR = "StartDeclarativePoliciesReportRequest";
    var _SDPRRt = "StartDeclarativePoliciesReportResult";
    var _SDR = "StartDateRange";
    var _SDS = "SpotDatafeedSubscription";
    var _SDSe = "ServiceDetailSet";
    var _SDTRR = "SlotDateTimeRangeRequest";
    var _SDV = "SetDefaultVersion";
    var _SDe = "ServiceDetails";
    var _SDer = "ServiceDetail";
    var _SDn = "SnapshotDetails";
    var _SDna = "SnapshotDetail";
    var _SDp = "SpreadDomain";
    var _SDu = "SubDomain";
    var _SEL = "S3ExportLocation";
    var _SET = "SampledEndTime";
    var _SF = "SupportedFeatures";
    var _SFC = "SuccessfulFleetCancellations";
    var _SFD = "SuccessfulFleetDeletions";
    var _SFII = "SourceFpgaImageId";
    var _SFLS = "SpotFleetLaunchSpecification";
    var _SFM = "SpotFleetMonitoring";
    var _SFR = "SuccessfulFleetRequests";
    var _SFRC = "SpotFleetRequestConfigs";
    var _SFRCD = "SpotFleetRequestConfigData";
    var _SFRCS = "SpotFleetRequestConfigSet";
    var _SFRCp = "SpotFleetRequestConfig";
    var _SFRI = "SpotFleetRequestId";
    var _SFRIL = "SpotFleetRequestIdList";
    var _SFRIp = "SpotFleetRequestIds";
    var _SFRS = "SpotFleetRequestState";
    var _SFTS = "SpotFleetTagSpecification";
    var _SFTSL = "SpotFleetTagSpecificationList";
    var _SG = "SubGeography";
    var _SGA = "SecurityGroupArn";
    var _SGFV = "SecurityGroupForVpcs";
    var _SGFVL = "SecurityGroupForVpcList";
    var _SGFVe = "SecurityGroupForVpc";
    var _SGI = "SecurityGroupId";
    var _SGIL = "SecurityGroupIdList";
    var _SGIS = "SecurityGroupIdSet";
    var _SGISL = "SecurityGroupIdStringList";
    var _SGISLR = "SecurityGroupIdStringListRequest";
    var _SGIe = "SecurityGroupIds";
    var _SGIec = "SecurityGroupIdentifier";
    var _SGL = "SecurityGroupList";
    var _SGR = "SecurityGroupRules";
    var _SGRA = "SecurityGroupRuleArn";
    var _SGRD = "SecurityGroupRuleDescription";
    var _SGRDL = "SecurityGroupRuleDescriptionList";
    var _SGRDe = "SecurityGroupRuleDescriptions";
    var _SGRI = "SecurityGroupRuleIds";
    var _SGRIL = "SecurityGroupRuleIdList";
    var _SGRIe = "SecurityGroupRuleId";
    var _SGRL = "SecurityGroupRuleList";
    var _SGRR = "SecurityGroupRuleRequest";
    var _SGRS = "SecurityGroupReferencingSupport";
    var _SGRSe = "SecurityGroupReferenceSet";
    var _SGRU = "SecurityGroupRuleUpdate";
    var _SGRUL = "SecurityGroupRuleUpdateList";
    var _SGRe = "SecurityGroupRule";
    var _SGRec = "SecurityGroupReference";
    var _SGRecu = "SecurityGroupReferences";
    var _SGSL = "SecurityGroupStringList";
    var _SGVA = "SecurityGroupVpcAssociations";
    var _SGVAL = "SecurityGroupVpcAssociationList";
    var _SGVAe = "SecurityGroupVpcAssociation";
    var _SGe = "SecurityGroups";
    var _SGec = "SecurityGroup";
    var _SH = "StartHour";
    var _SI10 = "SubnetIds";
    var _SIA = "ScheduledInstanceAvailability";
    var _SIAS = "ScheduledInstanceAvailabilitySet";
    var _SIAT = "SupportedIpAddressTypes";
    var _SIATu = "SupportedIpAddressType";
    var _SIAe = "SecondaryInterfaceArn";
    var _SIAec = "SecondaryInterfaceAttachment";
    var _SIBDM = "ScheduledInstancesBlockDeviceMapping";
    var _SIBDMS = "ScheduledInstancesBlockDeviceMappingSet";
    var _SICBA = "SubnetIpv6CidrBlockAssociation";
    var _SICBAS = "SubnetIpv6CidrBlockAssociationSet";
    var _SICR = "SubnetIpv4CidrReservations";
    var _SICRu = "SubnetIpv6CidrReservations";
    var _SICS = "SuccessfulInstanceCreditSpecifications";
    var _SICSI = "SuccessfulInstanceCreditSpecificationItem";
    var _SICSS = "SuccessfulInstanceCreditSpecificationSet";
    var _SIE = "ScheduledInstancesEbs";
    var _SIGB = "SizeInGB";
    var _SII = "SourceImageId";
    var _SIIA = "ScheduledInstancesIpv6Address";
    var _SIIAL = "ScheduledInstancesIpv6AddressList";
    var _SIIALe = "SecondaryInterfaceIpv4AddressList";
    var _SIIAe = "SecondaryInterfaceIpv4Address";
    var _SIIIP = "ScheduledInstancesIamInstanceProfile";
    var _SIIL = "SecondaryInterfaceIdList";
    var _SIIRS = "ScheduledInstanceIdRequestSet";
    var _SIIc = "ScheduledInstanceIds";
    var _SIIch = "ScheduledInstanceId";
    var _SIIe = "SecondaryInterfaceIds";
    var _SIIec = "SecondaryInterfaceId";
    var _SIIo = "SourceInstanceId";
    var _SIL = "SecondaryInterfaceList";
    var _SILS = "ScheduledInstancesLaunchSpecification";
    var _SILu = "SubnetIdList";
    var _SIM = "ScheduledInstancesMonitoring";
    var _SIMB = "SizeInMiB";
    var _SINI = "ScheduledInstancesNetworkInterface";
    var _SINIS = "ScheduledInstancesNetworkInterfaceSet";
    var _SIP = "ScheduledInstancesPlacement";
    var _SIPE = "StaleIpPermissionsEgress";
    var _SIPI = "SourceIpamPoolId";
    var _SIPIAC = "ScheduledInstancesPrivateIpAddressConfig";
    var _SIPIAS = "SecondaryInterfacePrivateIpAddressSpecification";
    var _SIPIASL = "SecondaryInterfacePrivateIpAddressSpecificationList";
    var _SIPIASLR = "SecondaryInterfacePrivateIpAddressSpecificationListRequest";
    var _SIPIASR = "SecondaryInterfacePrivateIpAddressSpecificationRequest";
    var _SIPL = "SubnetIpPrefixesList";
    var _SIPS = "StaleIpPermissionSet";
    var _SIPt = "StaleIpPermission";
    var _SIPta = "StaleIpPermissions";
    var _SIPu = "SubnetIpPrefixes";
    var _SIR = "SpotInstanceRequests";
    var _SIRI = "SpotInstanceRequestId";
    var _SIRIL = "SpotInstanceRequestIdList";
    var _SIRIp = "SpotInstanceRequestIds";
    var _SIRL = "SpotInstanceRequestList";
    var _SIRR = "ScheduledInstanceRecurrenceRequest";
    var _SIRc = "ScheduledInstanceRecurrence";
    var _SIRo = "SourceImageRegion";
    var _SIRp = "SpotInstanceRequest";
    var _SIRt = "StartInstancesRequest";
    var _SIRta = "StartInstancesResult";
    var _SIRto = "StopInstancesRequest";
    var _SIRtop = "StopInstancesResult";
    var _SIS = "ScheduledInstanceSet";
    var _SISF = "SpotInstanceStateFault";
    var _SISGIS = "ScheduledInstancesSecurityGroupIdSet";
    var _SISL = "SnapshotIdStringList";
    var _SISLu = "SubnetIdStringList";
    var _SISp = "SpotInstanceStatus";
    var _SIT = "SpotInstanceType";
    var _SITR = "StoreImageTaskResults";
    var _SITRS = "StoreImageTaskResultSet";
    var _SITRt = "StoreImageTaskResult";
    var _SITe = "SecondaryInterfaceType";
    var _SITi = "SingleInstanceType";
    var _SIc = "ScheduledInstance";
    var _SIe = "ServiceId";
    var _SIec = "SecondaryInterfaces";
    var _SIeco = "SecondaryInterface";
    var _SIer = "ServiceIds";
    var _SIn = "SnapshotId";
    var _SIna = "SnapshotIds";
    var _SInap = "SnapshotInfo";
    var _SIo = "SourceIp";
    var _SIt = "StartingInstances";
    var _SIta = "StartInstances";
    var _SIto = "StoppingInstances";
    var _SItop = "StopInstances";
    var _SIu = "SubnetId";
    var _SIub = "SubsystemId";
    var _SK2 = "S3Key";
    var _SKo = "S3objectKey";
    var _SL = "SnapshotLocation";
    var _SLGR = "SearchLocalGatewayRoutes";
    var _SLGRR = "SearchLocalGatewayRoutesRequest";
    var _SLGRRe = "SearchLocalGatewayRoutesResult";
    var _SLVI = "ServiceLinkVirtualInterfaces";
    var _SLVIA = "ServiceLinkVirtualInterfaceArn";
    var _SLVII = "ServiceLinkVirtualInterfaceIds";
    var _SLVIIS = "ServiceLinkVirtualInterfaceIdSet";
    var _SLVIIe = "ServiceLinkVirtualInterfaceId";
    var _SLVIS = "ServiceLinkVirtualInterfaceSet";
    var _SLVIe = "ServiceLinkVirtualInterface";
    var _SLn = "SnapshotList";
    var _SLo = "S3Location";
    var _SLp = "SpreadLevel";
    var _SLt = "StorageLocation";
    var _SLtr = "StringList";
    var _SLu = "SubnetList";
    var _SLub = "SubscriptionList";
    var _SM = "ServiceManaged";
    var _SMC = "SensitiveMacCredentials";
    var _SMO = "SpotMarketOptions";
    var _SMPPOLP = "SpotMaxPricePercentageOverLowestPrice";
    var _SMS = "SpotMaintenanceStrategies";
    var _SMTP = "SpotMaxTotalPrice";
    var _SMt = "StatusMessage";
    var _SMta = "StateMessage";
    var _SN10 = "ServiceName";
    var _SNA = "ServiceNetworkArn";
    var _SNAe = "SecondaryNetworkArn";
    var _SNE = "SnsNotificationsEnabled";
    var _SNI = "SecondaryNetworkId";
    var _SNIA = "StartNetworkInsightsAnalysis";
    var _SNIAR = "StartNetworkInsightsAnalysisRequest";
    var _SNIARt = "StartNetworkInsightsAnalysisResult";
    var _SNIASA = "StartNetworkInsightsAccessScopeAnalysis";
    var _SNIASAR = "StartNetworkInsightsAccessScopeAnalysisRequest";
    var _SNIASARt = "StartNetworkInsightsAccessScopeAnalysisResult";
    var _SNICBA = "SecondaryNetworkIpv4CidrBlockAssociation";
    var _SNICBAL = "SecondaryNetworkIpv4CidrBlockAssociationList";
    var _SNIL = "SecondaryNetworkIdList";
    var _SNIe = "SecondaryNetworkIds";
    var _SNL = "SecondaryNetworkList";
    var _SNN = "ServiceNetworkName";
    var _SNS = "SriovNetSupport";
    var _SNSe = "SecondaryNetworkSupported";
    var _SNT = "SecondaryNetworkType";
    var _SNe = "SecondaryNetwork";
    var _SNec = "SecondaryNetworks";
    var _SNeq = "SequenceNumber";
    var _SNer = "ServiceNames";
    var _SNes = "SessionNumber";
    var _SO = "SpotOptions";
    var _SOR = "SpotOptionsRequest";
    var _SOS = "SkipOsShutdown";
    var _SOT = "S3ObjectTags";
    var _SOTL = "S3ObjectTagList";
    var _SOTb = "S3ObjectTag";
    var _SP = "S3Prefix";
    var _SPA = "SamlProviderArn";
    var _SPH = "SpotPriceHistory";
    var _SPHL = "SpotPriceHistoryList";
    var _SPI = "ServicePermissionId";
    var _SPIA = "SecondaryPrivateIpAddresses";
    var _SPIAC = "SecondaryPrivateIpAddressCount";
    var _SPIAe = "SecondaryPrivateIpAddress";
    var _SPL = "SourcePrefixLists";
    var _SPLo = "SourcePrefixList";
    var _SPR = "SourcePortRanges";
    var _SPRo = "SourcePortRange";
    var _SPS = "SpotPlacementScores";
    var _SPSp = "SpotPlacementScore";
    var _SPo = "SourcePorts";
    var _SPou = "SourcePort";
    var _SPp = "SpotPrice";
    var _SPpo = "SpotPlacement";
    var _SQPD = "SuccessfulQueuedPurchaseDeletions";
    var _SQPDS = "SuccessfulQueuedPurchaseDeletionSet";
    var _SQPDu = "SuccessfulQueuedPurchaseDeletion";
    var _SR = "ServiceRegion";
    var _SRBI = "SnapshotRecycleBinInfo";
    var _SRBIL = "SnapshotRecycleBinInfoList";
    var _SRD = "SupportedRegionDetail";
    var _SRDT = "SupportedRootDeviceTypes";
    var _SRO = "StaticRoutesOnly";
    var _SRS = "SupportedRegionSet";
    var _SRT = "SubnetRouteTable";
    var _SRe = "ServiceRegions";
    var _SRer = "ServiceResource";
    var _SRo = "SourceRegion";
    var _SRou = "SourceResource";
    var _SRt = "StateReason";
    var _SRu = "SupportedRegions";
    var _SRup = "SupportedRegion";
    var _SS = "SecondarySubnet";
    var _SSA = "SecondarySubnetArn";
    var _SSC = "SqlServerCredentials";
    var _SSG = "StaleSecurityGroup";
    var _SSGN = "SourceSecurityGroupName";
    var _SSGOI = "SourceSecurityGroupOwnerId";
    var _SSGS = "StaleSecurityGroupSet";
    var _SSI = "SourceSnapshotId";
    var _SSICBA = "SecondarySubnetIpv4CidrBlockAssociation";
    var _SSICBAL = "SecondarySubnetIpv4CidrBlockAssociationList";
    var _SSIL = "SecondarySubnetIdList";
    var _SSIe = "SecondarySubnetId";
    var _SSIec = "SecondarySubnetIds";
    var _SSIo = "SourceSnapshotIds";
    var _SSL = "SecondarySubnetList";
    var _SSLU = "SqlServerLicenseUsage";
    var _SSP = "SelfServicePortal";
    var _SSPU = "SelfServicePortalUrl";
    var _SSS = "StaticSourcesSupport";
    var _SSSAMLPA = "SelfServiceSAMLProviderArn";
    var _SSSPA = "SelfServiceSamlProviderArn";
    var _SST = "SampledStartTime";
    var _SSTR = "SlotStartTimeRange";
    var _SSTRR = "SlotStartTimeRangeRequest";
    var _SSUPS = "S3StorageUploadPolicySignature";
    var _SSe = "SecondarySubnets";
    var _SSer = "ServiceState";
    var _SSn = "SnapshotSet";
    var _SSs = "SseSpecification";
    var _SSt = "S3Storage";
    var _SSu = "SupportedStrategies";
    var _SSy = "SystemStatus";
    var _ST11 = "StartTime";
    var _STA = "SnsTopicArn";
    var _STC = "SpotTargetCapacity";
    var _STD = "SnapshotTaskDetail";
    var _STDS = "ServiceTypeDetailSet";
    var _STDe = "ServiceTypeDetail";
    var _STFR = "StoreTaskFailureReason";
    var _STGAI = "SourceTransitGatewayAttachmentId";
    var _STGAT = "SourceTransitGatewayAttachmentType";
    var _STGMG = "SearchTransitGatewayMulticastGroups";
    var _STGMGR = "SearchTransitGatewayMulticastGroupsRequest";
    var _STGMGRe = "SearchTransitGatewayMulticastGroupsResult";
    var _STGR = "SearchTransitGatewayRoutes";
    var _STGRR = "SearchTransitGatewayRoutesRequest";
    var _STGRRe = "SearchTransitGatewayRoutesResult";
    var _STH = "SessionTimeoutHours";
    var _STR = "StateTransitionReason";
    var _STRk = "SkipTunnelReplacement";
    var _STS = "SnapshotTierStatuses";
    var _STSn = "SnapshotTierStatus";
    var _STSt = "StoreTaskState";
    var _STT10 = "StateTransitionTime";
    var _STa = "SampleType";
    var _STam = "SampleTime";
    var _STe = "ServiceType";
    var _STo = "SourceType";
    var _STp = "SplitTunnel";
    var _STs = "SseType";
    var _STt = "StorageTier";
    var _SU = "SensitiveUrl";
    var _SUC = "SupportedUsageClasses";
    var _SUD = "SensitiveUserData";
    var _SV = "SourceVersion";
    var _SVESPDV = "StartVpcEndpointServicePrivateDnsVerification";
    var _SVESPDVR = "StartVpcEndpointServicePrivateDnsVerificationRequest";
    var _SVESPDVRt = "StartVpcEndpointServicePrivateDnsVerificationResult";
    var _SVI = "SourceVolumeId";
    var _SVIu = "SubsystemVendorId";
    var _SVT = "SupportedVirtualizationTypes";
    var _SVh = "ShellVersion";
    var _SVo = "SourceVpc";
    var _SVu = "SupportedVersions";
    var _SWD = "StartWeekDay";
    var _S_ = "S3";
    var _Sc = "Schedule";
    var _Sco = "Scope";
    var _Scop = "Scopes";
    var _Scor = "Score";
    var _Se = "Service";
    var _Set = "Settings";
    var _Si = "Signature";
    var _Siz = "Size";
    var _Sn = "Snapshots";
    var _Sna = "Snapshot";
    var _So = "Sources";
    var _Soc = "Sockets";
    var _Sof = "Software";
    var _St = "State";
    var _Sta = "Status";
    var _Star = "Start";
    var _Stat = "Statistic";
    var _Statu = "Statuses";
    var _Sto = "Storage";
    var _Str = "Strategy";
    var _Su = "Subnet";
    var _Sub = "Subscriptions";
    var _Subn = "Subnets";
    var _Subs = "Subscription";
    var _Suc = "Successful";
    var _Succ = "Success";
    var _T10 = "Tags";
    var _TAAC = "TotalAvailableAddressCount";
    var _TAC = "TotalAvailableCapacity";
    var _TACo = "TotalAddressCount";
    var _TAI = "TransferAccountId";
    var _TB = "TunnelBandwidth";
    var _TC10 = "TargetConfigurations";
    var _TCR = "TargetConfigurationRequest";
    var _TCRS = "TargetConfigurationRequestSet";
    var _TCS = "TargetCapacitySpecification";
    var _TCSR = "TargetCapacitySpecificationRequest";
    var _TCSS = "TerminateConnectionStatusSet";
    var _TCSe = "TerminateConnectionStatus";
    var _TCUT = "TargetCapacityUnitType";
    var _TCVC = "TerminateClientVpnConnections";
    var _TCVCR = "TerminateClientVpnConnectionsRequest";
    var _TCVCRe = "TerminateClientVpnConnectionsResult";
    var _TCVR = "TargetConfigurationValueRollup";
    var _TCVS = "TargetConfigurationValueSet";
    var _TCa = "TargetConfiguration";
    var _TCar = "TargetCapacity";
    var _TCo = "TotalCapacity";
    var _TD = "TrafficDirection";
    var _TDL = "TagDescriptionList";
    var _TDa = "TagDescription";
    var _TDe = "TerminationDelay";
    var _TE = "TargetEnvironment";
    var _TED = "TermEndDate";
    var _TET = "TcpEstablishedTimeout";
    var _TEo = "TokenEndpoint";
    var _TFC = "TotalFulfilledCapacity";
    var _TFMIMB = "TotalFpgaMemoryInMiB";
    var _TG = "TransitGateway";
    var _TGA = "TransitGatewayAddress";
    var _TGAA = "TransitGatewayAttachmentAssociation";
    var _TGABC = "TransitGatewayAttachmentBgpConfiguration";
    var _TGABCL = "TransitGatewayAttachmentBgpConfigurationList";
    var _TGAI = "TransitGatewayAttachmentId";
    var _TGAIr = "TransitGatewayAttachmentIds";
    var _TGAL = "TransitGatewayAttachmentList";
    var _TGAP = "TransitGatewayAttachmentPropagations";
    var _TGAPL = "TransitGatewayAttachmentPropagationList";
    var _TGAPr = "TransitGatewayAttachmentPropagation";
    var _TGAr = "TransitGatewayAttachments";
    var _TGAra = "TransitGatewayAttachment";
    var _TGAran = "TransitGatewayArn";
    var _TGArans = "TransitGatewayAssociation";
    var _TGAransi = "TransitGatewayAsn";
    var _TGC = "TransitGatewayConfiguration";
    var _TGCB = "TransitGatewayCidrBlocks";
    var _TGCBSL = "TransitGatewayCidrBlockStringList";
    var _TGCDES = "TransitGatewayConfigurationDescribeEndpointStructure";
    var _TGCIS = "TransitGatewayConfigurationInputStructure";
    var _TGCL = "TransitGatewayConnectList";
    var _TGCO = "TransitGatewayConnectOptions";
    var _TGCP = "TransitGatewayConnectPeer";
    var _TGCPC = "TransitGatewayConnectPeerConfiguration";
    var _TGCPI = "TransitGatewayConnectPeerId";
    var _TGCPISL = "TransitGatewayConnectPeerIdStringList";
    var _TGCPIr = "TransitGatewayConnectPeerIds";
    var _TGCPL = "TransitGatewayConnectPeerList";
    var _TGCPr = "TransitGatewayConnectPeers";
    var _TGCRBO = "TransitGatewayConnectRequestBgpOptions";
    var _TGCVA = "TransitGatewayClientVpnAttachment";
    var _TGCa = "TargetGroupsConfig";
    var _TGCr = "TransitGatewayConnect";
    var _TGCra = "TransitGatewayConnects";
    var _TGI = "TransitGatewayId";
    var _TGISL = "TransitGatewayIdStringList";
    var _TGIr = "TransitGatewayIds";
    var _TGL = "TransitGatewayList";
    var _TGMD = "TransitGatewayMulticastDomain";
    var _TGMDA = "TransitGatewayMulticastDomainArn";
    var _TGMDAL = "TransitGatewayMulticastDomainAssociationList";
    var _TGMDAr = "TransitGatewayMulticastDomainAssociation";
    var _TGMDAra = "TransitGatewayMulticastDomainAssociations";
    var _TGMDGM = "TransitGatewayMulticastDeregisteredGroupMembers";
    var _TGMDGS = "TransitGatewayMulticastDeregisteredGroupSources";
    var _TGMDI = "TransitGatewayMulticastDomainId";
    var _TGMDISL = "TransitGatewayMulticastDomainIdStringList";
    var _TGMDIr = "TransitGatewayMulticastDomainIds";
    var _TGMDL = "TransitGatewayMulticastDomainList";
    var _TGMDO = "TransitGatewayMulticastDomainOptions";
    var _TGMDr = "TransitGatewayMulticastDomains";
    var _TGMG = "TransitGatewayMulticastGroup";
    var _TGMGL = "TransitGatewayMulticastGroupList";
    var _TGMIMB = "TotalGpuMemoryInMiB";
    var _TGMP = "TransitGatewayMeteringPolicy";
    var _TGMPE = "TransitGatewayMeteringPolicyEntry";
    var _TGMPEL = "TransitGatewayMeteringPolicyEntryList";
    var _TGMPEr = "TransitGatewayMeteringPolicyEntries";
    var _TGMPI = "TransitGatewayMeteringPolicyId";
    var _TGMPISL = "TransitGatewayMeteringPolicyIdStringList";
    var _TGMPIr = "TransitGatewayMeteringPolicyIds";
    var _TGMPL = "TransitGatewayMeteringPolicyList";
    var _TGMPR = "TransitGatewayMeteringPolicyRule";
    var _TGMPr = "TransitGatewayMeteringPolicies";
    var _TGMRGM = "TransitGatewayMulticastRegisteredGroupMembers";
    var _TGMRGS = "TransitGatewayMulticastRegisteredGroupSources";
    var _TGNIIL = "TransitGatewayNetworkInterfaceIdList";
    var _TGO = "TransitGatewayOptions";
    var _TGOI = "TransitGatewayOwnerId";
    var _TGP = "TransitGatewayPropagation";
    var _TGPA = "TransitGatewayPeeringAttachment";
    var _TGPAL = "TransitGatewayPeeringAttachmentList";
    var _TGPAO = "TransitGatewayPeeringAttachmentOptions";
    var _TGPAr = "TransitGatewayPeeringAttachments";
    var _TGPLA = "TransitGatewayPrefixListAttachment";
    var _TGPLR = "TransitGatewayPrefixListReference";
    var _TGPLRS = "TransitGatewayPrefixListReferenceSet";
    var _TGPLRr = "TransitGatewayPrefixListReferences";
    var _TGPR = "TransitGatewayPolicyRule";
    var _TGPRMD = "TransitGatewayPolicyRuleMetaData";
    var _TGPT = "TransitGatewayPolicyTable";
    var _TGPTA = "TransitGatewayPolicyTableAssociation";
    var _TGPTAL = "TransitGatewayPolicyTableAssociationList";
    var _TGPTE = "TransitGatewayPolicyTableEntries";
    var _TGPTEL = "TransitGatewayPolicyTableEntryList";
    var _TGPTEr = "TransitGatewayPolicyTableEntry";
    var _TGPTI = "TransitGatewayPolicyTableId";
    var _TGPTISL = "TransitGatewayPolicyTableIdStringList";
    var _TGPTIr = "TransitGatewayPolicyTableIds";
    var _TGPTL = "TransitGatewayPolicyTableList";
    var _TGPTr = "TransitGatewayPolicyTables";
    var _TGR = "TransitGatewayRoute";
    var _TGRA = "TransitGatewayRouteAttachment";
    var _TGRAL = "TransitGatewayRouteAttachmentList";
    var _TGRL = "TransitGatewayRouteList";
    var _TGRO = "TransitGatewayRequestOptions";
    var _TGRT = "TransitGatewayRouteTable";
    var _TGRTA = "TransitGatewayRouteTableAnnouncement";
    var _TGRTAI = "TransitGatewayRouteTableAnnouncementId";
    var _TGRTAISL = "TransitGatewayRouteTableAnnouncementIdStringList";
    var _TGRTAIr = "TransitGatewayRouteTableAnnouncementIds";
    var _TGRTAL = "TransitGatewayRouteTableAnnouncementList";
    var _TGRTALr = "TransitGatewayRouteTableAssociationList";
    var _TGRTAr = "TransitGatewayRouteTableAnnouncements";
    var _TGRTAra = "TransitGatewayRouteTableAssociation";
    var _TGRTI = "TransitGatewayRouteTableId";
    var _TGRTISL = "TransitGatewayRouteTableIdStringList";
    var _TGRTIr = "TransitGatewayRouteTableIds";
    var _TGRTL = "TransitGatewayRouteTableList";
    var _TGRTP = "TransitGatewayRouteTablePropagations";
    var _TGRTPL = "TransitGatewayRouteTablePropagationList";
    var _TGRTPr = "TransitGatewayRouteTablePropagation";
    var _TGRTR = "TransitGatewayRouteTableRoute";
    var _TGRTr = "TransitGatewayRouteTables";
    var _TGSIL = "TransitGatewaySubnetIdList";
    var _TGVA = "TransitGatewayVpcAttachment";
    var _TGVAL = "TransitGatewayVpcAttachmentList";
    var _TGVAO = "TransitGatewayVpcAttachmentOptions";
    var _TGVAr = "TransitGatewayVpcAttachments";
    var _TGa = "TargetGroup";
    var _TGar = "TargetGroups";
    var _TGr = "TransitGateways";
    var _THP = "TotalHourlyPrice";
    var _TI = "TerminateInstances";
    var _TIA = "TrunkInterfaceAssociation";
    var _TIAIL = "TrunkInterfaceAssociationIdList";
    var _TIAL = "TrunkInterfaceAssociationList";
    var _TIAT = "TrafficIpAddressType";
    var _TIC = "TotalInstanceCount";
    var _TICa = "TargetInstanceCount";
    var _TICu = "TunnelInsideCidr";
    var _TII = "TrunkInterfaceId";
    var _TIIC = "TunnelInsideIpv6Cidr";
    var _TIIV = "TunnelInsideIpVersion";
    var _TIMIMB = "TotalInferenceMemoryInMiB";
    var _TIR = "TerminateInstancesRequest";
    var _TIRe = "TerminateInstancesResult";
    var _TIWE = "TerminateInstancesWithExpiration";
    var _TIa = "TargetId";
    var _TIar = "TargetIops";
    var _TIe = "TenantId";
    var _TIer = "TerminatingInstances";
    var _TK = "TagKey";
    var _TL = "TagList";
    var _TLSGB = "TotalLocalStorageGB";
    var _TLSGBR = "TotalLocalStorageGBRequest";
    var _TLV = "TrackLatestVersion";
    var _TMAE = "TargetMultiAttachEnabled";
    var _TMF = "TrafficMirrorFilter";
    var _TMFI = "TrafficMirrorFilterId";
    var _TMFIL = "TrafficMirrorFilterIdList";
    var _TMFIr = "TrafficMirrorFilterIds";
    var _TMFR = "TrafficMirrorFilterRule";
    var _TMFRI = "TrafficMirrorFilterRuleId";
    var _TMFRIL = "TrafficMirrorFilterRuleIdList";
    var _TMFRIr = "TrafficMirrorFilterRuleIds";
    var _TMFRL = "TrafficMirrorFilterRuleList";
    var _TMFRS = "TrafficMirrorFilterRuleSet";
    var _TMFRr = "TrafficMirrorFilterRules";
    var _TMFS = "TrafficMirrorFilterSet";
    var _TMFr = "TrafficMirrorFilters";
    var _TMMIMB = "TotalMediaMemoryInMiB";
    var _TMNSL = "TrafficMirrorNetworkServiceList";
    var _TMPR = "TrafficMirrorPortRange";
    var _TMPRR = "TrafficMirrorPortRangeRequest";
    var _TMS = "TrafficMirrorSession";
    var _TMSI = "TrafficMirrorSessionId";
    var _TMSIL = "TrafficMirrorSessionIdList";
    var _TMSIr = "TrafficMirrorSessionIds";
    var _TMSS = "TrafficMirrorSessionSet";
    var _TMSr = "TrafficMirrorSessions";
    var _TMT = "TrafficMirrorTarget";
    var _TMTI = "TrafficMirrorTargetId";
    var _TMTIL = "TrafficMirrorTargetIdList";
    var _TMTIr = "TrafficMirrorTargetIds";
    var _TMTS = "TrafficMirrorTargetSet";
    var _TMTr = "TrafficMirrorTargets";
    var _TN = "TokenName";
    var _TNC = "TargetNetworkCidr";
    var _TNDMIMB = "TotalNeuronDeviceMemoryInMiB";
    var _TNI = "TargetNetworkId";
    var _TNS = "TargetNetworkSet";
    var _TNa = "TargetNetwork";
    var _TO = "TunnelOptions";
    var _TOAT = "TransferOfferAcceptedTimestamp";
    var _TOET = "TransferOfferExpirationTimestamp";
    var _TOL = "TunnelOptionsList";
    var _TOu = "TunnelOption";
    var _TP = "ToPort";
    var _TPC = "ThreadsPerCore";
    var _TPCL = "ThreadsPerCoreList";
    var _TPT = "TrustProviderType";
    var _TPr = "TransportProtocol";
    var _TR = "ThroughResources";
    var _TRC = "TargetResourceCount";
    var _TRD = "TemporaryRestoreDays";
    var _TRS = "ThroughResourcesStatement";
    var _TRSL = "ThroughResourcesStatementList";
    var _TRSR = "ThroughResourcesStatementRequest";
    var _TRSRL = "ThroughResourcesStatementRequestList";
    var _TRTI = "TargetRouteTableId";
    var _TRV = "TargetReservationValue";
    var _TRVS = "TargetReservationValueSet";
    var _TRh = "ThroughResource";
    var _TRi = "TimeRanges";
    var _TRim = "TimeRange";
    var _TS = "TagSpecifications";
    var _TSD = "TermStartDate";
    var _TSIGB = "TotalSizeInGB";
    var _TSIH = "TotalScheduledInstanceHours";
    var _TSL = "TagSpecificationList";
    var _TST = "TieringStartTime";
    var _TSTa = "TaskStartTime";
    var _TSa = "TagSpecification";
    var _TSag = "TagSet";
    var _TSar = "TargetSubnet";
    var _TSarg = "TargetSize";
    var _TSas = "TaskState";
    var _TSp = "TpmSupport";
    var _TT = "TrafficType";
    var _TTC = "TotalTargetCapacity";
    var _TTGAI = "TransportTransitGatewayAttachmentId";
    var _TTa = "TaskType";
    var _TTar = "TargetThroughput";
    var _TTr = "TransferType";
    var _TUC = "TotalUnavailableCapacity";
    var _TUP = "TotalUpfrontPrice";
    var _TV = "TargetVersion";
    var _TVC = "TotalVCpus";
    var _TVSI = "TargetVpcSubnetId";
    var _TVT = "TargetVolumeType";
    var _TVo = "TokenValue";
    var _Ta10 = "Tag";
    var _Te = "Tenancy";
    var _Ter = "Term";
    var _Th = "Throughput";
    var _Ti = "Timestamp";
    var _Tie = "Tier";
    var _To = "To";
    var _Ty = "Type";
    var _U = "Unsuccessful";
    var _UA = "UpdatedAt";
    var _UB = "UserBucket";
    var _UBD = "UserBucketDetails";
    var _UC = "UltraserverCount";
    var _UCMMTK = "UpdateCapacityManagerMonitoredTagKeys";
    var _UCMMTKR = "UpdateCapacityManagerMonitoredTagKeysRequest";
    var _UCMMTKRp = "UpdateCapacityManagerMonitoredTagKeysResult";
    var _UCMOA = "UpdateCapacityManagerOrganizationsAccess";
    var _UCMOAR = "UpdateCapacityManagerOrganizationsAccessRequest";
    var _UCMOARp = "UpdateCapacityManagerOrganizationsAccessResult";
    var _UCTL = "UsageClassTypeList";
    var _UCs = "UsageCount";
    var _UD = "UefiData";
    var _UDLTV = "UnsuccessfullyDeletedLaunchTemplateVersions";
    var _UDp = "UpdatedDate";
    var _UDpd = "UpdateDate";
    var _UDs = "UserData";
    var _UE10 = "UploadEnd";
    var _UEA = "UpdateEffectiveAt";
    var _UF = "UpfrontFee";
    var _UFD = "UnsuccessfulFleetDeletions";
    var _UFR = "UnsuccessfulFleetRequests";
    var _UG = "UserGroups";
    var _UGSL = "UserGroupStringList";
    var _UGs = "UserGroup";
    var _UI = "UserId";
    var _UIA = "UnassignedIpv6Addresses";
    var _UIAR = "UnassignIpv6AddressesRequest";
    var _UIARn = "UnassignIpv6AddressesResult";
    var _UIAn = "UnassignIpv6Addresses";
    var _UIC = "UsedInstanceCount";
    var _UICRA = "UpdateInterruptibleCapacityReservationAllocation";
    var _UICRAR = "UpdateInterruptibleCapacityReservationAllocationRequest";
    var _UICRARp = "UpdateInterruptibleCapacityReservationAllocationResult";
    var _UICS = "UnsuccessfulInstanceCreditSpecifications";
    var _UICSI = "UnsuccessfulInstanceCreditSpecificationItem";
    var _UICSIE = "UnsuccessfulInstanceCreditSpecificationItemError";
    var _UICSS = "UnsuccessfulInstanceCreditSpecificationSet";
    var _UIE = "UserInfoEndpoint";
    var _UIEn = "UnsuccessfulItemError";
    var _UIGP = "UserIdGroupPairs";
    var _UIGPL = "UserIdGroupPairList";
    var _UIGPS = "UserIdGroupPairSet";
    var _UIGPs = "UserIdGroupPair";
    var _UIL = "UnsuccessfulItemList";
    var _UILs = "UserIdList";
    var _UIP = "UnknownIpPermissions";
    var _UIPn = "UnassignedIpv6Prefixes";
    var _UIR = "UnmonitorInstancesRequest";
    var _UIRn = "UnmonitorInstancesResult";
    var _UIS = "UnsuccessfulItemSet";
    var _UISL = "UserIdStringList";
    var _UIn = "UnsuccessfulItem";
    var _UInm = "UnmonitorInstances";
    var _UIs = "UserIds";
    var _ULI = "UseLongIds";
    var _ULIA = "UseLongIdsAggregated";
    var _UO = "UsageOperation";
    var _UOUT = "UsageOperationUpdateTime";
    var _UP = "UpfrontPrice";
    var _UPIA = "UnassignPrivateIpAddresses";
    var _UPIAR = "UnassignPrivateIpAddressesRequest";
    var _UPNGA = "UnassignPrivateNatGatewayAddress";
    var _UPNGAR = "UnassignPrivateNatGatewayAddressRequest";
    var _UPNGARn = "UnassignPrivateNatGatewayAddressResult";
    var _UPS = "UploadPolicySignature";
    var _UPp = "UploadPolicy";
    var _UPs = "UsagePrice";
    var _URBOI = "UnusedReservationBillingOwnerId";
    var _US = "UsageStrategy";
    var _USGRDE = "UpdateSecurityGroupRuleDescriptionsEgress";
    var _USGRDER = "UpdateSecurityGroupRuleDescriptionsEgressRequest";
    var _USGRDERp = "UpdateSecurityGroupRuleDescriptionsEgressResult";
    var _USGRDI = "UpdateSecurityGroupRuleDescriptionsIngress";
    var _USGRDIR = "UpdateSecurityGroupRuleDescriptionsIngressRequest";
    var _USGRDIRp = "UpdateSecurityGroupRuleDescriptionsIngressResult";
    var _USR = "UnlockSnapshotRequest";
    var _USRn = "UnlockSnapshotResult";
    var _UST = "UdpStreamTimeout";
    var _USn = "UnlockSnapshot";
    var _USp = "UploadSize";
    var _USpl = "UploadStart";
    var _UT = "UpdateTime";
    var _UTP = "UserTrustProvider";
    var _UTPT = "UserTrustProviderType";
    var _UTd = "UdpTimeout";
    var _UTl = "UltraserverType";
    var _Ur = "Url";
    var _Us = "Username";
    var _V10 = "Value";
    var _VA = "VpcAttachment";
    var _VAE = "VerifiedAccessEndpoint";
    var _VAECO = "VerifiedAccessEndpointCidrOptions";
    var _VAEEO = "VerifiedAccessEndpointEniOptions";
    var _VAEI = "VerifiedAccessEndpointId";
    var _VAEIL = "VerifiedAccessEndpointIdList";
    var _VAEIe = "VerifiedAccessEndpointIds";
    var _VAEL = "VerifiedAccessEndpointList";
    var _VAELBO = "VerifiedAccessEndpointLoadBalancerOptions";
    var _VAEPR = "VerifiedAccessEndpointPortRange";
    var _VAEPRL = "VerifiedAccessEndpointPortRangeList";
    var _VAERO = "VerifiedAccessEndpointRdsOptions";
    var _VAES = "VerifiedAccessEndpointStatus";
    var _VAESIL = "VerifiedAccessEndpointSubnetIdList";
    var _VAET = "VerifiedAccessEndpointTargets";
    var _VAETD = "VerifiedAccessEndpointTargetDns";
    var _VAETIA = "VerifiedAccessEndpointTargetIpAddress";
    var _VAETL = "VerifiedAccessEndpointTargetList";
    var _VAETe = "VerifiedAccessEndpointTarget";
    var _VAEe = "VerifiedAccessEndpoints";
    var _VAG = "VerifiedAccessGroup";
    var _VAGA = "VerifiedAccessGroupArn";
    var _VAGI = "VerifiedAccessGroupId";
    var _VAGIL = "VerifiedAccessGroupIdList";
    var _VAGIe = "VerifiedAccessGroupIds";
    var _VAGL = "VerifiedAccessGroupList";
    var _VAGe = "VerifiedAccessGroups";
    var _VAI = "VerifiedAccessInstance";
    var _VAICSD = "VerifiedAccessInstanceCustomSubDomain";
    var _VAII = "VerifiedAccessInstanceId";
    var _VAIIL = "VerifiedAccessInstanceIdList";
    var _VAIIe = "VerifiedAccessInstanceIds";
    var _VAIL = "VerifiedAccessInstanceList";
    var _VAILC = "VerifiedAccessInstanceLoggingConfiguration";
    var _VAILCL = "VerifiedAccessInstanceLoggingConfigurationList";
    var _VAIOVCC = "VerifiedAccessInstanceOpenVpnClientConfiguration";
    var _VAIOVCCL = "VerifiedAccessInstanceOpenVpnClientConfigurationList";
    var _VAIOVCCR = "VerifiedAccessInstanceOpenVpnClientConfigurationRoute";
    var _VAIOVCCRL = "VerifiedAccessInstanceOpenVpnClientConfigurationRouteList";
    var _VAIUTPCC = "VerifiedAccessInstanceUserTrustProviderClientConfiguration";
    var _VAIe = "VerifiedAccessInstances";
    var _VAL = "VerifiedAccessLogs";
    var _VALCWLD = "VerifiedAccessLogCloudWatchLogsDestination";
    var _VALCWLDO = "VerifiedAccessLogCloudWatchLogsDestinationOptions";
    var _VALDS = "VerifiedAccessLogDeliveryStatus";
    var _VALKDFD = "VerifiedAccessLogKinesisDataFirehoseDestination";
    var _VALKDFDO = "VerifiedAccessLogKinesisDataFirehoseDestinationOptions";
    var _VALO = "VerifiedAccessLogOptions";
    var _VALSD = "VerifiedAccessLogS3Destination";
    var _VALSDO = "VerifiedAccessLogS3DestinationOptions";
    var _VALo = "VolumeAttachmentList";
    var _VALp = "VpcAttachmentList";
    var _VASSR = "VerifiedAccessSseSpecificationRequest";
    var _VASSRe = "VerifiedAccessSseSpecificationResponse";
    var _VATP = "VerifiedAccessTrustProvider";
    var _VATPC = "VerifiedAccessTrustProviderCondensed";
    var _VATPCL = "VerifiedAccessTrustProviderCondensedList";
    var _VATPI = "VerifiedAccessTrustProviderId";
    var _VATPIL = "VerifiedAccessTrustProviderIdList";
    var _VATPIe = "VerifiedAccessTrustProviderIds";
    var _VATPL = "VerifiedAccessTrustProviderList";
    var _VATPe = "VerifiedAccessTrustProviders";
    var _VAo = "VolumeAttachment";
    var _VAp = "VpcAttachments";
    var _VBPAE = "VpcBlockPublicAccessExclusion";
    var _VBPAEIL = "VpcBlockPublicAccessExclusionIdList";
    var _VBPAEL = "VpcBlockPublicAccessExclusionList";
    var _VBPAEp = "VpcBlockPublicAccessExclusions";
    var _VBPAO = "VpcBlockPublicAccessOptions";
    var _VC = "VpnConcentrator";
    var _VCBA = "VpcCidrBlockAssociation";
    var _VCBAS = "VpcCidrBlockAssociationSet";
    var _VCBS = "VpcCidrBlockState";
    var _VCC = "VCpuCount";
    var _VCCR = "VCpuCountRange";
    var _VCCRR = "VCpuCountRangeRequest";
    var _VCDSC = "VpnConnectionDeviceSampleConfiguration";
    var _VCDT = "VpnConnectionDeviceTypes";
    var _VCDTI = "VpnConnectionDeviceTypeId";
    var _VCDTL = "VpnConnectionDeviceTypeList";
    var _VCDTp = "VpnConnectionDeviceType";
    var _VCI = "VpnConcentratorId";
    var _VCISL = "VpnConcentratorIdStringList";
    var _VCISLp = "VpnConnectionIdStringList";
    var _VCIp = "VpnConnectionId";
    var _VCIpn = "VpnConcentratorIds";
    var _VCIpno = "VpnConnectionIds";
    var _VCIpu = "VCpuInfo";
    var _VCL = "VpcClassicLink";
    var _VCLIL = "VpcClassicLinkIdList";
    var _VCLL = "VpcClassicLinkList";
    var _VCLp = "VpnConcentratorList";
    var _VCLpn = "VpnConnectionList";
    var _VCO = "VpnConnectionOptions";
    var _VCOS = "VpnConnectionOptionsSpecification";
    var _VCa = "ValidCores";
    var _VCp = "VpnConnection";
    var _VCpn = "VpnConcentrators";
    var _VCpno = "VpnConnections";
    var _VD = "VersionDescription";
    var _VDo = "VolumeDetail";
    var _VE10 = "VpcEndpoint";
    var _VEA = "VpcEndpointAssociations";
    var _VEAS = "VpcEndpointAssociationSet";
    var _VEAp = "VpcEndpointAssociation";
    var _VEC = "VpcEncryptionControl";
    var _VECC = "VpcEncryptionControlConfiguration";
    var _VECE = "VpcEncryptionControlExclusion";
    var _VECEp = "VpcEncryptionControlExclusions";
    var _VECI = "VpcEncryptionControlId";
    var _VECIL = "VpcEncryptionControlIdList";
    var _VECIp = "VpcEncryptionControlIds";
    var _VECIpc = "VpcEndpointConnectionId";
    var _VECL = "VpcEncryptionControlList";
    var _VECS = "VpcEndpointConnectionSet";
    var _VECp = "VpcEncryptionControls";
    var _VECpc = "VpcEndpointConnections";
    var _VECpcn = "VpcEndpointConnection";
    var _VEI = "VpcEndpointIds";
    var _VEIL = "VpcEndpointIdList";
    var _VEIp = "VpcEndpointId";
    var _VENCR = "VpcEncryptionNonCompliantResource";
    var _VENCRL = "VpcEncryptionNonCompliantResourceList";
    var _VEO = "VpcEndpointOwner";
    var _VEPS = "VpcEndpointPolicySupported";
    var _VER = "VpcEndpointRegion";
    var _VERTIL = "VpcEndpointRouteTableIdList";
    var _VES = "VpcEndpointService";
    var _VESGIL = "VpcEndpointSecurityGroupIdList";
    var _VESIL = "VpcEndpointServiceIdList";
    var _VESILp = "VpcEndpointSubnetIdList";
    var _VESp = "VpnEcmpSupport";
    var _VESpc = "VpcEndpointState";
    var _VESpcn = "VpcEndpointSet";
    var _VET = "VpcEndpointType";
    var _VEa = "ValidationError";
    var _VEp = "VpcEndpoints";
    var _VF = "ValidFrom";
    var _VFR = "ValidationFailureReason";
    var _VG = "VpnGateway";
    var _VGI = "VpnGatewayId";
    var _VGISL = "VpnGatewayIdStringList";
    var _VGIp = "VpnGatewayIds";
    var _VGL = "VpnGatewayList";
    var _VGp = "VpnGateways";
    var _VI = "VpcId";
    var _VICBA = "VpcIpv6CidrBlockAssociation";
    var _VICBAS = "VpcIpv6CidrBlockAssociationSet";
    var _VIR = "VolumeInitializationRate";
    var _VISL = "VolumeIdStringList";
    var _VISLp = "VpcIdStringList";
    var _VIe = "VendorId";
    var _VIl = "VlanId";
    var _VIo = "VolumeId";
    var _VIol = "VolumeIds";
    var _VIp = "VpcIds";
    var _VL = "VpcLattice";
    var _VLE = "VpcLatticeExclusion";
    var _VLo = "VolumeList";
    var _VLp = "VpcList";
    var _VM = "VolumesModifications";
    var _VML = "VolumeModificationList";
    var _VMe = "VerificationMethod";
    var _VMo = "VolumeModification";
    var _VN = "VirtualName";
    var _VNI = "VirtualNetworkId";
    var _VNe = "VersionNumber";
    var _VOI = "VolumeOwnerId";
    var _VOIp = "VpcOwnerId";
    var _VP = "VpnProtocol";
    var _VPC = "VpcPeeringConnection";
    var _VPCI = "VpcPeeringConnectionId";
    var _VPCIL = "VpcPeeringConnectionIdList";
    var _VPCIp = "VpcPeeringConnectionIds";
    var _VPCL = "VpcPeeringConnectionList";
    var _VPCOD = "VpcPeeringConnectionOptionsDescription";
    var _VPCSR = "VpcPeeringConnectionStateReason";
    var _VPCVI = "VpcPeeringConnectionVpcInfo";
    var _VPCp = "VpcPeeringConnections";
    var _VPE = "VpcPeeringExclusion";
    var _VPG = "VirtualPrivateGateway";
    var _VPGE = "VirtualPrivateGatewayExclusion";
    var _VPp = "VpnPort";
    var _VPpc = "VpcPeering";
    var _VRBI = "VolumeRecycleBinInfo";
    var _VRBIL = "VolumeRecycleBinInfoList";
    var _VS = "VolumeStatuses";
    var _VSA = "VolumeStatusAction";
    var _VSAL = "VolumeStatusActionsList";
    var _VSAS = "VolumeStatusAttachmentStatus";
    var _VSASL = "VolumeStatusAttachmentStatusList";
    var _VSD = "VolumeStatusDetails";
    var _VSDL = "VolumeStatusDetailsList";
    var _VSE = "VolumeStatusEvent";
    var _VSEL = "VolumeStatusEventsList";
    var _VSI = "VolumeStatusInfo";
    var _VSIo = "VolumeStatusItem";
    var _VSL = "ValueStringList";
    var _VSLe = "VersionStringList";
    var _VSLo = "VolumeStatusList";
    var _VSR = "VpnStaticRoute";
    var _VSRL = "VpnStaticRouteList";
    var _VSo = "VolumeSize";
    var _VSol = "VolumeStatus";
    var _VT = "VolumeType";
    var _VTL = "VgwTelemetryList";
    var _VTLO = "VpnTunnelLogOptions";
    var _VTLOS = "VpnTunnelLogOptionsSpecification";
    var _VTLi = "VirtualizationTypeList";
    var _VTOIA = "VpnTunnelOutsideIpAddress";
    var _VTOS = "VpnTunnelOptionsSpecification";
    var _VTOSL = "VpnTunnelOptionsSpecificationsList";
    var _VTPC = "ValidThreadsPerCore";
    var _VTS = "VirtualizationTypeSet";
    var _VTg = "VgwTelemetry";
    var _VTi = "VirtualizationTypes";
    var _VTir = "VirtualizationType";
    var _VU = "ValidUntil";
    var _VW = "ValidationWarning";
    var _Va = "Values";
    var _Ve = "Versions";
    var _Ven = "Vendor";
    var _Ver = "Version";
    var _Vi = "Visibility";
    var _Vl = "Vlan";
    var _Vo = "Volumes";
    var _Vol = "Volume";
    var _Vp = "Vpc";
    var _Vpc = "Vpcs";
    var _W = "Warning";
    var _WBC = "WithdrawByoipCidr";
    var _WBCR = "WithdrawByoipCidrRequest";
    var _WBCRi = "WithdrawByoipCidrResult";
    var _WC = "WithCooldown";
    var _WCe = "WeightedCapacity";
    var _WL = "WorkloadsList";
    var _WM = "WarningMessage";
    var _WU = "WakeUp";
    var _We = "Weight";
    var _Wo = "Workloads";
    var _ZI = "ZoneId";
    var _ZISL = "ZoneIdStringList";
    var _ZIo = "ZoneIds";
    var _ZN = "ZoneName";
    var _ZNSL = "ZoneNameStringList";
    var _ZNo = "ZoneNames";
    var _ZT = "ZoneType";
    var _a10 = "associations";
    var _aA = "asnAssociation";
    var _aAC = "availableAddressCount";
    var _aAI = "awsAccountId";
    var _aAId = "addressAllocationId";
    var _aAS = "asnAssociationSet";
    var _aASA = "autoAcceptSharedAssociations";
    var _aASAu = "autoAcceptSharedAttachments";
    var _aASc = "accountAttributeSet";
    var _aASd = "additionalAccountSet";
    var _aASt = "attachedApplianceSet";
    var _aAc = "accessAll";
    var _aAp = "applianceArn";
    var _aBHP = "actualBlockHourlyPrice";
    var _aC = "availableCapacity";
    var _aCIA = "associateCarrierIpAddress";
    var _aCT = "archivalCompleteTime";
    var _aCc = "acceleratorCount";
    var _aCd = "addressCount";
    var _aD = "activeDirectory";
    var _aDNL = "allocationDefaultNetmaskLength";
    var _aDRFRV = "allowDnsResolutionFromRemoteVpc";
    var _aDRTI = "associationDefaultRouteTableId";
    var _aDS = "additionalDetailSet";
    var _aDT = "additionalDetailType";
    var _aDn = "announcementDirection";
    var _aDp = "applicationDomain";
    var _aE = "authorizationEndpoint";
    var _aEC = "analyzedEniCount";
    var _aEFLCLTRV = "allowEgressFromLocalClassicLinkToRemoteVpc";
    var _aEFLVTRCL = "allowEgressFromLocalVpcToRemoteClassicLink";
    var _aEIO = "autoEnableIO";
    var _aES = "attachedEbsStatus";
    var _aF = "addressFamily";
    var _aFNI = "additionalFlexibleNetworkInterfaces";
    var _aFS = "analysisFindingSet";
    var _aI10 = "allocationId";
    var _aIA = "assignedIpv6Addresses";
    var _aIAC = "availableIpAddressCount";
    var _aIAOC = "assignIpv6AddressOnCreation";
    var _aIC = "availableInstanceCapacity";
    var _aICv = "availableInstanceCount";
    var _aIPS = "assignedIpv6PrefixSet";
    var _aIPSs = "assignedIpv4PrefixSet";
    var _aIS = "activeInstanceSet";
    var _aISS = "allowedImagesSettingsState";
    var _aISc = "accountIdSet";
    var _aITS = "allowedInstanceTypeSet";
    var _aIc = "accountId";
    var _aId = "additionalInfo";
    var _aIm = "amiId";
    var _aIp = "appleInternal";
    var _aIs = "associationId";
    var _aIss = "assetId";
    var _aIt = "attachmentId";
    var _aIu = "autoImport";
    var _aL = "accountLevel";
    var _aLI = "amiLaunchIndex";
    var _aLT = "attachmentLimitType";
    var _aLc = "accessLogs";
    var _aM = "availabilityMode";
    var _aMIT = "allowsMultipleInstanceTypes";
    var _aML = "allocationMetadataList";
    var _aMNL = "allocationMinNetmaskLength";
    var _aMNLl = "allocationMaxNetmaskLength";
    var _aMS = "acceleratorManufacturerSet";
    var _aMSp = "applianceModeSupport";
    var _aN = "attributeName";
    var _aNS = "acceleratorNameSet";
    var _aNc = "accountName";
    var _aO = "authenticationOptions";
    var _aOI = "addressOwnerId";
    var _aP = "autoPlacement";
    var _aPCO = "accepterPeeringConnectionOptions";
    var _aPHS = "alternatePathHintSet";
    var _aPIA = "associatePublicIpAddress";
    var _aPIAS = "assignedPrivateIpAddressesSet";
    var _aPICB = "amazonProvidedIpv6CidrBlock";
    var _aPS = "addedPrincipalSet";
    var _aPSs = "asPathSet";
    var _aPZ = "autoProvisionZones";
    var _aPl = "allowedPrincipals";
    var _aR = "allowReassignment";
    var _aRA = "associatedRoleArn";
    var _aRAd = "additionalRoutesAvailable";
    var _aRAs = "associatedResourceAccessibility";
    var _aRAss = "associatedResourceArn";
    var _aRC = "acceptedRouteCount";
    var _aRP = "areRoutesPersisted";
    var _aRS = "associatedRoleSet";
    var _aRSl = "allocationRuleSet";
    var _aRSu = "autoRecoverySupported";
    var _aRTS = "allocationResourceTagSet";
    var _aRc = "aclRule";
    var _aRcc = "acceptanceRequired";
    var _aRd = "addressRegion";
    var _aRl = "allowReassociation";
    var _aRs = "associatedResource";
    var _aRu = "authorizationRule";
    var _aRut = "autoRecovery";
    var _aRw = "awsRegion";
    var _aS = "associationState";
    var _aSA = "amazonSideAsn";
    var _aSI = "autoScalingIps";
    var _aSS = "amdSevSnp";
    var _aSSs = "associatedSubnetSet";
    var _aSSt = "attributeSummarySet";
    var _aSc = "activityStatus";
    var _aSct = "actionsSet";
    var _aSd = "addressSet";
    var _aSdd = "addressesSet";
    var _aSl = "allocationStrategy";
    var _aSn = "analysisStatus";
    var _aSs = "associationStatus";
    var _aSss = "associationSet";
    var _aSt = "attachmentSet";
    var _aStt = "attachmentState";
    var _aStta = "attachmentStatuses";
    var _aSw = "awsService";
    var _aT22 = "addressTransfer";
    var _aTGAI = "accepterTransitGatewayAttachmentId";
    var _aTI = "accepterTgwInfo";
    var _aTMMB = "acceleratorTotalMemoryMiB";
    var _aTN = "associatedTargetNetwork";
    var _aTS = "addressTransferStatus";
    var _aTSc = "acceleratorTypeSet";
    var _aTSd = "addressTransferSet";
    var _aTd = "advertisementType";
    var _aTdd = "addressType";
    var _aTddr = "addressingType";
    var _aTl = "allocationType";
    var _aTll = "allocationTime";
    var _aTs = "associationTarget";
    var _aTt = "attachTime";
    var _aTtt = "attachedTo";
    var _aTtta = "attachmentType";
    var _aV = "attributeValue";
    var _aVC = "availableVCpus";
    var _aVI = "accepterVpcInfo";
    var _aVS = "attributeValueSet";
    var _aVTS = "activeVpnTunnelStatus";
    var _aZ = "availabilityZone";
    var _aZG = "availabilityZoneGroup";
    var _aZI = "availabilityZoneId";
    var _aZIS = "availabilityZoneIdSet";
    var _aZIv = "availabilityZoneInfo";
    var _aZS = "availabilityZoneSet";
    var _ac = "acl";
    var _acc = "accelerators";
    var _act = "active";
    var _ad = "address";
    var _af = "affinity";
    var _am = "amount";
    var _ar = "arn";
    var _arc = "architecture";
    var _as = "asn";
    var _ass = "association";
    var _at = "attachment";
    var _att = "attribute";
    var _atta = "attachments";
    var _b = "bucket";
    var _bA = "bgpAsn";
    var _bAE = "bgpAsnExtended";
    var _bBIG = "baselineBandwidthInGbps";
    var _bBIM = "baselineBandwidthInMbps";
    var _bC = "byoipCidr";
    var _bCS = "byoipCidrSet";
    var _bCg = "bgpConfigurations";
    var _bCy = "bytesConverted";
    var _bDM = "blockDeviceMapping";
    var _bDMS = "blockDeviceMappingSet";
    var _bDMl = "blockDurationMinutes";
    var _bEBM = "baselineEbsBandwidthMbps";
    var _bEDNS = "baseEndpointDnsNameSet";
    var _bI = "bundleId";
    var _bII = "branchInterfaceId";
    var _bIT = "bundleInstanceTask";
    var _bITS = "bundleInstanceTasksSet";
    var _bIa = "baselineIops";
    var _bLE = "bgpLogEnabled";
    var _bLGA = "bgpLogGroupArn";
    var _bLOF = "bgpLogOutputFormat";
    var _bM = "bootMode";
    var _bMa = "bareMetal";
    var _bN = "bucketName";
    var _bO = "bgpOptions";
    var _bOu = "bucketOwner";
    var _bP = "burstablePerformance";
    var _bPAS = "blockPublicAccessStates";
    var _bPF = "baselinePerformanceFactors";
    var _bPS = "burstablePerformanceSupported";
    var _bS = "byoasnSet";
    var _bSa = "baseSystem";
    var _bSf = "bfdStatus";
    var _bSg = "bgpStatus";
    var _bT = "bannerText";
    var _bTIMB = "baselineThroughputInMBps";
    var _bW = "bandwidthWeighting";
    var _bWa = "bandwidthWeightings";
    var _bl = "blackhole";
    var _by = "byoasn";
    var _byt = "bytes";
    var _c32 = "component";
    var _cA = "componentArn";
    var _cAS = "capacityAllocationSet";
    var _cAUS = "coipAddressUsageSet";
    var _cAe = "certificateArn";
    var _cAo = "componentAccount";
    var _cAr = "createdAt";
    var _cB = "cidrBlock";
    var _cBA = "cidrBlockAssociation";
    var _cBAS = "cidrBlockAssociationSet";
    var _cBDH = "capacityBlockDurationHours";
    var _cBDM = "capacityBlockDurationMinutes";
    var _cBEDH = "capacityBlockExtensionDurationHours";
    var _cBEED = "capacityBlockExtensionEndDate";
    var _cBEOI = "capacityBlockExtensionOfferingId";
    var _cBEOS = "capacityBlockExtensionOfferingSet";
    var _cBEPD = "capacityBlockExtensionPurchaseDate";
    var _cBES = "capacityBlockExtensionStatus";
    var _cBESD = "capacityBlockExtensionStartDate";
    var _cBESa = "capacityBlockExtensionSet";
    var _cBI = "capacityBlockId";
    var _cBOI = "capacityBlockOfferingId";
    var _cBOS = "capacityBlockOfferingSet";
    var _cBS = "capacityBlockSet";
    var _cBSS = "capacityBlockStatusSet";
    var _cBSi = "cidrBlockState";
    var _cBSid = "cidrBlockSet";
    var _cBr = "createdBy";
    var _cC = "currencyCode";
    var _cCB = "clientCidrBlock";
    var _cCO = "clientConnectOptions";
    var _cCRFE = "cancelCapacityReservationFleetError";
    var _cCl = "clientConfiguration";
    var _cCo = "coreCount";
    var _cCoi = "coipCidr";
    var _cCp = "cpuCredits";
    var _cD = "createDate";
    var _cDC = "creationDateCondition";
    var _cDM = "completionDurationMinutes";
    var _cDr = "creationDate";
    var _cDre = "createdDate";
    var _cE = "connectionEvents";
    var _cECSD = "cidrEndpointsCustomSubDomain";
    var _cED = "commitmentEndDate";
    var _cET = "connectionEstablishedTime";
    var _cETo = "connectionEndTime";
    var _cEr = "cronExpression";
    var _cF = "containerFormat";
    var _cFS = "currentFleetState";
    var _cG = "carrierGateway";
    var _cGC = "customerGatewayConfiguration";
    var _cGI = "carrierGatewayId";
    var _cGIu = "customerGatewayId";
    var _cGS = "carrierGatewaySet";
    var _cGSu = "customerGatewaySet";
    var _cGu = "customerGateway";
    var _cGur = "currentGeneration";
    var _cI13 = "carrierIp";
    var _cIA = "clientIpv6Address";
    var _cIBM = "currentInstanceBootMode";
    var _cIC = "committedInstanceCount";
    var _cIi = "cidrIp";
    var _cIid = "cidrIpv6";
    var _cIidr = "cidrIpv4";
    var _cIl = "clientIp";
    var _cIli = "clientId";
    var _cIo = "componentId";
    var _cIom = "commitmentInfo";
    var _cIon = "connectionId";
    var _cIop = "coIp";
    var _cIor = "coreInfo";
    var _cLB = "classicLoadBalancers";
    var _cLBC = "classicLoadBalancersConfig";
    var _cLBL = "classicLoadBalancerListener";
    var _cLBO = "clientLoginBannerOptions";
    var _cLDS = "classicLinkDnsSupported";
    var _cLE = "classicLinkEnabled";
    var _cLO = "connectionLogOptions";
    var _cMDEI = "capacityManagerDataExportId";
    var _cMDES = "capacityManagerDataExportSet";
    var _cMKE = "customerManagedKeyEnabled";
    var _cMP = "capacityManagerProvided";
    var _cMS = "capacityManagerStatus";
    var _cMSp = "cpuManufacturerSet";
    var _cMTKS = "capacityManagerTagKeySet";
    var _cN = "commonName";
    var _cNA = "coreNetworkArn";
    var _cNAA = "coreNetworkAttachmentArn";
    var _cNAo = "connectionNotificationArn";
    var _cNI = "connectionNotificationId";
    var _cNIo = "coreNetworkId";
    var _cNS = "connectionNotificationState";
    var _cNSo = "connectionNotificationSet";
    var _cNT = "connectionNotificationType";
    var _cNo = "connectionNotification";
    var _cO = "cpuOptions";
    var _cOI = "customerOwnedIp";
    var _cOIP = "customerOwnedIpv4Pool";
    var _cOP = "coolOffPeriod";
    var _cOPEO = "coolOffPeriodExpiresOn";
    var _cOi = "cidrOptions";
    var _cP = "coipPool";
    var _cPC = "connectPeerConfiguration";
    var _cPI = "coipPoolId";
    var _cPS = "coipPoolSet";
    var _cR = "capacityReservation";
    var _cRA = "capacityReservationArn";
    var _cRBRS = "capacityReservationBillingRequestSet";
    var _cRCC = "clientRootCertificateChain";
    var _cREO = "clientRouteEnforcementOptions";
    var _cRFA = "capacityReservationFleetArn";
    var _cRFI = "capacityReservationFleetId";
    var _cRFS = "capacityReservationFleetSet";
    var _cRGS = "capacityReservationGroupSet";
    var _cRI = "capacityReservationId";
    var _cRIS = "capacityReservationIdSet";
    var _cRIa = "capacityReservationInfo";
    var _cRL = "certificateRevocationList";
    var _cRO = "capacityReservationOptions";
    var _cRP = "capacityReservationPreference";
    var _cRRGA = "capacityReservationResourceGroupArn";
    var _cRS = "capacityReservationSet";
    var _cRSS = "capacityReservationStatusSet";
    var _cRSa = "capacityReservationSpecification";
    var _cRT = "capacityReservationTarget";
    var _cRa = "capacityRebalance";
    var _cRo = "componentRegion";
    var _cS4 = "cidrSet";
    var _cSBN = "certificateS3BucketName";
    var _cSFRS = "currentSpotFleetRequestState";
    var _cSOK = "certificateS3ObjectKey";
    var _cSl = "clientSecret";
    var _cSo = "conditionSet";
    var _cSom = "complianceStatus";
    var _cSon = "configurationState";
    var _cSonn = "connectionStatuses";
    var _cSr = "creditSpecification";
    var _cSu = "currentState";
    var _cSur = "currentStatus";
    var _cT = "clientToken";
    var _cTC = "connectionTrackingConfiguration";
    var _cTI = "conversionTaskId";
    var _cTS = "connectionTrackingSpecification";
    var _cTo = "conversionTasks";
    var _cTom = "completeTime";
    var _cTomp = "completionTime";
    var _cTon = "conversionTask";
    var _cTonn = "connectivityType";
    var _cTr = "createTime";
    var _cTre = "creationTime";
    var _cTrea = "creationTimestamp";
    var _cVE = "clientVpnEndpoint";
    var _cVEI = "clientVpnEndpointId";
    var _cVOI = "clientVpnOwnerId";
    var _cVP = "createVolumePermission";
    var _cVTN = "clientVpnTargetNetworks";
    var _cWL = "cloudWatchLogs";
    var _cWLO = "cloudWatchLogOptions";
    var _ca = "category";
    var _ch = "checksum";
    var _ci = "cidr";
    var _co13 = "code";
    var _con = "connections";
    var _conf = "configured";
    var _confi = "config";
    var _cont = "context";
    var _cor = "cores";
    var _cou = "count";
    var _cp = "cpu";
    var _d = "destination";
    var _dA = "destinationArn";
    var _dAIT = "denyAllIgwTraffic";
    var _dART = "defaultAssociationRouteTable";
    var _dAS = "destinationAddressSet";
    var _dASe = "deprovisionedAddressSet";
    var _dASi = "disableApiStop";
    var _dAT = "disableApiTermination";
    var _dAe = "destinationAddress";
    var _dC4 = "destinationCidr";
    var _dCA = "domainCertificateArn";
    var _dCAR = "deliverCrossAccountRole";
    var _dCB = "destinationCidrBlock";
    var _dCR = "destinationCapacityReservation";
    var _dCS = "dhcpConfigurationSet";
    var _dCe = "defaultCores";
    var _dCh = "dhcpConfiguration";
    var _dE = "dnsEntry";
    var _dEC = "dataExportCount";
    var _dEKI = "dataEncryptionKeyId";
    var _dEQCPI = "defaultEnaQueueCountPerInterface";
    var _dES = "dnsEntrySet";
    var _dFA = "defaultForAz";
    var _dHIS = "dedicatedHostIdSet";
    var _dHS = "dedicatedHostsSupported";
    var _dHT = "dnsHostnameType";
    var _dI = "deviceIndex";
    var _dICB = "destinationIpv6CidrBlock";
    var _dIF = "diskImageFormat";
    var _dIS = "diskImageSize";
    var _dIe = "destinationIp";
    var _dIi = "directoryId";
    var _dIis = "diskImage";
    var _dLEM = "deliverLogsErrorMessage";
    var _dLPA = "deliverLogsPermissionArn";
    var _dLS = "deliverLogsStatus";
    var _dMGM = "deregisteredMulticastGroupMembers";
    var _dMGS = "deregisteredMulticastGroupSources";
    var _dN = "deviceName";
    var _dNCI = "defaultNetworkCardIndex";
    var _dNII = "deregisteredNetworkInterfaceIds";
    var _dNn = "dnsName";
    var _dO = "dhcpOptions";
    var _dOI = "dhcpOptionsId";
    var _dOS = "dhcpOptionsSet";
    var _dOST = "disconnectOnSessionTimeout";
    var _dOT = "deleteOnTermination";
    var _dOe = "destinationOptions";
    var _dOev = "deviceOptions";
    var _dOn = "dnsOptions";
    var _dP = "deliveryPreference";
    var _dPLI = "destinationPrefixListId";
    var _dPLS = "destinationPrefixListSet";
    var _dPR = "destinationPortRange";
    var _dPRS = "destinationPortRangeSet";
    var _dPRT = "defaultPropagationRouteTable";
    var _dPS = "destinationPortSet";
    var _dPe = "deregistrationProtection";
    var _dPes = "destinationPort";
    var _dR = "dryRun";
    var _dRDAI = "defaultResourceDiscoveryAssociationId";
    var _dRDI = "defaultResourceDiscoveryId";
    var _dRIT = "dnsRecordIpType";
    var _dRRV = "deleteReplacedRootVolume";
    var _dRS = "dataRetentionSupport";
    var _dRSa = "dataResponseSet";
    var _dRTA = "defaultRouteTableAssociation";
    var _dRTP = "defaultRouteTablePropagation";
    var _dRe = "destinationRegion";
    var _dReb = "debuggingRestrictions";
    var _dRi = "discoveryRegion";
    var _dRy = "dynamicRouting";
    var _dS = "dnsServer";
    var _dSCR = "deletedSubnetCidrReservation";
    var _dSRS = "deleteSnapshotResultSet";
    var _dSe = "destinationSet";
    var _dSel = "deliveryStatus";
    var _dSeli = "deliveryStream";
    var _dSn = "dnsSupport";
    var _dT = "deletionTime";
    var _dTA = "dpdTimeoutAction";
    var _dTC = "deprecationTimeCondition";
    var _dTCT = "defaultTargetCapacityType";
    var _dTET = "defaultTcpEstablishedTimeout";
    var _dTGAI = "destinationTransitGatewayAttachmentId";
    var _dTGAT = "destinationTransitGatewayAttachmentType";
    var _dTPC = "defaultThreadsPerCore";
    var _dTPS = "deviceTrustProviderSet";
    var _dTPT = "deviceTrustProviderType";
    var _dTR = "dTraceRestrictions";
    var _dTS = "dpdTimeoutSeconds";
    var _dTe = "deprecationTime";
    var _dTel = "deleteTime";
    var _dTele = "deletionTimestamp";
    var _dTi = "disablingTime";
    var _dTis = "disabledTime";
    var _dUST = "defaultUdpStreamTimeout";
    var _dUT = "defaultUdpTimeout";
    var _dV = "destinationVpc";
    var _dVC = "defaultVCpus";
    var _dVD = "deviceValidationDomain";
    var _dVN = "defaultVersionNumber";
    var _dVe = "desiredVersion";
    var _dVef = "defaultVersion";
    var _dVefa = "defaultVisibility";
    var _da = "data";
    var _de = "description";
    var _dea = "deadline";
    var _def = "default";
    var _det = "details";
    var _dev = "device";
    var _di = "direction";
    var _dim = "dimension";
    var _dis = "disks";
    var _do = "domain";
    var _du = "duration";
    var _dua = "dualstack";
    var _e32 = "egress";
    var _eA = "eniAddress";
    var _eAC = "externalAuthorityConfiguration";
    var _eAn = "enableAcceleration";
    var _eAx = "exclusionsAllowed";
    var _eB = "egressBytes";
    var _eC = "errorCode";
    var _eCI = "ebsCardIndex";
    var _eCS = "ebsCardSet";
    var _eCTP = "excessCapacityTerminationPolicy";
    var _eCn = "encryptionControl";
    var _eCx = "explanationCode";
    var _eD = "endDate";
    var _eDH = "enableDnsHostnames";
    var _eDS = "enableDnsSupport";
    var _eDT = "earliestDatapointTimestamp";
    var _eDTn = "endDateType";
    var _eDf = "effectiveDate";
    var _eDn = "enableDns64";
    var _eDnd = "endpointDomain";
    var _eDv = "eventDescription";
    var _eEA = "endpointEniAddress";
    var _eEBD = "ebsEncryptionByDefault";
    var _eEI = "endpointEniId";
    var _eFRS = "egressFilterRuleSet";
    var _eFS = "elasticFileSystem";
    var _eGAI = "elasticGpuAssociationId";
    var _eGAS = "elasticGpuAssociationState";
    var _eGASl = "elasticGpuAssociationSet";
    var _eGAT = "elasticGpuAssociationTime";
    var _eGH = "elasticGpuHealth";
    var _eGI = "elasticGpuId";
    var _eGS = "elasticGpuSet";
    var _eGSS = "elasticGpuSpecificationSet";
    var _eGSl = "elasticGpuState";
    var _eGT = "elasticGpuType";
    var _eH = "endHour";
    var _eI13 = "exchangeId";
    var _eIAA = "elasticInferenceAcceleratorArn";
    var _eIAAI = "elasticInferenceAcceleratorAssociationId";
    var _eIAAS = "elasticInferenceAcceleratorAssociationState";
    var _eIAASl = "elasticInferenceAcceleratorAssociationSet";
    var _eIAAT = "elasticInferenceAcceleratorAssociationTime";
    var _eIAS = "elasticInferenceAcceleratorSet";
    var _eIAT = "endpointIpAddressType";
    var _eITI = "exportImageTaskId";
    var _eITS = "exportImageTaskSet";
    var _eITSn = "encryptionInTransitSupported";
    var _eITSx = "excludedInstanceTypeSet";
    var _eIb = "ebsInfo";
    var _eIf = "efaInfo";
    var _eIn = "eniId";
    var _eIv = "eventInformation";
    var _eIve = "eventId";
    var _eIx = "exclusionId";
    var _eKKI = "encryptionKmsKeyId";
    var _eLADI = "enableLniAtDeviceIndex";
    var _eLBL = "elasticLoadBalancerListener";
    var _eM = "errorMessage";
    var _eNAUM = "enableNetworkAddressUsageMetrics";
    var _eO = "ebsOptimized";
    var _eOI = "ebsOptimizedInfo";
    var _eOIG = "egressOnlyInternetGateway";
    var _eOIGI = "egressOnlyInternetGatewayId";
    var _eOIGS = "egressOnlyInternetGatewaySet";
    var _eOS = "ebsOptimizedSupport";
    var _eOn = "enclaveOptions";
    var _eP = "egressPackets";
    var _ePG = "enablePrivateGua";
    var _ePS = "excludePathSet";
    var _eQC = "enaQueueCount";
    var _eQN = "ec2QueryName";
    var _eRI = "externalResourceIdentifier";
    var _eRNDAAAAR = "enableResourceNameDnsAAAARecord";
    var _eRNDAR = "enableResourceNameDnsARecord";
    var _eS = "ephemeralStorage";
    var _eSE = "enaSrdEnabled";
    var _eSS = "enaSrdSpecification";
    var _eSSn = "enaSrdSupported";
    var _eST = "eventSubType";
    var _eSUE = "enaSrdUdpEnabled";
    var _eSUS = "enaSrdUdpSpecification";
    var _eSf = "efaSupported";
    var _eSn = "encryptionSupport";
    var _eSna = "enaSupport";
    var _eSnc = "encryptionState";
    var _eSnt = "entrySet";
    var _eSr = "errorSet";
    var _eSv = "eventsSet";
    var _eSx = "explanationSet";
    var _eT = "expirationTime";
    var _eTI = "exportTaskId";
    var _eTLC = "enableTunnelLifecycleControl";
    var _eTS = "exportToS3";
    var _eTSi = "eipTagSet";
    var _eTSx = "exportTaskSet";
    var _eTTCIS = "estimatedTimeToCompleteInSeconds";
    var _eTn = "endTime";
    var _eTna = "enablingTime";
    var _eTnab = "enabledTime";
    var _eTnd = "endpointType";
    var _eTv = "eventType";
    var _eTx = "exportTask";
    var _eWD = "endWeekDay";
    var _eb = "ebs";
    var _en = "enabled";
    var _enc = "encrypted";
    var _end = "end";
    var _enf = "enforced";
    var _er = "error";
    var _ev = "event";
    var _f = "filter";
    var _fA = "federatedAuthentication";
    var _fAD = "filterAtDestination";
    var _fAS = "filterAtSource";
    var _fAi = "firstAddress";
    var _fC = "fulfilledCapacity";
    var _fCRS = "fleetCapacityReservationSet";
    var _fCS = "findingComponentSet";
    var _fCa = "failureCode";
    var _fDN = "fipsDnsName";
    var _fE = "fipsEnabled";
    var _fEQS = "flexibleEnaQueuesSupport";
    var _fF = "fileFormat";
    var _fFCS = "failedFleetCancellationSet";
    var _fFi = "findingsFound";
    var _fI = "findingId";
    var _fIA = "fpgaImageAttribute";
    var _fIAS = "filterInArnSet";
    var _fIGI = "fpgaImageGlobalId";
    var _fII = "fpgaImageId";
    var _fIS = "fleetInstanceSet";
    var _fISp = "fpgaImageSet";
    var _fIl = "fleetId";
    var _fIp = "fpgaInfo";
    var _fLI = "flowLogId";
    var _fLIS = "flowLogIdSet";
    var _fLISa = "fastLaunchImageSet";
    var _fLS = "flowLogSet";
    var _fLSl = "flowLogStatus";
    var _fM = "failureMessage";
    var _fOAS = "filterOutArnSet";
    var _fODC = "fulfilledOnDemandCapacity";
    var _fP = "fromPort";
    var _fPCS = "forwardPathComponentSet";
    var _fPi = "filesystemProtections";
    var _fPix = "fixedPrice";
    var _fQPDS = "failedQueuedPurchaseDeletionSet";
    var _fR = "failureReason";
    var _fRa = "fastRestored";
    var _fS = "fleetSet";
    var _fSR = "firewallStatelessRule";
    var _fSRS = "fastSnapshotRestoreSet";
    var _fSRSES = "fastSnapshotRestoreStateErrorSet";
    var _fSRi = "firewallStatefulRule";
    var _fSSIB = "fullSnapshotSizeInBytes";
    var _fSST = "firstSlotStartTime";
    var _fSl = "fleetState";
    var _fTE = "freeTierEligible";
    var _fa = "fault";
    var _fo = "force";
    var _for = "format";
    var _fp = "fpgas";
    var _fr = "from";
    var _fre = "frequency";
    var _g = "group";
    var _gA = "groupArn";
    var _gAS = "gatewayAssociationState";
    var _gD = "groupDescription";
    var _gI = "gatewayId";
    var _gIA = "groupIpAddress";
    var _gIp = "gpuInfo";
    var _gIr = "groupId";
    var _gK = "greKey";
    var _gLBAS = "gatewayLoadBalancerArnSet";
    var _gLBEI = "gatewayLoadBalancerEndpointId";
    var _gLN = "groupLongName";
    var _gM = "groupMember";
    var _gN = "groupName";
    var _gOI = "groupOwnerId";
    var _gPS = "gpuPartitionSize";
    var _gS = "geographySet";
    var _gSr = "groupSet";
    var _gSro = "groupSource";
    var _gp = "gpus";
    var _gr = "groups";
    var _h22 = "hypervisor";
    var _hBD = "hiddenByDefault";
    var _hCP = "hiveCompatiblePartitions";
    var _hE32 = "httpEndpoint";
    var _hI = "hostId";
    var _hIS = "hostIdSet";
    var _hM = "hostMaintenance";
    var _hO = "hibernationOptions";
    var _hP = "hostProperties";
    var _hPI = "httpProtocolIpv6";
    var _hPRHL = "httpPutResponseHopLimit";
    var _hPo = "hourlyPrice";
    var _hR = "hostRecovery";
    var _hRGA = "hostResourceGroupArn";
    var _hRI = "hostReservationId";
    var _hRS = "historyRecordSet";
    var _hRSo = "hostReservationSet";
    var _hS = "hostSet";
    var _hSa = "haStatus";
    var _hSi = "hibernationSupported";
    var _hT = "httpTokens";
    var _hTE = "httpTokensEnforced";
    var _hTo = "hostnameType";
    var _hZI = "hostedZoneId";
    var _i = "id";
    var _iA = "ipv6Addresses";
    var _iAA = "ipv6AddressAttribute";
    var _iAC = "ipv6AddressCount";
    var _iAES = "imageAncestryEntrySet";
    var _iAI = "includeAllInstances";
    var _iAIn = "inferenceAcceleratorInfo";
    var _iAPI = "ipv4AddressesPerInterface";
    var _iAPIp = "ipv6AddressesPerInterface";
    var _iAPSI = "ipv4AddressesPerSecondaryInterface";
    var _iAS = "interfaceAssociationSet";
    var _iASp = "ipv6AddressesSet";
    var _iAT = "ipAddressType";
    var _iATOI = "includeAllTagsOfInstance";
    var _iAm = "imageAllowed";
    var _iAn = "interfaceAssociation";
    var _iAp = "ipAddress";
    var _iApa = "ipamArn";
    var _iApv = "ipv6Address";
    var _iB = "ingressBytes";
    var _iBPAS = "imageBlockPublicAccessState";
    var _iC = "instanceCount";
    var _iCA = "interruptibleCapacityAllocation";
    var _iCAS = "ipv6CidrAssociationSet";
    var _iCB = "ipv6CidrBlock";
    var _iCBA = "ipv6CidrBlockAssociation";
    var _iCBAS = "ipv4CidrBlockAssociationSet";
    var _iCBASp = "ipv6CidrBlockAssociationSet";
    var _iCBS = "ipv6CidrBlockState";
    var _iCBSp = "ipv6CidrBlockSet";
    var _iCBn = "insideCidrBlocks";
    var _iCE = "instanceConnectEndpoint";
    var _iCEA = "instanceConnectEndpointArn";
    var _iCEI = "instanceConnectEndpointId";
    var _iCES = "instanceConnectEndpointSet";
    var _iCRI = "interruptibleCapacityReservationId";
    var _iCS = "imageCriterionSet";
    var _iCSS = "instanceCreditSpecificationSet";
    var _iCn = "instanceCounts";
    var _iCp = "ipv6Cidr";
    var _iD = "imageData";
    var _iDAS = "ipamDiscoveredAccountSet";
    var _iDPAS = "ipamDiscoveredPublicAddressSet";
    var _iDRCS = "ipamDiscoveredResourceCidrSet";
    var _iDs = "isDefault";
    var _iE = "instanceExport";
    var _iEI = "instanceEventId";
    var _iERVT = "ipamExternalResourceVerificationToken";
    var _iERVTA = "ipamExternalResourceVerificationTokenArn";
    var _iERVTI = "ipamExternalResourceVerificationTokenId";
    var _iERVTS = "ipamExternalResourceVerificationTokenSet";
    var _iEW = "instanceEventWindow";
    var _iEWI = "instanceEventWindowId";
    var _iEWS = "instanceEventWindowState";
    var _iEWSn = "instanceEventWindowSet";
    var _iEs = "isEgress";
    var _iEsx = "isExcludable";
    var _iF = "instanceFamily";
    var _iFCS = "instanceFamilyCreditSpecification";
    var _iFR = "iamFleetRole";
    var _iFRS = "ingressFilterRuleSet";
    var _iG = "internetGateway";
    var _iGBM = "internetGatewayBlockMode";
    var _iGEM = "internetGatewayExclusionMode";
    var _iGI = "internetGatewayId";
    var _iGS = "internetGatewaySet";
    var _iGSn = "instanceGenerationSet";
    var _iH = "instanceHealth";
    var _iHn = "inboundHeader";
    var _iI = "instanceId";
    var _iIB = "instanceInterruptionBehavior";
    var _iIMS = "instanceImageMetadataSet";
    var _iIP = "iamInstanceProfile";
    var _iIPA = "iamInstanceProfileAssociation";
    var _iIPAS = "iamInstanceProfileAssociationSet";
    var _iIS = "instanceIdSet";
    var _iISB = "instanceInitiatedShutdownBehavior";
    var _iITS = "importImageTaskSet";
    var _iIm = "importInstance";
    var _iIma = "imageId";
    var _iIn = "interruptionInfo";
    var _iIns = "instanceIds";
    var _iIp = "ipamId";
    var _iL = "imageLocation";
    var _iLn = "instanceLifecycle";
    var _iM = "imageMetadata";
    var _iMC = "instanceMatchCriteria";
    var _iMO = "instanceMetadataOptions";
    var _iMOn = "instanceMarketOptions";
    var _iMT = "instanceMetadataTags";
    var _iMU = "importManifestUrl";
    var _iN = "ipv6Native";
    var _iNS = "imageNameSet";
    var _iOA = "imageOwnerAlias";
    var _iOI = "imageOwnerId";
    var _iOIn = "instanceOwnerId";
    var _iOIp = "ipOwnerId";
    var _iOS = "instanceOwningService";
    var _iP = "instancePort";
    var _iPA = "ipamPoolAllocation";
    var _iPAI = "ipamPoolAllocationId";
    var _iPAS = "ipamPoolAllocationSet";
    var _iPAp = "ipamPolicyArn";
    var _iPApa = "ipamPoolArn";
    var _iPC = "ipamPoolCidr";
    var _iPCI = "ipamPoolCidrId";
    var _iPCS = "ipamPoolCidrSet";
    var _iPCp = "ipv4PrefixCount";
    var _iPCpv = "ipv6PrefixCount";
    var _iPD = "ipamPolicyDocument";
    var _iPDS = "ipamPolicyDocumentSet";
    var _iPE = "ipamPolicyEnabled";
    var _iPEp = "ipPermissionsEgress";
    var _iPI = "ipamPolicyId";
    var _iPIp = "ipamPoolId";
    var _iPIs = "isPrimaryIpv6";
    var _iPLR = "ipamPrefixListResolver";
    var _iPLRA = "ipamPrefixListResolverArn";
    var _iPLRI = "ipamPrefixListResolverId";
    var _iPLRS = "ipamPrefixListResolverSet";
    var _iPLRSE = "ipamPrefixListResolverSyncEnabled";
    var _iPLRT = "ipamPrefixListResolverTarget";
    var _iPLRTA = "ipamPrefixListResolverTargetArn";
    var _iPLRTI = "ipamPrefixListResolverTargetId";
    var _iPLRTS = "ipamPrefixListResolverTargetSet";
    var _iPLRVS = "ipamPrefixListResolverVersionSet";
    var _iPR = "ipamPolicyRegion";
    var _iPRs = "isPermanentRestore";
    var _iPS = "ipamPolicySet";
    var _iPSm = "imageProviderSet";
    var _iPSp = "ipamPoolSet";
    var _iPSpr = "ipPrefixSet";
    var _iPSpv = "ipv6PoolSet";
    var _iPSpvr = "ipv4PrefixSet";
    var _iPSpvre = "ipv6PrefixSet";
    var _iPTUC = "instancePoolsToUseCount";
    var _iPn = "instancePlatform";
    var _iPng = "ingressPackets";
    var _iPnt = "interfacePermission";
    var _iPnte = "interfaceProtocol";
    var _iPo = "ioPerformance";
    var _iPp = "ipProtocol";
    var _iPpa = "ipamPolicy";
    var _iPpam = "ipamPool";
    var _iPpe = "ipPermissions";
    var _iPpv = "ipv4Prefix";
    var _iPpvo = "ipv6Pool";
    var _iPpvr = "ipv6Prefix";
    var _iPs = "isPublic";
    var _iPsr = "isPrimary";
    var _iR = "instanceRequirements";
    var _iRC = "ipamResourceCidr";
    var _iRCS = "ipamResourceCidrSet";
    var _iRD = "ipamResourceDiscovery";
    var _iRDA = "ipamResourceDiscoveryAssociation";
    var _iRDAA = "ipamResourceDiscoveryAssociationArn";
    var _iRDAI = "ipamResourceDiscoveryAssociationId";
    var _iRDAS = "ipamResourceDiscoveryAssociationSet";
    var _iRDAp = "ipamResourceDiscoveryArn";
    var _iRDI = "ipamResourceDiscoveryId";
    var _iRDR = "ipamResourceDiscoveryRegion";
    var _iRDS = "ipamResourceDiscoverySet";
    var _iRS = "imageReferenceSet";
    var _iRT = "ingressRouteTable";
    var _iRp = "ipamRegion";
    var _iRpa = "ipRanges";
    var _iRpv = "ipv6Ranges";
    var _iS = "interconnectStatus";
    var _iSA = "ipamScopeArn";
    var _iSD = "initializationStatusDetails";
    var _iSI = "instanceStorageInfo";
    var _iSIp = "ipamScopeId";
    var _iSM = "ingestionStatusMessage";
    var _iSS = "instanceStatusSet";
    var _iSSn = "instanceStorageSupported";
    var _iSSp = "ipamScopeSet";
    var _iST = "ipamScopeType";
    var _iSTS = "importSnapshotTaskSet";
    var _iSg = "igmpv2Support";
    var _iSm = "imagesSet";
    var _iSma = "imageState";
    var _iSmag = "imageSet";
    var _iSmd = "imdsSupport";
    var _iSmp = "impairedSince";
    var _iSn = "instancesSet";
    var _iSng = "ingestionStatus";
    var _iSns = "instanceSet";
    var _iSnst = "instanceState";
    var _iSnsta = "instanceStatus";
    var _iSp = "ipamScope";
    var _iSpa = "ipamSet";
    var _iSpo = "ipSource";
    var _iSpv = "ipv6Supported";
    var _iSpvu = "ipv6Support";
    var _iT13 = "instanceType";
    var _iTA = "instanceTagAttribute";
    var _iTC = "icmpTypeCode";
    var _iTCn = "includeTrustContext";
    var _iTI = "importTaskId";
    var _iTKS = "instanceTagKeySet";
    var _iTOS = "instanceTypeOfferingSet";
    var _iTS = "instanceTypeSet";
    var _iTSS = "instanceTypeSpecificationSet";
    var _iTd = "idempotencyToken";
    var _iTm = "imageType";
    var _iTn = "interruptionType";
    var _iTni = "initializationType";
    var _iTns = "instanceTenancy";
    var _iTnst = "instanceTypes";
    var _iTnt = "interfaceType";
    var _iU = "ipUsage";
    var _iURES = "imageUsageReportEntrySet";
    var _iURS = "imageUsageReportSet";
    var _iUS = "instanceUsageSet";
    var _iV = "ikeVersion";
    var _iVE = "isValidExchange";
    var _iVS = "ikeVersionSet";
    var _iVm = "importVolume";
    var _im = "image";
    var _in = "instance";
    var _ins = "instances";
    var _int = "interruptible";
    var _inte = "interval";
    var _io = "iops";
    var _ip = "ipam";
    var _ipv = "ipv4";
    var _is = "issuer";
    var _it = "item";
    var _k = "key";
    var _kDF = "kinesisDataFirehose";
    var _kF = "keyFormat";
    var _kFe = "keyFingerprint";
    var _kI = "kernelId";
    var _kKA = "kmsKeyArn";
    var _kKI = "kmsKeyId";
    var _kM = "keyMaterial";
    var _kN = "keyName";
    var _kPI = "keyPairId";
    var _kS = "keySet";
    var _kSe = "kextSigning";
    var _kT = "keyType";
    var _kV = "keyValue";
    var _ke = "kernel";
    var _key = "keyword";
    var _l = "lifecycle";
    var _lA = "localAddress";
    var _lADT = "lastAttemptedDiscoveryTime";
    var _lAZ = "launchedAvailabilityZone";
    var _lAZI = "launchedAvailabilityZoneId";
    var _lAa = "lastAddress";
    var _lBA = "loadBalancerArn";
    var _lBAE = "localBgpAsnExtended";
    var _lBAo = "localBgpAsn";
    var _lBC = "loadBalancersConfig";
    var _lBLP = "loadBalancerListenerPort";
    var _lBO = "loadBalancerOptions";
    var _lBP = "loadBalancerPort";
    var _lBS = "loadBalancerSet";
    var _lBT = "loadBalancerTarget";
    var _lBTG = "loadBalancerTargetGroup";
    var _lBTGS = "loadBalancerTargetGroupSet";
    var _lBTP = "loadBalancerTargetPort";
    var _lC = "loggingConfiguration";
    var _lCA = "licenseConfigurationArn";
    var _lCO = "lockCreatedOn";
    var _lCS = "loggingConfigurationSet";
    var _lD = "logDestination";
    var _lDS = "latestDeliveryStatus";
    var _lDSLU = "latestDeliveryS3LocationUri";
    var _lDSM = "latestDeliveryStatusMessage";
    var _lDST = "lockDurationStartTime";
    var _lDT = "latestDeliveryTime";
    var _lDTa = "latestDatapointTimestamp";
    var _lDTo = "logDestinationType";
    var _lDo = "lockDuration";
    var _lE = "logEnabled";
    var _lEO = "lockExpiresOn";
    var _lET = "lastEvaluatedTime";
    var _lEa = "lastError";
    var _lF = "logFormat";
    var _lFA = "lambdaFunctionArn";
    var _lG = "launchGroup";
    var _lGA = "logGroupArn";
    var _lGC = "logicalGpuCount";
    var _lGI = "localGatewayId";
    var _lGIi = "linkedGroupId";
    var _lGN = "logGroupName";
    var _lGRT = "localGatewayRouteTable";
    var _lGRTA = "localGatewayRouteTableArn";
    var _lGRTI = "localGatewayRouteTableId";
    var _lGRTS = "localGatewayRouteTableSet";
    var _lGRTVA = "localGatewayRouteTableVpcAssociation";
    var _lGRTVAI = "localGatewayRouteTableVpcAssociationId";
    var _lGRTVAS = "localGatewayRouteTableVpcAssociationSet";
    var _lGRTVIGA = "localGatewayRouteTableVirtualInterfaceGroupAssociation";
    var _lGRTVIGAI = "localGatewayRouteTableVirtualInterfaceGroupAssociationId";
    var _lGRTVIGAS = "localGatewayRouteTableVirtualInterfaceGroupAssociationSet";
    var _lGS = "localGatewaySet";
    var _lGVI = "localGatewayVirtualInterface";
    var _lGVIA = "localGatewayVirtualInterfaceArn";
    var _lGVIG = "localGatewayVirtualInterfaceGroup";
    var _lGVIGA = "localGatewayVirtualInterfaceGroupArn";
    var _lGVIGI = "localGatewayVirtualInterfaceGroupId";
    var _lGVIGS = "localGatewayVirtualInterfaceGroupSet";
    var _lGVII = "localGatewayVirtualInterfaceId";
    var _lGVIIS = "localGatewayVirtualInterfaceIdSet";
    var _lGVIS = "localGatewayVirtualInterfaceSet";
    var _lGo = "logGroup";
    var _lINC = "localIpv4NetworkCidr";
    var _lINCo = "localIpv6NetworkCidr";
    var _lLT = "lastLaunchedTime";
    var _lMA = "lastMaintenanceApplied";
    var _lO = "logOptions";
    var _lOF = "logOutputFormat";
    var _lP = "loadPermissions";
    var _lPa = "launchPermission";
    var _lPi = "limitPrice";
    var _lS = "licenseSpecifications";
    var _lSC = "lastStatusChange";
    var _lSDT = "lastSuccessfulDiscoveryTime";
    var _lSTS = "localStorageTypeSet";
    var _lSV = "lastSyncedVersion";
    var _lSa = "launchSpecification";
    var _lSau = "launchSpecifications";
    var _lSi = "licenseSet";
    var _lSo = "localStorage";
    var _lSoc = "lockState";
    var _lT = "launchTemplate";
    var _lTAO = "launchTemplateAndOverrides";
    var _lTC = "launchTemplateConfigs";
    var _lTD = "launchTemplateData";
    var _lTI = "launchTemplateId";
    var _lTN = "launchTemplateName";
    var _lTOS = "lastTieringOperationStatus";
    var _lTOSD = "lastTieringOperationStatusDetail";
    var _lTP = "lastTieringProgress";
    var _lTS = "launchTemplateSpecification";
    var _lTST = "lastTieringStartTime";
    var _lTV = "launchTemplateVersion";
    var _lTVS = "launchTemplateVersionSet";
    var _lTa = "launchTemplates";
    var _lTau = "launchTime";
    var _lTi = "licenseType";
    var _lTo = "locationType";
    var _lUT = "lastUpdateTime";
    var _lUTa = "lastUpdatedTime";
    var _lUTas = "lastUpdateTimestamp";
    var _lV = "logVersion";
    var _lVCS = "lastVersionCreationStatus";
    var _lVCSM = "lastVersionCreationStatusMessage";
    var _lVN = "latestVersionNumber";
    var _la = "lambda";
    var _lo = "location";
    var _loc = "locale";
    var _m29 = "min";
    var _mA = "mutualAuthentication";
    var _mAAA = "maintenanceAutoAppliedAfter";
    var _mAE = "multiAttachEnabled";
    var _mAI = "maxAggregationInterval";
    var _mAIS = "middleboxAttachmentIdSet";
    var _mAIe = "mediaAcceleratorInfo";
    var _mASS = "movingAddressStatusSet";
    var _mAa = "macAddress";
    var _mAe = "meteredAccount";
    var _mB = "managedBy";
    var _mBIM = "maximumBandwidthInMbps";
    var _mC = "missingComponent";
    var _mCOIOL = "mapCustomerOwnedIpOnLaunch";
    var _mD = "maintenanceDetails";
    var _mDA = "multicastDomainAssociations";
    var _mDK = "metaDataKey";
    var _mDRS = "metricDataResultSet";
    var _mDRSe = "metricDimensionResultSet";
    var _mDSC = "maximumDaysSinceCreated";
    var _mDSD = "maximumDaysSinceDeprecated";
    var _mDV = "metaDataValue";
    var _mDe = "metaData";
    var _mE = "maxEntries";
    var _mEA = "maximumEbsAttachments";
    var _mEC = "maximumEbsCards";
    var _mEI = "maximumEfaInterfaces";
    var _mEM = "managedExceptionMessage";
    var _mEQC = "maximumEnaQueueCount";
    var _mEQCPI = "maximumEnaQueueCountPerInterface";
    var _mFV = "mostFrequentValue";
    var _mG = "multicastGroups";
    var _mGBPVC = "memoryGiBPerVCpu";
    var _mHS = "macHostSet";
    var _mI = "maximumIops";
    var _mIe = "memoryInfo";
    var _mMB = "memoryMiB";
    var _mMT = "macModificationTask";
    var _mMTI = "macModificationTaskId";
    var _mMTS = "macModificationTaskSet";
    var _mNC = "maximumNetworkCards";
    var _mNI = "maximumNetworkInterfaces";
    var _mO = "metadataOptions";
    var _mOSLRG = "memberOfServiceLinkedResourceGroup";
    var _mOSLSVS = "macOSLatestSupportedVersionSet";
    var _mOa = "maintenanceOptions";
    var _mP = "maxPrice";
    var _mPCS = "marketplaceProductCodeSet";
    var _mPIOL = "mapPublicIpOnLaunch";
    var _mPL = "maxParallelLaunches";
    var _mPR = "meteringPolicyRule";
    var _mPS = "metricPointSet";
    var _mPSa = "matchPathSet";
    var _mR = "maxResults";
    var _mRS = "modificationResultSet";
    var _mS = "messageSet";
    var _mSIPC = "macSystemIntegrityProtectionConfig";
    var _mSNI = "maximumSecondaryNetworkInterfaces";
    var _mSPAPOOODP = "maxSpotPriceAsPercentageOfOptimalOnDemandPrice";
    var _mSa = "managementState";
    var _mSai = "maintenanceStrategies";
    var _mSo = "moveStatus";
    var _mSod = "modificationState";
    var _mSu = "multicastSupport";
    var _mT = "marketType";
    var _mTC = "minTargetCapacity";
    var _mTDID = "maxTermDurationInDays";
    var _mTDIDi = "minTermDurationInDays";
    var _mTIMB = "maximumThroughputInMBps";
    var _mTP = "maxTotalPrice";
    var _mTe = "memberType";
    var _mVE = "managesVpcEndpoints";
    var _mVS = "metricValueSet";
    var _ma = "max";
    var _mai = "main";
    var _man = "manufacturer";
    var _mana = "managed";
    var _mar = "marketplace";
    var _me = "message";
    var _med = "med";
    var _met = "metric";
    var _mo = "monitoring";
    var _mod = "mode";
    var _n = "name";
    var _nA = "networkAcl";
    var _nAAI = "networkAclAssociationId";
    var _nAI = "networkAclId";
    var _nAIe = "newAssociationId";
    var _nAOO = "nativeApplicationOidcOptions";
    var _nAS = "networkAclSet";
    var _nAo = "notAfter";
    var _nB = "notBefore";
    var _nBD = "notBeforeDeadline";
    var _nBG = "networkBorderGroup";
    var _nBGe = "networkBandwidthGbps";
    var _nC = "networkCards";
    var _nCI = "networkCardIndex";
    var _nCRS = "nonCompliantResourceSet";
    var _nD = "noDevice";
    var _nDe = "neuronDevices";
    var _nES = "nitroEnclavesSupport";
    var _nG = "natGateway";
    var _nGAS = "natGatewayAddressSet";
    var _nGI = "natGatewayId";
    var _nGS = "natGatewaySet";
    var _nHI = "nextHopIp";
    var _nI = "networkId";
    var _nIA = "networkInsightsAnalysis";
    var _nIAA = "networkInsightsAnalysisArn";
    var _nIAI = "networkInsightsAnalysisId";
    var _nIAS = "networkInsightsAccessScope";
    var _nIASA = "networkInsightsAccessScopeArn";
    var _nIASAA = "networkInsightsAccessScopeAnalysisArn";
    var _nIASAI = "networkInsightsAccessScopeAnalysisId";
    var _nIASAS = "networkInsightsAccessScopeAnalysisSet";
    var _nIASAe = "networkInsightsAccessScopeAnalysis";
    var _nIASC = "networkInsightsAccessScopeContent";
    var _nIASI = "networkInsightsAccessScopeId";
    var _nIASS = "networkInsightsAccessScopeSet";
    var _nIASe = "networkInsightsAnalysisSet";
    var _nIASet = "networkInterfaceAttachmentStatus";
    var _nIC = "networkInterfaceCount";
    var _nID = "networkInterfaceDescription";
    var _nII = "networkInterfaceId";
    var _nIIS = "networkInterfaceIdSet";
    var _nIO = "networkInterfaceOptions";
    var _nIOI = "networkInterfaceOwnerId";
    var _nIP = "networkInsightsPath";
    var _nIPA = "networkInsightsPathArn";
    var _nIPI = "networkInsightsPathId";
    var _nIPIe = "networkInterfacePermissionId";
    var _nIPS = "networkInsightsPathSet";
    var _nIPe = "networkInterfacePermissions";
    var _nIS = "networkInterfaceSet";
    var _nIe = "networkInterface";
    var _nIet = "networkInfo";
    var _nIeu = "neuronInfo";
    var _nL = "netmaskLength";
    var _nLBA = "networkLoadBalancerArn";
    var _nLBAS = "networkLoadBalancerArnSet";
    var _nNS = "networkNodeSet";
    var _nOA = "numberOfAccounts";
    var _nOFA = "numberOfFailedAccounts";
    var _nOMA = "numberOfMatchedAccounts";
    var _nOUA = "numberOfUnmatchedAccounts";
    var _nP = "nvramProtections";
    var _nPF = "networkPathFound";
    var _nPO = "networkPerformanceOptions";
    var _nPe = "networkPerformance";
    var _nPet = "networkPlatform";
    var _nR = "noReboot";
    var _nS = "nvmeSupport";
    var _nSS = "networkServiceSet";
    var _nSST = "nextSlotStartTime";
    var _nSa = "nameserverSet";
    var _nT = "networkType";
    var _nTI = "nitroTpmInfo";
    var _nTS = "nitroTpmSupport";
    var _nTe = "nextToken";
    var _nV = "nestedVirtualization";
    var _o = "origin";
    var _oA = "outpostArn";
    var _oAr = "organizationsAccess";
    var _oArg = "organizationArn";
    var _oAw = "ownerAlias";
    var _oC = "offeringClass";
    var _oDAS = "onDemandAllocationStrategy";
    var _oDFC = "onDemandFulfilledCapacity";
    var _oDMPPOLP = "onDemandMaxPricePercentageOverLowestPrice";
    var _oDMTP = "onDemandMaxTotalPrice";
    var _oDO = "onDemandOptions";
    var _oDS = "occurrenceDaySet";
    var _oDTC = "onDemandTargetCapacity";
    var _oEP = "organizationsEntityPath";
    var _oF = "outputFormat";
    var _oH = "outboundHeader";
    var _oI = "ownerId";
    var _oIA = "outsideIpAddress";
    var _oIAT = "outsideIpAddressType";
    var _oIS = "optInStatus";
    var _oIf = "offeringId";
    var _oIr = "originalIops";
    var _oIu = "outpostId";
    var _oK = "objectKey";
    var _oLI = "outpostLagId";
    var _oLS = "outpostLagSet";
    var _oMAE = "originalMultiAttachEnabled";
    var _oN = "optionName";
    var _oNA = "odbNetworkArn";
    var _oO = "oidcOptions";
    var _oRIWEA = "outputReservedInstancesWillExpireAt";
    var _oRS = "operatingRegionSet";
    var _oRTE = "occurrenceRelativeToEnd";
    var _oS = "offeringSet";
    var _oST = "oldestSampleTime";
    var _oSr = "originalSize";
    var _oSv = "overlapStatus";
    var _oT = "optimizingTime";
    var _oTI = "organizationTargetId";
    var _oTS = "organizationTargetSet";
    var _oTf = "offeringType";
    var _oTr = "originalThroughput";
    var _oU = "occurrenceUnit";
    var _oUA = "organizationalUnitArn";
    var _oUES = "organizationalUnitExclusionSet";
    var _oUI = "organizationalUnitId";
    var _oVCS = "openVpnConfigurationSet";
    var _oVS = "optionValueSet";
    var _oVT = "originalVolumeType";
    var _op = "options";
    var _ope = "operator";
    var _oper = "operation";
    var _ou = "output";
    var _ov = "overrides";
    var _ow = "owner";
    var _p = "principal";
    var _pA = "poolArn";
    var _pAI = "peeringAttachmentId";
    var _pAR = "poolAddressRange";
    var _pARS = "poolAddressRangeSet";
    var _pAe = "peerAddress";
    var _pAee = "peerAsn";
    var _pAr = "principalArn";
    var _pAu = "publiclyAdvertisable";
    var _pB = "provisionedBandwidth";
    var _pBA = "peerBgpAsn";
    var _pBAE = "peerBgpAsnExtended";
    var _pBIG = "peakBandwidthInGbps";
    var _pC = "productCodes";
    var _pCB = "poolCidrBlock";
    var _pCBS = "poolCidrBlockSet";
    var _pCI = "preserveClientIp";
    var _pCNI = "peerCoreNetworkId";
    var _pCS = "poolCidrSet";
    var _pCSS = "postureComplianceStatusSet";
    var _pCa = "partitionCount";
    var _pCo = "poolCount";
    var _pCr = "productCode";
    var _pD = "passwordData";
    var _pDE = "privateDnsEnabled";
    var _pDEr = "privateDnsEntry";
    var _pDHG = "phase1DHGroup";
    var _pDHGNS = "phase1DHGroupNumberSet";
    var _pDHGNSh = "phase2DHGroupNumberSet";
    var _pDHGh = "phase2DHGroup";
    var _pDN = "publicDnsNames";
    var _pDNC = "privateDnsNameConfiguration";
    var _pDNO = "privateDnsNameOptions";
    var _pDNOOL = "privateDnsNameOptionsOnLaunch";
    var _pDNS = "privateDnsNameSet";
    var _pDNVS = "privateDnsNameVerificationState";
    var _pDNr = "privateDnsName";
    var _pDNu = "publicDnsName";
    var _pDOFIRE = "privateDnsOnlyForInboundResolverEndpoint";
    var _pDP = "privateDnsPreference";
    var _pDRTI = "propagationDefaultRouteTableId";
    var _pDS = "pricingDetailsSet";
    var _pDSDN = "publicDualStackDnsName";
    var _pDSDS = "privateDnsSpecifiedDomainSet";
    var _pDSI = "publicDefaultScopeId";
    var _pDSIr = "privateDefaultScopeId";
    var _pDa = "paymentDue";
    var _pDl = "platformDetails";
    var _pDo = "policyDocument";
    var _pDoo = "poolDepth";
    var _pDr = "productDescription";
    var _pE = "policyEnabled";
    var _pEA = "phase1EncryptionAlgorithm";
    var _pEAS = "phase1EncryptionAlgorithmSet";
    var _pEASh = "phase2EncryptionAlgorithmSet";
    var _pEAh = "phase2EncryptionAlgorithm";
    var _pEk = "pkceEnabled";
    var _pF = "packetField";
    var _pFS = "previousFleetState";
    var _pG = "placementGroup";
    var _pGA = "placementGroupArn";
    var _pGI = "placementGroupInfo";
    var _pGS = "placementGroupSet";
    var _pHP = "perHourPartition";
    var _pHS = "packetHeaderStatement";
    var _pI = "publicIp";
    var _pIA = "phase1IntegrityAlgorithm";
    var _pIAC = "privateIpAddressCount";
    var _pIAS = "privateIpAddressesSet";
    var _pIASh = "phase1IntegrityAlgorithmSet";
    var _pIASha = "phase2IntegrityAlgorithmSet";
    var _pIASr = "privateIpAddressSet";
    var _pIASri = "privateIpv4AddressSet";
    var _pIAh = "phase2IntegrityAlgorithm";
    var _pIAr = "privateIpAddress";
    var _pIAri = "privateIpAddresses";
    var _pIDN = "publicIpv6DnsName";
    var _pIDNO = "publicIpDnsNameOptions";
    var _pIDNu = "publicIpv4DnsName";
    var _pIP = "publicIpv4Pool";
    var _pIPI = "publicIpv4PoolId";
    var _pIPS = "publicIpv4PoolSet";
    var _pIS = "publicIpSource";
    var _pIc = "pciId";
    var _pIo = "poolId";
    var _pIr = "processorInfo";
    var _pIri = "primaryIpv6";
    var _pIriv = "privateIp";
    var _pK = "publicKey";
    var _pKM = "publicKeyMaterial";
    var _pL = "prefixList";
    var _pLA = "prefixListArn";
    var _pLAS = "prefixListAssociationSet";
    var _pLD = "peerLivenessDetection";
    var _pLI = "prefixListId";
    var _pLIr = "prefixListIds";
    var _pLN = "prefixListName";
    var _pLOI = "prefixListOwnerId";
    var _pLR = "prefixListRegion";
    var _pLS = "prefixListSet";
    var _pLSh = "phase1LifetimeSeconds";
    var _pLSha = "phase2LifetimeSeconds";
    var _pLa = "packetLength";
    var _pM = "pendingMaintenance";
    var _pN = "partitionNumber";
    var _pO = "paymentOption";
    var _pOI = "peerOwnerId";
    var _pOe = "peeringOptions";
    var _pP = "progressPercentage";
    var _pR = "ptrRecord";
    var _pRD = "persistRoutesDuration";
    var _pRN = "policyRuleNumber";
    var _pRNo = "policyReferenceName";
    var _pRS = "portRangeSet";
    var _pRSe = "persistRoutesState";
    var _pRU = "ptrRecordUpdate";
    var _pRa = "payerResponsibility";
    var _pRo = "portRange";
    var _pRol = "policyRule";
    var _pS = "provisioningStatus";
    var _pSET = "previousSlotEndTime";
    var _pSFRS = "previousSpotFleetRequestState";
    var _pSK = "preSharedKey";
    var _pSKA = "preSharedKeyArn";
    var _pSKE = "publicSigningKeyEndpoint";
    var _pSKU = "publicSigningKeyUrl";
    var _pSR = "provisioningStatusReason";
    var _pSe = "permissionState";
    var _pSee = "peeringStatus";
    var _pSh = "phcSupport";
    var _pSr = "previousState";
    var _pSre = "previousStatus";
    var _pSri = "priceSchedules";
    var _pSrin = "principalSet";
    var _pSro = "protocolSet";
    var _pSroc = "processingStatus";
    var _pT = "principalType";
    var _pTGI = "peerTransitGatewayId";
    var _pTr = "provisionTime";
    var _pTu = "purchaseToken";
    var _pU = "presignedUrl";
    var _pVI = "peerVpcId";
    var _pVIr = "primaryVpcId";
    var _pVS = "propagatingVgwSet";
    var _pZI = "parentZoneId";
    var _pZN = "parentZoneName";
    var _pe = "period";
    var _per = "permission";
    var _pl = "platform";
    var _pla = "placement";
    var _po = "port";
    var _pr = "protocol";
    var _pre = "prefix";
    var _pri = "priority";
    var _pric = "price";
    var _prim = "primary";
    var _pro = "progress";
    var _prop = "propagation";
    var _prov = "provisioned";
    var _pu = "public";
    var _pur = "purchase";
    var _q = "quantity";
    var _r4 = "return";
    var _rA = "ruleAction";
    var _rAE = "remoteAccessEnabled";
    var _rAe = "reservationArn";
    var _rAes = "resourceArn";
    var _rB = "requestedBy";
    var _rBET = "recycleBinEnterTime";
    var _rBETe = "recycleBinExitTime";
    var _rC10 = "returnCode";
    var _rCA = "resourceConfigurationArn";
    var _rCGA = "resourceConfigurationGroupArn";
    var _rCO = "reservedCapacityOptions";
    var _rCS = "resourceComplianceStatus";
    var _rCT = "reservationCreateTimestamp";
    var _rCTe = "reportCreationTime";
    var _rCe = "resourceCidr";
    var _rCea = "reasonCode";
    var _rCec = "recurringCharges";
    var _rD = "restoreDuration";
    var _rDAC = "resourceDiscoveryAssociationCount";
    var _rDCA = "rdsDbClusterArn";
    var _rDI = "ramDiskId";
    var _rDIA = "rdsDbInstanceArn";
    var _rDN = "rootDeviceName";
    var _rDPA = "rdsDbProxyArn";
    var _rDS = "resourceDiscoveryStatus";
    var _rDT = "rootDeviceType";
    var _rE = "responseError";
    var _rEDT = "reservationEndDateType";
    var _rEIT = "requireEncryptionInTransit";
    var _rET = "reservationEndTimestamp";
    var _rETe = "restoreExpiryTime";
    var _rEd = "rdsEndpoint";
    var _rEe = "regionEndpoint";
    var _rEes = "resourceExclusions";
    var _rFP = "rekeyFuzzPercentage";
    var _rGA = "ruleGroupArn";
    var _rGI = "referencedGroupId";
    var _rGIe = "referencedGroupInfo";
    var _rGROPS = "ruleGroupRuleOptionsPairSet";
    var _rGT = "ruleGroupType";
    var _rGTPS = "ruleGroupTypePairSet";
    var _rHS = "requireHibernateSupport";
    var _rI = "reservationId";
    var _rIDS = "routeInstallationDetailSet";
    var _rII = "reservedInstancesId";
    var _rIIe = "reservedInstanceId";
    var _rILI = "reservedInstancesListingId";
    var _rILS = "reservedInstancesListingsSet";
    var _rIMC = "reservationInstanceMatchCriteria";
    var _rIMI = "reservedInstancesModificationId";
    var _rIMS = "reservedInstancesModificationsSet";
    var _rINC = "remoteIpv4NetworkCidr";
    var _rINCe = "remoteIpv6NetworkCidr";
    var _rIOI = "reservedInstancesOfferingId";
    var _rIOS = "reservedInstancesOfferingsSet";
    var _rIS = "reservedInstancesSet";
    var _rISR = "routeInstallationStatusReason";
    var _rISo = "routeInstallationStatus";
    var _rIVR = "reservedInstanceValueRollup";
    var _rIVS = "reservedInstanceValueSet";
    var _rIa = "ramdiskId";
    var _rIe = "reportId";
    var _rIeg = "regionInfo";
    var _rIeq = "requesterId";
    var _rIes = "resourceId";
    var _rM = "reasonMessage";
    var _rMGM = "registeredMulticastGroupMembers";
    var _rMGS = "registeredMulticastGroupSources";
    var _rMS = "rebootMigrationSupport";
    var _rMTS = "rekeyMarginTimeSeconds";
    var _rMe = "rebootMigration";
    var _rMeq = "requesterManaged";
    var _rN10 = "ruleNumber";
    var _rNII = "registeredNetworkInterfaceIds";
    var _rNe = "regionName";
    var _rNes = "resourceName";
    var _rNo = "roleName";
    var _rO = "resourceOwner";
    var _rOI = "resourceOwnerId";
    var _rOS = "ruleOptionSet";
    var _rOSe = "resourceOverlapStatus";
    var _rOd = "rdsOptions";
    var _rOo = "routeOrigin";
    var _rPCO = "requesterPeeringConnectionOptions";
    var _rPCS = "returnPathComponentSet";
    var _rR = "resourceRegion";
    var _rRVT = "replaceRootVolumeTask";
    var _rRVTI = "replaceRootVolumeTaskId";
    var _rRVTS = "replaceRootVolumeTaskSet";
    var _rS = "reservationState";
    var _rSA = "routeServerAssociation";
    var _rSAS = "routeServerAssociationSet";
    var _rSE = "routeServerEndpoint";
    var _rSEI = "routeServerEndpointId";
    var _rSES = "routeServerEndpointSet";
    var _rSGRS = "revokedSecurityGroupRuleSet";
    var _rSI = "routeServerId";
    var _rSP = "routeServerPeer";
    var _rSPI = "routeServerPeerId";
    var _rSPS = "routeServerPeerSet";
    var _rSPSo = "routeServerPropagationSet";
    var _rSPo = "routeServerPropagation";
    var _rSS = "regionalSummarySet";
    var _rSSo = "routeServerSet";
    var _rST = "reservationStartTimestamp";
    var _rSTe = "restoreStartTime";
    var _rSe = "referenceSet";
    var _rSep = "reportSet";
    var _rSepl = "replacementStrategy";
    var _rSes = "reservationSet";
    var _rSeso = "resourceStatement";
    var _rSesou = "resourceSet";
    var _rSo = "routeServer";
    var _rSou = "routeSet";
    var _rSout = "routeStatus";
    var _rSu = "ruleSet";
    var _rT13 = "reservationType";
    var _rTAI = "routeTableAssociationId";
    var _rTI = "routeTableId";
    var _rTIS = "routeTableIdSet";
    var _rTIe = "requesterTgwInfo";
    var _rTOS = "resourceTypeOptionSet";
    var _rTR = "routeTableRoute";
    var _rTS = "routeTableSet";
    var _rTSe = "resourceTypeSet";
    var _rTSes = "resourceTagSet";
    var _rTSese = "reservationTypeSet";
    var _rTV = "remainingTotalValue";
    var _rTe = "resourceType";
    var _rTel = "releaseTime";
    var _rTeq = "requestTime";
    var _rTes = "resourceTag";
    var _rTo = "routeTable";
    var _rTu = "ruleType";
    var _rUFO = "reservationUnusedFinancialOwner";
    var _rUI = "replaceUnhealthyInstances";
    var _rUV = "remainingUpfrontValue";
    var _rV = "returnValue";
    var _rVI = "referencingVpcId";
    var _rVIe = "requesterVpcInfo";
    var _rVe = "reservationValue";
    var _rWS = "replayWindowSize";
    var _ra = "ramdisk";
    var _re = "resource";
    var _rea = "reason";
    var _rec = "recurrence";
    var _reg = "region";
    var _req = "requested";
    var _res = "result";
    var _ro = "route";
    var _rou = "routes";
    var _s32 = "smithy.ts.sdk.synthetic.com.amazonaws.ec2";
    var _sA = "sourceArn";
    var _sAS = "sourceAddressSet";
    var _sASu = "suggestedAccountSet";
    var _sAZ = "singleAvailabilityZone";
    var _sAo = "sourceAddress";
    var _sAt = "startupAction";
    var _sAu = "supportedArchitectures";
    var _sAub = "subnetArn";
    var _sB = "s3Bucket";
    var _sBM = "supportedBootModes";
    var _sBN = "s3BucketName";
    var _sBP = "s3BucketPrefix";
    var _sC = "serviceConfiguration";
    var _sCA = "serverCertificateArn";
    var _sCAE = "serialConsoleAccessEnabled";
    var _sCB = "sourceCidrBlock";
    var _sCR = "sourceCapacityReservation";
    var _sCRI = "sourceCapacityReservationId";
    var _sCRIu = "subnetCidrReservationId";
    var _sCRu = "subnetCidrReservation";
    var _sCS = "serviceConfigurationSet";
    var _sCSIG = "sustainedClockSpeedInGhz";
    var _sCc = "scopeCount";
    var _sCn = "snapshotConfiguration";
    var _sCt = "staticCidr";
    var _sD = "startDate";
    var _sDC = "sourceDestCheck";
    var _sDIH = "slotDurationInHours";
    var _sDLTVS = "successfullyDeletedLaunchTemplateVersionSet";
    var _sDS = "spotDatafeedSubscription";
    var _sDSe = "serviceDetailSet";
    var _sDSn = "snapshotDetailSet";
    var _sDp = "spreadDomain";
    var _sDu = "subDomain";
    var _sEL = "s3ExportLocation";
    var _sET = "sampledEndTime";
    var _sF = "supportedFeatures";
    var _sFCS = "successfulFleetCancellationSet";
    var _sFDS = "successfulFleetDeletionSet";
    var _sFRC = "spotFleetRequestConfig";
    var _sFRCS = "spotFleetRequestConfigSet";
    var _sFRI = "spotFleetRequestId";
    var _sFRS = "successfulFleetRequestSet";
    var _sFRSp = "spotFleetRequestState";
    var _sG = "securityGroup";
    var _sGA = "securityGroupArn";
    var _sGFVS = "securityGroupForVpcSet";
    var _sGI = "securityGroupId";
    var _sGIS = "securityGroupIdSet";
    var _sGIe = "securityGroupIds";
    var _sGIec = "securityGroupInfo";
    var _sGR = "securityGroupRule";
    var _sGRA = "securityGroupRuleArn";
    var _sGRI = "securityGroupRuleId";
    var _sGRS = "securityGroupRuleSet";
    var _sGRSe = "securityGroupReferenceSet";
    var _sGRSec = "securityGroupReferencingSupport";
    var _sGS = "subGeographySet";
    var _sGSe = "securityGroupSet";
    var _sGVAS = "securityGroupVpcAssociationSet";
    var _sGe = "securityGroups";
    var _sH = "startHour";
    var _sI = "serviceId";
    var _sIA = "secondaryInterfaceArn";
    var _sIAS = "scheduledInstanceAvailabilitySet";
    var _sIATS = "supportedIpAddressTypeSet";
    var _sICRS = "subnetIpv4CidrReservationSet";
    var _sICRSu = "subnetIpv6CidrReservationSet";
    var _sICSS = "successfulInstanceCreditSpecificationSet";
    var _sIGB = "sizeInGB";
    var _sII = "sourceInstanceId";
    var _sIIc = "scheduledInstanceId";
    var _sIIe = "secondaryInterfaceId";
    var _sIIo = "sourceImageId";
    var _sIMB = "sizeInMiB";
    var _sIP = "staleIpPermissions";
    var _sIPE = "staleIpPermissionsEgress";
    var _sIPI = "sourceIpamPoolId";
    var _sIR = "sourceImageRegion";
    var _sIRI = "spotInstanceRequestId";
    var _sIRS = "spotInstanceRequestSet";
    var _sIS = "scheduledInstanceSet";
    var _sISe = "secondaryInterfaceSet";
    var _sISu = "subnetIdSet";
    var _sIT = "spotInstanceType";
    var _sITRS = "storeImageTaskResultSet";
    var _sITe = "secondaryInterfaceType";
    var _sITi = "singleInstanceType";
    var _sIn = "snapshotId";
    var _sIo = "sourceIp";
    var _sIu = "subnetId";
    var _sIub = "subnetIds";
    var _sK = "s3Key";
    var _sKo = "s3objectKey";
    var _sL = "s3Location";
    var _sLVIA = "serviceLinkVirtualInterfaceArn";
    var _sLVII = "serviceLinkVirtualInterfaceId";
    var _sLVIIS = "serviceLinkVirtualInterfaceIdSet";
    var _sLVIS = "serviceLinkVirtualInterfaceSet";
    var _sLp = "spreadLevel";
    var _sM = "serviceManaged";
    var _sMPPOLP = "spotMaxPricePercentageOverLowestPrice";
    var _sMS = "spotMaintenanceStrategies";
    var _sMTP = "spotMaxTotalPrice";
    var _sMt = "statusMessage";
    var _sMta = "stateMessage";
    var _sN = "serviceName";
    var _sNA = "secondaryNetworkArn";
    var _sNAe = "serviceNetworkArn";
    var _sNE = "snsNotificationsEnabled";
    var _sNI = "secondaryNetworkId";
    var _sNN = "serviceNetworkName";
    var _sNS = "secondaryNetworkSet";
    var _sNSe = "serviceNameSet";
    var _sNSec = "secondaryNetworkSupported";
    var _sNSr = "sriovNetSupport";
    var _sNT = "secondaryNetworkType";
    var _sNe = "secondaryNetwork";
    var _sNeq = "sequenceNumber";
    var _sNes = "sessionNumber";
    var _sO = "spotOptions";
    var _sP = "s3Prefix";
    var _sPA = "samlProviderArn";
    var _sPHS = "spotPriceHistorySet";
    var _sPI = "servicePermissionId";
    var _sPIAC = "secondaryPrivateIpAddressCount";
    var _sPLS = "sourcePrefixListSet";
    var _sPR = "sourcePortRange";
    var _sPRS = "sourcePortRangeSet";
    var _sPS = "sourcePortSet";
    var _sPSS = "spotPlacementScoreSet";
    var _sPp = "spotPrice";
    var _sQPDS = "successfulQueuedPurchaseDeletionSet";
    var _sR = "serviceRegion";
    var _sRDT = "supportedRootDeviceTypes";
    var _sRO = "staticRoutesOnly";
    var _sRS = "supportedRegionSet";
    var _sRT = "subnetRouteTable";
    var _sRe = "serviceResource";
    var _sRo = "sourceResource";
    var _sRt = "stateReason";
    var _sS = "secondarySubnet";
    var _sSA = "secondarySubnetArn";
    var _sSC = "sqlServerCredentials";
    var _sSGN = "sourceSecurityGroupName";
    var _sSGOI = "sourceSecurityGroupOwnerId";
    var _sSGS = "staleSecurityGroupSet";
    var _sSI = "secondarySubnetId";
    var _sSLU = "sqlServerLicenseUsage";
    var _sSPU = "selfServicePortalUrl";
    var _sSS = "secondarySubnetSet";
    var _sSSPA = "selfServiceSamlProviderArn";
    var _sSSt = "staticSourcesSupport";
    var _sST = "sampledStartTime";
    var _sSe = "settingSet";
    var _sSer = "serviceState";
    var _sSn = "snapshotSet";
    var _sSo = "sourceSet";
    var _sSs = "sseSpecification";
    var _sSt = "statusSet";
    var _sSu = "subscriptionSet";
    var _sSub = "subnetSet";
    var _sSup = "supportedStrategies";
    var _sSy = "systemStatus";
    var _sT19 = "startTime";
    var _sTA = "snsTopicArn";
    var _sTC = "spotTargetCapacity";
    var _sTD = "snapshotTaskDetail";
    var _sTFR = "storeTaskFailureReason";
    var _sTGAI = "sourceTransitGatewayAttachmentId";
    var _sTGAT = "sourceTransitGatewayAttachmentType";
    var _sTH = "sessionTimeoutHours";
    var _sTR = "stateTransitionReason";
    var _sTS = "storeTaskState";
    var _sTSS = "snapshotTierStatusSet";
    var _sTT = "stateTransitionTime";
    var _sTa = "sampleTime";
    var _sTe = "serviceType";
    var _sTo = "sourceType";
    var _sTp = "splitTunnel";
    var _sTs = "sseType";
    var _sTt = "storageTier";
    var _sUC = "supportedUsageClasses";
    var _sV = "sourceVpc";
    var _sVI = "sourceVolumeId";
    var _sVT = "supportedVirtualizationTypes";
    var _sVh = "shellVersion";
    var _sVu = "supportedVersions";
    var _sWD = "startWeekDay";
    var _s_ = "s3";
    var _sc4 = "schedule";
    var _sco = "scope";
    var _scop = "scopes";
    var _scor = "score";
    var _se14 = "service";
    var _si = "size";
    var _so = "source";
    var _soc = "sockets";
    var _sof = "software";
    var _st = "state";
    var _sta = "status";
    var _star = "start";
    var _stat = "statistic";
    var _sto = "storage";
    var _str = "strategy";
    var _su = "subnet";
    var _sub = "subnets";
    var _suc = "successful";
    var _succ = "success";
    var _t = "tenancy";
    var _tAAC = "totalAvailableAddressCount";
    var _tAC = "totalAvailableCapacity";
    var _tACo = "totalAddressCount";
    var _tAI = "transferAccountId";
    var _tB = "tunnelBandwidth";
    var _tC = "totalCapacity";
    var _tCS = "targetCapacitySpecification";
    var _tCUT = "targetCapacityUnitType";
    var _tCVR = "targetConfigurationValueRollup";
    var _tCVS = "targetConfigurationValueSet";
    var _tCa = "targetCapacity";
    var _tCar = "targetConfiguration";
    var _tD = "terminationDelay";
    var _tDr = "trafficDirection";
    var _tE = "targetEnvironment";
    var _tED = "termEndDate";
    var _tET = "tcpEstablishedTimeout";
    var _tEo = "tokenEndpoint";
    var _tFC = "totalFulfilledCapacity";
    var _tFMIMB = "totalFpgaMemoryInMiB";
    var _tG = "transitGateway";
    var _tGA = "transitGatewayAttachments";
    var _tGAI = "transitGatewayAttachmentId";
    var _tGAP = "transitGatewayAttachmentPropagations";
    var _tGAr = "transitGatewayAttachment";
    var _tGAra = "transitGatewayArn";
    var _tGAran = "transitGatewayAsn";
    var _tGArans = "transitGatewayAddress";
    var _tGC = "transitGatewayConfiguration";
    var _tGCB = "transitGatewayCidrBlocks";
    var _tGCP = "transitGatewayConnectPeer";
    var _tGCPI = "transitGatewayConnectPeerId";
    var _tGCPS = "transitGatewayConnectPeerSet";
    var _tGCS = "transitGatewayConnectSet";
    var _tGCVA = "transitGatewayClientVpnAttachment";
    var _tGCa = "targetGroupsConfig";
    var _tGCr = "transitGatewayConnect";
    var _tGI = "transitGatewayId";
    var _tGMD = "transitGatewayMulticastDomain";
    var _tGMDA = "transitGatewayMulticastDomainArn";
    var _tGMDI = "transitGatewayMulticastDomainId";
    var _tGMDr = "transitGatewayMulticastDomains";
    var _tGMIMB = "totalGpuMemoryInMiB";
    var _tGMP = "transitGatewayMeteringPolicy";
    var _tGMPE = "transitGatewayMeteringPolicyEntry";
    var _tGMPEr = "transitGatewayMeteringPolicyEntries";
    var _tGMPI = "transitGatewayMeteringPolicyId";
    var _tGMPr = "transitGatewayMeteringPolicies";
    var _tGOI = "transitGatewayOwnerId";
    var _tGPA = "transitGatewayPeeringAttachment";
    var _tGPAr = "transitGatewayPeeringAttachments";
    var _tGPLR = "transitGatewayPrefixListReference";
    var _tGPLRS = "transitGatewayPrefixListReferenceSet";
    var _tGPT = "transitGatewayPolicyTable";
    var _tGPTE = "transitGatewayPolicyTableEntries";
    var _tGPTI = "transitGatewayPolicyTableId";
    var _tGPTr = "transitGatewayPolicyTables";
    var _tGRT = "transitGatewayRouteTable";
    var _tGRTA = "transitGatewayRouteTableAnnouncement";
    var _tGRTAI = "transitGatewayRouteTableAnnouncementId";
    var _tGRTAr = "transitGatewayRouteTableAnnouncements";
    var _tGRTI = "transitGatewayRouteTableId";
    var _tGRTP = "transitGatewayRouteTablePropagations";
    var _tGRTR = "transitGatewayRouteTableRoute";
    var _tGRTr = "transitGatewayRouteTables";
    var _tGS = "transitGatewaySet";
    var _tGVA = "transitGatewayVpcAttachment";
    var _tGVAr = "transitGatewayVpcAttachments";
    var _tGa = "targetGroups";
    var _tHP = "totalHourlyPrice";
    var _tI10 = "terminateInstances";
    var _tIAT = "trafficIpAddressType";
    var _tIC = "totalInstanceCount";
    var _tICa = "targetInstanceCount";
    var _tICu = "tunnelInsideCidr";
    var _tII = "trunkInterfaceId";
    var _tIIC = "tunnelInsideIpv6Cidr";
    var _tIIV = "tunnelInsideIpVersion";
    var _tIMIMB = "totalInferenceMemoryInMiB";
    var _tIWE = "terminateInstancesWithExpiration";
    var _tIa = "targetId";
    var _tIar = "targetIops";
    var _tIe = "tenantId";
    var _tK = "tagKey";
    var _tLSGB = "totalLocalStorageGB";
    var _tLV = "trackLatestVersion";
    var _tMAE = "targetMultiAttachEnabled";
    var _tMF = "trafficMirrorFilter";
    var _tMFI = "trafficMirrorFilterId";
    var _tMFR = "trafficMirrorFilterRule";
    var _tMFRI = "trafficMirrorFilterRuleId";
    var _tMFRS = "trafficMirrorFilterRuleSet";
    var _tMFS = "trafficMirrorFilterSet";
    var _tMMIMB = "totalMediaMemoryInMiB";
    var _tMS = "trafficMirrorSession";
    var _tMSI = "trafficMirrorSessionId";
    var _tMSS = "trafficMirrorSessionSet";
    var _tMT = "trafficMirrorTarget";
    var _tMTI = "trafficMirrorTargetId";
    var _tMTS = "trafficMirrorTargetSet";
    var _tN = "tokenName";
    var _tNDMIMB = "totalNeuronDeviceMemoryInMiB";
    var _tNI = "targetNetworkId";
    var _tOAT = "transferOfferAcceptedTimestamp";
    var _tOET = "transferOfferExpirationTimestamp";
    var _tOS = "tunnelOptionSet";
    var _tP = "toPort";
    var _tPC = "threadsPerCore";
    var _tPT = "trustProviderType";
    var _tPr = "transportProtocol";
    var _tRC = "targetResourceCount";
    var _tRS = "throughResourceSet";
    var _tRSi = "timeRangeSet";
    var _tRTI = "targetRouteTableId";
    var _tS = "tagSet";
    var _tSD = "termStartDate";
    var _tSIGB = "totalSizeInGB";
    var _tSIH = "totalScheduledInstanceHours";
    var _tSS = "tagSpecificationSet";
    var _tST = "tieringStartTime";
    var _tSTa = "taskStartTime";
    var _tSa = "targetSubnet";
    var _tSar = "targetSize";
    var _tSas = "taskState";
    var _tSp = "tpmSupport";
    var _tT13 = "trafficType";
    var _tTC = "totalTargetCapacity";
    var _tTGAI = "transportTransitGatewayAttachmentId";
    var _tTa = "taskType";
    var _tTar = "targetThroughput";
    var _tTr = "transferType";
    var _tUC = "totalUnavailableCapacity";
    var _tUP = "totalUpfrontPrice";
    var _tV = "tokenValue";
    var _tVC = "totalVCpus";
    var _tVT = "targetVolumeType";
    var _ta = "tag";
    var _tag = "tags";
    var _te = "term";
    var _th = "throughput";
    var _ti = "timestamp";
    var _tie = "tier";
    var _to = "to";
    var _ty = "type";
    var _u = "unsuccessful";
    var _uA = "updatedAt";
    var _uB = "userBucket";
    var _uC = "ultraserverCount";
    var _uCs = "usageCount";
    var _uD = "uefiData";
    var _uDLTVS = "unsuccessfullyDeletedLaunchTemplateVersionSet";
    var _uDp = "updatedDate";
    var _uDpd = "updateDate";
    var _uDs = "userData";
    var _uEA = "updateEffectiveAt";
    var _uF = "upfrontFee";
    var _uFDS = "unsuccessfulFleetDeletionSet";
    var _uFRS = "unsuccessfulFleetRequestSet";
    var _uI = "userId";
    var _uIA = "unassignedIpv6Addresses";
    var _uIC = "usedInstanceCount";
    var _uICSS = "unsuccessfulInstanceCreditSpecificationSet";
    var _uIE = "userInfoEndpoint";
    var _uIPS = "unknownIpPermissionSet";
    var _uIPSn = "unassignedIpv6PrefixSet";
    var _uLI = "useLongIds";
    var _uLIA = "useLongIdsAggregated";
    var _uO = "usageOperation";
    var _uOUT = "usageOperationUpdateTime";
    var _uP = "upfrontPrice";
    var _uPS = "uploadPolicySignature";
    var _uPp = "uploadPolicy";
    var _uPs = "usagePrice";
    var _uRBOI = "unusedReservationBillingOwnerId";
    var _uS = "usageStrategy";
    var _uST = "udpStreamTimeout";
    var _uT = "updateTime";
    var _uTP = "userTrustProvider";
    var _uTPT = "userTrustProviderType";
    var _uTd = "udpTimeout";
    var _uTl = "ultraserverType";
    var _ur = "url";
    var _us = "username";
    var _v = "value";
    var _vAE = "verifiedAccessEndpoint";
    var _vAEI = "verifiedAccessEndpointId";
    var _vAES = "verifiedAccessEndpointSet";
    var _vAETD = "verifiedAccessEndpointTargetDns";
    var _vAETIA = "verifiedAccessEndpointTargetIpAddress";
    var _vAETS = "verifiedAccessEndpointTargetSet";
    var _vAG = "verifiedAccessGroup";
    var _vAGA = "verifiedAccessGroupArn";
    var _vAGI = "verifiedAccessGroupId";
    var _vAGS = "verifiedAccessGroupSet";
    var _vAI = "verifiedAccessInstance";
    var _vAII = "verifiedAccessInstanceId";
    var _vAIS = "verifiedAccessInstanceSet";
    var _vATP = "verifiedAccessTrustProvider";
    var _vATPI = "verifiedAccessTrustProviderId";
    var _vATPS = "verifiedAccessTrustProviderSet";
    var _vBPAE = "vpcBlockPublicAccessExclusion";
    var _vBPAES = "vpcBlockPublicAccessExclusionSet";
    var _vBPAO = "vpcBlockPublicAccessOptions";
    var _vC = "vpnConcentrator";
    var _vCC = "vCpuCount";
    var _vCDSC = "vpnConnectionDeviceSampleConfiguration";
    var _vCDTI = "vpnConnectionDeviceTypeId";
    var _vCDTS = "vpnConnectionDeviceTypeSet";
    var _vCI = "vpnConnectionId";
    var _vCIp = "vCpuInfo";
    var _vCIpn = "vpnConcentratorId";
    var _vCS = "vpnConcentratorSet";
    var _vCSp = "vpnConnectionSet";
    var _vCa = "validCores";
    var _vCp = "vpnConnection";
    var _vD = "versionDescription";
    var _vE = "vpcEndpoint";
    var _vEAS = "vpcEndpointAssociationSet";
    var _vEC = "vpcEncryptionControl";
    var _vECI = "vpcEncryptionControlId";
    var _vECIp = "vpcEndpointConnectionId";
    var _vECS = "vpcEncryptionControlSet";
    var _vECSp = "vpcEndpointConnectionSet";
    var _vEI = "vpcEndpointId";
    var _vEO = "vpcEndpointOwner";
    var _vEPS = "vpcEndpointPolicySupported";
    var _vER = "vpcEndpointRegion";
    var _vES = "vpcEndpointService";
    var _vESp = "vpcEndpointSet";
    var _vESpc = "vpcEndpointState";
    var _vESpn = "vpnEcmpSupport";
    var _vET = "vpcEndpointType";
    var _vF = "validFrom";
    var _vFR = "validationFailureReason";
    var _vG = "vpnGateway";
    var _vGI = "vpnGatewayId";
    var _vGS = "vpnGatewaySet";
    var _vI = "vpcId";
    var _vIR = "volumeInitializationRate";
    var _vIl = "vlanId";
    var _vIo = "volumeId";
    var _vL = "vpcLattice";
    var _vM = "volumeModification";
    var _vMS = "volumeModificationSet";
    var _vN = "virtualName";
    var _vNI = "virtualNetworkId";
    var _vNe = "versionNumber";
    var _vOI = "volumeOwnerId";
    var _vOIp = "vpcOwnerId";
    var _vP = "vpnProtocol";
    var _vPC = "vpcPeeringConnection";
    var _vPCI = "vpcPeeringConnectionId";
    var _vPCS = "vpcPeeringConnectionSet";
    var _vPG = "virtualPrivateGateway";
    var _vPp = "vpnPort";
    var _vPpc = "vpcPeering";
    var _vS = "volumeSet";
    var _vSS = "volumeStatusSet";
    var _vSa = "valueSet";
    var _vSo = "volumeSize";
    var _vSol = "volumeStatus";
    var _vSp = "vpcSet";
    var _vT = "volumeType";
    var _vTOIA = "vpnTunnelOutsideIpAddress";
    var _vTPC = "validThreadsPerCore";
    var _vTg = "vgwTelemetry";
    var _vTi = "virtualizationType";
    var _vU = "validUntil";
    var _ve = "version";
    var _ven = "vendor";
    var _vi = "visibility";
    var _vl = "vlan";
    var _vo = "volumes";
    var _vol = "volume";
    var _vp = "vpc";
    var _vpc = "vpcs";
    var _w = "warning";
    var _wC = "weightedCapacity";
    var _wM = "warningMessage";
    var _wS = "workloadSet";
    var _we = "weight";
    var _xN = "xmlName";
    var _zI = "zoneId";
    var _zN = "zoneName";
    var _zS = "zoneState";
    var _zT = "zoneType";
    var n032 = "com.amazonaws.ec2";
    var schema_1 = (init_schema4(), __toCommonJS(schema_exports));
    var EC2ServiceException_1 = require_EC2ServiceException();
    var _s_registry32 = schema_1.TypeRegistry.for(_s32);
    exports2.EC2ServiceException$ = [-3, _s32, "EC2ServiceException", 0, [], []];
    _s_registry32.registerError(exports2.EC2ServiceException$, EC2ServiceException_1.EC2ServiceException);
    exports2.errorTypeRegistries = [
      _s_registry32
    ];
    var ClientSecretType = [0, n032, _CST, 8, 0];
    var CopySnapshotRequestPSU = [0, n032, _CSRPSU, 8, 0];
    var customerGatewayConfiguration = [0, n032, _cGC, 8, 0];
    var EkPubKeyValue = [0, n032, _EPKV, 8, 0];
    var ImportManifestUrl = [0, n032, _IMU, 8, 0];
    var ModifyInstanceAttributeValue = [0, n032, _MIAV, 8, 0];
    var PasswordData = [0, n032, _PD, 8, 0];
    var preSharedKey = [0, n032, _pSK, 8, 0];
    var ReportInstanceStatusRequestDescription = [0, n032, _RISRD, 8, 0];
    var RunInstancesUserData = [0, n032, _RIUD, 8, 0];
    var S3StorageUploadPolicySignature = [0, n032, _SSUPS, 8, 0];
    var SensitiveMacCredentials = [0, n032, _SMC, 8, 0];
    var SensitiveUrl = [0, n032, _SU, 8, 0];
    var SensitiveUserData = [0, n032, _SUD, 8, 0];
    var VpnConnectionDeviceSampleConfiguration = [0, n032, _VCDSC, 8, 0];
    exports2.AcceleratorCount$ = [
      3,
      n032,
      _AC,
      0,
      [_M, _Ma],
      [[1, {
        [_eQN]: `Min`,
        [_xN]: _m29
      }], [1, {
        [_eQN]: `Max`,
        [_xN]: _ma
      }]]
    ];
    exports2.AcceleratorCountRequest$ = [
      3,
      n032,
      _ACR,
      0,
      [_M, _Ma],
      [1, 1]
    ];
    exports2.AcceleratorTotalMemoryMiB$ = [
      3,
      n032,
      _ATMMB,
      0,
      [_M, _Ma],
      [[1, {
        [_eQN]: `Min`,
        [_xN]: _m29
      }], [1, {
        [_eQN]: `Max`,
        [_xN]: _ma
      }]]
    ];
    exports2.AcceleratorTotalMemoryMiBRequest$ = [
      3,
      n032,
      _ATMMBR,
      0,
      [_M, _Ma],
      [1, 1]
    ];
    exports2.AcceptAddressTransferRequest$ = [
      3,
      n032,
      _AATR,
      0,
      [_A10, _TS, _DR],
      [0, [() => TagSpecificationList, { [_xN]: _TSa }], 2],
      1
    ];
    exports2.AcceptAddressTransferResult$ = [
      3,
      n032,
      _AATRc,
      0,
      [_AT13],
      [[() => exports2.AddressTransfer$, {
        [_eQN]: `AddressTransfer`,
        [_xN]: _aT22
      }]]
    ];
    exports2.AcceptCapacityReservationBillingOwnershipRequest$ = [
      3,
      n032,
      _ACRBOR,
      0,
      [_CRI, _DR],
      [0, 2],
      1
    ];
    exports2.AcceptCapacityReservationBillingOwnershipResult$ = [
      3,
      n032,
      _ACRBORc,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.AcceptReservedInstancesExchangeQuoteRequest$ = [
      3,
      n032,
      _ARIEQR,
      0,
      [_RII, _DR, _TC10],
      [[() => ReservedInstanceIdSet, { [_xN]: _RIIe }], 2, [() => TargetConfigurationRequestSet, { [_xN]: _TCa }]],
      1
    ];
    exports2.AcceptReservedInstancesExchangeQuoteResult$ = [
      3,
      n032,
      _ARIEQRc,
      0,
      [_EI10],
      [[0, {
        [_eQN]: `ExchangeId`,
        [_xN]: _eI13
      }]]
    ];
    exports2.AcceptTransitGatewayClientVpnAttachmentRequest$ = [
      3,
      n032,
      _ATGCVAR,
      0,
      [_TGAI, _DR],
      [0, 2],
      1
    ];
    exports2.AcceptTransitGatewayClientVpnAttachmentResult$ = [
      3,
      n032,
      _ATGCVARc,
      0,
      [_TGCVA],
      [[() => exports2.TransitGatewayClientVpnAttachment$, {
        [_eQN]: `TransitGatewayClientVpnAttachment`,
        [_xN]: _tGCVA
      }]]
    ];
    exports2.AcceptTransitGatewayMulticastDomainAssociationsRequest$ = [
      3,
      n032,
      _ATGMDAR,
      0,
      [_TGMDI, _TGAI, _SI10, _DR],
      [0, 0, [() => ValueStringList, 0], 2]
    ];
    exports2.AcceptTransitGatewayMulticastDomainAssociationsResult$ = [
      3,
      n032,
      _ATGMDARc,
      0,
      [_As],
      [[() => exports2.TransitGatewayMulticastDomainAssociations$, {
        [_eQN]: `Associations`,
        [_xN]: _a10
      }]]
    ];
    exports2.AcceptTransitGatewayPeeringAttachmentRequest$ = [
      3,
      n032,
      _ATGPAR,
      0,
      [_TGAI, _DR],
      [0, 2],
      1
    ];
    exports2.AcceptTransitGatewayPeeringAttachmentResult$ = [
      3,
      n032,
      _ATGPARc,
      0,
      [_TGPA],
      [[() => exports2.TransitGatewayPeeringAttachment$, {
        [_eQN]: `TransitGatewayPeeringAttachment`,
        [_xN]: _tGPA
      }]]
    ];
    exports2.AcceptTransitGatewayVpcAttachmentRequest$ = [
      3,
      n032,
      _ATGVAR,
      0,
      [_TGAI, _DR],
      [0, 2],
      1
    ];
    exports2.AcceptTransitGatewayVpcAttachmentResult$ = [
      3,
      n032,
      _ATGVARc,
      0,
      [_TGVA],
      [[() => exports2.TransitGatewayVpcAttachment$, {
        [_eQN]: `TransitGatewayVpcAttachment`,
        [_xN]: _tGVA
      }]]
    ];
    exports2.AcceptVpcEndpointConnectionsRequest$ = [
      3,
      n032,
      _AVECR,
      0,
      [_SIe, _VEI, _DR],
      [0, [() => VpcEndpointIdList, { [_xN]: _VEIp }], 2],
      2
    ];
    exports2.AcceptVpcEndpointConnectionsResult$ = [
      3,
      n032,
      _AVECRc,
      0,
      [_U],
      [[() => UnsuccessfulItemSet, {
        [_eQN]: `Unsuccessful`,
        [_xN]: _u
      }]]
    ];
    exports2.AcceptVpcPeeringConnectionRequest$ = [
      3,
      n032,
      _AVPCR,
      0,
      [_VPCI, _DR],
      [[0, {
        [_eQN]: `VpcPeeringConnectionId`,
        [_xN]: _vPCI
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.AcceptVpcPeeringConnectionResult$ = [
      3,
      n032,
      _AVPCRc,
      0,
      [_VPC],
      [[() => exports2.VpcPeeringConnection$, {
        [_eQN]: `VpcPeeringConnection`,
        [_xN]: _vPC
      }]]
    ];
    exports2.AccessScopeAnalysisFinding$ = [
      3,
      n032,
      _ASAF,
      0,
      [_NIASAI, _NIASI, _FI, _FC],
      [[0, {
        [_eQN]: `NetworkInsightsAccessScopeAnalysisId`,
        [_xN]: _nIASAI
      }], [0, {
        [_eQN]: `NetworkInsightsAccessScopeId`,
        [_xN]: _nIASI
      }], [0, {
        [_eQN]: `FindingId`,
        [_xN]: _fI
      }], [() => PathComponentList, {
        [_eQN]: `FindingComponentSet`,
        [_xN]: _fCS
      }]]
    ];
    exports2.AccessScopePath$ = [
      3,
      n032,
      _ASP,
      0,
      [_S, _D, _TR],
      [[() => exports2.PathStatement$, {
        [_eQN]: `Source`,
        [_xN]: _so
      }], [() => exports2.PathStatement$, {
        [_eQN]: `Destination`,
        [_xN]: _d
      }], [() => ThroughResourcesStatementList, {
        [_eQN]: `ThroughResourceSet`,
        [_xN]: _tRS
      }]]
    ];
    exports2.AccessScopePathRequest$ = [
      3,
      n032,
      _ASPR,
      0,
      [_S, _D, _TR],
      [[() => exports2.PathStatementRequest$, 0], [() => exports2.PathStatementRequest$, 0], [() => ThroughResourcesStatementRequestList, { [_xN]: _TRh }]]
    ];
    exports2.AccountAttribute$ = [
      3,
      n032,
      _AA,
      0,
      [_AN, _AV],
      [[0, {
        [_eQN]: `AttributeName`,
        [_xN]: _aN
      }], [() => AccountAttributeValueList, {
        [_eQN]: `AttributeValueSet`,
        [_xN]: _aVS
      }]]
    ];
    exports2.AccountAttributeValue$ = [
      3,
      n032,
      _AAV,
      0,
      [_AVt],
      [[0, {
        [_eQN]: `AttributeValue`,
        [_xN]: _aV
      }]]
    ];
    exports2.ActiveInstance$ = [
      3,
      n032,
      _AI2,
      0,
      [_II2, _IT4, _SIRI, _IH],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [0, {
        [_eQN]: `SpotInstanceRequestId`,
        [_xN]: _sIRI
      }], [0, {
        [_eQN]: `InstanceHealth`,
        [_xN]: _iH
      }]]
    ];
    exports2.ActiveVpnTunnelStatus$ = [
      3,
      n032,
      _AVTS,
      0,
      [_PEA, _PEAh, _PIA, _PIAh, _PDHG, _PDHGh, _IV, _PS, _PSR],
      [[0, {
        [_eQN]: `Phase1EncryptionAlgorithm`,
        [_xN]: _pEA
      }], [0, {
        [_eQN]: `Phase2EncryptionAlgorithm`,
        [_xN]: _pEAh
      }], [0, {
        [_eQN]: `Phase1IntegrityAlgorithm`,
        [_xN]: _pIA
      }], [0, {
        [_eQN]: `Phase2IntegrityAlgorithm`,
        [_xN]: _pIAh
      }], [1, {
        [_eQN]: `Phase1DHGroup`,
        [_xN]: _pDHG
      }], [1, {
        [_eQN]: `Phase2DHGroup`,
        [_xN]: _pDHGh
      }], [0, {
        [_eQN]: `IkeVersion`,
        [_xN]: _iV
      }], [0, {
        [_eQN]: `ProvisioningStatus`,
        [_xN]: _pS
      }], [0, {
        [_eQN]: `ProvisioningStatusReason`,
        [_xN]: _pSR
      }]]
    ];
    exports2.AddedPrincipal$ = [
      3,
      n032,
      _AP,
      0,
      [_PT, _P10, _SPI, _SIe],
      [[0, {
        [_eQN]: `PrincipalType`,
        [_xN]: _pT
      }], [0, {
        [_eQN]: `Principal`,
        [_xN]: _p
      }], [0, {
        [_eQN]: `ServicePermissionId`,
        [_xN]: _sPI
      }], [0, {
        [_eQN]: `ServiceId`,
        [_xN]: _sI
      }]]
    ];
    exports2.AddIpamOperatingRegion$ = [
      3,
      n032,
      _AIOR,
      0,
      [_RN],
      [0]
    ];
    exports2.AddIpamOrganizationalUnitExclusion$ = [
      3,
      n032,
      _AIOUE,
      0,
      [_OEP],
      [0]
    ];
    exports2.AdditionalDetail$ = [
      3,
      n032,
      _AD,
      0,
      [_ADT, _C11, _VES, _RO, _RGTP, _RGROP, _SN10, _LB],
      [[0, {
        [_eQN]: `AdditionalDetailType`,
        [_xN]: _aDT
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `Component`,
        [_xN]: _c32
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `VpcEndpointService`,
        [_xN]: _vES
      }], [() => RuleOptionList, {
        [_eQN]: `RuleOptionSet`,
        [_xN]: _rOS
      }], [() => RuleGroupTypePairList, {
        [_eQN]: `RuleGroupTypePairSet`,
        [_xN]: _rGTPS
      }], [() => RuleGroupRuleOptionsPairList, {
        [_eQN]: `RuleGroupRuleOptionsPairSet`,
        [_xN]: _rGROPS
      }], [0, {
        [_eQN]: `ServiceName`,
        [_xN]: _sN
      }], [() => AnalysisComponentList, {
        [_eQN]: `LoadBalancerSet`,
        [_xN]: _lBS
      }]]
    ];
    exports2.AddPrefixListEntry$ = [
      3,
      n032,
      _APLE,
      0,
      [_Ci, _De],
      [0, 0],
      1
    ];
    exports2.Address$ = [
      3,
      n032,
      _A10,
      0,
      [_AIl, _AIs, _Do, _NII, _NIOI, _PIAr, _T10, _PIP, _NBG, _COI, _COIP, _CI, _SIu, _SM, _II2, _PI10],
      [[0, {
        [_eQN]: `AllocationId`,
        [_xN]: _aI10
      }], [0, {
        [_eQN]: `AssociationId`,
        [_xN]: _aIs
      }], [0, {
        [_eQN]: `Domain`,
        [_xN]: _do
      }], [0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], [0, {
        [_eQN]: `NetworkInterfaceOwnerId`,
        [_xN]: _nIOI
      }], [0, {
        [_eQN]: `PrivateIpAddress`,
        [_xN]: _pIAr
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `PublicIpv4Pool`,
        [_xN]: _pIP
      }], [0, {
        [_eQN]: `NetworkBorderGroup`,
        [_xN]: _nBG
      }], [0, {
        [_eQN]: `CustomerOwnedIp`,
        [_xN]: _cOI
      }], [0, {
        [_eQN]: `CustomerOwnedIpv4Pool`,
        [_xN]: _cOIP
      }], [0, {
        [_eQN]: `CarrierIp`,
        [_xN]: _cI13
      }], [0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }], [0, {
        [_eQN]: `ServiceManaged`,
        [_xN]: _sM
      }], [0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `PublicIp`,
        [_xN]: _pI
      }]]
    ];
    exports2.AddressAttribute$ = [
      3,
      n032,
      _AAd,
      0,
      [_PI10, _AIl, _PR, _PRU],
      [[0, {
        [_eQN]: `PublicIp`,
        [_xN]: _pI
      }], [0, {
        [_eQN]: `AllocationId`,
        [_xN]: _aI10
      }], [0, {
        [_eQN]: `PtrRecord`,
        [_xN]: _pR
      }], [() => exports2.PtrUpdateStatus$, {
        [_eQN]: `PtrRecordUpdate`,
        [_xN]: _pRU
      }]]
    ];
    exports2.AddressTransfer$ = [
      3,
      n032,
      _AT13,
      0,
      [_PI10, _AIl, _TAI, _TOET, _TOAT, _ATS],
      [[0, {
        [_eQN]: `PublicIp`,
        [_xN]: _pI
      }], [0, {
        [_eQN]: `AllocationId`,
        [_xN]: _aI10
      }], [0, {
        [_eQN]: `TransferAccountId`,
        [_xN]: _tAI
      }], [4, {
        [_eQN]: `TransferOfferExpirationTimestamp`,
        [_xN]: _tOET
      }], [4, {
        [_eQN]: `TransferOfferAcceptedTimestamp`,
        [_xN]: _tOAT
      }], [0, {
        [_eQN]: `AddressTransferStatus`,
        [_xN]: _aTS
      }]]
    ];
    exports2.AdvertiseByoipCidrRequest$ = [
      3,
      n032,
      _ABCR,
      0,
      [_Ci, _Asn, _DR, _NBG],
      [0, 0, 2, 0],
      1
    ];
    exports2.AdvertiseByoipCidrResult$ = [
      3,
      n032,
      _ABCRd,
      0,
      [_BC],
      [[() => exports2.ByoipCidr$, {
        [_eQN]: `ByoipCidr`,
        [_xN]: _bC
      }]]
    ];
    exports2.AllocateAddressRequest$ = [
      3,
      n032,
      _AAR,
      0,
      [_Do, _A10, _PIP, _NBG, _COIP, _TS, _IPI2, _DR],
      [0, 0, 0, 0, 0, [() => TagSpecificationList, { [_xN]: _TSa }], 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]]
    ];
    exports2.AllocateAddressResult$ = [
      3,
      n032,
      _AARl,
      0,
      [_AIl, _PIP, _NBG, _Do, _COI, _COIP, _CI, _PI10],
      [[0, {
        [_eQN]: `AllocationId`,
        [_xN]: _aI10
      }], [0, {
        [_eQN]: `PublicIpv4Pool`,
        [_xN]: _pIP
      }], [0, {
        [_eQN]: `NetworkBorderGroup`,
        [_xN]: _nBG
      }], [0, {
        [_eQN]: `Domain`,
        [_xN]: _do
      }], [0, {
        [_eQN]: `CustomerOwnedIp`,
        [_xN]: _cOI
      }], [0, {
        [_eQN]: `CustomerOwnedIpv4Pool`,
        [_xN]: _cOIP
      }], [0, {
        [_eQN]: `CarrierIp`,
        [_xN]: _cI13
      }], [0, {
        [_eQN]: `PublicIp`,
        [_xN]: _pI
      }]]
    ];
    exports2.AllocateHostsRequest$ = [
      3,
      n032,
      _AHR,
      0,
      [_IF, _TS, _HR, _OA, _HM, _AIss, _AZI, _APu, _CT4, _IT4, _Q, _AZ],
      [0, [() => TagSpecificationList, { [_xN]: _TSa }], 0, 0, 0, [64 | 0, { [_xN]: _AIsse }], 0, [0, {
        [_eQN]: `AutoPlacement`,
        [_xN]: _aP
      }], [0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [1, {
        [_eQN]: `Quantity`,
        [_xN]: _q
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }]]
    ];
    exports2.AllocateHostsResult$ = [
      3,
      n032,
      _AHRl,
      0,
      [_HI],
      [[() => ResponseHostIdList, {
        [_eQN]: `HostIdSet`,
        [_xN]: _hIS
      }]]
    ];
    exports2.AllocateIpamPoolCidrRequest$ = [
      3,
      n032,
      _AIPCR,
      0,
      [_IPI2, _DR, _Ci, _NL, _CT4, _De, _PNC, _ACl, _DC],
      [0, 2, 0, 1, [0, 4], 0, 2, [() => IpamPoolAllocationAllowedCidrs, { [_xN]: _ACll }], [() => IpamPoolAllocationDisallowedCidrs, { [_xN]: _DCi }]],
      1
    ];
    exports2.AllocateIpamPoolCidrResult$ = [
      3,
      n032,
      _AIPCRl,
      0,
      [_IPA],
      [[() => exports2.IpamPoolAllocation$, {
        [_eQN]: `IpamPoolAllocation`,
        [_xN]: _iPA
      }]]
    ];
    exports2.AllowedPrincipal$ = [
      3,
      n032,
      _APl,
      0,
      [_PT, _P10, _SPI, _T10, _SIe],
      [[0, {
        [_eQN]: `PrincipalType`,
        [_xN]: _pT
      }], [0, {
        [_eQN]: `Principal`,
        [_xN]: _p
      }], [0, {
        [_eQN]: `ServicePermissionId`,
        [_xN]: _sPI
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `ServiceId`,
        [_xN]: _sI
      }]]
    ];
    exports2.AlternatePathHint$ = [
      3,
      n032,
      _APH,
      0,
      [_CIo, _CA10],
      [[0, {
        [_eQN]: `ComponentId`,
        [_xN]: _cIo
      }], [0, {
        [_eQN]: `ComponentArn`,
        [_xN]: _cA
      }]]
    ];
    exports2.AnalysisAclRule$ = [
      3,
      n032,
      _AARn,
      0,
      [_Ci, _E11, _PRo, _Pr10, _RA10, _RNu],
      [[0, {
        [_eQN]: `Cidr`,
        [_xN]: _ci
      }], [2, {
        [_eQN]: `Egress`,
        [_xN]: _e32
      }], [() => exports2.PortRange$, {
        [_eQN]: `PortRange`,
        [_xN]: _pRo
      }], [0, {
        [_eQN]: `Protocol`,
        [_xN]: _pr
      }], [0, {
        [_eQN]: `RuleAction`,
        [_xN]: _rA
      }], [1, {
        [_eQN]: `RuleNumber`,
        [_xN]: _rN10
      }]]
    ];
    exports2.AnalysisComponent$ = [
      3,
      n032,
      _ACn,
      0,
      [_I, _Ar, _N],
      [[0, {
        [_eQN]: `Id`,
        [_xN]: _i
      }], [0, {
        [_eQN]: `Arn`,
        [_xN]: _ar
      }], [0, {
        [_eQN]: `Name`,
        [_xN]: _n
      }]]
    ];
    exports2.AnalysisLoadBalancerListener$ = [
      3,
      n032,
      _ALBL,
      0,
      [_LBP, _IP],
      [[1, {
        [_eQN]: `LoadBalancerPort`,
        [_xN]: _lBP
      }], [1, {
        [_eQN]: `InstancePort`,
        [_xN]: _iP
      }]]
    ];
    exports2.AnalysisLoadBalancerTarget$ = [
      3,
      n032,
      _ALBT,
      0,
      [_A10, _AZ, _AZI, _In, _Po],
      [[0, {
        [_eQN]: `Address`,
        [_xN]: _ad
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `Instance`,
        [_xN]: _in
      }], [1, {
        [_eQN]: `Port`,
        [_xN]: _po
      }]]
    ];
    exports2.AnalysisPacketHeader$ = [
      3,
      n032,
      _APHn,
      0,
      [_DA, _DPR, _Pr10, _SA, _SPR],
      [[() => IpAddressList, {
        [_eQN]: `DestinationAddressSet`,
        [_xN]: _dAS
      }], [() => PortRangeList, {
        [_eQN]: `DestinationPortRangeSet`,
        [_xN]: _dPRS
      }], [0, {
        [_eQN]: `Protocol`,
        [_xN]: _pr
      }], [() => IpAddressList, {
        [_eQN]: `SourceAddressSet`,
        [_xN]: _sAS
      }], [() => PortRangeList, {
        [_eQN]: `SourcePortRangeSet`,
        [_xN]: _sPRS
      }]]
    ];
    exports2.AnalysisRouteTableRoute$ = [
      3,
      n032,
      _ARTR,
      0,
      [_DCe, _DPLI, _EOIGI, _GI2, _II2, _NGI, _NII, _O, _TGI, _VPCI, _St, _CGI, _CNA, _LGI],
      [[0, {
        [_eQN]: `DestinationCidr`,
        [_xN]: _dC4
      }], [0, {
        [_eQN]: `DestinationPrefixListId`,
        [_xN]: _dPLI
      }], [0, {
        [_eQN]: `EgressOnlyInternetGatewayId`,
        [_xN]: _eOIGI
      }], [0, {
        [_eQN]: `GatewayId`,
        [_xN]: _gI
      }], [0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `NatGatewayId`,
        [_xN]: _nGI
      }], [0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], [0, {
        [_eQN]: `Origin`,
        [_xN]: _o
      }], [0, {
        [_eQN]: `TransitGatewayId`,
        [_xN]: _tGI
      }], [0, {
        [_eQN]: `VpcPeeringConnectionId`,
        [_xN]: _vPCI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `CarrierGatewayId`,
        [_xN]: _cGI
      }], [0, {
        [_eQN]: `CoreNetworkArn`,
        [_xN]: _cNA
      }], [0, {
        [_eQN]: `LocalGatewayId`,
        [_xN]: _lGI
      }]]
    ];
    exports2.AnalysisSecurityGroupRule$ = [
      3,
      n032,
      _ASGR,
      0,
      [_Ci, _Di, _SGI, _PRo, _PLI, _Pr10],
      [[0, {
        [_eQN]: `Cidr`,
        [_xN]: _ci
      }], [0, {
        [_eQN]: `Direction`,
        [_xN]: _di
      }], [0, {
        [_eQN]: `SecurityGroupId`,
        [_xN]: _sGI
      }], [() => exports2.PortRange$, {
        [_eQN]: `PortRange`,
        [_xN]: _pRo
      }], [0, {
        [_eQN]: `PrefixListId`,
        [_xN]: _pLI
      }], [0, {
        [_eQN]: `Protocol`,
        [_xN]: _pr
      }]]
    ];
    exports2.ApplySecurityGroupsToClientVpnTargetNetworkRequest$ = [
      3,
      n032,
      _ASGTCVTNR,
      0,
      [_CVEI, _VI, _SGIe, _DR],
      [0, 0, [() => ClientVpnSecurityGroupIdSet, { [_xN]: _SGI }], 2],
      3
    ];
    exports2.ApplySecurityGroupsToClientVpnTargetNetworkResult$ = [
      3,
      n032,
      _ASGTCVTNRp,
      0,
      [_SGIe],
      [[() => ClientVpnSecurityGroupIdSet, {
        [_eQN]: `SecurityGroupIds`,
        [_xN]: _sGIe
      }]]
    ];
    exports2.AsnAssociation$ = [
      3,
      n032,
      _AAs,
      0,
      [_Asn, _Ci, _SMt, _St],
      [[0, {
        [_eQN]: `Asn`,
        [_xN]: _as
      }], [0, {
        [_eQN]: `Cidr`,
        [_xN]: _ci
      }], [0, {
        [_eQN]: `StatusMessage`,
        [_xN]: _sMt
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }]]
    ];
    exports2.AsnAuthorizationContext$ = [
      3,
      n032,
      _AAC,
      0,
      [_Me, _Si],
      [0, 0],
      2
    ];
    exports2.AssignedPrivateIpAddress$ = [
      3,
      n032,
      _APIA,
      0,
      [_PIAr],
      [[0, {
        [_eQN]: `PrivateIpAddress`,
        [_xN]: _pIAr
      }]]
    ];
    exports2.AssignIpv6AddressesRequest$ = [
      3,
      n032,
      _AIAR,
      0,
      [_NII, _IPC, _IPp, _IA, _IAC],
      [[0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], 1, [() => IpPrefixList, { [_xN]: _IPpv }], [() => Ipv6AddressList, {
        [_eQN]: `Ipv6Addresses`,
        [_xN]: _iA
      }], [1, {
        [_eQN]: `Ipv6AddressCount`,
        [_xN]: _iAC
      }]],
      1
    ];
    exports2.AssignIpv6AddressesResult$ = [
      3,
      n032,
      _AIARs,
      0,
      [_AIA, _AIP, _NII],
      [[() => Ipv6AddressList, {
        [_eQN]: `AssignedIpv6Addresses`,
        [_xN]: _aIA
      }], [() => IpPrefixList, {
        [_eQN]: `AssignedIpv6PrefixSet`,
        [_xN]: _aIPS
      }], [0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }]]
    ];
    exports2.AssignPrivateIpAddressesRequest$ = [
      3,
      n032,
      _APIAR,
      0,
      [_NII, _IPpvr, _IPCp, _PIAri, _SPIAC, _AR10],
      [[0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], [() => IpPrefixList, { [_xN]: _IPpvre }], 1, [() => PrivateIpAddressStringList, {
        [_eQN]: `PrivateIpAddress`,
        [_xN]: _pIAr
      }], [1, {
        [_eQN]: `SecondaryPrivateIpAddressCount`,
        [_xN]: _sPIAC
      }], [2, {
        [_eQN]: `AllowReassignment`,
        [_xN]: _aR
      }]],
      1
    ];
    exports2.AssignPrivateIpAddressesResult$ = [
      3,
      n032,
      _APIARs,
      0,
      [_NII, _APIAs, _AIPs],
      [[0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], [() => AssignedPrivateIpAddressList, {
        [_eQN]: `AssignedPrivateIpAddressesSet`,
        [_xN]: _aPIAS
      }], [() => Ipv4PrefixesList, {
        [_eQN]: `AssignedIpv4PrefixSet`,
        [_xN]: _aIPSs
      }]]
    ];
    exports2.AssignPrivateNatGatewayAddressRequest$ = [
      3,
      n032,
      _APNGAR,
      0,
      [_NGI, _PIAri, _PIAC, _DR],
      [0, [() => IpList, { [_xN]: _PIAr }], 1, 2],
      1
    ];
    exports2.AssignPrivateNatGatewayAddressResult$ = [
      3,
      n032,
      _APNGARs,
      0,
      [_NGI, _NGA],
      [[0, {
        [_eQN]: `NatGatewayId`,
        [_xN]: _nGI
      }], [() => NatGatewayAddressList, {
        [_eQN]: `NatGatewayAddressSet`,
        [_xN]: _nGAS
      }]]
    ];
    exports2.AssociateAddressRequest$ = [
      3,
      n032,
      _AARs,
      0,
      [_AIl, _II2, _PI10, _DR, _NII, _PIAr, _ARl],
      [0, 0, 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], [0, {
        [_eQN]: `PrivateIpAddress`,
        [_xN]: _pIAr
      }], [2, {
        [_eQN]: `AllowReassociation`,
        [_xN]: _aRl
      }]]
    ];
    exports2.AssociateAddressResult$ = [
      3,
      n032,
      _AARss,
      0,
      [_AIs],
      [[0, {
        [_eQN]: `AssociationId`,
        [_xN]: _aIs
      }]]
    ];
    exports2.AssociateCapacityReservationBillingOwnerRequest$ = [
      3,
      n032,
      _ACRBORs,
      0,
      [_CRI, _URBOI, _DR],
      [0, 0, 2],
      2
    ];
    exports2.AssociateCapacityReservationBillingOwnerResult$ = [
      3,
      n032,
      _ACRBORss,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.AssociateClientVpnTargetNetworkRequest$ = [
      3,
      n032,
      _ACVTNR,
      0,
      [_CVEI, _SIu, _CT4, _DR, _AZ, _AZI],
      [0, 0, [0, 4], 2, 0, 0],
      1
    ];
    exports2.AssociateClientVpnTargetNetworkResult$ = [
      3,
      n032,
      _ACVTNRs,
      0,
      [_AIs, _Sta],
      [[0, {
        [_eQN]: `AssociationId`,
        [_xN]: _aIs
      }], [() => exports2.AssociationStatus$, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }]]
    ];
    exports2.AssociateDhcpOptionsRequest$ = [
      3,
      n032,
      _ADOR,
      0,
      [_DOI, _VI, _DR],
      [0, 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      2
    ];
    exports2.AssociatedRole$ = [
      3,
      n032,
      _ARs,
      0,
      [_ARA, _CSBN, _CSOK, _EKKI],
      [[0, {
        [_eQN]: `AssociatedRoleArn`,
        [_xN]: _aRA
      }], [0, {
        [_eQN]: `CertificateS3BucketName`,
        [_xN]: _cSBN
      }], [0, {
        [_eQN]: `CertificateS3ObjectKey`,
        [_xN]: _cSOK
      }], [0, {
        [_eQN]: `EncryptionKmsKeyId`,
        [_xN]: _eKKI
      }]]
    ];
    exports2.AssociatedTargetNetwork$ = [
      3,
      n032,
      _ATN,
      0,
      [_NI, _NT],
      [[0, {
        [_eQN]: `NetworkId`,
        [_xN]: _nI
      }], [0, {
        [_eQN]: `NetworkType`,
        [_xN]: _nT
      }]]
    ];
    exports2.AssociateEnclaveCertificateIamRoleRequest$ = [
      3,
      n032,
      _AECIRR,
      0,
      [_CAe, _RAo, _DR],
      [0, 0, 2],
      2
    ];
    exports2.AssociateEnclaveCertificateIamRoleResult$ = [
      3,
      n032,
      _AECIRRs,
      0,
      [_CSBN, _CSOK, _EKKI],
      [[0, {
        [_eQN]: `CertificateS3BucketName`,
        [_xN]: _cSBN
      }], [0, {
        [_eQN]: `CertificateS3ObjectKey`,
        [_xN]: _cSOK
      }], [0, {
        [_eQN]: `EncryptionKmsKeyId`,
        [_xN]: _eKKI
      }]]
    ];
    exports2.AssociateIamInstanceProfileRequest$ = [
      3,
      n032,
      _AIIPR,
      0,
      [_IIP, _II2],
      [[() => exports2.IamInstanceProfileSpecification$, 0], 0],
      2
    ];
    exports2.AssociateIamInstanceProfileResult$ = [
      3,
      n032,
      _AIIPRs,
      0,
      [_IIPA],
      [[() => exports2.IamInstanceProfileAssociation$, {
        [_eQN]: `IamInstanceProfileAssociation`,
        [_xN]: _iIPA
      }]]
    ];
    exports2.AssociateInstanceEventWindowRequest$ = [
      3,
      n032,
      _AIEWR,
      0,
      [_IEWI, _ATs, _DR],
      [0, [() => exports2.InstanceEventWindowAssociationRequest$, 0], 2],
      2
    ];
    exports2.AssociateInstanceEventWindowResult$ = [
      3,
      n032,
      _AIEWRs,
      0,
      [_IEW],
      [[() => exports2.InstanceEventWindow$, {
        [_eQN]: `InstanceEventWindow`,
        [_xN]: _iEW
      }]]
    ];
    exports2.AssociateIpamByoasnRequest$ = [
      3,
      n032,
      _AIBR,
      0,
      [_Asn, _Ci, _DR],
      [0, 0, 2],
      2
    ];
    exports2.AssociateIpamByoasnResult$ = [
      3,
      n032,
      _AIBRs,
      0,
      [_AAs],
      [[() => exports2.AsnAssociation$, {
        [_eQN]: `AsnAssociation`,
        [_xN]: _aA
      }]]
    ];
    exports2.AssociateIpamResourceDiscoveryRequest$ = [
      3,
      n032,
      _AIRDR,
      0,
      [_IIp, _IRDI, _DR, _TS, _CT4],
      [0, 0, 2, [() => TagSpecificationList, { [_xN]: _TSa }], [0, 4]],
      2
    ];
    exports2.AssociateIpamResourceDiscoveryResult$ = [
      3,
      n032,
      _AIRDRs,
      0,
      [_IRDA],
      [[() => exports2.IpamResourceDiscoveryAssociation$, {
        [_eQN]: `IpamResourceDiscoveryAssociation`,
        [_xN]: _iRDA
      }]]
    ];
    exports2.AssociateNatGatewayAddressRequest$ = [
      3,
      n032,
      _ANGAR,
      0,
      [_NGI, _AIll, _PIAri, _DR, _AZ, _AZI],
      [0, [() => AllocationIdList, { [_xN]: _AIl }], [() => IpList, { [_xN]: _PIAr }], 2, 0, 0],
      2
    ];
    exports2.AssociateNatGatewayAddressResult$ = [
      3,
      n032,
      _ANGARs,
      0,
      [_NGI, _NGA],
      [[0, {
        [_eQN]: `NatGatewayId`,
        [_xN]: _nGI
      }], [() => NatGatewayAddressList, {
        [_eQN]: `NatGatewayAddressSet`,
        [_xN]: _nGAS
      }]]
    ];
    exports2.AssociateRouteServerRequest$ = [
      3,
      n032,
      _ARSR,
      0,
      [_RSI, _VI, _DR],
      [0, 0, 2],
      2
    ];
    exports2.AssociateRouteServerResult$ = [
      3,
      n032,
      _ARSRs,
      0,
      [_RSA],
      [[() => exports2.RouteServerAssociation$, {
        [_eQN]: `RouteServerAssociation`,
        [_xN]: _rSA
      }]]
    ];
    exports2.AssociateRouteTableRequest$ = [
      3,
      n032,
      _ARTRs,
      0,
      [_RTI, _GI2, _PIP, _DR, _SIu],
      [[0, {
        [_eQN]: `RouteTableId`,
        [_xN]: _rTI
      }], 0, 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }]],
      1
    ];
    exports2.AssociateRouteTableResult$ = [
      3,
      n032,
      _ARTRss,
      0,
      [_AIs, _AS],
      [[0, {
        [_eQN]: `AssociationId`,
        [_xN]: _aIs
      }], [() => exports2.RouteTableAssociationState$, {
        [_eQN]: `AssociationState`,
        [_xN]: _aS
      }]]
    ];
    exports2.AssociateSecurityGroupVpcRequest$ = [
      3,
      n032,
      _ASGVR,
      0,
      [_GIr, _VI, _DR],
      [0, 0, 2],
      2
    ];
    exports2.AssociateSecurityGroupVpcResult$ = [
      3,
      n032,
      _ASGVRs,
      0,
      [_St],
      [[0, {
        [_eQN]: `State`,
        [_xN]: _st
      }]]
    ];
    exports2.AssociateSubnetCidrBlockRequest$ = [
      3,
      n032,
      _ASCBR,
      0,
      [_SIu, _IIPI, _INL, _ICB],
      [[0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }], 0, 1, [0, {
        [_eQN]: `Ipv6CidrBlock`,
        [_xN]: _iCB
      }]],
      1
    ];
    exports2.AssociateSubnetCidrBlockResult$ = [
      3,
      n032,
      _ASCBRs,
      0,
      [_ICBA, _SIu],
      [[() => exports2.SubnetIpv6CidrBlockAssociation$, {
        [_eQN]: `Ipv6CidrBlockAssociation`,
        [_xN]: _iCBA
      }], [0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }]]
    ];
    exports2.AssociateTransitGatewayMulticastDomainRequest$ = [
      3,
      n032,
      _ATGMDR,
      0,
      [_TGMDI, _TGAI, _SI10, _DR],
      [0, 0, [() => TransitGatewaySubnetIdList, 0], 2],
      3
    ];
    exports2.AssociateTransitGatewayMulticastDomainResult$ = [
      3,
      n032,
      _ATGMDRs,
      0,
      [_As],
      [[() => exports2.TransitGatewayMulticastDomainAssociations$, {
        [_eQN]: `Associations`,
        [_xN]: _a10
      }]]
    ];
    exports2.AssociateTransitGatewayPolicyTableRequest$ = [
      3,
      n032,
      _ATGPTR,
      0,
      [_TGPTI, _TGAI, _DR],
      [0, 0, 2],
      2
    ];
    exports2.AssociateTransitGatewayPolicyTableResult$ = [
      3,
      n032,
      _ATGPTRs,
      0,
      [_Ass],
      [[() => exports2.TransitGatewayPolicyTableAssociation$, {
        [_eQN]: `Association`,
        [_xN]: _ass
      }]]
    ];
    exports2.AssociateTransitGatewayRouteTableRequest$ = [
      3,
      n032,
      _ATGRTR,
      0,
      [_TGRTI, _TGAI, _DR],
      [0, 0, 2],
      2
    ];
    exports2.AssociateTransitGatewayRouteTableResult$ = [
      3,
      n032,
      _ATGRTRs,
      0,
      [_Ass],
      [[() => exports2.TransitGatewayAssociation$, {
        [_eQN]: `Association`,
        [_xN]: _ass
      }]]
    ];
    exports2.AssociateTrunkInterfaceRequest$ = [
      3,
      n032,
      _ATIR,
      0,
      [_BII, _TII, _VIl, _GK, _CT4, _DR],
      [0, 0, 1, 1, [0, 4], 2],
      2
    ];
    exports2.AssociateTrunkInterfaceResult$ = [
      3,
      n032,
      _ATIRs,
      0,
      [_IAn, _CT4],
      [[() => exports2.TrunkInterfaceAssociation$, {
        [_eQN]: `InterfaceAssociation`,
        [_xN]: _iAn
      }], [0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }]]
    ];
    exports2.AssociateVpcCidrBlockRequest$ = [
      3,
      n032,
      _AVCBR,
      0,
      [_VI, _CB, _ICBNBG, _IPpvo, _ICB, _IIPIp, _INLp, _IIPI, _INL, _APICB],
      [[0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], 0, 0, 0, 0, 0, 1, 0, 1, [2, {
        [_eQN]: `AmazonProvidedIpv6CidrBlock`,
        [_xN]: _aPICB
      }]],
      1
    ];
    exports2.AssociateVpcCidrBlockResult$ = [
      3,
      n032,
      _AVCBRs,
      0,
      [_ICBA, _CBA, _VI],
      [[() => exports2.VpcIpv6CidrBlockAssociation$, {
        [_eQN]: `Ipv6CidrBlockAssociation`,
        [_xN]: _iCBA
      }], [() => exports2.VpcCidrBlockAssociation$, {
        [_eQN]: `CidrBlockAssociation`,
        [_xN]: _cBA
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }]]
    ];
    exports2.AssociationStatus$ = [
      3,
      n032,
      _ASs,
      0,
      [_Co, _Me],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }]]
    ];
    exports2.AthenaIntegration$ = [
      3,
      n032,
      _AIt,
      0,
      [_IRSDA, _PLF, _PSD, _PED],
      [0, 0, 4, 4],
      2
    ];
    exports2.AttachClassicLinkVpcRequest$ = [
      3,
      n032,
      _ACLVR,
      0,
      [_II2, _VI, _G, _DR],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [() => GroupIdStringList, { [_xN]: _SGI }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      3
    ];
    exports2.AttachClassicLinkVpcResult$ = [
      3,
      n032,
      _ACLVRt,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.AttachInternetGatewayRequest$ = [
      3,
      n032,
      _AIGR,
      0,
      [_IGI, _VI, _DR],
      [[0, {
        [_eQN]: `InternetGatewayId`,
        [_xN]: _iGI
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      2
    ];
    exports2.AttachmentEnaSrdSpecification$ = [
      3,
      n032,
      _AESS,
      0,
      [_ESE2, _ESUS],
      [[2, {
        [_eQN]: `EnaSrdEnabled`,
        [_xN]: _eSE
      }], [() => exports2.AttachmentEnaSrdUdpSpecification$, {
        [_eQN]: `EnaSrdUdpSpecification`,
        [_xN]: _eSUS
      }]]
    ];
    exports2.AttachmentEnaSrdUdpSpecification$ = [
      3,
      n032,
      _AESUS,
      0,
      [_ESUE],
      [[2, {
        [_eQN]: `EnaSrdUdpEnabled`,
        [_xN]: _eSUE
      }]]
    ];
    exports2.AttachNetworkInterfaceRequest$ = [
      3,
      n032,
      _ANIR,
      0,
      [_NII, _II2, _DI, _NCI, _ESS, _EQC, _DR],
      [[0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], [0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [1, {
        [_eQN]: `DeviceIndex`,
        [_xN]: _dI
      }], 1, () => exports2.EnaSrdSpecification$, 1, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      3
    ];
    exports2.AttachNetworkInterfaceResult$ = [
      3,
      n032,
      _ANIRt,
      0,
      [_AItt, _NCI],
      [[0, {
        [_eQN]: `AttachmentId`,
        [_xN]: _aIt
      }], [1, {
        [_eQN]: `NetworkCardIndex`,
        [_xN]: _nCI
      }]]
    ];
    exports2.AttachVerifiedAccessTrustProviderRequest$ = [
      3,
      n032,
      _AVATPR,
      0,
      [_VAII, _VATPI, _CT4, _DR],
      [0, 0, [0, 4], 2],
      2
    ];
    exports2.AttachVerifiedAccessTrustProviderResult$ = [
      3,
      n032,
      _AVATPRt,
      0,
      [_VATP, _VAI],
      [[() => exports2.VerifiedAccessTrustProvider$, {
        [_eQN]: `VerifiedAccessTrustProvider`,
        [_xN]: _vATP
      }], [() => exports2.VerifiedAccessInstance$, {
        [_eQN]: `VerifiedAccessInstance`,
        [_xN]: _vAI
      }]]
    ];
    exports2.AttachVolumeRequest$ = [
      3,
      n032,
      _AVR,
      0,
      [_Dev, _II2, _VIo, _ECI, _DR],
      [0, 0, 0, 1, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      3
    ];
    exports2.AttachVpnGatewayRequest$ = [
      3,
      n032,
      _AVGR,
      0,
      [_VI, _VGI, _DR],
      [0, 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      2
    ];
    exports2.AttachVpnGatewayResult$ = [
      3,
      n032,
      _AVGRt,
      0,
      [_VA],
      [[() => exports2.VpcAttachment$, {
        [_eQN]: `Attachment`,
        [_xN]: _at
      }]]
    ];
    exports2.AttributeBooleanValue$ = [
      3,
      n032,
      _ABV,
      0,
      [_V10],
      [[2, {
        [_eQN]: `Value`,
        [_xN]: _v
      }]]
    ];
    exports2.AttributeSummary$ = [
      3,
      n032,
      _ASt,
      0,
      [_AN, _MFV, _NOMA, _NOUA, _RS],
      [[0, {
        [_eQN]: `AttributeName`,
        [_xN]: _aN
      }], [0, {
        [_eQN]: `MostFrequentValue`,
        [_xN]: _mFV
      }], [1, {
        [_eQN]: `NumberOfMatchedAccounts`,
        [_xN]: _nOMA
      }], [1, {
        [_eQN]: `NumberOfUnmatchedAccounts`,
        [_xN]: _nOUA
      }], [() => RegionalSummaryList, {
        [_eQN]: `RegionalSummarySet`,
        [_xN]: _rSS
      }]]
    ];
    exports2.AttributeValue$ = [
      3,
      n032,
      _AVt,
      0,
      [_V10],
      [[0, {
        [_eQN]: `Value`,
        [_xN]: _v
      }]]
    ];
    exports2.AuthorizationRule$ = [
      3,
      n032,
      _ARu,
      0,
      [_CVEI, _De, _GIr, _AAc, _DCe, _Sta],
      [[0, {
        [_eQN]: `ClientVpnEndpointId`,
        [_xN]: _cVEI
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [0, {
        [_eQN]: `GroupId`,
        [_xN]: _gIr
      }], [2, {
        [_eQN]: `AccessAll`,
        [_xN]: _aAc
      }], [0, {
        [_eQN]: `DestinationCidr`,
        [_xN]: _dC4
      }], [() => exports2.ClientVpnAuthorizationRuleStatus$, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }]]
    ];
    exports2.AuthorizeClientVpnIngressRequest$ = [
      3,
      n032,
      _ACVIR,
      0,
      [_CVEI, _TNC, _AGI, _AAG, _De, _CT4, _DR],
      [0, 0, 0, 2, 0, [0, 4], 2],
      2
    ];
    exports2.AuthorizeClientVpnIngressResult$ = [
      3,
      n032,
      _ACVIRu,
      0,
      [_Sta],
      [[() => exports2.ClientVpnAuthorizationRuleStatus$, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }]]
    ];
    exports2.AuthorizeSecurityGroupEgressRequest$ = [
      3,
      n032,
      _ASGER,
      0,
      [_GIr, _TS, _DR, _SSGN, _SSGOI, _IPpr, _FP, _TP, _CIi, _IPpe],
      [[0, {
        [_eQN]: `GroupId`,
        [_xN]: _gIr
      }], [() => TagSpecificationList, { [_xN]: _TSa }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [0, {
        [_eQN]: `SourceSecurityGroupName`,
        [_xN]: _sSGN
      }], [0, {
        [_eQN]: `SourceSecurityGroupOwnerId`,
        [_xN]: _sSGOI
      }], [0, {
        [_eQN]: `IpProtocol`,
        [_xN]: _iPp
      }], [1, {
        [_eQN]: `FromPort`,
        [_xN]: _fP
      }], [1, {
        [_eQN]: `ToPort`,
        [_xN]: _tP
      }], [0, {
        [_eQN]: `CidrIp`,
        [_xN]: _cIi
      }], [() => IpPermissionList, {
        [_eQN]: `IpPermissions`,
        [_xN]: _iPpe
      }]],
      1
    ];
    exports2.AuthorizeSecurityGroupEgressResult$ = [
      3,
      n032,
      _ASGERu,
      0,
      [_R, _SGR],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }], [() => SecurityGroupRuleList, {
        [_eQN]: `SecurityGroupRuleSet`,
        [_xN]: _sGRS
      }]]
    ];
    exports2.AuthorizeSecurityGroupIngressRequest$ = [
      3,
      n032,
      _ASGIR,
      0,
      [_CIi, _FP, _GIr, _GN, _IPpe, _IPpr, _SSGN, _SSGOI, _TP, _TS, _DR],
      [0, 1, 0, 0, [() => IpPermissionList, 0], 0, 0, 0, 1, [() => TagSpecificationList, { [_xN]: _TSa }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]]
    ];
    exports2.AuthorizeSecurityGroupIngressResult$ = [
      3,
      n032,
      _ASGIRu,
      0,
      [_R, _SGR],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }], [() => SecurityGroupRuleList, {
        [_eQN]: `SecurityGroupRuleSet`,
        [_xN]: _sGRS
      }]]
    ];
    exports2.AvailabilityZone$ = [
      3,
      n032,
      _AZ,
      0,
      [_OIS, _Mes, _RN, _ZN, _ZI, _GN, _NBG, _ZT, _PZN, _PZI, _GLN, _Ge, _SG, _St],
      [[0, {
        [_eQN]: `OptInStatus`,
        [_xN]: _oIS
      }], [() => AvailabilityZoneMessageList, {
        [_eQN]: `MessageSet`,
        [_xN]: _mS
      }], [0, {
        [_eQN]: `RegionName`,
        [_xN]: _rNe
      }], [0, {
        [_eQN]: `ZoneName`,
        [_xN]: _zN
      }], [0, {
        [_eQN]: `ZoneId`,
        [_xN]: _zI
      }], [0, {
        [_eQN]: `GroupName`,
        [_xN]: _gN
      }], [0, {
        [_eQN]: `NetworkBorderGroup`,
        [_xN]: _nBG
      }], [0, {
        [_eQN]: `ZoneType`,
        [_xN]: _zT
      }], [0, {
        [_eQN]: `ParentZoneName`,
        [_xN]: _pZN
      }], [0, {
        [_eQN]: `ParentZoneId`,
        [_xN]: _pZI
      }], [0, {
        [_eQN]: `GroupLongName`,
        [_xN]: _gLN
      }], [() => AvailabilityZoneGeographyList, {
        [_eQN]: `GeographySet`,
        [_xN]: _gS
      }], [() => AvailabilityZoneSubGeographyList, {
        [_eQN]: `SubGeographySet`,
        [_xN]: _sGS
      }], [0, {
        [_eQN]: `ZoneState`,
        [_xN]: _zS
      }]]
    ];
    exports2.AvailabilityZoneAddress$ = [
      3,
      n032,
      _AZA,
      0,
      [_AZ, _AZI, _AIll],
      [0, 0, [() => AllocationIdList, { [_xN]: _AIl }]]
    ];
    exports2.AvailabilityZoneGeography$ = [
      3,
      n032,
      _AZG,
      0,
      [_N],
      [[0, {
        [_eQN]: `Name`,
        [_xN]: _n
      }]]
    ];
    exports2.AvailabilityZoneMessage$ = [
      3,
      n032,
      _AZM,
      0,
      [_Me],
      [[0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }]]
    ];
    exports2.AvailabilityZoneSubGeography$ = [
      3,
      n032,
      _AZSG,
      0,
      [_N],
      [[0, {
        [_eQN]: `Name`,
        [_xN]: _n
      }]]
    ];
    exports2.AvailableCapacity$ = [
      3,
      n032,
      _ACv,
      0,
      [_AIC, _AVC],
      [[() => AvailableInstanceCapacityList, {
        [_eQN]: `AvailableInstanceCapacity`,
        [_xN]: _aIC
      }], [1, {
        [_eQN]: `AvailableVCpus`,
        [_xN]: _aVC
      }]]
    ];
    exports2.BaselineEbsBandwidthMbps$ = [
      3,
      n032,
      _BEBM,
      0,
      [_M, _Ma],
      [[1, {
        [_eQN]: `Min`,
        [_xN]: _m29
      }], [1, {
        [_eQN]: `Max`,
        [_xN]: _ma
      }]]
    ];
    exports2.BaselineEbsBandwidthMbpsRequest$ = [
      3,
      n032,
      _BEBMR,
      0,
      [_M, _Ma],
      [1, 1]
    ];
    exports2.BaselinePerformanceFactors$ = [
      3,
      n032,
      _BPF,
      0,
      [_Cp],
      [[() => exports2.CpuPerformanceFactor$, {
        [_eQN]: `Cpu`,
        [_xN]: _cp
      }]]
    ];
    exports2.BaselinePerformanceFactorsRequest$ = [
      3,
      n032,
      _BPFR,
      0,
      [_Cp],
      [[() => exports2.CpuPerformanceFactorRequest$, 0]]
    ];
    exports2.BlobAttributeValue$ = [
      3,
      n032,
      _BAV,
      0,
      [_V10],
      [[21, {
        [_eQN]: `Value`,
        [_xN]: _v
      }]]
    ];
    exports2.BlockDeviceMapping$ = [
      3,
      n032,
      _BDM,
      0,
      [_Eb, _ND, _DN, _VN],
      [[() => exports2.EbsBlockDevice$, {
        [_eQN]: `Ebs`,
        [_xN]: _eb
      }], [0, {
        [_eQN]: `NoDevice`,
        [_xN]: _nD
      }], [0, {
        [_eQN]: `DeviceName`,
        [_xN]: _dN
      }], [0, {
        [_eQN]: `VirtualName`,
        [_xN]: _vN
      }]]
    ];
    exports2.BlockDeviceMappingResponse$ = [
      3,
      n032,
      _BDMR,
      0,
      [_DN, _VN, _Eb, _ND],
      [[0, {
        [_eQN]: `DeviceName`,
        [_xN]: _dN
      }], [0, {
        [_eQN]: `VirtualName`,
        [_xN]: _vN
      }], [() => exports2.EbsBlockDeviceResponse$, {
        [_eQN]: `Ebs`,
        [_xN]: _eb
      }], [0, {
        [_eQN]: `NoDevice`,
        [_xN]: _nD
      }]]
    ];
    exports2.BlockPublicAccessStates$ = [
      3,
      n032,
      _BPAS,
      0,
      [_IGBM],
      [[0, {
        [_eQN]: `InternetGatewayBlockMode`,
        [_xN]: _iGBM
      }]]
    ];
    exports2.BundleInstanceRequest$ = [
      3,
      n032,
      _BIR,
      0,
      [_II2, _Sto, _DR],
      [0, [() => exports2.Storage$, 0], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      2
    ];
    exports2.BundleInstanceResult$ = [
      3,
      n032,
      _BIRu,
      0,
      [_BT],
      [[() => exports2.BundleTask$, {
        [_eQN]: `BundleInstanceTask`,
        [_xN]: _bIT
      }]]
    ];
    exports2.BundleTask$ = [
      3,
      n032,
      _BT,
      0,
      [_II2, _BI, _St, _ST11, _UT, _Sto, _Pro, _BTE],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `BundleId`,
        [_xN]: _bI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [4, {
        [_eQN]: `StartTime`,
        [_xN]: _sT19
      }], [4, {
        [_eQN]: `UpdateTime`,
        [_xN]: _uT
      }], [() => exports2.Storage$, {
        [_eQN]: `Storage`,
        [_xN]: _sto
      }], [0, {
        [_eQN]: `Progress`,
        [_xN]: _pro
      }], [() => exports2.BundleTaskError$, {
        [_eQN]: `Error`,
        [_xN]: _er
      }]]
    ];
    exports2.BundleTaskError$ = [
      3,
      n032,
      _BTE,
      0,
      [_Co, _Me],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }]]
    ];
    exports2.Byoasn$ = [
      3,
      n032,
      _B,
      0,
      [_Asn, _IIp, _SMt, _St],
      [[0, {
        [_eQN]: `Asn`,
        [_xN]: _as
      }], [0, {
        [_eQN]: `IpamId`,
        [_xN]: _iIp
      }], [0, {
        [_eQN]: `StatusMessage`,
        [_xN]: _sMt
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }]]
    ];
    exports2.ByoipCidr$ = [
      3,
      n032,
      _BC,
      0,
      [_Ci, _De, _AAsn, _SMt, _St, _NBG, _ATd],
      [[0, {
        [_eQN]: `Cidr`,
        [_xN]: _ci
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [() => AsnAssociationSet, {
        [_eQN]: `AsnAssociationSet`,
        [_xN]: _aAS
      }], [0, {
        [_eQN]: `StatusMessage`,
        [_xN]: _sMt
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `NetworkBorderGroup`,
        [_xN]: _nBG
      }], [0, {
        [_eQN]: `AdvertisementType`,
        [_xN]: _aTd
      }]]
    ];
    exports2.CancelBundleTaskRequest$ = [
      3,
      n032,
      _CBTR,
      0,
      [_BI, _DR],
      [0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.CancelBundleTaskResult$ = [
      3,
      n032,
      _CBTRa,
      0,
      [_BT],
      [[() => exports2.BundleTask$, {
        [_eQN]: `BundleInstanceTask`,
        [_xN]: _bIT
      }]]
    ];
    exports2.CancelCapacityReservationFleetError$ = [
      3,
      n032,
      _CCRFE,
      0,
      [_Co, _Me],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }]]
    ];
    exports2.CancelCapacityReservationFleetsRequest$ = [
      3,
      n032,
      _CCRFR,
      0,
      [_CRFI, _DR],
      [[() => CapacityReservationFleetIdSet, { [_xN]: _CRFIa }], 2],
      1
    ];
    exports2.CancelCapacityReservationFleetsResult$ = [
      3,
      n032,
      _CCRFRa,
      0,
      [_SFC, _FFC],
      [[() => CapacityReservationFleetCancellationStateSet, {
        [_eQN]: `SuccessfulFleetCancellationSet`,
        [_xN]: _sFCS
      }], [() => FailedCapacityReservationFleetCancellationResultSet, {
        [_eQN]: `FailedFleetCancellationSet`,
        [_xN]: _fFCS
      }]]
    ];
    exports2.CancelCapacityReservationRequest$ = [
      3,
      n032,
      _CCRR,
      0,
      [_CRI, _DR],
      [0, 2],
      1
    ];
    exports2.CancelCapacityReservationResult$ = [
      3,
      n032,
      _CCRRa,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.CancelConversionRequest$ = [
      3,
      n032,
      _CCR,
      0,
      [_CTI, _DR, _RM],
      [[0, {
        [_eQN]: `ConversionTaskId`,
        [_xN]: _cTI
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [0, {
        [_eQN]: `ReasonMessage`,
        [_xN]: _rM
      }]],
      1
    ];
    exports2.CancelDeclarativePoliciesReportRequest$ = [
      3,
      n032,
      _CDPRR,
      0,
      [_RI, _DR],
      [0, 2],
      1
    ];
    exports2.CancelDeclarativePoliciesReportResult$ = [
      3,
      n032,
      _CDPRRa,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.CancelExportTaskRequest$ = [
      3,
      n032,
      _CETR,
      0,
      [_ETI],
      [[0, {
        [_eQN]: `ExportTaskId`,
        [_xN]: _eTI
      }]],
      1
    ];
    exports2.CancelImageLaunchPermissionRequest$ = [
      3,
      n032,
      _CILPR,
      0,
      [_IIm, _DR],
      [0, 2],
      1
    ];
    exports2.CancelImageLaunchPermissionResult$ = [
      3,
      n032,
      _CILPRa,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.CancelImportTaskRequest$ = [
      3,
      n032,
      _CITR,
      0,
      [_CR, _DR, _ITI],
      [0, 2, 0]
    ];
    exports2.CancelImportTaskResult$ = [
      3,
      n032,
      _CITRa,
      0,
      [_ITI, _PSr, _St],
      [[0, {
        [_eQN]: `ImportTaskId`,
        [_xN]: _iTI
      }], [0, {
        [_eQN]: `PreviousState`,
        [_xN]: _pSr
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }]]
    ];
    exports2.CancelledSpotInstanceRequest$ = [
      3,
      n032,
      _CSIR,
      0,
      [_SIRI, _St],
      [[0, {
        [_eQN]: `SpotInstanceRequestId`,
        [_xN]: _sIRI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }]]
    ];
    exports2.CancelReservedInstancesListingRequest$ = [
      3,
      n032,
      _CRILR,
      0,
      [_RILI],
      [[0, {
        [_eQN]: `ReservedInstancesListingId`,
        [_xN]: _rILI
      }]],
      1
    ];
    exports2.CancelReservedInstancesListingResult$ = [
      3,
      n032,
      _CRILRa,
      0,
      [_RIL],
      [[() => ReservedInstancesListingList, {
        [_eQN]: `ReservedInstancesListingsSet`,
        [_xN]: _rILS
      }]]
    ];
    exports2.CancelSpotFleetRequestsError$ = [
      3,
      n032,
      _CSFRE,
      0,
      [_Co, _Me],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }]]
    ];
    exports2.CancelSpotFleetRequestsErrorItem$ = [
      3,
      n032,
      _CSFREI,
      0,
      [_Er, _SFRI],
      [[() => exports2.CancelSpotFleetRequestsError$, {
        [_eQN]: `Error`,
        [_xN]: _er
      }], [0, {
        [_eQN]: `SpotFleetRequestId`,
        [_xN]: _sFRI
      }]]
    ];
    exports2.CancelSpotFleetRequestsRequest$ = [
      3,
      n032,
      _CSFRR,
      0,
      [_SFRIp, _TI, _DR],
      [[() => SpotFleetRequestIdList, {
        [_eQN]: `SpotFleetRequestId`,
        [_xN]: _sFRI
      }], [2, {
        [_eQN]: `TerminateInstances`,
        [_xN]: _tI10
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      2
    ];
    exports2.CancelSpotFleetRequestsResponse$ = [
      3,
      n032,
      _CSFRRa,
      0,
      [_SFR, _UFR],
      [[() => CancelSpotFleetRequestsSuccessSet, {
        [_eQN]: `SuccessfulFleetRequestSet`,
        [_xN]: _sFRS
      }], [() => CancelSpotFleetRequestsErrorSet, {
        [_eQN]: `UnsuccessfulFleetRequestSet`,
        [_xN]: _uFRS
      }]]
    ];
    exports2.CancelSpotFleetRequestsSuccessItem$ = [
      3,
      n032,
      _CSFRSI,
      0,
      [_CSFRS, _PSFRS, _SFRI],
      [[0, {
        [_eQN]: `CurrentSpotFleetRequestState`,
        [_xN]: _cSFRS
      }], [0, {
        [_eQN]: `PreviousSpotFleetRequestState`,
        [_xN]: _pSFRS
      }], [0, {
        [_eQN]: `SpotFleetRequestId`,
        [_xN]: _sFRI
      }]]
    ];
    exports2.CancelSpotInstanceRequestsRequest$ = [
      3,
      n032,
      _CSIRR,
      0,
      [_SIRIp, _DR],
      [[() => SpotInstanceRequestIdList, { [_xN]: _SIRI }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.CancelSpotInstanceRequestsResult$ = [
      3,
      n032,
      _CSIRRa,
      0,
      [_CSIRa],
      [[() => CancelledSpotInstanceRequestList, {
        [_eQN]: `SpotInstanceRequestSet`,
        [_xN]: _sIRS
      }]]
    ];
    exports2.CapacityAllocation$ = [
      3,
      n032,
      _CAa,
      0,
      [_ATl, _Cou, _AM],
      [[0, {
        [_eQN]: `AllocationType`,
        [_xN]: _aTl
      }], [1, {
        [_eQN]: `Count`,
        [_xN]: _cou
      }], [() => CapacityAllocationMetadataList, {
        [_eQN]: `AllocationMetadataList`,
        [_xN]: _aML
      }]]
    ];
    exports2.CapacityAllocationMetadataEntry$ = [
      3,
      n032,
      _CAME,
      0,
      [_K10, _V10],
      [[0, {
        [_eQN]: `Key`,
        [_xN]: _k
      }], [0, {
        [_eQN]: `Value`,
        [_xN]: _v
      }]]
    ];
    exports2.CapacityBlock$ = [
      3,
      n032,
      _CBa,
      0,
      [_CBI, _UTl, _AZ, _AZI, _CRIa, _SD, _ED, _CD, _St, _T10],
      [[0, {
        [_eQN]: `CapacityBlockId`,
        [_xN]: _cBI
      }], [0, {
        [_eQN]: `UltraserverType`,
        [_xN]: _uTl
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [() => CapacityReservationIdSet, {
        [_eQN]: `CapacityReservationIdSet`,
        [_xN]: _cRIS
      }], [4, {
        [_eQN]: `StartDate`,
        [_xN]: _sD
      }], [4, {
        [_eQN]: `EndDate`,
        [_xN]: _eD
      }], [4, {
        [_eQN]: `CreateDate`,
        [_xN]: _cD
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.CapacityBlockExtension$ = [
      3,
      n032,
      _CBE,
      0,
      [_CRI, _IT4, _IC, _AZ, _AZI, _CBEOI, _CBEDH, _CBES, _CBEPD, _CBESD, _CBEED, _UF, _CC, _ZT],
      [[0, {
        [_eQN]: `CapacityReservationId`,
        [_xN]: _cRI
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [1, {
        [_eQN]: `InstanceCount`,
        [_xN]: _iC
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [0, {
        [_eQN]: `CapacityBlockExtensionOfferingId`,
        [_xN]: _cBEOI
      }], [1, {
        [_eQN]: `CapacityBlockExtensionDurationHours`,
        [_xN]: _cBEDH
      }], [0, {
        [_eQN]: `CapacityBlockExtensionStatus`,
        [_xN]: _cBES
      }], [4, {
        [_eQN]: `CapacityBlockExtensionPurchaseDate`,
        [_xN]: _cBEPD
      }], [4, {
        [_eQN]: `CapacityBlockExtensionStartDate`,
        [_xN]: _cBESD
      }], [4, {
        [_eQN]: `CapacityBlockExtensionEndDate`,
        [_xN]: _cBEED
      }], [0, {
        [_eQN]: `UpfrontFee`,
        [_xN]: _uF
      }], [0, {
        [_eQN]: `CurrencyCode`,
        [_xN]: _cC
      }], [0, {
        [_eQN]: `ZoneType`,
        [_xN]: _zT
      }]]
    ];
    exports2.CapacityBlockExtensionOffering$ = [
      3,
      n032,
      _CBEO,
      0,
      [_CBEOI, _IT4, _IC, _AZ, _AZI, _SD, _CBESD, _CBEED, _CBEDH, _UF, _CC, _Te, _ZT],
      [[0, {
        [_eQN]: `CapacityBlockExtensionOfferingId`,
        [_xN]: _cBEOI
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [1, {
        [_eQN]: `InstanceCount`,
        [_xN]: _iC
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [4, {
        [_eQN]: `StartDate`,
        [_xN]: _sD
      }], [4, {
        [_eQN]: `CapacityBlockExtensionStartDate`,
        [_xN]: _cBESD
      }], [4, {
        [_eQN]: `CapacityBlockExtensionEndDate`,
        [_xN]: _cBEED
      }], [1, {
        [_eQN]: `CapacityBlockExtensionDurationHours`,
        [_xN]: _cBEDH
      }], [0, {
        [_eQN]: `UpfrontFee`,
        [_xN]: _uF
      }], [0, {
        [_eQN]: `CurrencyCode`,
        [_xN]: _cC
      }], [0, {
        [_eQN]: `Tenancy`,
        [_xN]: _t
      }], [0, {
        [_eQN]: `ZoneType`,
        [_xN]: _zT
      }]]
    ];
    exports2.CapacityBlockOffering$ = [
      3,
      n032,
      _CBO,
      0,
      [_CBOI, _IT4, _AZ, _IC, _SD, _ED, _CBDH, _UF, _CC, _Te, _UTl, _UC, _CBDM, _ZT],
      [[0, {
        [_eQN]: `CapacityBlockOfferingId`,
        [_xN]: _cBOI
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [1, {
        [_eQN]: `InstanceCount`,
        [_xN]: _iC
      }], [4, {
        [_eQN]: `StartDate`,
        [_xN]: _sD
      }], [4, {
        [_eQN]: `EndDate`,
        [_xN]: _eD
      }], [1, {
        [_eQN]: `CapacityBlockDurationHours`,
        [_xN]: _cBDH
      }], [0, {
        [_eQN]: `UpfrontFee`,
        [_xN]: _uF
      }], [0, {
        [_eQN]: `CurrencyCode`,
        [_xN]: _cC
      }], [0, {
        [_eQN]: `Tenancy`,
        [_xN]: _t
      }], [0, {
        [_eQN]: `UltraserverType`,
        [_xN]: _uTl
      }], [1, {
        [_eQN]: `UltraserverCount`,
        [_xN]: _uC
      }], [1, {
        [_eQN]: `CapacityBlockDurationMinutes`,
        [_xN]: _cBDM
      }], [0, {
        [_eQN]: `ZoneType`,
        [_xN]: _zT
      }]]
    ];
    exports2.CapacityBlockStatus$ = [
      3,
      n032,
      _CBS,
      0,
      [_CBI, _IS, _TCo, _TAC, _TUC, _CRS],
      [[0, {
        [_eQN]: `CapacityBlockId`,
        [_xN]: _cBI
      }], [0, {
        [_eQN]: `InterconnectStatus`,
        [_xN]: _iS
      }], [1, {
        [_eQN]: `TotalCapacity`,
        [_xN]: _tC
      }], [1, {
        [_eQN]: `TotalAvailableCapacity`,
        [_xN]: _tAC
      }], [1, {
        [_eQN]: `TotalUnavailableCapacity`,
        [_xN]: _tUC
      }], [() => CapacityReservationStatusSet, {
        [_eQN]: `CapacityReservationStatusSet`,
        [_xN]: _cRSS
      }]]
    ];
    exports2.CapacityManagerCondition$ = [
      3,
      n032,
      _CMC,
      0,
      [_DCim],
      [[() => exports2.DimensionCondition$, 0]]
    ];
    exports2.CapacityManagerDataExportResponse$ = [
      3,
      n032,
      _CMDER,
      0,
      [_CMDEI, _SBN, _SBP, _Sc, _OF, _CTr, _LDS, _LDSM, _LDSLU, _LDT, _T10],
      [[0, {
        [_eQN]: `CapacityManagerDataExportId`,
        [_xN]: _cMDEI
      }], [0, {
        [_eQN]: `S3BucketName`,
        [_xN]: _sBN
      }], [0, {
        [_eQN]: `S3BucketPrefix`,
        [_xN]: _sBP
      }], [0, {
        [_eQN]: `Schedule`,
        [_xN]: _sc4
      }], [0, {
        [_eQN]: `OutputFormat`,
        [_xN]: _oF
      }], [4, {
        [_eQN]: `CreateTime`,
        [_xN]: _cTr
      }], [0, {
        [_eQN]: `LatestDeliveryStatus`,
        [_xN]: _lDS
      }], [0, {
        [_eQN]: `LatestDeliveryStatusMessage`,
        [_xN]: _lDSM
      }], [0, {
        [_eQN]: `LatestDeliveryS3LocationUri`,
        [_xN]: _lDSLU
      }], [4, {
        [_eQN]: `LatestDeliveryTime`,
        [_xN]: _lDT
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.CapacityManagerDimension$ = [
      3,
      n032,
      _CMD,
      0,
      [_RR, _AZI, _AIc, _ANc, _IF, _IT4, _IPn, _RAe, _RIe, _RT13, _RCT, _RST, _RET, _REDT, _Te, _RSe, _RIMC, _RUFO, _T10],
      [[0, {
        [_eQN]: `ResourceRegion`,
        [_xN]: _rR
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [0, {
        [_eQN]: `AccountId`,
        [_xN]: _aIc
      }], [0, {
        [_eQN]: `AccountName`,
        [_xN]: _aNc
      }], [0, {
        [_eQN]: `InstanceFamily`,
        [_xN]: _iF
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [0, {
        [_eQN]: `InstancePlatform`,
        [_xN]: _iPn
      }], [0, {
        [_eQN]: `ReservationArn`,
        [_xN]: _rAe
      }], [0, {
        [_eQN]: `ReservationId`,
        [_xN]: _rI
      }], [0, {
        [_eQN]: `ReservationType`,
        [_xN]: _rT13
      }], [4, {
        [_eQN]: `ReservationCreateTimestamp`,
        [_xN]: _rCT
      }], [4, {
        [_eQN]: `ReservationStartTimestamp`,
        [_xN]: _rST
      }], [4, {
        [_eQN]: `ReservationEndTimestamp`,
        [_xN]: _rET
      }], [0, {
        [_eQN]: `ReservationEndDateType`,
        [_xN]: _rEDT
      }], [0, {
        [_eQN]: `Tenancy`,
        [_xN]: _t
      }], [0, {
        [_eQN]: `ReservationState`,
        [_xN]: _rS
      }], [0, {
        [_eQN]: `ReservationInstanceMatchCriteria`,
        [_xN]: _rIMC
      }], [0, {
        [_eQN]: `ReservationUnusedFinancialOwner`,
        [_xN]: _rUFO
      }], [() => CapacityManagerTagDimensionSet, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.CapacityManagerMonitoredTagKey$ = [
      3,
      n032,
      _CMMTK,
      0,
      [_TK, _Sta, _SMt, _CMP, _EDT],
      [[0, {
        [_eQN]: `TagKey`,
        [_xN]: _tK
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `StatusMessage`,
        [_xN]: _sMt
      }], [2, {
        [_eQN]: `CapacityManagerProvided`,
        [_xN]: _cMP
      }], [4, {
        [_eQN]: `EarliestDatapointTimestamp`,
        [_xN]: _eDT
      }]]
    ];
    exports2.CapacityManagerTagDimension$ = [
      3,
      n032,
      _CMTD,
      0,
      [_K10, _V10],
      [[0, {
        [_eQN]: `Key`,
        [_xN]: _k
      }], [0, {
        [_eQN]: `Value`,
        [_xN]: _v
      }]]
    ];
    exports2.CapacityReservation$ = [
      3,
      n032,
      _CRa,
      0,
      [_CRI, _OI, _CRA2, _AZI, _IT4, _IPn, _AZ, _Te, _TIC, _AICv, _EO, _ES, _St, _SD, _ED, _EDTn, _IMC, _CD, _T10, _OA, _CRFIa, _PGA, _CAap, _RT13, _URBOI, _CIom, _DP, _CBI, _Int, _ICA, _IIn],
      [[0, {
        [_eQN]: `CapacityReservationId`,
        [_xN]: _cRI
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `CapacityReservationArn`,
        [_xN]: _cRA
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [0, {
        [_eQN]: `InstancePlatform`,
        [_xN]: _iPn
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [0, {
        [_eQN]: `Tenancy`,
        [_xN]: _t
      }], [1, {
        [_eQN]: `TotalInstanceCount`,
        [_xN]: _tIC
      }], [1, {
        [_eQN]: `AvailableInstanceCount`,
        [_xN]: _aICv
      }], [2, {
        [_eQN]: `EbsOptimized`,
        [_xN]: _eO
      }], [2, {
        [_eQN]: `EphemeralStorage`,
        [_xN]: _eS
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [4, {
        [_eQN]: `StartDate`,
        [_xN]: _sD
      }], [4, {
        [_eQN]: `EndDate`,
        [_xN]: _eD
      }], [0, {
        [_eQN]: `EndDateType`,
        [_xN]: _eDTn
      }], [0, {
        [_eQN]: `InstanceMatchCriteria`,
        [_xN]: _iMC
      }], [4, {
        [_eQN]: `CreateDate`,
        [_xN]: _cD
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `OutpostArn`,
        [_xN]: _oA
      }], [0, {
        [_eQN]: `CapacityReservationFleetId`,
        [_xN]: _cRFI
      }], [0, {
        [_eQN]: `PlacementGroupArn`,
        [_xN]: _pGA
      }], [() => CapacityAllocations, {
        [_eQN]: `CapacityAllocationSet`,
        [_xN]: _cAS
      }], [0, {
        [_eQN]: `ReservationType`,
        [_xN]: _rT13
      }], [0, {
        [_eQN]: `UnusedReservationBillingOwnerId`,
        [_xN]: _uRBOI
      }], [() => exports2.CapacityReservationCommitmentInfo$, {
        [_eQN]: `CommitmentInfo`,
        [_xN]: _cIom
      }], [0, {
        [_eQN]: `DeliveryPreference`,
        [_xN]: _dP
      }], [0, {
        [_eQN]: `CapacityBlockId`,
        [_xN]: _cBI
      }], [2, {
        [_eQN]: `Interruptible`,
        [_xN]: _int
      }], [() => exports2.InterruptibleCapacityAllocation$, {
        [_eQN]: `InterruptibleCapacityAllocation`,
        [_xN]: _iCA
      }], [() => exports2.InterruptionInfo$, {
        [_eQN]: `InterruptionInfo`,
        [_xN]: _iIn
      }]]
    ];
    exports2.CapacityReservationBillingRequest$ = [
      3,
      n032,
      _CRBR,
      0,
      [_CRI, _RB, _URBOI, _LUT, _Sta, _SMt, _CRIap],
      [[0, {
        [_eQN]: `CapacityReservationId`,
        [_xN]: _cRI
      }], [0, {
        [_eQN]: `RequestedBy`,
        [_xN]: _rB
      }], [0, {
        [_eQN]: `UnusedReservationBillingOwnerId`,
        [_xN]: _uRBOI
      }], [4, {
        [_eQN]: `LastUpdateTime`,
        [_xN]: _lUT
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `StatusMessage`,
        [_xN]: _sMt
      }], [() => exports2.CapacityReservationInfo$, {
        [_eQN]: `CapacityReservationInfo`,
        [_xN]: _cRIa
      }]]
    ];
    exports2.CapacityReservationCommitmentInfo$ = [
      3,
      n032,
      _CRCI,
      0,
      [_CIC, _CED],
      [[1, {
        [_eQN]: `CommittedInstanceCount`,
        [_xN]: _cIC
      }], [4, {
        [_eQN]: `CommitmentEndDate`,
        [_xN]: _cED
      }]]
    ];
    exports2.CapacityReservationFleet$ = [
      3,
      n032,
      _CRF,
      0,
      [_CRFIa, _CRFA, _St, _TTC, _TFC, _Te, _ED, _CTr, _IMC, _ASl, _ITS, _T10],
      [[0, {
        [_eQN]: `CapacityReservationFleetId`,
        [_xN]: _cRFI
      }], [0, {
        [_eQN]: `CapacityReservationFleetArn`,
        [_xN]: _cRFA
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [1, {
        [_eQN]: `TotalTargetCapacity`,
        [_xN]: _tTC
      }], [1, {
        [_eQN]: `TotalFulfilledCapacity`,
        [_xN]: _tFC
      }], [0, {
        [_eQN]: `Tenancy`,
        [_xN]: _t
      }], [4, {
        [_eQN]: `EndDate`,
        [_xN]: _eD
      }], [4, {
        [_eQN]: `CreateTime`,
        [_xN]: _cTr
      }], [0, {
        [_eQN]: `InstanceMatchCriteria`,
        [_xN]: _iMC
      }], [0, {
        [_eQN]: `AllocationStrategy`,
        [_xN]: _aSl
      }], [() => FleetCapacityReservationSet, {
        [_eQN]: `InstanceTypeSpecificationSet`,
        [_xN]: _iTSS
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.CapacityReservationFleetCancellationState$ = [
      3,
      n032,
      _CRFCS,
      0,
      [_CFS, _PFS, _CRFIa],
      [[0, {
        [_eQN]: `CurrentFleetState`,
        [_xN]: _cFS
      }], [0, {
        [_eQN]: `PreviousFleetState`,
        [_xN]: _pFS
      }], [0, {
        [_eQN]: `CapacityReservationFleetId`,
        [_xN]: _cRFI
      }]]
    ];
    exports2.CapacityReservationGroup$ = [
      3,
      n032,
      _CRG,
      0,
      [_GA, _OI],
      [[0, {
        [_eQN]: `GroupArn`,
        [_xN]: _gA
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }]]
    ];
    exports2.CapacityReservationInfo$ = [
      3,
      n032,
      _CRIap,
      0,
      [_IT4, _AZ, _Te, _AZI],
      [[0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [0, {
        [_eQN]: `Tenancy`,
        [_xN]: _t
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }]]
    ];
    exports2.CapacityReservationOptions$ = [
      3,
      n032,
      _CRO,
      0,
      [_US],
      [[0, {
        [_eQN]: `UsageStrategy`,
        [_xN]: _uS
      }]]
    ];
    exports2.CapacityReservationOptionsRequest$ = [
      3,
      n032,
      _CROR,
      0,
      [_US],
      [0]
    ];
    exports2.CapacityReservationSpecification$ = [
      3,
      n032,
      _CRSa,
      0,
      [_CRP, _CRT],
      [0, () => exports2.CapacityReservationTarget$]
    ];
    exports2.CapacityReservationSpecificationResponse$ = [
      3,
      n032,
      _CRSR,
      0,
      [_CRP, _CRT],
      [[0, {
        [_eQN]: `CapacityReservationPreference`,
        [_xN]: _cRP
      }], [() => exports2.CapacityReservationTargetResponse$, {
        [_eQN]: `CapacityReservationTarget`,
        [_xN]: _cRT
      }]]
    ];
    exports2.CapacityReservationStatus$ = [
      3,
      n032,
      _CRSap,
      0,
      [_CRI, _TCo, _TAC, _TUC],
      [[0, {
        [_eQN]: `CapacityReservationId`,
        [_xN]: _cRI
      }], [1, {
        [_eQN]: `TotalCapacity`,
        [_xN]: _tC
      }], [1, {
        [_eQN]: `TotalAvailableCapacity`,
        [_xN]: _tAC
      }], [1, {
        [_eQN]: `TotalUnavailableCapacity`,
        [_xN]: _tUC
      }]]
    ];
    exports2.CapacityReservationTarget$ = [
      3,
      n032,
      _CRT,
      0,
      [_CRI, _CRRGA],
      [0, 0]
    ];
    exports2.CapacityReservationTargetResponse$ = [
      3,
      n032,
      _CRTR,
      0,
      [_CRI, _CRRGA],
      [[0, {
        [_eQN]: `CapacityReservationId`,
        [_xN]: _cRI
      }], [0, {
        [_eQN]: `CapacityReservationResourceGroupArn`,
        [_xN]: _cRRGA
      }]]
    ];
    exports2.CapacityReservationTopology$ = [
      3,
      n032,
      _CRTa,
      0,
      [_CRI, _CBI, _St, _IT4, _GN, _NN, _AZI, _AZ],
      [[0, {
        [_eQN]: `CapacityReservationId`,
        [_xN]: _cRI
      }], [0, {
        [_eQN]: `CapacityBlockId`,
        [_xN]: _cBI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [0, {
        [_eQN]: `GroupName`,
        [_xN]: _gN
      }], [() => NetworkNodeSet, {
        [_eQN]: `NetworkNodeSet`,
        [_xN]: _nNS
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }]]
    ];
    exports2.CarrierGateway$ = [
      3,
      n032,
      _CG,
      0,
      [_CGI, _VI, _St, _OI, _T10],
      [[0, {
        [_eQN]: `CarrierGatewayId`,
        [_xN]: _cGI
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.CertificateAuthentication$ = [
      3,
      n032,
      _CAer,
      0,
      [_CRCC],
      [[0, {
        [_eQN]: `ClientRootCertificateChain`,
        [_xN]: _cRCC
      }]]
    ];
    exports2.CertificateAuthenticationRequest$ = [
      3,
      n032,
      _CAR,
      0,
      [_CRCCA],
      [0]
    ];
    exports2.CidrAuthorizationContext$ = [
      3,
      n032,
      _CAC,
      0,
      [_Me, _Si],
      [0, 0],
      2
    ];
    exports2.CidrBlock$ = [
      3,
      n032,
      _CB,
      0,
      [_CB],
      [[0, {
        [_eQN]: `CidrBlock`,
        [_xN]: _cB
      }]]
    ];
    exports2.ClassicLinkDnsSupport$ = [
      3,
      n032,
      _CLDS,
      0,
      [_CLDSl, _VI],
      [[2, {
        [_eQN]: `ClassicLinkDnsSupported`,
        [_xN]: _cLDS
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }]]
    ];
    exports2.ClassicLinkInstance$ = [
      3,
      n032,
      _CLI,
      0,
      [_G, _II2, _T10, _VI],
      [[() => GroupIdentifierList, {
        [_eQN]: `GroupSet`,
        [_xN]: _gSr
      }], [0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }]]
    ];
    exports2.ClassicLoadBalancer$ = [
      3,
      n032,
      _CLB,
      0,
      [_N],
      [[0, {
        [_eQN]: `Name`,
        [_xN]: _n
      }]]
    ];
    exports2.ClassicLoadBalancersConfig$ = [
      3,
      n032,
      _CLBC,
      0,
      [_CLBl],
      [[() => ClassicLoadBalancers, {
        [_eQN]: `ClassicLoadBalancers`,
        [_xN]: _cLB
      }]]
    ];
    exports2.ClientCertificateRevocationListStatus$ = [
      3,
      n032,
      _CCRLS,
      0,
      [_Co, _Me],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }]]
    ];
    exports2.ClientConnectOptions$ = [
      3,
      n032,
      _CCO,
      0,
      [_En, _LFA],
      [2, 0]
    ];
    exports2.ClientConnectResponseOptions$ = [
      3,
      n032,
      _CCRO,
      0,
      [_En, _LFA, _Sta],
      [[2, {
        [_eQN]: `Enabled`,
        [_xN]: _en
      }], [0, {
        [_eQN]: `LambdaFunctionArn`,
        [_xN]: _lFA
      }], [() => exports2.ClientVpnEndpointAttributeStatus$, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }]]
    ];
    exports2.ClientData$ = [
      3,
      n032,
      _CDl,
      0,
      [_Com, _UE10, _USp, _USpl],
      [0, 4, 1, 4]
    ];
    exports2.ClientLoginBannerOptions$ = [
      3,
      n032,
      _CLBO,
      0,
      [_En, _BTa],
      [2, 0]
    ];
    exports2.ClientLoginBannerResponseOptions$ = [
      3,
      n032,
      _CLBRO,
      0,
      [_En, _BTa],
      [[2, {
        [_eQN]: `Enabled`,
        [_xN]: _en
      }], [0, {
        [_eQN]: `BannerText`,
        [_xN]: _bT
      }]]
    ];
    exports2.ClientRouteEnforcementOptions$ = [
      3,
      n032,
      _CREO,
      0,
      [_Enf],
      [2]
    ];
    exports2.ClientRouteEnforcementResponseOptions$ = [
      3,
      n032,
      _CRERO,
      0,
      [_Enf],
      [[2, {
        [_eQN]: `Enforced`,
        [_xN]: _enf
      }]]
    ];
    exports2.ClientVpnAuthentication$ = [
      3,
      n032,
      _CVA,
      0,
      [_Ty, _ADc, _MA, _FA],
      [[0, {
        [_eQN]: `Type`,
        [_xN]: _ty
      }], [() => exports2.DirectoryServiceAuthentication$, {
        [_eQN]: `ActiveDirectory`,
        [_xN]: _aD
      }], [() => exports2.CertificateAuthentication$, {
        [_eQN]: `MutualAuthentication`,
        [_xN]: _mA
      }], [() => exports2.FederatedAuthentication$, {
        [_eQN]: `FederatedAuthentication`,
        [_xN]: _fA
      }]]
    ];
    exports2.ClientVpnAuthenticationRequest$ = [
      3,
      n032,
      _CVAR,
      0,
      [_Ty, _ADc, _MA, _FA],
      [0, () => exports2.DirectoryServiceAuthenticationRequest$, () => exports2.CertificateAuthenticationRequest$, () => exports2.FederatedAuthenticationRequest$]
    ];
    exports2.ClientVpnAuthorizationRuleStatus$ = [
      3,
      n032,
      _CVARS,
      0,
      [_Co, _Me],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }]]
    ];
    exports2.ClientVpnConnection$ = [
      3,
      n032,
      _CVC,
      0,
      [_CVEI, _Ti, _CIon, _Us, _CET, _IB, _EB, _IPng, _EP, _CIl, _CIA, _CN, _Sta, _CETo, _PCS],
      [[0, {
        [_eQN]: `ClientVpnEndpointId`,
        [_xN]: _cVEI
      }], [0, {
        [_eQN]: `Timestamp`,
        [_xN]: _ti
      }], [0, {
        [_eQN]: `ConnectionId`,
        [_xN]: _cIon
      }], [0, {
        [_eQN]: `Username`,
        [_xN]: _us
      }], [0, {
        [_eQN]: `ConnectionEstablishedTime`,
        [_xN]: _cET
      }], [0, {
        [_eQN]: `IngressBytes`,
        [_xN]: _iB
      }], [0, {
        [_eQN]: `EgressBytes`,
        [_xN]: _eB
      }], [0, {
        [_eQN]: `IngressPackets`,
        [_xN]: _iPng
      }], [0, {
        [_eQN]: `EgressPackets`,
        [_xN]: _eP
      }], [0, {
        [_eQN]: `ClientIp`,
        [_xN]: _cIl
      }], [0, {
        [_eQN]: `ClientIpv6Address`,
        [_xN]: _cIA
      }], [0, {
        [_eQN]: `CommonName`,
        [_xN]: _cN
      }], [() => exports2.ClientVpnConnectionStatus$, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `ConnectionEndTime`,
        [_xN]: _cETo
      }], [() => ValueStringList, {
        [_eQN]: `PostureComplianceStatusSet`,
        [_xN]: _pCSS
      }]]
    ];
    exports2.ClientVpnConnectionStatus$ = [
      3,
      n032,
      _CVCS,
      0,
      [_Co, _Me],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }]]
    ];
    exports2.ClientVpnEndpoint$ = [
      3,
      n032,
      _CVE,
      0,
      [_CVEI, _De, _Sta, _CTre, _DT, _DNn, _CCB, _DS10, _STp, _VP, _TPr, _VPp, _ATNs, _SCA, _AO, _CLO, _T10, _SGIe, _VI, _SSPU, _CCO, _STH, _CLBO, _CREO, _DOST, _EIAT, _TIAT, _TGC],
      [[0, {
        [_eQN]: `ClientVpnEndpointId`,
        [_xN]: _cVEI
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [() => exports2.ClientVpnEndpointStatus$, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `CreationTime`,
        [_xN]: _cTre
      }], [0, {
        [_eQN]: `DeletionTime`,
        [_xN]: _dT
      }], [0, {
        [_eQN]: `DnsName`,
        [_xN]: _dNn
      }], [0, {
        [_eQN]: `ClientCidrBlock`,
        [_xN]: _cCB
      }], [() => ValueStringList, {
        [_eQN]: `DnsServer`,
        [_xN]: _dS
      }], [2, {
        [_eQN]: `SplitTunnel`,
        [_xN]: _sTp
      }], [0, {
        [_eQN]: `VpnProtocol`,
        [_xN]: _vP
      }], [0, {
        [_eQN]: `TransportProtocol`,
        [_xN]: _tPr
      }], [1, {
        [_eQN]: `VpnPort`,
        [_xN]: _vPp
      }], [() => AssociatedTargetNetworkSet, {
        [_eQN]: `AssociatedTargetNetwork`,
        [_xN]: _aTN
      }], [0, {
        [_eQN]: `ServerCertificateArn`,
        [_xN]: _sCA
      }], [() => ClientVpnAuthenticationList, {
        [_eQN]: `AuthenticationOptions`,
        [_xN]: _aO
      }], [() => exports2.ConnectionLogResponseOptions$, {
        [_eQN]: `ConnectionLogOptions`,
        [_xN]: _cLO
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [() => ClientVpnSecurityGroupIdSet, {
        [_eQN]: `SecurityGroupIdSet`,
        [_xN]: _sGIS
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [0, {
        [_eQN]: `SelfServicePortalUrl`,
        [_xN]: _sSPU
      }], [() => exports2.ClientConnectResponseOptions$, {
        [_eQN]: `ClientConnectOptions`,
        [_xN]: _cCO
      }], [1, {
        [_eQN]: `SessionTimeoutHours`,
        [_xN]: _sTH
      }], [() => exports2.ClientLoginBannerResponseOptions$, {
        [_eQN]: `ClientLoginBannerOptions`,
        [_xN]: _cLBO
      }], [() => exports2.ClientRouteEnforcementResponseOptions$, {
        [_eQN]: `ClientRouteEnforcementOptions`,
        [_xN]: _cREO
      }], [2, {
        [_eQN]: `DisconnectOnSessionTimeout`,
        [_xN]: _dOST
      }], [0, {
        [_eQN]: `EndpointIpAddressType`,
        [_xN]: _eIAT
      }], [0, {
        [_eQN]: `TrafficIpAddressType`,
        [_xN]: _tIAT
      }], [() => exports2.TransitGatewayConfigurationDescribeEndpointStructure$, {
        [_eQN]: `TransitGatewayConfiguration`,
        [_xN]: _tGC
      }]]
    ];
    exports2.ClientVpnEndpointAttributeStatus$ = [
      3,
      n032,
      _CVEAS,
      0,
      [_Co, _Me],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }]]
    ];
    exports2.ClientVpnEndpointStatus$ = [
      3,
      n032,
      _CVES,
      0,
      [_Co, _Me],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }]]
    ];
    exports2.ClientVpnRoute$ = [
      3,
      n032,
      _CVR,
      0,
      [_CVEI, _DCe, _TSar, _Ty, _O, _Sta, _De, _TGAI],
      [[0, {
        [_eQN]: `ClientVpnEndpointId`,
        [_xN]: _cVEI
      }], [0, {
        [_eQN]: `DestinationCidr`,
        [_xN]: _dC4
      }], [0, {
        [_eQN]: `TargetSubnet`,
        [_xN]: _tSa
      }], [0, {
        [_eQN]: `Type`,
        [_xN]: _ty
      }], [0, {
        [_eQN]: `Origin`,
        [_xN]: _o
      }], [() => exports2.ClientVpnRouteStatus$, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [0, {
        [_eQN]: `TransitGatewayAttachmentId`,
        [_xN]: _tGAI
      }]]
    ];
    exports2.ClientVpnRouteStatus$ = [
      3,
      n032,
      _CVRS,
      0,
      [_Co, _Me],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }]]
    ];
    exports2.CloudWatchLogOptions$ = [
      3,
      n032,
      _CWLO,
      0,
      [_LE, _LGA, _LOF, _BLE, _BLGA, _BLOF],
      [[2, {
        [_eQN]: `LogEnabled`,
        [_xN]: _lE
      }], [0, {
        [_eQN]: `LogGroupArn`,
        [_xN]: _lGA
      }], [0, {
        [_eQN]: `LogOutputFormat`,
        [_xN]: _lOF
      }], [2, {
        [_eQN]: `BgpLogEnabled`,
        [_xN]: _bLE
      }], [0, {
        [_eQN]: `BgpLogGroupArn`,
        [_xN]: _bLGA
      }], [0, {
        [_eQN]: `BgpLogOutputFormat`,
        [_xN]: _bLOF
      }]]
    ];
    exports2.CloudWatchLogOptionsSpecification$ = [
      3,
      n032,
      _CWLOS,
      0,
      [_LE, _LGA, _LOF, _BLE, _BLGA, _BLOF],
      [2, 0, 0, 2, 0, 0]
    ];
    exports2.CoipAddressUsage$ = [
      3,
      n032,
      _CAU,
      0,
      [_AIl, _AAI, _ASw, _CIop],
      [[0, {
        [_eQN]: `AllocationId`,
        [_xN]: _aI10
      }], [0, {
        [_eQN]: `AwsAccountId`,
        [_xN]: _aAI
      }], [0, {
        [_eQN]: `AwsService`,
        [_xN]: _aSw
      }], [0, {
        [_eQN]: `CoIp`,
        [_xN]: _cIop
      }]]
    ];
    exports2.CoipCidr$ = [
      3,
      n032,
      _CCo,
      0,
      [_Ci, _CPI, _LGRTI],
      [[0, {
        [_eQN]: `Cidr`,
        [_xN]: _ci
      }], [0, {
        [_eQN]: `CoipPoolId`,
        [_xN]: _cPI
      }], [0, {
        [_eQN]: `LocalGatewayRouteTableId`,
        [_xN]: _lGRTI
      }]]
    ];
    exports2.CoipPool$ = [
      3,
      n032,
      _CP,
      0,
      [_PIo, _PC10, _LGRTI, _T10, _PA10],
      [[0, {
        [_eQN]: `PoolId`,
        [_xN]: _pIo
      }], [() => ValueStringList, {
        [_eQN]: `PoolCidrSet`,
        [_xN]: _pCS
      }], [0, {
        [_eQN]: `LocalGatewayRouteTableId`,
        [_xN]: _lGRTI
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `PoolArn`,
        [_xN]: _pA
      }]]
    ];
    exports2.ConfirmProductInstanceRequest$ = [
      3,
      n032,
      _CPIR,
      0,
      [_II2, _PCr10, _DR],
      [0, 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      2
    ];
    exports2.ConfirmProductInstanceResult$ = [
      3,
      n032,
      _CPIRo,
      0,
      [_R, _OI],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }]]
    ];
    exports2.ConnectionLogOptions$ = [
      3,
      n032,
      _CLO,
      0,
      [_En, _CLG, _CLS],
      [2, 0, 0]
    ];
    exports2.ConnectionLogResponseOptions$ = [
      3,
      n032,
      _CLRO,
      0,
      [_En, _CLG, _CLS],
      [2, 0, 0]
    ];
    exports2.ConnectionNotification$ = [
      3,
      n032,
      _CNo,
      0,
      [_CNI, _SIe, _VEIp, _CNT, _CNAo, _CE, _CNS, _SR],
      [[0, {
        [_eQN]: `ConnectionNotificationId`,
        [_xN]: _cNI
      }], [0, {
        [_eQN]: `ServiceId`,
        [_xN]: _sI
      }], [0, {
        [_eQN]: `VpcEndpointId`,
        [_xN]: _vEI
      }], [0, {
        [_eQN]: `ConnectionNotificationType`,
        [_xN]: _cNT
      }], [0, {
        [_eQN]: `ConnectionNotificationArn`,
        [_xN]: _cNAo
      }], [() => ValueStringList, {
        [_eQN]: `ConnectionEvents`,
        [_xN]: _cE
      }], [0, {
        [_eQN]: `ConnectionNotificationState`,
        [_xN]: _cNS
      }], [0, {
        [_eQN]: `ServiceRegion`,
        [_xN]: _sR
      }]]
    ];
    exports2.ConnectionTrackingConfiguration$ = [
      3,
      n032,
      _CTC,
      0,
      [_TET, _UST, _UTd],
      [[1, {
        [_eQN]: `TcpEstablishedTimeout`,
        [_xN]: _tET
      }], [1, {
        [_eQN]: `UdpStreamTimeout`,
        [_xN]: _uST
      }], [1, {
        [_eQN]: `UdpTimeout`,
        [_xN]: _uTd
      }]]
    ];
    exports2.ConnectionTrackingSpecification$ = [
      3,
      n032,
      _CTS,
      0,
      [_TET, _UTd, _UST],
      [[1, {
        [_eQN]: `TcpEstablishedTimeout`,
        [_xN]: _tET
      }], [1, {
        [_eQN]: `UdpTimeout`,
        [_xN]: _uTd
      }], [1, {
        [_eQN]: `UdpStreamTimeout`,
        [_xN]: _uST
      }]]
    ];
    exports2.ConnectionTrackingSpecificationRequest$ = [
      3,
      n032,
      _CTSR,
      0,
      [_TET, _UST, _UTd],
      [1, 1, 1]
    ];
    exports2.ConnectionTrackingSpecificationResponse$ = [
      3,
      n032,
      _CTSRo,
      0,
      [_TET, _UST, _UTd],
      [[1, {
        [_eQN]: `TcpEstablishedTimeout`,
        [_xN]: _tET
      }], [1, {
        [_eQN]: `UdpStreamTimeout`,
        [_xN]: _uST
      }], [1, {
        [_eQN]: `UdpTimeout`,
        [_xN]: _uTd
      }]]
    ];
    exports2.ConversionTask$ = [
      3,
      n032,
      _CTo,
      0,
      [_CTI, _ET, _IImp, _IVm, _St, _SMt, _T10],
      [[0, {
        [_eQN]: `ConversionTaskId`,
        [_xN]: _cTI
      }], [0, {
        [_eQN]: `ExpirationTime`,
        [_xN]: _eT
      }], [() => exports2.ImportInstanceTaskDetails$, {
        [_eQN]: `ImportInstance`,
        [_xN]: _iIm
      }], [() => exports2.ImportVolumeTaskDetails$, {
        [_eQN]: `ImportVolume`,
        [_xN]: _iVm
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `StatusMessage`,
        [_xN]: _sMt
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.CopyFpgaImageRequest$ = [
      3,
      n032,
      _CFIR,
      0,
      [_SFII, _SRo, _DR, _De, _N, _CT4],
      [0, 0, 2, 0, 0, 0],
      2
    ];
    exports2.CopyFpgaImageResult$ = [
      3,
      n032,
      _CFIRo,
      0,
      [_FII],
      [[0, {
        [_eQN]: `FpgaImageId`,
        [_xN]: _fII
      }]]
    ];
    exports2.CopyImageRequest$ = [
      3,
      n032,
      _CIR,
      0,
      [_N, _SII, _SRo, _CT4, _De, _Enc, _KKI, _DOA, _CIT, _TS, _SCCDM, _DAZ, _DAZI, _DR],
      [0, 0, 0, [0, 4], 0, [2, {
        [_eQN]: `Encrypted`,
        [_xN]: _enc
      }], [0, {
        [_eQN]: `KmsKeyId`,
        [_xN]: _kKI
      }], 0, 2, [() => TagSpecificationList, { [_xN]: _TSa }], 1, 0, 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      3
    ];
    exports2.CopyImageResult$ = [
      3,
      n032,
      _CIRo,
      0,
      [_IIm],
      [[0, {
        [_eQN]: `ImageId`,
        [_xN]: _iIma
      }]]
    ];
    exports2.CopySnapshotRequest$ = [
      3,
      n032,
      _CSR,
      0,
      [_SRo, _SSI, _De, _DOA, _DRe, _Enc, _KKI, _PU, _TS, _CDM, _DAZ, _DR],
      [0, 0, 0, 0, [0, {
        [_eQN]: `DestinationRegion`,
        [_xN]: _dRe
      }], [2, {
        [_eQN]: `Encrypted`,
        [_xN]: _enc
      }], [0, {
        [_eQN]: `KmsKeyId`,
        [_xN]: _kKI
      }], [() => CopySnapshotRequestPSU, {
        [_eQN]: `PresignedUrl`,
        [_xN]: _pU
      }], [() => TagSpecificationList, { [_xN]: _TSa }], 1, 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      2
    ];
    exports2.CopySnapshotResult$ = [
      3,
      n032,
      _CSRo,
      0,
      [_T10, _SIn],
      [[() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `SnapshotId`,
        [_xN]: _sIn
      }]]
    ];
    exports2.CopyVolumesRequest$ = [
      3,
      n032,
      _CVRo,
      0,
      [_SVI, _Io, _Siz, _VT, _DR, _TS, _MAE, _Th, _CT4],
      [0, 1, 1, 0, 2, [() => TagSpecificationList, { [_xN]: _TSa }], 2, 1, [0, 4]],
      1
    ];
    exports2.CopyVolumesResult$ = [
      3,
      n032,
      _CVRop,
      0,
      [_Vo],
      [[() => VolumeList, {
        [_eQN]: `VolumeSet`,
        [_xN]: _vS
      }]]
    ];
    exports2.CpuOptions$ = [
      3,
      n032,
      _CO,
      0,
      [_CCor, _TPC, _ASS, _NV],
      [[1, {
        [_eQN]: `CoreCount`,
        [_xN]: _cCo
      }], [1, {
        [_eQN]: `ThreadsPerCore`,
        [_xN]: _tPC
      }], [0, {
        [_eQN]: `AmdSevSnp`,
        [_xN]: _aSS
      }], [0, {
        [_eQN]: `NestedVirtualization`,
        [_xN]: _nV
      }]]
    ];
    exports2.CpuOptionsRequest$ = [
      3,
      n032,
      _COR,
      0,
      [_CCor, _TPC, _ASS, _NV],
      [1, 1, 0, 0]
    ];
    exports2.CpuPerformanceFactor$ = [
      3,
      n032,
      _CPF,
      0,
      [_Re],
      [[() => PerformanceFactorReferenceSet, {
        [_eQN]: `ReferenceSet`,
        [_xN]: _rSe
      }]]
    ];
    exports2.CpuPerformanceFactorRequest$ = [
      3,
      n032,
      _CPFR,
      0,
      [_Re],
      [[() => PerformanceFactorReferenceSetRequest, { [_xN]: _Ref }]]
    ];
    exports2.CreateCapacityManagerDataExportRequest$ = [
      3,
      n032,
      _CCMDER,
      0,
      [_SBN, _Sc, _OF, _SBP, _CT4, _DR, _TS],
      [0, 0, 0, 0, [0, 4], 2, [() => TagSpecificationList, { [_xN]: _TSa }]],
      3
    ];
    exports2.CreateCapacityManagerDataExportResult$ = [
      3,
      n032,
      _CCMDERr,
      0,
      [_CMDEI],
      [[0, {
        [_eQN]: `CapacityManagerDataExportId`,
        [_xN]: _cMDEI
      }]]
    ];
    exports2.CreateCapacityReservationBySplittingRequest$ = [
      3,
      n032,
      _CCRBSR,
      0,
      [_SCRI, _IC, _DR, _CT4, _TS],
      [0, 1, 2, [0, 4], [() => TagSpecificationList, { [_xN]: _TSa }]],
      2
    ];
    exports2.CreateCapacityReservationBySplittingResult$ = [
      3,
      n032,
      _CCRBSRr,
      0,
      [_SCR, _DCR, _IC],
      [[() => exports2.CapacityReservation$, {
        [_eQN]: `SourceCapacityReservation`,
        [_xN]: _sCR
      }], [() => exports2.CapacityReservation$, {
        [_eQN]: `DestinationCapacityReservation`,
        [_xN]: _dCR
      }], [1, {
        [_eQN]: `InstanceCount`,
        [_xN]: _iC
      }]]
    ];
    exports2.CreateCapacityReservationFleetRequest$ = [
      3,
      n032,
      _CCRFRr,
      0,
      [_ITS, _TTC, _ASl, _CT4, _Te, _ED, _IMC, _TS, _DR],
      [[() => ReservationFleetInstanceSpecificationList, { [_xN]: _ITSn }], 1, 0, [0, 4], 0, 4, 0, [() => TagSpecificationList, { [_xN]: _TSa }], 2],
      2
    ];
    exports2.CreateCapacityReservationFleetResult$ = [
      3,
      n032,
      _CCRFRre,
      0,
      [_CRFIa, _St, _TTC, _TFC, _IMC, _ASl, _CTr, _ED, _Te, _FCR, _T10],
      [[0, {
        [_eQN]: `CapacityReservationFleetId`,
        [_xN]: _cRFI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [1, {
        [_eQN]: `TotalTargetCapacity`,
        [_xN]: _tTC
      }], [1, {
        [_eQN]: `TotalFulfilledCapacity`,
        [_xN]: _tFC
      }], [0, {
        [_eQN]: `InstanceMatchCriteria`,
        [_xN]: _iMC
      }], [0, {
        [_eQN]: `AllocationStrategy`,
        [_xN]: _aSl
      }], [4, {
        [_eQN]: `CreateTime`,
        [_xN]: _cTr
      }], [4, {
        [_eQN]: `EndDate`,
        [_xN]: _eD
      }], [0, {
        [_eQN]: `Tenancy`,
        [_xN]: _t
      }], [() => FleetCapacityReservationSet, {
        [_eQN]: `FleetCapacityReservationSet`,
        [_xN]: _fCRS
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.CreateCapacityReservationRequest$ = [
      3,
      n032,
      _CCRRr,
      0,
      [_IT4, _IPn, _IC, _CT4, _AZ, _AZI, _Te, _EO, _ES, _ED, _EDTn, _IMC, _TS, _DR, _OA, _PGA, _SD, _CDo, _DP],
      [0, 0, 1, 0, 0, 0, 0, 2, 2, 4, 0, 0, [() => TagSpecificationList, 0], 2, 0, 0, 4, 1, 0],
      3
    ];
    exports2.CreateCapacityReservationResult$ = [
      3,
      n032,
      _CCRRre,
      0,
      [_CRa],
      [[() => exports2.CapacityReservation$, {
        [_eQN]: `CapacityReservation`,
        [_xN]: _cR
      }]]
    ];
    exports2.CreateCarrierGatewayRequest$ = [
      3,
      n032,
      _CCGR,
      0,
      [_VI, _TS, _DR, _CT4],
      [0, [() => TagSpecificationList, { [_xN]: _TSa }], 2, [0, 4]],
      1
    ];
    exports2.CreateCarrierGatewayResult$ = [
      3,
      n032,
      _CCGRr,
      0,
      [_CG],
      [[() => exports2.CarrierGateway$, {
        [_eQN]: `CarrierGateway`,
        [_xN]: _cG
      }]]
    ];
    exports2.CreateClientVpnEndpointRequest$ = [
      3,
      n032,
      _CCVER,
      0,
      [_SCA, _AO, _CLO, _CCB, _DS10, _TPr, _VPp, _De, _STp, _DR, _CT4, _TS, _SGIe, _VI, _SSP, _CCO, _STH, _CLBO, _CREO, _DOST, _EIAT, _TIAT, _TGC],
      [0, [() => ClientVpnAuthenticationRequestList, { [_xN]: _Au10 }], () => exports2.ConnectionLogOptions$, 0, [() => ValueStringList, 0], 0, 1, 0, 2, 2, [0, 4], [() => TagSpecificationList, { [_xN]: _TSa }], [() => ClientVpnSecurityGroupIdSet, { [_xN]: _SGI }], 0, 0, () => exports2.ClientConnectOptions$, 1, () => exports2.ClientLoginBannerOptions$, () => exports2.ClientRouteEnforcementOptions$, 2, 0, 0, [() => exports2.TransitGatewayConfigurationInputStructure$, 0]],
      3
    ];
    exports2.CreateClientVpnEndpointResult$ = [
      3,
      n032,
      _CCVERr,
      0,
      [_CVEI, _Sta, _DNn],
      [[0, {
        [_eQN]: `ClientVpnEndpointId`,
        [_xN]: _cVEI
      }], [() => exports2.ClientVpnEndpointStatus$, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `DnsName`,
        [_xN]: _dNn
      }]]
    ];
    exports2.CreateClientVpnRouteRequest$ = [
      3,
      n032,
      _CCVRR,
      0,
      [_CVEI, _DCB, _TVSI, _De, _CT4, _DR],
      [0, 0, 0, 0, [0, 4], 2],
      2
    ];
    exports2.CreateClientVpnRouteResult$ = [
      3,
      n032,
      _CCVRRr,
      0,
      [_Sta],
      [[() => exports2.ClientVpnRouteStatus$, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }]]
    ];
    exports2.CreateCoipCidrRequest$ = [
      3,
      n032,
      _CCCR,
      0,
      [_Ci, _CPI, _DR],
      [0, 0, 2],
      2
    ];
    exports2.CreateCoipCidrResult$ = [
      3,
      n032,
      _CCCRr,
      0,
      [_CCo],
      [[() => exports2.CoipCidr$, {
        [_eQN]: `CoipCidr`,
        [_xN]: _cCoi
      }]]
    ];
    exports2.CreateCoipPoolRequest$ = [
      3,
      n032,
      _CCPR,
      0,
      [_LGRTI, _TS, _DR],
      [0, [() => TagSpecificationList, { [_xN]: _TSa }], 2],
      1
    ];
    exports2.CreateCoipPoolResult$ = [
      3,
      n032,
      _CCPRr,
      0,
      [_CP],
      [[() => exports2.CoipPool$, {
        [_eQN]: `CoipPool`,
        [_xN]: _cP
      }]]
    ];
    exports2.CreateCustomerGatewayRequest$ = [
      3,
      n032,
      _CCGRre,
      0,
      [_Ty, _BA, _PI10, _CAe, _TS, _DN, _IAp, _BAE, _DR],
      [0, 1, 0, 0, [() => TagSpecificationList, { [_xN]: _TSa }], 0, 0, 1, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.CreateCustomerGatewayResult$ = [
      3,
      n032,
      _CCGRrea,
      0,
      [_CGu],
      [[() => exports2.CustomerGateway$, {
        [_eQN]: `CustomerGateway`,
        [_xN]: _cGu
      }]]
    ];
    exports2.CreateDefaultSubnetRequest$ = [
      3,
      n032,
      _CDSR,
      0,
      [_AZ, _DR, _IN, _AZI],
      [0, 2, 2, 0]
    ];
    exports2.CreateDefaultSubnetResult$ = [
      3,
      n032,
      _CDSRr,
      0,
      [_Su],
      [[() => exports2.Subnet$, {
        [_eQN]: `Subnet`,
        [_xN]: _su
      }]]
    ];
    exports2.CreateDefaultVpcRequest$ = [
      3,
      n032,
      _CDVR,
      0,
      [_DR],
      [2]
    ];
    exports2.CreateDefaultVpcResult$ = [
      3,
      n032,
      _CDVRr,
      0,
      [_Vp],
      [[() => exports2.Vpc$, {
        [_eQN]: `Vpc`,
        [_xN]: _vp
      }]]
    ];
    exports2.CreateDelegateMacVolumeOwnershipTaskRequest$ = [
      3,
      n032,
      _CDMVOTR,
      0,
      [_II2, _MC, _CT4, _DR, _TS],
      [0, [() => SensitiveMacCredentials, 0], [0, 4], 2, [() => TagSpecificationList, { [_xN]: _TSa }]],
      2
    ];
    exports2.CreateDelegateMacVolumeOwnershipTaskResult$ = [
      3,
      n032,
      _CDMVOTRr,
      0,
      [_MMT],
      [[() => exports2.MacModificationTask$, {
        [_eQN]: `MacModificationTask`,
        [_xN]: _mMT
      }]]
    ];
    exports2.CreateDhcpOptionsRequest$ = [
      3,
      n032,
      _CDOR,
      0,
      [_DCh, _TS, _DR],
      [[() => NewDhcpConfigurationList, {
        [_eQN]: `DhcpConfiguration`,
        [_xN]: _dCh
      }], [() => TagSpecificationList, { [_xN]: _TSa }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.CreateDhcpOptionsResult$ = [
      3,
      n032,
      _CDORr,
      0,
      [_DO],
      [[() => exports2.DhcpOptions$, {
        [_eQN]: `DhcpOptions`,
        [_xN]: _dO
      }]]
    ];
    exports2.CreateEgressOnlyInternetGatewayRequest$ = [
      3,
      n032,
      _CEOIGR,
      0,
      [_VI, _CT4, _DR, _TS],
      [0, 0, 2, [() => TagSpecificationList, { [_xN]: _TSa }]],
      1
    ];
    exports2.CreateEgressOnlyInternetGatewayResult$ = [
      3,
      n032,
      _CEOIGRr,
      0,
      [_CT4, _EOIG],
      [[0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }], [() => exports2.EgressOnlyInternetGateway$, {
        [_eQN]: `EgressOnlyInternetGateway`,
        [_xN]: _eOIG
      }]]
    ];
    exports2.CreateFleetError$ = [
      3,
      n032,
      _CFE,
      0,
      [_LTAO, _L2, _EC, _EM],
      [[() => exports2.LaunchTemplateAndOverridesResponse$, {
        [_eQN]: `LaunchTemplateAndOverrides`,
        [_xN]: _lTAO
      }], [0, {
        [_eQN]: `Lifecycle`,
        [_xN]: _l
      }], [0, {
        [_eQN]: `ErrorCode`,
        [_xN]: _eC
      }], [0, {
        [_eQN]: `ErrorMessage`,
        [_xN]: _eM
      }]]
    ];
    exports2.CreateFleetInstance$ = [
      3,
      n032,
      _CFI,
      0,
      [_LTAO, _L2, _IIns, _IT4, _Pl],
      [[() => exports2.LaunchTemplateAndOverridesResponse$, {
        [_eQN]: `LaunchTemplateAndOverrides`,
        [_xN]: _lTAO
      }], [0, {
        [_eQN]: `Lifecycle`,
        [_xN]: _l
      }], [() => InstanceIdsSet, {
        [_eQN]: `InstanceIds`,
        [_xN]: _iIns
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [0, {
        [_eQN]: `Platform`,
        [_xN]: _pl
      }]]
    ];
    exports2.CreateFleetRequest$ = [
      3,
      n032,
      _CFR,
      0,
      [_LTC, _TCS, _DR, _CT4, _SO, _ODO, _RCO, _ECTP, _TIWE, _Ty, _VF, _VU, _RUI, _TS, _Con],
      [[() => FleetLaunchTemplateConfigListRequest, 0], () => exports2.TargetCapacitySpecificationRequest$, 2, [0, 4], () => exports2.SpotOptionsRequest$, () => exports2.OnDemandOptionsRequest$, [() => exports2.ReservedCapacityOptionsRequest$, 0], 0, 2, 0, 4, 4, 2, [() => TagSpecificationList, { [_xN]: _TSa }], 0],
      2
    ];
    exports2.CreateFleetResult$ = [
      3,
      n032,
      _CFRr,
      0,
      [_FIl, _Err, _Ins],
      [[0, {
        [_eQN]: `FleetId`,
        [_xN]: _fIl
      }], [() => CreateFleetErrorsSet, {
        [_eQN]: `ErrorSet`,
        [_xN]: _eSr
      }], [() => CreateFleetInstancesSet, {
        [_eQN]: `FleetInstanceSet`,
        [_xN]: _fIS
      }]]
    ];
    exports2.CreateFlowLogsRequest$ = [
      3,
      n032,
      _CFLR,
      0,
      [_RIes, _RTe, _DR, _CT4, _DLPA, _DCAR, _LGN, _TT, _LDTo, _LD, _LF, _TS, _MAI, _DOe],
      [[() => FlowLogResourceIds, { [_xN]: _RIeso }], 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, [() => TagSpecificationList, { [_xN]: _TSa }], 1, () => exports2.DestinationOptionsRequest$],
      2
    ];
    exports2.CreateFlowLogsResult$ = [
      3,
      n032,
      _CFLRr,
      0,
      [_CT4, _FLI, _U],
      [[0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }], [() => ValueStringList, {
        [_eQN]: `FlowLogIdSet`,
        [_xN]: _fLIS
      }], [() => UnsuccessfulItemSet, {
        [_eQN]: `Unsuccessful`,
        [_xN]: _u
      }]]
    ];
    exports2.CreateFpgaImageRequest$ = [
      3,
      n032,
      _CFIRr,
      0,
      [_ISL, _DR, _LSL, _De, _N, _CT4, _TS],
      [() => exports2.StorageLocation$, 2, () => exports2.StorageLocation$, 0, 0, 0, [() => TagSpecificationList, { [_xN]: _TSa }]],
      1
    ];
    exports2.CreateFpgaImageResult$ = [
      3,
      n032,
      _CFIRre,
      0,
      [_FII, _FIGI],
      [[0, {
        [_eQN]: `FpgaImageId`,
        [_xN]: _fII
      }], [0, {
        [_eQN]: `FpgaImageGlobalId`,
        [_xN]: _fIGI
      }]]
    ];
    exports2.CreateImageRequest$ = [
      3,
      n032,
      _CIRr,
      0,
      [_II2, _N, _TS, _SL, _DR, _De, _NR, _BDMl],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `Name`,
        [_xN]: _n
      }], [() => TagSpecificationList, { [_xN]: _TSa }], 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [2, {
        [_eQN]: `NoReboot`,
        [_xN]: _nR
      }], [() => BlockDeviceMappingRequestList, {
        [_eQN]: `BlockDeviceMapping`,
        [_xN]: _bDM
      }]],
      2
    ];
    exports2.CreateImageResult$ = [
      3,
      n032,
      _CIRre,
      0,
      [_IIm],
      [[0, {
        [_eQN]: `ImageId`,
        [_xN]: _iIma
      }]]
    ];
    exports2.CreateImageUsageReportRequest$ = [
      3,
      n032,
      _CIURR,
      0,
      [_IIm, _RTes, _DR, _AIcc, _CT4, _TS],
      [0, [() => ImageUsageResourceTypeRequestList, { [_xN]: _RTe }], 2, [() => ImageUsageReportUserIdStringList, { [_xN]: _AIc }], [0, 4], [() => TagSpecificationList, { [_xN]: _TSa }]],
      2
    ];
    exports2.CreateImageUsageReportResult$ = [
      3,
      n032,
      _CIURRr,
      0,
      [_RI],
      [[0, {
        [_eQN]: `ReportId`,
        [_xN]: _rIe
      }]]
    ];
    exports2.CreateInstanceConnectEndpointRequest$ = [
      3,
      n032,
      _CICER,
      0,
      [_SIu, _DR, _SGIe, _PCI, _CT4, _TS, _IAT],
      [0, 2, [() => SecurityGroupIdStringListRequest, { [_xN]: _SGI }], 2, [0, 4], [() => TagSpecificationList, { [_xN]: _TSa }], 0],
      1
    ];
    exports2.CreateInstanceConnectEndpointResult$ = [
      3,
      n032,
      _CICERr,
      0,
      [_ICE4, _CT4],
      [[() => exports2.Ec2InstanceConnectEndpoint$, {
        [_eQN]: `InstanceConnectEndpoint`,
        [_xN]: _iCE
      }], [0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }]]
    ];
    exports2.CreateInstanceEventWindowRequest$ = [
      3,
      n032,
      _CIEWR,
      0,
      [_DR, _N, _TRi, _CEr, _TS],
      [2, 0, [() => InstanceEventWindowTimeRangeRequestSet, { [_xN]: _TRim }], 0, [() => TagSpecificationList, { [_xN]: _TSa }]]
    ];
    exports2.CreateInstanceEventWindowResult$ = [
      3,
      n032,
      _CIEWRr,
      0,
      [_IEW],
      [[() => exports2.InstanceEventWindow$, {
        [_eQN]: `InstanceEventWindow`,
        [_xN]: _iEW
      }]]
    ];
    exports2.CreateInstanceExportTaskRequest$ = [
      3,
      n032,
      _CIETR,
      0,
      [_II2, _TE, _ETST, _TS, _De],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `TargetEnvironment`,
        [_xN]: _tE
      }], [() => exports2.ExportToS3TaskSpecification$, {
        [_eQN]: `ExportToS3`,
        [_xN]: _eTS
      }], [() => TagSpecificationList, { [_xN]: _TSa }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }]],
      3
    ];
    exports2.CreateInstanceExportTaskResult$ = [
      3,
      n032,
      _CIETRr,
      0,
      [_ETx],
      [[() => exports2.ExportTask$, {
        [_eQN]: `ExportTask`,
        [_xN]: _eTx
      }]]
    ];
    exports2.CreateInternetGatewayRequest$ = [
      3,
      n032,
      _CIGR,
      0,
      [_TS, _DR],
      [[() => TagSpecificationList, { [_xN]: _TSa }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]]
    ];
    exports2.CreateInternetGatewayResult$ = [
      3,
      n032,
      _CIGRr,
      0,
      [_IG],
      [[() => exports2.InternetGateway$, {
        [_eQN]: `InternetGateway`,
        [_xN]: _iG
      }]]
    ];
    exports2.CreateInterruptibleCapacityReservationAllocationRequest$ = [
      3,
      n032,
      _CICRAR,
      0,
      [_CRI, _IC, _CT4, _DR, _TS],
      [0, 1, [0, 4], 2, [() => TagSpecificationList, { [_xN]: _TSa }]],
      2
    ];
    exports2.CreateInterruptibleCapacityReservationAllocationResult$ = [
      3,
      n032,
      _CICRARr,
      0,
      [_SCRI, _TICa, _Sta, _ITn],
      [[0, {
        [_eQN]: `SourceCapacityReservationId`,
        [_xN]: _sCRI
      }], [1, {
        [_eQN]: `TargetInstanceCount`,
        [_xN]: _tICa
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `InterruptionType`,
        [_xN]: _iTn
      }]]
    ];
    exports2.CreateIpamExternalResourceVerificationTokenRequest$ = [
      3,
      n032,
      _CIERVTR,
      0,
      [_IIp, _DR, _TS, _CT4],
      [0, 2, [() => TagSpecificationList, { [_xN]: _TSa }], [0, 4]],
      1
    ];
    exports2.CreateIpamExternalResourceVerificationTokenResult$ = [
      3,
      n032,
      _CIERVTRr,
      0,
      [_IERVT],
      [[() => exports2.IpamExternalResourceVerificationToken$, {
        [_eQN]: `IpamExternalResourceVerificationToken`,
        [_xN]: _iERVT
      }]]
    ];
    exports2.CreateIpamPolicyRequest$ = [
      3,
      n032,
      _CIPR,
      0,
      [_IIp, _DR, _TS, _CT4],
      [0, 2, [() => TagSpecificationList, { [_xN]: _TSa }], [0, 4]],
      1
    ];
    exports2.CreateIpamPolicyResult$ = [
      3,
      n032,
      _CIPRr,
      0,
      [_IPpa],
      [[() => exports2.IpamPolicy$, {
        [_eQN]: `IpamPolicy`,
        [_xN]: _iPpa
      }]]
    ];
    exports2.CreateIpamPoolRequest$ = [
      3,
      n032,
      _CIPRre,
      0,
      [_ISI, _AF, _DR, _Lo, _SIPI, _De, _AIu, _PAu, _AMNL, _AMNLl, _ADNL, _ART, _TS, _CT4, _ASw, _PIS, _SRou],
      [0, 0, 2, 0, 0, 0, 2, 2, 1, 1, 1, [() => RequestIpamResourceTagList, { [_xN]: _ARTl }], [() => TagSpecificationList, { [_xN]: _TSa }], [0, 4], 0, 0, () => exports2.IpamPoolSourceResourceRequest$],
      2
    ];
    exports2.CreateIpamPoolResult$ = [
      3,
      n032,
      _CIPRrea,
      0,
      [_IPpam],
      [[() => exports2.IpamPool$, {
        [_eQN]: `IpamPool`,
        [_xN]: _iPpam
      }]]
    ];
    exports2.CreateIpamPrefixListResolverRequest$ = [
      3,
      n032,
      _CIPLRR,
      0,
      [_IIp, _AF, _DR, _De, _Ru, _TS, _CT4],
      [0, 0, 2, 0, [() => IpamPrefixListResolverRuleRequestSet, { [_xN]: _Rul }], [() => TagSpecificationList, { [_xN]: _TSa }], [0, 4]],
      2
    ];
    exports2.CreateIpamPrefixListResolverResult$ = [
      3,
      n032,
      _CIPLRRr,
      0,
      [_IPLR],
      [[() => exports2.IpamPrefixListResolver$, {
        [_eQN]: `IpamPrefixListResolver`,
        [_xN]: _iPLR
      }]]
    ];
    exports2.CreateIpamPrefixListResolverTargetRequest$ = [
      3,
      n032,
      _CIPLRTR,
      0,
      [_IPLRI, _PLI, _PLR, _TLV, _DR, _DV, _TS, _CT4],
      [0, 0, 0, 2, 2, 1, [() => TagSpecificationList, { [_xN]: _TSa }], [0, 4]],
      4
    ];
    exports2.CreateIpamPrefixListResolverTargetResult$ = [
      3,
      n032,
      _CIPLRTRr,
      0,
      [_IPLRT],
      [[() => exports2.IpamPrefixListResolverTarget$, {
        [_eQN]: `IpamPrefixListResolverTarget`,
        [_xN]: _iPLRT
      }]]
    ];
    exports2.CreateIpamRequest$ = [
      3,
      n032,
      _CIRrea,
      0,
      [_DR, _De, _OR, _TS, _CT4, _Tie, _EPG, _MAe],
      [2, 0, [() => AddIpamOperatingRegionSet, { [_xN]: _ORp }], [() => TagSpecificationList, { [_xN]: _TSa }], [0, 4], 0, 2, 0]
    ];
    exports2.CreateIpamResourceDiscoveryRequest$ = [
      3,
      n032,
      _CIRDR,
      0,
      [_DR, _De, _OR, _TS, _CT4],
      [2, 0, [() => AddIpamOperatingRegionSet, { [_xN]: _ORp }], [() => TagSpecificationList, { [_xN]: _TSa }], [0, 4]]
    ];
    exports2.CreateIpamResourceDiscoveryResult$ = [
      3,
      n032,
      _CIRDRr,
      0,
      [_IRD],
      [[() => exports2.IpamResourceDiscovery$, {
        [_eQN]: `IpamResourceDiscovery`,
        [_xN]: _iRD
      }]]
    ];
    exports2.CreateIpamResult$ = [
      3,
      n032,
      _CIRreat,
      0,
      [_Ip],
      [[() => exports2.Ipam$, {
        [_eQN]: `Ipam`,
        [_xN]: _ip
      }]]
    ];
    exports2.CreateIpamScopeRequest$ = [
      3,
      n032,
      _CISR,
      0,
      [_IIp, _DR, _De, _TS, _CT4, _EAC],
      [0, 2, 0, [() => TagSpecificationList, { [_xN]: _TSa }], [0, 4], () => exports2.ExternalAuthorityConfiguration$],
      1
    ];
    exports2.CreateIpamScopeResult$ = [
      3,
      n032,
      _CISRr,
      0,
      [_ISp],
      [[() => exports2.IpamScope$, {
        [_eQN]: `IpamScope`,
        [_xN]: _iSp
      }]]
    ];
    exports2.CreateKeyPairRequest$ = [
      3,
      n032,
      _CKPR,
      0,
      [_KN, _KT, _TS, _KF, _DR],
      [0, 0, [() => TagSpecificationList, { [_xN]: _TSa }], 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.CreateLaunchTemplateRequest$ = [
      3,
      n032,
      _CLTR,
      0,
      [_LTN, _LTD, _DR, _CT4, _VD, _Op, _TS],
      [0, [() => exports2.RequestLaunchTemplateData$, 0], 2, [0, 4], 0, () => exports2.OperatorRequest$, [() => TagSpecificationList, { [_xN]: _TSa }]],
      2
    ];
    exports2.CreateLaunchTemplateResult$ = [
      3,
      n032,
      _CLTRr,
      0,
      [_LT, _W],
      [[() => exports2.LaunchTemplate$, {
        [_eQN]: `LaunchTemplate`,
        [_xN]: _lT
      }], [() => exports2.ValidationWarning$, {
        [_eQN]: `Warning`,
        [_xN]: _w
      }]]
    ];
    exports2.CreateLaunchTemplateVersionRequest$ = [
      3,
      n032,
      _CLTVR,
      0,
      [_LTD, _DR, _CT4, _LTI, _LTN, _SV, _VD, _RAes],
      [[() => exports2.RequestLaunchTemplateData$, 0], 2, [0, 4], 0, 0, 0, 0, 2],
      1
    ];
    exports2.CreateLaunchTemplateVersionResult$ = [
      3,
      n032,
      _CLTVRr,
      0,
      [_LTV, _W],
      [[() => exports2.LaunchTemplateVersion$, {
        [_eQN]: `LaunchTemplateVersion`,
        [_xN]: _lTV
      }], [() => exports2.ValidationWarning$, {
        [_eQN]: `Warning`,
        [_xN]: _w
      }]]
    ];
    exports2.CreateLocalGatewayRouteRequest$ = [
      3,
      n032,
      _CLGRR,
      0,
      [_LGRTI, _DCB, _LGVIGI, _DR, _NII, _DPLI],
      [0, 0, 0, 2, 0, 0],
      1
    ];
    exports2.CreateLocalGatewayRouteResult$ = [
      3,
      n032,
      _CLGRRr,
      0,
      [_Ro],
      [[() => exports2.LocalGatewayRoute$, {
        [_eQN]: `Route`,
        [_xN]: _ro
      }]]
    ];
    exports2.CreateLocalGatewayRouteTableRequest$ = [
      3,
      n032,
      _CLGRTR,
      0,
      [_LGI, _Mo, _TS, _DR],
      [0, 0, [() => TagSpecificationList, { [_xN]: _TSa }], 2],
      1
    ];
    exports2.CreateLocalGatewayRouteTableResult$ = [
      3,
      n032,
      _CLGRTRr,
      0,
      [_LGRT],
      [[() => exports2.LocalGatewayRouteTable$, {
        [_eQN]: `LocalGatewayRouteTable`,
        [_xN]: _lGRT
      }]]
    ];
    exports2.CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest$ = [
      3,
      n032,
      _CLGRTVIGAR,
      0,
      [_LGRTI, _LGVIGI, _TS, _DR],
      [0, 0, [() => TagSpecificationList, { [_xN]: _TSa }], 2],
      2
    ];
    exports2.CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationResult$ = [
      3,
      n032,
      _CLGRTVIGARr,
      0,
      [_LGRTVIGA],
      [[() => exports2.LocalGatewayRouteTableVirtualInterfaceGroupAssociation$, {
        [_eQN]: `LocalGatewayRouteTableVirtualInterfaceGroupAssociation`,
        [_xN]: _lGRTVIGA
      }]]
    ];
    exports2.CreateLocalGatewayRouteTableVpcAssociationRequest$ = [
      3,
      n032,
      _CLGRTVAR,
      0,
      [_LGRTI, _VI, _TS, _DR],
      [0, 0, [() => TagSpecificationList, { [_xN]: _TSa }], 2],
      2
    ];
    exports2.CreateLocalGatewayRouteTableVpcAssociationResult$ = [
      3,
      n032,
      _CLGRTVARr,
      0,
      [_LGRTVA],
      [[() => exports2.LocalGatewayRouteTableVpcAssociation$, {
        [_eQN]: `LocalGatewayRouteTableVpcAssociation`,
        [_xN]: _lGRTVA
      }]]
    ];
    exports2.CreateLocalGatewayVirtualInterfaceGroupRequest$ = [
      3,
      n032,
      _CLGVIGR,
      0,
      [_LGI, _LBA, _LBAE, _TS, _DR],
      [0, 1, 1, [() => TagSpecificationList, { [_xN]: _TSa }], 2],
      1
    ];
    exports2.CreateLocalGatewayVirtualInterfaceGroupResult$ = [
      3,
      n032,
      _CLGVIGRr,
      0,
      [_LGVIG],
      [[() => exports2.LocalGatewayVirtualInterfaceGroup$, {
        [_eQN]: `LocalGatewayVirtualInterfaceGroup`,
        [_xN]: _lGVIG
      }]]
    ];
    exports2.CreateLocalGatewayVirtualInterfaceRequest$ = [
      3,
      n032,
      _CLGVIR,
      0,
      [_LGVIGI, _OLI, _Vl, _LA, _PAe, _PBA, _TS, _DR, _PBAE],
      [0, 0, 1, 0, 0, 1, [() => TagSpecificationList, { [_xN]: _TSa }], 2, 1],
      5
    ];
    exports2.CreateLocalGatewayVirtualInterfaceResult$ = [
      3,
      n032,
      _CLGVIRr,
      0,
      [_LGVI],
      [[() => exports2.LocalGatewayVirtualInterface$, {
        [_eQN]: `LocalGatewayVirtualInterface`,
        [_xN]: _lGVI
      }]]
    ];
    exports2.CreateMacSystemIntegrityProtectionModificationTaskRequest$ = [
      3,
      n032,
      _CMSIPMTR,
      0,
      [_II2, _MSIPS, _CT4, _DR, _MC, _MSIPC, _TS],
      [0, 0, [0, 4], 2, [() => SensitiveMacCredentials, 0], () => exports2.MacSystemIntegrityProtectionConfigurationRequest$, [() => TagSpecificationList, { [_xN]: _TSa }]],
      2
    ];
    exports2.CreateMacSystemIntegrityProtectionModificationTaskResult$ = [
      3,
      n032,
      _CMSIPMTRr,
      0,
      [_MMT],
      [[() => exports2.MacModificationTask$, {
        [_eQN]: `MacModificationTask`,
        [_xN]: _mMT
      }]]
    ];
    exports2.CreateManagedPrefixListRequest$ = [
      3,
      n032,
      _CMPLR,
      0,
      [_PLN, _ME, _AF, _DR, _Ent, _TS, _CT4],
      [0, 1, 0, 2, [() => AddPrefixListEntries, { [_xN]: _Entr }], [() => TagSpecificationList, { [_xN]: _TSa }], [0, 4]],
      3
    ];
    exports2.CreateManagedPrefixListResult$ = [
      3,
      n032,
      _CMPLRr,
      0,
      [_PL],
      [[() => exports2.ManagedPrefixList$, {
        [_eQN]: `PrefixList`,
        [_xN]: _pL
      }]]
    ];
    exports2.CreateNatGatewayRequest$ = [
      3,
      n032,
      _CNGR,
      0,
      [_AMv, _AIl, _CT4, _DR, _SIu, _VI, _AZAv, _TS, _CTon, _PIAr, _SAI, _SPIA, _SPIAC],
      [0, 0, [0, 4], 2, 0, 0, [() => AvailabilityZoneAddresses, { [_xN]: _AZA }], [() => TagSpecificationList, { [_xN]: _TSa }], 0, 0, [() => AllocationIdList, { [_xN]: _SAIe }], [() => IpList, { [_xN]: _SPIAe }], 1]
    ];
    exports2.CreateNatGatewayResult$ = [
      3,
      n032,
      _CNGRr,
      0,
      [_CT4, _NG],
      [[0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }], [() => exports2.NatGateway$, {
        [_eQN]: `NatGateway`,
        [_xN]: _nG
      }]]
    ];
    exports2.CreateNetworkAclEntryRequest$ = [
      3,
      n032,
      _CNAER,
      0,
      [_NAI, _RNu, _Pr10, _RA10, _E11, _DR, _CB, _ICB, _ITC, _PRo],
      [[0, {
        [_eQN]: `NetworkAclId`,
        [_xN]: _nAI
      }], [1, {
        [_eQN]: `RuleNumber`,
        [_xN]: _rN10
      }], [0, {
        [_eQN]: `Protocol`,
        [_xN]: _pr
      }], [0, {
        [_eQN]: `RuleAction`,
        [_xN]: _rA
      }], [2, {
        [_eQN]: `Egress`,
        [_xN]: _e32
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [0, {
        [_eQN]: `CidrBlock`,
        [_xN]: _cB
      }], [0, {
        [_eQN]: `Ipv6CidrBlock`,
        [_xN]: _iCB
      }], [() => exports2.IcmpTypeCode$, { [_xN]: _Ic }], [() => exports2.PortRange$, {
        [_eQN]: `PortRange`,
        [_xN]: _pRo
      }]],
      5
    ];
    exports2.CreateNetworkAclRequest$ = [
      3,
      n032,
      _CNAR,
      0,
      [_VI, _TS, _CT4, _DR],
      [[0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [() => TagSpecificationList, { [_xN]: _TSa }], [0, 4], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.CreateNetworkAclResult$ = [
      3,
      n032,
      _CNARr,
      0,
      [_NA, _CT4],
      [[() => exports2.NetworkAcl$, {
        [_eQN]: `NetworkAcl`,
        [_xN]: _nA
      }], [0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }]]
    ];
    exports2.CreateNetworkInsightsAccessScopeRequest$ = [
      3,
      n032,
      _CNIASR,
      0,
      [_MP, _EPx, _CT4, _TS, _DR],
      [[() => AccessScopePathListRequest, { [_xN]: _MPa }], [() => AccessScopePathListRequest, { [_xN]: _EPxc }], [0, 4], [() => TagSpecificationList, { [_xN]: _TSa }], 2]
    ];
    exports2.CreateNetworkInsightsAccessScopeResult$ = [
      3,
      n032,
      _CNIASRr,
      0,
      [_NIAS, _NIASC],
      [[() => exports2.NetworkInsightsAccessScope$, {
        [_eQN]: `NetworkInsightsAccessScope`,
        [_xN]: _nIAS
      }], [() => exports2.NetworkInsightsAccessScopeContent$, {
        [_eQN]: `NetworkInsightsAccessScopeContent`,
        [_xN]: _nIASC
      }]]
    ];
    exports2.CreateNetworkInsightsPathRequest$ = [
      3,
      n032,
      _CNIPR,
      0,
      [_S, _Pr10, _SIo, _DIe, _D, _DPe, _TS, _DR, _CT4, _FAS, _FAD],
      [0, 0, 0, 0, 0, 1, [() => TagSpecificationList, { [_xN]: _TSa }], 2, [0, 4], () => exports2.PathRequestFilter$, () => exports2.PathRequestFilter$],
      2
    ];
    exports2.CreateNetworkInsightsPathResult$ = [
      3,
      n032,
      _CNIPRr,
      0,
      [_NIP],
      [[() => exports2.NetworkInsightsPath$, {
        [_eQN]: `NetworkInsightsPath`,
        [_xN]: _nIP
      }]]
    ];
    exports2.CreateNetworkInterfacePermissionRequest$ = [
      3,
      n032,
      _CNIPRre,
      0,
      [_NII, _Pe, _AAI, _ASw, _DR],
      [0, 0, 0, 0, 2],
      2
    ];
    exports2.CreateNetworkInterfacePermissionResult$ = [
      3,
      n032,
      _CNIPRrea,
      0,
      [_IPnt],
      [[() => exports2.NetworkInterfacePermission$, {
        [_eQN]: `InterfacePermission`,
        [_xN]: _iPnt
      }]]
    ];
    exports2.CreateNetworkInterfaceRequest$ = [
      3,
      n032,
      _CNIR,
      0,
      [_SIu, _IPpvr, _IPCp, _IPp, _IPC, _ITnt, _TS, _CT4, _EPI, _CTS, _Op, _De, _PIAr, _G, _PIAri, _SPIAC, _IA, _IAC, _DR],
      [[0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }], [() => Ipv4PrefixList, { [_xN]: _IPpvre }], 1, [() => Ipv6PrefixList, { [_xN]: _IPpv }], 1, 0, [() => TagSpecificationList, { [_xN]: _TSa }], [0, 4], 2, () => exports2.ConnectionTrackingSpecificationRequest$, () => exports2.OperatorRequest$, [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [0, {
        [_eQN]: `PrivateIpAddress`,
        [_xN]: _pIAr
      }], [() => SecurityGroupIdStringList, { [_xN]: _SGI }], [() => PrivateIpAddressSpecificationList, {
        [_eQN]: `PrivateIpAddresses`,
        [_xN]: _pIAri
      }], [1, {
        [_eQN]: `SecondaryPrivateIpAddressCount`,
        [_xN]: _sPIAC
      }], [() => InstanceIpv6AddressList, {
        [_eQN]: `Ipv6Addresses`,
        [_xN]: _iA
      }], [1, {
        [_eQN]: `Ipv6AddressCount`,
        [_xN]: _iAC
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.CreateNetworkInterfaceResult$ = [
      3,
      n032,
      _CNIRr,
      0,
      [_NIe, _CT4],
      [[() => exports2.NetworkInterface$, {
        [_eQN]: `NetworkInterface`,
        [_xN]: _nIe
      }], [0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }]]
    ];
    exports2.CreatePlacementGroupRequest$ = [
      3,
      n032,
      _CPGR,
      0,
      [_PCa, _TS, _SLp, _LGIi, _Op, _DR, _GN, _Str],
      [1, [() => TagSpecificationList, { [_xN]: _TSa }], 0, 0, () => exports2.OperatorRequest$, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [0, {
        [_eQN]: `GroupName`,
        [_xN]: _gN
      }], [0, {
        [_eQN]: `Strategy`,
        [_xN]: _str
      }]]
    ];
    exports2.CreatePlacementGroupResult$ = [
      3,
      n032,
      _CPGRr,
      0,
      [_PG],
      [[() => exports2.PlacementGroup$, {
        [_eQN]: `PlacementGroup`,
        [_xN]: _pG
      }]]
    ];
    exports2.CreatePublicIpv4PoolRequest$ = [
      3,
      n032,
      _CPIPR,
      0,
      [_DR, _TS, _NBG],
      [2, [() => TagSpecificationList, { [_xN]: _TSa }], 0]
    ];
    exports2.CreatePublicIpv4PoolResult$ = [
      3,
      n032,
      _CPIPRr,
      0,
      [_PIo],
      [[0, {
        [_eQN]: `PoolId`,
        [_xN]: _pIo
      }]]
    ];
    exports2.CreateReplaceRootVolumeTaskRequest$ = [
      3,
      n032,
      _CRRVTR,
      0,
      [_II2, _SIn, _CT4, _DR, _TS, _IIm, _DRRV, _VIR],
      [0, 0, [0, 4], 2, [() => TagSpecificationList, { [_xN]: _TSa }], 0, 2, 1],
      1
    ];
    exports2.CreateReplaceRootVolumeTaskResult$ = [
      3,
      n032,
      _CRRVTRr,
      0,
      [_RRVT],
      [[() => exports2.ReplaceRootVolumeTask$, {
        [_eQN]: `ReplaceRootVolumeTask`,
        [_xN]: _rRVT
      }]]
    ];
    exports2.CreateReservedInstancesListingRequest$ = [
      3,
      n032,
      _CRILRr,
      0,
      [_RIIes, _IC, _PSri, _CT4],
      [[0, {
        [_eQN]: `ReservedInstancesId`,
        [_xN]: _rII
      }], [1, {
        [_eQN]: `InstanceCount`,
        [_xN]: _iC
      }], [() => PriceScheduleSpecificationList, {
        [_eQN]: `PriceSchedules`,
        [_xN]: _pSri
      }], [0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }]],
      4
    ];
    exports2.CreateReservedInstancesListingResult$ = [
      3,
      n032,
      _CRILRre,
      0,
      [_RIL],
      [[() => ReservedInstancesListingList, {
        [_eQN]: `ReservedInstancesListingsSet`,
        [_xN]: _rILS
      }]]
    ];
    exports2.CreateRestoreImageTaskRequest$ = [
      3,
      n032,
      _CRITR,
      0,
      [_Bu, _OK, _N, _TS, _DR],
      [0, 0, 0, [() => TagSpecificationList, { [_xN]: _TSa }], 2],
      2
    ];
    exports2.CreateRestoreImageTaskResult$ = [
      3,
      n032,
      _CRITRr,
      0,
      [_IIm],
      [[0, {
        [_eQN]: `ImageId`,
        [_xN]: _iIma
      }]]
    ];
    exports2.CreateRouteRequest$ = [
      3,
      n032,
      _CRR,
      0,
      [_RTI, _DPLI, _VEIp, _TGI, _LGI, _CGI, _CNA, _ONA, _DR, _DCB, _GI2, _DICB, _EOIGI, _II2, _NII, _VPCI, _NGI],
      [[0, {
        [_eQN]: `RouteTableId`,
        [_xN]: _rTI
      }], 0, 0, 0, 0, 0, 0, 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [0, {
        [_eQN]: `DestinationCidrBlock`,
        [_xN]: _dCB
      }], [0, {
        [_eQN]: `GatewayId`,
        [_xN]: _gI
      }], [0, {
        [_eQN]: `DestinationIpv6CidrBlock`,
        [_xN]: _dICB
      }], [0, {
        [_eQN]: `EgressOnlyInternetGatewayId`,
        [_xN]: _eOIGI
      }], [0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], [0, {
        [_eQN]: `VpcPeeringConnectionId`,
        [_xN]: _vPCI
      }], [0, {
        [_eQN]: `NatGatewayId`,
        [_xN]: _nGI
      }]],
      1
    ];
    exports2.CreateRouteResult$ = [
      3,
      n032,
      _CRRr,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.CreateRouteServerEndpointRequest$ = [
      3,
      n032,
      _CRSER,
      0,
      [_RSI, _SIu, _CT4, _DR, _TS],
      [0, 0, [0, 4], 2, [() => TagSpecificationList, { [_xN]: _TSa }]],
      2
    ];
    exports2.CreateRouteServerEndpointResult$ = [
      3,
      n032,
      _CRSERr,
      0,
      [_RSE],
      [[() => exports2.RouteServerEndpoint$, {
        [_eQN]: `RouteServerEndpoint`,
        [_xN]: _rSE
      }]]
    ];
    exports2.CreateRouteServerPeerRequest$ = [
      3,
      n032,
      _CRSPR,
      0,
      [_RSEI, _PAe, _BO, _DR, _TS],
      [0, 0, () => exports2.RouteServerBgpOptionsRequest$, 2, [() => TagSpecificationList, { [_xN]: _TSa }]],
      3
    ];
    exports2.CreateRouteServerPeerResult$ = [
      3,
      n032,
      _CRSPRr,
      0,
      [_RSP],
      [[() => exports2.RouteServerPeer$, {
        [_eQN]: `RouteServerPeer`,
        [_xN]: _rSP
      }]]
    ];
    exports2.CreateRouteServerRequest$ = [
      3,
      n032,
      _CRSRr,
      0,
      [_ASA, _CT4, _DR, _PRe, _PRD, _SNE, _TS],
      [1, [0, 4], 2, 0, 1, 2, [() => TagSpecificationList, { [_xN]: _TSa }]],
      1
    ];
    exports2.CreateRouteServerResult$ = [
      3,
      n032,
      _CRSRre,
      0,
      [_RSo],
      [[() => exports2.RouteServer$, {
        [_eQN]: `RouteServer`,
        [_xN]: _rSo
      }]]
    ];
    exports2.CreateRouteTableRequest$ = [
      3,
      n032,
      _CRTRr,
      0,
      [_VI, _TS, _CT4, _DR],
      [[0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [() => TagSpecificationList, { [_xN]: _TSa }], [0, 4], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.CreateRouteTableResult$ = [
      3,
      n032,
      _CRTRre,
      0,
      [_RTo, _CT4],
      [[() => exports2.RouteTable$, {
        [_eQN]: `RouteTable`,
        [_xN]: _rTo
      }], [0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }]]
    ];
    exports2.CreateSecondaryNetworkRequest$ = [
      3,
      n032,
      _CSNR,
      0,
      [_ICBp, _NT, _CT4, _DR, _TS],
      [0, 0, [0, 4], 2, [() => TagSpecificationList, { [_xN]: _TSa }]],
      2
    ];
    exports2.CreateSecondaryNetworkResult$ = [
      3,
      n032,
      _CSNRr,
      0,
      [_SNe, _CT4],
      [[() => exports2.SecondaryNetwork$, {
        [_eQN]: `SecondaryNetwork`,
        [_xN]: _sNe
      }], [0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }]]
    ];
    exports2.CreateSecondarySubnetRequest$ = [
      3,
      n032,
      _CSSR,
      0,
      [_ICBp, _SNI, _CT4, _AZ, _AZI, _DR, _TS],
      [0, 0, [0, 4], 0, 0, 2, [() => TagSpecificationList, { [_xN]: _TSa }]],
      2
    ];
    exports2.CreateSecondarySubnetResult$ = [
      3,
      n032,
      _CSSRr,
      0,
      [_SS, _CT4],
      [[() => exports2.SecondarySubnet$, {
        [_eQN]: `SecondarySubnet`,
        [_xN]: _sS
      }], [0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }]]
    ];
    exports2.CreateSecurityGroupRequest$ = [
      3,
      n032,
      _CSGR,
      0,
      [_De, _GN, _VI, _TS, _DR],
      [[0, { [_xN]: _GD }], 0, 0, [() => TagSpecificationList, { [_xN]: _TSa }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      2
    ];
    exports2.CreateSecurityGroupResult$ = [
      3,
      n032,
      _CSGRr,
      0,
      [_GIr, _T10, _SGA],
      [[0, {
        [_eQN]: `GroupId`,
        [_xN]: _gIr
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `SecurityGroupArn`,
        [_xN]: _sGA
      }]]
    ];
    exports2.CreateSnapshotRequest$ = [
      3,
      n032,
      _CSRr,
      0,
      [_VIo, _De, _OA, _TS, _Loc, _DR],
      [0, 0, 0, [() => TagSpecificationList, { [_xN]: _TSa }], 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.CreateSnapshotsRequest$ = [
      3,
      n032,
      _CSRre,
      0,
      [_ISn, _De, _OA, _TS, _DR, _CTFS, _Loc],
      [[() => exports2.InstanceSpecification$, 0], 0, 0, [() => TagSpecificationList, { [_xN]: _TSa }], 2, 0, 0],
      1
    ];
    exports2.CreateSnapshotsResult$ = [
      3,
      n032,
      _CSRrea,
      0,
      [_Sn],
      [[() => SnapshotSet, {
        [_eQN]: `SnapshotSet`,
        [_xN]: _sSn
      }]]
    ];
    exports2.CreateSpotDatafeedSubscriptionRequest$ = [
      3,
      n032,
      _CSDSR,
      0,
      [_Bu, _DR, _Pre],
      [[0, {
        [_eQN]: `Bucket`,
        [_xN]: _b
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [0, {
        [_eQN]: `Prefix`,
        [_xN]: _pre
      }]],
      1
    ];
    exports2.CreateSpotDatafeedSubscriptionResult$ = [
      3,
      n032,
      _CSDSRr,
      0,
      [_SDS],
      [[() => exports2.SpotDatafeedSubscription$, {
        [_eQN]: `SpotDatafeedSubscription`,
        [_xN]: _sDS
      }]]
    ];
    exports2.CreateStoreImageTaskRequest$ = [
      3,
      n032,
      _CSITR,
      0,
      [_IIm, _Bu, _SOT, _DR],
      [0, 0, [() => S3ObjectTagList, { [_xN]: _SOTb }], 2],
      2
    ];
    exports2.CreateStoreImageTaskResult$ = [
      3,
      n032,
      _CSITRr,
      0,
      [_OK],
      [[0, {
        [_eQN]: `ObjectKey`,
        [_xN]: _oK
      }]]
    ];
    exports2.CreateSubnetCidrReservationRequest$ = [
      3,
      n032,
      _CSCRR,
      0,
      [_SIu, _Ci, _RT13, _De, _DR, _TS],
      [0, 0, 0, 0, 2, [() => TagSpecificationList, { [_xN]: _TSa }]],
      3
    ];
    exports2.CreateSubnetCidrReservationResult$ = [
      3,
      n032,
      _CSCRRr,
      0,
      [_SCRu],
      [[() => exports2.SubnetCidrReservation$, {
        [_eQN]: `SubnetCidrReservation`,
        [_xN]: _sCRu
      }]]
    ];
    exports2.CreateSubnetRequest$ = [
      3,
      n032,
      _CSRreat,
      0,
      [_VI, _TS, _AZ, _AZI, _CB, _ICB, _OA, _IN, _IIPIp, _INLp, _IIPI, _INL, _DR],
      [0, [() => TagSpecificationList, { [_xN]: _TSa }], 0, 0, 0, 0, 0, 2, 0, 1, 0, 1, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.CreateSubnetResult$ = [
      3,
      n032,
      _CSRreate,
      0,
      [_Su],
      [[() => exports2.Subnet$, {
        [_eQN]: `Subnet`,
        [_xN]: _su
      }]]
    ];
    exports2.CreateTagsRequest$ = [
      3,
      n032,
      _CTR4,
      0,
      [_Res, _T10, _DR],
      [[64 | 0, { [_xN]: _RIeso }], [() => TagList, { [_xN]: _Ta10 }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      2
    ];
    exports2.CreateTrafficMirrorFilterRequest$ = [
      3,
      n032,
      _CTMFR,
      0,
      [_De, _TS, _DR, _CT4],
      [0, [() => TagSpecificationList, { [_xN]: _TSa }], 2, [0, 4]]
    ];
    exports2.CreateTrafficMirrorFilterResult$ = [
      3,
      n032,
      _CTMFRr,
      0,
      [_TMF, _CT4],
      [[() => exports2.TrafficMirrorFilter$, {
        [_eQN]: `TrafficMirrorFilter`,
        [_xN]: _tMF
      }], [0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }]]
    ];
    exports2.CreateTrafficMirrorFilterRuleRequest$ = [
      3,
      n032,
      _CTMFRR,
      0,
      [_TMFI, _TD, _RNu, _RA10, _DCB, _SCB, _DPRe, _SPRo, _Pr10, _De, _DR, _CT4, _TS],
      [0, 0, 1, 0, 0, 0, () => exports2.TrafficMirrorPortRangeRequest$, () => exports2.TrafficMirrorPortRangeRequest$, 1, 0, 2, [0, 4], [() => TagSpecificationList, { [_xN]: _TSa }]],
      6
    ];
    exports2.CreateTrafficMirrorFilterRuleResult$ = [
      3,
      n032,
      _CTMFRRr,
      0,
      [_TMFR, _CT4],
      [[() => exports2.TrafficMirrorFilterRule$, {
        [_eQN]: `TrafficMirrorFilterRule`,
        [_xN]: _tMFR
      }], [0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }]]
    ];
    exports2.CreateTrafficMirrorSessionRequest$ = [
      3,
      n032,
      _CTMSR,
      0,
      [_NII, _TMTI, _TMFI, _SNes, _PLa, _VNI, _De, _TS, _DR, _CT4],
      [0, 0, 0, 1, 1, 1, 0, [() => TagSpecificationList, { [_xN]: _TSa }], 2, [0, 4]],
      4
    ];
    exports2.CreateTrafficMirrorSessionResult$ = [
      3,
      n032,
      _CTMSRr,
      0,
      [_TMS, _CT4],
      [[() => exports2.TrafficMirrorSession$, {
        [_eQN]: `TrafficMirrorSession`,
        [_xN]: _tMS
      }], [0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }]]
    ];
    exports2.CreateTrafficMirrorTargetRequest$ = [
      3,
      n032,
      _CTMTR,
      0,
      [_NII, _NLBA, _De, _TS, _DR, _CT4, _GLBEI],
      [0, 0, 0, [() => TagSpecificationList, { [_xN]: _TSa }], 2, [0, 4], 0]
    ];
    exports2.CreateTrafficMirrorTargetResult$ = [
      3,
      n032,
      _CTMTRr,
      0,
      [_TMT, _CT4],
      [[() => exports2.TrafficMirrorTarget$, {
        [_eQN]: `TrafficMirrorTarget`,
        [_xN]: _tMT
      }], [0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }]]
    ];
    exports2.CreateTransitGatewayConnectPeerRequest$ = [
      3,
      n032,
      _CTGCPR,
      0,
      [_TGAI, _PAe, _ICBn, _TGA, _BO, _TS, _DR],
      [0, 0, [() => InsideCidrBlocksStringList, 0], 0, () => exports2.TransitGatewayConnectRequestBgpOptions$, [() => TagSpecificationList, { [_xN]: _TSa }], 2],
      3
    ];
    exports2.CreateTransitGatewayConnectPeerResult$ = [
      3,
      n032,
      _CTGCPRr,
      0,
      [_TGCP],
      [[() => exports2.TransitGatewayConnectPeer$, {
        [_eQN]: `TransitGatewayConnectPeer`,
        [_xN]: _tGCP
      }]]
    ];
    exports2.CreateTransitGatewayConnectRequest$ = [
      3,
      n032,
      _CTGCR,
      0,
      [_TTGAI, _Opt, _TS, _DR],
      [0, () => exports2.CreateTransitGatewayConnectRequestOptions$, [() => TagSpecificationList, { [_xN]: _TSa }], 2],
      2
    ];
    exports2.CreateTransitGatewayConnectRequestOptions$ = [
      3,
      n032,
      _CTGCRO,
      0,
      [_Pr10],
      [0],
      1
    ];
    exports2.CreateTransitGatewayConnectResult$ = [
      3,
      n032,
      _CTGCRr,
      0,
      [_TGCr],
      [[() => exports2.TransitGatewayConnect$, {
        [_eQN]: `TransitGatewayConnect`,
        [_xN]: _tGCr
      }]]
    ];
    exports2.CreateTransitGatewayMeteringPolicyEntryRequest$ = [
      3,
      n032,
      _CTGMPER,
      0,
      [_TGMPI, _PRN, _MAe, _STGAI, _STGAT, _SCB, _SPRo, _DTGAI, _DTGAT, _DCB, _DPRe, _Pr10, _DR],
      [0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2],
      3
    ];
    exports2.CreateTransitGatewayMeteringPolicyEntryResult$ = [
      3,
      n032,
      _CTGMPERr,
      0,
      [_TGMPE],
      [[() => exports2.TransitGatewayMeteringPolicyEntry$, {
        [_eQN]: `TransitGatewayMeteringPolicyEntry`,
        [_xN]: _tGMPE
      }]]
    ];
    exports2.CreateTransitGatewayMeteringPolicyRequest$ = [
      3,
      n032,
      _CTGMPR,
      0,
      [_TGI, _MAIi, _TS, _DR],
      [0, [64 | 0, { [_xN]: _MAIid }], [() => TagSpecificationList, 0], 2],
      1
    ];
    exports2.CreateTransitGatewayMeteringPolicyResult$ = [
      3,
      n032,
      _CTGMPRr,
      0,
      [_TGMP],
      [[() => exports2.TransitGatewayMeteringPolicy$, {
        [_eQN]: `TransitGatewayMeteringPolicy`,
        [_xN]: _tGMP
      }]]
    ];
    exports2.CreateTransitGatewayMulticastDomainRequest$ = [
      3,
      n032,
      _CTGMDR,
      0,
      [_TGI, _Opt, _TS, _DR],
      [0, () => exports2.CreateTransitGatewayMulticastDomainRequestOptions$, [() => TagSpecificationList, { [_xN]: _TSa }], 2],
      1
    ];
    exports2.CreateTransitGatewayMulticastDomainRequestOptions$ = [
      3,
      n032,
      _CTGMDRO,
      0,
      [_ISg, _SSS, _AASA],
      [0, 0, 0]
    ];
    exports2.CreateTransitGatewayMulticastDomainResult$ = [
      3,
      n032,
      _CTGMDRr,
      0,
      [_TGMD],
      [[() => exports2.TransitGatewayMulticastDomain$, {
        [_eQN]: `TransitGatewayMulticastDomain`,
        [_xN]: _tGMD
      }]]
    ];
    exports2.CreateTransitGatewayPeeringAttachmentRequest$ = [
      3,
      n032,
      _CTGPAR,
      0,
      [_TGI, _PTGI, _PAI, _PRee, _Opt, _TS, _DR],
      [0, 0, 0, 0, () => exports2.CreateTransitGatewayPeeringAttachmentRequestOptions$, [() => TagSpecificationList, { [_xN]: _TSa }], 2],
      4
    ];
    exports2.CreateTransitGatewayPeeringAttachmentRequestOptions$ = [
      3,
      n032,
      _CTGPARO,
      0,
      [_DRy],
      [0]
    ];
    exports2.CreateTransitGatewayPeeringAttachmentResult$ = [
      3,
      n032,
      _CTGPARr,
      0,
      [_TGPA],
      [[() => exports2.TransitGatewayPeeringAttachment$, {
        [_eQN]: `TransitGatewayPeeringAttachment`,
        [_xN]: _tGPA
      }]]
    ];
    exports2.CreateTransitGatewayPolicyTableRequest$ = [
      3,
      n032,
      _CTGPTR,
      0,
      [_TGI, _TS, _DR],
      [0, [() => TagSpecificationList, 0], 2],
      1
    ];
    exports2.CreateTransitGatewayPolicyTableResult$ = [
      3,
      n032,
      _CTGPTRr,
      0,
      [_TGPT],
      [[() => exports2.TransitGatewayPolicyTable$, {
        [_eQN]: `TransitGatewayPolicyTable`,
        [_xN]: _tGPT
      }]]
    ];
    exports2.CreateTransitGatewayPrefixListReferenceRequest$ = [
      3,
      n032,
      _CTGPLRR,
      0,
      [_TGRTI, _PLI, _TGAI, _Bl, _DR],
      [0, 0, 0, 2, 2],
      2
    ];
    exports2.CreateTransitGatewayPrefixListReferenceResult$ = [
      3,
      n032,
      _CTGPLRRr,
      0,
      [_TGPLR],
      [[() => exports2.TransitGatewayPrefixListReference$, {
        [_eQN]: `TransitGatewayPrefixListReference`,
        [_xN]: _tGPLR
      }]]
    ];
    exports2.CreateTransitGatewayRequest$ = [
      3,
      n032,
      _CTGR,
      0,
      [_De, _Opt, _TS, _DR],
      [0, [() => exports2.TransitGatewayRequestOptions$, 0], [() => TagSpecificationList, { [_xN]: _TSa }], 2]
    ];
    exports2.CreateTransitGatewayResult$ = [
      3,
      n032,
      _CTGRr,
      0,
      [_TG],
      [[() => exports2.TransitGateway$, {
        [_eQN]: `TransitGateway`,
        [_xN]: _tG
      }]]
    ];
    exports2.CreateTransitGatewayRouteRequest$ = [
      3,
      n032,
      _CTGRR,
      0,
      [_DCB, _TGRTI, _TGAI, _Bl, _DR],
      [0, 0, 0, 2, 2],
      2
    ];
    exports2.CreateTransitGatewayRouteResult$ = [
      3,
      n032,
      _CTGRRr,
      0,
      [_Ro],
      [[() => exports2.TransitGatewayRoute$, {
        [_eQN]: `Route`,
        [_xN]: _ro
      }]]
    ];
    exports2.CreateTransitGatewayRouteTableAnnouncementRequest$ = [
      3,
      n032,
      _CTGRTAR,
      0,
      [_TGRTI, _PAIe, _TS, _DR],
      [0, 0, [() => TagSpecificationList, { [_xN]: _TSa }], 2],
      2
    ];
    exports2.CreateTransitGatewayRouteTableAnnouncementResult$ = [
      3,
      n032,
      _CTGRTARr,
      0,
      [_TGRTA],
      [[() => exports2.TransitGatewayRouteTableAnnouncement$, {
        [_eQN]: `TransitGatewayRouteTableAnnouncement`,
        [_xN]: _tGRTA
      }]]
    ];
    exports2.CreateTransitGatewayRouteTableRequest$ = [
      3,
      n032,
      _CTGRTR,
      0,
      [_TGI, _TS, _DR],
      [0, [() => TagSpecificationList, 0], 2],
      1
    ];
    exports2.CreateTransitGatewayRouteTableResult$ = [
      3,
      n032,
      _CTGRTRr,
      0,
      [_TGRT],
      [[() => exports2.TransitGatewayRouteTable$, {
        [_eQN]: `TransitGatewayRouteTable`,
        [_xN]: _tGRT
      }]]
    ];
    exports2.CreateTransitGatewayVpcAttachmentRequest$ = [
      3,
      n032,
      _CTGVAR,
      0,
      [_TGI, _VI, _SI10, _Opt, _TS, _DR],
      [0, 0, [() => TransitGatewaySubnetIdList, 0], () => exports2.CreateTransitGatewayVpcAttachmentRequestOptions$, [() => TagSpecificationList, 0], 2],
      3
    ];
    exports2.CreateTransitGatewayVpcAttachmentRequestOptions$ = [
      3,
      n032,
      _CTGVARO,
      0,
      [_DSn, _SGRS, _ISpv, _AMS],
      [0, 0, 0, 0]
    ];
    exports2.CreateTransitGatewayVpcAttachmentResult$ = [
      3,
      n032,
      _CTGVARr,
      0,
      [_TGVA],
      [[() => exports2.TransitGatewayVpcAttachment$, {
        [_eQN]: `TransitGatewayVpcAttachment`,
        [_xN]: _tGVA
      }]]
    ];
    exports2.CreateVerifiedAccessEndpointCidrOptions$ = [
      3,
      n032,
      _CVAECO,
      0,
      [_Pr10, _SI10, _Ci, _PRor],
      [0, [() => CreateVerifiedAccessEndpointSubnetIdList, { [_xN]: _SIu }], 0, [() => CreateVerifiedAccessEndpointPortRangeList, { [_xN]: _PRo }]]
    ];
    exports2.CreateVerifiedAccessEndpointEniOptions$ = [
      3,
      n032,
      _CVAEEO,
      0,
      [_NII, _Pr10, _Po, _PRor],
      [0, 0, 1, [() => CreateVerifiedAccessEndpointPortRangeList, { [_xN]: _PRo }]]
    ];
    exports2.CreateVerifiedAccessEndpointLoadBalancerOptions$ = [
      3,
      n032,
      _CVAELBO,
      0,
      [_Pr10, _Po, _LBAo, _SI10, _PRor],
      [0, 1, 0, [() => CreateVerifiedAccessEndpointSubnetIdList, { [_xN]: _SIu }], [() => CreateVerifiedAccessEndpointPortRangeList, { [_xN]: _PRo }]]
    ];
    exports2.CreateVerifiedAccessEndpointPortRange$ = [
      3,
      n032,
      _CVAEPR,
      0,
      [_FP, _TP],
      [1, 1]
    ];
    exports2.CreateVerifiedAccessEndpointRdsOptions$ = [
      3,
      n032,
      _CVAERO,
      0,
      [_Pr10, _Po, _RDIA, _RDCA, _RDPA, _RE, _SI10],
      [0, 1, 0, 0, 0, 0, [() => CreateVerifiedAccessEndpointSubnetIdList, { [_xN]: _SIu }]]
    ];
    exports2.CreateVerifiedAccessEndpointRequest$ = [
      3,
      n032,
      _CVAER,
      0,
      [_VAGI, _ETn, _ATt, _DCA, _ADp, _EDP, _SGIe, _LBO, _NIO, _De, _PDo, _TS, _CT4, _DR, _SSs, _ROd, _COi],
      [0, 0, 0, 0, 0, 0, [() => SecurityGroupIdList, { [_xN]: _SGI }], [() => exports2.CreateVerifiedAccessEndpointLoadBalancerOptions$, 0], [() => exports2.CreateVerifiedAccessEndpointEniOptions$, 0], 0, 0, [() => TagSpecificationList, { [_xN]: _TSa }], [0, 4], 2, () => exports2.VerifiedAccessSseSpecificationRequest$, [() => exports2.CreateVerifiedAccessEndpointRdsOptions$, 0], [() => exports2.CreateVerifiedAccessEndpointCidrOptions$, 0]],
      3
    ];
    exports2.CreateVerifiedAccessEndpointResult$ = [
      3,
      n032,
      _CVAERr,
      0,
      [_VAE],
      [[() => exports2.VerifiedAccessEndpoint$, {
        [_eQN]: `VerifiedAccessEndpoint`,
        [_xN]: _vAE
      }]]
    ];
    exports2.CreateVerifiedAccessGroupRequest$ = [
      3,
      n032,
      _CVAGR,
      0,
      [_VAII, _De, _PDo, _TS, _CT4, _DR, _SSs],
      [0, 0, 0, [() => TagSpecificationList, { [_xN]: _TSa }], [0, 4], 2, () => exports2.VerifiedAccessSseSpecificationRequest$],
      1
    ];
    exports2.CreateVerifiedAccessGroupResult$ = [
      3,
      n032,
      _CVAGRr,
      0,
      [_VAG],
      [[() => exports2.VerifiedAccessGroup$, {
        [_eQN]: `VerifiedAccessGroup`,
        [_xN]: _vAG
      }]]
    ];
    exports2.CreateVerifiedAccessInstanceRequest$ = [
      3,
      n032,
      _CVAIR,
      0,
      [_De, _TS, _CT4, _DR, _FIPSE, _CECSD],
      [0, [() => TagSpecificationList, { [_xN]: _TSa }], [0, 4], 2, 2, 0]
    ];
    exports2.CreateVerifiedAccessInstanceResult$ = [
      3,
      n032,
      _CVAIRr,
      0,
      [_VAI],
      [[() => exports2.VerifiedAccessInstance$, {
        [_eQN]: `VerifiedAccessInstance`,
        [_xN]: _vAI
      }]]
    ];
    exports2.CreateVerifiedAccessNativeApplicationOidcOptions$ = [
      3,
      n032,
      _CVANAOO,
      0,
      [_PSKE, _Is, _AE, _TEo, _UIE, _CIli, _CS4, _Sco],
      [0, 0, 0, 0, 0, 0, [() => ClientSecretType, 0], 0]
    ];
    exports2.CreateVerifiedAccessTrustProviderDeviceOptions$ = [
      3,
      n032,
      _CVATPDO,
      0,
      [_TIe, _PSKU],
      [0, 0]
    ];
    exports2.CreateVerifiedAccessTrustProviderOidcOptions$ = [
      3,
      n032,
      _CVATPOO,
      0,
      [_Is, _AE, _TEo, _UIE, _CIli, _CS4, _Sco],
      [0, 0, 0, 0, 0, [() => ClientSecretType, 0], 0]
    ];
    exports2.CreateVerifiedAccessTrustProviderRequest$ = [
      3,
      n032,
      _CVATPR,
      0,
      [_TPT, _PRNo, _UTPT, _DTPT, _OO, _DOev, _De, _TS, _CT4, _DR, _SSs, _NAOO],
      [0, 0, 0, 0, [() => exports2.CreateVerifiedAccessTrustProviderOidcOptions$, 0], () => exports2.CreateVerifiedAccessTrustProviderDeviceOptions$, 0, [() => TagSpecificationList, { [_xN]: _TSa }], [0, 4], 2, () => exports2.VerifiedAccessSseSpecificationRequest$, [() => exports2.CreateVerifiedAccessNativeApplicationOidcOptions$, 0]],
      2
    ];
    exports2.CreateVerifiedAccessTrustProviderResult$ = [
      3,
      n032,
      _CVATPRr,
      0,
      [_VATP],
      [[() => exports2.VerifiedAccessTrustProvider$, {
        [_eQN]: `VerifiedAccessTrustProvider`,
        [_xN]: _vATP
      }]]
    ];
    exports2.CreateVolumePermission$ = [
      3,
      n032,
      _CVP,
      0,
      [_UI, _Gr],
      [[0, {
        [_eQN]: `UserId`,
        [_xN]: _uI
      }], [0, {
        [_eQN]: `Group`,
        [_xN]: _g
      }]]
    ];
    exports2.CreateVolumePermissionModifications$ = [
      3,
      n032,
      _CVPM,
      0,
      [_Ad, _Rem],
      [[() => CreateVolumePermissionList, 0], [() => CreateVolumePermissionList, 0]]
    ];
    exports2.CreateVolumeRequest$ = [
      3,
      n032,
      _CVRr,
      0,
      [_AZ, _AZI, _Enc, _Io, _KKI, _OA, _Siz, _SIn, _VT, _TS, _MAE, _Th, _CT4, _VIR, _Op, _DR],
      [0, 0, [2, {
        [_eQN]: `Encrypted`,
        [_xN]: _enc
      }], 1, 0, 0, 1, 0, 0, [() => TagSpecificationList, { [_xN]: _TSa }], 2, 1, [0, 4], 1, () => exports2.OperatorRequest$, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]]
    ];
    exports2.CreateVpcBlockPublicAccessExclusionRequest$ = [
      3,
      n032,
      _CVBPAER,
      0,
      [_IGEM, _DR, _SIu, _VI, _TS],
      [0, 2, 0, 0, [() => TagSpecificationList, { [_xN]: _TSa }]],
      1
    ];
    exports2.CreateVpcBlockPublicAccessExclusionResult$ = [
      3,
      n032,
      _CVBPAERr,
      0,
      [_VBPAE],
      [[() => exports2.VpcBlockPublicAccessExclusion$, {
        [_eQN]: `VpcBlockPublicAccessExclusion`,
        [_xN]: _vBPAE
      }]]
    ];
    exports2.CreateVpcEncryptionControlRequest$ = [
      3,
      n032,
      _CVECR,
      0,
      [_VI, _DR, _TS],
      [0, 2, [() => TagSpecificationList, { [_xN]: _TSa }]],
      1
    ];
    exports2.CreateVpcEncryptionControlResult$ = [
      3,
      n032,
      _CVECRr,
      0,
      [_VEC],
      [[() => exports2.VpcEncryptionControl$, {
        [_eQN]: `VpcEncryptionControl`,
        [_xN]: _vEC
      }]]
    ];
    exports2.CreateVpcEndpointConnectionNotificationRequest$ = [
      3,
      n032,
      _CVECNR,
      0,
      [_CNAo, _CE, _DR, _SIe, _VEIp, _CT4],
      [0, [() => ValueStringList, 0], 2, 0, 0, 0],
      2
    ];
    exports2.CreateVpcEndpointConnectionNotificationResult$ = [
      3,
      n032,
      _CVECNRr,
      0,
      [_CNo, _CT4],
      [[() => exports2.ConnectionNotification$, {
        [_eQN]: `ConnectionNotification`,
        [_xN]: _cNo
      }], [0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }]]
    ];
    exports2.CreateVpcEndpointRequest$ = [
      3,
      n032,
      _CVER,
      0,
      [_VI, _DR, _VET, _SN10, _PDo, _RTIo, _SI10, _SGIe, _IAT, _DOn, _CT4, _PDE, _TS, _SC, _SNA, _RCA, _SR],
      [0, 2, 0, 0, 0, [() => VpcEndpointRouteTableIdList, { [_xN]: _RTI }], [() => VpcEndpointSubnetIdList, { [_xN]: _SIu }], [() => VpcEndpointSecurityGroupIdList, { [_xN]: _SGI }], 0, [() => exports2.DnsOptionsSpecification$, 0], 0, 2, [() => TagSpecificationList, { [_xN]: _TSa }], [() => SubnetConfigurationsList, { [_xN]: _SCu }], 0, 0, 0],
      1
    ];
    exports2.CreateVpcEndpointResult$ = [
      3,
      n032,
      _CVERr,
      0,
      [_VE10, _CT4],
      [[() => exports2.VpcEndpoint$, {
        [_eQN]: `VpcEndpoint`,
        [_xN]: _vE
      }], [0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }]]
    ];
    exports2.CreateVpcEndpointServiceConfigurationRequest$ = [
      3,
      n032,
      _CVESCR,
      0,
      [_DR, _ARc, _PDN, _NLBAe, _GLBA, _SIAT, _SRu, _CT4, _TS],
      [2, 2, 0, [() => ValueStringList, { [_xN]: _NLBA }], [() => ValueStringList, { [_xN]: _GLBAa }], [() => ValueStringList, { [_xN]: _SIATu }], [() => ValueStringList, { [_xN]: _SRup }], 0, [() => TagSpecificationList, { [_xN]: _TSa }]]
    ];
    exports2.CreateVpcEndpointServiceConfigurationResult$ = [
      3,
      n032,
      _CVESCRr,
      0,
      [_SCe, _CT4],
      [[() => exports2.ServiceConfiguration$, {
        [_eQN]: `ServiceConfiguration`,
        [_xN]: _sC
      }], [0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }]]
    ];
    exports2.CreateVpcPeeringConnectionRequest$ = [
      3,
      n032,
      _CVPCR,
      0,
      [_VI, _PRee, _TS, _DR, _PVI, _POI],
      [[0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], 0, [() => TagSpecificationList, { [_xN]: _TSa }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [0, {
        [_eQN]: `PeerVpcId`,
        [_xN]: _pVI
      }], [0, {
        [_eQN]: `PeerOwnerId`,
        [_xN]: _pOI
      }]],
      1
    ];
    exports2.CreateVpcPeeringConnectionResult$ = [
      3,
      n032,
      _CVPCRr,
      0,
      [_VPC],
      [[() => exports2.VpcPeeringConnection$, {
        [_eQN]: `VpcPeeringConnection`,
        [_xN]: _vPC
      }]]
    ];
    exports2.CreateVpcRequest$ = [
      3,
      n032,
      _CVRre,
      0,
      [_CB, _IPpvo, _ICB, _IIPIp, _INLp, _IIPI, _INL, _ICBNBG, _VEC, _TS, _DR, _ITns, _APICB],
      [0, 0, 0, 0, 1, 0, 1, 0, () => exports2.VpcEncryptionControlConfiguration$, [() => TagSpecificationList, { [_xN]: _TSa }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [0, {
        [_eQN]: `InstanceTenancy`,
        [_xN]: _iTns
      }], [2, {
        [_eQN]: `AmazonProvidedIpv6CidrBlock`,
        [_xN]: _aPICB
      }]]
    ];
    exports2.CreateVpcResult$ = [
      3,
      n032,
      _CVRrea,
      0,
      [_Vp],
      [[() => exports2.Vpc$, {
        [_eQN]: `Vpc`,
        [_xN]: _vp
      }]]
    ];
    exports2.CreateVpnConcentratorRequest$ = [
      3,
      n032,
      _CVCR,
      0,
      [_Ty, _TGI, _TS, _DR],
      [0, 0, [() => TagSpecificationList, { [_xN]: _TSa }], 2],
      1
    ];
    exports2.CreateVpnConcentratorResult$ = [
      3,
      n032,
      _CVCRr,
      0,
      [_VC],
      [[() => exports2.VpnConcentrator$, {
        [_eQN]: `VpnConcentrator`,
        [_xN]: _vC
      }]]
    ];
    exports2.CreateVpnConnectionRequest$ = [
      3,
      n032,
      _CVCRre,
      0,
      [_CGIu, _Ty, _VGI, _TGI, _VCI, _TS, _PSKS, _DR, _Opt],
      [0, 0, 0, 0, 0, [() => TagSpecificationList, { [_xN]: _TSa }], 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => exports2.VpnConnectionOptionsSpecification$, {
        [_eQN]: `Options`,
        [_xN]: _op
      }]],
      2
    ];
    exports2.CreateVpnConnectionResult$ = [
      3,
      n032,
      _CVCRrea,
      0,
      [_VCp],
      [[() => exports2.VpnConnection$, {
        [_eQN]: `VpnConnection`,
        [_xN]: _vCp
      }]]
    ];
    exports2.CreateVpnConnectionRouteRequest$ = [
      3,
      n032,
      _CVCRR,
      0,
      [_DCB, _VCIp],
      [0, 0],
      2
    ];
    exports2.CreateVpnGatewayRequest$ = [
      3,
      n032,
      _CVGR,
      0,
      [_Ty, _AZ, _TS, _ASA, _DR],
      [0, 0, [() => TagSpecificationList, { [_xN]: _TSa }], 1, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.CreateVpnGatewayResult$ = [
      3,
      n032,
      _CVGRr,
      0,
      [_VG],
      [[() => exports2.VpnGateway$, {
        [_eQN]: `VpnGateway`,
        [_xN]: _vG
      }]]
    ];
    exports2.CreationDateCondition$ = [
      3,
      n032,
      _CDC,
      0,
      [_MDSC],
      [[1, {
        [_eQN]: `MaximumDaysSinceCreated`,
        [_xN]: _mDSC
      }]]
    ];
    exports2.CreationDateConditionRequest$ = [
      3,
      n032,
      _CDCR,
      0,
      [_MDSC],
      [1]
    ];
    exports2.CreditSpecification$ = [
      3,
      n032,
      _CSr,
      0,
      [_CCp],
      [[0, {
        [_eQN]: `CpuCredits`,
        [_xN]: _cCp
      }]]
    ];
    exports2.CreditSpecificationRequest$ = [
      3,
      n032,
      _CSRred,
      0,
      [_CCp],
      [0],
      1
    ];
    exports2.CustomerGateway$ = [
      3,
      n032,
      _CGu,
      0,
      [_CAe, _DN, _T10, _BAE, _CGIu, _St, _Ty, _IAp, _BA],
      [[0, {
        [_eQN]: `CertificateArn`,
        [_xN]: _cAe
      }], [0, {
        [_eQN]: `DeviceName`,
        [_xN]: _dN
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `BgpAsnExtended`,
        [_xN]: _bAE
      }], [0, {
        [_eQN]: `CustomerGatewayId`,
        [_xN]: _cGIu
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `Type`,
        [_xN]: _ty
      }], [0, {
        [_eQN]: `IpAddress`,
        [_xN]: _iAp
      }], [0, {
        [_eQN]: `BgpAsn`,
        [_xN]: _bA
      }]]
    ];
    exports2.DataQuery$ = [
      3,
      n032,
      _DQ,
      0,
      [_I, _S, _D, _Met, _Stat, _Per],
      [0, 0, 0, 0, 0, 0]
    ];
    exports2.DataResponse$ = [
      3,
      n032,
      _DRa,
      0,
      [_I, _S, _D, _Met, _Stat, _Per, _MPe],
      [[0, {
        [_eQN]: `Id`,
        [_xN]: _i
      }], [0, {
        [_eQN]: `Source`,
        [_xN]: _so
      }], [0, {
        [_eQN]: `Destination`,
        [_xN]: _d
      }], [0, {
        [_eQN]: `Metric`,
        [_xN]: _met
      }], [0, {
        [_eQN]: `Statistic`,
        [_xN]: _stat
      }], [0, {
        [_eQN]: `Period`,
        [_xN]: _pe
      }], [() => MetricPoints, {
        [_eQN]: `MetricPointSet`,
        [_xN]: _mPS
      }]]
    ];
    exports2.DeclarativePoliciesReport$ = [
      3,
      n032,
      _DPRec,
      0,
      [_RI, _SB, _SP, _TIa, _ST11, _ETnd, _Sta, _T10],
      [[0, {
        [_eQN]: `ReportId`,
        [_xN]: _rIe
      }], [0, {
        [_eQN]: `S3Bucket`,
        [_xN]: _sB
      }], [0, {
        [_eQN]: `S3Prefix`,
        [_xN]: _sP
      }], [0, {
        [_eQN]: `TargetId`,
        [_xN]: _tIa
      }], [4, {
        [_eQN]: `StartTime`,
        [_xN]: _sT19
      }], [4, {
        [_eQN]: `EndTime`,
        [_xN]: _eTn
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.DefaultConnectionTrackingConfiguration$ = [
      3,
      n032,
      _DCTC,
      0,
      [_DTET, _DUT, _DUST],
      [[1, {
        [_eQN]: `DefaultTcpEstablishedTimeout`,
        [_xN]: _dTET
      }], [1, {
        [_eQN]: `DefaultUdpTimeout`,
        [_xN]: _dUT
      }], [1, {
        [_eQN]: `DefaultUdpStreamTimeout`,
        [_xN]: _dUST
      }]]
    ];
    exports2.DeleteCapacityManagerDataExportRequest$ = [
      3,
      n032,
      _DCMDER,
      0,
      [_CMDEI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteCapacityManagerDataExportResult$ = [
      3,
      n032,
      _DCMDERe,
      0,
      [_CMDEI],
      [[0, {
        [_eQN]: `CapacityManagerDataExportId`,
        [_xN]: _cMDEI
      }]]
    ];
    exports2.DeleteCarrierGatewayRequest$ = [
      3,
      n032,
      _DCGR,
      0,
      [_CGI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteCarrierGatewayResult$ = [
      3,
      n032,
      _DCGRe,
      0,
      [_CG],
      [[() => exports2.CarrierGateway$, {
        [_eQN]: `CarrierGateway`,
        [_xN]: _cG
      }]]
    ];
    exports2.DeleteClientVpnEndpointRequest$ = [
      3,
      n032,
      _DCVER,
      0,
      [_CVEI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteClientVpnEndpointResult$ = [
      3,
      n032,
      _DCVERe,
      0,
      [_Sta],
      [[() => exports2.ClientVpnEndpointStatus$, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }]]
    ];
    exports2.DeleteClientVpnRouteRequest$ = [
      3,
      n032,
      _DCVRR,
      0,
      [_CVEI, _DCB, _TVSI, _DR],
      [0, 0, 0, 2],
      2
    ];
    exports2.DeleteClientVpnRouteResult$ = [
      3,
      n032,
      _DCVRRe,
      0,
      [_Sta],
      [[() => exports2.ClientVpnRouteStatus$, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }]]
    ];
    exports2.DeleteCoipCidrRequest$ = [
      3,
      n032,
      _DCCR,
      0,
      [_Ci, _CPI, _DR],
      [0, 0, 2],
      2
    ];
    exports2.DeleteCoipCidrResult$ = [
      3,
      n032,
      _DCCRe,
      0,
      [_CCo],
      [[() => exports2.CoipCidr$, {
        [_eQN]: `CoipCidr`,
        [_xN]: _cCoi
      }]]
    ];
    exports2.DeleteCoipPoolRequest$ = [
      3,
      n032,
      _DCPR,
      0,
      [_CPI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteCoipPoolResult$ = [
      3,
      n032,
      _DCPRe,
      0,
      [_CP],
      [[() => exports2.CoipPool$, {
        [_eQN]: `CoipPool`,
        [_xN]: _cP
      }]]
    ];
    exports2.DeleteCustomerGatewayRequest$ = [
      3,
      n032,
      _DCGRel,
      0,
      [_CGIu, _DR],
      [0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.DeleteDhcpOptionsRequest$ = [
      3,
      n032,
      _DDOR,
      0,
      [_DOI, _DR],
      [0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.DeleteEgressOnlyInternetGatewayRequest$ = [
      3,
      n032,
      _DEOIGR,
      0,
      [_EOIGI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteEgressOnlyInternetGatewayResult$ = [
      3,
      n032,
      _DEOIGRe,
      0,
      [_RC10],
      [[2, {
        [_eQN]: `ReturnCode`,
        [_xN]: _rC10
      }]]
    ];
    exports2.DeleteFleetError$ = [
      3,
      n032,
      _DFE,
      0,
      [_Co, _Me],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }]]
    ];
    exports2.DeleteFleetErrorItem$ = [
      3,
      n032,
      _DFEI,
      0,
      [_Er, _FIl],
      [[() => exports2.DeleteFleetError$, {
        [_eQN]: `Error`,
        [_xN]: _er
      }], [0, {
        [_eQN]: `FleetId`,
        [_xN]: _fIl
      }]]
    ];
    exports2.DeleteFleetsRequest$ = [
      3,
      n032,
      _DFR,
      0,
      [_FIle, _TI, _DR],
      [[64 | 0, { [_xN]: _FIl }], 2, 2],
      2
    ];
    exports2.DeleteFleetsResult$ = [
      3,
      n032,
      _DFRe,
      0,
      [_SFD, _UFD],
      [[() => DeleteFleetSuccessSet, {
        [_eQN]: `SuccessfulFleetDeletionSet`,
        [_xN]: _sFDS
      }], [() => DeleteFleetErrorSet, {
        [_eQN]: `UnsuccessfulFleetDeletionSet`,
        [_xN]: _uFDS
      }]]
    ];
    exports2.DeleteFleetSuccessItem$ = [
      3,
      n032,
      _DFSI,
      0,
      [_CFS, _PFS, _FIl],
      [[0, {
        [_eQN]: `CurrentFleetState`,
        [_xN]: _cFS
      }], [0, {
        [_eQN]: `PreviousFleetState`,
        [_xN]: _pFS
      }], [0, {
        [_eQN]: `FleetId`,
        [_xN]: _fIl
      }]]
    ];
    exports2.DeleteFlowLogsRequest$ = [
      3,
      n032,
      _DFLR,
      0,
      [_FLI, _DR],
      [[() => FlowLogIdList, { [_xN]: _FLIl }], 2],
      1
    ];
    exports2.DeleteFlowLogsResult$ = [
      3,
      n032,
      _DFLRe,
      0,
      [_U],
      [[() => UnsuccessfulItemSet, {
        [_eQN]: `Unsuccessful`,
        [_xN]: _u
      }]]
    ];
    exports2.DeleteFpgaImageRequest$ = [
      3,
      n032,
      _DFIR,
      0,
      [_FII, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteFpgaImageResult$ = [
      3,
      n032,
      _DFIRe,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.DeleteImageUsageReportRequest$ = [
      3,
      n032,
      _DIURR,
      0,
      [_RI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteImageUsageReportResult$ = [
      3,
      n032,
      _DIURRe,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.DeleteInstanceConnectEndpointRequest$ = [
      3,
      n032,
      _DICER,
      0,
      [_ICEI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteInstanceConnectEndpointResult$ = [
      3,
      n032,
      _DICERe,
      0,
      [_ICE4],
      [[() => exports2.Ec2InstanceConnectEndpoint$, {
        [_eQN]: `InstanceConnectEndpoint`,
        [_xN]: _iCE
      }]]
    ];
    exports2.DeleteInstanceEventWindowRequest$ = [
      3,
      n032,
      _DIEWR,
      0,
      [_IEWI, _DR, _FD],
      [[0, { [_xN]: _IEWI }], 2, 2],
      1
    ];
    exports2.DeleteInstanceEventWindowResult$ = [
      3,
      n032,
      _DIEWRe,
      0,
      [_IEWS],
      [[() => exports2.InstanceEventWindowStateChange$, {
        [_eQN]: `InstanceEventWindowState`,
        [_xN]: _iEWS
      }]]
    ];
    exports2.DeleteInternetGatewayRequest$ = [
      3,
      n032,
      _DIGR,
      0,
      [_IGI, _DR],
      [[0, {
        [_eQN]: `InternetGatewayId`,
        [_xN]: _iGI
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.DeleteIpamExternalResourceVerificationTokenRequest$ = [
      3,
      n032,
      _DIERVTR,
      0,
      [_IERVTI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteIpamExternalResourceVerificationTokenResult$ = [
      3,
      n032,
      _DIERVTRe,
      0,
      [_IERVT],
      [[() => exports2.IpamExternalResourceVerificationToken$, {
        [_eQN]: `IpamExternalResourceVerificationToken`,
        [_xN]: _iERVT
      }]]
    ];
    exports2.DeleteIpamPolicyRequest$ = [
      3,
      n032,
      _DIPR,
      0,
      [_IPIp, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteIpamPolicyResult$ = [
      3,
      n032,
      _DIPRe,
      0,
      [_IPpa],
      [[() => exports2.IpamPolicy$, {
        [_eQN]: `IpamPolicy`,
        [_xN]: _iPpa
      }]]
    ];
    exports2.DeleteIpamPoolRequest$ = [
      3,
      n032,
      _DIPRel,
      0,
      [_IPI2, _DR, _Ca],
      [0, 2, 2],
      1
    ];
    exports2.DeleteIpamPoolResult$ = [
      3,
      n032,
      _DIPRele,
      0,
      [_IPpam],
      [[() => exports2.IpamPool$, {
        [_eQN]: `IpamPool`,
        [_xN]: _iPpam
      }]]
    ];
    exports2.DeleteIpamPrefixListResolverRequest$ = [
      3,
      n032,
      _DIPLRR,
      0,
      [_IPLRI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteIpamPrefixListResolverResult$ = [
      3,
      n032,
      _DIPLRRe,
      0,
      [_IPLR],
      [[() => exports2.IpamPrefixListResolver$, {
        [_eQN]: `IpamPrefixListResolver`,
        [_xN]: _iPLR
      }]]
    ];
    exports2.DeleteIpamPrefixListResolverTargetRequest$ = [
      3,
      n032,
      _DIPLRTR,
      0,
      [_IPLRTI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteIpamPrefixListResolverTargetResult$ = [
      3,
      n032,
      _DIPLRTRe,
      0,
      [_IPLRT],
      [[() => exports2.IpamPrefixListResolverTarget$, {
        [_eQN]: `IpamPrefixListResolverTarget`,
        [_xN]: _iPLRT
      }]]
    ];
    exports2.DeleteIpamRequest$ = [
      3,
      n032,
      _DIR,
      0,
      [_IIp, _DR, _Ca],
      [0, 2, 2],
      1
    ];
    exports2.DeleteIpamResourceDiscoveryRequest$ = [
      3,
      n032,
      _DIRDR,
      0,
      [_IRDI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteIpamResourceDiscoveryResult$ = [
      3,
      n032,
      _DIRDRe,
      0,
      [_IRD],
      [[() => exports2.IpamResourceDiscovery$, {
        [_eQN]: `IpamResourceDiscovery`,
        [_xN]: _iRD
      }]]
    ];
    exports2.DeleteIpamResult$ = [
      3,
      n032,
      _DIRe,
      0,
      [_Ip],
      [[() => exports2.Ipam$, {
        [_eQN]: `Ipam`,
        [_xN]: _ip
      }]]
    ];
    exports2.DeleteIpamScopeRequest$ = [
      3,
      n032,
      _DISR,
      0,
      [_ISI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteIpamScopeResult$ = [
      3,
      n032,
      _DISRe,
      0,
      [_ISp],
      [[() => exports2.IpamScope$, {
        [_eQN]: `IpamScope`,
        [_xN]: _iSp
      }]]
    ];
    exports2.DeleteKeyPairRequest$ = [
      3,
      n032,
      _DKPR,
      0,
      [_KN, _KPI, _DR],
      [0, 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]]
    ];
    exports2.DeleteKeyPairResult$ = [
      3,
      n032,
      _DKPRe,
      0,
      [_R, _KPI],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }], [0, {
        [_eQN]: `KeyPairId`,
        [_xN]: _kPI
      }]]
    ];
    exports2.DeleteLaunchTemplateRequest$ = [
      3,
      n032,
      _DLTR,
      0,
      [_DR, _LTI, _LTN],
      [2, 0, 0]
    ];
    exports2.DeleteLaunchTemplateResult$ = [
      3,
      n032,
      _DLTRe,
      0,
      [_LT],
      [[() => exports2.LaunchTemplate$, {
        [_eQN]: `LaunchTemplate`,
        [_xN]: _lT
      }]]
    ];
    exports2.DeleteLaunchTemplateVersionsRequest$ = [
      3,
      n032,
      _DLTVR,
      0,
      [_Ve, _DR, _LTI, _LTN],
      [[() => VersionStringList, { [_xN]: _LTV }], 2, 0, 0],
      1
    ];
    exports2.DeleteLaunchTemplateVersionsResponseErrorItem$ = [
      3,
      n032,
      _DLTVREI,
      0,
      [_LTI, _LTN, _VNe, _REe],
      [[0, {
        [_eQN]: `LaunchTemplateId`,
        [_xN]: _lTI
      }], [0, {
        [_eQN]: `LaunchTemplateName`,
        [_xN]: _lTN
      }], [1, {
        [_eQN]: `VersionNumber`,
        [_xN]: _vNe
      }], [() => exports2.ResponseError$, {
        [_eQN]: `ResponseError`,
        [_xN]: _rE
      }]]
    ];
    exports2.DeleteLaunchTemplateVersionsResponseSuccessItem$ = [
      3,
      n032,
      _DLTVRSI,
      0,
      [_LTI, _LTN, _VNe],
      [[0, {
        [_eQN]: `LaunchTemplateId`,
        [_xN]: _lTI
      }], [0, {
        [_eQN]: `LaunchTemplateName`,
        [_xN]: _lTN
      }], [1, {
        [_eQN]: `VersionNumber`,
        [_xN]: _vNe
      }]]
    ];
    exports2.DeleteLaunchTemplateVersionsResult$ = [
      3,
      n032,
      _DLTVRe,
      0,
      [_SDLTV, _UDLTV],
      [[() => DeleteLaunchTemplateVersionsResponseSuccessSet, {
        [_eQN]: `SuccessfullyDeletedLaunchTemplateVersionSet`,
        [_xN]: _sDLTVS
      }], [() => DeleteLaunchTemplateVersionsResponseErrorSet, {
        [_eQN]: `UnsuccessfullyDeletedLaunchTemplateVersionSet`,
        [_xN]: _uDLTVS
      }]]
    ];
    exports2.DeleteLocalGatewayRouteRequest$ = [
      3,
      n032,
      _DLGRR,
      0,
      [_LGRTI, _DCB, _DR, _DPLI],
      [0, 0, 2, 0],
      1
    ];
    exports2.DeleteLocalGatewayRouteResult$ = [
      3,
      n032,
      _DLGRRe,
      0,
      [_Ro],
      [[() => exports2.LocalGatewayRoute$, {
        [_eQN]: `Route`,
        [_xN]: _ro
      }]]
    ];
    exports2.DeleteLocalGatewayRouteTableRequest$ = [
      3,
      n032,
      _DLGRTR,
      0,
      [_LGRTI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteLocalGatewayRouteTableResult$ = [
      3,
      n032,
      _DLGRTRe,
      0,
      [_LGRT],
      [[() => exports2.LocalGatewayRouteTable$, {
        [_eQN]: `LocalGatewayRouteTable`,
        [_xN]: _lGRT
      }]]
    ];
    exports2.DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest$ = [
      3,
      n032,
      _DLGRTVIGAR,
      0,
      [_LGRTVIGAI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociationResult$ = [
      3,
      n032,
      _DLGRTVIGARe,
      0,
      [_LGRTVIGA],
      [[() => exports2.LocalGatewayRouteTableVirtualInterfaceGroupAssociation$, {
        [_eQN]: `LocalGatewayRouteTableVirtualInterfaceGroupAssociation`,
        [_xN]: _lGRTVIGA
      }]]
    ];
    exports2.DeleteLocalGatewayRouteTableVpcAssociationRequest$ = [
      3,
      n032,
      _DLGRTVAR,
      0,
      [_LGRTVAI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteLocalGatewayRouteTableVpcAssociationResult$ = [
      3,
      n032,
      _DLGRTVARe,
      0,
      [_LGRTVA],
      [[() => exports2.LocalGatewayRouteTableVpcAssociation$, {
        [_eQN]: `LocalGatewayRouteTableVpcAssociation`,
        [_xN]: _lGRTVA
      }]]
    ];
    exports2.DeleteLocalGatewayVirtualInterfaceGroupRequest$ = [
      3,
      n032,
      _DLGVIGR,
      0,
      [_LGVIGI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteLocalGatewayVirtualInterfaceGroupResult$ = [
      3,
      n032,
      _DLGVIGRe,
      0,
      [_LGVIG],
      [[() => exports2.LocalGatewayVirtualInterfaceGroup$, {
        [_eQN]: `LocalGatewayVirtualInterfaceGroup`,
        [_xN]: _lGVIG
      }]]
    ];
    exports2.DeleteLocalGatewayVirtualInterfaceRequest$ = [
      3,
      n032,
      _DLGVIR,
      0,
      [_LGVII, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteLocalGatewayVirtualInterfaceResult$ = [
      3,
      n032,
      _DLGVIRe,
      0,
      [_LGVI],
      [[() => exports2.LocalGatewayVirtualInterface$, {
        [_eQN]: `LocalGatewayVirtualInterface`,
        [_xN]: _lGVI
      }]]
    ];
    exports2.DeleteManagedPrefixListRequest$ = [
      3,
      n032,
      _DMPLR,
      0,
      [_PLI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteManagedPrefixListResult$ = [
      3,
      n032,
      _DMPLRe,
      0,
      [_PL],
      [[() => exports2.ManagedPrefixList$, {
        [_eQN]: `PrefixList`,
        [_xN]: _pL
      }]]
    ];
    exports2.DeleteNatGatewayRequest$ = [
      3,
      n032,
      _DNGR,
      0,
      [_NGI, _DR],
      [[0, { [_xN]: _NGI }], 2],
      1
    ];
    exports2.DeleteNatGatewayResult$ = [
      3,
      n032,
      _DNGRe,
      0,
      [_NGI],
      [[0, {
        [_eQN]: `NatGatewayId`,
        [_xN]: _nGI
      }]]
    ];
    exports2.DeleteNetworkAclEntryRequest$ = [
      3,
      n032,
      _DNAER,
      0,
      [_NAI, _RNu, _E11, _DR],
      [[0, {
        [_eQN]: `NetworkAclId`,
        [_xN]: _nAI
      }], [1, {
        [_eQN]: `RuleNumber`,
        [_xN]: _rN10
      }], [2, {
        [_eQN]: `Egress`,
        [_xN]: _e32
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      3
    ];
    exports2.DeleteNetworkAclRequest$ = [
      3,
      n032,
      _DNAR,
      0,
      [_NAI, _DR],
      [[0, {
        [_eQN]: `NetworkAclId`,
        [_xN]: _nAI
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.DeleteNetworkInsightsAccessScopeAnalysisRequest$ = [
      3,
      n032,
      _DNIASAR,
      0,
      [_NIASAI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteNetworkInsightsAccessScopeAnalysisResult$ = [
      3,
      n032,
      _DNIASARe,
      0,
      [_NIASAI],
      [[0, {
        [_eQN]: `NetworkInsightsAccessScopeAnalysisId`,
        [_xN]: _nIASAI
      }]]
    ];
    exports2.DeleteNetworkInsightsAccessScopeRequest$ = [
      3,
      n032,
      _DNIASR,
      0,
      [_NIASI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteNetworkInsightsAccessScopeResult$ = [
      3,
      n032,
      _DNIASRe,
      0,
      [_NIASI],
      [[0, {
        [_eQN]: `NetworkInsightsAccessScopeId`,
        [_xN]: _nIASI
      }]]
    ];
    exports2.DeleteNetworkInsightsAnalysisRequest$ = [
      3,
      n032,
      _DNIAR,
      0,
      [_NIAI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteNetworkInsightsAnalysisResult$ = [
      3,
      n032,
      _DNIARe,
      0,
      [_NIAI],
      [[0, {
        [_eQN]: `NetworkInsightsAnalysisId`,
        [_xN]: _nIAI
      }]]
    ];
    exports2.DeleteNetworkInsightsPathRequest$ = [
      3,
      n032,
      _DNIPR,
      0,
      [_NIPI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteNetworkInsightsPathResult$ = [
      3,
      n032,
      _DNIPRe,
      0,
      [_NIPI],
      [[0, {
        [_eQN]: `NetworkInsightsPathId`,
        [_xN]: _nIPI
      }]]
    ];
    exports2.DeleteNetworkInterfacePermissionRequest$ = [
      3,
      n032,
      _DNIPRel,
      0,
      [_NIPIe, _F, _DR],
      [0, 2, 2],
      1
    ];
    exports2.DeleteNetworkInterfacePermissionResult$ = [
      3,
      n032,
      _DNIPRele,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.DeleteNetworkInterfaceRequest$ = [
      3,
      n032,
      _DNIR,
      0,
      [_NII, _DR],
      [[0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.DeletePlacementGroupRequest$ = [
      3,
      n032,
      _DPGR,
      0,
      [_GN, _DR],
      [[0, {
        [_eQN]: `GroupName`,
        [_xN]: _gN
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.DeletePublicIpv4PoolRequest$ = [
      3,
      n032,
      _DPIPR,
      0,
      [_PIo, _DR, _NBG],
      [0, 2, 0],
      1
    ];
    exports2.DeletePublicIpv4PoolResult$ = [
      3,
      n032,
      _DPIPRe,
      0,
      [_RV],
      [[2, {
        [_eQN]: `ReturnValue`,
        [_xN]: _rV
      }]]
    ];
    exports2.DeleteQueuedReservedInstancesError$ = [
      3,
      n032,
      _DQRIE,
      0,
      [_Co, _Me],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }]]
    ];
    exports2.DeleteQueuedReservedInstancesRequest$ = [
      3,
      n032,
      _DQRIR,
      0,
      [_RIIese, _DR],
      [[() => DeleteQueuedReservedInstancesIdList, { [_xN]: _RIIes }], 2],
      1
    ];
    exports2.DeleteQueuedReservedInstancesResult$ = [
      3,
      n032,
      _DQRIRe,
      0,
      [_SQPD, _FQPD],
      [[() => SuccessfulQueuedPurchaseDeletionSet, {
        [_eQN]: `SuccessfulQueuedPurchaseDeletionSet`,
        [_xN]: _sQPDS
      }], [() => FailedQueuedPurchaseDeletionSet, {
        [_eQN]: `FailedQueuedPurchaseDeletionSet`,
        [_xN]: _fQPDS
      }]]
    ];
    exports2.DeleteRouteRequest$ = [
      3,
      n032,
      _DRR,
      0,
      [_RTI, _DPLI, _DR, _DCB, _DICB],
      [[0, {
        [_eQN]: `RouteTableId`,
        [_xN]: _rTI
      }], 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [0, {
        [_eQN]: `DestinationCidrBlock`,
        [_xN]: _dCB
      }], [0, {
        [_eQN]: `DestinationIpv6CidrBlock`,
        [_xN]: _dICB
      }]],
      1
    ];
    exports2.DeleteRouteServerEndpointRequest$ = [
      3,
      n032,
      _DRSER,
      0,
      [_RSEI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteRouteServerEndpointResult$ = [
      3,
      n032,
      _DRSERe,
      0,
      [_RSE],
      [[() => exports2.RouteServerEndpoint$, {
        [_eQN]: `RouteServerEndpoint`,
        [_xN]: _rSE
      }]]
    ];
    exports2.DeleteRouteServerPeerRequest$ = [
      3,
      n032,
      _DRSPR,
      0,
      [_RSPI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteRouteServerPeerResult$ = [
      3,
      n032,
      _DRSPRe,
      0,
      [_RSP],
      [[() => exports2.RouteServerPeer$, {
        [_eQN]: `RouteServerPeer`,
        [_xN]: _rSP
      }]]
    ];
    exports2.DeleteRouteServerRequest$ = [
      3,
      n032,
      _DRSR,
      0,
      [_RSI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteRouteServerResult$ = [
      3,
      n032,
      _DRSRe,
      0,
      [_RSo],
      [[() => exports2.RouteServer$, {
        [_eQN]: `RouteServer`,
        [_xN]: _rSo
      }]]
    ];
    exports2.DeleteRouteTableRequest$ = [
      3,
      n032,
      _DRTR,
      0,
      [_RTI, _DR],
      [[0, {
        [_eQN]: `RouteTableId`,
        [_xN]: _rTI
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.DeleteSecondaryNetworkRequest$ = [
      3,
      n032,
      _DSNR,
      0,
      [_SNI, _CT4, _DR],
      [0, [0, 4], 2],
      1
    ];
    exports2.DeleteSecondaryNetworkResult$ = [
      3,
      n032,
      _DSNRe,
      0,
      [_SNe, _CT4],
      [[() => exports2.SecondaryNetwork$, {
        [_eQN]: `SecondaryNetwork`,
        [_xN]: _sNe
      }], [0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }]]
    ];
    exports2.DeleteSecondarySubnetRequest$ = [
      3,
      n032,
      _DSSR,
      0,
      [_SSIe, _CT4, _DR],
      [0, [0, 4], 2],
      1
    ];
    exports2.DeleteSecondarySubnetResult$ = [
      3,
      n032,
      _DSSRe,
      0,
      [_SS, _CT4],
      [[() => exports2.SecondarySubnet$, {
        [_eQN]: `SecondarySubnet`,
        [_xN]: _sS
      }], [0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }]]
    ];
    exports2.DeleteSecurityGroupRequest$ = [
      3,
      n032,
      _DSGR,
      0,
      [_GIr, _GN, _DR],
      [0, 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]]
    ];
    exports2.DeleteSecurityGroupResult$ = [
      3,
      n032,
      _DSGRe,
      0,
      [_R, _GIr],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }], [0, {
        [_eQN]: `GroupId`,
        [_xN]: _gIr
      }]]
    ];
    exports2.DeleteSnapshotRequest$ = [
      3,
      n032,
      _DSR,
      0,
      [_SIn, _DR],
      [0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.DeleteSnapshotReturnCode$ = [
      3,
      n032,
      _DSRC,
      0,
      [_SIn, _RC10],
      [[0, {
        [_eQN]: `SnapshotId`,
        [_xN]: _sIn
      }], [0, {
        [_eQN]: `ReturnCode`,
        [_xN]: _rC10
      }]]
    ];
    exports2.DeleteSpotDatafeedSubscriptionRequest$ = [
      3,
      n032,
      _DSDSR,
      0,
      [_DR],
      [[2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]]
    ];
    exports2.DeleteSubnetCidrReservationRequest$ = [
      3,
      n032,
      _DSCRR,
      0,
      [_SCRIu, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteSubnetCidrReservationResult$ = [
      3,
      n032,
      _DSCRRe,
      0,
      [_DSCR],
      [[() => exports2.SubnetCidrReservation$, {
        [_eQN]: `DeletedSubnetCidrReservation`,
        [_xN]: _dSCR
      }]]
    ];
    exports2.DeleteSubnetRequest$ = [
      3,
      n032,
      _DSRe,
      0,
      [_SIu, _DR],
      [0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.DeleteTagsRequest$ = [
      3,
      n032,
      _DTR,
      0,
      [_Res, _DR, _T10],
      [[64 | 0, {
        [_eQN]: `ResourceId`,
        [_xN]: _rIes
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => TagList, {
        [_eQN]: `Tag`,
        [_xN]: _ta
      }]],
      1
    ];
    exports2.DeleteTrafficMirrorFilterRequest$ = [
      3,
      n032,
      _DTMFR,
      0,
      [_TMFI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteTrafficMirrorFilterResult$ = [
      3,
      n032,
      _DTMFRe,
      0,
      [_TMFI],
      [[0, {
        [_eQN]: `TrafficMirrorFilterId`,
        [_xN]: _tMFI
      }]]
    ];
    exports2.DeleteTrafficMirrorFilterRuleRequest$ = [
      3,
      n032,
      _DTMFRR,
      0,
      [_TMFRI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteTrafficMirrorFilterRuleResult$ = [
      3,
      n032,
      _DTMFRRe,
      0,
      [_TMFRI],
      [[0, {
        [_eQN]: `TrafficMirrorFilterRuleId`,
        [_xN]: _tMFRI
      }]]
    ];
    exports2.DeleteTrafficMirrorSessionRequest$ = [
      3,
      n032,
      _DTMSR,
      0,
      [_TMSI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteTrafficMirrorSessionResult$ = [
      3,
      n032,
      _DTMSRe,
      0,
      [_TMSI],
      [[0, {
        [_eQN]: `TrafficMirrorSessionId`,
        [_xN]: _tMSI
      }]]
    ];
    exports2.DeleteTrafficMirrorTargetRequest$ = [
      3,
      n032,
      _DTMTR,
      0,
      [_TMTI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteTrafficMirrorTargetResult$ = [
      3,
      n032,
      _DTMTRe,
      0,
      [_TMTI],
      [[0, {
        [_eQN]: `TrafficMirrorTargetId`,
        [_xN]: _tMTI
      }]]
    ];
    exports2.DeleteTransitGatewayClientVpnAttachmentRequest$ = [
      3,
      n032,
      _DTGCVAR,
      0,
      [_TGAI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteTransitGatewayClientVpnAttachmentResult$ = [
      3,
      n032,
      _DTGCVARe,
      0,
      [_TGCVA],
      [[() => exports2.TransitGatewayClientVpnAttachment$, {
        [_eQN]: `TransitGatewayClientVpnAttachment`,
        [_xN]: _tGCVA
      }]]
    ];
    exports2.DeleteTransitGatewayConnectPeerRequest$ = [
      3,
      n032,
      _DTGCPR,
      0,
      [_TGCPI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteTransitGatewayConnectPeerResult$ = [
      3,
      n032,
      _DTGCPRe,
      0,
      [_TGCP],
      [[() => exports2.TransitGatewayConnectPeer$, {
        [_eQN]: `TransitGatewayConnectPeer`,
        [_xN]: _tGCP
      }]]
    ];
    exports2.DeleteTransitGatewayConnectRequest$ = [
      3,
      n032,
      _DTGCR,
      0,
      [_TGAI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteTransitGatewayConnectResult$ = [
      3,
      n032,
      _DTGCRe,
      0,
      [_TGCr],
      [[() => exports2.TransitGatewayConnect$, {
        [_eQN]: `TransitGatewayConnect`,
        [_xN]: _tGCr
      }]]
    ];
    exports2.DeleteTransitGatewayMeteringPolicyEntryRequest$ = [
      3,
      n032,
      _DTGMPER,
      0,
      [_TGMPI, _PRN, _DR],
      [0, 1, 2],
      2
    ];
    exports2.DeleteTransitGatewayMeteringPolicyEntryResult$ = [
      3,
      n032,
      _DTGMPERe,
      0,
      [_TGMPE],
      [[() => exports2.TransitGatewayMeteringPolicyEntry$, {
        [_eQN]: `TransitGatewayMeteringPolicyEntry`,
        [_xN]: _tGMPE
      }]]
    ];
    exports2.DeleteTransitGatewayMeteringPolicyRequest$ = [
      3,
      n032,
      _DTGMPR,
      0,
      [_TGMPI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteTransitGatewayMeteringPolicyResult$ = [
      3,
      n032,
      _DTGMPRe,
      0,
      [_TGMP],
      [[() => exports2.TransitGatewayMeteringPolicy$, {
        [_eQN]: `TransitGatewayMeteringPolicy`,
        [_xN]: _tGMP
      }]]
    ];
    exports2.DeleteTransitGatewayMulticastDomainRequest$ = [
      3,
      n032,
      _DTGMDR,
      0,
      [_TGMDI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteTransitGatewayMulticastDomainResult$ = [
      3,
      n032,
      _DTGMDRe,
      0,
      [_TGMD],
      [[() => exports2.TransitGatewayMulticastDomain$, {
        [_eQN]: `TransitGatewayMulticastDomain`,
        [_xN]: _tGMD
      }]]
    ];
    exports2.DeleteTransitGatewayPeeringAttachmentRequest$ = [
      3,
      n032,
      _DTGPAR,
      0,
      [_TGAI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteTransitGatewayPeeringAttachmentResult$ = [
      3,
      n032,
      _DTGPARe,
      0,
      [_TGPA],
      [[() => exports2.TransitGatewayPeeringAttachment$, {
        [_eQN]: `TransitGatewayPeeringAttachment`,
        [_xN]: _tGPA
      }]]
    ];
    exports2.DeleteTransitGatewayPolicyTableRequest$ = [
      3,
      n032,
      _DTGPTR,
      0,
      [_TGPTI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteTransitGatewayPolicyTableResult$ = [
      3,
      n032,
      _DTGPTRe,
      0,
      [_TGPT],
      [[() => exports2.TransitGatewayPolicyTable$, {
        [_eQN]: `TransitGatewayPolicyTable`,
        [_xN]: _tGPT
      }]]
    ];
    exports2.DeleteTransitGatewayPrefixListReferenceRequest$ = [
      3,
      n032,
      _DTGPLRR,
      0,
      [_TGRTI, _PLI, _DR],
      [0, 0, 2],
      2
    ];
    exports2.DeleteTransitGatewayPrefixListReferenceResult$ = [
      3,
      n032,
      _DTGPLRRe,
      0,
      [_TGPLR],
      [[() => exports2.TransitGatewayPrefixListReference$, {
        [_eQN]: `TransitGatewayPrefixListReference`,
        [_xN]: _tGPLR
      }]]
    ];
    exports2.DeleteTransitGatewayRequest$ = [
      3,
      n032,
      _DTGR,
      0,
      [_TGI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteTransitGatewayResult$ = [
      3,
      n032,
      _DTGRe,
      0,
      [_TG],
      [[() => exports2.TransitGateway$, {
        [_eQN]: `TransitGateway`,
        [_xN]: _tG
      }]]
    ];
    exports2.DeleteTransitGatewayRouteRequest$ = [
      3,
      n032,
      _DTGRR,
      0,
      [_TGRTI, _DCB, _DR],
      [0, 0, 2],
      2
    ];
    exports2.DeleteTransitGatewayRouteResult$ = [
      3,
      n032,
      _DTGRRe,
      0,
      [_Ro],
      [[() => exports2.TransitGatewayRoute$, {
        [_eQN]: `Route`,
        [_xN]: _ro
      }]]
    ];
    exports2.DeleteTransitGatewayRouteTableAnnouncementRequest$ = [
      3,
      n032,
      _DTGRTAR,
      0,
      [_TGRTAI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteTransitGatewayRouteTableAnnouncementResult$ = [
      3,
      n032,
      _DTGRTARe,
      0,
      [_TGRTA],
      [[() => exports2.TransitGatewayRouteTableAnnouncement$, {
        [_eQN]: `TransitGatewayRouteTableAnnouncement`,
        [_xN]: _tGRTA
      }]]
    ];
    exports2.DeleteTransitGatewayRouteTableRequest$ = [
      3,
      n032,
      _DTGRTR,
      0,
      [_TGRTI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteTransitGatewayRouteTableResult$ = [
      3,
      n032,
      _DTGRTRe,
      0,
      [_TGRT],
      [[() => exports2.TransitGatewayRouteTable$, {
        [_eQN]: `TransitGatewayRouteTable`,
        [_xN]: _tGRT
      }]]
    ];
    exports2.DeleteTransitGatewayVpcAttachmentRequest$ = [
      3,
      n032,
      _DTGVAR,
      0,
      [_TGAI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteTransitGatewayVpcAttachmentResult$ = [
      3,
      n032,
      _DTGVARe,
      0,
      [_TGVA],
      [[() => exports2.TransitGatewayVpcAttachment$, {
        [_eQN]: `TransitGatewayVpcAttachment`,
        [_xN]: _tGVA
      }]]
    ];
    exports2.DeleteVerifiedAccessEndpointRequest$ = [
      3,
      n032,
      _DVAER,
      0,
      [_VAEI, _CT4, _DR],
      [0, [0, 4], 2],
      1
    ];
    exports2.DeleteVerifiedAccessEndpointResult$ = [
      3,
      n032,
      _DVAERe,
      0,
      [_VAE],
      [[() => exports2.VerifiedAccessEndpoint$, {
        [_eQN]: `VerifiedAccessEndpoint`,
        [_xN]: _vAE
      }]]
    ];
    exports2.DeleteVerifiedAccessGroupRequest$ = [
      3,
      n032,
      _DVAGR,
      0,
      [_VAGI, _CT4, _DR],
      [0, [0, 4], 2],
      1
    ];
    exports2.DeleteVerifiedAccessGroupResult$ = [
      3,
      n032,
      _DVAGRe,
      0,
      [_VAG],
      [[() => exports2.VerifiedAccessGroup$, {
        [_eQN]: `VerifiedAccessGroup`,
        [_xN]: _vAG
      }]]
    ];
    exports2.DeleteVerifiedAccessInstanceRequest$ = [
      3,
      n032,
      _DVAIR,
      0,
      [_VAII, _DR, _CT4],
      [0, 2, [0, 4]],
      1
    ];
    exports2.DeleteVerifiedAccessInstanceResult$ = [
      3,
      n032,
      _DVAIRe,
      0,
      [_VAI],
      [[() => exports2.VerifiedAccessInstance$, {
        [_eQN]: `VerifiedAccessInstance`,
        [_xN]: _vAI
      }]]
    ];
    exports2.DeleteVerifiedAccessTrustProviderRequest$ = [
      3,
      n032,
      _DVATPR,
      0,
      [_VATPI, _DR, _CT4],
      [0, 2, [0, 4]],
      1
    ];
    exports2.DeleteVerifiedAccessTrustProviderResult$ = [
      3,
      n032,
      _DVATPRe,
      0,
      [_VATP],
      [[() => exports2.VerifiedAccessTrustProvider$, {
        [_eQN]: `VerifiedAccessTrustProvider`,
        [_xN]: _vATP
      }]]
    ];
    exports2.DeleteVolumeRequest$ = [
      3,
      n032,
      _DVR,
      0,
      [_VIo, _DR],
      [0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.DeleteVpcBlockPublicAccessExclusionRequest$ = [
      3,
      n032,
      _DVBPAER,
      0,
      [_EIx, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteVpcBlockPublicAccessExclusionResult$ = [
      3,
      n032,
      _DVBPAERe,
      0,
      [_VBPAE],
      [[() => exports2.VpcBlockPublicAccessExclusion$, {
        [_eQN]: `VpcBlockPublicAccessExclusion`,
        [_xN]: _vBPAE
      }]]
    ];
    exports2.DeleteVpcEncryptionControlRequest$ = [
      3,
      n032,
      _DVECR,
      0,
      [_VECI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteVpcEncryptionControlResult$ = [
      3,
      n032,
      _DVECRe,
      0,
      [_VEC],
      [[() => exports2.VpcEncryptionControl$, {
        [_eQN]: `VpcEncryptionControl`,
        [_xN]: _vEC
      }]]
    ];
    exports2.DeleteVpcEndpointConnectionNotificationsRequest$ = [
      3,
      n032,
      _DVECNR,
      0,
      [_CNIo, _DR],
      [[() => ConnectionNotificationIdsList, { [_xN]: _CNI }], 2],
      1
    ];
    exports2.DeleteVpcEndpointConnectionNotificationsResult$ = [
      3,
      n032,
      _DVECNRe,
      0,
      [_U],
      [[() => UnsuccessfulItemSet, {
        [_eQN]: `Unsuccessful`,
        [_xN]: _u
      }]]
    ];
    exports2.DeleteVpcEndpointServiceConfigurationsRequest$ = [
      3,
      n032,
      _DVESCR,
      0,
      [_SIer, _DR],
      [[() => VpcEndpointServiceIdList, { [_xN]: _SIe }], 2],
      1
    ];
    exports2.DeleteVpcEndpointServiceConfigurationsResult$ = [
      3,
      n032,
      _DVESCRe,
      0,
      [_U],
      [[() => UnsuccessfulItemSet, {
        [_eQN]: `Unsuccessful`,
        [_xN]: _u
      }]]
    ];
    exports2.DeleteVpcEndpointsRequest$ = [
      3,
      n032,
      _DVER,
      0,
      [_VEI, _DR],
      [[() => VpcEndpointIdList, { [_xN]: _VEIp }], 2],
      1
    ];
    exports2.DeleteVpcEndpointsResult$ = [
      3,
      n032,
      _DVERe,
      0,
      [_U],
      [[() => UnsuccessfulItemSet, {
        [_eQN]: `Unsuccessful`,
        [_xN]: _u
      }]]
    ];
    exports2.DeleteVpcPeeringConnectionRequest$ = [
      3,
      n032,
      _DVPCR,
      0,
      [_VPCI, _DR],
      [[0, {
        [_eQN]: `VpcPeeringConnectionId`,
        [_xN]: _vPCI
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.DeleteVpcPeeringConnectionResult$ = [
      3,
      n032,
      _DVPCRe,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.DeleteVpcRequest$ = [
      3,
      n032,
      _DVRe,
      0,
      [_VI, _DR],
      [0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.DeleteVpnConcentratorRequest$ = [
      3,
      n032,
      _DVCR,
      0,
      [_VCI, _DR],
      [0, 2],
      1
    ];
    exports2.DeleteVpnConcentratorResult$ = [
      3,
      n032,
      _DVCRe,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.DeleteVpnConnectionRequest$ = [
      3,
      n032,
      _DVCRel,
      0,
      [_VCIp, _DR],
      [0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.DeleteVpnConnectionRouteRequest$ = [
      3,
      n032,
      _DVCRR,
      0,
      [_DCB, _VCIp],
      [0, 0],
      2
    ];
    exports2.DeleteVpnGatewayRequest$ = [
      3,
      n032,
      _DVGR,
      0,
      [_VGI, _DR],
      [0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.DeprecationTimeCondition$ = [
      3,
      n032,
      _DTC,
      0,
      [_MDSD],
      [[1, {
        [_eQN]: `MaximumDaysSinceDeprecated`,
        [_xN]: _mDSD
      }]]
    ];
    exports2.DeprecationTimeConditionRequest$ = [
      3,
      n032,
      _DTCR,
      0,
      [_MDSD],
      [1]
    ];
    exports2.DeprovisionByoipCidrRequest$ = [
      3,
      n032,
      _DBCR,
      0,
      [_Ci, _DR],
      [0, 2],
      1
    ];
    exports2.DeprovisionByoipCidrResult$ = [
      3,
      n032,
      _DBCRe,
      0,
      [_BC],
      [[() => exports2.ByoipCidr$, {
        [_eQN]: `ByoipCidr`,
        [_xN]: _bC
      }]]
    ];
    exports2.DeprovisionIpamByoasnRequest$ = [
      3,
      n032,
      _DIBR,
      0,
      [_IIp, _Asn, _DR],
      [0, 0, 2],
      2
    ];
    exports2.DeprovisionIpamByoasnResult$ = [
      3,
      n032,
      _DIBRe,
      0,
      [_B],
      [[() => exports2.Byoasn$, {
        [_eQN]: `Byoasn`,
        [_xN]: _by
      }]]
    ];
    exports2.DeprovisionIpamPoolCidrRequest$ = [
      3,
      n032,
      _DIPCR,
      0,
      [_IPI2, _DR, _Ci],
      [0, 2, 0],
      1
    ];
    exports2.DeprovisionIpamPoolCidrResult$ = [
      3,
      n032,
      _DIPCRe,
      0,
      [_IPCpa],
      [[() => exports2.IpamPoolCidr$, {
        [_eQN]: `IpamPoolCidr`,
        [_xN]: _iPC
      }]]
    ];
    exports2.DeprovisionPublicIpv4PoolCidrRequest$ = [
      3,
      n032,
      _DPIPCR,
      0,
      [_PIo, _Ci, _DR],
      [0, 0, 2],
      2
    ];
    exports2.DeprovisionPublicIpv4PoolCidrResult$ = [
      3,
      n032,
      _DPIPCRe,
      0,
      [_PIo, _DAe],
      [[0, {
        [_eQN]: `PoolId`,
        [_xN]: _pIo
      }], [() => DeprovisionedAddressSet, {
        [_eQN]: `DeprovisionedAddressSet`,
        [_xN]: _dASe
      }]]
    ];
    exports2.DeregisterImageRequest$ = [
      3,
      n032,
      _DIRer,
      0,
      [_IIm, _DAS, _DR],
      [0, 2, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.DeregisterImageResult$ = [
      3,
      n032,
      _DIRere,
      0,
      [_R, _DSRel],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }], [() => DeleteSnapshotResultSet, {
        [_eQN]: `DeleteSnapshotResultSet`,
        [_xN]: _dSRS
      }]]
    ];
    exports2.DeregisterInstanceEventNotificationAttributesRequest$ = [
      3,
      n032,
      _DIENAR,
      0,
      [_ITA, _DR],
      [[() => exports2.DeregisterInstanceTagAttributeRequest$, 0], 2],
      1
    ];
    exports2.DeregisterInstanceEventNotificationAttributesResult$ = [
      3,
      n032,
      _DIENARe,
      0,
      [_ITA],
      [[() => exports2.InstanceTagNotificationAttribute$, {
        [_eQN]: `InstanceTagAttribute`,
        [_xN]: _iTA
      }]]
    ];
    exports2.DeregisterInstanceTagAttributeRequest$ = [
      3,
      n032,
      _DITAR,
      0,
      [_IATOI, _ITK],
      [2, [() => InstanceTagKeySet, { [_xN]: _ITKn }]]
    ];
    exports2.DeregisterTransitGatewayMulticastGroupMembersRequest$ = [
      3,
      n032,
      _DTGMGMR,
      0,
      [_TGMDI, _GIA, _NIIe, _DR],
      [0, 0, [() => TransitGatewayNetworkInterfaceIdList, 0], 2]
    ];
    exports2.DeregisterTransitGatewayMulticastGroupMembersResult$ = [
      3,
      n032,
      _DTGMGMRe,
      0,
      [_DMGM],
      [[() => exports2.TransitGatewayMulticastDeregisteredGroupMembers$, {
        [_eQN]: `DeregisteredMulticastGroupMembers`,
        [_xN]: _dMGM
      }]]
    ];
    exports2.DeregisterTransitGatewayMulticastGroupSourcesRequest$ = [
      3,
      n032,
      _DTGMGSR,
      0,
      [_TGMDI, _GIA, _NIIe, _DR],
      [0, 0, [() => TransitGatewayNetworkInterfaceIdList, 0], 2]
    ];
    exports2.DeregisterTransitGatewayMulticastGroupSourcesResult$ = [
      3,
      n032,
      _DTGMGSRe,
      0,
      [_DMGS],
      [[() => exports2.TransitGatewayMulticastDeregisteredGroupSources$, {
        [_eQN]: `DeregisteredMulticastGroupSources`,
        [_xN]: _dMGS
      }]]
    ];
    exports2.DescribeAccountAttributesRequest$ = [
      3,
      n032,
      _DAAR,
      0,
      [_DR, _ANt],
      [[2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => AccountAttributeNameStringList, {
        [_eQN]: `AttributeName`,
        [_xN]: _aN
      }]]
    ];
    exports2.DescribeAccountAttributesResult$ = [
      3,
      n032,
      _DAARe,
      0,
      [_AAcc],
      [[() => AccountAttributeList, {
        [_eQN]: `AccountAttributeSet`,
        [_xN]: _aASc
      }]]
    ];
    exports2.DescribeAddressesAttributeRequest$ = [
      3,
      n032,
      _DAARes,
      0,
      [_AIll, _At, _NTe, _MR, _DR],
      [[() => AllocationIds, { [_xN]: _AIl }], 0, 0, 1, 2]
    ];
    exports2.DescribeAddressesAttributeResult$ = [
      3,
      n032,
      _DAAResc,
      0,
      [_Add, _NTe],
      [[() => AddressSet, {
        [_eQN]: `AddressSet`,
        [_xN]: _aSd
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeAddressesRequest$ = [
      3,
      n032,
      _DAR,
      0,
      [_PIu, _DR, _Fi, _AIll],
      [[() => PublicIpStringList, { [_xN]: _PI10 }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => FilterList, { [_xN]: _Fil }], [() => AllocationIdList, { [_xN]: _AIl }]]
    ];
    exports2.DescribeAddressesResult$ = [
      3,
      n032,
      _DARe,
      0,
      [_Add],
      [[() => AddressList, {
        [_eQN]: `AddressesSet`,
        [_xN]: _aSdd
      }]]
    ];
    exports2.DescribeAddressTransfersRequest$ = [
      3,
      n032,
      _DATR,
      0,
      [_AIll, _NTe, _MR, _DR],
      [[() => AllocationIdList, { [_xN]: _AIl }], 0, 1, 2]
    ];
    exports2.DescribeAddressTransfersResult$ = [
      3,
      n032,
      _DATRe,
      0,
      [_ATdd, _NTe],
      [[() => AddressTransferList, {
        [_eQN]: `AddressTransferSet`,
        [_xN]: _aTSd
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeAggregateIdFormatRequest$ = [
      3,
      n032,
      _DAIFR,
      0,
      [_DR],
      [2]
    ];
    exports2.DescribeAggregateIdFormatResult$ = [
      3,
      n032,
      _DAIFRe,
      0,
      [_ULIA, _Statu],
      [[2, {
        [_eQN]: `UseLongIdsAggregated`,
        [_xN]: _uLIA
      }], [() => IdFormatList, {
        [_eQN]: `StatusSet`,
        [_xN]: _sSt
      }]]
    ];
    exports2.DescribeAvailabilityZonesRequest$ = [
      3,
      n032,
      _DAZR,
      0,
      [_ZNo, _ZIo, _AAZ, _DR, _Fi],
      [[() => ZoneNameStringList, { [_xN]: _ZN }], [() => ZoneIdStringList, { [_xN]: _ZI }], 2, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => FilterList, { [_xN]: _Fil }]]
    ];
    exports2.DescribeAvailabilityZonesResult$ = [
      3,
      n032,
      _DAZRe,
      0,
      [_AZv],
      [[() => AvailabilityZoneList, {
        [_eQN]: `AvailabilityZoneInfo`,
        [_xN]: _aZIv
      }]]
    ];
    exports2.DescribeAwsNetworkPerformanceMetricSubscriptionsRequest$ = [
      3,
      n032,
      _DANPMSR,
      0,
      [_MR, _NTe, _Fi, _DR],
      [1, 0, [() => FilterList, { [_xN]: _Fil }], 2]
    ];
    exports2.DescribeAwsNetworkPerformanceMetricSubscriptionsResult$ = [
      3,
      n032,
      _DANPMSRe,
      0,
      [_NTe, _Sub],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => SubscriptionList, {
        [_eQN]: `SubscriptionSet`,
        [_xN]: _sSu
      }]]
    ];
    exports2.DescribeBundleTasksRequest$ = [
      3,
      n032,
      _DBTR,
      0,
      [_BIu, _DR, _Fi],
      [[() => BundleIdStringList, { [_xN]: _BI }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => FilterList, { [_xN]: _Fil }]]
    ];
    exports2.DescribeBundleTasksResult$ = [
      3,
      n032,
      _DBTRe,
      0,
      [_BTu],
      [[() => BundleTaskList, {
        [_eQN]: `BundleInstanceTasksSet`,
        [_xN]: _bITS
      }]]
    ];
    exports2.DescribeByoipCidrsRequest$ = [
      3,
      n032,
      _DBCRes,
      0,
      [_MR, _DR, _NTe],
      [1, 2, 0],
      1
    ];
    exports2.DescribeByoipCidrsResult$ = [
      3,
      n032,
      _DBCResc,
      0,
      [_BCy, _NTe],
      [[() => ByoipCidrSet, {
        [_eQN]: `ByoipCidrSet`,
        [_xN]: _bCS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeCapacityBlockExtensionHistoryRequest$ = [
      3,
      n032,
      _DCBEHR,
      0,
      [_CRIa, _NTe, _MR, _Fi, _DR],
      [[() => CapacityReservationIdSet, { [_xN]: _CRI }], 0, 1, [() => FilterList, { [_xN]: _Fil }], 2]
    ];
    exports2.DescribeCapacityBlockExtensionHistoryResult$ = [
      3,
      n032,
      _DCBEHRe,
      0,
      [_CBEa, _NTe],
      [[() => CapacityBlockExtensionSet, {
        [_eQN]: `CapacityBlockExtensionSet`,
        [_xN]: _cBESa
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeCapacityBlockExtensionOfferingsRequest$ = [
      3,
      n032,
      _DCBEOR,
      0,
      [_CBEDH, _CRI, _DR, _NTe, _MR],
      [1, 0, 2, 0, 1],
      2
    ];
    exports2.DescribeCapacityBlockExtensionOfferingsResult$ = [
      3,
      n032,
      _DCBEORe,
      0,
      [_CBEOa, _NTe],
      [[() => CapacityBlockExtensionOfferingSet, {
        [_eQN]: `CapacityBlockExtensionOfferingSet`,
        [_xN]: _cBEOS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeCapacityBlockOfferingsRequest$ = [
      3,
      n032,
      _DCBOR,
      0,
      [_CDH, _DR, _IT4, _IC, _SDR, _EDR, _NTe, _MR, _UTl, _UC, _AAZ],
      [1, 2, 0, 1, 4, 4, 0, 1, 0, 1, 2],
      1
    ];
    exports2.DescribeCapacityBlockOfferingsResult$ = [
      3,
      n032,
      _DCBORe,
      0,
      [_CBOa, _NTe],
      [[() => CapacityBlockOfferingSet, {
        [_eQN]: `CapacityBlockOfferingSet`,
        [_xN]: _cBOS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeCapacityBlocksRequest$ = [
      3,
      n032,
      _DCBR,
      0,
      [_CBIa, _NTe, _MR, _Fi, _DR],
      [[() => CapacityBlockIds, { [_xN]: _CBI }], 0, 1, [() => FilterList, { [_xN]: _Fil }], 2]
    ];
    exports2.DescribeCapacityBlocksResult$ = [
      3,
      n032,
      _DCBRe,
      0,
      [_CBap, _NTe],
      [[() => CapacityBlockSet, {
        [_eQN]: `CapacityBlockSet`,
        [_xN]: _cBS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeCapacityBlockStatusRequest$ = [
      3,
      n032,
      _DCBSR,
      0,
      [_CBIa, _NTe, _MR, _Fi, _DR],
      [[() => CapacityBlockIds, { [_xN]: _CBI }], 0, 1, [() => FilterList, { [_xN]: _Fil }], 2]
    ];
    exports2.DescribeCapacityBlockStatusResult$ = [
      3,
      n032,
      _DCBSRe,
      0,
      [_CBSa, _NTe],
      [[() => CapacityBlockStatusSet, {
        [_eQN]: `CapacityBlockStatusSet`,
        [_xN]: _cBSS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeCapacityManagerDataExportsRequest$ = [
      3,
      n032,
      _DCMDERes,
      0,
      [_CMDEIa, _MR, _NTe, _DR, _Fi],
      [[() => CapacityManagerDataExportIdSet, { [_xN]: _CMDEI }], 1, 0, 2, [() => FilterList, { [_xN]: _Fil }]]
    ];
    exports2.DescribeCapacityManagerDataExportsResult$ = [
      3,
      n032,
      _DCMDEResc,
      0,
      [_CMDE, _NTe],
      [[() => CapacityManagerDataExportResponseSet, {
        [_eQN]: `CapacityManagerDataExportSet`,
        [_xN]: _cMDES
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeCapacityReservationBillingRequestsRequest$ = [
      3,
      n032,
      _DCRBRR,
      0,
      [_Rol, _CRIa, _NTe, _MR, _Fi, _DR],
      [0, [() => CapacityReservationIdSet, { [_xN]: _CRI }], 0, 1, [() => FilterList, { [_xN]: _Fil }], 2],
      1
    ];
    exports2.DescribeCapacityReservationBillingRequestsResult$ = [
      3,
      n032,
      _DCRBRRe,
      0,
      [_NTe, _CRBRa],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => CapacityReservationBillingRequestSet, {
        [_eQN]: `CapacityReservationBillingRequestSet`,
        [_xN]: _cRBRS
      }]]
    ];
    exports2.DescribeCapacityReservationFleetsRequest$ = [
      3,
      n032,
      _DCRFR,
      0,
      [_CRFI, _NTe, _MR, _Fi, _DR],
      [[() => CapacityReservationFleetIdSet, { [_xN]: _CRFIa }], 0, 1, [() => FilterList, { [_xN]: _Fil }], 2]
    ];
    exports2.DescribeCapacityReservationFleetsResult$ = [
      3,
      n032,
      _DCRFRe,
      0,
      [_CRFa, _NTe],
      [[() => CapacityReservationFleetSet, {
        [_eQN]: `CapacityReservationFleetSet`,
        [_xN]: _cRFS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeCapacityReservationsRequest$ = [
      3,
      n032,
      _DCRR,
      0,
      [_CRIa, _NTe, _MR, _Fi, _DR],
      [[() => CapacityReservationIdSet, { [_xN]: _CRI }], 0, 1, [() => FilterList, { [_xN]: _Fil }], 2]
    ];
    exports2.DescribeCapacityReservationsResult$ = [
      3,
      n032,
      _DCRRe,
      0,
      [_NTe, _CRap],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => CapacityReservationSet, {
        [_eQN]: `CapacityReservationSet`,
        [_xN]: _cRS
      }]]
    ];
    exports2.DescribeCapacityReservationTopologyRequest$ = [
      3,
      n032,
      _DCRTR,
      0,
      [_DR, _NTe, _MR, _CRIa, _Fi],
      [2, 0, 1, [() => CapacityReservationIdSet, { [_xN]: _CRI }], [() => FilterList, { [_xN]: _Fil }]]
    ];
    exports2.DescribeCapacityReservationTopologyResult$ = [
      3,
      n032,
      _DCRTRe,
      0,
      [_NTe, _CRap],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => CapacityReservationTopologySet, {
        [_eQN]: `CapacityReservationSet`,
        [_xN]: _cRS
      }]]
    ];
    exports2.DescribeCarrierGatewaysRequest$ = [
      3,
      n032,
      _DCGRes,
      0,
      [_CGIa, _Fi, _MR, _NTe, _DR],
      [[64 | 0, { [_xN]: _CGI }], [() => FilterList, { [_xN]: _Fil }], 1, 0, 2]
    ];
    exports2.DescribeCarrierGatewaysResult$ = [
      3,
      n032,
      _DCGResc,
      0,
      [_CGa, _NTe],
      [[() => CarrierGatewaySet, {
        [_eQN]: `CarrierGatewaySet`,
        [_xN]: _cGS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeClassicLinkInstancesRequest$ = [
      3,
      n032,
      _DCLIR,
      0,
      [_DR, _IIns, _Fi, _NTe, _MR],
      [[2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => InstanceIdStringList, { [_xN]: _II2 }], [() => FilterList, { [_xN]: _Fil }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [1, {
        [_eQN]: `MaxResults`,
        [_xN]: _mR
      }]]
    ];
    exports2.DescribeClassicLinkInstancesResult$ = [
      3,
      n032,
      _DCLIRe,
      0,
      [_Ins, _NTe],
      [[() => ClassicLinkInstanceList, {
        [_eQN]: `InstancesSet`,
        [_xN]: _iSn
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeClientVpnAuthorizationRulesRequest$ = [
      3,
      n032,
      _DCVARR,
      0,
      [_CVEI, _DR, _NTe, _Fi, _MR],
      [0, 2, 0, [() => FilterList, { [_xN]: _Fil }], 1],
      1
    ];
    exports2.DescribeClientVpnAuthorizationRulesResult$ = [
      3,
      n032,
      _DCVARRe,
      0,
      [_ARut, _NTe],
      [[() => AuthorizationRuleSet, {
        [_eQN]: `AuthorizationRule`,
        [_xN]: _aRu
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeClientVpnConnectionsRequest$ = [
      3,
      n032,
      _DCVCR,
      0,
      [_CVEI, _Fi, _NTe, _MR, _DR],
      [0, [() => FilterList, { [_xN]: _Fil }], 0, 1, 2],
      1
    ];
    exports2.DescribeClientVpnConnectionsResult$ = [
      3,
      n032,
      _DCVCRe,
      0,
      [_Conn, _NTe],
      [[() => ClientVpnConnectionSet, {
        [_eQN]: `Connections`,
        [_xN]: _con
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeClientVpnEndpointsRequest$ = [
      3,
      n032,
      _DCVERes,
      0,
      [_CVEIl, _MR, _NTe, _Fi, _DR],
      [[() => ClientVpnEndpointIdList, { [_xN]: _CVEI }], 1, 0, [() => FilterList, { [_xN]: _Fil }], 2]
    ];
    exports2.DescribeClientVpnEndpointsResult$ = [
      3,
      n032,
      _DCVEResc,
      0,
      [_CVEl, _NTe],
      [[() => EndpointSet, {
        [_eQN]: `ClientVpnEndpoint`,
        [_xN]: _cVE
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeClientVpnRoutesRequest$ = [
      3,
      n032,
      _DCVRRes,
      0,
      [_CVEI, _Fi, _MR, _NTe, _DR],
      [0, [() => FilterList, { [_xN]: _Fil }], 1, 0, 2],
      1
    ];
    exports2.DescribeClientVpnRoutesResult$ = [
      3,
      n032,
      _DCVRResc,
      0,
      [_Rou, _NTe],
      [[() => ClientVpnRouteSet, {
        [_eQN]: `Routes`,
        [_xN]: _rou
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeClientVpnTargetNetworksRequest$ = [
      3,
      n032,
      _DCVTNR,
      0,
      [_CVEI, _AIsso, _MR, _NTe, _Fi, _DR],
      [0, [() => ValueStringList, 0], 1, 0, [() => FilterList, { [_xN]: _Fil }], 2],
      1
    ];
    exports2.DescribeClientVpnTargetNetworksResult$ = [
      3,
      n032,
      _DCVTNRe,
      0,
      [_CVTN, _NTe],
      [[() => TargetNetworkSet, {
        [_eQN]: `ClientVpnTargetNetworks`,
        [_xN]: _cVTN
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeCoipPoolsRequest$ = [
      3,
      n032,
      _DCPRes,
      0,
      [_PIoo, _Fi, _MR, _NTe, _DR],
      [[() => CoipPoolIdSet, { [_xN]: _PIo }], [() => FilterList, { [_xN]: _Fil }], 1, 0, 2]
    ];
    exports2.DescribeCoipPoolsResult$ = [
      3,
      n032,
      _DCPResc,
      0,
      [_CPo, _NTe],
      [[() => CoipPoolSet, {
        [_eQN]: `CoipPoolSet`,
        [_xN]: _cPS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeConversionTasksRequest$ = [
      3,
      n032,
      _DCTR,
      0,
      [_DR, _CTIo],
      [[2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => ConversionIdStringList, {
        [_eQN]: `ConversionTaskId`,
        [_xN]: _cTI
      }]]
    ];
    exports2.DescribeConversionTasksResult$ = [
      3,
      n032,
      _DCTRe,
      0,
      [_CTonv],
      [[() => DescribeConversionTaskList, {
        [_eQN]: `ConversionTasks`,
        [_xN]: _cTo
      }]]
    ];
    exports2.DescribeCustomerGatewaysRequest$ = [
      3,
      n032,
      _DCGRescr,
      0,
      [_CGIus, _Fi, _DR],
      [[() => CustomerGatewayIdStringList, { [_xN]: _CGIu }], [() => FilterList, { [_xN]: _Fil }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]]
    ];
    exports2.DescribeCustomerGatewaysResult$ = [
      3,
      n032,
      _DCGRescri,
      0,
      [_CGus],
      [[() => CustomerGatewayList, {
        [_eQN]: `CustomerGatewaySet`,
        [_xN]: _cGSu
      }]]
    ];
    exports2.DescribeDeclarativePoliciesReportsRequest$ = [
      3,
      n032,
      _DDPRR,
      0,
      [_DR, _NTe, _MR, _RIep],
      [2, 0, 1, [() => ValueStringList, { [_xN]: _RI }]]
    ];
    exports2.DescribeDeclarativePoliciesReportsResult$ = [
      3,
      n032,
      _DDPRRe,
      0,
      [_NTe, _Rep],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => DeclarativePoliciesReportList, {
        [_eQN]: `ReportSet`,
        [_xN]: _rSep
      }]]
    ];
    exports2.DescribeDhcpOptionsRequest$ = [
      3,
      n032,
      _DDORe,
      0,
      [_DOIh, _NTe, _MR, _DR, _Fi],
      [[() => DhcpOptionsIdStringList, { [_xN]: _DOI }], 0, 1, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => FilterList, { [_xN]: _Fil }]]
    ];
    exports2.DescribeDhcpOptionsResult$ = [
      3,
      n032,
      _DDORes,
      0,
      [_NTe, _DO],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => DhcpOptionsList, {
        [_eQN]: `DhcpOptionsSet`,
        [_xN]: _dOS
      }]]
    ];
    exports2.DescribeEgressOnlyInternetGatewaysRequest$ = [
      3,
      n032,
      _DEOIGRes,
      0,
      [_DR, _EOIGIg, _MR, _NTe, _Fi],
      [2, [() => EgressOnlyInternetGatewayIdList, { [_xN]: _EOIGI }], 1, 0, [() => FilterList, { [_xN]: _Fil }]]
    ];
    exports2.DescribeEgressOnlyInternetGatewaysResult$ = [
      3,
      n032,
      _DEOIGResc,
      0,
      [_EOIGg, _NTe],
      [[() => EgressOnlyInternetGatewayList, {
        [_eQN]: `EgressOnlyInternetGatewaySet`,
        [_xN]: _eOIGS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeElasticGpusRequest$ = [
      3,
      n032,
      _DEGR,
      0,
      [_EGI, _DR, _Fi, _MR, _NTe],
      [[() => ElasticGpuIdSet, { [_xN]: _EGIl }], 2, [() => FilterList, { [_xN]: _Fil }], 1, 0]
    ];
    exports2.DescribeElasticGpusResult$ = [
      3,
      n032,
      _DEGRe,
      0,
      [_EGS, _MR, _NTe],
      [[() => ElasticGpuSet, {
        [_eQN]: `ElasticGpuSet`,
        [_xN]: _eGS
      }], [1, {
        [_eQN]: `MaxResults`,
        [_xN]: _mR
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeExportImageTasksRequest$ = [
      3,
      n032,
      _DEITR,
      0,
      [_DR, _Fi, _EITI, _MR, _NTe],
      [2, [() => FilterList, { [_xN]: _Fil }], [() => ExportImageTaskIdList, { [_xN]: _EITIx }], 1, 0]
    ];
    exports2.DescribeExportImageTasksResult$ = [
      3,
      n032,
      _DEITRe,
      0,
      [_EIT, _NTe],
      [[() => ExportImageTaskList, {
        [_eQN]: `ExportImageTaskSet`,
        [_xN]: _eITS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeExportTasksRequest$ = [
      3,
      n032,
      _DETR,
      0,
      [_Fi, _ETIx],
      [[() => FilterList, { [_xN]: _Fil }], [() => ExportTaskIdStringList, {
        [_eQN]: `ExportTaskId`,
        [_xN]: _eTI
      }]]
    ];
    exports2.DescribeExportTasksResult$ = [
      3,
      n032,
      _DETRe,
      0,
      [_ETxp],
      [[() => ExportTaskList, {
        [_eQN]: `ExportTaskSet`,
        [_xN]: _eTSx
      }]]
    ];
    exports2.DescribeFastLaunchImagesRequest$ = [
      3,
      n032,
      _DFLIR,
      0,
      [_IIma, _Fi, _MR, _NTe, _DR],
      [[() => FastLaunchImageIdList, { [_xN]: _IIm }], [() => FilterList, { [_xN]: _Fil }], 1, 0, 2]
    ];
    exports2.DescribeFastLaunchImagesResult$ = [
      3,
      n032,
      _DFLIRe,
      0,
      [_FLIa, _NTe],
      [[() => DescribeFastLaunchImagesSuccessSet, {
        [_eQN]: `FastLaunchImageSet`,
        [_xN]: _fLISa
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeFastLaunchImagesSuccessItem$ = [
      3,
      n032,
      _DFLISI,
      0,
      [_IIm, _RTe, _SCn, _LT, _MPL, _OI, _St, _STR, _STT10],
      [[0, {
        [_eQN]: `ImageId`,
        [_xN]: _iIma
      }], [0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }], [() => exports2.FastLaunchSnapshotConfigurationResponse$, {
        [_eQN]: `SnapshotConfiguration`,
        [_xN]: _sCn
      }], [() => exports2.FastLaunchLaunchTemplateSpecificationResponse$, {
        [_eQN]: `LaunchTemplate`,
        [_xN]: _lT
      }], [1, {
        [_eQN]: `MaxParallelLaunches`,
        [_xN]: _mPL
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `StateTransitionReason`,
        [_xN]: _sTR
      }], [4, {
        [_eQN]: `StateTransitionTime`,
        [_xN]: _sTT
      }]]
    ];
    exports2.DescribeFastSnapshotRestoresRequest$ = [
      3,
      n032,
      _DFSRR,
      0,
      [_Fi, _MR, _NTe, _DR],
      [[() => FilterList, { [_xN]: _Fil }], 1, 0, 2]
    ];
    exports2.DescribeFastSnapshotRestoresResult$ = [
      3,
      n032,
      _DFSRRe,
      0,
      [_FSR, _NTe],
      [[() => DescribeFastSnapshotRestoreSuccessSet, {
        [_eQN]: `FastSnapshotRestoreSet`,
        [_xN]: _fSRS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeFastSnapshotRestoreSuccessItem$ = [
      3,
      n032,
      _DFSRSI,
      0,
      [_SIn, _AZ, _AZI, _St, _STR, _OI, _OAw, _ETna, _OT, _ETnab, _DTi, _DTis],
      [[0, {
        [_eQN]: `SnapshotId`,
        [_xN]: _sIn
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `StateTransitionReason`,
        [_xN]: _sTR
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `OwnerAlias`,
        [_xN]: _oAw
      }], [4, {
        [_eQN]: `EnablingTime`,
        [_xN]: _eTna
      }], [4, {
        [_eQN]: `OptimizingTime`,
        [_xN]: _oT
      }], [4, {
        [_eQN]: `EnabledTime`,
        [_xN]: _eTnab
      }], [4, {
        [_eQN]: `DisablingTime`,
        [_xN]: _dTi
      }], [4, {
        [_eQN]: `DisabledTime`,
        [_xN]: _dTis
      }]]
    ];
    exports2.DescribeFleetError$ = [
      3,
      n032,
      _DFEe,
      0,
      [_LTAO, _L2, _EC, _EM],
      [[() => exports2.LaunchTemplateAndOverridesResponse$, {
        [_eQN]: `LaunchTemplateAndOverrides`,
        [_xN]: _lTAO
      }], [0, {
        [_eQN]: `Lifecycle`,
        [_xN]: _l
      }], [0, {
        [_eQN]: `ErrorCode`,
        [_xN]: _eC
      }], [0, {
        [_eQN]: `ErrorMessage`,
        [_xN]: _eM
      }]]
    ];
    exports2.DescribeFleetHistoryRequest$ = [
      3,
      n032,
      _DFHR,
      0,
      [_FIl, _ST11, _DR, _ETv, _MR, _NTe],
      [0, 4, 2, 0, 1, 0],
      2
    ];
    exports2.DescribeFleetHistoryResult$ = [
      3,
      n032,
      _DFHRe,
      0,
      [_HRi, _LET, _NTe, _FIl, _ST11],
      [[() => HistoryRecordSet, {
        [_eQN]: `HistoryRecordSet`,
        [_xN]: _hRS
      }], [4, {
        [_eQN]: `LastEvaluatedTime`,
        [_xN]: _lET
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [0, {
        [_eQN]: `FleetId`,
        [_xN]: _fIl
      }], [4, {
        [_eQN]: `StartTime`,
        [_xN]: _sT19
      }]]
    ];
    exports2.DescribeFleetInstancesRequest$ = [
      3,
      n032,
      _DFIRes,
      0,
      [_FIl, _DR, _MR, _NTe, _Fi],
      [0, 2, 1, 0, [() => FilterList, { [_xN]: _Fil }]],
      1
    ];
    exports2.DescribeFleetInstancesResult$ = [
      3,
      n032,
      _DFIResc,
      0,
      [_AIct, _NTe, _FIl],
      [[() => ActiveInstanceSet, {
        [_eQN]: `ActiveInstanceSet`,
        [_xN]: _aIS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [0, {
        [_eQN]: `FleetId`,
        [_xN]: _fIl
      }]]
    ];
    exports2.DescribeFleetsInstances$ = [
      3,
      n032,
      _DFI,
      0,
      [_LTAO, _L2, _IIns, _IT4, _Pl],
      [[() => exports2.LaunchTemplateAndOverridesResponse$, {
        [_eQN]: `LaunchTemplateAndOverrides`,
        [_xN]: _lTAO
      }], [0, {
        [_eQN]: `Lifecycle`,
        [_xN]: _l
      }], [() => InstanceIdsSet, {
        [_eQN]: `InstanceIds`,
        [_xN]: _iIns
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [0, {
        [_eQN]: `Platform`,
        [_xN]: _pl
      }]]
    ];
    exports2.DescribeFleetsRequest$ = [
      3,
      n032,
      _DFRes,
      0,
      [_DR, _MR, _NTe, _FIle, _Fi],
      [2, 1, 0, [64 | 0, { [_xN]: _FIl }], [() => FilterList, { [_xN]: _Fil }]]
    ];
    exports2.DescribeFleetsResult$ = [
      3,
      n032,
      _DFResc,
      0,
      [_NTe, _Fl],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => FleetSet, {
        [_eQN]: `FleetSet`,
        [_xN]: _fS
      }]]
    ];
    exports2.DescribeFlowLogsRequest$ = [
      3,
      n032,
      _DFLRes,
      0,
      [_DR, _Fil, _FLI, _MR, _NTe],
      [2, [() => FilterList, 0], [() => FlowLogIdList, { [_xN]: _FLIl }], 1, 0]
    ];
    exports2.DescribeFlowLogsResult$ = [
      3,
      n032,
      _DFLResc,
      0,
      [_FL, _NTe],
      [[() => FlowLogSet, {
        [_eQN]: `FlowLogSet`,
        [_xN]: _fLS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeFpgaImageAttributeRequest$ = [
      3,
      n032,
      _DFIAR,
      0,
      [_FII, _At, _DR],
      [0, 0, 2],
      2
    ];
    exports2.DescribeFpgaImageAttributeResult$ = [
      3,
      n032,
      _DFIARe,
      0,
      [_FIA],
      [[() => exports2.FpgaImageAttribute$, {
        [_eQN]: `FpgaImageAttribute`,
        [_xN]: _fIA
      }]]
    ];
    exports2.DescribeFpgaImagesRequest$ = [
      3,
      n032,
      _DFIRescr,
      0,
      [_DR, _FIIp, _Ow, _Fi, _NTe, _MR],
      [2, [() => FpgaImageIdList, { [_xN]: _FII }], [() => OwnerStringList, { [_xN]: _Own }], [() => FilterList, { [_xN]: _Fil }], 0, 1]
    ];
    exports2.DescribeFpgaImagesResult$ = [
      3,
      n032,
      _DFIRescri,
      0,
      [_FIp, _NTe],
      [[() => FpgaImageList, {
        [_eQN]: `FpgaImageSet`,
        [_xN]: _fISp
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeHostReservationOfferingsRequest$ = [
      3,
      n032,
      _DHROR,
      0,
      [_Fil, _MD, _MR, _MDi, _NTe, _OIf],
      [[() => FilterList, 0], 1, 1, 1, 0, 0]
    ];
    exports2.DescribeHostReservationOfferingsResult$ = [
      3,
      n032,
      _DHRORe,
      0,
      [_NTe, _OS],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => HostOfferingSet, {
        [_eQN]: `OfferingSet`,
        [_xN]: _oS
      }]]
    ];
    exports2.DescribeHostReservationsRequest$ = [
      3,
      n032,
      _DHRR,
      0,
      [_Fil, _HRIS, _MR, _NTe],
      [[() => FilterList, 0], [() => HostReservationIdSet, 0], 1, 0]
    ];
    exports2.DescribeHostReservationsResult$ = [
      3,
      n032,
      _DHRRe,
      0,
      [_HRS, _NTe],
      [[() => HostReservationSet, {
        [_eQN]: `HostReservationSet`,
        [_xN]: _hRSo
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeHostsRequest$ = [
      3,
      n032,
      _DHR,
      0,
      [_HI, _NTe, _MR, _Fil],
      [[() => RequestHostIdList, {
        [_eQN]: `HostId`,
        [_xN]: _hI
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [1, {
        [_eQN]: `MaxResults`,
        [_xN]: _mR
      }], [() => FilterList, {
        [_eQN]: `Filter`,
        [_xN]: _f
      }]]
    ];
    exports2.DescribeHostsResult$ = [
      3,
      n032,
      _DHRe,
      0,
      [_H, _NTe],
      [[() => HostList, {
        [_eQN]: `HostSet`,
        [_xN]: _hS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeIamInstanceProfileAssociationsRequest$ = [
      3,
      n032,
      _DIIPAR,
      0,
      [_AIsso, _Fi, _MR, _NTe],
      [[() => AssociationIdList, { [_xN]: _AIs }], [() => FilterList, { [_xN]: _Fil }], 1, 0]
    ];
    exports2.DescribeIamInstanceProfileAssociationsResult$ = [
      3,
      n032,
      _DIIPARe,
      0,
      [_IIPAa, _NTe],
      [[() => IamInstanceProfileAssociationSet, {
        [_eQN]: `IamInstanceProfileAssociationSet`,
        [_xN]: _iIPAS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeIdentityIdFormatRequest$ = [
      3,
      n032,
      _DIIFR,
      0,
      [_PAr10, _Reso],
      [[0, {
        [_eQN]: `PrincipalArn`,
        [_xN]: _pAr
      }], [0, {
        [_eQN]: `Resource`,
        [_xN]: _re
      }]],
      1
    ];
    exports2.DescribeIdentityIdFormatResult$ = [
      3,
      n032,
      _DIIFRe,
      0,
      [_Statu],
      [[() => IdFormatList, {
        [_eQN]: `StatusSet`,
        [_xN]: _sSt
      }]]
    ];
    exports2.DescribeIdFormatRequest$ = [
      3,
      n032,
      _DIFR,
      0,
      [_Reso],
      [0]
    ];
    exports2.DescribeIdFormatResult$ = [
      3,
      n032,
      _DIFRe,
      0,
      [_Statu],
      [[() => IdFormatList, {
        [_eQN]: `StatusSet`,
        [_xN]: _sSt
      }]]
    ];
    exports2.DescribeImageAttributeRequest$ = [
      3,
      n032,
      _DIAR,
      0,
      [_At, _IIm, _DR],
      [0, 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      2
    ];
    exports2.DescribeImageReferencesRequest$ = [
      3,
      n032,
      _DIRR,
      0,
      [_IIma, _IART, _RTes, _NTe, _DR, _MR],
      [[64 | 0, { [_xN]: _IIm }], 2, [() => ResourceTypeRequestList, { [_xN]: _RTe }], 0, 2, 1],
      1
    ];
    exports2.DescribeImageReferencesResult$ = [
      3,
      n032,
      _DIRRe,
      0,
      [_NTe, _IR],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => ImageReferenceList, {
        [_eQN]: `ImageReferenceSet`,
        [_xN]: _iRS
      }]]
    ];
    exports2.DescribeImagesRequest$ = [
      3,
      n032,
      _DIRes,
      0,
      [_EU, _IIma, _Ow, _ID, _IDn, _MR, _NTe, _DR, _Fi],
      [[() => ExecutableByStringList, { [_xN]: _EBx }], [() => ImageIdStringList, { [_xN]: _IIm }], [() => OwnerStringList, { [_xN]: _Own }], 2, 2, 1, 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => FilterList, { [_xN]: _Fil }]]
    ];
    exports2.DescribeImagesResult$ = [
      3,
      n032,
      _DIResc,
      0,
      [_NTe, _Im],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => ImageList, {
        [_eQN]: `ImagesSet`,
        [_xN]: _iSm
      }]]
    ];
    exports2.DescribeImageUsageReportEntriesRequest$ = [
      3,
      n032,
      _DIURER,
      0,
      [_IIma, _RIep, _NTe, _Fi, _DR, _MR],
      [[64 | 0, { [_xN]: _IIm }], [64 | 0, { [_xN]: _RI }], 0, [() => FilterList, { [_xN]: _Fil }], 2, 1]
    ];
    exports2.DescribeImageUsageReportEntriesResult$ = [
      3,
      n032,
      _DIURERe,
      0,
      [_NTe, _IURE],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => ImageUsageReportEntryList, {
        [_eQN]: `ImageUsageReportEntrySet`,
        [_xN]: _iURES
      }]]
    ];
    exports2.DescribeImageUsageReportsRequest$ = [
      3,
      n032,
      _DIURRes,
      0,
      [_IIma, _RIep, _NTe, _Fi, _DR, _MR],
      [[64 | 0, { [_xN]: _IIm }], [64 | 0, { [_xN]: _RI }], 0, [() => FilterList, { [_xN]: _Fil }], 2, 1]
    ];
    exports2.DescribeImageUsageReportsResult$ = [
      3,
      n032,
      _DIURResc,
      0,
      [_NTe, _IUR],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => ImageUsageReportList, {
        [_eQN]: `ImageUsageReportSet`,
        [_xN]: _iURS
      }]]
    ];
    exports2.DescribeImportImageTasksRequest$ = [
      3,
      n032,
      _DIITR,
      0,
      [_DR, _Fi, _ITIm, _MR, _NTe],
      [2, [() => FilterList, { [_xN]: _Fi }], [() => ImportTaskIdList, { [_xN]: _ITI }], 1, 0]
    ];
    exports2.DescribeImportImageTasksResult$ = [
      3,
      n032,
      _DIITRe,
      0,
      [_IIT, _NTe],
      [[() => ImportImageTaskList, {
        [_eQN]: `ImportImageTaskSet`,
        [_xN]: _iITS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeImportSnapshotTasksRequest$ = [
      3,
      n032,
      _DISTR,
      0,
      [_DR, _Fi, _ITIm, _MR, _NTe],
      [2, [() => FilterList, { [_xN]: _Fi }], [() => ImportSnapshotTaskIdList, { [_xN]: _ITI }], 1, 0]
    ];
    exports2.DescribeImportSnapshotTasksResult$ = [
      3,
      n032,
      _DISTRe,
      0,
      [_IST, _NTe],
      [[() => ImportSnapshotTaskList, {
        [_eQN]: `ImportSnapshotTaskSet`,
        [_xN]: _iSTS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeInstanceAttributeRequest$ = [
      3,
      n032,
      _DIARe,
      0,
      [_II2, _At, _DR],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `Attribute`,
        [_xN]: _att
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      2
    ];
    exports2.DescribeInstanceConnectEndpointsRequest$ = [
      3,
      n032,
      _DICERes,
      0,
      [_DR, _MR, _NTe, _Fi, _ICEIn],
      [2, 1, 0, [() => FilterList, { [_xN]: _Fil }], [() => ValueStringList, { [_xN]: _ICEI }]]
    ];
    exports2.DescribeInstanceConnectEndpointsResult$ = [
      3,
      n032,
      _DICEResc,
      0,
      [_ICEn, _NTe],
      [[() => InstanceConnectEndpointSet, {
        [_eQN]: `InstanceConnectEndpointSet`,
        [_xN]: _iCES
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeInstanceCreditSpecificationsRequest$ = [
      3,
      n032,
      _DICSR,
      0,
      [_DR, _Fi, _IIns, _MR, _NTe],
      [2, [() => FilterList, { [_xN]: _Fil }], [() => InstanceIdStringList, { [_xN]: _II2 }], 1, 0]
    ];
    exports2.DescribeInstanceCreditSpecificationsResult$ = [
      3,
      n032,
      _DICSRe,
      0,
      [_ICS, _NTe],
      [[() => InstanceCreditSpecificationList, {
        [_eQN]: `InstanceCreditSpecificationSet`,
        [_xN]: _iCSS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeInstanceEventNotificationAttributesRequest$ = [
      3,
      n032,
      _DIENARes,
      0,
      [_DR],
      [2]
    ];
    exports2.DescribeInstanceEventNotificationAttributesResult$ = [
      3,
      n032,
      _DIENAResc,
      0,
      [_ITA],
      [[() => exports2.InstanceTagNotificationAttribute$, {
        [_eQN]: `InstanceTagAttribute`,
        [_xN]: _iTA
      }]]
    ];
    exports2.DescribeInstanceEventWindowsRequest$ = [
      3,
      n032,
      _DIEWRes,
      0,
      [_DR, _IEWIn, _Fi, _MR, _NTe],
      [2, [() => InstanceEventWindowIdSet, { [_xN]: _IEWI }], [() => FilterList, { [_xN]: _Fil }], 1, 0]
    ];
    exports2.DescribeInstanceEventWindowsResult$ = [
      3,
      n032,
      _DIEWResc,
      0,
      [_IEWn, _NTe],
      [[() => InstanceEventWindowSet, {
        [_eQN]: `InstanceEventWindowSet`,
        [_xN]: _iEWSn
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeInstanceImageMetadataRequest$ = [
      3,
      n032,
      _DIIMR,
      0,
      [_Fi, _IIns, _MR, _NTe, _DR],
      [[() => FilterList, { [_xN]: _Fil }], [() => InstanceIdStringList, { [_xN]: _II2 }], 1, 0, 2]
    ];
    exports2.DescribeInstanceImageMetadataResult$ = [
      3,
      n032,
      _DIIMRe,
      0,
      [_IIM, _NTe],
      [[() => InstanceImageMetadataList, {
        [_eQN]: `InstanceImageMetadataSet`,
        [_xN]: _iIMS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeInstanceSqlHaHistoryStatesRequest$ = [
      3,
      n032,
      _DISHHSR,
      0,
      [_IIns, _ST11, _ETnd, _NTe, _MR, _Fi, _DR],
      [[() => InstanceIdStringList, { [_xN]: _II2 }], 4, 4, 0, 1, [() => FilterList, { [_xN]: _Fil }], 2]
    ];
    exports2.DescribeInstanceSqlHaHistoryStatesResult$ = [
      3,
      n032,
      _DISHHSRe,
      0,
      [_Ins, _NTe],
      [[() => RegisteredInstanceList, {
        [_eQN]: `InstanceSet`,
        [_xN]: _iSns
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeInstanceSqlHaStatesRequest$ = [
      3,
      n032,
      _DISHSR,
      0,
      [_IIns, _NTe, _MR, _Fi, _DR],
      [[() => InstanceIdStringList, { [_xN]: _II2 }], 0, 1, [() => FilterList, { [_xN]: _Fil }], 2]
    ];
    exports2.DescribeInstanceSqlHaStatesResult$ = [
      3,
      n032,
      _DISHSRe,
      0,
      [_Ins, _NTe],
      [[() => RegisteredInstanceList, {
        [_eQN]: `InstanceSet`,
        [_xN]: _iSns
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeInstancesRequest$ = [
      3,
      n032,
      _DIRescr,
      0,
      [_IIns, _IMR, _DR, _Fi, _NTe, _MR],
      [[() => InstanceIdStringList, { [_xN]: _II2 }], 2, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => FilterList, { [_xN]: _Fil }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [1, {
        [_eQN]: `MaxResults`,
        [_xN]: _mR
      }]]
    ];
    exports2.DescribeInstancesResult$ = [
      3,
      n032,
      _DIRescri,
      0,
      [_NTe, _Rese],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => ReservationList, {
        [_eQN]: `ReservationSet`,
        [_xN]: _rSes
      }]]
    ];
    exports2.DescribeInstanceStatusRequest$ = [
      3,
      n032,
      _DISRes,
      0,
      [_IIns, _MR, _NTe, _IMR, _DR, _Fi, _IAI],
      [[() => InstanceIdStringList, { [_xN]: _II2 }], 1, 0, 2, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => FilterList, { [_xN]: _Fil }], [2, {
        [_eQN]: `IncludeAllInstances`,
        [_xN]: _iAI
      }]]
    ];
    exports2.DescribeInstanceStatusResult$ = [
      3,
      n032,
      _DISResc,
      0,
      [_ISns, _NTe],
      [[() => InstanceStatusList, {
        [_eQN]: `InstanceStatusSet`,
        [_xN]: _iSS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeInstanceTopologyRequest$ = [
      3,
      n032,
      _DITR,
      0,
      [_DR, _NTe, _MR, _IIns, _GNr, _Fi],
      [2, 0, 1, [64 | 0, { [_xN]: _II2 }], [64 | 0, { [_xN]: _GN }], [() => FilterList, { [_xN]: _Fil }]]
    ];
    exports2.DescribeInstanceTopologyResult$ = [
      3,
      n032,
      _DITRe,
      0,
      [_Ins, _NTe],
      [[() => InstanceSet, {
        [_eQN]: `InstanceSet`,
        [_xN]: _iSns
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeInstanceTypeOfferingsRequest$ = [
      3,
      n032,
      _DITOR,
      0,
      [_DR, _LTo, _Fi, _MR, _NTe],
      [2, 0, [() => FilterList, { [_xN]: _Fil }], 1, 0]
    ];
    exports2.DescribeInstanceTypeOfferingsResult$ = [
      3,
      n032,
      _DITORe,
      0,
      [_ITO, _NTe],
      [[() => InstanceTypeOfferingsList, {
        [_eQN]: `InstanceTypeOfferingSet`,
        [_xN]: _iTOS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeInstanceTypesRequest$ = [
      3,
      n032,
      _DITRes,
      0,
      [_DR, _ITnst, _Fi, _MR, _NTe],
      [2, [64 | 0, { [_xN]: _IT4 }], [() => FilterList, { [_xN]: _Fil }], 1, 0]
    ];
    exports2.DescribeInstanceTypesResult$ = [
      3,
      n032,
      _DITResc,
      0,
      [_ITnst, _NTe],
      [[() => InstanceTypeInfoList, {
        [_eQN]: `InstanceTypeSet`,
        [_xN]: _iTS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeInternetGatewaysRequest$ = [
      3,
      n032,
      _DIGRe,
      0,
      [_NTe, _MR, _DR, _IGIn, _Fi],
      [0, 1, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => InternetGatewayIdList, {
        [_eQN]: `InternetGatewayId`,
        [_xN]: _iGI
      }], [() => FilterList, { [_xN]: _Fil }]]
    ];
    exports2.DescribeInternetGatewaysResult$ = [
      3,
      n032,
      _DIGRes,
      0,
      [_IGn, _NTe],
      [[() => InternetGatewayList, {
        [_eQN]: `InternetGatewaySet`,
        [_xN]: _iGS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeIpamByoasnRequest$ = [
      3,
      n032,
      _DIBRes,
      0,
      [_DR, _MR, _NTe],
      [2, 1, 0]
    ];
    exports2.DescribeIpamByoasnResult$ = [
      3,
      n032,
      _DIBResc,
      0,
      [_By, _NTe],
      [[() => ByoasnSet, {
        [_eQN]: `ByoasnSet`,
        [_xN]: _bS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeIpamExternalResourceVerificationTokensRequest$ = [
      3,
      n032,
      _DIERVTRes,
      0,
      [_DR, _Fi, _NTe, _MR, _IERVTIp],
      [2, [() => FilterList, { [_xN]: _Fil }], 0, 1, [() => ValueStringList, { [_xN]: _IERVTI }]]
    ];
    exports2.DescribeIpamExternalResourceVerificationTokensResult$ = [
      3,
      n032,
      _DIERVTResc,
      0,
      [_NTe, _IERVTp],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => IpamExternalResourceVerificationTokenSet, {
        [_eQN]: `IpamExternalResourceVerificationTokenSet`,
        [_xN]: _iERVTS
      }]]
    ];
    exports2.DescribeIpamPoliciesRequest$ = [
      3,
      n032,
      _DIPRes,
      0,
      [_DR, _Fi, _MR, _NTe, _IPIpa],
      [2, [() => FilterList, { [_xN]: _Fil }], 1, 0, [() => ValueStringList, { [_xN]: _IPIp }]]
    ];
    exports2.DescribeIpamPoliciesResult$ = [
      3,
      n032,
      _DIPResc,
      0,
      [_NTe, _IPpamo],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => IpamPolicySet, {
        [_eQN]: `IpamPolicySet`,
        [_xN]: _iPS
      }]]
    ];
    exports2.DescribeIpamPoolsRequest$ = [
      3,
      n032,
      _DIPRescr,
      0,
      [_DR, _Fi, _MR, _NTe, _IPIpam],
      [2, [() => FilterList, { [_xN]: _Fil }], 1, 0, [() => ValueStringList, { [_xN]: _IPI2 }]]
    ];
    exports2.DescribeIpamPoolsResult$ = [
      3,
      n032,
      _DIPRescri,
      0,
      [_NTe, _IPpamoo],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => IpamPoolSet, {
        [_eQN]: `IpamPoolSet`,
        [_xN]: _iPSp
      }]]
    ];
    exports2.DescribeIpamPrefixListResolversRequest$ = [
      3,
      n032,
      _DIPLRRes,
      0,
      [_DR, _Fi, _MR, _NTe, _IPLRIp],
      [2, [() => FilterList, { [_xN]: _Fil }], 1, 0, [() => ValueStringList, { [_xN]: _IPLRI }]]
    ];
    exports2.DescribeIpamPrefixListResolversResult$ = [
      3,
      n032,
      _DIPLRResc,
      0,
      [_NTe, _IPLRp],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => IpamPrefixListResolverSet, {
        [_eQN]: `IpamPrefixListResolverSet`,
        [_xN]: _iPLRS
      }]]
    ];
    exports2.DescribeIpamPrefixListResolverTargetsRequest$ = [
      3,
      n032,
      _DIPLRTRes,
      0,
      [_DR, _Fi, _MR, _NTe, _IPLRTIp, _IPLRI],
      [2, [() => FilterList, { [_xN]: _Fil }], 1, 0, [() => ValueStringList, { [_xN]: _IPLRTI }], 0]
    ];
    exports2.DescribeIpamPrefixListResolverTargetsResult$ = [
      3,
      n032,
      _DIPLRTResc,
      0,
      [_NTe, _IPLRTp],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => IpamPrefixListResolverTargetSet, {
        [_eQN]: `IpamPrefixListResolverTargetSet`,
        [_xN]: _iPLRTS
      }]]
    ];
    exports2.DescribeIpamResourceDiscoveriesRequest$ = [
      3,
      n032,
      _DIRDRes,
      0,
      [_DR, _IRDIp, _NTe, _MR, _Fi],
      [2, [() => ValueStringList, { [_xN]: _IRDI }], 0, 1, [() => FilterList, { [_xN]: _Fil }]]
    ];
    exports2.DescribeIpamResourceDiscoveriesResult$ = [
      3,
      n032,
      _DIRDResc,
      0,
      [_IRDp, _NTe],
      [[() => IpamResourceDiscoverySet, {
        [_eQN]: `IpamResourceDiscoverySet`,
        [_xN]: _iRDS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeIpamResourceDiscoveryAssociationsRequest$ = [
      3,
      n032,
      _DIRDAR,
      0,
      [_DR, _IRDAI, _NTe, _MR, _Fi],
      [2, [() => ValueStringList, { [_xN]: _IRDAIp }], 0, 1, [() => FilterList, { [_xN]: _Fil }]]
    ];
    exports2.DescribeIpamResourceDiscoveryAssociationsResult$ = [
      3,
      n032,
      _DIRDARe,
      0,
      [_IRDAp, _NTe],
      [[() => IpamResourceDiscoveryAssociationSet, {
        [_eQN]: `IpamResourceDiscoveryAssociationSet`,
        [_xN]: _iRDAS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeIpamScopesRequest$ = [
      3,
      n032,
      _DISRescr,
      0,
      [_DR, _Fi, _MR, _NTe, _ISIp],
      [2, [() => FilterList, { [_xN]: _Fil }], 1, 0, [() => ValueStringList, { [_xN]: _ISI }]]
    ];
    exports2.DescribeIpamScopesResult$ = [
      3,
      n032,
      _DISRescri,
      0,
      [_NTe, _ISpa],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => IpamScopeSet, {
        [_eQN]: `IpamScopeSet`,
        [_xN]: _iSSp
      }]]
    ];
    exports2.DescribeIpamsRequest$ = [
      3,
      n032,
      _DIRescrib,
      0,
      [_DR, _Fi, _MR, _NTe, _IIpa],
      [2, [() => FilterList, { [_xN]: _Fil }], 1, 0, [() => ValueStringList, { [_xN]: _IIp }]]
    ];
    exports2.DescribeIpamsResult$ = [
      3,
      n032,
      _DIRescribe,
      0,
      [_NTe, _Ipa],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => IpamSet, {
        [_eQN]: `IpamSet`,
        [_xN]: _iSpa
      }]]
    ];
    exports2.DescribeIpv6PoolsRequest$ = [
      3,
      n032,
      _DIPRescrib,
      0,
      [_PIoo, _NTe, _MR, _DR, _Fi],
      [[() => Ipv6PoolIdList, { [_xN]: _PIo }], 0, 1, 2, [() => FilterList, { [_xN]: _Fil }]]
    ];
    exports2.DescribeIpv6PoolsResult$ = [
      3,
      n032,
      _DIPRescribe,
      0,
      [_IPpvoo, _NTe],
      [[() => Ipv6PoolSet, {
        [_eQN]: `Ipv6PoolSet`,
        [_xN]: _iPSpv
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeKeyPairsRequest$ = [
      3,
      n032,
      _DKPRes,
      0,
      [_KNe, _KPIe, _IPK, _DR, _Fi],
      [[() => KeyNameStringList, { [_xN]: _KN }], [() => KeyPairIdStringList, { [_xN]: _KPI }], 2, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => FilterList, { [_xN]: _Fil }]]
    ];
    exports2.DescribeKeyPairsResult$ = [
      3,
      n032,
      _DKPResc,
      0,
      [_KP],
      [[() => KeyPairList, {
        [_eQN]: `KeySet`,
        [_xN]: _kS
      }]]
    ];
    exports2.DescribeLaunchTemplatesRequest$ = [
      3,
      n032,
      _DLTRes,
      0,
      [_DR, _LTIa, _LTNa, _Fi, _NTe, _MR, _IMR],
      [2, [() => LaunchTemplateIdStringList, { [_xN]: _LTI }], [() => LaunchTemplateNameStringList, { [_xN]: _LTN }], [() => FilterList, { [_xN]: _Fil }], 0, 1, 2]
    ];
    exports2.DescribeLaunchTemplatesResult$ = [
      3,
      n032,
      _DLTResc,
      0,
      [_LTa, _NTe],
      [[() => LaunchTemplateSet, {
        [_eQN]: `LaunchTemplates`,
        [_xN]: _lTa
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeLaunchTemplateVersionsRequest$ = [
      3,
      n032,
      _DLTVRes,
      0,
      [_DR, _LTI, _LTN, _Ve, _MV, _MVa, _NTe, _MR, _Fi, _RAes, _IMR],
      [2, 0, 0, [() => VersionStringList, { [_xN]: _LTV }], 0, 0, 0, 1, [() => FilterList, { [_xN]: _Fil }], 2, 2]
    ];
    exports2.DescribeLaunchTemplateVersionsResult$ = [
      3,
      n032,
      _DLTVResc,
      0,
      [_LTVa, _NTe],
      [[() => LaunchTemplateVersionSet, {
        [_eQN]: `LaunchTemplateVersionSet`,
        [_xN]: _lTVS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeLocalGatewayRouteTablesRequest$ = [
      3,
      n032,
      _DLGRTRes,
      0,
      [_LGRTIo, _Fi, _MR, _NTe, _DR],
      [[() => LocalGatewayRouteTableIdSet, { [_xN]: _LGRTI }], [() => FilterList, { [_xN]: _Fil }], 1, 0, 2]
    ];
    exports2.DescribeLocalGatewayRouteTablesResult$ = [
      3,
      n032,
      _DLGRTResc,
      0,
      [_LGRTo, _NTe],
      [[() => LocalGatewayRouteTableSet, {
        [_eQN]: `LocalGatewayRouteTableSet`,
        [_xN]: _lGRTS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociationsRequest$ = [
      3,
      n032,
      _DLGRTVIGARes,
      0,
      [_LGRTVIGAIo, _Fi, _MR, _NTe, _DR],
      [[() => LocalGatewayRouteTableVirtualInterfaceGroupAssociationIdSet, { [_xN]: _LGRTVIGAI }], [() => FilterList, { [_xN]: _Fil }], 1, 0, 2]
    ];
    exports2.DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociationsResult$ = [
      3,
      n032,
      _DLGRTVIGAResc,
      0,
      [_LGRTVIGAo, _NTe],
      [[() => LocalGatewayRouteTableVirtualInterfaceGroupAssociationSet, {
        [_eQN]: `LocalGatewayRouteTableVirtualInterfaceGroupAssociationSet`,
        [_xN]: _lGRTVIGAS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeLocalGatewayRouteTableVpcAssociationsRequest$ = [
      3,
      n032,
      _DLGRTVARes,
      0,
      [_LGRTVAIo, _Fi, _MR, _NTe, _DR],
      [[() => LocalGatewayRouteTableVpcAssociationIdSet, { [_xN]: _LGRTVAI }], [() => FilterList, { [_xN]: _Fil }], 1, 0, 2]
    ];
    exports2.DescribeLocalGatewayRouteTableVpcAssociationsResult$ = [
      3,
      n032,
      _DLGRTVAResc,
      0,
      [_LGRTVAo, _NTe],
      [[() => LocalGatewayRouteTableVpcAssociationSet, {
        [_eQN]: `LocalGatewayRouteTableVpcAssociationSet`,
        [_xN]: _lGRTVAS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeLocalGatewaysRequest$ = [
      3,
      n032,
      _DLGR,
      0,
      [_LGIo, _Fi, _MR, _NTe, _DR],
      [[() => LocalGatewayIdSet, { [_xN]: _LGI }], [() => FilterList, { [_xN]: _Fil }], 1, 0, 2]
    ];
    exports2.DescribeLocalGatewaysResult$ = [
      3,
      n032,
      _DLGRe,
      0,
      [_LG, _NTe],
      [[() => LocalGatewaySet, {
        [_eQN]: `LocalGatewaySet`,
        [_xN]: _lGS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeLocalGatewayVirtualInterfaceGroupsRequest$ = [
      3,
      n032,
      _DLGVIGRes,
      0,
      [_LGVIGIo, _Fi, _MR, _NTe, _DR],
      [[() => LocalGatewayVirtualInterfaceGroupIdSet, { [_xN]: _LGVIGI }], [() => FilterList, { [_xN]: _Fil }], 1, 0, 2]
    ];
    exports2.DescribeLocalGatewayVirtualInterfaceGroupsResult$ = [
      3,
      n032,
      _DLGVIGResc,
      0,
      [_LGVIGo, _NTe],
      [[() => LocalGatewayVirtualInterfaceGroupSet, {
        [_eQN]: `LocalGatewayVirtualInterfaceGroupSet`,
        [_xN]: _lGVIGS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeLocalGatewayVirtualInterfacesRequest$ = [
      3,
      n032,
      _DLGVIRes,
      0,
      [_LGVIIo, _Fi, _MR, _NTe, _DR],
      [[() => LocalGatewayVirtualInterfaceIdSet, { [_xN]: _LGVII }], [() => FilterList, { [_xN]: _Fil }], 1, 0, 2]
    ];
    exports2.DescribeLocalGatewayVirtualInterfacesResult$ = [
      3,
      n032,
      _DLGVIResc,
      0,
      [_LGVIo, _NTe],
      [[() => LocalGatewayVirtualInterfaceSet, {
        [_eQN]: `LocalGatewayVirtualInterfaceSet`,
        [_xN]: _lGVIS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeLockedSnapshotsRequest$ = [
      3,
      n032,
      _DLSR,
      0,
      [_Fi, _MR, _NTe, _SIna, _DR],
      [[() => FilterList, { [_xN]: _Fil }], 1, 0, [() => SnapshotIdStringList, { [_xN]: _SIn }], 2]
    ];
    exports2.DescribeLockedSnapshotsResult$ = [
      3,
      n032,
      _DLSRe,
      0,
      [_Sn, _NTe],
      [[() => LockedSnapshotsInfoList, {
        [_eQN]: `SnapshotSet`,
        [_xN]: _sSn
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeMacHostsRequest$ = [
      3,
      n032,
      _DMHR,
      0,
      [_Fi, _HI, _MR, _NTe],
      [[() => FilterList, { [_xN]: _Fil }], [() => RequestHostIdList, { [_xN]: _HIo }], 1, 0]
    ];
    exports2.DescribeMacHostsResult$ = [
      3,
      n032,
      _DMHRe,
      0,
      [_MH, _NTe],
      [[() => MacHostList, {
        [_eQN]: `MacHostSet`,
        [_xN]: _mHS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeMacModificationTasksRequest$ = [
      3,
      n032,
      _DMMTR,
      0,
      [_DR, _Fi, _MMTI, _MR, _NTe],
      [2, [() => FilterList, { [_xN]: _Fil }], [() => MacModificationTaskIdList, { [_xN]: _MMTIa }], 1, 0]
    ];
    exports2.DescribeMacModificationTasksResult$ = [
      3,
      n032,
      _DMMTRe,
      0,
      [_MMTa, _NTe],
      [[() => MacModificationTaskList, {
        [_eQN]: `MacModificationTaskSet`,
        [_xN]: _mMTS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeManagedPrefixListsRequest$ = [
      3,
      n032,
      _DMPLRes,
      0,
      [_DR, _Fi, _MR, _NTe, _PLIr],
      [2, [() => FilterList, { [_xN]: _Fil }], 1, 0, [() => ValueStringList, { [_xN]: _PLI }]]
    ];
    exports2.DescribeManagedPrefixListsResult$ = [
      3,
      n032,
      _DMPLResc,
      0,
      [_NTe, _PLr],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => ManagedPrefixListSet, {
        [_eQN]: `PrefixListSet`,
        [_xN]: _pLS
      }]]
    ];
    exports2.DescribeMovingAddressesRequest$ = [
      3,
      n032,
      _DMAR,
      0,
      [_DR, _PIu, _NTe, _Fi, _MR],
      [[2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => ValueStringList, {
        [_eQN]: `PublicIp`,
        [_xN]: _pI
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => FilterList, {
        [_eQN]: `Filter`,
        [_xN]: _f
      }], [1, {
        [_eQN]: `MaxResults`,
        [_xN]: _mR
      }]]
    ];
    exports2.DescribeMovingAddressesResult$ = [
      3,
      n032,
      _DMARe,
      0,
      [_MAS, _NTe],
      [[() => MovingAddressStatusSet, {
        [_eQN]: `MovingAddressStatusSet`,
        [_xN]: _mASS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeNatGatewaysRequest$ = [
      3,
      n032,
      _DNGRes,
      0,
      [_DR, _Fil, _MR, _NGIa, _NTe],
      [2, [() => FilterList, 0], 1, [() => NatGatewayIdStringList, { [_xN]: _NGI }], 0]
    ];
    exports2.DescribeNatGatewaysResult$ = [
      3,
      n032,
      _DNGResc,
      0,
      [_NGa, _NTe],
      [[() => NatGatewayList, {
        [_eQN]: `NatGatewaySet`,
        [_xN]: _nGS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeNetworkAclsRequest$ = [
      3,
      n032,
      _DNARe,
      0,
      [_NTe, _MR, _DR, _NAIe, _Fi],
      [0, 1, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => NetworkAclIdStringList, { [_xN]: _NAI }], [() => FilterList, { [_xN]: _Fil }]]
    ];
    exports2.DescribeNetworkAclsResult$ = [
      3,
      n032,
      _DNARes,
      0,
      [_NAe, _NTe],
      [[() => NetworkAclList, {
        [_eQN]: `NetworkAclSet`,
        [_xN]: _nAS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeNetworkInsightsAccessScopeAnalysesRequest$ = [
      3,
      n032,
      _DNIASARes,
      0,
      [_NIASAIe, _NIASI, _ASTB, _ASTE, _Fi, _MR, _DR, _NTe],
      [[() => NetworkInsightsAccessScopeAnalysisIdList, { [_xN]: _NIASAI }], 0, 4, 4, [() => FilterList, { [_xN]: _Fil }], 1, 2, 0]
    ];
    exports2.DescribeNetworkInsightsAccessScopeAnalysesResult$ = [
      3,
      n032,
      _DNIASAResc,
      0,
      [_NIASA, _NTe],
      [[() => NetworkInsightsAccessScopeAnalysisList, {
        [_eQN]: `NetworkInsightsAccessScopeAnalysisSet`,
        [_xN]: _nIASAS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeNetworkInsightsAccessScopesRequest$ = [
      3,
      n032,
      _DNIASRes,
      0,
      [_NIASIe, _Fi, _MR, _DR, _NTe],
      [[() => NetworkInsightsAccessScopeIdList, { [_xN]: _NIASI }], [() => FilterList, { [_xN]: _Fil }], 1, 2, 0]
    ];
    exports2.DescribeNetworkInsightsAccessScopesResult$ = [
      3,
      n032,
      _DNIASResc,
      0,
      [_NIASe, _NTe],
      [[() => NetworkInsightsAccessScopeList, {
        [_eQN]: `NetworkInsightsAccessScopeSet`,
        [_xN]: _nIASS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeNetworkInsightsAnalysesRequest$ = [
      3,
      n032,
      _DNIARes,
      0,
      [_NIAIe, _NIPI, _AST, _AET, _Fi, _MR, _DR, _NTe],
      [[() => NetworkInsightsAnalysisIdList, { [_xN]: _NIAI }], 0, 4, 4, [() => FilterList, { [_xN]: _Fil }], 1, 2, 0]
    ];
    exports2.DescribeNetworkInsightsAnalysesResult$ = [
      3,
      n032,
      _DNIAResc,
      0,
      [_NIA, _NTe],
      [[() => NetworkInsightsAnalysisList, {
        [_eQN]: `NetworkInsightsAnalysisSet`,
        [_xN]: _nIASe
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeNetworkInsightsPathsRequest$ = [
      3,
      n032,
      _DNIPRes,
      0,
      [_NIPIet, _Fi, _MR, _DR, _NTe],
      [[() => NetworkInsightsPathIdList, { [_xN]: _NIPI }], [() => FilterList, { [_xN]: _Fil }], 1, 2, 0]
    ];
    exports2.DescribeNetworkInsightsPathsResult$ = [
      3,
      n032,
      _DNIPResc,
      0,
      [_NIPe, _NTe],
      [[() => NetworkInsightsPathList, {
        [_eQN]: `NetworkInsightsPathSet`,
        [_xN]: _nIPS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeNetworkInterfaceAttributeRequest$ = [
      3,
      n032,
      _DNIARescr,
      0,
      [_NII, _DR, _At],
      [[0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [0, {
        [_eQN]: `Attribute`,
        [_xN]: _att
      }]],
      1
    ];
    exports2.DescribeNetworkInterfaceAttributeResult$ = [
      3,
      n032,
      _DNIARescri,
      0,
      [_Att, _De, _G, _NII, _SDC, _APIAss],
      [[() => exports2.NetworkInterfaceAttachment$, {
        [_eQN]: `Attachment`,
        [_xN]: _at
      }], [() => exports2.AttributeValue$, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [() => GroupIdentifierList, {
        [_eQN]: `GroupSet`,
        [_xN]: _gSr
      }], [0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], [() => exports2.AttributeBooleanValue$, {
        [_eQN]: `SourceDestCheck`,
        [_xN]: _sDC
      }], [2, {
        [_eQN]: `AssociatePublicIpAddress`,
        [_xN]: _aPIA
      }]]
    ];
    exports2.DescribeNetworkInterfacePermissionsRequest$ = [
      3,
      n032,
      _DNIPRescr,
      0,
      [_NIPIetw, _Fi, _NTe, _MR],
      [[64 | 0, { [_xN]: _NIPIe }], [() => FilterList, { [_xN]: _Fil }], 0, 1]
    ];
    exports2.DescribeNetworkInterfacePermissionsResult$ = [
      3,
      n032,
      _DNIPRescri,
      0,
      [_NIPet, _NTe],
      [[() => NetworkInterfacePermissionList, {
        [_eQN]: `NetworkInterfacePermissions`,
        [_xN]: _nIPe
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeNetworkInterfacesRequest$ = [
      3,
      n032,
      _DNIRe,
      0,
      [_NTe, _MR, _IMR, _DR, _NIIe, _Fi],
      [0, 1, 2, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => NetworkInterfaceIdList, { [_xN]: _NII }], [() => FilterList, {
        [_eQN]: `Filter`,
        [_xN]: _f
      }]]
    ];
    exports2.DescribeNetworkInterfacesResult$ = [
      3,
      n032,
      _DNIRes,
      0,
      [_NIet, _NTe],
      [[() => NetworkInterfaceList, {
        [_eQN]: `NetworkInterfaceSet`,
        [_xN]: _nIS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeOutpostLagsRequest$ = [
      3,
      n032,
      _DOLR,
      0,
      [_OLIu, _Fi, _MR, _NTe, _DR],
      [[() => OutpostLagIdSet, { [_xN]: _OLI }], [() => FilterList, { [_xN]: _Fil }], 1, 0, 2]
    ];
    exports2.DescribeOutpostLagsResult$ = [
      3,
      n032,
      _DOLRe,
      0,
      [_OL, _NTe],
      [[() => OutpostLagSet, {
        [_eQN]: `OutpostLagSet`,
        [_xN]: _oLS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribePlacementGroupsRequest$ = [
      3,
      n032,
      _DPGRe,
      0,
      [_GIro, _DR, _GNr, _Fi],
      [[() => PlacementGroupIdStringList, { [_xN]: _GIr }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [64 | 0, {
        [_eQN]: `GroupName`,
        [_xN]: _gN
      }], [() => FilterList, { [_xN]: _Fil }]]
    ];
    exports2.DescribePlacementGroupsResult$ = [
      3,
      n032,
      _DPGRes,
      0,
      [_PGl],
      [[() => PlacementGroupList, {
        [_eQN]: `PlacementGroupSet`,
        [_xN]: _pGS
      }]]
    ];
    exports2.DescribePrefixListsRequest$ = [
      3,
      n032,
      _DPLR,
      0,
      [_DR, _Fi, _MR, _NTe, _PLIr],
      [2, [() => FilterList, { [_xN]: _Fil }], 1, 0, [() => PrefixListResourceIdStringList, { [_xN]: _PLI }]]
    ];
    exports2.DescribePrefixListsResult$ = [
      3,
      n032,
      _DPLRe,
      0,
      [_NTe, _PLr],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => PrefixListSet, {
        [_eQN]: `PrefixListSet`,
        [_xN]: _pLS
      }]]
    ];
    exports2.DescribePrincipalIdFormatRequest$ = [
      3,
      n032,
      _DPIFR,
      0,
      [_DR, _Res, _MR, _NTe],
      [2, [() => ResourceList, { [_xN]: _Reso }], 1, 0]
    ];
    exports2.DescribePrincipalIdFormatResult$ = [
      3,
      n032,
      _DPIFRe,
      0,
      [_Pri, _NTe],
      [[() => PrincipalIdFormatList, {
        [_eQN]: `PrincipalSet`,
        [_xN]: _pSrin
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribePublicIpv4PoolsRequest$ = [
      3,
      n032,
      _DPIPRes,
      0,
      [_PIoo, _NTe, _MR, _Fi],
      [[() => PublicIpv4PoolIdStringList, { [_xN]: _PIo }], 0, 1, [() => FilterList, { [_xN]: _Fil }]]
    ];
    exports2.DescribePublicIpv4PoolsResult$ = [
      3,
      n032,
      _DPIPResc,
      0,
      [_PIPu, _NTe],
      [[() => PublicIpv4PoolSet, {
        [_eQN]: `PublicIpv4PoolSet`,
        [_xN]: _pIPS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeRegionsRequest$ = [
      3,
      n032,
      _DRRe,
      0,
      [_RNe, _ARll, _DR, _Fi],
      [[() => RegionNameStringList, { [_xN]: _RN }], 2, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => FilterList, { [_xN]: _Fil }]]
    ];
    exports2.DescribeRegionsResult$ = [
      3,
      n032,
      _DRRes,
      0,
      [_Reg],
      [[() => RegionList, {
        [_eQN]: `RegionInfo`,
        [_xN]: _rIeg
      }]]
    ];
    exports2.DescribeReplaceRootVolumeTasksRequest$ = [
      3,
      n032,
      _DRRVTR,
      0,
      [_RRVTI, _Fi, _MR, _NTe, _DR],
      [[() => ReplaceRootVolumeTaskIds, { [_xN]: _RRVTIe }], [() => FilterList, { [_xN]: _Fil }], 1, 0, 2]
    ];
    exports2.DescribeReplaceRootVolumeTasksResult$ = [
      3,
      n032,
      _DRRVTRe,
      0,
      [_RRVTe, _NTe],
      [[() => ReplaceRootVolumeTasks, {
        [_eQN]: `ReplaceRootVolumeTaskSet`,
        [_xN]: _rRVTS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeReservedInstancesListingsRequest$ = [
      3,
      n032,
      _DRILR,
      0,
      [_RIIes, _RILI, _Fi],
      [[0, {
        [_eQN]: `ReservedInstancesId`,
        [_xN]: _rII
      }], [0, {
        [_eQN]: `ReservedInstancesListingId`,
        [_xN]: _rILI
      }], [() => FilterList, { [_xN]: _Fil }]]
    ];
    exports2.DescribeReservedInstancesListingsResult$ = [
      3,
      n032,
      _DRILRe,
      0,
      [_RIL],
      [[() => ReservedInstancesListingList, {
        [_eQN]: `ReservedInstancesListingsSet`,
        [_xN]: _rILS
      }]]
    ];
    exports2.DescribeReservedInstancesModificationsRequest$ = [
      3,
      n032,
      _DRIMR,
      0,
      [_RIMI, _NTe, _Fi],
      [[() => ReservedInstancesModificationIdStringList, { [_xN]: _RIMIe }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => FilterList, { [_xN]: _Fil }]]
    ];
    exports2.DescribeReservedInstancesModificationsResult$ = [
      3,
      n032,
      _DRIMRe,
      0,
      [_NTe, _RIM],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => ReservedInstancesModificationList, {
        [_eQN]: `ReservedInstancesModificationsSet`,
        [_xN]: _rIMS
      }]]
    ];
    exports2.DescribeReservedInstancesOfferingsRequest$ = [
      3,
      n032,
      _DRIOR,
      0,
      [_AZ, _IM, _IT4, _MD, _MIC, _MDi, _OC, _PDr, _RIOI, _AZI, _DR, _Fi, _ITns, _OTf, _NTe, _MR],
      [0, 2, 0, 1, 1, 1, 0, 0, [64 | 0, { [_xN]: _RIOIe }], 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => FilterList, { [_xN]: _Fil }], [0, {
        [_eQN]: `InstanceTenancy`,
        [_xN]: _iTns
      }], [0, {
        [_eQN]: `OfferingType`,
        [_xN]: _oTf
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [1, {
        [_eQN]: `MaxResults`,
        [_xN]: _mR
      }]]
    ];
    exports2.DescribeReservedInstancesOfferingsResult$ = [
      3,
      n032,
      _DRIORe,
      0,
      [_NTe, _RIO],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => ReservedInstancesOfferingList, {
        [_eQN]: `ReservedInstancesOfferingsSet`,
        [_xN]: _rIOS
      }]]
    ];
    exports2.DescribeReservedInstancesRequest$ = [
      3,
      n032,
      _DRIR,
      0,
      [_OC, _RIIese, _DR, _Fi, _OTf],
      [0, [() => ReservedInstancesIdStringList, { [_xN]: _RIIes }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => FilterList, { [_xN]: _Fil }], [0, {
        [_eQN]: `OfferingType`,
        [_xN]: _oTf
      }]]
    ];
    exports2.DescribeReservedInstancesResult$ = [
      3,
      n032,
      _DRIRe,
      0,
      [_RIese],
      [[() => ReservedInstancesList, {
        [_eQN]: `ReservedInstancesSet`,
        [_xN]: _rIS
      }]]
    ];
    exports2.DescribeRouteServerEndpointsRequest$ = [
      3,
      n032,
      _DRSERes,
      0,
      [_RSEIo, _NTe, _MR, _Fi, _DR],
      [[64 | 0, { [_xN]: _RSEI }], 0, 1, [() => FilterList, { [_xN]: _Fil }], 2]
    ];
    exports2.DescribeRouteServerEndpointsResult$ = [
      3,
      n032,
      _DRSEResc,
      0,
      [_RSEo, _NTe],
      [[() => RouteServerEndpointsList, {
        [_eQN]: `RouteServerEndpointSet`,
        [_xN]: _rSES
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeRouteServerPeersRequest$ = [
      3,
      n032,
      _DRSPRes,
      0,
      [_RSPIo, _NTe, _MR, _Fi, _DR],
      [[64 | 0, { [_xN]: _RSPI }], 0, 1, [() => FilterList, { [_xN]: _Fil }], 2]
    ];
    exports2.DescribeRouteServerPeersResult$ = [
      3,
      n032,
      _DRSPResc,
      0,
      [_RSPo, _NTe],
      [[() => RouteServerPeersList, {
        [_eQN]: `RouteServerPeerSet`,
        [_xN]: _rSPS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeRouteServersRequest$ = [
      3,
      n032,
      _DRSRes,
      0,
      [_RSIo, _NTe, _MR, _Fi, _DR],
      [[64 | 0, { [_xN]: _RSI }], 0, 1, [() => FilterList, { [_xN]: _Fil }], 2]
    ];
    exports2.DescribeRouteServersResult$ = [
      3,
      n032,
      _DRSResc,
      0,
      [_RSou, _NTe],
      [[() => RouteServersList, {
        [_eQN]: `RouteServerSet`,
        [_xN]: _rSSo
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeRouteTablesRequest$ = [
      3,
      n032,
      _DRTRe,
      0,
      [_NTe, _MR, _DR, _RTIo, _Fi],
      [0, 1, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => RouteTableIdStringList, { [_xN]: _RTI }], [() => FilterList, { [_xN]: _Fil }]]
    ];
    exports2.DescribeRouteTablesResult$ = [
      3,
      n032,
      _DRTRes,
      0,
      [_RTou, _NTe],
      [[() => RouteTableList, {
        [_eQN]: `RouteTableSet`,
        [_xN]: _rTS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeScheduledInstanceAvailabilityRequest$ = [
      3,
      n032,
      _DSIAR,
      0,
      [_FSSTR, _Rec, _DR, _Fi, _MR, _MSDIH, _MSDIHi, _NTe],
      [() => exports2.SlotDateTimeRangeRequest$, [() => exports2.ScheduledInstanceRecurrenceRequest$, 0], 2, [() => FilterList, { [_xN]: _Fil }], 1, 1, 1, 0],
      2
    ];
    exports2.DescribeScheduledInstanceAvailabilityResult$ = [
      3,
      n032,
      _DSIARe,
      0,
      [_NTe, _SIAS],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => ScheduledInstanceAvailabilitySet, {
        [_eQN]: `ScheduledInstanceAvailabilitySet`,
        [_xN]: _sIAS
      }]]
    ];
    exports2.DescribeScheduledInstancesRequest$ = [
      3,
      n032,
      _DSIR,
      0,
      [_DR, _Fi, _MR, _NTe, _SIIc, _SSTR],
      [2, [() => FilterList, { [_xN]: _Fil }], 1, 0, [() => ScheduledInstanceIdRequestSet, { [_xN]: _SIIch }], () => exports2.SlotStartTimeRangeRequest$]
    ];
    exports2.DescribeScheduledInstancesResult$ = [
      3,
      n032,
      _DSIRe,
      0,
      [_NTe, _SIS],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => ScheduledInstanceSet, {
        [_eQN]: `ScheduledInstanceSet`,
        [_xN]: _sIS
      }]]
    ];
    exports2.DescribeSecondaryInterfacesRequest$ = [
      3,
      n032,
      _DSIRes,
      0,
      [_DR, _Fi, _MR, _NTe, _SIIe],
      [2, [() => FilterList, { [_xN]: _Fil }], 1, 0, [() => SecondaryInterfaceIdList, { [_xN]: _SIIec }]]
    ];
    exports2.DescribeSecondaryInterfacesResult$ = [
      3,
      n032,
      _DSIResc,
      0,
      [_SIec, _NTe],
      [[() => SecondaryInterfaceList, {
        [_eQN]: `SecondaryInterfaceSet`,
        [_xN]: _sISe
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeSecondaryNetworksRequest$ = [
      3,
      n032,
      _DSNRes,
      0,
      [_DR, _Fi, _MR, _NTe, _SNIe],
      [2, [() => FilterList, { [_xN]: _Fil }], 1, 0, [() => SecondaryNetworkIdList, { [_xN]: _SNI }]]
    ];
    exports2.DescribeSecondaryNetworksResult$ = [
      3,
      n032,
      _DSNResc,
      0,
      [_SNec, _NTe],
      [[() => SecondaryNetworkList, {
        [_eQN]: `SecondaryNetworkSet`,
        [_xN]: _sNS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeSecondarySubnetsRequest$ = [
      3,
      n032,
      _DSSRes,
      0,
      [_DR, _Fi, _MR, _NTe, _SSIec],
      [2, [() => FilterList, { [_xN]: _Fil }], 1, 0, [() => SecondarySubnetIdList, { [_xN]: _SSIe }]]
    ];
    exports2.DescribeSecondarySubnetsResult$ = [
      3,
      n032,
      _DSSResc,
      0,
      [_SSe, _NTe],
      [[() => SecondarySubnetList, {
        [_eQN]: `SecondarySubnetSet`,
        [_xN]: _sSS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeSecurityGroupReferencesRequest$ = [
      3,
      n032,
      _DSGRR,
      0,
      [_GIr, _DR],
      [[() => GroupIds, 0], 2],
      1
    ];
    exports2.DescribeSecurityGroupReferencesResult$ = [
      3,
      n032,
      _DSGRRe,
      0,
      [_SGRSe],
      [[() => SecurityGroupReferences, {
        [_eQN]: `SecurityGroupReferenceSet`,
        [_xN]: _sGRSe
      }]]
    ];
    exports2.DescribeSecurityGroupRulesRequest$ = [
      3,
      n032,
      _DSGRRes,
      0,
      [_Fi, _SGRI, _DR, _NTe, _MR],
      [[() => FilterList, { [_xN]: _Fil }], [() => SecurityGroupRuleIdList, { [_xN]: _SGRIe }], 2, 0, 1]
    ];
    exports2.DescribeSecurityGroupRulesResult$ = [
      3,
      n032,
      _DSGRResc,
      0,
      [_SGR, _NTe],
      [[() => SecurityGroupRuleList, {
        [_eQN]: `SecurityGroupRuleSet`,
        [_xN]: _sGRS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeSecurityGroupsRequest$ = [
      3,
      n032,
      _DSGRes,
      0,
      [_GIro, _GNr, _NTe, _MR, _DR, _Fi],
      [[() => GroupIdStringList, { [_xN]: _GIr }], [() => GroupNameStringList, { [_xN]: _GN }], 0, 1, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => FilterList, { [_xN]: _Fil }]]
    ];
    exports2.DescribeSecurityGroupsResult$ = [
      3,
      n032,
      _DSGResc,
      0,
      [_NTe, _SGe],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => SecurityGroupList, {
        [_eQN]: `SecurityGroupInfo`,
        [_xN]: _sGIec
      }]]
    ];
    exports2.DescribeSecurityGroupVpcAssociationsRequest$ = [
      3,
      n032,
      _DSGVAR,
      0,
      [_Fi, _NTe, _MR, _DR],
      [[() => FilterList, { [_xN]: _Fil }], 0, 1, 2]
    ];
    exports2.DescribeSecurityGroupVpcAssociationsResult$ = [
      3,
      n032,
      _DSGVARe,
      0,
      [_SGVA, _NTe],
      [[() => SecurityGroupVpcAssociationList, {
        [_eQN]: `SecurityGroupVpcAssociationSet`,
        [_xN]: _sGVAS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeServiceLinkVirtualInterfacesRequest$ = [
      3,
      n032,
      _DSLVIR,
      0,
      [_SLVII, _Fi, _MR, _NTe, _DR],
      [[() => ServiceLinkVirtualInterfaceIdSet, { [_xN]: _SLVIIe }], [() => FilterList, { [_xN]: _Fil }], 1, 0, 2]
    ];
    exports2.DescribeServiceLinkVirtualInterfacesResult$ = [
      3,
      n032,
      _DSLVIRe,
      0,
      [_SLVI, _NTe],
      [[() => ServiceLinkVirtualInterfaceSet, {
        [_eQN]: `ServiceLinkVirtualInterfaceSet`,
        [_xN]: _sLVIS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeSnapshotAttributeRequest$ = [
      3,
      n032,
      _DSAR,
      0,
      [_At, _SIn, _DR],
      [0, 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      2
    ];
    exports2.DescribeSnapshotAttributeResult$ = [
      3,
      n032,
      _DSARe,
      0,
      [_PCro, _SIn, _CVPr],
      [[() => ProductCodeList, {
        [_eQN]: `ProductCodes`,
        [_xN]: _pC
      }], [0, {
        [_eQN]: `SnapshotId`,
        [_xN]: _sIn
      }], [() => CreateVolumePermissionList, {
        [_eQN]: `CreateVolumePermission`,
        [_xN]: _cVP
      }]]
    ];
    exports2.DescribeSnapshotsRequest$ = [
      3,
      n032,
      _DSRes,
      0,
      [_MR, _NTe, _OIw, _RBUI, _SIna, _DR, _Fi],
      [1, 0, [() => OwnerStringList, { [_xN]: _Own }], [64 | 0, { [_xN]: _RBe }], [() => SnapshotIdStringList, { [_xN]: _SIn }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => FilterList, { [_xN]: _Fil }]]
    ];
    exports2.DescribeSnapshotsResult$ = [
      3,
      n032,
      _DSResc,
      0,
      [_NTe, _Sn],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => SnapshotList, {
        [_eQN]: `SnapshotSet`,
        [_xN]: _sSn
      }]]
    ];
    exports2.DescribeSnapshotTierStatusRequest$ = [
      3,
      n032,
      _DSTSR,
      0,
      [_Fi, _DR, _NTe, _MR],
      [[() => FilterList, { [_xN]: _Fil }], 2, 0, 1]
    ];
    exports2.DescribeSnapshotTierStatusResult$ = [
      3,
      n032,
      _DSTSRe,
      0,
      [_STS, _NTe],
      [[() => snapshotTierStatusSet, {
        [_eQN]: `SnapshotTierStatusSet`,
        [_xN]: _sTSS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeSpotDatafeedSubscriptionRequest$ = [
      3,
      n032,
      _DSDSRe,
      0,
      [_DR],
      [[2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]]
    ];
    exports2.DescribeSpotDatafeedSubscriptionResult$ = [
      3,
      n032,
      _DSDSRes,
      0,
      [_SDS],
      [[() => exports2.SpotDatafeedSubscription$, {
        [_eQN]: `SpotDatafeedSubscription`,
        [_xN]: _sDS
      }]]
    ];
    exports2.DescribeSpotFleetInstancesRequest$ = [
      3,
      n032,
      _DSFIR,
      0,
      [_SFRI, _DR, _NTe, _MR],
      [[0, {
        [_eQN]: `SpotFleetRequestId`,
        [_xN]: _sFRI
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [1, {
        [_eQN]: `MaxResults`,
        [_xN]: _mR
      }]],
      1
    ];
    exports2.DescribeSpotFleetInstancesResponse$ = [
      3,
      n032,
      _DSFIRe,
      0,
      [_AIct, _NTe, _SFRI],
      [[() => ActiveInstanceSet, {
        [_eQN]: `ActiveInstanceSet`,
        [_xN]: _aIS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [0, {
        [_eQN]: `SpotFleetRequestId`,
        [_xN]: _sFRI
      }]]
    ];
    exports2.DescribeSpotFleetRequestHistoryRequest$ = [
      3,
      n032,
      _DSFRHR,
      0,
      [_SFRI, _ST11, _DR, _ETv, _NTe, _MR],
      [[0, {
        [_eQN]: `SpotFleetRequestId`,
        [_xN]: _sFRI
      }], [4, {
        [_eQN]: `StartTime`,
        [_xN]: _sT19
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [0, {
        [_eQN]: `EventType`,
        [_xN]: _eTv
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [1, {
        [_eQN]: `MaxResults`,
        [_xN]: _mR
      }]],
      2
    ];
    exports2.DescribeSpotFleetRequestHistoryResponse$ = [
      3,
      n032,
      _DSFRHRe,
      0,
      [_HRi, _LET, _NTe, _SFRI, _ST11],
      [[() => HistoryRecords, {
        [_eQN]: `HistoryRecordSet`,
        [_xN]: _hRS
      }], [4, {
        [_eQN]: `LastEvaluatedTime`,
        [_xN]: _lET
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [0, {
        [_eQN]: `SpotFleetRequestId`,
        [_xN]: _sFRI
      }], [4, {
        [_eQN]: `StartTime`,
        [_xN]: _sT19
      }]]
    ];
    exports2.DescribeSpotFleetRequestsRequest$ = [
      3,
      n032,
      _DSFRR,
      0,
      [_DR, _SFRIp, _NTe, _MR],
      [[2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => SpotFleetRequestIdList, {
        [_eQN]: `SpotFleetRequestId`,
        [_xN]: _sFRI
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [1, {
        [_eQN]: `MaxResults`,
        [_xN]: _mR
      }]]
    ];
    exports2.DescribeSpotFleetRequestsResponse$ = [
      3,
      n032,
      _DSFRRe,
      0,
      [_NTe, _SFRC],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => SpotFleetRequestConfigSet, {
        [_eQN]: `SpotFleetRequestConfigSet`,
        [_xN]: _sFRCS
      }]]
    ];
    exports2.DescribeSpotInstanceRequestsRequest$ = [
      3,
      n032,
      _DSIRR,
      0,
      [_NTe, _MR, _DR, _SIRIp, _Fi],
      [0, 1, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => SpotInstanceRequestIdList, { [_xN]: _SIRI }], [() => FilterList, { [_xN]: _Fil }]]
    ];
    exports2.DescribeSpotInstanceRequestsResult$ = [
      3,
      n032,
      _DSIRRe,
      0,
      [_SIR, _NTe],
      [[() => SpotInstanceRequestList, {
        [_eQN]: `SpotInstanceRequestSet`,
        [_xN]: _sIRS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeSpotPriceHistoryRequest$ = [
      3,
      n032,
      _DSPHR,
      0,
      [_AZI, _DR, _ST11, _ETnd, _ITnst, _PDro, _Fi, _AZ, _MR, _NTe],
      [0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [4, {
        [_eQN]: `StartTime`,
        [_xN]: _sT19
      }], [4, {
        [_eQN]: `EndTime`,
        [_xN]: _eTn
      }], [64 | 0, { [_xN]: _IT4 }], [64 | 0, { [_xN]: _PDr }], [() => FilterList, { [_xN]: _Fil }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [1, {
        [_eQN]: `MaxResults`,
        [_xN]: _mR
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeSpotPriceHistoryResult$ = [
      3,
      n032,
      _DSPHRe,
      0,
      [_NTe, _SPH],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => SpotPriceHistoryList, {
        [_eQN]: `SpotPriceHistorySet`,
        [_xN]: _sPHS
      }]]
    ];
    exports2.DescribeStaleSecurityGroupsRequest$ = [
      3,
      n032,
      _DSSGR,
      0,
      [_VI, _DR, _MR, _NTe],
      [0, 2, 1, 0],
      1
    ];
    exports2.DescribeStaleSecurityGroupsResult$ = [
      3,
      n032,
      _DSSGRe,
      0,
      [_NTe, _SSGS],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => StaleSecurityGroupSet, {
        [_eQN]: `StaleSecurityGroupSet`,
        [_xN]: _sSGS
      }]]
    ];
    exports2.DescribeStoreImageTasksRequest$ = [
      3,
      n032,
      _DSITR,
      0,
      [_IIma, _DR, _Fi, _NTe, _MR],
      [[() => ImageIdList, { [_xN]: _IIm }], 2, [() => FilterList, { [_xN]: _Fil }], 0, 1]
    ];
    exports2.DescribeStoreImageTasksResult$ = [
      3,
      n032,
      _DSITRe,
      0,
      [_SITR, _NTe],
      [[() => StoreImageTaskResultSet, {
        [_eQN]: `StoreImageTaskResultSet`,
        [_xN]: _sITRS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeSubnetsRequest$ = [
      3,
      n032,
      _DSRescr,
      0,
      [_Fi, _SI10, _NTe, _MR, _DR],
      [[() => FilterList, { [_xN]: _Fil }], [() => SubnetIdStringList, { [_xN]: _SIu }], 0, 1, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]]
    ];
    exports2.DescribeSubnetsResult$ = [
      3,
      n032,
      _DSRescri,
      0,
      [_NTe, _Subn],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => SubnetList, {
        [_eQN]: `SubnetSet`,
        [_xN]: _sSub
      }]]
    ];
    exports2.DescribeTagsRequest$ = [
      3,
      n032,
      _DTRe,
      0,
      [_DR, _Fi, _MR, _NTe],
      [[2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => FilterList, { [_xN]: _Fil }], [1, {
        [_eQN]: `MaxResults`,
        [_xN]: _mR
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeTagsResult$ = [
      3,
      n032,
      _DTRes,
      0,
      [_NTe, _T10],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => TagDescriptionList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.DescribeTrafficMirrorFilterRulesRequest$ = [
      3,
      n032,
      _DTMFRRes,
      0,
      [_TMFRIr, _TMFI, _DR, _Fi, _MR, _NTe],
      [[() => TrafficMirrorFilterRuleIdList, { [_xN]: _TMFRI }], 0, 2, [() => FilterList, { [_xN]: _Fil }], 1, 0]
    ];
    exports2.DescribeTrafficMirrorFilterRulesResult$ = [
      3,
      n032,
      _DTMFRResc,
      0,
      [_TMFRr, _NTe],
      [[() => TrafficMirrorFilterRuleSet, {
        [_eQN]: `TrafficMirrorFilterRuleSet`,
        [_xN]: _tMFRS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeTrafficMirrorFiltersRequest$ = [
      3,
      n032,
      _DTMFRes,
      0,
      [_TMFIr, _DR, _Fi, _MR, _NTe],
      [[() => TrafficMirrorFilterIdList, { [_xN]: _TMFI }], 2, [() => FilterList, { [_xN]: _Fil }], 1, 0]
    ];
    exports2.DescribeTrafficMirrorFiltersResult$ = [
      3,
      n032,
      _DTMFResc,
      0,
      [_TMFr, _NTe],
      [[() => TrafficMirrorFilterSet, {
        [_eQN]: `TrafficMirrorFilterSet`,
        [_xN]: _tMFS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeTrafficMirrorSessionsRequest$ = [
      3,
      n032,
      _DTMSRes,
      0,
      [_TMSIr, _DR, _Fi, _MR, _NTe],
      [[() => TrafficMirrorSessionIdList, { [_xN]: _TMSI }], 2, [() => FilterList, { [_xN]: _Fil }], 1, 0]
    ];
    exports2.DescribeTrafficMirrorSessionsResult$ = [
      3,
      n032,
      _DTMSResc,
      0,
      [_TMSr, _NTe],
      [[() => TrafficMirrorSessionSet, {
        [_eQN]: `TrafficMirrorSessionSet`,
        [_xN]: _tMSS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeTrafficMirrorTargetsRequest$ = [
      3,
      n032,
      _DTMTRes,
      0,
      [_TMTIr, _DR, _Fi, _MR, _NTe],
      [[() => TrafficMirrorTargetIdList, { [_xN]: _TMTI }], 2, [() => FilterList, { [_xN]: _Fil }], 1, 0]
    ];
    exports2.DescribeTrafficMirrorTargetsResult$ = [
      3,
      n032,
      _DTMTResc,
      0,
      [_TMTr, _NTe],
      [[() => TrafficMirrorTargetSet, {
        [_eQN]: `TrafficMirrorTargetSet`,
        [_xN]: _tMTS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeTransitGatewayAttachmentsRequest$ = [
      3,
      n032,
      _DTGAR,
      0,
      [_TGAIr, _Fi, _MR, _NTe, _DR],
      [64 | 0, [() => FilterList, { [_xN]: _Fil }], 1, 0, 2]
    ];
    exports2.DescribeTransitGatewayAttachmentsResult$ = [
      3,
      n032,
      _DTGARe,
      0,
      [_TGAr, _NTe],
      [[() => TransitGatewayAttachmentList, {
        [_eQN]: `TransitGatewayAttachments`,
        [_xN]: _tGA
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeTransitGatewayConnectPeersRequest$ = [
      3,
      n032,
      _DTGCPRes,
      0,
      [_TGCPIr, _Fi, _MR, _NTe, _DR],
      [[() => TransitGatewayConnectPeerIdStringList, 0], [() => FilterList, { [_xN]: _Fil }], 1, 0, 2]
    ];
    exports2.DescribeTransitGatewayConnectPeersResult$ = [
      3,
      n032,
      _DTGCPResc,
      0,
      [_TGCPr, _NTe],
      [[() => TransitGatewayConnectPeerList, {
        [_eQN]: `TransitGatewayConnectPeerSet`,
        [_xN]: _tGCPS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeTransitGatewayConnectsRequest$ = [
      3,
      n032,
      _DTGCRes,
      0,
      [_TGAIr, _Fi, _MR, _NTe, _DR],
      [64 | 0, [() => FilterList, { [_xN]: _Fil }], 1, 0, 2]
    ];
    exports2.DescribeTransitGatewayConnectsResult$ = [
      3,
      n032,
      _DTGCResc,
      0,
      [_TGCra, _NTe],
      [[() => TransitGatewayConnectList, {
        [_eQN]: `TransitGatewayConnectSet`,
        [_xN]: _tGCS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeTransitGatewayMeteringPoliciesRequest$ = [
      3,
      n032,
      _DTGMPRes,
      0,
      [_TGMPIr, _Fi, _MR, _NTe, _DR],
      [[() => TransitGatewayMeteringPolicyIdStringList, 0], [() => FilterList, { [_xN]: _Fil }], 1, 0, 2]
    ];
    exports2.DescribeTransitGatewayMeteringPoliciesResult$ = [
      3,
      n032,
      _DTGMPResc,
      0,
      [_TGMPr, _NTe],
      [[() => TransitGatewayMeteringPolicyList, {
        [_eQN]: `TransitGatewayMeteringPolicies`,
        [_xN]: _tGMPr
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeTransitGatewayMulticastDomainsRequest$ = [
      3,
      n032,
      _DTGMDRes,
      0,
      [_TGMDIr, _Fi, _MR, _NTe, _DR],
      [[() => TransitGatewayMulticastDomainIdStringList, 0], [() => FilterList, { [_xN]: _Fil }], 1, 0, 2]
    ];
    exports2.DescribeTransitGatewayMulticastDomainsResult$ = [
      3,
      n032,
      _DTGMDResc,
      0,
      [_TGMDr, _NTe],
      [[() => TransitGatewayMulticastDomainList, {
        [_eQN]: `TransitGatewayMulticastDomains`,
        [_xN]: _tGMDr
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeTransitGatewayPeeringAttachmentsRequest$ = [
      3,
      n032,
      _DTGPARes,
      0,
      [_TGAIr, _Fi, _MR, _NTe, _DR],
      [64 | 0, [() => FilterList, { [_xN]: _Fil }], 1, 0, 2]
    ];
    exports2.DescribeTransitGatewayPeeringAttachmentsResult$ = [
      3,
      n032,
      _DTGPAResc,
      0,
      [_TGPAr, _NTe],
      [[() => TransitGatewayPeeringAttachmentList, {
        [_eQN]: `TransitGatewayPeeringAttachments`,
        [_xN]: _tGPAr
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeTransitGatewayPolicyTablesRequest$ = [
      3,
      n032,
      _DTGPTRes,
      0,
      [_TGPTIr, _Fi, _MR, _NTe, _DR],
      [[() => TransitGatewayPolicyTableIdStringList, 0], [() => FilterList, { [_xN]: _Fil }], 1, 0, 2]
    ];
    exports2.DescribeTransitGatewayPolicyTablesResult$ = [
      3,
      n032,
      _DTGPTResc,
      0,
      [_TGPTr, _NTe],
      [[() => TransitGatewayPolicyTableList, {
        [_eQN]: `TransitGatewayPolicyTables`,
        [_xN]: _tGPTr
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeTransitGatewayRouteTableAnnouncementsRequest$ = [
      3,
      n032,
      _DTGRTARes,
      0,
      [_TGRTAIr, _Fi, _MR, _NTe, _DR],
      [[() => TransitGatewayRouteTableAnnouncementIdStringList, 0], [() => FilterList, { [_xN]: _Fil }], 1, 0, 2]
    ];
    exports2.DescribeTransitGatewayRouteTableAnnouncementsResult$ = [
      3,
      n032,
      _DTGRTAResc,
      0,
      [_TGRTAr, _NTe],
      [[() => TransitGatewayRouteTableAnnouncementList, {
        [_eQN]: `TransitGatewayRouteTableAnnouncements`,
        [_xN]: _tGRTAr
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeTransitGatewayRouteTablesRequest$ = [
      3,
      n032,
      _DTGRTRes,
      0,
      [_TGRTIr, _Fi, _MR, _NTe, _DR],
      [[() => TransitGatewayRouteTableIdStringList, 0], [() => FilterList, { [_xN]: _Fil }], 1, 0, 2]
    ];
    exports2.DescribeTransitGatewayRouteTablesResult$ = [
      3,
      n032,
      _DTGRTResc,
      0,
      [_TGRTr, _NTe],
      [[() => TransitGatewayRouteTableList, {
        [_eQN]: `TransitGatewayRouteTables`,
        [_xN]: _tGRTr
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeTransitGatewaysRequest$ = [
      3,
      n032,
      _DTGRes,
      0,
      [_TGIr, _Fi, _MR, _NTe, _DR],
      [[() => TransitGatewayIdStringList, 0], [() => FilterList, { [_xN]: _Fil }], 1, 0, 2]
    ];
    exports2.DescribeTransitGatewaysResult$ = [
      3,
      n032,
      _DTGResc,
      0,
      [_TGr, _NTe],
      [[() => TransitGatewayList, {
        [_eQN]: `TransitGatewaySet`,
        [_xN]: _tGS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeTransitGatewayVpcAttachmentsRequest$ = [
      3,
      n032,
      _DTGVARes,
      0,
      [_TGAIr, _Fi, _MR, _NTe, _DR],
      [64 | 0, [() => FilterList, { [_xN]: _Fil }], 1, 0, 2]
    ];
    exports2.DescribeTransitGatewayVpcAttachmentsResult$ = [
      3,
      n032,
      _DTGVAResc,
      0,
      [_TGVAr, _NTe],
      [[() => TransitGatewayVpcAttachmentList, {
        [_eQN]: `TransitGatewayVpcAttachments`,
        [_xN]: _tGVAr
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeTrunkInterfaceAssociationsRequest$ = [
      3,
      n032,
      _DTIAR,
      0,
      [_AIsso, _DR, _Fi, _NTe, _MR],
      [[() => TrunkInterfaceAssociationIdList, { [_xN]: _AIs }], 2, [() => FilterList, { [_xN]: _Fil }], 0, 1]
    ];
    exports2.DescribeTrunkInterfaceAssociationsResult$ = [
      3,
      n032,
      _DTIARe,
      0,
      [_IAnt, _NTe],
      [[() => TrunkInterfaceAssociationList, {
        [_eQN]: `InterfaceAssociationSet`,
        [_xN]: _iAS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeVerifiedAccessEndpointsRequest$ = [
      3,
      n032,
      _DVAERes,
      0,
      [_VAEIe, _VAII, _VAGI, _MR, _NTe, _Fi, _DR],
      [[() => VerifiedAccessEndpointIdList, { [_xN]: _VAEI }], 0, 0, 1, 0, [() => FilterList, { [_xN]: _Fil }], 2]
    ];
    exports2.DescribeVerifiedAccessEndpointsResult$ = [
      3,
      n032,
      _DVAEResc,
      0,
      [_VAEe, _NTe],
      [[() => VerifiedAccessEndpointList, {
        [_eQN]: `VerifiedAccessEndpointSet`,
        [_xN]: _vAES
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeVerifiedAccessGroupsRequest$ = [
      3,
      n032,
      _DVAGRes,
      0,
      [_VAGIe, _VAII, _MR, _NTe, _Fi, _DR],
      [[() => VerifiedAccessGroupIdList, { [_xN]: _VAGI }], 0, 1, 0, [() => FilterList, { [_xN]: _Fil }], 2]
    ];
    exports2.DescribeVerifiedAccessGroupsResult$ = [
      3,
      n032,
      _DVAGResc,
      0,
      [_VAGe, _NTe],
      [[() => VerifiedAccessGroupList, {
        [_eQN]: `VerifiedAccessGroupSet`,
        [_xN]: _vAGS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeVerifiedAccessInstanceLoggingConfigurationsRequest$ = [
      3,
      n032,
      _DVAILCR,
      0,
      [_VAIIe, _MR, _NTe, _Fi, _DR],
      [[() => VerifiedAccessInstanceIdList, { [_xN]: _VAII }], 1, 0, [() => FilterList, { [_xN]: _Fil }], 2]
    ];
    exports2.DescribeVerifiedAccessInstanceLoggingConfigurationsResult$ = [
      3,
      n032,
      _DVAILCRe,
      0,
      [_LC, _NTe],
      [[() => VerifiedAccessInstanceLoggingConfigurationList, {
        [_eQN]: `LoggingConfigurationSet`,
        [_xN]: _lCS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeVerifiedAccessInstancesRequest$ = [
      3,
      n032,
      _DVAIRes,
      0,
      [_VAIIe, _MR, _NTe, _Fi, _DR],
      [[() => VerifiedAccessInstanceIdList, { [_xN]: _VAII }], 1, 0, [() => FilterList, { [_xN]: _Fil }], 2]
    ];
    exports2.DescribeVerifiedAccessInstancesResult$ = [
      3,
      n032,
      _DVAIResc,
      0,
      [_VAIe, _NTe],
      [[() => VerifiedAccessInstanceList, {
        [_eQN]: `VerifiedAccessInstanceSet`,
        [_xN]: _vAIS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeVerifiedAccessTrustProvidersRequest$ = [
      3,
      n032,
      _DVATPRes,
      0,
      [_VATPIe, _MR, _NTe, _Fi, _DR],
      [[() => VerifiedAccessTrustProviderIdList, { [_xN]: _VATPI }], 1, 0, [() => FilterList, { [_xN]: _Fil }], 2]
    ];
    exports2.DescribeVerifiedAccessTrustProvidersResult$ = [
      3,
      n032,
      _DVATPResc,
      0,
      [_VATPe, _NTe],
      [[() => VerifiedAccessTrustProviderList, {
        [_eQN]: `VerifiedAccessTrustProviderSet`,
        [_xN]: _vATPS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeVolumeAttributeRequest$ = [
      3,
      n032,
      _DVAR,
      0,
      [_At, _VIo, _DR],
      [0, 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      2
    ];
    exports2.DescribeVolumeAttributeResult$ = [
      3,
      n032,
      _DVARe,
      0,
      [_AEIO, _PCro, _VIo],
      [[() => exports2.AttributeBooleanValue$, {
        [_eQN]: `AutoEnableIO`,
        [_xN]: _aEIO
      }], [() => ProductCodeList, {
        [_eQN]: `ProductCodes`,
        [_xN]: _pC
      }], [0, {
        [_eQN]: `VolumeId`,
        [_xN]: _vIo
      }]]
    ];
    exports2.DescribeVolumesModificationsRequest$ = [
      3,
      n032,
      _DVMR,
      0,
      [_DR, _VIol, _Fi, _NTe, _MR],
      [2, [() => VolumeIdStringList, { [_xN]: _VIo }], [() => FilterList, { [_xN]: _Fil }], 0, 1]
    ];
    exports2.DescribeVolumesModificationsResult$ = [
      3,
      n032,
      _DVMRe,
      0,
      [_NTe, _VM],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => VolumeModificationList, {
        [_eQN]: `VolumeModificationSet`,
        [_xN]: _vMS
      }]]
    ];
    exports2.DescribeVolumesRequest$ = [
      3,
      n032,
      _DVRes,
      0,
      [_VIol, _IMR, _DR, _Fi, _NTe, _MR],
      [[() => VolumeIdStringList, { [_xN]: _VIo }], 2, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => FilterList, { [_xN]: _Fil }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [1, {
        [_eQN]: `MaxResults`,
        [_xN]: _mR
      }]]
    ];
    exports2.DescribeVolumesResult$ = [
      3,
      n032,
      _DVResc,
      0,
      [_NTe, _Vo],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => VolumeList, {
        [_eQN]: `VolumeSet`,
        [_xN]: _vS
      }]]
    ];
    exports2.DescribeVolumeStatusRequest$ = [
      3,
      n032,
      _DVSR,
      0,
      [_MR, _NTe, _VIol, _IMR, _DR, _Fi],
      [1, 0, [() => VolumeIdStringList, { [_xN]: _VIo }], 2, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => FilterList, { [_xN]: _Fil }]]
    ];
    exports2.DescribeVolumeStatusResult$ = [
      3,
      n032,
      _DVSRe,
      0,
      [_NTe, _VS],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => VolumeStatusList, {
        [_eQN]: `VolumeStatusSet`,
        [_xN]: _vSS
      }]]
    ];
    exports2.DescribeVpcAttributeRequest$ = [
      3,
      n032,
      _DVARes,
      0,
      [_At, _VI, _DR],
      [0, 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      2
    ];
    exports2.DescribeVpcAttributeResult$ = [
      3,
      n032,
      _DVAResc,
      0,
      [_EDH, _EDS, _ENAUM, _VI],
      [[() => exports2.AttributeBooleanValue$, {
        [_eQN]: `EnableDnsHostnames`,
        [_xN]: _eDH
      }], [() => exports2.AttributeBooleanValue$, {
        [_eQN]: `EnableDnsSupport`,
        [_xN]: _eDS
      }], [() => exports2.AttributeBooleanValue$, {
        [_eQN]: `EnableNetworkAddressUsageMetrics`,
        [_xN]: _eNAUM
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }]]
    ];
    exports2.DescribeVpcBlockPublicAccessExclusionsRequest$ = [
      3,
      n032,
      _DVBPAERes,
      0,
      [_DR, _Fi, _EIxc, _NTe, _MR],
      [2, [() => FilterList, { [_xN]: _Fil }], [() => VpcBlockPublicAccessExclusionIdList, { [_xN]: _EIx }], 0, 1]
    ];
    exports2.DescribeVpcBlockPublicAccessExclusionsResult$ = [
      3,
      n032,
      _DVBPAEResc,
      0,
      [_VBPAEp, _NTe],
      [[() => VpcBlockPublicAccessExclusionList, {
        [_eQN]: `VpcBlockPublicAccessExclusionSet`,
        [_xN]: _vBPAES
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeVpcBlockPublicAccessOptionsRequest$ = [
      3,
      n032,
      _DVBPAOR,
      0,
      [_DR],
      [2]
    ];
    exports2.DescribeVpcBlockPublicAccessOptionsResult$ = [
      3,
      n032,
      _DVBPAORe,
      0,
      [_VBPAO],
      [[() => exports2.VpcBlockPublicAccessOptions$, {
        [_eQN]: `VpcBlockPublicAccessOptions`,
        [_xN]: _vBPAO
      }]]
    ];
    exports2.DescribeVpcClassicLinkDnsSupportRequest$ = [
      3,
      n032,
      _DVCLDSR,
      0,
      [_VIp, _MR, _NTe],
      [[() => VpcClassicLinkIdList, { [_xN]: _VIp }], [1, {
        [_eQN]: `MaxResults`,
        [_xN]: _mR
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeVpcClassicLinkDnsSupportResult$ = [
      3,
      n032,
      _DVCLDSRe,
      0,
      [_NTe, _Vpc],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => ClassicLinkDnsSupportList, {
        [_eQN]: `Vpcs`,
        [_xN]: _vpc
      }]]
    ];
    exports2.DescribeVpcClassicLinkRequest$ = [
      3,
      n032,
      _DVCLR,
      0,
      [_DR, _VIp, _Fi],
      [[2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => VpcClassicLinkIdList, { [_xN]: _VI }], [() => FilterList, { [_xN]: _Fil }]]
    ];
    exports2.DescribeVpcClassicLinkResult$ = [
      3,
      n032,
      _DVCLRe,
      0,
      [_Vpc],
      [[() => VpcClassicLinkList, {
        [_eQN]: `VpcSet`,
        [_xN]: _vSp
      }]]
    ];
    exports2.DescribeVpcEncryptionControlsRequest$ = [
      3,
      n032,
      _DVECRes,
      0,
      [_DR, _Fi, _VECIp, _VIp, _NTe, _MR],
      [2, [() => FilterList, { [_xN]: _Fil }], [() => VpcEncryptionControlIdList, { [_xN]: _VECI }], [() => VpcIdStringList, { [_xN]: _VI }], 0, 1]
    ];
    exports2.DescribeVpcEncryptionControlsResult$ = [
      3,
      n032,
      _DVECResc,
      0,
      [_VECp, _NTe],
      [[() => VpcEncryptionControlList, {
        [_eQN]: `VpcEncryptionControlSet`,
        [_xN]: _vECS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeVpcEndpointAssociationsRequest$ = [
      3,
      n032,
      _DVEAR,
      0,
      [_DR, _VEI, _Fi, _MR, _NTe],
      [2, [() => VpcEndpointIdList, { [_xN]: _VEIp }], [() => FilterList, { [_xN]: _Fil }], 1, 0]
    ];
    exports2.DescribeVpcEndpointAssociationsResult$ = [
      3,
      n032,
      _DVEARe,
      0,
      [_VEA, _NTe],
      [[() => VpcEndpointAssociationSet, {
        [_eQN]: `VpcEndpointAssociationSet`,
        [_xN]: _vEAS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeVpcEndpointConnectionNotificationsRequest$ = [
      3,
      n032,
      _DVECNRes,
      0,
      [_DR, _CNI, _Fi, _MR, _NTe],
      [2, 0, [() => FilterList, { [_xN]: _Fil }], 1, 0]
    ];
    exports2.DescribeVpcEndpointConnectionNotificationsResult$ = [
      3,
      n032,
      _DVECNResc,
      0,
      [_CNSo, _NTe],
      [[() => ConnectionNotificationSet, {
        [_eQN]: `ConnectionNotificationSet`,
        [_xN]: _cNSo
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeVpcEndpointConnectionsRequest$ = [
      3,
      n032,
      _DVECRescr,
      0,
      [_DR, _Fi, _MR, _NTe],
      [2, [() => FilterList, { [_xN]: _Fil }], 1, 0]
    ];
    exports2.DescribeVpcEndpointConnectionsResult$ = [
      3,
      n032,
      _DVECRescri,
      0,
      [_VECpc, _NTe],
      [[() => VpcEndpointConnectionSet, {
        [_eQN]: `VpcEndpointConnectionSet`,
        [_xN]: _vECSp
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeVpcEndpointServiceConfigurationsRequest$ = [
      3,
      n032,
      _DVESCRes,
      0,
      [_DR, _SIer, _Fi, _MR, _NTe],
      [2, [() => VpcEndpointServiceIdList, { [_xN]: _SIe }], [() => FilterList, { [_xN]: _Fil }], 1, 0]
    ];
    exports2.DescribeVpcEndpointServiceConfigurationsResult$ = [
      3,
      n032,
      _DVESCResc,
      0,
      [_SCer, _NTe],
      [[() => ServiceConfigurationSet, {
        [_eQN]: `ServiceConfigurationSet`,
        [_xN]: _sCS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeVpcEndpointServicePermissionsRequest$ = [
      3,
      n032,
      _DVESPR,
      0,
      [_SIe, _DR, _Fi, _MR, _NTe],
      [0, 2, [() => FilterList, { [_xN]: _Fil }], 1, 0],
      1
    ];
    exports2.DescribeVpcEndpointServicePermissionsResult$ = [
      3,
      n032,
      _DVESPRe,
      0,
      [_APll, _NTe],
      [[() => AllowedPrincipalSet, {
        [_eQN]: `AllowedPrincipals`,
        [_xN]: _aPl
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeVpcEndpointServicesRequest$ = [
      3,
      n032,
      _DVESR,
      0,
      [_DR, _SNer, _Fi, _MR, _NTe, _SRe],
      [2, [() => ValueStringList, { [_xN]: _SN10 }], [() => FilterList, { [_xN]: _Fil }], 1, 0, [() => ValueStringList, { [_xN]: _SR }]]
    ];
    exports2.DescribeVpcEndpointServicesResult$ = [
      3,
      n032,
      _DVESRe,
      0,
      [_SNer, _SDe, _NTe],
      [[() => ValueStringList, {
        [_eQN]: `ServiceNameSet`,
        [_xN]: _sNSe
      }], [() => ServiceDetailSet, {
        [_eQN]: `ServiceDetailSet`,
        [_xN]: _sDSe
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeVpcEndpointsRequest$ = [
      3,
      n032,
      _DVERes,
      0,
      [_DR, _VEI, _Fi, _MR, _NTe],
      [2, [() => VpcEndpointIdList, { [_xN]: _VEIp }], [() => FilterList, { [_xN]: _Fil }], 1, 0]
    ];
    exports2.DescribeVpcEndpointsResult$ = [
      3,
      n032,
      _DVEResc,
      0,
      [_VEp, _NTe],
      [[() => VpcEndpointSet, {
        [_eQN]: `VpcEndpointSet`,
        [_xN]: _vESp
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeVpcPeeringConnectionsRequest$ = [
      3,
      n032,
      _DVPCRes,
      0,
      [_NTe, _MR, _DR, _VPCIp, _Fi],
      [0, 1, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => VpcPeeringConnectionIdList, { [_xN]: _VPCI }], [() => FilterList, { [_xN]: _Fil }]]
    ];
    exports2.DescribeVpcPeeringConnectionsResult$ = [
      3,
      n032,
      _DVPCResc,
      0,
      [_VPCp, _NTe],
      [[() => VpcPeeringConnectionList, {
        [_eQN]: `VpcPeeringConnectionSet`,
        [_xN]: _vPCS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeVpcsRequest$ = [
      3,
      n032,
      _DVRescr,
      0,
      [_Fi, _VIp, _NTe, _MR, _DR],
      [[() => FilterList, { [_xN]: _Fil }], [() => VpcIdStringList, { [_xN]: _VI }], 0, 1, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]]
    ];
    exports2.DescribeVpcsResult$ = [
      3,
      n032,
      _DVRescri,
      0,
      [_NTe, _Vpc],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => VpcList, {
        [_eQN]: `VpcSet`,
        [_xN]: _vSp
      }]]
    ];
    exports2.DescribeVpnConcentratorsRequest$ = [
      3,
      n032,
      _DVCRes,
      0,
      [_VCIpn, _Fi, _MR, _NTe, _DR],
      [[() => VpnConcentratorIdStringList, { [_xN]: _VCI }], [() => FilterList, { [_xN]: _Fil }], 1, 0, 2]
    ];
    exports2.DescribeVpnConcentratorsResult$ = [
      3,
      n032,
      _DVCResc,
      0,
      [_VCpn, _NTe],
      [[() => VpnConcentratorList, {
        [_eQN]: `VpnConcentratorSet`,
        [_xN]: _vCS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.DescribeVpnConnectionsRequest$ = [
      3,
      n032,
      _DVCRescr,
      0,
      [_Fi, _VCIpno, _DR],
      [[() => FilterList, { [_xN]: _Fil }], [() => VpnConnectionIdStringList, { [_xN]: _VCIp }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]]
    ];
    exports2.DescribeVpnConnectionsResult$ = [
      3,
      n032,
      _DVCRescri,
      0,
      [_VCpno],
      [[() => VpnConnectionList, {
        [_eQN]: `VpnConnectionSet`,
        [_xN]: _vCSp
      }]]
    ];
    exports2.DescribeVpnGatewaysRequest$ = [
      3,
      n032,
      _DVGRe,
      0,
      [_Fi, _VGIp, _DR],
      [[() => FilterList, { [_xN]: _Fil }], [() => VpnGatewayIdStringList, { [_xN]: _VGI }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]]
    ];
    exports2.DescribeVpnGatewaysResult$ = [
      3,
      n032,
      _DVGRes,
      0,
      [_VGp],
      [[() => VpnGatewayList, {
        [_eQN]: `VpnGatewaySet`,
        [_xN]: _vGS
      }]]
    ];
    exports2.DestinationOptionsRequest$ = [
      3,
      n032,
      _DOR,
      0,
      [_FF, _HCP, _PHP],
      [0, 2, 2]
    ];
    exports2.DestinationOptionsResponse$ = [
      3,
      n032,
      _DORe,
      0,
      [_FF, _HCP, _PHP],
      [[0, {
        [_eQN]: `FileFormat`,
        [_xN]: _fF
      }], [2, {
        [_eQN]: `HiveCompatiblePartitions`,
        [_xN]: _hCP
      }], [2, {
        [_eQN]: `PerHourPartition`,
        [_xN]: _pHP
      }]]
    ];
    exports2.DetachClassicLinkVpcRequest$ = [
      3,
      n032,
      _DCLVR,
      0,
      [_II2, _VI, _DR],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      2
    ];
    exports2.DetachClassicLinkVpcResult$ = [
      3,
      n032,
      _DCLVRe,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.DetachInternetGatewayRequest$ = [
      3,
      n032,
      _DIGRet,
      0,
      [_IGI, _VI, _DR],
      [[0, {
        [_eQN]: `InternetGatewayId`,
        [_xN]: _iGI
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      2
    ];
    exports2.DetachNetworkInterfaceRequest$ = [
      3,
      n032,
      _DNIRet,
      0,
      [_AItt, _DR, _F],
      [[0, {
        [_eQN]: `AttachmentId`,
        [_xN]: _aIt
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [2, {
        [_eQN]: `Force`,
        [_xN]: _fo
      }]],
      1
    ];
    exports2.DetachVerifiedAccessTrustProviderRequest$ = [
      3,
      n032,
      _DVATPRet,
      0,
      [_VAII, _VATPI, _CT4, _DR],
      [0, 0, [0, 4], 2],
      2
    ];
    exports2.DetachVerifiedAccessTrustProviderResult$ = [
      3,
      n032,
      _DVATPReta,
      0,
      [_VATP, _VAI],
      [[() => exports2.VerifiedAccessTrustProvider$, {
        [_eQN]: `VerifiedAccessTrustProvider`,
        [_xN]: _vATP
      }], [() => exports2.VerifiedAccessInstance$, {
        [_eQN]: `VerifiedAccessInstance`,
        [_xN]: _vAI
      }]]
    ];
    exports2.DetachVolumeRequest$ = [
      3,
      n032,
      _DVRet,
      0,
      [_VIo, _Dev, _F, _II2, _DR],
      [0, 0, 2, 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.DetachVpnGatewayRequest$ = [
      3,
      n032,
      _DVGRet,
      0,
      [_VI, _VGI, _DR],
      [0, 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      2
    ];
    exports2.DeviceOptions$ = [
      3,
      n032,
      _DOev,
      0,
      [_TIe, _PSKU],
      [[0, {
        [_eQN]: `TenantId`,
        [_xN]: _tIe
      }], [0, {
        [_eQN]: `PublicSigningKeyUrl`,
        [_xN]: _pSKU
      }]]
    ];
    exports2.DhcpConfiguration$ = [
      3,
      n032,
      _DChc,
      0,
      [_K10, _Va],
      [[0, {
        [_eQN]: `Key`,
        [_xN]: _k
      }], [() => DhcpConfigurationValueList, {
        [_eQN]: `ValueSet`,
        [_xN]: _vSa
      }]]
    ];
    exports2.DhcpOptions$ = [
      3,
      n032,
      _DO,
      0,
      [_OI, _T10, _DOI, _DCh],
      [[0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `DhcpOptionsId`,
        [_xN]: _dOI
      }], [() => DhcpConfigurationList, {
        [_eQN]: `DhcpConfigurationSet`,
        [_xN]: _dCS
      }]]
    ];
    exports2.DimensionCondition$ = [
      3,
      n032,
      _DCim,
      0,
      [_Dim, _Comp, _Va],
      [0, 0, [() => ConditionValueList, { [_xN]: _V10 }]]
    ];
    exports2.DirectoryServiceAuthentication$ = [
      3,
      n032,
      _DSA,
      0,
      [_DIi],
      [[0, {
        [_eQN]: `DirectoryId`,
        [_xN]: _dIi
      }]]
    ];
    exports2.DirectoryServiceAuthenticationRequest$ = [
      3,
      n032,
      _DSARi,
      0,
      [_DIi],
      [0]
    ];
    exports2.DisableAddressTransferRequest$ = [
      3,
      n032,
      _DATRi,
      0,
      [_AIl, _DR],
      [0, 2],
      1
    ];
    exports2.DisableAddressTransferResult$ = [
      3,
      n032,
      _DATRis,
      0,
      [_AT13],
      [[() => exports2.AddressTransfer$, {
        [_eQN]: `AddressTransfer`,
        [_xN]: _aT22
      }]]
    ];
    exports2.DisableAllowedImagesSettingsRequest$ = [
      3,
      n032,
      _DAISR,
      0,
      [_DR],
      [2]
    ];
    exports2.DisableAllowedImagesSettingsResult$ = [
      3,
      n032,
      _DAISRi,
      0,
      [_AISS],
      [[0, {
        [_eQN]: `AllowedImagesSettingsState`,
        [_xN]: _aISS
      }]]
    ];
    exports2.DisableAwsNetworkPerformanceMetricSubscriptionRequest$ = [
      3,
      n032,
      _DANPMSRi,
      0,
      [_S, _D, _Met, _Stat, _DR],
      [0, 0, 0, 0, 2]
    ];
    exports2.DisableAwsNetworkPerformanceMetricSubscriptionResult$ = [
      3,
      n032,
      _DANPMSRis,
      0,
      [_Ou],
      [[2, {
        [_eQN]: `Output`,
        [_xN]: _ou
      }]]
    ];
    exports2.DisableCapacityManagerRequest$ = [
      3,
      n032,
      _DCMR,
      0,
      [_DR, _CT4],
      [2, [0, 4]]
    ];
    exports2.DisableCapacityManagerResult$ = [
      3,
      n032,
      _DCMRi,
      0,
      [_CMS, _OAr],
      [[0, {
        [_eQN]: `CapacityManagerStatus`,
        [_xN]: _cMS
      }], [2, {
        [_eQN]: `OrganizationsAccess`,
        [_xN]: _oAr
      }]]
    ];
    exports2.DisableEbsEncryptionByDefaultRequest$ = [
      3,
      n032,
      _DEEBDR,
      0,
      [_DR],
      [2]
    ];
    exports2.DisableEbsEncryptionByDefaultResult$ = [
      3,
      n032,
      _DEEBDRi,
      0,
      [_EEBD],
      [[2, {
        [_eQN]: `EbsEncryptionByDefault`,
        [_xN]: _eEBD
      }]]
    ];
    exports2.DisableFastLaunchRequest$ = [
      3,
      n032,
      _DFLRi,
      0,
      [_IIm, _F, _DR],
      [0, 2, 2],
      1
    ];
    exports2.DisableFastLaunchResult$ = [
      3,
      n032,
      _DFLRis,
      0,
      [_IIm, _RTe, _SCn, _LT, _MPL, _OI, _St, _STR, _STT10],
      [[0, {
        [_eQN]: `ImageId`,
        [_xN]: _iIma
      }], [0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }], [() => exports2.FastLaunchSnapshotConfigurationResponse$, {
        [_eQN]: `SnapshotConfiguration`,
        [_xN]: _sCn
      }], [() => exports2.FastLaunchLaunchTemplateSpecificationResponse$, {
        [_eQN]: `LaunchTemplate`,
        [_xN]: _lT
      }], [1, {
        [_eQN]: `MaxParallelLaunches`,
        [_xN]: _mPL
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `StateTransitionReason`,
        [_xN]: _sTR
      }], [4, {
        [_eQN]: `StateTransitionTime`,
        [_xN]: _sTT
      }]]
    ];
    exports2.DisableFastSnapshotRestoreErrorItem$ = [
      3,
      n032,
      _DFSREI,
      0,
      [_SIn, _FSRSE],
      [[0, {
        [_eQN]: `SnapshotId`,
        [_xN]: _sIn
      }], [() => DisableFastSnapshotRestoreStateErrorSet, {
        [_eQN]: `FastSnapshotRestoreStateErrorSet`,
        [_xN]: _fSRSES
      }]]
    ];
    exports2.DisableFastSnapshotRestoresRequest$ = [
      3,
      n032,
      _DFSRRi,
      0,
      [_SSIo, _AZv, _AZIv, _DR],
      [[() => SnapshotIdStringList, { [_xN]: _SSI }], [() => AvailabilityZoneStringList, { [_xN]: _AZ }], [() => AvailabilityZoneIdStringList, { [_xN]: _AZI }], 2],
      1
    ];
    exports2.DisableFastSnapshotRestoresResult$ = [
      3,
      n032,
      _DFSRRis,
      0,
      [_Suc, _U],
      [[() => DisableFastSnapshotRestoreSuccessSet, {
        [_eQN]: `Successful`,
        [_xN]: _suc
      }], [() => DisableFastSnapshotRestoreErrorSet, {
        [_eQN]: `Unsuccessful`,
        [_xN]: _u
      }]]
    ];
    exports2.DisableFastSnapshotRestoreStateError$ = [
      3,
      n032,
      _DFSRSE,
      0,
      [_Co, _Me],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }]]
    ];
    exports2.DisableFastSnapshotRestoreStateErrorItem$ = [
      3,
      n032,
      _DFSRSEI,
      0,
      [_AZ, _AZI, _Er],
      [[0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [() => exports2.DisableFastSnapshotRestoreStateError$, {
        [_eQN]: `Error`,
        [_xN]: _er
      }]]
    ];
    exports2.DisableFastSnapshotRestoreSuccessItem$ = [
      3,
      n032,
      _DFSRSIi,
      0,
      [_SIn, _AZ, _AZI, _St, _STR, _OI, _OAw, _ETna, _OT, _ETnab, _DTi, _DTis],
      [[0, {
        [_eQN]: `SnapshotId`,
        [_xN]: _sIn
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `StateTransitionReason`,
        [_xN]: _sTR
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `OwnerAlias`,
        [_xN]: _oAw
      }], [4, {
        [_eQN]: `EnablingTime`,
        [_xN]: _eTna
      }], [4, {
        [_eQN]: `OptimizingTime`,
        [_xN]: _oT
      }], [4, {
        [_eQN]: `EnabledTime`,
        [_xN]: _eTnab
      }], [4, {
        [_eQN]: `DisablingTime`,
        [_xN]: _dTi
      }], [4, {
        [_eQN]: `DisabledTime`,
        [_xN]: _dTis
      }]]
    ];
    exports2.DisableImageBlockPublicAccessRequest$ = [
      3,
      n032,
      _DIBPAR,
      0,
      [_DR],
      [2]
    ];
    exports2.DisableImageBlockPublicAccessResult$ = [
      3,
      n032,
      _DIBPARi,
      0,
      [_IBPAS],
      [[0, {
        [_eQN]: `ImageBlockPublicAccessState`,
        [_xN]: _iBPAS
      }]]
    ];
    exports2.DisableImageDeprecationRequest$ = [
      3,
      n032,
      _DIDR,
      0,
      [_IIm, _DR],
      [0, 2],
      1
    ];
    exports2.DisableImageDeprecationResult$ = [
      3,
      n032,
      _DIDRi,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.DisableImageDeregistrationProtectionRequest$ = [
      3,
      n032,
      _DIDPR,
      0,
      [_IIm, _DR],
      [0, 2],
      1
    ];
    exports2.DisableImageDeregistrationProtectionResult$ = [
      3,
      n032,
      _DIDPRi,
      0,
      [_R],
      [[0, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.DisableImageRequest$ = [
      3,
      n032,
      _DIRi,
      0,
      [_IIm, _DR],
      [0, 2],
      1
    ];
    exports2.DisableImageResult$ = [
      3,
      n032,
      _DIRis,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.DisableInstanceSqlHaStandbyDetectionsRequest$ = [
      3,
      n032,
      _DISHSDR,
      0,
      [_IIns, _DR],
      [[() => InstanceIdUpdateStringList, { [_xN]: _II2 }], 2],
      1
    ];
    exports2.DisableInstanceSqlHaStandbyDetectionsResult$ = [
      3,
      n032,
      _DISHSDRi,
      0,
      [_Ins],
      [[() => RegisteredInstanceList, {
        [_eQN]: `InstanceSet`,
        [_xN]: _iSns
      }]]
    ];
    exports2.DisableIpamOrganizationAdminAccountRequest$ = [
      3,
      n032,
      _DIOAAR,
      0,
      [_DAAI, _DR],
      [0, 2],
      1
    ];
    exports2.DisableIpamOrganizationAdminAccountResult$ = [
      3,
      n032,
      _DIOAARi,
      0,
      [_Succ],
      [[2, {
        [_eQN]: `Success`,
        [_xN]: _succ
      }]]
    ];
    exports2.DisableIpamPolicyRequest$ = [
      3,
      n032,
      _DIPRi,
      0,
      [_IPIp, _DR, _OTI],
      [0, 2, 0],
      1
    ];
    exports2.DisableIpamPolicyResult$ = [
      3,
      n032,
      _DIPRis,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.DisableRouteServerPropagationRequest$ = [
      3,
      n032,
      _DRSPRi,
      0,
      [_RSI, _RTI, _DR],
      [0, 0, 2],
      2
    ];
    exports2.DisableRouteServerPropagationResult$ = [
      3,
      n032,
      _DRSPRis,
      0,
      [_RSPou],
      [[() => exports2.RouteServerPropagation$, {
        [_eQN]: `RouteServerPropagation`,
        [_xN]: _rSPo
      }]]
    ];
    exports2.DisableSerialConsoleAccessRequest$ = [
      3,
      n032,
      _DSCAR,
      0,
      [_DR],
      [2]
    ];
    exports2.DisableSerialConsoleAccessResult$ = [
      3,
      n032,
      _DSCARi,
      0,
      [_SCAE],
      [[2, {
        [_eQN]: `SerialConsoleAccessEnabled`,
        [_xN]: _sCAE
      }]]
    ];
    exports2.DisableSnapshotBlockPublicAccessRequest$ = [
      3,
      n032,
      _DSBPAR,
      0,
      [_DR],
      [2]
    ];
    exports2.DisableSnapshotBlockPublicAccessResult$ = [
      3,
      n032,
      _DSBPARi,
      0,
      [_St],
      [[0, {
        [_eQN]: `State`,
        [_xN]: _st
      }]]
    ];
    exports2.DisableTransitGatewayRouteTablePropagationRequest$ = [
      3,
      n032,
      _DTGRTPR,
      0,
      [_TGRTI, _TGAI, _DR, _TGRTAI],
      [0, 0, 2, 0],
      1
    ];
    exports2.DisableTransitGatewayRouteTablePropagationResult$ = [
      3,
      n032,
      _DTGRTPRi,
      0,
      [_Prop],
      [[() => exports2.TransitGatewayPropagation$, {
        [_eQN]: `Propagation`,
        [_xN]: _prop
      }]]
    ];
    exports2.DisableVgwRoutePropagationRequest$ = [
      3,
      n032,
      _DVRPR,
      0,
      [_GI2, _RTI, _DR],
      [0, 0, 2],
      2
    ];
    exports2.DisableVpcClassicLinkDnsSupportRequest$ = [
      3,
      n032,
      _DVCLDSRi,
      0,
      [_VI],
      [[0, { [_xN]: _VI }]]
    ];
    exports2.DisableVpcClassicLinkDnsSupportResult$ = [
      3,
      n032,
      _DVCLDSRis,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.DisableVpcClassicLinkRequest$ = [
      3,
      n032,
      _DVCLRi,
      0,
      [_VI, _DR],
      [[0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.DisableVpcClassicLinkResult$ = [
      3,
      n032,
      _DVCLRis,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.DisassociateAddressRequest$ = [
      3,
      n032,
      _DARi,
      0,
      [_AIs, _PI10, _DR],
      [0, 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]]
    ];
    exports2.DisassociateCapacityReservationBillingOwnerRequest$ = [
      3,
      n032,
      _DCRBOR,
      0,
      [_CRI, _URBOI, _DR],
      [0, 0, 2],
      2
    ];
    exports2.DisassociateCapacityReservationBillingOwnerResult$ = [
      3,
      n032,
      _DCRBORi,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.DisassociateClientVpnTargetNetworkRequest$ = [
      3,
      n032,
      _DCVTNRi,
      0,
      [_CVEI, _AIs, _DR],
      [0, 0, 2],
      2
    ];
    exports2.DisassociateClientVpnTargetNetworkResult$ = [
      3,
      n032,
      _DCVTNRis,
      0,
      [_AIs, _Sta],
      [[0, {
        [_eQN]: `AssociationId`,
        [_xN]: _aIs
      }], [() => exports2.AssociationStatus$, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }]]
    ];
    exports2.DisassociateEnclaveCertificateIamRoleRequest$ = [
      3,
      n032,
      _DECIRR,
      0,
      [_CAe, _RAo, _DR],
      [0, 0, 2],
      2
    ];
    exports2.DisassociateEnclaveCertificateIamRoleResult$ = [
      3,
      n032,
      _DECIRRi,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.DisassociateIamInstanceProfileRequest$ = [
      3,
      n032,
      _DIIPR,
      0,
      [_AIs],
      [0],
      1
    ];
    exports2.DisassociateIamInstanceProfileResult$ = [
      3,
      n032,
      _DIIPRi,
      0,
      [_IIPA],
      [[() => exports2.IamInstanceProfileAssociation$, {
        [_eQN]: `IamInstanceProfileAssociation`,
        [_xN]: _iIPA
      }]]
    ];
    exports2.DisassociateInstanceEventWindowRequest$ = [
      3,
      n032,
      _DIEWRi,
      0,
      [_IEWI, _ATs, _DR],
      [0, [() => exports2.InstanceEventWindowDisassociationRequest$, 0], 2],
      2
    ];
    exports2.DisassociateInstanceEventWindowResult$ = [
      3,
      n032,
      _DIEWRis,
      0,
      [_IEW],
      [[() => exports2.InstanceEventWindow$, {
        [_eQN]: `InstanceEventWindow`,
        [_xN]: _iEW
      }]]
    ];
    exports2.DisassociateIpamByoasnRequest$ = [
      3,
      n032,
      _DIBRi,
      0,
      [_Asn, _Ci, _DR],
      [0, 0, 2],
      2
    ];
    exports2.DisassociateIpamByoasnResult$ = [
      3,
      n032,
      _DIBRis,
      0,
      [_AAs],
      [[() => exports2.AsnAssociation$, {
        [_eQN]: `AsnAssociation`,
        [_xN]: _aA
      }]]
    ];
    exports2.DisassociateIpamResourceDiscoveryRequest$ = [
      3,
      n032,
      _DIRDRi,
      0,
      [_IRDAIp, _DR],
      [0, 2],
      1
    ];
    exports2.DisassociateIpamResourceDiscoveryResult$ = [
      3,
      n032,
      _DIRDRis,
      0,
      [_IRDA],
      [[() => exports2.IpamResourceDiscoveryAssociation$, {
        [_eQN]: `IpamResourceDiscoveryAssociation`,
        [_xN]: _iRDA
      }]]
    ];
    exports2.DisassociateNatGatewayAddressRequest$ = [
      3,
      n032,
      _DNGAR,
      0,
      [_NGI, _AIsso, _MDDS, _DR],
      [0, [() => EipAssociationIdList, { [_xN]: _AIs }], 1, 2],
      2
    ];
    exports2.DisassociateNatGatewayAddressResult$ = [
      3,
      n032,
      _DNGARi,
      0,
      [_NGI, _NGA],
      [[0, {
        [_eQN]: `NatGatewayId`,
        [_xN]: _nGI
      }], [() => NatGatewayAddressList, {
        [_eQN]: `NatGatewayAddressSet`,
        [_xN]: _nGAS
      }]]
    ];
    exports2.DisassociateRouteServerRequest$ = [
      3,
      n032,
      _DRSRi,
      0,
      [_RSI, _VI, _DR],
      [0, 0, 2],
      2
    ];
    exports2.DisassociateRouteServerResult$ = [
      3,
      n032,
      _DRSRis,
      0,
      [_RSA],
      [[() => exports2.RouteServerAssociation$, {
        [_eQN]: `RouteServerAssociation`,
        [_xN]: _rSA
      }]]
    ];
    exports2.DisassociateRouteTableRequest$ = [
      3,
      n032,
      _DRTRi,
      0,
      [_AIs, _DR],
      [[0, {
        [_eQN]: `AssociationId`,
        [_xN]: _aIs
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.DisassociateSecurityGroupVpcRequest$ = [
      3,
      n032,
      _DSGVR,
      0,
      [_GIr, _VI, _DR],
      [0, 0, 2],
      2
    ];
    exports2.DisassociateSecurityGroupVpcResult$ = [
      3,
      n032,
      _DSGVRi,
      0,
      [_St],
      [[0, {
        [_eQN]: `State`,
        [_xN]: _st
      }]]
    ];
    exports2.DisassociateSubnetCidrBlockRequest$ = [
      3,
      n032,
      _DSCBR,
      0,
      [_AIs],
      [[0, {
        [_eQN]: `AssociationId`,
        [_xN]: _aIs
      }]],
      1
    ];
    exports2.DisassociateSubnetCidrBlockResult$ = [
      3,
      n032,
      _DSCBRi,
      0,
      [_ICBA, _SIu],
      [[() => exports2.SubnetIpv6CidrBlockAssociation$, {
        [_eQN]: `Ipv6CidrBlockAssociation`,
        [_xN]: _iCBA
      }], [0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }]]
    ];
    exports2.DisassociateTransitGatewayMulticastDomainRequest$ = [
      3,
      n032,
      _DTGMDRi,
      0,
      [_TGMDI, _TGAI, _SI10, _DR],
      [0, 0, [() => TransitGatewaySubnetIdList, 0], 2],
      3
    ];
    exports2.DisassociateTransitGatewayMulticastDomainResult$ = [
      3,
      n032,
      _DTGMDRis,
      0,
      [_As],
      [[() => exports2.TransitGatewayMulticastDomainAssociations$, {
        [_eQN]: `Associations`,
        [_xN]: _a10
      }]]
    ];
    exports2.DisassociateTransitGatewayPolicyTableRequest$ = [
      3,
      n032,
      _DTGPTRi,
      0,
      [_TGPTI, _TGAI, _DR],
      [0, 0, 2],
      2
    ];
    exports2.DisassociateTransitGatewayPolicyTableResult$ = [
      3,
      n032,
      _DTGPTRis,
      0,
      [_Ass],
      [[() => exports2.TransitGatewayPolicyTableAssociation$, {
        [_eQN]: `Association`,
        [_xN]: _ass
      }]]
    ];
    exports2.DisassociateTransitGatewayRouteTableRequest$ = [
      3,
      n032,
      _DTGRTRi,
      0,
      [_TGRTI, _TGAI, _DR],
      [0, 0, 2],
      2
    ];
    exports2.DisassociateTransitGatewayRouteTableResult$ = [
      3,
      n032,
      _DTGRTRis,
      0,
      [_Ass],
      [[() => exports2.TransitGatewayAssociation$, {
        [_eQN]: `Association`,
        [_xN]: _ass
      }]]
    ];
    exports2.DisassociateTrunkInterfaceRequest$ = [
      3,
      n032,
      _DTIR,
      0,
      [_AIs, _CT4, _DR],
      [0, [0, 4], 2],
      1
    ];
    exports2.DisassociateTrunkInterfaceResult$ = [
      3,
      n032,
      _DTIRi,
      0,
      [_R, _CT4],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }], [0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }]]
    ];
    exports2.DisassociateVpcCidrBlockRequest$ = [
      3,
      n032,
      _DVCBR,
      0,
      [_AIs],
      [[0, {
        [_eQN]: `AssociationId`,
        [_xN]: _aIs
      }]],
      1
    ];
    exports2.DisassociateVpcCidrBlockResult$ = [
      3,
      n032,
      _DVCBRi,
      0,
      [_ICBA, _CBA, _VI],
      [[() => exports2.VpcIpv6CidrBlockAssociation$, {
        [_eQN]: `Ipv6CidrBlockAssociation`,
        [_xN]: _iCBA
      }], [() => exports2.VpcCidrBlockAssociation$, {
        [_eQN]: `CidrBlockAssociation`,
        [_xN]: _cBA
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }]]
    ];
    exports2.DiskImage$ = [
      3,
      n032,
      _DIis,
      0,
      [_De, _Ima, _Vol],
      [0, [() => exports2.DiskImageDetail$, 0], [() => exports2.VolumeDetail$, 0]]
    ];
    exports2.DiskImageDescription$ = [
      3,
      n032,
      _DID,
      0,
      [_Ch, _Fo, _IMU, _Siz],
      [[0, {
        [_eQN]: `Checksum`,
        [_xN]: _ch
      }], [0, {
        [_eQN]: `Format`,
        [_xN]: _for
      }], [() => ImportManifestUrl, {
        [_eQN]: `ImportManifestUrl`,
        [_xN]: _iMU
      }], [1, {
        [_eQN]: `Size`,
        [_xN]: _si
      }]]
    ];
    exports2.DiskImageDetail$ = [
      3,
      n032,
      _DIDi,
      0,
      [_Fo, _Byt, _IMU],
      [[0, {
        [_eQN]: `Format`,
        [_xN]: _for
      }], [1, {
        [_eQN]: `Bytes`,
        [_xN]: _byt
      }], [() => ImportManifestUrl, {
        [_eQN]: `ImportManifestUrl`,
        [_xN]: _iMU
      }]],
      3
    ];
    exports2.DiskImageVolumeDescription$ = [
      3,
      n032,
      _DIVD,
      0,
      [_I, _Siz],
      [[0, {
        [_eQN]: `Id`,
        [_xN]: _i
      }], [1, {
        [_eQN]: `Size`,
        [_xN]: _si
      }]]
    ];
    exports2.DiskInfo$ = [
      3,
      n032,
      _DIisk,
      0,
      [_SIGB, _Cou, _Ty],
      [[1, {
        [_eQN]: `SizeInGB`,
        [_xN]: _sIGB
      }], [1, {
        [_eQN]: `Count`,
        [_xN]: _cou
      }], [0, {
        [_eQN]: `Type`,
        [_xN]: _ty
      }]]
    ];
    exports2.DnsEntry$ = [
      3,
      n032,
      _DE,
      0,
      [_DNn, _HZI],
      [[0, {
        [_eQN]: `DnsName`,
        [_xN]: _dNn
      }], [0, {
        [_eQN]: `HostedZoneId`,
        [_xN]: _hZI
      }]]
    ];
    exports2.DnsOptions$ = [
      3,
      n032,
      _DOn,
      0,
      [_DRIT, _PDOFIRE, _PDP, _PDSD],
      [[0, {
        [_eQN]: `DnsRecordIpType`,
        [_xN]: _dRIT
      }], [2, {
        [_eQN]: `PrivateDnsOnlyForInboundResolverEndpoint`,
        [_xN]: _pDOFIRE
      }], [0, {
        [_eQN]: `PrivateDnsPreference`,
        [_xN]: _pDP
      }], [() => PrivateDnsSpecifiedDomainSet, {
        [_eQN]: `PrivateDnsSpecifiedDomainSet`,
        [_xN]: _pDSDS
      }]]
    ];
    exports2.DnsOptionsSpecification$ = [
      3,
      n032,
      _DOS,
      0,
      [_DRIT, _PDOFIRE, _PDP, _PDSD],
      [0, 2, 0, [() => PrivateDnsSpecifiedDomainSet, { [_xN]: _PDSDr }]]
    ];
    exports2.DnsServersOptionsModifyStructure$ = [
      3,
      n032,
      _DSOMS,
      0,
      [_CDS, _En],
      [[() => ValueStringList, 0], 2]
    ];
    exports2.EbsBlockDevice$ = [
      3,
      n032,
      _EBD,
      0,
      [_DOT, _Io, _SIn, _VSo, _VT, _KKI, _Th, _OA, _AZ, _Enc, _VIR, _AZI, _ECI],
      [[2, {
        [_eQN]: `DeleteOnTermination`,
        [_xN]: _dOT
      }], [1, {
        [_eQN]: `Iops`,
        [_xN]: _io
      }], [0, {
        [_eQN]: `SnapshotId`,
        [_xN]: _sIn
      }], [1, {
        [_eQN]: `VolumeSize`,
        [_xN]: _vSo
      }], [0, {
        [_eQN]: `VolumeType`,
        [_xN]: _vT
      }], [0, {
        [_eQN]: `KmsKeyId`,
        [_xN]: _kKI
      }], [1, {
        [_eQN]: `Throughput`,
        [_xN]: _th
      }], [0, {
        [_eQN]: `OutpostArn`,
        [_xN]: _oA
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [2, {
        [_eQN]: `Encrypted`,
        [_xN]: _enc
      }], 1, 0, 1]
    ];
    exports2.EbsBlockDeviceResponse$ = [
      3,
      n032,
      _EBDR,
      0,
      [_Enc, _DOT, _Io, _Th, _KKI, _SIn, _VSo, _VT],
      [[2, {
        [_eQN]: `Encrypted`,
        [_xN]: _enc
      }], [2, {
        [_eQN]: `DeleteOnTermination`,
        [_xN]: _dOT
      }], [1, {
        [_eQN]: `Iops`,
        [_xN]: _io
      }], [1, {
        [_eQN]: `Throughput`,
        [_xN]: _th
      }], [0, {
        [_eQN]: `KmsKeyId`,
        [_xN]: _kKI
      }], [0, {
        [_eQN]: `SnapshotId`,
        [_xN]: _sIn
      }], [1, {
        [_eQN]: `VolumeSize`,
        [_xN]: _vSo
      }], [0, {
        [_eQN]: `VolumeType`,
        [_xN]: _vT
      }]]
    ];
    exports2.EbsCardInfo$ = [
      3,
      n032,
      _ECIb,
      0,
      [_ECI, _BBIM, _BTIMB, _BIa, _MBIM, _MTIMB, _MI],
      [[1, {
        [_eQN]: `EbsCardIndex`,
        [_xN]: _eCI
      }], [1, {
        [_eQN]: `BaselineBandwidthInMbps`,
        [_xN]: _bBIM
      }], [1, {
        [_eQN]: `BaselineThroughputInMBps`,
        [_xN]: _bTIMB
      }], [1, {
        [_eQN]: `BaselineIops`,
        [_xN]: _bIa
      }], [1, {
        [_eQN]: `MaximumBandwidthInMbps`,
        [_xN]: _mBIM
      }], [1, {
        [_eQN]: `MaximumThroughputInMBps`,
        [_xN]: _mTIMB
      }], [1, {
        [_eQN]: `MaximumIops`,
        [_xN]: _mI
      }]]
    ];
    exports2.EbsInfo$ = [
      3,
      n032,
      _EIb,
      0,
      [_EOS, _ESn, _EOI, _NS, _MEA, _ALT, _MEC, _ECb],
      [[0, {
        [_eQN]: `EbsOptimizedSupport`,
        [_xN]: _eOS
      }], [0, {
        [_eQN]: `EncryptionSupport`,
        [_xN]: _eSn
      }], [() => exports2.EbsOptimizedInfo$, {
        [_eQN]: `EbsOptimizedInfo`,
        [_xN]: _eOI
      }], [0, {
        [_eQN]: `NvmeSupport`,
        [_xN]: _nS
      }], [1, {
        [_eQN]: `MaximumEbsAttachments`,
        [_xN]: _mEA
      }], [0, {
        [_eQN]: `AttachmentLimitType`,
        [_xN]: _aLT
      }], [1, {
        [_eQN]: `MaximumEbsCards`,
        [_xN]: _mEC
      }], [() => EbsCardInfoList, {
        [_eQN]: `EbsCardSet`,
        [_xN]: _eCS
      }]]
    ];
    exports2.EbsInstanceBlockDevice$ = [
      3,
      n032,
      _EIBD,
      0,
      [_ATtt, _DOT, _Sta, _VIo, _ARss, _VOI, _Op, _ECI],
      [[4, {
        [_eQN]: `AttachTime`,
        [_xN]: _aTt
      }], [2, {
        [_eQN]: `DeleteOnTermination`,
        [_xN]: _dOT
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `VolumeId`,
        [_xN]: _vIo
      }], [0, {
        [_eQN]: `AssociatedResource`,
        [_xN]: _aRs
      }], [0, {
        [_eQN]: `VolumeOwnerId`,
        [_xN]: _vOI
      }], [() => exports2.OperatorResponse$, {
        [_eQN]: `Operator`,
        [_xN]: _ope
      }], [1, {
        [_eQN]: `EbsCardIndex`,
        [_xN]: _eCI
      }]]
    ];
    exports2.EbsInstanceBlockDeviceSpecification$ = [
      3,
      n032,
      _EIBDS,
      0,
      [_VIo, _DOT],
      [[0, {
        [_eQN]: `VolumeId`,
        [_xN]: _vIo
      }], [2, {
        [_eQN]: `DeleteOnTermination`,
        [_xN]: _dOT
      }]]
    ];
    exports2.EbsOptimizedInfo$ = [
      3,
      n032,
      _EOI,
      0,
      [_BBIM, _BTIMB, _BIa, _MBIM, _MTIMB, _MI],
      [[1, {
        [_eQN]: `BaselineBandwidthInMbps`,
        [_xN]: _bBIM
      }], [1, {
        [_eQN]: `BaselineThroughputInMBps`,
        [_xN]: _bTIMB
      }], [1, {
        [_eQN]: `BaselineIops`,
        [_xN]: _bIa
      }], [1, {
        [_eQN]: `MaximumBandwidthInMbps`,
        [_xN]: _mBIM
      }], [1, {
        [_eQN]: `MaximumThroughputInMBps`,
        [_xN]: _mTIMB
      }], [1, {
        [_eQN]: `MaximumIops`,
        [_xN]: _mI
      }]]
    ];
    exports2.EbsStatusDetails$ = [
      3,
      n032,
      _ESD,
      0,
      [_ISm, _N, _Sta],
      [[4, {
        [_eQN]: `ImpairedSince`,
        [_xN]: _iSmp
      }], [0, {
        [_eQN]: `Name`,
        [_xN]: _n
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }]]
    ];
    exports2.EbsStatusSummary$ = [
      3,
      n032,
      _ESSb,
      0,
      [_Det, _Sta],
      [[() => EbsStatusDetailsList, {
        [_eQN]: `Details`,
        [_xN]: _det
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }]]
    ];
    exports2.Ec2InstanceConnectEndpoint$ = [
      3,
      n032,
      _EICE,
      0,
      [_OI, _ICEI, _ICEA, _St, _SMta, _DNn, _FDN, _NIIe, _VI, _AZ, _CAr, _SIu, _PCI, _SGIe, _T10, _IAT, _PDNu, _AZI],
      [[0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `InstanceConnectEndpointId`,
        [_xN]: _iCEI
      }], [0, {
        [_eQN]: `InstanceConnectEndpointArn`,
        [_xN]: _iCEA
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `StateMessage`,
        [_xN]: _sMta
      }], [0, {
        [_eQN]: `DnsName`,
        [_xN]: _dNn
      }], [0, {
        [_eQN]: `FipsDnsName`,
        [_xN]: _fDN
      }], [() => NetworkInterfaceIdSet, {
        [_eQN]: `NetworkInterfaceIdSet`,
        [_xN]: _nIIS
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [4, {
        [_eQN]: `CreatedAt`,
        [_xN]: _cAr
      }], [0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }], [2, {
        [_eQN]: `PreserveClientIp`,
        [_xN]: _pCI
      }], [() => SecurityGroupIdSet, {
        [_eQN]: `SecurityGroupIdSet`,
        [_xN]: _sGIS
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `IpAddressType`,
        [_xN]: _iAT
      }], [() => exports2.InstanceConnectEndpointPublicDnsNames$, {
        [_eQN]: `PublicDnsNames`,
        [_xN]: _pDN
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }]]
    ];
    exports2.EfaInfo$ = [
      3,
      n032,
      _EIf,
      0,
      [_MEI],
      [[1, {
        [_eQN]: `MaximumEfaInterfaces`,
        [_xN]: _mEI
      }]]
    ];
    exports2.EgressOnlyInternetGateway$ = [
      3,
      n032,
      _EOIG,
      0,
      [_Atta, _EOIGI, _T10],
      [[() => InternetGatewayAttachmentList, {
        [_eQN]: `AttachmentSet`,
        [_xN]: _aSt
      }], [0, {
        [_eQN]: `EgressOnlyInternetGatewayId`,
        [_xN]: _eOIGI
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.ElasticGpuAssociation$ = [
      3,
      n032,
      _EGA,
      0,
      [_EGIl, _EGAI, _EGAS, _EGAT],
      [[0, {
        [_eQN]: `ElasticGpuId`,
        [_xN]: _eGI
      }], [0, {
        [_eQN]: `ElasticGpuAssociationId`,
        [_xN]: _eGAI
      }], [0, {
        [_eQN]: `ElasticGpuAssociationState`,
        [_xN]: _eGAS
      }], [0, {
        [_eQN]: `ElasticGpuAssociationTime`,
        [_xN]: _eGAT
      }]]
    ];
    exports2.ElasticGpuHealth$ = [
      3,
      n032,
      _EGH,
      0,
      [_Sta],
      [[0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }]]
    ];
    exports2.ElasticGpus$ = [
      3,
      n032,
      _EG,
      0,
      [_EGIl, _AZ, _EGT, _EGH, _EGSl, _II2, _T10],
      [[0, {
        [_eQN]: `ElasticGpuId`,
        [_xN]: _eGI
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [0, {
        [_eQN]: `ElasticGpuType`,
        [_xN]: _eGT
      }], [() => exports2.ElasticGpuHealth$, {
        [_eQN]: `ElasticGpuHealth`,
        [_xN]: _eGH
      }], [0, {
        [_eQN]: `ElasticGpuState`,
        [_xN]: _eGSl
      }], [0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.ElasticGpuSpecification$ = [
      3,
      n032,
      _EGSla,
      0,
      [_Ty],
      [0],
      1
    ];
    exports2.ElasticGpuSpecificationResponse$ = [
      3,
      n032,
      _EGSR,
      0,
      [_Ty],
      [[0, {
        [_eQN]: `Type`,
        [_xN]: _ty
      }]]
    ];
    exports2.ElasticInferenceAccelerator$ = [
      3,
      n032,
      _EIA,
      0,
      [_Ty, _Cou],
      [0, 1],
      1
    ];
    exports2.ElasticInferenceAcceleratorAssociation$ = [
      3,
      n032,
      _EIAA,
      0,
      [_EIAAl, _EIAAI, _EIAAS, _EIAAT],
      [[0, {
        [_eQN]: `ElasticInferenceAcceleratorArn`,
        [_xN]: _eIAA
      }], [0, {
        [_eQN]: `ElasticInferenceAcceleratorAssociationId`,
        [_xN]: _eIAAI
      }], [0, {
        [_eQN]: `ElasticInferenceAcceleratorAssociationState`,
        [_xN]: _eIAAS
      }], [4, {
        [_eQN]: `ElasticInferenceAcceleratorAssociationTime`,
        [_xN]: _eIAAT
      }]]
    ];
    exports2.EnableAddressTransferRequest$ = [
      3,
      n032,
      _EATR,
      0,
      [_AIl, _TAI, _DR],
      [0, 0, 2],
      2
    ];
    exports2.EnableAddressTransferResult$ = [
      3,
      n032,
      _EATRn,
      0,
      [_AT13],
      [[() => exports2.AddressTransfer$, {
        [_eQN]: `AddressTransfer`,
        [_xN]: _aT22
      }]]
    ];
    exports2.EnableAllowedImagesSettingsRequest$ = [
      3,
      n032,
      _EAISR,
      0,
      [_AISS, _DR],
      [0, 2],
      1
    ];
    exports2.EnableAllowedImagesSettingsResult$ = [
      3,
      n032,
      _EAISRn,
      0,
      [_AISS],
      [[0, {
        [_eQN]: `AllowedImagesSettingsState`,
        [_xN]: _aISS
      }]]
    ];
    exports2.EnableAwsNetworkPerformanceMetricSubscriptionRequest$ = [
      3,
      n032,
      _EANPMSR,
      0,
      [_S, _D, _Met, _Stat, _DR],
      [0, 0, 0, 0, 2]
    ];
    exports2.EnableAwsNetworkPerformanceMetricSubscriptionResult$ = [
      3,
      n032,
      _EANPMSRn,
      0,
      [_Ou],
      [[2, {
        [_eQN]: `Output`,
        [_xN]: _ou
      }]]
    ];
    exports2.EnableCapacityManagerRequest$ = [
      3,
      n032,
      _ECMR,
      0,
      [_OAr, _DR, _CT4],
      [2, 2, [0, 4]]
    ];
    exports2.EnableCapacityManagerResult$ = [
      3,
      n032,
      _ECMRn,
      0,
      [_CMS, _OAr],
      [[0, {
        [_eQN]: `CapacityManagerStatus`,
        [_xN]: _cMS
      }], [2, {
        [_eQN]: `OrganizationsAccess`,
        [_xN]: _oAr
      }]]
    ];
    exports2.EnableEbsEncryptionByDefaultRequest$ = [
      3,
      n032,
      _EEEBDR,
      0,
      [_DR],
      [2]
    ];
    exports2.EnableEbsEncryptionByDefaultResult$ = [
      3,
      n032,
      _EEEBDRn,
      0,
      [_EEBD],
      [[2, {
        [_eQN]: `EbsEncryptionByDefault`,
        [_xN]: _eEBD
      }]]
    ];
    exports2.EnableFastLaunchRequest$ = [
      3,
      n032,
      _EFLR,
      0,
      [_IIm, _RTe, _SCn, _LT, _MPL, _DR],
      [0, 0, () => exports2.FastLaunchSnapshotConfigurationRequest$, () => exports2.FastLaunchLaunchTemplateSpecificationRequest$, 1, 2],
      1
    ];
    exports2.EnableFastLaunchResult$ = [
      3,
      n032,
      _EFLRn,
      0,
      [_IIm, _RTe, _SCn, _LT, _MPL, _OI, _St, _STR, _STT10],
      [[0, {
        [_eQN]: `ImageId`,
        [_xN]: _iIma
      }], [0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }], [() => exports2.FastLaunchSnapshotConfigurationResponse$, {
        [_eQN]: `SnapshotConfiguration`,
        [_xN]: _sCn
      }], [() => exports2.FastLaunchLaunchTemplateSpecificationResponse$, {
        [_eQN]: `LaunchTemplate`,
        [_xN]: _lT
      }], [1, {
        [_eQN]: `MaxParallelLaunches`,
        [_xN]: _mPL
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `StateTransitionReason`,
        [_xN]: _sTR
      }], [4, {
        [_eQN]: `StateTransitionTime`,
        [_xN]: _sTT
      }]]
    ];
    exports2.EnableFastSnapshotRestoreErrorItem$ = [
      3,
      n032,
      _EFSREI,
      0,
      [_SIn, _FSRSE],
      [[0, {
        [_eQN]: `SnapshotId`,
        [_xN]: _sIn
      }], [() => EnableFastSnapshotRestoreStateErrorSet, {
        [_eQN]: `FastSnapshotRestoreStateErrorSet`,
        [_xN]: _fSRSES
      }]]
    ];
    exports2.EnableFastSnapshotRestoresRequest$ = [
      3,
      n032,
      _EFSRR,
      0,
      [_SSIo, _AZv, _AZIv, _DR],
      [[() => SnapshotIdStringList, { [_xN]: _SSI }], [() => AvailabilityZoneStringList, { [_xN]: _AZ }], [() => AvailabilityZoneIdStringList, { [_xN]: _AZI }], 2],
      1
    ];
    exports2.EnableFastSnapshotRestoresResult$ = [
      3,
      n032,
      _EFSRRn,
      0,
      [_Suc, _U],
      [[() => EnableFastSnapshotRestoreSuccessSet, {
        [_eQN]: `Successful`,
        [_xN]: _suc
      }], [() => EnableFastSnapshotRestoreErrorSet, {
        [_eQN]: `Unsuccessful`,
        [_xN]: _u
      }]]
    ];
    exports2.EnableFastSnapshotRestoreStateError$ = [
      3,
      n032,
      _EFSRSE,
      0,
      [_Co, _Me],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }]]
    ];
    exports2.EnableFastSnapshotRestoreStateErrorItem$ = [
      3,
      n032,
      _EFSRSEI,
      0,
      [_AZ, _AZI, _Er],
      [[0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [() => exports2.EnableFastSnapshotRestoreStateError$, {
        [_eQN]: `Error`,
        [_xN]: _er
      }]]
    ];
    exports2.EnableFastSnapshotRestoreSuccessItem$ = [
      3,
      n032,
      _EFSRSI,
      0,
      [_SIn, _AZ, _AZI, _St, _STR, _OI, _OAw, _ETna, _OT, _ETnab, _DTi, _DTis],
      [[0, {
        [_eQN]: `SnapshotId`,
        [_xN]: _sIn
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `StateTransitionReason`,
        [_xN]: _sTR
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `OwnerAlias`,
        [_xN]: _oAw
      }], [4, {
        [_eQN]: `EnablingTime`,
        [_xN]: _eTna
      }], [4, {
        [_eQN]: `OptimizingTime`,
        [_xN]: _oT
      }], [4, {
        [_eQN]: `EnabledTime`,
        [_xN]: _eTnab
      }], [4, {
        [_eQN]: `DisablingTime`,
        [_xN]: _dTi
      }], [4, {
        [_eQN]: `DisabledTime`,
        [_xN]: _dTis
      }]]
    ];
    exports2.EnableImageBlockPublicAccessRequest$ = [
      3,
      n032,
      _EIBPAR,
      0,
      [_IBPAS, _DR],
      [0, 2],
      1
    ];
    exports2.EnableImageBlockPublicAccessResult$ = [
      3,
      n032,
      _EIBPARn,
      0,
      [_IBPAS],
      [[0, {
        [_eQN]: `ImageBlockPublicAccessState`,
        [_xN]: _iBPAS
      }]]
    ];
    exports2.EnableImageDeprecationRequest$ = [
      3,
      n032,
      _EIDR,
      0,
      [_IIm, _DAep, _DR],
      [0, 4, 2],
      2
    ];
    exports2.EnableImageDeprecationResult$ = [
      3,
      n032,
      _EIDRn,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.EnableImageDeregistrationProtectionRequest$ = [
      3,
      n032,
      _EIDPR,
      0,
      [_IIm, _WC, _DR],
      [0, 2, 2],
      1
    ];
    exports2.EnableImageDeregistrationProtectionResult$ = [
      3,
      n032,
      _EIDPRn,
      0,
      [_R],
      [[0, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.EnableImageRequest$ = [
      3,
      n032,
      _EIR,
      0,
      [_IIm, _DR],
      [0, 2],
      1
    ];
    exports2.EnableImageResult$ = [
      3,
      n032,
      _EIRn,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.EnableInstanceSqlHaStandbyDetectionsRequest$ = [
      3,
      n032,
      _EISHSDR,
      0,
      [_IIns, _SSC, _DR],
      [[() => InstanceIdUpdateStringList, { [_xN]: _II2 }], 0, 2],
      1
    ];
    exports2.EnableInstanceSqlHaStandbyDetectionsResult$ = [
      3,
      n032,
      _EISHSDRn,
      0,
      [_Ins],
      [[() => RegisteredInstanceList, {
        [_eQN]: `InstanceSet`,
        [_xN]: _iSns
      }]]
    ];
    exports2.EnableIpamOrganizationAdminAccountRequest$ = [
      3,
      n032,
      _EIOAAR,
      0,
      [_DAAI, _DR],
      [0, 2],
      1
    ];
    exports2.EnableIpamOrganizationAdminAccountResult$ = [
      3,
      n032,
      _EIOAARn,
      0,
      [_Succ],
      [[2, {
        [_eQN]: `Success`,
        [_xN]: _succ
      }]]
    ];
    exports2.EnableIpamPolicyRequest$ = [
      3,
      n032,
      _EIPR,
      0,
      [_IPIp, _DR, _OTI],
      [0, 2, 0],
      1
    ];
    exports2.EnableIpamPolicyResult$ = [
      3,
      n032,
      _EIPRn,
      0,
      [_IPIp],
      [[0, {
        [_eQN]: `IpamPolicyId`,
        [_xN]: _iPI
      }]]
    ];
    exports2.EnableReachabilityAnalyzerOrganizationSharingRequest$ = [
      3,
      n032,
      _ERAOSR,
      0,
      [_DR],
      [2]
    ];
    exports2.EnableReachabilityAnalyzerOrganizationSharingResult$ = [
      3,
      n032,
      _ERAOSRn,
      0,
      [_RV],
      [[2, {
        [_eQN]: `ReturnValue`,
        [_xN]: _rV
      }]]
    ];
    exports2.EnableRouteServerPropagationRequest$ = [
      3,
      n032,
      _ERSPR,
      0,
      [_RSI, _RTI, _DR],
      [0, 0, 2],
      2
    ];
    exports2.EnableRouteServerPropagationResult$ = [
      3,
      n032,
      _ERSPRn,
      0,
      [_RSPou],
      [[() => exports2.RouteServerPropagation$, {
        [_eQN]: `RouteServerPropagation`,
        [_xN]: _rSPo
      }]]
    ];
    exports2.EnableSerialConsoleAccessRequest$ = [
      3,
      n032,
      _ESCAR,
      0,
      [_DR],
      [2]
    ];
    exports2.EnableSerialConsoleAccessResult$ = [
      3,
      n032,
      _ESCARn,
      0,
      [_SCAE],
      [[2, {
        [_eQN]: `SerialConsoleAccessEnabled`,
        [_xN]: _sCAE
      }]]
    ];
    exports2.EnableSnapshotBlockPublicAccessRequest$ = [
      3,
      n032,
      _ESBPAR,
      0,
      [_St, _DR],
      [0, 2],
      1
    ];
    exports2.EnableSnapshotBlockPublicAccessResult$ = [
      3,
      n032,
      _ESBPARn,
      0,
      [_St],
      [[0, {
        [_eQN]: `State`,
        [_xN]: _st
      }]]
    ];
    exports2.EnableTransitGatewayRouteTablePropagationRequest$ = [
      3,
      n032,
      _ETGRTPR,
      0,
      [_TGRTI, _TGAI, _DR, _TGRTAI],
      [0, 0, 2, 0],
      1
    ];
    exports2.EnableTransitGatewayRouteTablePropagationResult$ = [
      3,
      n032,
      _ETGRTPRn,
      0,
      [_Prop],
      [[() => exports2.TransitGatewayPropagation$, {
        [_eQN]: `Propagation`,
        [_xN]: _prop
      }]]
    ];
    exports2.EnableVgwRoutePropagationRequest$ = [
      3,
      n032,
      _EVRPR,
      0,
      [_GI2, _RTI, _DR],
      [0, 0, 2],
      2
    ];
    exports2.EnableVolumeIORequest$ = [
      3,
      n032,
      _EVIOR,
      0,
      [_VIo, _DR],
      [[0, {
        [_eQN]: `VolumeId`,
        [_xN]: _vIo
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.EnableVpcClassicLinkDnsSupportRequest$ = [
      3,
      n032,
      _EVCLDSR,
      0,
      [_VI],
      [[0, { [_xN]: _VI }]]
    ];
    exports2.EnableVpcClassicLinkDnsSupportResult$ = [
      3,
      n032,
      _EVCLDSRn,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.EnableVpcClassicLinkRequest$ = [
      3,
      n032,
      _EVCLR,
      0,
      [_VI, _DR],
      [[0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.EnableVpcClassicLinkResult$ = [
      3,
      n032,
      _EVCLRn,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.EnaSrdSpecification$ = [
      3,
      n032,
      _ESS,
      0,
      [_ESE2, _ESUS],
      [2, () => exports2.EnaSrdUdpSpecification$]
    ];
    exports2.EnaSrdSpecificationRequest$ = [
      3,
      n032,
      _ESSR,
      0,
      [_ESE2, _ESUS],
      [2, () => exports2.EnaSrdUdpSpecificationRequest$]
    ];
    exports2.EnaSrdUdpSpecification$ = [
      3,
      n032,
      _ESUS,
      0,
      [_ESUE],
      [2]
    ];
    exports2.EnaSrdUdpSpecificationRequest$ = [
      3,
      n032,
      _ESUSR,
      0,
      [_ESUE],
      [2]
    ];
    exports2.EnclaveOptions$ = [
      3,
      n032,
      _EOn,
      0,
      [_En],
      [[2, {
        [_eQN]: `Enabled`,
        [_xN]: _en
      }]]
    ];
    exports2.EnclaveOptionsRequest$ = [
      3,
      n032,
      _EOR,
      0,
      [_En],
      [2]
    ];
    exports2.EncryptionSupport$ = [
      3,
      n032,
      _ESn,
      0,
      [_ESnc, _SMta],
      [[0, {
        [_eQN]: `EncryptionState`,
        [_xN]: _eSnc
      }], [0, {
        [_eQN]: `StateMessage`,
        [_xN]: _sMta
      }]]
    ];
    exports2.EventInformation$ = [
      3,
      n032,
      _EIv,
      0,
      [_EDv, _EST, _II2],
      [[0, {
        [_eQN]: `EventDescription`,
        [_xN]: _eDv
      }], [0, {
        [_eQN]: `EventSubType`,
        [_xN]: _eST
      }], [0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }]]
    ];
    exports2.Explanation$ = [
      3,
      n032,
      _Ex,
      0,
      [_Ac, _ARcl, _A10, _Add, _ATtta, _AZv, _AZIv, _Cid, _C11, _CGu, _D, _DVe, _Di, _ECx, _IRT, _IG, _LBAo, _CLBL, _LBLP, _LBT, _LBTG, _LBTGo, _LBTP, _ELBL, _MCi, _NG, _NIe, _PF, _VPC, _Po, _PRor, _PL, _Prot, _RTR, _RTo, _SGec, _SGRe, _SGe, _SVo, _St, _Su, _SRT, _Vp, _VE10, _VCp, _VG, _TG, _TGRT, _TGRTR, _TGAra, _CAo, _CRo, _FSRi, _FSRir],
      [[() => exports2.AnalysisComponent$, {
        [_eQN]: `Acl`,
        [_xN]: _ac
      }], [() => exports2.AnalysisAclRule$, {
        [_eQN]: `AclRule`,
        [_xN]: _aRc
      }], [0, {
        [_eQN]: `Address`,
        [_xN]: _ad
      }], [() => IpAddressList, {
        [_eQN]: `AddressSet`,
        [_xN]: _aSd
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `AttachedTo`,
        [_xN]: _aTtt
      }], [() => ValueStringList, {
        [_eQN]: `AvailabilityZoneSet`,
        [_xN]: _aZS
      }], [() => ValueStringList, {
        [_eQN]: `AvailabilityZoneIdSet`,
        [_xN]: _aZIS
      }], [() => ValueStringList, {
        [_eQN]: `CidrSet`,
        [_xN]: _cS4
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `Component`,
        [_xN]: _c32
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `CustomerGateway`,
        [_xN]: _cGu
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `Destination`,
        [_xN]: _d
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `DestinationVpc`,
        [_xN]: _dV
      }], [0, {
        [_eQN]: `Direction`,
        [_xN]: _di
      }], [0, {
        [_eQN]: `ExplanationCode`,
        [_xN]: _eCx
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `IngressRouteTable`,
        [_xN]: _iRT
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `InternetGateway`,
        [_xN]: _iG
      }], [0, {
        [_eQN]: `LoadBalancerArn`,
        [_xN]: _lBA
      }], [() => exports2.AnalysisLoadBalancerListener$, {
        [_eQN]: `ClassicLoadBalancerListener`,
        [_xN]: _cLBL
      }], [1, {
        [_eQN]: `LoadBalancerListenerPort`,
        [_xN]: _lBLP
      }], [() => exports2.AnalysisLoadBalancerTarget$, {
        [_eQN]: `LoadBalancerTarget`,
        [_xN]: _lBT
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `LoadBalancerTargetGroup`,
        [_xN]: _lBTG
      }], [() => AnalysisComponentList, {
        [_eQN]: `LoadBalancerTargetGroupSet`,
        [_xN]: _lBTGS
      }], [1, {
        [_eQN]: `LoadBalancerTargetPort`,
        [_xN]: _lBTP
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `ElasticLoadBalancerListener`,
        [_xN]: _eLBL
      }], [0, {
        [_eQN]: `MissingComponent`,
        [_xN]: _mC
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `NatGateway`,
        [_xN]: _nG
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `NetworkInterface`,
        [_xN]: _nIe
      }], [0, {
        [_eQN]: `PacketField`,
        [_xN]: _pF
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `VpcPeeringConnection`,
        [_xN]: _vPC
      }], [1, {
        [_eQN]: `Port`,
        [_xN]: _po
      }], [() => PortRangeList, {
        [_eQN]: `PortRangeSet`,
        [_xN]: _pRS
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `PrefixList`,
        [_xN]: _pL
      }], [() => StringList, {
        [_eQN]: `ProtocolSet`,
        [_xN]: _pSro
      }], [() => exports2.AnalysisRouteTableRoute$, {
        [_eQN]: `RouteTableRoute`,
        [_xN]: _rTR
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `RouteTable`,
        [_xN]: _rTo
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `SecurityGroup`,
        [_xN]: _sG
      }], [() => exports2.AnalysisSecurityGroupRule$, {
        [_eQN]: `SecurityGroupRule`,
        [_xN]: _sGR
      }], [() => AnalysisComponentList, {
        [_eQN]: `SecurityGroupSet`,
        [_xN]: _sGSe
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `SourceVpc`,
        [_xN]: _sV
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `Subnet`,
        [_xN]: _su
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `SubnetRouteTable`,
        [_xN]: _sRT
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `Vpc`,
        [_xN]: _vp
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `VpcEndpoint`,
        [_xN]: _vE
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `VpnConnection`,
        [_xN]: _vCp
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `VpnGateway`,
        [_xN]: _vG
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `TransitGateway`,
        [_xN]: _tG
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `TransitGatewayRouteTable`,
        [_xN]: _tGRT
      }], [() => exports2.TransitGatewayRouteTableRoute$, {
        [_eQN]: `TransitGatewayRouteTableRoute`,
        [_xN]: _tGRTR
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `TransitGatewayAttachment`,
        [_xN]: _tGAr
      }], [0, {
        [_eQN]: `ComponentAccount`,
        [_xN]: _cAo
      }], [0, {
        [_eQN]: `ComponentRegion`,
        [_xN]: _cRo
      }], [() => exports2.FirewallStatelessRule$, {
        [_eQN]: `FirewallStatelessRule`,
        [_xN]: _fSR
      }], [() => exports2.FirewallStatefulRule$, {
        [_eQN]: `FirewallStatefulRule`,
        [_xN]: _fSRi
      }]]
    ];
    exports2.ExportClientVpnClientCertificateRevocationListRequest$ = [
      3,
      n032,
      _ECVCCRLR,
      0,
      [_CVEI, _DR],
      [0, 2],
      1
    ];
    exports2.ExportClientVpnClientCertificateRevocationListResult$ = [
      3,
      n032,
      _ECVCCRLRx,
      0,
      [_CRL, _Sta],
      [[0, {
        [_eQN]: `CertificateRevocationList`,
        [_xN]: _cRL
      }], [() => exports2.ClientCertificateRevocationListStatus$, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }]]
    ];
    exports2.ExportClientVpnClientConfigurationRequest$ = [
      3,
      n032,
      _ECVCCR,
      0,
      [_CVEI, _DR],
      [0, 2],
      1
    ];
    exports2.ExportClientVpnClientConfigurationResult$ = [
      3,
      n032,
      _ECVCCRx,
      0,
      [_CCl],
      [[0, {
        [_eQN]: `ClientConfiguration`,
        [_xN]: _cCl
      }]]
    ];
    exports2.ExportImageRequest$ = [
      3,
      n032,
      _EIRx,
      0,
      [_DIF, _IIm, _SEL, _CT4, _De, _DR, _RNo, _TS],
      [0, 0, () => exports2.ExportTaskS3LocationRequest$, [0, 4], 0, 2, 0, [() => TagSpecificationList, { [_xN]: _TSa }]],
      3
    ];
    exports2.ExportImageResult$ = [
      3,
      n032,
      _EIRxp,
      0,
      [_De, _DIF, _EITIx, _IIm, _RNo, _Pro, _SEL, _Sta, _SMt, _T10],
      [[0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [0, {
        [_eQN]: `DiskImageFormat`,
        [_xN]: _dIF
      }], [0, {
        [_eQN]: `ExportImageTaskId`,
        [_xN]: _eITI
      }], [0, {
        [_eQN]: `ImageId`,
        [_xN]: _iIma
      }], [0, {
        [_eQN]: `RoleName`,
        [_xN]: _rNo
      }], [0, {
        [_eQN]: `Progress`,
        [_xN]: _pro
      }], [() => exports2.ExportTaskS3Location$, {
        [_eQN]: `S3ExportLocation`,
        [_xN]: _sEL
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `StatusMessage`,
        [_xN]: _sMt
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.ExportImageTask$ = [
      3,
      n032,
      _EITx,
      0,
      [_De, _EITIx, _IIm, _Pro, _SEL, _Sta, _SMt, _T10],
      [[0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [0, {
        [_eQN]: `ExportImageTaskId`,
        [_xN]: _eITI
      }], [0, {
        [_eQN]: `ImageId`,
        [_xN]: _iIma
      }], [0, {
        [_eQN]: `Progress`,
        [_xN]: _pro
      }], [() => exports2.ExportTaskS3Location$, {
        [_eQN]: `S3ExportLocation`,
        [_xN]: _sEL
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `StatusMessage`,
        [_xN]: _sMt
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.ExportTask$ = [
      3,
      n032,
      _ETx,
      0,
      [_De, _ETI, _ETST, _IED, _St, _SMt, _T10],
      [[0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [0, {
        [_eQN]: `ExportTaskId`,
        [_xN]: _eTI
      }], [() => exports2.ExportToS3Task$, {
        [_eQN]: `ExportToS3`,
        [_xN]: _eTS
      }], [() => exports2.InstanceExportDetails$, {
        [_eQN]: `InstanceExport`,
        [_xN]: _iE
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `StatusMessage`,
        [_xN]: _sMt
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.ExportTaskS3Location$ = [
      3,
      n032,
      _ETSL,
      0,
      [_SB, _SP],
      [[0, {
        [_eQN]: `S3Bucket`,
        [_xN]: _sB
      }], [0, {
        [_eQN]: `S3Prefix`,
        [_xN]: _sP
      }]]
    ];
    exports2.ExportTaskS3LocationRequest$ = [
      3,
      n032,
      _ETSLR,
      0,
      [_SB, _SP],
      [0, 0],
      1
    ];
    exports2.ExportToS3Task$ = [
      3,
      n032,
      _ETST,
      0,
      [_CF, _DIF, _SB, _SK2],
      [[0, {
        [_eQN]: `ContainerFormat`,
        [_xN]: _cF
      }], [0, {
        [_eQN]: `DiskImageFormat`,
        [_xN]: _dIF
      }], [0, {
        [_eQN]: `S3Bucket`,
        [_xN]: _sB
      }], [0, {
        [_eQN]: `S3Key`,
        [_xN]: _sK
      }]]
    ];
    exports2.ExportToS3TaskSpecification$ = [
      3,
      n032,
      _ETSTS,
      0,
      [_DIF, _CF, _SB, _SP],
      [[0, {
        [_eQN]: `DiskImageFormat`,
        [_xN]: _dIF
      }], [0, {
        [_eQN]: `ContainerFormat`,
        [_xN]: _cF
      }], [0, {
        [_eQN]: `S3Bucket`,
        [_xN]: _sB
      }], [0, {
        [_eQN]: `S3Prefix`,
        [_xN]: _sP
      }]]
    ];
    exports2.ExportTransitGatewayRoutesRequest$ = [
      3,
      n032,
      _ETGRR,
      0,
      [_TGRTI, _SB, _Fi, _DR],
      [0, 0, [() => FilterList, { [_xN]: _Fil }], 2],
      2
    ];
    exports2.ExportTransitGatewayRoutesResult$ = [
      3,
      n032,
      _ETGRRx,
      0,
      [_SLo],
      [[0, {
        [_eQN]: `S3Location`,
        [_xN]: _sL
      }]]
    ];
    exports2.ExportVerifiedAccessInstanceClientConfigurationRequest$ = [
      3,
      n032,
      _EVAICCR,
      0,
      [_VAII, _DR],
      [0, 2],
      1
    ];
    exports2.ExportVerifiedAccessInstanceClientConfigurationResult$ = [
      3,
      n032,
      _EVAICCRx,
      0,
      [_Ver, _VAII, _Regi, _DTP, _UTP, _OVC],
      [[0, {
        [_eQN]: `Version`,
        [_xN]: _ve
      }], [0, {
        [_eQN]: `VerifiedAccessInstanceId`,
        [_xN]: _vAII
      }], [0, {
        [_eQN]: `Region`,
        [_xN]: _reg
      }], [() => DeviceTrustProviderTypeList, {
        [_eQN]: `DeviceTrustProviderSet`,
        [_xN]: _dTPS
      }], [() => exports2.VerifiedAccessInstanceUserTrustProviderClientConfiguration$, {
        [_eQN]: `UserTrustProvider`,
        [_xN]: _uTP
      }], [() => VerifiedAccessInstanceOpenVpnClientConfigurationList, {
        [_eQN]: `OpenVpnConfigurationSet`,
        [_xN]: _oVCS
      }]]
    ];
    exports2.ExternalAuthorityConfiguration$ = [
      3,
      n032,
      _EAC,
      0,
      [_Ty, _ERI],
      [0, 0]
    ];
    exports2.FailedCapacityReservationFleetCancellationResult$ = [
      3,
      n032,
      _FCRFCR,
      0,
      [_CRFIa, _CCRFE],
      [[0, {
        [_eQN]: `CapacityReservationFleetId`,
        [_xN]: _cRFI
      }], [() => exports2.CancelCapacityReservationFleetError$, {
        [_eQN]: `CancelCapacityReservationFleetError`,
        [_xN]: _cCRFE
      }]]
    ];
    exports2.FailedQueuedPurchaseDeletion$ = [
      3,
      n032,
      _FQPDa,
      0,
      [_Er, _RIIes],
      [[() => exports2.DeleteQueuedReservedInstancesError$, {
        [_eQN]: `Error`,
        [_xN]: _er
      }], [0, {
        [_eQN]: `ReservedInstancesId`,
        [_xN]: _rII
      }]]
    ];
    exports2.FastLaunchLaunchTemplateSpecificationRequest$ = [
      3,
      n032,
      _FLLTSR,
      0,
      [_Ver, _LTI, _LTN],
      [0, 0, 0],
      1
    ];
    exports2.FastLaunchLaunchTemplateSpecificationResponse$ = [
      3,
      n032,
      _FLLTSRa,
      0,
      [_LTI, _LTN, _Ver],
      [[0, {
        [_eQN]: `LaunchTemplateId`,
        [_xN]: _lTI
      }], [0, {
        [_eQN]: `LaunchTemplateName`,
        [_xN]: _lTN
      }], [0, {
        [_eQN]: `Version`,
        [_xN]: _ve
      }]]
    ];
    exports2.FastLaunchSnapshotConfigurationRequest$ = [
      3,
      n032,
      _FLSCR,
      0,
      [_TRC],
      [1]
    ];
    exports2.FastLaunchSnapshotConfigurationResponse$ = [
      3,
      n032,
      _FLSCRa,
      0,
      [_TRC],
      [[1, {
        [_eQN]: `TargetResourceCount`,
        [_xN]: _tRC
      }]]
    ];
    exports2.FederatedAuthentication$ = [
      3,
      n032,
      _FA,
      0,
      [_SPA, _SSSPA],
      [[0, {
        [_eQN]: `SamlProviderArn`,
        [_xN]: _sPA
      }], [0, {
        [_eQN]: `SelfServiceSamlProviderArn`,
        [_xN]: _sSSPA
      }]]
    ];
    exports2.FederatedAuthenticationRequest$ = [
      3,
      n032,
      _FAR,
      0,
      [_SAMLPA, _SSSAMLPA],
      [0, 0]
    ];
    exports2.Filter$ = [
      3,
      n032,
      _Fil,
      0,
      [_N, _Va],
      [0, [() => ValueStringList, { [_xN]: _V10 }]]
    ];
    exports2.FilterPortRange$ = [
      3,
      n032,
      _FPR,
      0,
      [_FP, _TP],
      [[1, {
        [_eQN]: `FromPort`,
        [_xN]: _fP
      }], [1, {
        [_eQN]: `ToPort`,
        [_xN]: _tP
      }]]
    ];
    exports2.FirewallStatefulRule$ = [
      3,
      n032,
      _FSRir,
      0,
      [_RGA, _So, _Des, _SPo, _DPes, _Pr10, _RA10, _Di],
      [[0, {
        [_eQN]: `RuleGroupArn`,
        [_xN]: _rGA
      }], [() => ValueStringList, {
        [_eQN]: `SourceSet`,
        [_xN]: _sSo
      }], [() => ValueStringList, {
        [_eQN]: `DestinationSet`,
        [_xN]: _dSe
      }], [() => PortRangeList, {
        [_eQN]: `SourcePortSet`,
        [_xN]: _sPS
      }], [() => PortRangeList, {
        [_eQN]: `DestinationPortSet`,
        [_xN]: _dPS
      }], [0, {
        [_eQN]: `Protocol`,
        [_xN]: _pr
      }], [0, {
        [_eQN]: `RuleAction`,
        [_xN]: _rA
      }], [0, {
        [_eQN]: `Direction`,
        [_xN]: _di
      }]]
    ];
    exports2.FirewallStatelessRule$ = [
      3,
      n032,
      _FSRi,
      0,
      [_RGA, _So, _Des, _SPo, _DPes, _Prot, _RA10, _Prio],
      [[0, {
        [_eQN]: `RuleGroupArn`,
        [_xN]: _rGA
      }], [() => ValueStringList, {
        [_eQN]: `SourceSet`,
        [_xN]: _sSo
      }], [() => ValueStringList, {
        [_eQN]: `DestinationSet`,
        [_xN]: _dSe
      }], [() => PortRangeList, {
        [_eQN]: `SourcePortSet`,
        [_xN]: _sPS
      }], [() => PortRangeList, {
        [_eQN]: `DestinationPortSet`,
        [_xN]: _dPS
      }], [() => ProtocolIntList, {
        [_eQN]: `ProtocolSet`,
        [_xN]: _pSro
      }], [0, {
        [_eQN]: `RuleAction`,
        [_xN]: _rA
      }], [1, {
        [_eQN]: `Priority`,
        [_xN]: _pri
      }]]
    ];
    exports2.FleetBlockDeviceMappingRequest$ = [
      3,
      n032,
      _FBDMR,
      0,
      [_DN, _VN, _Eb, _ND],
      [0, 0, () => exports2.FleetEbsBlockDeviceRequest$, 0]
    ];
    exports2.FleetCapacityReservation$ = [
      3,
      n032,
      _FCRl,
      0,
      [_CRI, _AZI, _IT4, _IPn, _AZ, _TIC, _FCu, _EO, _CD, _We, _Prio],
      [[0, {
        [_eQN]: `CapacityReservationId`,
        [_xN]: _cRI
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [0, {
        [_eQN]: `InstancePlatform`,
        [_xN]: _iPn
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [1, {
        [_eQN]: `TotalInstanceCount`,
        [_xN]: _tIC
      }], [1, {
        [_eQN]: `FulfilledCapacity`,
        [_xN]: _fC
      }], [2, {
        [_eQN]: `EbsOptimized`,
        [_xN]: _eO
      }], [4, {
        [_eQN]: `CreateDate`,
        [_xN]: _cD
      }], [1, {
        [_eQN]: `Weight`,
        [_xN]: _we
      }], [1, {
        [_eQN]: `Priority`,
        [_xN]: _pri
      }]]
    ];
    exports2.FleetData$ = [
      3,
      n032,
      _FDl,
      0,
      [_ASc, _CTr, _FIl, _FS, _CT4, _ECTP, _FCu, _FODC, _LTC, _TCS, _TIWE, _Ty, _VF, _VU, _RUI, _SO, _ODO, _RCO, _T10, _Err, _Ins, _Con],
      [[0, {
        [_eQN]: `ActivityStatus`,
        [_xN]: _aSc
      }], [4, {
        [_eQN]: `CreateTime`,
        [_xN]: _cTr
      }], [0, {
        [_eQN]: `FleetId`,
        [_xN]: _fIl
      }], [0, {
        [_eQN]: `FleetState`,
        [_xN]: _fSl
      }], [0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }], [0, {
        [_eQN]: `ExcessCapacityTerminationPolicy`,
        [_xN]: _eCTP
      }], [1, {
        [_eQN]: `FulfilledCapacity`,
        [_xN]: _fC
      }], [1, {
        [_eQN]: `FulfilledOnDemandCapacity`,
        [_xN]: _fODC
      }], [() => FleetLaunchTemplateConfigList, {
        [_eQN]: `LaunchTemplateConfigs`,
        [_xN]: _lTC
      }], [() => exports2.TargetCapacitySpecification$, {
        [_eQN]: `TargetCapacitySpecification`,
        [_xN]: _tCS
      }], [2, {
        [_eQN]: `TerminateInstancesWithExpiration`,
        [_xN]: _tIWE
      }], [0, {
        [_eQN]: `Type`,
        [_xN]: _ty
      }], [4, {
        [_eQN]: `ValidFrom`,
        [_xN]: _vF
      }], [4, {
        [_eQN]: `ValidUntil`,
        [_xN]: _vU
      }], [2, {
        [_eQN]: `ReplaceUnhealthyInstances`,
        [_xN]: _rUI
      }], [() => exports2.SpotOptions$, {
        [_eQN]: `SpotOptions`,
        [_xN]: _sO
      }], [() => exports2.OnDemandOptions$, {
        [_eQN]: `OnDemandOptions`,
        [_xN]: _oDO
      }], [() => exports2.ReservedCapacityOptions$, {
        [_eQN]: `ReservedCapacityOptions`,
        [_xN]: _rCO
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [() => DescribeFleetsErrorSet, {
        [_eQN]: `ErrorSet`,
        [_xN]: _eSr
      }], [() => DescribeFleetsInstancesSet, {
        [_eQN]: `FleetInstanceSet`,
        [_xN]: _fIS
      }], [0, {
        [_eQN]: `Context`,
        [_xN]: _cont
      }]]
    ];
    exports2.FleetEbsBlockDeviceRequest$ = [
      3,
      n032,
      _FEBDR,
      0,
      [_Enc, _DOT, _Io, _Th, _KKI, _SIn, _VSo, _VT],
      [2, 2, 1, 1, 0, 0, 1, 0]
    ];
    exports2.FleetLaunchTemplateConfig$ = [
      3,
      n032,
      _FLTC,
      0,
      [_LTS, _Ov],
      [[() => exports2.FleetLaunchTemplateSpecification$, {
        [_eQN]: `LaunchTemplateSpecification`,
        [_xN]: _lTS
      }], [() => FleetLaunchTemplateOverridesList, {
        [_eQN]: `Overrides`,
        [_xN]: _ov
      }]]
    ];
    exports2.FleetLaunchTemplateConfigRequest$ = [
      3,
      n032,
      _FLTCR,
      0,
      [_LTS, _Ov],
      [() => exports2.FleetLaunchTemplateSpecificationRequest$, [() => FleetLaunchTemplateOverridesListRequest, 0]]
    ];
    exports2.FleetLaunchTemplateOverrides$ = [
      3,
      n032,
      _FLTO,
      0,
      [_IT4, _MPax, _SIu, _AZ, _WCe, _Prio, _Pla, _IRn, _IIm, _BDMl, _AZI],
      [[0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [0, {
        [_eQN]: `MaxPrice`,
        [_xN]: _mP
      }], [0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [1, {
        [_eQN]: `WeightedCapacity`,
        [_xN]: _wC
      }], [1, {
        [_eQN]: `Priority`,
        [_xN]: _pri
      }], [() => exports2.PlacementResponse$, {
        [_eQN]: `Placement`,
        [_xN]: _pla
      }], [() => exports2.InstanceRequirements$, {
        [_eQN]: `InstanceRequirements`,
        [_xN]: _iR
      }], [0, {
        [_eQN]: `ImageId`,
        [_xN]: _iIma
      }], [() => BlockDeviceMappingResponseList, {
        [_eQN]: `BlockDeviceMappingSet`,
        [_xN]: _bDMS
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }]]
    ];
    exports2.FleetLaunchTemplateOverridesRequest$ = [
      3,
      n032,
      _FLTOR,
      0,
      [_IT4, _MPax, _SIu, _AZ, _WCe, _Prio, _Pla, _BDMl, _IRn, _IIm, _AZI],
      [0, 0, 0, 0, 1, 1, [() => exports2.Placement$, 0], [() => FleetBlockDeviceMappingRequestList, { [_xN]: _BDM }], [() => exports2.InstanceRequirementsRequest$, 0], 0, 0]
    ];
    exports2.FleetLaunchTemplateSpecification$ = [
      3,
      n032,
      _FLTS,
      0,
      [_LTI, _LTN, _Ver],
      [[0, {
        [_eQN]: `LaunchTemplateId`,
        [_xN]: _lTI
      }], [0, {
        [_eQN]: `LaunchTemplateName`,
        [_xN]: _lTN
      }], [0, {
        [_eQN]: `Version`,
        [_xN]: _ve
      }]]
    ];
    exports2.FleetLaunchTemplateSpecificationRequest$ = [
      3,
      n032,
      _FLTSR,
      0,
      [_LTI, _LTN, _Ver],
      [0, 0, 0]
    ];
    exports2.FleetSpotCapacityRebalance$ = [
      3,
      n032,
      _FSCR,
      0,
      [_RSep, _TDe],
      [[0, {
        [_eQN]: `ReplacementStrategy`,
        [_xN]: _rSepl
      }], [1, {
        [_eQN]: `TerminationDelay`,
        [_xN]: _tD
      }]]
    ];
    exports2.FleetSpotCapacityRebalanceRequest$ = [
      3,
      n032,
      _FSCRR,
      0,
      [_RSep, _TDe],
      [0, 1]
    ];
    exports2.FleetSpotMaintenanceStrategies$ = [
      3,
      n032,
      _FSMS,
      0,
      [_CRapa],
      [[() => exports2.FleetSpotCapacityRebalance$, {
        [_eQN]: `CapacityRebalance`,
        [_xN]: _cRa
      }]]
    ];
    exports2.FleetSpotMaintenanceStrategiesRequest$ = [
      3,
      n032,
      _FSMSR,
      0,
      [_CRapa],
      [() => exports2.FleetSpotCapacityRebalanceRequest$]
    ];
    exports2.FlowLog$ = [
      3,
      n032,
      _FLl,
      0,
      [_CTre, _DLEM, _DLPA, _DCAR, _DLS, _FLIl, _FLS, _LGN, _RIeso, _TT, _LDTo, _LD, _LF, _T10, _MAI, _DOe],
      [[4, {
        [_eQN]: `CreationTime`,
        [_xN]: _cTre
      }], [0, {
        [_eQN]: `DeliverLogsErrorMessage`,
        [_xN]: _dLEM
      }], [0, {
        [_eQN]: `DeliverLogsPermissionArn`,
        [_xN]: _dLPA
      }], [0, {
        [_eQN]: `DeliverCrossAccountRole`,
        [_xN]: _dCAR
      }], [0, {
        [_eQN]: `DeliverLogsStatus`,
        [_xN]: _dLS
      }], [0, {
        [_eQN]: `FlowLogId`,
        [_xN]: _fLI
      }], [0, {
        [_eQN]: `FlowLogStatus`,
        [_xN]: _fLSl
      }], [0, {
        [_eQN]: `LogGroupName`,
        [_xN]: _lGN
      }], [0, {
        [_eQN]: `ResourceId`,
        [_xN]: _rIes
      }], [0, {
        [_eQN]: `TrafficType`,
        [_xN]: _tT13
      }], [0, {
        [_eQN]: `LogDestinationType`,
        [_xN]: _lDTo
      }], [0, {
        [_eQN]: `LogDestination`,
        [_xN]: _lD
      }], [0, {
        [_eQN]: `LogFormat`,
        [_xN]: _lF
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [1, {
        [_eQN]: `MaxAggregationInterval`,
        [_xN]: _mAI
      }], [() => exports2.DestinationOptionsResponse$, {
        [_eQN]: `DestinationOptions`,
        [_xN]: _dOe
      }]]
    ];
    exports2.FpgaDeviceInfo$ = [
      3,
      n032,
      _FDI,
      0,
      [_N, _Man, _Cou, _MIe],
      [[0, {
        [_eQN]: `Name`,
        [_xN]: _n
      }], [0, {
        [_eQN]: `Manufacturer`,
        [_xN]: _man
      }], [1, {
        [_eQN]: `Count`,
        [_xN]: _cou
      }], [() => exports2.FpgaDeviceMemoryInfo$, {
        [_eQN]: `MemoryInfo`,
        [_xN]: _mIe
      }]]
    ];
    exports2.FpgaDeviceMemoryInfo$ = [
      3,
      n032,
      _FDMI,
      0,
      [_SIMB],
      [[1, {
        [_eQN]: `SizeInMiB`,
        [_xN]: _sIMB
      }]]
    ];
    exports2.FpgaImage$ = [
      3,
      n032,
      _FIpg,
      0,
      [_FII, _FIGI, _N, _De, _SVh, _PIc, _St, _CTr, _UT, _OI, _OAw, _PCro, _T10, _Pu, _DRS, _ITnst],
      [[0, {
        [_eQN]: `FpgaImageId`,
        [_xN]: _fII
      }], [0, {
        [_eQN]: `FpgaImageGlobalId`,
        [_xN]: _fIGI
      }], [0, {
        [_eQN]: `Name`,
        [_xN]: _n
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [0, {
        [_eQN]: `ShellVersion`,
        [_xN]: _sVh
      }], [() => exports2.PciId$, {
        [_eQN]: `PciId`,
        [_xN]: _pIc
      }], [() => exports2.FpgaImageState$, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [4, {
        [_eQN]: `CreateTime`,
        [_xN]: _cTr
      }], [4, {
        [_eQN]: `UpdateTime`,
        [_xN]: _uT
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `OwnerAlias`,
        [_xN]: _oAw
      }], [() => ProductCodeList, {
        [_eQN]: `ProductCodes`,
        [_xN]: _pC
      }], [() => TagList, {
        [_eQN]: `Tags`,
        [_xN]: _tag
      }], [2, {
        [_eQN]: `Public`,
        [_xN]: _pu
      }], [2, {
        [_eQN]: `DataRetentionSupport`,
        [_xN]: _dRS
      }], [() => InstanceTypesList, {
        [_eQN]: `InstanceTypes`,
        [_xN]: _iTnst
      }]]
    ];
    exports2.FpgaImageAttribute$ = [
      3,
      n032,
      _FIA,
      0,
      [_FII, _N, _De, _LP, _PCro],
      [[0, {
        [_eQN]: `FpgaImageId`,
        [_xN]: _fII
      }], [0, {
        [_eQN]: `Name`,
        [_xN]: _n
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [() => LoadPermissionList, {
        [_eQN]: `LoadPermissions`,
        [_xN]: _lP
      }], [() => ProductCodeList, {
        [_eQN]: `ProductCodes`,
        [_xN]: _pC
      }]]
    ];
    exports2.FpgaImageState$ = [
      3,
      n032,
      _FIS,
      0,
      [_Co, _Me],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }]]
    ];
    exports2.FpgaInfo$ = [
      3,
      n032,
      _FIpga,
      0,
      [_Fp, _TFMIMB],
      [[() => FpgaDeviceInfoList, {
        [_eQN]: `Fpgas`,
        [_xN]: _fp
      }], [1, {
        [_eQN]: `TotalFpgaMemoryInMiB`,
        [_xN]: _tFMIMB
      }]]
    ];
    exports2.GetActiveVpnTunnelStatusRequest$ = [
      3,
      n032,
      _GAVTSR,
      0,
      [_VCIp, _VTOIA, _DR],
      [0, 0, 2],
      2
    ];
    exports2.GetActiveVpnTunnelStatusResult$ = [
      3,
      n032,
      _GAVTSRe,
      0,
      [_AVTS],
      [[() => exports2.ActiveVpnTunnelStatus$, {
        [_eQN]: `ActiveVpnTunnelStatus`,
        [_xN]: _aVTS
      }]]
    ];
    exports2.GetAllowedImagesSettingsRequest$ = [
      3,
      n032,
      _GAISR,
      0,
      [_DR],
      [2]
    ];
    exports2.GetAllowedImagesSettingsResult$ = [
      3,
      n032,
      _GAISRe,
      0,
      [_St, _ICm, _MB],
      [[0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [() => ImageCriterionList, {
        [_eQN]: `ImageCriterionSet`,
        [_xN]: _iCS
      }], [0, {
        [_eQN]: `ManagedBy`,
        [_xN]: _mB
      }]]
    ];
    exports2.GetAssociatedEnclaveCertificateIamRolesRequest$ = [
      3,
      n032,
      _GAECIRR,
      0,
      [_CAe, _DR],
      [0, 2],
      1
    ];
    exports2.GetAssociatedEnclaveCertificateIamRolesResult$ = [
      3,
      n032,
      _GAECIRRe,
      0,
      [_ARsso],
      [[() => AssociatedRolesList, {
        [_eQN]: `AssociatedRoleSet`,
        [_xN]: _aRS
      }]]
    ];
    exports2.GetAssociatedIpv6PoolCidrsRequest$ = [
      3,
      n032,
      _GAIPCR,
      0,
      [_PIo, _NTe, _MR, _DR],
      [0, 0, 1, 2],
      1
    ];
    exports2.GetAssociatedIpv6PoolCidrsResult$ = [
      3,
      n032,
      _GAIPCRe,
      0,
      [_ICAp, _NTe],
      [[() => Ipv6CidrAssociationSet, {
        [_eQN]: `Ipv6CidrAssociationSet`,
        [_xN]: _iCAS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetAwsNetworkPerformanceDataRequest$ = [
      3,
      n032,
      _GANPDR,
      0,
      [_DQa, _ST11, _ETnd, _MR, _NTe, _DR],
      [[() => DataQueries, { [_xN]: _DQ }], 4, 4, 1, 0, 2]
    ];
    exports2.GetAwsNetworkPerformanceDataResult$ = [
      3,
      n032,
      _GANPDRe,
      0,
      [_DRat, _NTe],
      [[() => DataResponses, {
        [_eQN]: `DataResponseSet`,
        [_xN]: _dRSa
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetCapacityManagerAttributesRequest$ = [
      3,
      n032,
      _GCMAR,
      0,
      [_DR],
      [2]
    ];
    exports2.GetCapacityManagerAttributesResult$ = [
      3,
      n032,
      _GCMARe,
      0,
      [_CMS, _OAr, _DEC, _ISng, _ISM, _EDT, _LDTa],
      [[0, {
        [_eQN]: `CapacityManagerStatus`,
        [_xN]: _cMS
      }], [2, {
        [_eQN]: `OrganizationsAccess`,
        [_xN]: _oAr
      }], [1, {
        [_eQN]: `DataExportCount`,
        [_xN]: _dEC
      }], [0, {
        [_eQN]: `IngestionStatus`,
        [_xN]: _iSng
      }], [0, {
        [_eQN]: `IngestionStatusMessage`,
        [_xN]: _iSM
      }], [4, {
        [_eQN]: `EarliestDatapointTimestamp`,
        [_xN]: _eDT
      }], [4, {
        [_eQN]: `LatestDatapointTimestamp`,
        [_xN]: _lDTa
      }]]
    ];
    exports2.GetCapacityManagerMetricDataRequest$ = [
      3,
      n032,
      _GCMMDR,
      0,
      [_MN, _ST11, _ETnd, _Per, _GB, _FB, _MR, _NTe, _DR],
      [[() => MetricSet, { [_xN]: _MNe }], 4, 4, 1, [() => GroupBySet, { [_xN]: _GB }], [() => CapacityManagerConditionSet, 0], 1, 0, 2],
      4
    ];
    exports2.GetCapacityManagerMetricDataResult$ = [
      3,
      n032,
      _GCMMDRe,
      0,
      [_MDR, _NTe],
      [[() => MetricDataResultSet, {
        [_eQN]: `MetricDataResultSet`,
        [_xN]: _mDRS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetCapacityManagerMetricDimensionsRequest$ = [
      3,
      n032,
      _GCMMDRet,
      0,
      [_GB, _ST11, _ETnd, _MN, _FB, _MR, _NTe, _DR],
      [[() => GroupBySet, { [_xN]: _GB }], 4, 4, [() => MetricSet, { [_xN]: _MNe }], [() => CapacityManagerConditionSet, 0], 1, 0, 2],
      4
    ];
    exports2.GetCapacityManagerMetricDimensionsResult$ = [
      3,
      n032,
      _GCMMDReta,
      0,
      [_MDRe, _NTe],
      [[() => MetricDimensionResultSet, {
        [_eQN]: `MetricDimensionResultSet`,
        [_xN]: _mDRSe
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetCapacityManagerMonitoredTagKeysRequest$ = [
      3,
      n032,
      _GCMMTKR,
      0,
      [_MR, _NTe, _DR],
      [1, 0, 2]
    ];
    exports2.GetCapacityManagerMonitoredTagKeysResult$ = [
      3,
      n032,
      _GCMMTKRe,
      0,
      [_CMTK, _NTe],
      [[() => CapacityManagerMonitoredTagKeyList, {
        [_eQN]: `CapacityManagerTagKeySet`,
        [_xN]: _cMTKS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetCapacityReservationUsageRequest$ = [
      3,
      n032,
      _GCRUR,
      0,
      [_CRI, _NTe, _MR, _DR],
      [0, 0, 1, 2],
      1
    ];
    exports2.GetCapacityReservationUsageResult$ = [
      3,
      n032,
      _GCRURe,
      0,
      [_NTe, _CRI, _IT4, _TIC, _AICv, _St, _IU, _Int, _ICA, _IIn],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [0, {
        [_eQN]: `CapacityReservationId`,
        [_xN]: _cRI
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [1, {
        [_eQN]: `TotalInstanceCount`,
        [_xN]: _tIC
      }], [1, {
        [_eQN]: `AvailableInstanceCount`,
        [_xN]: _aICv
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [() => InstanceUsageSet, {
        [_eQN]: `InstanceUsageSet`,
        [_xN]: _iUS
      }], [2, {
        [_eQN]: `Interruptible`,
        [_xN]: _int
      }], [() => exports2.InterruptibleCapacityAllocation$, {
        [_eQN]: `InterruptibleCapacityAllocation`,
        [_xN]: _iCA
      }], [() => exports2.InterruptionInfo$, {
        [_eQN]: `InterruptionInfo`,
        [_xN]: _iIn
      }]]
    ];
    exports2.GetCoipPoolUsageRequest$ = [
      3,
      n032,
      _GCPUR,
      0,
      [_PIo, _Fi, _MR, _NTe, _DR],
      [0, [() => FilterList, { [_xN]: _Fil }], 1, 0, 2],
      1
    ];
    exports2.GetCoipPoolUsageResult$ = [
      3,
      n032,
      _GCPURe,
      0,
      [_CPI, _CAUo, _LGRTI, _NTe],
      [[0, {
        [_eQN]: `CoipPoolId`,
        [_xN]: _cPI
      }], [() => CoipAddressUsageSet, {
        [_eQN]: `CoipAddressUsageSet`,
        [_xN]: _cAUS
      }], [0, {
        [_eQN]: `LocalGatewayRouteTableId`,
        [_xN]: _lGRTI
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetConsoleOutputRequest$ = [
      3,
      n032,
      _GCOR,
      0,
      [_II2, _La, _DR],
      [0, 2, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.GetConsoleOutputResult$ = [
      3,
      n032,
      _GCORe,
      0,
      [_II2, _Ti, _Ou],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [4, {
        [_eQN]: `Timestamp`,
        [_xN]: _ti
      }], [0, {
        [_eQN]: `Output`,
        [_xN]: _ou
      }]]
    ];
    exports2.GetConsoleScreenshotRequest$ = [
      3,
      n032,
      _GCSR,
      0,
      [_II2, _DR, _WU],
      [0, 2, 2],
      1
    ];
    exports2.GetConsoleScreenshotResult$ = [
      3,
      n032,
      _GCSRe,
      0,
      [_IDm, _II2],
      [[0, {
        [_eQN]: `ImageData`,
        [_xN]: _iD
      }], [0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }]]
    ];
    exports2.GetDeclarativePoliciesReportSummaryRequest$ = [
      3,
      n032,
      _GDPRSR,
      0,
      [_RI, _DR],
      [0, 2],
      1
    ];
    exports2.GetDeclarativePoliciesReportSummaryResult$ = [
      3,
      n032,
      _GDPRSRe,
      0,
      [_RI, _SB, _SP, _TIa, _ST11, _ETnd, _NOA, _NOFA, _AStt],
      [[0, {
        [_eQN]: `ReportId`,
        [_xN]: _rIe
      }], [0, {
        [_eQN]: `S3Bucket`,
        [_xN]: _sB
      }], [0, {
        [_eQN]: `S3Prefix`,
        [_xN]: _sP
      }], [0, {
        [_eQN]: `TargetId`,
        [_xN]: _tIa
      }], [4, {
        [_eQN]: `StartTime`,
        [_xN]: _sT19
      }], [4, {
        [_eQN]: `EndTime`,
        [_xN]: _eTn
      }], [1, {
        [_eQN]: `NumberOfAccounts`,
        [_xN]: _nOA
      }], [1, {
        [_eQN]: `NumberOfFailedAccounts`,
        [_xN]: _nOFA
      }], [() => AttributeSummaryList, {
        [_eQN]: `AttributeSummarySet`,
        [_xN]: _aSSt
      }]]
    ];
    exports2.GetDefaultCreditSpecificationRequest$ = [
      3,
      n032,
      _GDCSR,
      0,
      [_IF, _DR],
      [0, 2],
      1
    ];
    exports2.GetDefaultCreditSpecificationResult$ = [
      3,
      n032,
      _GDCSRe,
      0,
      [_IFCS],
      [[() => exports2.InstanceFamilyCreditSpecification$, {
        [_eQN]: `InstanceFamilyCreditSpecification`,
        [_xN]: _iFCS
      }]]
    ];
    exports2.GetEbsDefaultKmsKeyIdRequest$ = [
      3,
      n032,
      _GEDKKIR,
      0,
      [_DR],
      [2]
    ];
    exports2.GetEbsDefaultKmsKeyIdResult$ = [
      3,
      n032,
      _GEDKKIRe,
      0,
      [_KKI],
      [[0, {
        [_eQN]: `KmsKeyId`,
        [_xN]: _kKI
      }]]
    ];
    exports2.GetEbsEncryptionByDefaultRequest$ = [
      3,
      n032,
      _GEEBDR,
      0,
      [_DR],
      [2]
    ];
    exports2.GetEbsEncryptionByDefaultResult$ = [
      3,
      n032,
      _GEEBDRe,
      0,
      [_EEBD, _STs],
      [[2, {
        [_eQN]: `EbsEncryptionByDefault`,
        [_xN]: _eEBD
      }], [0, {
        [_eQN]: `SseType`,
        [_xN]: _sTs
      }]]
    ];
    exports2.GetEnabledIpamPolicyRequest$ = [
      3,
      n032,
      _GEIPR,
      0,
      [_DR],
      [2]
    ];
    exports2.GetEnabledIpamPolicyResult$ = [
      3,
      n032,
      _GEIPRe,
      0,
      [_IPE2, _IPIp, _MB],
      [[2, {
        [_eQN]: `IpamPolicyEnabled`,
        [_xN]: _iPE
      }], [0, {
        [_eQN]: `IpamPolicyId`,
        [_xN]: _iPI
      }], [0, {
        [_eQN]: `ManagedBy`,
        [_xN]: _mB
      }]]
    ];
    exports2.GetFlowLogsIntegrationTemplateRequest$ = [
      3,
      n032,
      _GFLITR,
      0,
      [_FLIl, _CDSDA, _ISnt, _DR],
      [0, 0, [() => exports2.IntegrateServices$, { [_xN]: _ISnte }], 2],
      3
    ];
    exports2.GetFlowLogsIntegrationTemplateResult$ = [
      3,
      n032,
      _GFLITRe,
      0,
      [_Resu],
      [[0, {
        [_eQN]: `Result`,
        [_xN]: _res
      }]]
    ];
    exports2.GetGroupsForCapacityReservationRequest$ = [
      3,
      n032,
      _GGFCRR,
      0,
      [_CRI, _NTe, _MR, _DR],
      [0, 0, 1, 2],
      1
    ];
    exports2.GetGroupsForCapacityReservationResult$ = [
      3,
      n032,
      _GGFCRRe,
      0,
      [_NTe, _CRGa],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => CapacityReservationGroupSet, {
        [_eQN]: `CapacityReservationGroupSet`,
        [_xN]: _cRGS
      }]]
    ];
    exports2.GetHostReservationPurchasePreviewRequest$ = [
      3,
      n032,
      _GHRPPR,
      0,
      [_HIS, _OIf],
      [[() => RequestHostIdSet, 0], 0],
      2
    ];
    exports2.GetHostReservationPurchasePreviewResult$ = [
      3,
      n032,
      _GHRPPRe,
      0,
      [_CC, _Pur, _THP, _TUP],
      [[0, {
        [_eQN]: `CurrencyCode`,
        [_xN]: _cC
      }], [() => PurchaseSet, {
        [_eQN]: `Purchase`,
        [_xN]: _pur
      }], [0, {
        [_eQN]: `TotalHourlyPrice`,
        [_xN]: _tHP
      }], [0, {
        [_eQN]: `TotalUpfrontPrice`,
        [_xN]: _tUP
      }]]
    ];
    exports2.GetImageAncestryRequest$ = [
      3,
      n032,
      _GIAR,
      0,
      [_IIm, _DR],
      [0, 2],
      1
    ];
    exports2.GetImageAncestryResult$ = [
      3,
      n032,
      _GIARe,
      0,
      [_IAE],
      [[() => ImageAncestryEntryList, {
        [_eQN]: `ImageAncestryEntrySet`,
        [_xN]: _iAES
      }]]
    ];
    exports2.GetImageBlockPublicAccessStateRequest$ = [
      3,
      n032,
      _GIBPASR,
      0,
      [_DR],
      [2]
    ];
    exports2.GetImageBlockPublicAccessStateResult$ = [
      3,
      n032,
      _GIBPASRe,
      0,
      [_IBPAS, _MB],
      [[0, {
        [_eQN]: `ImageBlockPublicAccessState`,
        [_xN]: _iBPAS
      }], [0, {
        [_eQN]: `ManagedBy`,
        [_xN]: _mB
      }]]
    ];
    exports2.GetInstanceMetadataDefaultsRequest$ = [
      3,
      n032,
      _GIMDR,
      0,
      [_DR],
      [2]
    ];
    exports2.GetInstanceMetadataDefaultsResult$ = [
      3,
      n032,
      _GIMDRe,
      0,
      [_AL],
      [[() => exports2.InstanceMetadataDefaultsResponse$, {
        [_eQN]: `AccountLevel`,
        [_xN]: _aL
      }]]
    ];
    exports2.GetInstanceTpmEkPubRequest$ = [
      3,
      n032,
      _GITEPR,
      0,
      [_II2, _KT, _KF, _DR],
      [[0, { [_xN]: _II2 }], 0, 0, 2],
      3
    ];
    exports2.GetInstanceTpmEkPubResult$ = [
      3,
      n032,
      _GITEPRe,
      0,
      [_II2, _KT, _KF, _KV],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `KeyType`,
        [_xN]: _kT
      }], [0, {
        [_eQN]: `KeyFormat`,
        [_xN]: _kF
      }], [() => EkPubKeyValue, {
        [_eQN]: `KeyValue`,
        [_xN]: _kV
      }]]
    ];
    exports2.GetInstanceTypesFromInstanceRequirementsRequest$ = [
      3,
      n032,
      _GITFIRR,
      0,
      [_ATr, _VTi, _IRn, _DR, _MR, _NTe, _Con],
      [[() => ArchitectureTypeSet, { [_xN]: _ATrc }], [() => VirtualizationTypeSet, { [_xN]: _VTir }], [() => exports2.InstanceRequirementsRequest$, 0], 2, 1, 0, 0],
      3
    ];
    exports2.GetInstanceTypesFromInstanceRequirementsResult$ = [
      3,
      n032,
      _GITFIRRe,
      0,
      [_ITnst, _NTe],
      [[() => InstanceTypeInfoFromInstanceRequirementsSet, {
        [_eQN]: `InstanceTypeSet`,
        [_xN]: _iTS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetInstanceUefiDataRequest$ = [
      3,
      n032,
      _GIUDR,
      0,
      [_II2, _DR],
      [[0, { [_xN]: _II2 }], 2],
      1
    ];
    exports2.GetInstanceUefiDataResult$ = [
      3,
      n032,
      _GIUDRe,
      0,
      [_II2, _UD],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `UefiData`,
        [_xN]: _uD
      }]]
    ];
    exports2.GetIpamAddressHistoryRequest$ = [
      3,
      n032,
      _GIAHR,
      0,
      [_Ci, _ISI, _DR, _VI, _ST11, _ETnd, _MR, _NTe],
      [0, 0, 2, 0, 4, 4, 1, 0],
      2
    ];
    exports2.GetIpamAddressHistoryResult$ = [
      3,
      n032,
      _GIAHRe,
      0,
      [_HRi, _NTe],
      [[() => IpamAddressHistoryRecordSet, {
        [_eQN]: `HistoryRecordSet`,
        [_xN]: _hRS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetIpamDiscoveredAccountsRequest$ = [
      3,
      n032,
      _GIDAR,
      0,
      [_IRDI, _DRi, _DR, _Fi, _NTe, _MR],
      [0, 0, 2, [() => FilterList, { [_xN]: _Fil }], 0, 1],
      2
    ];
    exports2.GetIpamDiscoveredAccountsResult$ = [
      3,
      n032,
      _GIDARe,
      0,
      [_IDA, _NTe],
      [[() => IpamDiscoveredAccountSet, {
        [_eQN]: `IpamDiscoveredAccountSet`,
        [_xN]: _iDAS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetIpamDiscoveredPublicAddressesRequest$ = [
      3,
      n032,
      _GIDPAR,
      0,
      [_IRDI, _ARd, _DR, _Fi, _NTe, _MR],
      [0, 0, 2, [() => FilterList, { [_xN]: _Fil }], 0, 1],
      2
    ];
    exports2.GetIpamDiscoveredPublicAddressesResult$ = [
      3,
      n032,
      _GIDPARe,
      0,
      [_IDPA, _OST, _NTe],
      [[() => IpamDiscoveredPublicAddressSet, {
        [_eQN]: `IpamDiscoveredPublicAddressSet`,
        [_xN]: _iDPAS
      }], [4, {
        [_eQN]: `OldestSampleTime`,
        [_xN]: _oST
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetIpamDiscoveredResourceCidrsRequest$ = [
      3,
      n032,
      _GIDRCR,
      0,
      [_IRDI, _RR, _DR, _Fi, _NTe, _MR],
      [0, 0, 2, [() => FilterList, { [_xN]: _Fil }], 0, 1],
      2
    ];
    exports2.GetIpamDiscoveredResourceCidrsResult$ = [
      3,
      n032,
      _GIDRCRe,
      0,
      [_IDRC, _NTe],
      [[() => IpamDiscoveredResourceCidrSet, {
        [_eQN]: `IpamDiscoveredResourceCidrSet`,
        [_xN]: _iDRCS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetIpamPolicyAllocationRulesRequest$ = [
      3,
      n032,
      _GIPARR,
      0,
      [_IPIp, _DR, _Fi, _Lo, _RTe, _MR, _NTe],
      [0, 2, [() => FilterList, { [_xN]: _Fil }], 0, 0, 1, 0],
      1
    ];
    exports2.GetIpamPolicyAllocationRulesResult$ = [
      3,
      n032,
      _GIPARRe,
      0,
      [_IPD, _NTe],
      [[() => IpamPolicyDocumentSet, {
        [_eQN]: `IpamPolicyDocumentSet`,
        [_xN]: _iPDS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetIpamPolicyOrganizationTargetsRequest$ = [
      3,
      n032,
      _GIPOTR,
      0,
      [_IPIp, _DR, _MR, _NTe, _Fi],
      [0, 2, 1, 0, [() => FilterList, { [_xN]: _Fil }]],
      1
    ];
    exports2.GetIpamPolicyOrganizationTargetsResult$ = [
      3,
      n032,
      _GIPOTRe,
      0,
      [_OTr, _NTe],
      [[() => IpamPolicyOrganizationTargetSet, {
        [_eQN]: `OrganizationTargetSet`,
        [_xN]: _oTS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetIpamPoolAllocationsRequest$ = [
      3,
      n032,
      _GIPAR,
      0,
      [_IPI2, _DR, _IPAI, _Fi, _MR, _NTe],
      [0, 2, 0, [() => FilterList, { [_xN]: _Fil }], 1, 0],
      1
    ];
    exports2.GetIpamPoolAllocationsResult$ = [
      3,
      n032,
      _GIPARe,
      0,
      [_IPAp, _NTe],
      [[() => IpamPoolAllocationSet, {
        [_eQN]: `IpamPoolAllocationSet`,
        [_xN]: _iPAS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetIpamPoolCidrsRequest$ = [
      3,
      n032,
      _GIPCR,
      0,
      [_IPI2, _DR, _Fi, _MR, _NTe],
      [0, 2, [() => FilterList, { [_xN]: _Fil }], 1, 0],
      1
    ];
    exports2.GetIpamPoolCidrsResult$ = [
      3,
      n032,
      _GIPCRe,
      0,
      [_IPCpam, _NTe],
      [[() => IpamPoolCidrSet, {
        [_eQN]: `IpamPoolCidrSet`,
        [_xN]: _iPCS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetIpamPrefixListResolverRulesRequest$ = [
      3,
      n032,
      _GIPLRRR,
      0,
      [_IPLRI, _DR, _Fi, _MR, _NTe],
      [0, 2, [() => FilterList, { [_xN]: _Fil }], 1, 0],
      1
    ];
    exports2.GetIpamPrefixListResolverRulesResult$ = [
      3,
      n032,
      _GIPLRRRe,
      0,
      [_Ru, _NTe],
      [[() => IpamPrefixListResolverRuleSet, {
        [_eQN]: `RuleSet`,
        [_xN]: _rSu
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetIpamPrefixListResolverVersionEntriesRequest$ = [
      3,
      n032,
      _GIPLRVER,
      0,
      [_IPLRI, _IPLRV, _DR, _MR, _NTe],
      [0, 1, 2, 1, 0],
      2
    ];
    exports2.GetIpamPrefixListResolverVersionEntriesResult$ = [
      3,
      n032,
      _GIPLRVERe,
      0,
      [_Ent, _NTe],
      [[() => IpamPrefixListResolverVersionEntrySet, {
        [_eQN]: `EntrySet`,
        [_xN]: _eSnt
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetIpamPrefixListResolverVersionsRequest$ = [
      3,
      n032,
      _GIPLRVR,
      0,
      [_IPLRI, _DR, _IPLRVp, _MR, _Fi, _NTe],
      [0, 2, [() => IpamPrefixListResolverVersionNumberSet, { [_xN]: _IPLRV }], 1, [() => FilterList, { [_xN]: _Fil }], 0],
      1
    ];
    exports2.GetIpamPrefixListResolverVersionsResult$ = [
      3,
      n032,
      _GIPLRVRe,
      0,
      [_IPLRVp, _NTe],
      [[() => IpamPrefixListResolverVersionSet, {
        [_eQN]: `IpamPrefixListResolverVersionSet`,
        [_xN]: _iPLRVS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetIpamResourceCidrsRequest$ = [
      3,
      n032,
      _GIRCR,
      0,
      [_ISI, _DR, _Fi, _MR, _NTe, _IPI2, _RIeso, _RTe, _RTeso, _ROe],
      [0, 2, [() => FilterList, { [_xN]: _Fil }], 1, 0, 0, 0, 0, () => exports2.RequestIpamResourceTag$, 0],
      1
    ];
    exports2.GetIpamResourceCidrsResult$ = [
      3,
      n032,
      _GIRCRe,
      0,
      [_NTe, _IRC],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => IpamResourceCidrSet, {
        [_eQN]: `IpamResourceCidrSet`,
        [_xN]: _iRCS
      }]]
    ];
    exports2.GetLaunchTemplateDataRequest$ = [
      3,
      n032,
      _GLTDR,
      0,
      [_II2, _DR],
      [0, 2],
      1
    ];
    exports2.GetLaunchTemplateDataResult$ = [
      3,
      n032,
      _GLTDRe,
      0,
      [_LTD],
      [[() => exports2.ResponseLaunchTemplateData$, {
        [_eQN]: `LaunchTemplateData`,
        [_xN]: _lTD
      }]]
    ];
    exports2.GetManagedPrefixListAssociationsRequest$ = [
      3,
      n032,
      _GMPLAR,
      0,
      [_PLI, _DR, _MR, _NTe],
      [0, 2, 1, 0],
      1
    ];
    exports2.GetManagedPrefixListAssociationsResult$ = [
      3,
      n032,
      _GMPLARe,
      0,
      [_PLA, _NTe],
      [[() => PrefixListAssociationSet, {
        [_eQN]: `PrefixListAssociationSet`,
        [_xN]: _pLAS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetManagedPrefixListEntriesRequest$ = [
      3,
      n032,
      _GMPLER,
      0,
      [_PLI, _DR, _TV, _MR, _NTe],
      [0, 2, 1, 1, 0],
      1
    ];
    exports2.GetManagedPrefixListEntriesResult$ = [
      3,
      n032,
      _GMPLERe,
      0,
      [_Ent, _NTe],
      [[() => PrefixListEntrySet, {
        [_eQN]: `EntrySet`,
        [_xN]: _eSnt
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetManagedResourceVisibilityRequest$ = [
      3,
      n032,
      _GMRVR,
      0,
      [_DR],
      [2]
    ];
    exports2.GetManagedResourceVisibilityResult$ = [
      3,
      n032,
      _GMRVRe,
      0,
      [_Vi],
      [[() => exports2.ManagedResourceVisibilitySettings$, {
        [_eQN]: `Visibility`,
        [_xN]: _vi
      }]]
    ];
    exports2.GetNetworkInsightsAccessScopeAnalysisFindingsRequest$ = [
      3,
      n032,
      _GNIASAFR,
      0,
      [_NIASAI, _MR, _NTe, _DR],
      [0, 1, 0, 2],
      1
    ];
    exports2.GetNetworkInsightsAccessScopeAnalysisFindingsResult$ = [
      3,
      n032,
      _GNIASAFRe,
      0,
      [_NIASAI, _ASn, _AFn, _NTe],
      [[0, {
        [_eQN]: `NetworkInsightsAccessScopeAnalysisId`,
        [_xN]: _nIASAI
      }], [0, {
        [_eQN]: `AnalysisStatus`,
        [_xN]: _aSn
      }], [() => AccessScopeAnalysisFindingList, {
        [_eQN]: `AnalysisFindingSet`,
        [_xN]: _aFS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetNetworkInsightsAccessScopeContentRequest$ = [
      3,
      n032,
      _GNIASCR,
      0,
      [_NIASI, _DR],
      [0, 2],
      1
    ];
    exports2.GetNetworkInsightsAccessScopeContentResult$ = [
      3,
      n032,
      _GNIASCRe,
      0,
      [_NIASC],
      [[() => exports2.NetworkInsightsAccessScopeContent$, {
        [_eQN]: `NetworkInsightsAccessScopeContent`,
        [_xN]: _nIASC
      }]]
    ];
    exports2.GetPasswordDataRequest$ = [
      3,
      n032,
      _GPDR,
      0,
      [_II2, _DR],
      [0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.GetPasswordDataResult$ = [
      3,
      n032,
      _GPDRe,
      0,
      [_II2, _Ti, _PD],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [4, {
        [_eQN]: `Timestamp`,
        [_xN]: _ti
      }], [() => PasswordData, {
        [_eQN]: `PasswordData`,
        [_xN]: _pD
      }]]
    ];
    exports2.GetReservedInstancesExchangeQuoteRequest$ = [
      3,
      n032,
      _GRIEQR,
      0,
      [_RII, _DR, _TC10],
      [[() => ReservedInstanceIdSet, { [_xN]: _RIIe }], 2, [() => TargetConfigurationRequestSet, { [_xN]: _TCa }]],
      1
    ];
    exports2.GetReservedInstancesExchangeQuoteResult$ = [
      3,
      n032,
      _GRIEQRe,
      0,
      [_CC, _IVE, _ORIWEA, _PDa, _RIVR, _RIVS, _TCVR, _TCVS, _VFR],
      [[0, {
        [_eQN]: `CurrencyCode`,
        [_xN]: _cC
      }], [2, {
        [_eQN]: `IsValidExchange`,
        [_xN]: _iVE
      }], [4, {
        [_eQN]: `OutputReservedInstancesWillExpireAt`,
        [_xN]: _oRIWEA
      }], [0, {
        [_eQN]: `PaymentDue`,
        [_xN]: _pDa
      }], [() => exports2.ReservationValue$, {
        [_eQN]: `ReservedInstanceValueRollup`,
        [_xN]: _rIVR
      }], [() => ReservedInstanceReservationValueSet, {
        [_eQN]: `ReservedInstanceValueSet`,
        [_xN]: _rIVS
      }], [() => exports2.ReservationValue$, {
        [_eQN]: `TargetConfigurationValueRollup`,
        [_xN]: _tCVR
      }], [() => TargetReservationValueSet, {
        [_eQN]: `TargetConfigurationValueSet`,
        [_xN]: _tCVS
      }], [0, {
        [_eQN]: `ValidationFailureReason`,
        [_xN]: _vFR
      }]]
    ];
    exports2.GetRouteServerAssociationsRequest$ = [
      3,
      n032,
      _GRSAR,
      0,
      [_RSI, _DR],
      [0, 2],
      1
    ];
    exports2.GetRouteServerAssociationsResult$ = [
      3,
      n032,
      _GRSARe,
      0,
      [_RSAo],
      [[() => RouteServerAssociationsList, {
        [_eQN]: `RouteServerAssociationSet`,
        [_xN]: _rSAS
      }]]
    ];
    exports2.GetRouteServerPropagationsRequest$ = [
      3,
      n032,
      _GRSPR,
      0,
      [_RSI, _RTI, _DR],
      [0, 0, 2],
      1
    ];
    exports2.GetRouteServerPropagationsResult$ = [
      3,
      n032,
      _GRSPRe,
      0,
      [_RSPout],
      [[() => RouteServerPropagationsList, {
        [_eQN]: `RouteServerPropagationSet`,
        [_xN]: _rSPSo
      }]]
    ];
    exports2.GetRouteServerRoutingDatabaseRequest$ = [
      3,
      n032,
      _GRSRDR,
      0,
      [_RSI, _NTe, _MR, _DR, _Fi],
      [0, 0, 1, 2, [() => FilterList, { [_xN]: _Fil }]],
      1
    ];
    exports2.GetRouteServerRoutingDatabaseResult$ = [
      3,
      n032,
      _GRSRDRe,
      0,
      [_ARP, _Rou, _NTe],
      [[2, {
        [_eQN]: `AreRoutesPersisted`,
        [_xN]: _aRP
      }], [() => RouteServerRouteList, {
        [_eQN]: `RouteSet`,
        [_xN]: _rSou
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetSecurityGroupsForVpcRequest$ = [
      3,
      n032,
      _GSGFVR,
      0,
      [_VI, _NTe, _MR, _Fi, _DR],
      [0, 0, 1, [() => FilterList, { [_xN]: _Fil }], 2],
      1
    ];
    exports2.GetSecurityGroupsForVpcResult$ = [
      3,
      n032,
      _GSGFVRe,
      0,
      [_NTe, _SGFV],
      [[0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }], [() => SecurityGroupForVpcList, {
        [_eQN]: `SecurityGroupForVpcSet`,
        [_xN]: _sGFVS
      }]]
    ];
    exports2.GetSerialConsoleAccessStatusRequest$ = [
      3,
      n032,
      _GSCASR,
      0,
      [_DR],
      [2]
    ];
    exports2.GetSerialConsoleAccessStatusResult$ = [
      3,
      n032,
      _GSCASRe,
      0,
      [_SCAE, _MB],
      [[2, {
        [_eQN]: `SerialConsoleAccessEnabled`,
        [_xN]: _sCAE
      }], [0, {
        [_eQN]: `ManagedBy`,
        [_xN]: _mB
      }]]
    ];
    exports2.GetSnapshotBlockPublicAccessStateRequest$ = [
      3,
      n032,
      _GSBPASR,
      0,
      [_DR],
      [2]
    ];
    exports2.GetSnapshotBlockPublicAccessStateResult$ = [
      3,
      n032,
      _GSBPASRe,
      0,
      [_St, _MB],
      [[0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `ManagedBy`,
        [_xN]: _mB
      }]]
    ];
    exports2.GetSpotPlacementScoresRequest$ = [
      3,
      n032,
      _GSPSR,
      0,
      [_TCar, _ITnst, _TCUT, _SAZ, _RNe, _IRWM, _DR, _MR, _NTe],
      [1, [64 | 0, { [_xN]: _IT4 }], 0, 2, [64 | 0, { [_xN]: _RN }], [() => exports2.InstanceRequirementsWithMetadataRequest$, 0], 2, 1, 0],
      1
    ];
    exports2.GetSpotPlacementScoresResult$ = [
      3,
      n032,
      _GSPSRe,
      0,
      [_SPS, _NTe],
      [[() => SpotPlacementScores, {
        [_eQN]: `SpotPlacementScoreSet`,
        [_xN]: _sPSS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetSubnetCidrReservationsRequest$ = [
      3,
      n032,
      _GSCRR,
      0,
      [_SIu, _Fi, _DR, _NTe, _MR],
      [0, [() => FilterList, { [_xN]: _Fil }], 2, 0, 1],
      1
    ];
    exports2.GetSubnetCidrReservationsResult$ = [
      3,
      n032,
      _GSCRRe,
      0,
      [_SICR, _SICRu, _NTe],
      [[() => SubnetCidrReservationList, {
        [_eQN]: `SubnetIpv4CidrReservationSet`,
        [_xN]: _sICRS
      }], [() => SubnetCidrReservationList, {
        [_eQN]: `SubnetIpv6CidrReservationSet`,
        [_xN]: _sICRSu
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetTransitGatewayAttachmentPropagationsRequest$ = [
      3,
      n032,
      _GTGAPR,
      0,
      [_TGAI, _Fi, _MR, _NTe, _DR],
      [0, [() => FilterList, { [_xN]: _Fil }], 1, 0, 2],
      1
    ];
    exports2.GetTransitGatewayAttachmentPropagationsResult$ = [
      3,
      n032,
      _GTGAPRe,
      0,
      [_TGAP, _NTe],
      [[() => TransitGatewayAttachmentPropagationList, {
        [_eQN]: `TransitGatewayAttachmentPropagations`,
        [_xN]: _tGAP
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetTransitGatewayMeteringPolicyEntriesRequest$ = [
      3,
      n032,
      _GTGMPER,
      0,
      [_TGMPI, _Fi, _MR, _NTe, _DR],
      [0, [() => FilterList, { [_xN]: _Fil }], 1, 0, 2],
      1
    ];
    exports2.GetTransitGatewayMeteringPolicyEntriesResult$ = [
      3,
      n032,
      _GTGMPERe,
      0,
      [_TGMPEr, _NTe],
      [[() => TransitGatewayMeteringPolicyEntryList, {
        [_eQN]: `TransitGatewayMeteringPolicyEntries`,
        [_xN]: _tGMPEr
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetTransitGatewayMulticastDomainAssociationsRequest$ = [
      3,
      n032,
      _GTGMDAR,
      0,
      [_TGMDI, _Fi, _MR, _NTe, _DR],
      [0, [() => FilterList, { [_xN]: _Fil }], 1, 0, 2],
      1
    ];
    exports2.GetTransitGatewayMulticastDomainAssociationsResult$ = [
      3,
      n032,
      _GTGMDARe,
      0,
      [_MDA, _NTe],
      [[() => TransitGatewayMulticastDomainAssociationList, {
        [_eQN]: `MulticastDomainAssociations`,
        [_xN]: _mDA
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetTransitGatewayPolicyTableAssociationsRequest$ = [
      3,
      n032,
      _GTGPTAR,
      0,
      [_TGPTI, _Fi, _MR, _NTe, _DR],
      [0, [() => FilterList, { [_xN]: _Fil }], 1, 0, 2],
      1
    ];
    exports2.GetTransitGatewayPolicyTableAssociationsResult$ = [
      3,
      n032,
      _GTGPTARe,
      0,
      [_As, _NTe],
      [[() => TransitGatewayPolicyTableAssociationList, {
        [_eQN]: `Associations`,
        [_xN]: _a10
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetTransitGatewayPolicyTableEntriesRequest$ = [
      3,
      n032,
      _GTGPTER,
      0,
      [_TGPTI, _Fi, _MR, _NTe, _DR],
      [0, [() => FilterList, { [_xN]: _Fil }], 1, 0, 2],
      1
    ];
    exports2.GetTransitGatewayPolicyTableEntriesResult$ = [
      3,
      n032,
      _GTGPTERe,
      0,
      [_TGPTE],
      [[() => TransitGatewayPolicyTableEntryList, {
        [_eQN]: `TransitGatewayPolicyTableEntries`,
        [_xN]: _tGPTE
      }]]
    ];
    exports2.GetTransitGatewayPrefixListReferencesRequest$ = [
      3,
      n032,
      _GTGPLRR,
      0,
      [_TGRTI, _Fi, _MR, _NTe, _DR],
      [0, [() => FilterList, { [_xN]: _Fil }], 1, 0, 2],
      1
    ];
    exports2.GetTransitGatewayPrefixListReferencesResult$ = [
      3,
      n032,
      _GTGPLRRe,
      0,
      [_TGPLRr, _NTe],
      [[() => TransitGatewayPrefixListReferenceSet, {
        [_eQN]: `TransitGatewayPrefixListReferenceSet`,
        [_xN]: _tGPLRS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetTransitGatewayRouteTableAssociationsRequest$ = [
      3,
      n032,
      _GTGRTAR,
      0,
      [_TGRTI, _Fi, _MR, _NTe, _DR],
      [0, [() => FilterList, { [_xN]: _Fil }], 1, 0, 2],
      1
    ];
    exports2.GetTransitGatewayRouteTableAssociationsResult$ = [
      3,
      n032,
      _GTGRTARe,
      0,
      [_As, _NTe],
      [[() => TransitGatewayRouteTableAssociationList, {
        [_eQN]: `Associations`,
        [_xN]: _a10
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetTransitGatewayRouteTablePropagationsRequest$ = [
      3,
      n032,
      _GTGRTPR,
      0,
      [_TGRTI, _Fi, _MR, _NTe, _DR],
      [0, [() => FilterList, { [_xN]: _Fil }], 1, 0, 2],
      1
    ];
    exports2.GetTransitGatewayRouteTablePropagationsResult$ = [
      3,
      n032,
      _GTGRTPRe,
      0,
      [_TGRTP, _NTe],
      [[() => TransitGatewayRouteTablePropagationList, {
        [_eQN]: `TransitGatewayRouteTablePropagations`,
        [_xN]: _tGRTP
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetVerifiedAccessEndpointPolicyRequest$ = [
      3,
      n032,
      _GVAEPR,
      0,
      [_VAEI, _DR],
      [0, 2],
      1
    ];
    exports2.GetVerifiedAccessEndpointPolicyResult$ = [
      3,
      n032,
      _GVAEPRe,
      0,
      [_PE, _PDo],
      [[2, {
        [_eQN]: `PolicyEnabled`,
        [_xN]: _pE
      }], [0, {
        [_eQN]: `PolicyDocument`,
        [_xN]: _pDo
      }]]
    ];
    exports2.GetVerifiedAccessEndpointTargetsRequest$ = [
      3,
      n032,
      _GVAETR,
      0,
      [_VAEI, _MR, _NTe, _DR],
      [[0, { [_xN]: _VAEI }], 1, 0, 2],
      1
    ];
    exports2.GetVerifiedAccessEndpointTargetsResult$ = [
      3,
      n032,
      _GVAETRe,
      0,
      [_VAET, _NTe],
      [[() => VerifiedAccessEndpointTargetList, {
        [_eQN]: `VerifiedAccessEndpointTargetSet`,
        [_xN]: _vAETS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetVerifiedAccessGroupPolicyRequest$ = [
      3,
      n032,
      _GVAGPR,
      0,
      [_VAGI, _DR],
      [0, 2],
      1
    ];
    exports2.GetVerifiedAccessGroupPolicyResult$ = [
      3,
      n032,
      _GVAGPRe,
      0,
      [_PE, _PDo],
      [[2, {
        [_eQN]: `PolicyEnabled`,
        [_xN]: _pE
      }], [0, {
        [_eQN]: `PolicyDocument`,
        [_xN]: _pDo
      }]]
    ];
    exports2.GetVpcResourcesBlockingEncryptionEnforcementRequest$ = [
      3,
      n032,
      _GVRBEER,
      0,
      [_VI, _MR, _NTe, _DR],
      [0, 1, 0, 2],
      1
    ];
    exports2.GetVpcResourcesBlockingEncryptionEnforcementResult$ = [
      3,
      n032,
      _GVRBEERe,
      0,
      [_NCR, _NTe],
      [[() => VpcEncryptionNonCompliantResourceList, {
        [_eQN]: `NonCompliantResourceSet`,
        [_xN]: _nCRS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetVpnConnectionDeviceSampleConfigurationRequest$ = [
      3,
      n032,
      _GVCDSCR,
      0,
      [_VCIp, _VCDTI, _IKEV, _STa, _DR],
      [0, 0, 0, 0, 2],
      2
    ];
    exports2.GetVpnConnectionDeviceSampleConfigurationResult$ = [
      3,
      n032,
      _GVCDSCRe,
      0,
      [_VCDSC],
      [[() => VpnConnectionDeviceSampleConfiguration, {
        [_eQN]: `VpnConnectionDeviceSampleConfiguration`,
        [_xN]: _vCDSC
      }]]
    ];
    exports2.GetVpnConnectionDeviceTypesRequest$ = [
      3,
      n032,
      _GVCDTR,
      0,
      [_MR, _NTe, _DR],
      [1, 0, 2]
    ];
    exports2.GetVpnConnectionDeviceTypesResult$ = [
      3,
      n032,
      _GVCDTRe,
      0,
      [_VCDT, _NTe],
      [[() => VpnConnectionDeviceTypeList, {
        [_eQN]: `VpnConnectionDeviceTypeSet`,
        [_xN]: _vCDTS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.GetVpnTunnelReplacementStatusRequest$ = [
      3,
      n032,
      _GVTRSR,
      0,
      [_VCIp, _VTOIA, _DR],
      [0, 0, 2],
      2
    ];
    exports2.GetVpnTunnelReplacementStatusResult$ = [
      3,
      n032,
      _GVTRSRe,
      0,
      [_VCIp, _TGI, _CGIu, _VGI, _VTOIA, _MDa],
      [[0, {
        [_eQN]: `VpnConnectionId`,
        [_xN]: _vCI
      }], [0, {
        [_eQN]: `TransitGatewayId`,
        [_xN]: _tGI
      }], [0, {
        [_eQN]: `CustomerGatewayId`,
        [_xN]: _cGIu
      }], [0, {
        [_eQN]: `VpnGatewayId`,
        [_xN]: _vGI
      }], [0, {
        [_eQN]: `VpnTunnelOutsideIpAddress`,
        [_xN]: _vTOIA
      }], [() => exports2.MaintenanceDetails$, {
        [_eQN]: `MaintenanceDetails`,
        [_xN]: _mD
      }]]
    ];
    exports2.GpuDeviceInfo$ = [
      3,
      n032,
      _GDI,
      0,
      [_N, _Man, _Cou, _LGC, _GPS, _Wo, _MIe],
      [[0, {
        [_eQN]: `Name`,
        [_xN]: _n
      }], [0, {
        [_eQN]: `Manufacturer`,
        [_xN]: _man
      }], [1, {
        [_eQN]: `Count`,
        [_xN]: _cou
      }], [1, {
        [_eQN]: `LogicalGpuCount`,
        [_xN]: _lGC
      }], [1, {
        [_eQN]: `GpuPartitionSize`,
        [_xN]: _gPS
      }], [() => WorkloadsList, {
        [_eQN]: `WorkloadSet`,
        [_xN]: _wS
      }], [() => exports2.GpuDeviceMemoryInfo$, {
        [_eQN]: `MemoryInfo`,
        [_xN]: _mIe
      }]]
    ];
    exports2.GpuDeviceMemoryInfo$ = [
      3,
      n032,
      _GDMI,
      0,
      [_SIMB],
      [[1, {
        [_eQN]: `SizeInMiB`,
        [_xN]: _sIMB
      }]]
    ];
    exports2.GpuInfo$ = [
      3,
      n032,
      _GIp,
      0,
      [_Gp, _TGMIMB],
      [[() => GpuDeviceInfoList, {
        [_eQN]: `Gpus`,
        [_xN]: _gp
      }], [1, {
        [_eQN]: `TotalGpuMemoryInMiB`,
        [_xN]: _tGMIMB
      }]]
    ];
    exports2.GroupIdentifier$ = [
      3,
      n032,
      _GIrou,
      0,
      [_GIr, _GN],
      [[0, {
        [_eQN]: `GroupId`,
        [_xN]: _gIr
      }], [0, {
        [_eQN]: `GroupName`,
        [_xN]: _gN
      }]]
    ];
    exports2.HibernationOptions$ = [
      3,
      n032,
      _HO,
      0,
      [_Conf],
      [[2, {
        [_eQN]: `Configured`,
        [_xN]: _conf
      }]]
    ];
    exports2.HibernationOptionsRequest$ = [
      3,
      n032,
      _HOR,
      0,
      [_Conf],
      [2]
    ];
    exports2.HistoryRecord$ = [
      3,
      n032,
      _HRis,
      0,
      [_EIv, _ETv, _Ti],
      [[() => exports2.EventInformation$, {
        [_eQN]: `EventInformation`,
        [_xN]: _eIv
      }], [0, {
        [_eQN]: `EventType`,
        [_xN]: _eTv
      }], [4, {
        [_eQN]: `Timestamp`,
        [_xN]: _ti
      }]]
    ];
    exports2.HistoryRecordEntry$ = [
      3,
      n032,
      _HRE,
      0,
      [_EIv, _ETv, _Ti],
      [[() => exports2.EventInformation$, {
        [_eQN]: `EventInformation`,
        [_xN]: _eIv
      }], [0, {
        [_eQN]: `EventType`,
        [_xN]: _eTv
      }], [4, {
        [_eQN]: `Timestamp`,
        [_xN]: _ti
      }]]
    ];
    exports2.Host$ = [
      3,
      n032,
      _Ho,
      0,
      [_APu, _AZ, _ACv, _CT4, _HIo, _HP, _HRI, _Ins, _St, _ATll, _RTel, _T10, _HR, _AMIT, _OI, _AZI, _MOSLRG, _OA, _HM, _AIsse],
      [[0, {
        [_eQN]: `AutoPlacement`,
        [_xN]: _aP
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [() => exports2.AvailableCapacity$, {
        [_eQN]: `AvailableCapacity`,
        [_xN]: _aC
      }], [0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }], [0, {
        [_eQN]: `HostId`,
        [_xN]: _hI
      }], [() => exports2.HostProperties$, {
        [_eQN]: `HostProperties`,
        [_xN]: _hP
      }], [0, {
        [_eQN]: `HostReservationId`,
        [_xN]: _hRI
      }], [() => HostInstanceList, {
        [_eQN]: `Instances`,
        [_xN]: _ins
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [4, {
        [_eQN]: `AllocationTime`,
        [_xN]: _aTll
      }], [4, {
        [_eQN]: `ReleaseTime`,
        [_xN]: _rTel
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `HostRecovery`,
        [_xN]: _hR
      }], [0, {
        [_eQN]: `AllowsMultipleInstanceTypes`,
        [_xN]: _aMIT
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [2, {
        [_eQN]: `MemberOfServiceLinkedResourceGroup`,
        [_xN]: _mOSLRG
      }], [0, {
        [_eQN]: `OutpostArn`,
        [_xN]: _oA
      }], [0, {
        [_eQN]: `HostMaintenance`,
        [_xN]: _hM
      }], [0, {
        [_eQN]: `AssetId`,
        [_xN]: _aIss
      }]]
    ];
    exports2.HostInstance$ = [
      3,
      n032,
      _HIos,
      0,
      [_II2, _IT4, _OI],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }]]
    ];
    exports2.HostOffering$ = [
      3,
      n032,
      _HOo,
      0,
      [_CC, _Du, _HPo, _IF, _OIf, _PO, _UP],
      [[0, {
        [_eQN]: `CurrencyCode`,
        [_xN]: _cC
      }], [1, {
        [_eQN]: `Duration`,
        [_xN]: _du
      }], [0, {
        [_eQN]: `HourlyPrice`,
        [_xN]: _hPo
      }], [0, {
        [_eQN]: `InstanceFamily`,
        [_xN]: _iF
      }], [0, {
        [_eQN]: `OfferingId`,
        [_xN]: _oIf
      }], [0, {
        [_eQN]: `PaymentOption`,
        [_xN]: _pO
      }], [0, {
        [_eQN]: `UpfrontPrice`,
        [_xN]: _uP
      }]]
    ];
    exports2.HostProperties$ = [
      3,
      n032,
      _HP,
      0,
      [_Cor, _IT4, _IF, _Soc, _TVC],
      [[1, {
        [_eQN]: `Cores`,
        [_xN]: _cor
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [0, {
        [_eQN]: `InstanceFamily`,
        [_xN]: _iF
      }], [1, {
        [_eQN]: `Sockets`,
        [_xN]: _soc
      }], [1, {
        [_eQN]: `TotalVCpus`,
        [_xN]: _tVC
      }]]
    ];
    exports2.HostReservation$ = [
      3,
      n032,
      _HRo,
      0,
      [_Cou, _CC, _Du, _End, _HIS, _HRI, _HPo, _IF, _OIf, _PO, _Star, _St, _UP, _T10],
      [[1, {
        [_eQN]: `Count`,
        [_xN]: _cou
      }], [0, {
        [_eQN]: `CurrencyCode`,
        [_xN]: _cC
      }], [1, {
        [_eQN]: `Duration`,
        [_xN]: _du
      }], [4, {
        [_eQN]: `End`,
        [_xN]: _end
      }], [() => ResponseHostIdSet, {
        [_eQN]: `HostIdSet`,
        [_xN]: _hIS
      }], [0, {
        [_eQN]: `HostReservationId`,
        [_xN]: _hRI
      }], [0, {
        [_eQN]: `HourlyPrice`,
        [_xN]: _hPo
      }], [0, {
        [_eQN]: `InstanceFamily`,
        [_xN]: _iF
      }], [0, {
        [_eQN]: `OfferingId`,
        [_xN]: _oIf
      }], [0, {
        [_eQN]: `PaymentOption`,
        [_xN]: _pO
      }], [4, {
        [_eQN]: `Start`,
        [_xN]: _star
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `UpfrontPrice`,
        [_xN]: _uP
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.IamInstanceProfile$ = [
      3,
      n032,
      _IIP,
      0,
      [_Ar, _I],
      [[0, {
        [_eQN]: `Arn`,
        [_xN]: _ar
      }], [0, {
        [_eQN]: `Id`,
        [_xN]: _i
      }]]
    ];
    exports2.IamInstanceProfileAssociation$ = [
      3,
      n032,
      _IIPA,
      0,
      [_AIs, _II2, _IIP, _St, _Ti],
      [[0, {
        [_eQN]: `AssociationId`,
        [_xN]: _aIs
      }], [0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [() => exports2.IamInstanceProfile$, {
        [_eQN]: `IamInstanceProfile`,
        [_xN]: _iIP
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [4, {
        [_eQN]: `Timestamp`,
        [_xN]: _ti
      }]]
    ];
    exports2.IamInstanceProfileSpecification$ = [
      3,
      n032,
      _IIPS,
      0,
      [_Ar, _N],
      [[0, {
        [_eQN]: `Arn`,
        [_xN]: _ar
      }], [0, {
        [_eQN]: `Name`,
        [_xN]: _n
      }]]
    ];
    exports2.IcmpTypeCode$ = [
      3,
      n032,
      _ITC,
      0,
      [_Co, _Ty],
      [[1, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [1, {
        [_eQN]: `Type`,
        [_xN]: _ty
      }]]
    ];
    exports2.IdFormat$ = [
      3,
      n032,
      _IFd,
      0,
      [_Dea, _Reso, _ULI],
      [[4, {
        [_eQN]: `Deadline`,
        [_xN]: _dea
      }], [0, {
        [_eQN]: `Resource`,
        [_xN]: _re
      }], [2, {
        [_eQN]: `UseLongIds`,
        [_xN]: _uLI
      }]]
    ];
    exports2.IKEVersionsListValue$ = [
      3,
      n032,
      _IKEVLV,
      0,
      [_V10],
      [[0, {
        [_eQN]: `Value`,
        [_xN]: _v
      }]]
    ];
    exports2.IKEVersionsRequestListValue$ = [
      3,
      n032,
      _IKEVRLV,
      0,
      [_V10],
      [0]
    ];
    exports2.Image$ = [
      3,
      n032,
      _Ima,
      0,
      [_PDl, _UO, _BDMl, _De, _ESna, _Hy, _IOA, _N, _RDN, _RDT, _SNS, _SRt, _T10, _VTir, _BM, _TSp, _DTe, _ISmd, _SIIo, _DPer, _LLT, _IAm, _SII, _SIRo, _FTE, _IIm, _IL, _St, _OI, _CDr, _Pu, _PCro, _Arc, _ITm, _KI, _RIa, _Pl],
      [[0, {
        [_eQN]: `PlatformDetails`,
        [_xN]: _pDl
      }], [0, {
        [_eQN]: `UsageOperation`,
        [_xN]: _uO
      }], [() => BlockDeviceMappingList, {
        [_eQN]: `BlockDeviceMapping`,
        [_xN]: _bDM
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [2, {
        [_eQN]: `EnaSupport`,
        [_xN]: _eSna
      }], [0, {
        [_eQN]: `Hypervisor`,
        [_xN]: _h22
      }], [0, {
        [_eQN]: `ImageOwnerAlias`,
        [_xN]: _iOA
      }], [0, {
        [_eQN]: `Name`,
        [_xN]: _n
      }], [0, {
        [_eQN]: `RootDeviceName`,
        [_xN]: _rDN
      }], [0, {
        [_eQN]: `RootDeviceType`,
        [_xN]: _rDT
      }], [0, {
        [_eQN]: `SriovNetSupport`,
        [_xN]: _sNSr
      }], [() => exports2.StateReason$, {
        [_eQN]: `StateReason`,
        [_xN]: _sRt
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `VirtualizationType`,
        [_xN]: _vTi
      }], [0, {
        [_eQN]: `BootMode`,
        [_xN]: _bM
      }], [0, {
        [_eQN]: `TpmSupport`,
        [_xN]: _tSp
      }], [0, {
        [_eQN]: `DeprecationTime`,
        [_xN]: _dTe
      }], [0, {
        [_eQN]: `ImdsSupport`,
        [_xN]: _iSmd
      }], [0, {
        [_eQN]: `SourceInstanceId`,
        [_xN]: _sII
      }], [0, {
        [_eQN]: `DeregistrationProtection`,
        [_xN]: _dPe
      }], [0, {
        [_eQN]: `LastLaunchedTime`,
        [_xN]: _lLT
      }], [2, {
        [_eQN]: `ImageAllowed`,
        [_xN]: _iAm
      }], [0, {
        [_eQN]: `SourceImageId`,
        [_xN]: _sIIo
      }], [0, {
        [_eQN]: `SourceImageRegion`,
        [_xN]: _sIR
      }], [2, {
        [_eQN]: `FreeTierEligible`,
        [_xN]: _fTE
      }], [0, {
        [_eQN]: `ImageId`,
        [_xN]: _iIma
      }], [0, {
        [_eQN]: `ImageLocation`,
        [_xN]: _iL
      }], [0, {
        [_eQN]: `ImageState`,
        [_xN]: _iSma
      }], [0, {
        [_eQN]: `ImageOwnerId`,
        [_xN]: _iOI
      }], [0, {
        [_eQN]: `CreationDate`,
        [_xN]: _cDr
      }], [2, {
        [_eQN]: `IsPublic`,
        [_xN]: _iPs
      }], [() => ProductCodeList, {
        [_eQN]: `ProductCodes`,
        [_xN]: _pC
      }], [0, {
        [_eQN]: `Architecture`,
        [_xN]: _arc
      }], [0, {
        [_eQN]: `ImageType`,
        [_xN]: _iTm
      }], [0, {
        [_eQN]: `KernelId`,
        [_xN]: _kI
      }], [0, {
        [_eQN]: `RamdiskId`,
        [_xN]: _rIa
      }], [0, {
        [_eQN]: `Platform`,
        [_xN]: _pl
      }]]
    ];
    exports2.ImageAncestryEntry$ = [
      3,
      n032,
      _IAEm,
      0,
      [_CDr, _IIm, _IOA, _SII, _SIRo],
      [[4, {
        [_eQN]: `CreationDate`,
        [_xN]: _cDr
      }], [0, {
        [_eQN]: `ImageId`,
        [_xN]: _iIma
      }], [0, {
        [_eQN]: `ImageOwnerAlias`,
        [_xN]: _iOA
      }], [0, {
        [_eQN]: `SourceImageId`,
        [_xN]: _sIIo
      }], [0, {
        [_eQN]: `SourceImageRegion`,
        [_xN]: _sIR
      }]]
    ];
    exports2.ImageAttribute$ = [
      3,
      n032,
      _IAma,
      0,
      [_De, _KI, _RIa, _SNS, _BM, _TSp, _UD, _LLT, _ISmd, _DPer, _IIm, _LPa, _PCro, _BDMl],
      [[() => exports2.AttributeValue$, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [() => exports2.AttributeValue$, {
        [_eQN]: `Kernel`,
        [_xN]: _ke
      }], [() => exports2.AttributeValue$, {
        [_eQN]: `Ramdisk`,
        [_xN]: _ra
      }], [() => exports2.AttributeValue$, {
        [_eQN]: `SriovNetSupport`,
        [_xN]: _sNSr
      }], [() => exports2.AttributeValue$, {
        [_eQN]: `BootMode`,
        [_xN]: _bM
      }], [() => exports2.AttributeValue$, {
        [_eQN]: `TpmSupport`,
        [_xN]: _tSp
      }], [() => exports2.AttributeValue$, {
        [_eQN]: `UefiData`,
        [_xN]: _uD
      }], [() => exports2.AttributeValue$, {
        [_eQN]: `LastLaunchedTime`,
        [_xN]: _lLT
      }], [() => exports2.AttributeValue$, {
        [_eQN]: `ImdsSupport`,
        [_xN]: _iSmd
      }], [() => exports2.AttributeValue$, {
        [_eQN]: `DeregistrationProtection`,
        [_xN]: _dPe
      }], [0, {
        [_eQN]: `ImageId`,
        [_xN]: _iIma
      }], [() => LaunchPermissionList, {
        [_eQN]: `LaunchPermission`,
        [_xN]: _lPa
      }], [() => ProductCodeList, {
        [_eQN]: `ProductCodes`,
        [_xN]: _pC
      }], [() => BlockDeviceMappingList, {
        [_eQN]: `BlockDeviceMapping`,
        [_xN]: _bDM
      }]]
    ];
    exports2.ImageCriterion$ = [
      3,
      n032,
      _ICma,
      0,
      [_IPm, _MPC, _INm, _DTC, _CDC],
      [[() => ImageProviderList, {
        [_eQN]: `ImageProviderSet`,
        [_xN]: _iPSm
      }], [() => MarketplaceProductCodeList, {
        [_eQN]: `MarketplaceProductCodeSet`,
        [_xN]: _mPCS
      }], [() => ImageNameList, {
        [_eQN]: `ImageNameSet`,
        [_xN]: _iNS
      }], [() => exports2.DeprecationTimeCondition$, {
        [_eQN]: `DeprecationTimeCondition`,
        [_xN]: _dTC
      }], [() => exports2.CreationDateCondition$, {
        [_eQN]: `CreationDateCondition`,
        [_xN]: _cDC
      }]]
    ];
    exports2.ImageCriterionRequest$ = [
      3,
      n032,
      _ICR,
      0,
      [_IPm, _MPC, _INm, _DTC, _CDC],
      [[() => ImageProviderRequestList, { [_xN]: _IPma }], [() => MarketplaceProductCodeRequestList, { [_xN]: _MPCa }], [() => ImageNameRequestList, { [_xN]: _INma }], () => exports2.DeprecationTimeConditionRequest$, () => exports2.CreationDateConditionRequest$]
    ];
    exports2.ImageDiskContainer$ = [
      3,
      n032,
      _IDC,
      0,
      [_De, _DN, _Fo, _SIn, _Ur, _UB],
      [0, 0, 0, 0, [() => SensitiveUrl, 0], () => exports2.UserBucket$]
    ];
    exports2.ImageMetadata$ = [
      3,
      n032,
      _IMm,
      0,
      [_IIm, _N, _OI, _St, _IOA, _CDr, _DTe, _IAm, _IPs],
      [[0, {
        [_eQN]: `ImageId`,
        [_xN]: _iIma
      }], [0, {
        [_eQN]: `Name`,
        [_xN]: _n
      }], [0, {
        [_eQN]: `ImageOwnerId`,
        [_xN]: _iOI
      }], [0, {
        [_eQN]: `ImageState`,
        [_xN]: _iSma
      }], [0, {
        [_eQN]: `ImageOwnerAlias`,
        [_xN]: _iOA
      }], [0, {
        [_eQN]: `CreationDate`,
        [_xN]: _cDr
      }], [0, {
        [_eQN]: `DeprecationTime`,
        [_xN]: _dTe
      }], [2, {
        [_eQN]: `ImageAllowed`,
        [_xN]: _iAm
      }], [2, {
        [_eQN]: `IsPublic`,
        [_xN]: _iPs
      }]]
    ];
    exports2.ImageRecycleBinInfo$ = [
      3,
      n032,
      _IRBI,
      0,
      [_IIm, _N, _De, _RBET, _RBETe],
      [[0, {
        [_eQN]: `ImageId`,
        [_xN]: _iIma
      }], [0, {
        [_eQN]: `Name`,
        [_xN]: _n
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [4, {
        [_eQN]: `RecycleBinEnterTime`,
        [_xN]: _rBET
      }], [4, {
        [_eQN]: `RecycleBinExitTime`,
        [_xN]: _rBETe
      }]]
    ];
    exports2.ImageReference$ = [
      3,
      n032,
      _IRm,
      0,
      [_IIm, _RTe, _Ar],
      [[0, {
        [_eQN]: `ImageId`,
        [_xN]: _iIma
      }], [0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }], [0, {
        [_eQN]: `Arn`,
        [_xN]: _ar
      }]]
    ];
    exports2.ImageUsageReport$ = [
      3,
      n032,
      _IURm,
      0,
      [_IIm, _RI, _RTes, _AIcc, _St, _SRt, _CTre, _ET, _T10],
      [[0, {
        [_eQN]: `ImageId`,
        [_xN]: _iIma
      }], [0, {
        [_eQN]: `ReportId`,
        [_xN]: _rIe
      }], [() => ImageUsageResourceTypeList, {
        [_eQN]: `ResourceTypeSet`,
        [_xN]: _rTSe
      }], [() => UserIdList, {
        [_eQN]: `AccountIdSet`,
        [_xN]: _aISc
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `StateReason`,
        [_xN]: _sRt
      }], [4, {
        [_eQN]: `CreationTime`,
        [_xN]: _cTre
      }], [4, {
        [_eQN]: `ExpirationTime`,
        [_xN]: _eT
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.ImageUsageReportEntry$ = [
      3,
      n032,
      _IUREm,
      0,
      [_RTe, _RI, _UCs, _AIc, _IIm, _RCTe],
      [[0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }], [0, {
        [_eQN]: `ReportId`,
        [_xN]: _rIe
      }], [1, {
        [_eQN]: `UsageCount`,
        [_xN]: _uCs
      }], [0, {
        [_eQN]: `AccountId`,
        [_xN]: _aIc
      }], [0, {
        [_eQN]: `ImageId`,
        [_xN]: _iIma
      }], [4, {
        [_eQN]: `ReportCreationTime`,
        [_xN]: _rCTe
      }]]
    ];
    exports2.ImageUsageResourceType$ = [
      3,
      n032,
      _IURT,
      0,
      [_RTe, _RTO],
      [[0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }], [() => ImageUsageResourceTypeOptionList, {
        [_eQN]: `ResourceTypeOptionSet`,
        [_xN]: _rTOS
      }]]
    ];
    exports2.ImageUsageResourceTypeOption$ = [
      3,
      n032,
      _IURTO,
      0,
      [_ON, _OV],
      [[0, {
        [_eQN]: `OptionName`,
        [_xN]: _oN
      }], [() => ImageUsageResourceTypeOptionValuesList, {
        [_eQN]: `OptionValueSet`,
        [_xN]: _oVS
      }]]
    ];
    exports2.ImageUsageResourceTypeOptionRequest$ = [
      3,
      n032,
      _IURTOR,
      0,
      [_ON, _OV],
      [0, [() => ImageUsageResourceTypeOptionValuesList, { [_xN]: _OVp }]]
    ];
    exports2.ImageUsageResourceTypeRequest$ = [
      3,
      n032,
      _IURTR,
      0,
      [_RTe, _RTO],
      [0, [() => ImageUsageResourceTypeOptionRequestList, { [_xN]: _RTOe }]]
    ];
    exports2.ImportClientVpnClientCertificateRevocationListRequest$ = [
      3,
      n032,
      _ICVCCRLR,
      0,
      [_CVEI, _CRL, _DR],
      [0, 0, 2],
      2
    ];
    exports2.ImportClientVpnClientCertificateRevocationListResult$ = [
      3,
      n032,
      _ICVCCRLRm,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.ImportImageLicenseConfigurationRequest$ = [
      3,
      n032,
      _IILCR,
      0,
      [_LCA],
      [0]
    ];
    exports2.ImportImageLicenseConfigurationResponse$ = [
      3,
      n032,
      _IILCRm,
      0,
      [_LCA],
      [[0, {
        [_eQN]: `LicenseConfigurationArn`,
        [_xN]: _lCA
      }]]
    ];
    exports2.ImportImageRequest$ = [
      3,
      n032,
      _IIR,
      0,
      [_Arc, _CDl, _CT4, _De, _DCis, _DR, _Enc, _Hy, _KKI, _LTi, _Pl, _RNo, _LS, _TS, _UO, _BM],
      [0, () => exports2.ClientData$, 0, 0, [() => ImageDiskContainerList, { [_xN]: _DCisk }], 2, 2, 0, 0, 0, 0, 0, [() => ImportImageLicenseSpecificationListRequest, 0], [() => TagSpecificationList, { [_xN]: _TSa }], 0, 0]
    ];
    exports2.ImportImageResult$ = [
      3,
      n032,
      _IIRm,
      0,
      [_Arc, _De, _Enc, _Hy, _IIm, _ITI, _KKI, _LTi, _Pl, _Pro, _SDn, _Sta, _SMt, _LS, _T10, _UO],
      [[0, {
        [_eQN]: `Architecture`,
        [_xN]: _arc
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [2, {
        [_eQN]: `Encrypted`,
        [_xN]: _enc
      }], [0, {
        [_eQN]: `Hypervisor`,
        [_xN]: _h22
      }], [0, {
        [_eQN]: `ImageId`,
        [_xN]: _iIma
      }], [0, {
        [_eQN]: `ImportTaskId`,
        [_xN]: _iTI
      }], [0, {
        [_eQN]: `KmsKeyId`,
        [_xN]: _kKI
      }], [0, {
        [_eQN]: `LicenseType`,
        [_xN]: _lTi
      }], [0, {
        [_eQN]: `Platform`,
        [_xN]: _pl
      }], [0, {
        [_eQN]: `Progress`,
        [_xN]: _pro
      }], [() => SnapshotDetailList, {
        [_eQN]: `SnapshotDetailSet`,
        [_xN]: _sDSn
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `StatusMessage`,
        [_xN]: _sMt
      }], [() => ImportImageLicenseSpecificationListResponse, {
        [_eQN]: `LicenseSpecifications`,
        [_xN]: _lS
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `UsageOperation`,
        [_xN]: _uO
      }]]
    ];
    exports2.ImportImageTask$ = [
      3,
      n032,
      _IITm,
      0,
      [_Arc, _De, _Enc, _Hy, _IIm, _ITI, _KKI, _LTi, _Pl, _Pro, _SDn, _Sta, _SMt, _T10, _LS, _UO, _BM],
      [[0, {
        [_eQN]: `Architecture`,
        [_xN]: _arc
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [2, {
        [_eQN]: `Encrypted`,
        [_xN]: _enc
      }], [0, {
        [_eQN]: `Hypervisor`,
        [_xN]: _h22
      }], [0, {
        [_eQN]: `ImageId`,
        [_xN]: _iIma
      }], [0, {
        [_eQN]: `ImportTaskId`,
        [_xN]: _iTI
      }], [0, {
        [_eQN]: `KmsKeyId`,
        [_xN]: _kKI
      }], [0, {
        [_eQN]: `LicenseType`,
        [_xN]: _lTi
      }], [0, {
        [_eQN]: `Platform`,
        [_xN]: _pl
      }], [0, {
        [_eQN]: `Progress`,
        [_xN]: _pro
      }], [() => SnapshotDetailList, {
        [_eQN]: `SnapshotDetailSet`,
        [_xN]: _sDSn
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `StatusMessage`,
        [_xN]: _sMt
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [() => ImportImageLicenseSpecificationListResponse, {
        [_eQN]: `LicenseSpecifications`,
        [_xN]: _lS
      }], [0, {
        [_eQN]: `UsageOperation`,
        [_xN]: _uO
      }], [0, {
        [_eQN]: `BootMode`,
        [_xN]: _bM
      }]]
    ];
    exports2.ImportInstanceLaunchSpecification$ = [
      3,
      n032,
      _IILS,
      0,
      [_Arc, _GNr, _GIro, _AId, _UDs, _IT4, _Pla, _Mon, _SIu, _IISB, _PIAr],
      [[0, {
        [_eQN]: `Architecture`,
        [_xN]: _arc
      }], [() => SecurityGroupStringList, { [_xN]: _GN }], [() => SecurityGroupIdStringList, { [_xN]: _GIr }], [0, {
        [_eQN]: `AdditionalInfo`,
        [_xN]: _aId
      }], [() => exports2.UserData$, {
        [_eQN]: `UserData`,
        [_xN]: _uDs
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [() => exports2.Placement$, {
        [_eQN]: `Placement`,
        [_xN]: _pla
      }], [2, {
        [_eQN]: `Monitoring`,
        [_xN]: _mo
      }], [0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }], [0, {
        [_eQN]: `InstanceInitiatedShutdownBehavior`,
        [_xN]: _iISB
      }], [0, {
        [_eQN]: `PrivateIpAddress`,
        [_xN]: _pIAr
      }]]
    ];
    exports2.ImportInstanceRequest$ = [
      3,
      n032,
      _IIRmp,
      0,
      [_Pl, _DR, _De, _LSa, _DIiskm],
      [[0, {
        [_eQN]: `Platform`,
        [_xN]: _pl
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [() => exports2.ImportInstanceLaunchSpecification$, {
        [_eQN]: `LaunchSpecification`,
        [_xN]: _lSa
      }], [() => DiskImageList, {
        [_eQN]: `DiskImage`,
        [_xN]: _dIis
      }]],
      1
    ];
    exports2.ImportInstanceResult$ = [
      3,
      n032,
      _IIRmpo,
      0,
      [_CTo],
      [[() => exports2.ConversionTask$, {
        [_eQN]: `ConversionTask`,
        [_xN]: _cTon
      }]]
    ];
    exports2.ImportInstanceTaskDetails$ = [
      3,
      n032,
      _IITD,
      0,
      [_De, _II2, _Pl, _Vo],
      [[0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `Platform`,
        [_xN]: _pl
      }], [() => ImportInstanceVolumeDetailSet, {
        [_eQN]: `Volumes`,
        [_xN]: _vo
      }]]
    ];
    exports2.ImportInstanceVolumeDetailItem$ = [
      3,
      n032,
      _IIVDI,
      0,
      [_AZ, _AZI, _BCyt, _De, _Ima, _Sta, _SMt, _Vol],
      [[0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [1, {
        [_eQN]: `BytesConverted`,
        [_xN]: _bCy
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [() => exports2.DiskImageDescription$, {
        [_eQN]: `Image`,
        [_xN]: _im
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `StatusMessage`,
        [_xN]: _sMt
      }], [() => exports2.DiskImageVolumeDescription$, {
        [_eQN]: `Volume`,
        [_xN]: _vol
      }]]
    ];
    exports2.ImportKeyPairRequest$ = [
      3,
      n032,
      _IKPR,
      0,
      [_KN, _PKM, _TS, _DR],
      [[0, {
        [_eQN]: `KeyName`,
        [_xN]: _kN
      }], [21, {
        [_eQN]: `PublicKeyMaterial`,
        [_xN]: _pKM
      }], [() => TagSpecificationList, { [_xN]: _TSa }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      2
    ];
    exports2.ImportKeyPairResult$ = [
      3,
      n032,
      _IKPRm,
      0,
      [_KFe, _KN, _KPI, _T10],
      [[0, {
        [_eQN]: `KeyFingerprint`,
        [_xN]: _kFe
      }], [0, {
        [_eQN]: `KeyName`,
        [_xN]: _kN
      }], [0, {
        [_eQN]: `KeyPairId`,
        [_xN]: _kPI
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.ImportSnapshotRequest$ = [
      3,
      n032,
      _ISR,
      0,
      [_CDl, _CT4, _De, _DCisk, _DR, _Enc, _KKI, _RNo, _TS],
      [() => exports2.ClientData$, 0, 0, [() => exports2.SnapshotDiskContainer$, 0], 2, 2, 0, 0, [() => TagSpecificationList, { [_xN]: _TSa }]]
    ];
    exports2.ImportSnapshotResult$ = [
      3,
      n032,
      _ISRm,
      0,
      [_De, _ITI, _STD, _T10],
      [[0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [0, {
        [_eQN]: `ImportTaskId`,
        [_xN]: _iTI
      }], [() => exports2.SnapshotTaskDetail$, {
        [_eQN]: `SnapshotTaskDetail`,
        [_xN]: _sTD
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.ImportSnapshotTask$ = [
      3,
      n032,
      _ISTm,
      0,
      [_De, _ITI, _STD, _T10],
      [[0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [0, {
        [_eQN]: `ImportTaskId`,
        [_xN]: _iTI
      }], [() => exports2.SnapshotTaskDetail$, {
        [_eQN]: `SnapshotTaskDetail`,
        [_xN]: _sTD
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.ImportVolumeRequest$ = [
      3,
      n032,
      _IVR,
      0,
      [_Ima, _Vol, _AZI, _DR, _AZ, _De],
      [[() => exports2.DiskImageDetail$, {
        [_eQN]: `Image`,
        [_xN]: _im
      }], [() => exports2.VolumeDetail$, {
        [_eQN]: `Volume`,
        [_xN]: _vol
      }], 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }]],
      2
    ];
    exports2.ImportVolumeResult$ = [
      3,
      n032,
      _IVRm,
      0,
      [_CTo],
      [[() => exports2.ConversionTask$, {
        [_eQN]: `ConversionTask`,
        [_xN]: _cTon
      }]]
    ];
    exports2.ImportVolumeTaskDetails$ = [
      3,
      n032,
      _IVTD,
      0,
      [_AZ, _AZI, _BCyt, _De, _Ima, _Vol],
      [[0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [1, {
        [_eQN]: `BytesConverted`,
        [_xN]: _bCy
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [() => exports2.DiskImageDescription$, {
        [_eQN]: `Image`,
        [_xN]: _im
      }], [() => exports2.DiskImageVolumeDescription$, {
        [_eQN]: `Volume`,
        [_xN]: _vol
      }]]
    ];
    exports2.InferenceAcceleratorInfo$ = [
      3,
      n032,
      _IAIn,
      0,
      [_Acc, _TIMIMB],
      [[() => InferenceDeviceInfoList, {
        [_eQN]: `Accelerators`,
        [_xN]: _acc
      }], [1, {
        [_eQN]: `TotalInferenceMemoryInMiB`,
        [_xN]: _tIMIMB
      }]]
    ];
    exports2.InferenceDeviceInfo$ = [
      3,
      n032,
      _IDI,
      0,
      [_Cou, _N, _Man, _MIe],
      [[1, {
        [_eQN]: `Count`,
        [_xN]: _cou
      }], [0, {
        [_eQN]: `Name`,
        [_xN]: _n
      }], [0, {
        [_eQN]: `Manufacturer`,
        [_xN]: _man
      }], [() => exports2.InferenceDeviceMemoryInfo$, {
        [_eQN]: `MemoryInfo`,
        [_xN]: _mIe
      }]]
    ];
    exports2.InferenceDeviceMemoryInfo$ = [
      3,
      n032,
      _IDMI,
      0,
      [_SIMB],
      [[1, {
        [_eQN]: `SizeInMiB`,
        [_xN]: _sIMB
      }]]
    ];
    exports2.InitializationStatusDetails$ = [
      3,
      n032,
      _ISD,
      0,
      [_ITni, _Pro, _ETTCIS],
      [[0, {
        [_eQN]: `InitializationType`,
        [_xN]: _iTni
      }], [1, {
        [_eQN]: `Progress`,
        [_xN]: _pro
      }], [1, {
        [_eQN]: `EstimatedTimeToCompleteInSeconds`,
        [_xN]: _eTTCIS
      }]]
    ];
    exports2.Instance$ = [
      3,
      n032,
      _In,
      0,
      [_Arc, _BDMl, _CT4, _EO, _ESna, _Hy, _IIP, _ILn, _EGAl, _EIAAla, _NIet, _OA, _RDN, _RDT, _SGe, _SDC, _SIRI, _SNS, _SRt, _T10, _VTir, _CO, _CBI, _CRI, _CRSa, _HO, _Li, _MO, _EOn, _BM, _PDl, _UO, _UOUT, _PDNO, _IApv, _TSp, _MOa, _CIBM, _NPO, _Op, _SIec, _II2, _IIm, _St, _PDN, _PDNub, _STR, _KN, _ALI, _PCro, _IT4, _LTau, _Pla, _KI, _RIa, _Pl, _Mon, _SIu, _VI, _PIAr, _PIAu],
      [[0, {
        [_eQN]: `Architecture`,
        [_xN]: _arc
      }], [() => InstanceBlockDeviceMappingList, {
        [_eQN]: `BlockDeviceMapping`,
        [_xN]: _bDM
      }], [0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }], [2, {
        [_eQN]: `EbsOptimized`,
        [_xN]: _eO
      }], [2, {
        [_eQN]: `EnaSupport`,
        [_xN]: _eSna
      }], [0, {
        [_eQN]: `Hypervisor`,
        [_xN]: _h22
      }], [() => exports2.IamInstanceProfile$, {
        [_eQN]: `IamInstanceProfile`,
        [_xN]: _iIP
      }], [0, {
        [_eQN]: `InstanceLifecycle`,
        [_xN]: _iLn
      }], [() => ElasticGpuAssociationList, {
        [_eQN]: `ElasticGpuAssociationSet`,
        [_xN]: _eGASl
      }], [() => ElasticInferenceAcceleratorAssociationList, {
        [_eQN]: `ElasticInferenceAcceleratorAssociationSet`,
        [_xN]: _eIAASl
      }], [() => InstanceNetworkInterfaceList, {
        [_eQN]: `NetworkInterfaceSet`,
        [_xN]: _nIS
      }], [0, {
        [_eQN]: `OutpostArn`,
        [_xN]: _oA
      }], [0, {
        [_eQN]: `RootDeviceName`,
        [_xN]: _rDN
      }], [0, {
        [_eQN]: `RootDeviceType`,
        [_xN]: _rDT
      }], [() => GroupIdentifierList, {
        [_eQN]: `GroupSet`,
        [_xN]: _gSr
      }], [2, {
        [_eQN]: `SourceDestCheck`,
        [_xN]: _sDC
      }], [0, {
        [_eQN]: `SpotInstanceRequestId`,
        [_xN]: _sIRI
      }], [0, {
        [_eQN]: `SriovNetSupport`,
        [_xN]: _sNSr
      }], [() => exports2.StateReason$, {
        [_eQN]: `StateReason`,
        [_xN]: _sRt
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `VirtualizationType`,
        [_xN]: _vTi
      }], [() => exports2.CpuOptions$, {
        [_eQN]: `CpuOptions`,
        [_xN]: _cO
      }], [0, {
        [_eQN]: `CapacityBlockId`,
        [_xN]: _cBI
      }], [0, {
        [_eQN]: `CapacityReservationId`,
        [_xN]: _cRI
      }], [() => exports2.CapacityReservationSpecificationResponse$, {
        [_eQN]: `CapacityReservationSpecification`,
        [_xN]: _cRSa
      }], [() => exports2.HibernationOptions$, {
        [_eQN]: `HibernationOptions`,
        [_xN]: _hO
      }], [() => LicenseList, {
        [_eQN]: `LicenseSet`,
        [_xN]: _lSi
      }], [() => exports2.InstanceMetadataOptionsResponse$, {
        [_eQN]: `MetadataOptions`,
        [_xN]: _mO
      }], [() => exports2.EnclaveOptions$, {
        [_eQN]: `EnclaveOptions`,
        [_xN]: _eOn
      }], [0, {
        [_eQN]: `BootMode`,
        [_xN]: _bM
      }], [0, {
        [_eQN]: `PlatformDetails`,
        [_xN]: _pDl
      }], [0, {
        [_eQN]: `UsageOperation`,
        [_xN]: _uO
      }], [4, {
        [_eQN]: `UsageOperationUpdateTime`,
        [_xN]: _uOUT
      }], [() => exports2.PrivateDnsNameOptionsResponse$, {
        [_eQN]: `PrivateDnsNameOptions`,
        [_xN]: _pDNO
      }], [0, {
        [_eQN]: `Ipv6Address`,
        [_xN]: _iApv
      }], [0, {
        [_eQN]: `TpmSupport`,
        [_xN]: _tSp
      }], [() => exports2.InstanceMaintenanceOptions$, {
        [_eQN]: `MaintenanceOptions`,
        [_xN]: _mOa
      }], [0, {
        [_eQN]: `CurrentInstanceBootMode`,
        [_xN]: _cIBM
      }], [() => exports2.InstanceNetworkPerformanceOptions$, {
        [_eQN]: `NetworkPerformanceOptions`,
        [_xN]: _nPO
      }], [() => exports2.OperatorResponse$, {
        [_eQN]: `Operator`,
        [_xN]: _ope
      }], [() => InstanceSecondaryInterfaceList, {
        [_eQN]: `SecondaryInterfaceSet`,
        [_xN]: _sISe
      }], [0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `ImageId`,
        [_xN]: _iIma
      }], [() => exports2.InstanceState$, {
        [_eQN]: `InstanceState`,
        [_xN]: _iSnst
      }], [0, {
        [_eQN]: `PrivateDnsName`,
        [_xN]: _pDNr
      }], [0, {
        [_eQN]: `DnsName`,
        [_xN]: _dNn
      }], [0, {
        [_eQN]: `Reason`,
        [_xN]: _rea
      }], [0, {
        [_eQN]: `KeyName`,
        [_xN]: _kN
      }], [1, {
        [_eQN]: `AmiLaunchIndex`,
        [_xN]: _aLI
      }], [() => ProductCodeList, {
        [_eQN]: `ProductCodes`,
        [_xN]: _pC
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [4, {
        [_eQN]: `LaunchTime`,
        [_xN]: _lTau
      }], [() => exports2.Placement$, {
        [_eQN]: `Placement`,
        [_xN]: _pla
      }], [0, {
        [_eQN]: `KernelId`,
        [_xN]: _kI
      }], [0, {
        [_eQN]: `RamdiskId`,
        [_xN]: _rIa
      }], [0, {
        [_eQN]: `Platform`,
        [_xN]: _pl
      }], [() => exports2.Monitoring$, {
        [_eQN]: `Monitoring`,
        [_xN]: _mo
      }], [0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [0, {
        [_eQN]: `PrivateIpAddress`,
        [_xN]: _pIAr
      }], [0, {
        [_eQN]: `IpAddress`,
        [_xN]: _iAp
      }]]
    ];
    exports2.InstanceAttachmentEnaSrdSpecification$ = [
      3,
      n032,
      _IAESS,
      0,
      [_ESE2, _ESUS],
      [[2, {
        [_eQN]: `EnaSrdEnabled`,
        [_xN]: _eSE
      }], [() => exports2.InstanceAttachmentEnaSrdUdpSpecification$, {
        [_eQN]: `EnaSrdUdpSpecification`,
        [_xN]: _eSUS
      }]]
    ];
    exports2.InstanceAttachmentEnaSrdUdpSpecification$ = [
      3,
      n032,
      _IAESUS,
      0,
      [_ESUE],
      [[2, {
        [_eQN]: `EnaSrdUdpEnabled`,
        [_xN]: _eSUE
      }]]
    ];
    exports2.InstanceAttribute$ = [
      3,
      n032,
      _IAns,
      0,
      [_BDMl, _DAT, _ESna, _EOn, _EO, _II2, _IISB, _IT4, _KI, _PCro, _RIa, _RDN, _SDC, _SNS, _UDs, _DASi, _G],
      [[() => InstanceBlockDeviceMappingList, {
        [_eQN]: `BlockDeviceMapping`,
        [_xN]: _bDM
      }], [() => exports2.AttributeBooleanValue$, {
        [_eQN]: `DisableApiTermination`,
        [_xN]: _dAT
      }], [() => exports2.AttributeBooleanValue$, {
        [_eQN]: `EnaSupport`,
        [_xN]: _eSna
      }], [() => exports2.EnclaveOptions$, {
        [_eQN]: `EnclaveOptions`,
        [_xN]: _eOn
      }], [() => exports2.AttributeBooleanValue$, {
        [_eQN]: `EbsOptimized`,
        [_xN]: _eO
      }], [0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [() => exports2.AttributeValue$, {
        [_eQN]: `InstanceInitiatedShutdownBehavior`,
        [_xN]: _iISB
      }], [() => exports2.AttributeValue$, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [() => exports2.AttributeValue$, {
        [_eQN]: `Kernel`,
        [_xN]: _ke
      }], [() => ProductCodeList, {
        [_eQN]: `ProductCodes`,
        [_xN]: _pC
      }], [() => exports2.AttributeValue$, {
        [_eQN]: `Ramdisk`,
        [_xN]: _ra
      }], [() => exports2.AttributeValue$, {
        [_eQN]: `RootDeviceName`,
        [_xN]: _rDN
      }], [() => exports2.AttributeBooleanValue$, {
        [_eQN]: `SourceDestCheck`,
        [_xN]: _sDC
      }], [() => exports2.AttributeValue$, {
        [_eQN]: `SriovNetSupport`,
        [_xN]: _sNSr
      }], [() => exports2.AttributeValue$, {
        [_eQN]: `UserData`,
        [_xN]: _uDs
      }], [() => exports2.AttributeBooleanValue$, {
        [_eQN]: `DisableApiStop`,
        [_xN]: _dASi
      }], [() => GroupIdentifierList, {
        [_eQN]: `GroupSet`,
        [_xN]: _gSr
      }]]
    ];
    exports2.InstanceBlockDeviceMapping$ = [
      3,
      n032,
      _IBDM,
      0,
      [_DN, _Eb],
      [[0, {
        [_eQN]: `DeviceName`,
        [_xN]: _dN
      }], [() => exports2.EbsInstanceBlockDevice$, {
        [_eQN]: `Ebs`,
        [_xN]: _eb
      }]]
    ];
    exports2.InstanceBlockDeviceMappingSpecification$ = [
      3,
      n032,
      _IBDMS,
      0,
      [_DN, _Eb, _VN, _ND],
      [[0, {
        [_eQN]: `DeviceName`,
        [_xN]: _dN
      }], [() => exports2.EbsInstanceBlockDeviceSpecification$, {
        [_eQN]: `Ebs`,
        [_xN]: _eb
      }], [0, {
        [_eQN]: `VirtualName`,
        [_xN]: _vN
      }], [0, {
        [_eQN]: `NoDevice`,
        [_xN]: _nD
      }]]
    ];
    exports2.InstanceCapacity$ = [
      3,
      n032,
      _ICn,
      0,
      [_ACv, _IT4, _TCo],
      [[1, {
        [_eQN]: `AvailableCapacity`,
        [_xN]: _aC
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [1, {
        [_eQN]: `TotalCapacity`,
        [_xN]: _tC
      }]]
    ];
    exports2.InstanceConnectEndpointDnsNames$ = [
      3,
      n032,
      _ICEDN,
      0,
      [_DNn, _FDN],
      [[0, {
        [_eQN]: `DnsName`,
        [_xN]: _dNn
      }], [0, {
        [_eQN]: `FipsDnsName`,
        [_xN]: _fDN
      }]]
    ];
    exports2.InstanceConnectEndpointPublicDnsNames$ = [
      3,
      n032,
      _ICEPDN,
      0,
      [_Ipv, _Dua],
      [[() => exports2.InstanceConnectEndpointDnsNames$, {
        [_eQN]: `Ipv4`,
        [_xN]: _ipv
      }], [() => exports2.InstanceConnectEndpointDnsNames$, {
        [_eQN]: `Dualstack`,
        [_xN]: _dua
      }]]
    ];
    exports2.InstanceCount$ = [
      3,
      n032,
      _IC,
      0,
      [_IC, _St],
      [[1, {
        [_eQN]: `InstanceCount`,
        [_xN]: _iC
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }]]
    ];
    exports2.InstanceCreditSpecification$ = [
      3,
      n032,
      _ICSn,
      0,
      [_II2, _CCp],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `CpuCredits`,
        [_xN]: _cCp
      }]]
    ];
    exports2.InstanceCreditSpecificationRequest$ = [
      3,
      n032,
      _ICSR,
      0,
      [_II2, _CCp],
      [0, 0],
      1
    ];
    exports2.InstanceEventWindow$ = [
      3,
      n032,
      _IEW,
      0,
      [_IEWI, _TRi, _N, _CEr, _ATs, _St, _T10],
      [[0, {
        [_eQN]: `InstanceEventWindowId`,
        [_xN]: _iEWI
      }], [() => InstanceEventWindowTimeRangeList, {
        [_eQN]: `TimeRangeSet`,
        [_xN]: _tRSi
      }], [0, {
        [_eQN]: `Name`,
        [_xN]: _n
      }], [0, {
        [_eQN]: `CronExpression`,
        [_xN]: _cEr
      }], [() => exports2.InstanceEventWindowAssociationTarget$, {
        [_eQN]: `AssociationTarget`,
        [_xN]: _aTs
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.InstanceEventWindowAssociationRequest$ = [
      3,
      n032,
      _IEWAR,
      0,
      [_IIns, _ITnsta, _DHI],
      [[() => InstanceIdList, { [_xN]: _II2 }], [() => TagList, { [_xN]: _ITnstan }], [() => DedicatedHostIdList, { [_xN]: _DHIe }]]
    ];
    exports2.InstanceEventWindowAssociationTarget$ = [
      3,
      n032,
      _IEWAT,
      0,
      [_IIns, _T10, _DHI],
      [[() => InstanceIdList, {
        [_eQN]: `InstanceIdSet`,
        [_xN]: _iIS
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [() => DedicatedHostIdList, {
        [_eQN]: `DedicatedHostIdSet`,
        [_xN]: _dHIS
      }]]
    ];
    exports2.InstanceEventWindowDisassociationRequest$ = [
      3,
      n032,
      _IEWDR,
      0,
      [_IIns, _ITnsta, _DHI],
      [[() => InstanceIdList, { [_xN]: _II2 }], [() => TagList, { [_xN]: _ITnstan }], [() => DedicatedHostIdList, { [_xN]: _DHIe }]]
    ];
    exports2.InstanceEventWindowStateChange$ = [
      3,
      n032,
      _IEWSC,
      0,
      [_IEWI, _St],
      [[0, {
        [_eQN]: `InstanceEventWindowId`,
        [_xN]: _iEWI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }]]
    ];
    exports2.InstanceEventWindowTimeRange$ = [
      3,
      n032,
      _IEWTR,
      0,
      [_SWD, _SH, _EWD, _EH],
      [[0, {
        [_eQN]: `StartWeekDay`,
        [_xN]: _sWD
      }], [1, {
        [_eQN]: `StartHour`,
        [_xN]: _sH
      }], [0, {
        [_eQN]: `EndWeekDay`,
        [_xN]: _eWD
      }], [1, {
        [_eQN]: `EndHour`,
        [_xN]: _eH
      }]]
    ];
    exports2.InstanceEventWindowTimeRangeRequest$ = [
      3,
      n032,
      _IEWTRR,
      0,
      [_SWD, _SH, _EWD, _EH],
      [0, 1, 0, 1]
    ];
    exports2.InstanceExportDetails$ = [
      3,
      n032,
      _IED,
      0,
      [_II2, _TE],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `TargetEnvironment`,
        [_xN]: _tE
      }]]
    ];
    exports2.InstanceFamilyCreditSpecification$ = [
      3,
      n032,
      _IFCS,
      0,
      [_IF, _CCp],
      [[0, {
        [_eQN]: `InstanceFamily`,
        [_xN]: _iF
      }], [0, {
        [_eQN]: `CpuCredits`,
        [_xN]: _cCp
      }]]
    ];
    exports2.InstanceImageMetadata$ = [
      3,
      n032,
      _IIM,
      0,
      [_II2, _IT4, _LTau, _AZ, _ZI, _St, _OI, _T10, _IMm, _Op],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [4, {
        [_eQN]: `LaunchTime`,
        [_xN]: _lTau
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [0, {
        [_eQN]: `ZoneId`,
        [_xN]: _zI
      }], [() => exports2.InstanceState$, {
        [_eQN]: `InstanceState`,
        [_xN]: _iSnst
      }], [0, {
        [_eQN]: `InstanceOwnerId`,
        [_xN]: _iOIn
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [() => exports2.ImageMetadata$, {
        [_eQN]: `ImageMetadata`,
        [_xN]: _iM
      }], [() => exports2.OperatorResponse$, {
        [_eQN]: `Operator`,
        [_xN]: _ope
      }]]
    ];
    exports2.InstanceIpv4Prefix$ = [
      3,
      n032,
      _IIPn,
      0,
      [_IPpvre],
      [[0, {
        [_eQN]: `Ipv4Prefix`,
        [_xN]: _iPpv
      }]]
    ];
    exports2.InstanceIpv6Address$ = [
      3,
      n032,
      _IIA,
      0,
      [_IApv, _IPIs],
      [[0, {
        [_eQN]: `Ipv6Address`,
        [_xN]: _iApv
      }], [2, {
        [_eQN]: `IsPrimaryIpv6`,
        [_xN]: _iPIs
      }]]
    ];
    exports2.InstanceIpv6AddressRequest$ = [
      3,
      n032,
      _IIAR,
      0,
      [_IApv],
      [0]
    ];
    exports2.InstanceIpv6Prefix$ = [
      3,
      n032,
      _IIPns,
      0,
      [_IPpv],
      [[0, {
        [_eQN]: `Ipv6Prefix`,
        [_xN]: _iPpvr
      }]]
    ];
    exports2.InstanceMaintenanceOptions$ = [
      3,
      n032,
      _IMO,
      0,
      [_ARuto, _RMe],
      [[0, {
        [_eQN]: `AutoRecovery`,
        [_xN]: _aRut
      }], [0, {
        [_eQN]: `RebootMigration`,
        [_xN]: _rMe
      }]]
    ];
    exports2.InstanceMaintenanceOptionsRequest$ = [
      3,
      n032,
      _IMOR,
      0,
      [_ARuto],
      [0]
    ];
    exports2.InstanceMarketOptionsRequest$ = [
      3,
      n032,
      _IMORn,
      0,
      [_MT, _SO],
      [0, () => exports2.SpotMarketOptions$]
    ];
    exports2.InstanceMetadataDefaultsResponse$ = [
      3,
      n032,
      _IMDR,
      0,
      [_HT, _HPRHL, _HE, _IMT, _MB, _MEM, _HTE],
      [[0, {
        [_eQN]: `HttpTokens`,
        [_xN]: _hT
      }], [1, {
        [_eQN]: `HttpPutResponseHopLimit`,
        [_xN]: _hPRHL
      }], [0, {
        [_eQN]: `HttpEndpoint`,
        [_xN]: _hE32
      }], [0, {
        [_eQN]: `InstanceMetadataTags`,
        [_xN]: _iMT
      }], [0, {
        [_eQN]: `ManagedBy`,
        [_xN]: _mB
      }], [0, {
        [_eQN]: `ManagedExceptionMessage`,
        [_xN]: _mEM
      }], [0, {
        [_eQN]: `HttpTokensEnforced`,
        [_xN]: _hTE
      }]]
    ];
    exports2.InstanceMetadataOptionsRequest$ = [
      3,
      n032,
      _IMORns,
      0,
      [_HT, _HPRHL, _HE, _HPI, _IMT],
      [0, 1, 0, 0, 0]
    ];
    exports2.InstanceMetadataOptionsResponse$ = [
      3,
      n032,
      _IMORnst,
      0,
      [_St, _HT, _HPRHL, _HE, _HPI, _IMT],
      [[0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `HttpTokens`,
        [_xN]: _hT
      }], [1, {
        [_eQN]: `HttpPutResponseHopLimit`,
        [_xN]: _hPRHL
      }], [0, {
        [_eQN]: `HttpEndpoint`,
        [_xN]: _hE32
      }], [0, {
        [_eQN]: `HttpProtocolIpv6`,
        [_xN]: _hPI
      }], [0, {
        [_eQN]: `InstanceMetadataTags`,
        [_xN]: _iMT
      }]]
    ];
    exports2.InstanceMonitoring$ = [
      3,
      n032,
      _IMn,
      0,
      [_II2, _Mon],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [() => exports2.Monitoring$, {
        [_eQN]: `Monitoring`,
        [_xN]: _mo
      }]]
    ];
    exports2.InstanceNetworkInterface$ = [
      3,
      n032,
      _INI,
      0,
      [_Ass, _Att, _De, _G, _IA, _MAa, _NII, _OI, _PDN, _PIAr, _PIAri, _SDC, _Sta, _SIu, _VI, _ITnt, _IPpvr, _IPp, _CTC, _Op],
      [[() => exports2.InstanceNetworkInterfaceAssociation$, {
        [_eQN]: `Association`,
        [_xN]: _ass
      }], [() => exports2.InstanceNetworkInterfaceAttachment$, {
        [_eQN]: `Attachment`,
        [_xN]: _at
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [() => GroupIdentifierList, {
        [_eQN]: `GroupSet`,
        [_xN]: _gSr
      }], [() => InstanceIpv6AddressList, {
        [_eQN]: `Ipv6AddressesSet`,
        [_xN]: _iASp
      }], [0, {
        [_eQN]: `MacAddress`,
        [_xN]: _mAa
      }], [0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `PrivateDnsName`,
        [_xN]: _pDNr
      }], [0, {
        [_eQN]: `PrivateIpAddress`,
        [_xN]: _pIAr
      }], [() => InstancePrivateIpAddressList, {
        [_eQN]: `PrivateIpAddressesSet`,
        [_xN]: _pIAS
      }], [2, {
        [_eQN]: `SourceDestCheck`,
        [_xN]: _sDC
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [0, {
        [_eQN]: `InterfaceType`,
        [_xN]: _iTnt
      }], [() => InstanceIpv4PrefixList, {
        [_eQN]: `Ipv4PrefixSet`,
        [_xN]: _iPSpvr
      }], [() => InstanceIpv6PrefixList, {
        [_eQN]: `Ipv6PrefixSet`,
        [_xN]: _iPSpvre
      }], [() => exports2.ConnectionTrackingSpecificationResponse$, {
        [_eQN]: `ConnectionTrackingConfiguration`,
        [_xN]: _cTC
      }], [() => exports2.OperatorResponse$, {
        [_eQN]: `Operator`,
        [_xN]: _ope
      }]]
    ];
    exports2.InstanceNetworkInterfaceAssociation$ = [
      3,
      n032,
      _INIA,
      0,
      [_CI, _COI, _IOI, _PDNub, _PI10],
      [[0, {
        [_eQN]: `CarrierIp`,
        [_xN]: _cI13
      }], [0, {
        [_eQN]: `CustomerOwnedIp`,
        [_xN]: _cOI
      }], [0, {
        [_eQN]: `IpOwnerId`,
        [_xN]: _iOIp
      }], [0, {
        [_eQN]: `PublicDnsName`,
        [_xN]: _pDNu
      }], [0, {
        [_eQN]: `PublicIp`,
        [_xN]: _pI
      }]]
    ];
    exports2.InstanceNetworkInterfaceAttachment$ = [
      3,
      n032,
      _INIAn,
      0,
      [_ATtt, _AItt, _DOT, _DI, _Sta, _NCI, _ESS, _EQC],
      [[4, {
        [_eQN]: `AttachTime`,
        [_xN]: _aTt
      }], [0, {
        [_eQN]: `AttachmentId`,
        [_xN]: _aIt
      }], [2, {
        [_eQN]: `DeleteOnTermination`,
        [_xN]: _dOT
      }], [1, {
        [_eQN]: `DeviceIndex`,
        [_xN]: _dI
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [1, {
        [_eQN]: `NetworkCardIndex`,
        [_xN]: _nCI
      }], [() => exports2.InstanceAttachmentEnaSrdSpecification$, {
        [_eQN]: `EnaSrdSpecification`,
        [_xN]: _eSS
      }], [1, {
        [_eQN]: `EnaQueueCount`,
        [_xN]: _eQC
      }]]
    ];
    exports2.InstanceNetworkInterfaceSpecification$ = [
      3,
      n032,
      _INIS,
      0,
      [_APIAss, _DOT, _De, _DI, _G, _IAC, _IA, _NII, _PIAr, _PIAri, _SPIAC, _SIu, _ACIA, _ITnt, _NCI, _IPpvr, _IPCp, _IPp, _IPC, _PIr, _ESS, _CTS, _EQC],
      [[2, {
        [_eQN]: `AssociatePublicIpAddress`,
        [_xN]: _aPIA
      }], [2, {
        [_eQN]: `DeleteOnTermination`,
        [_xN]: _dOT
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [1, {
        [_eQN]: `DeviceIndex`,
        [_xN]: _dI
      }], [() => SecurityGroupIdStringList, { [_xN]: _SGI }], [1, {
        [_eQN]: `Ipv6AddressCount`,
        [_xN]: _iAC
      }], [() => InstanceIpv6AddressList, {
        [_eQN]: `Ipv6Addresses`,
        [_xN]: _iASp
      }], [0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], [0, {
        [_eQN]: `PrivateIpAddress`,
        [_xN]: _pIAr
      }], [() => PrivateIpAddressSpecificationList, {
        [_eQN]: `PrivateIpAddresses`,
        [_xN]: _pIAS
      }], [1, {
        [_eQN]: `SecondaryPrivateIpAddressCount`,
        [_xN]: _sPIAC
      }], [0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }], 2, 0, 1, [() => Ipv4PrefixList, { [_xN]: _IPpvre }], 1, [() => Ipv6PrefixList, { [_xN]: _IPpv }], 1, 2, () => exports2.EnaSrdSpecificationRequest$, () => exports2.ConnectionTrackingSpecificationRequest$, 1]
    ];
    exports2.InstanceNetworkPerformanceOptions$ = [
      3,
      n032,
      _INPO,
      0,
      [_BW],
      [[0, {
        [_eQN]: `BandwidthWeighting`,
        [_xN]: _bW
      }]]
    ];
    exports2.InstanceNetworkPerformanceOptionsRequest$ = [
      3,
      n032,
      _INPOR,
      0,
      [_BW],
      [0]
    ];
    exports2.InstancePrivateIpAddress$ = [
      3,
      n032,
      _IPIA,
      0,
      [_Ass, _Prim, _PDN, _PIAr],
      [[() => exports2.InstanceNetworkInterfaceAssociation$, {
        [_eQN]: `Association`,
        [_xN]: _ass
      }], [2, {
        [_eQN]: `Primary`,
        [_xN]: _prim
      }], [0, {
        [_eQN]: `PrivateDnsName`,
        [_xN]: _pDNr
      }], [0, {
        [_eQN]: `PrivateIpAddress`,
        [_xN]: _pIAr
      }]]
    ];
    exports2.InstanceRequirements$ = [
      3,
      n032,
      _IRn,
      0,
      [_VCC, _MMB, _CM, _MGBPVC, _EITxc, _IGns, _SMPPOLP, _ODMPPOLP, _BMa, _BP, _RHS, _NIC, _LSo, _LST, _TLSGB, _BEBM, _ATc, _AC, _AMc, _ANcc, _ATMMB, _NBGe, _AIT, _MSPAPOOODP, _BPF, _REIT],
      [[() => exports2.VCpuCountRange$, {
        [_eQN]: `VCpuCount`,
        [_xN]: _vCC
      }], [() => exports2.MemoryMiB$, {
        [_eQN]: `MemoryMiB`,
        [_xN]: _mMB
      }], [() => CpuManufacturerSet, {
        [_eQN]: `CpuManufacturerSet`,
        [_xN]: _cMSp
      }], [() => exports2.MemoryGiBPerVCpu$, {
        [_eQN]: `MemoryGiBPerVCpu`,
        [_xN]: _mGBPVC
      }], [() => ExcludedInstanceTypeSet, {
        [_eQN]: `ExcludedInstanceTypeSet`,
        [_xN]: _eITSx
      }], [() => InstanceGenerationSet, {
        [_eQN]: `InstanceGenerationSet`,
        [_xN]: _iGSn
      }], [1, {
        [_eQN]: `SpotMaxPricePercentageOverLowestPrice`,
        [_xN]: _sMPPOLP
      }], [1, {
        [_eQN]: `OnDemandMaxPricePercentageOverLowestPrice`,
        [_xN]: _oDMPPOLP
      }], [0, {
        [_eQN]: `BareMetal`,
        [_xN]: _bMa
      }], [0, {
        [_eQN]: `BurstablePerformance`,
        [_xN]: _bP
      }], [2, {
        [_eQN]: `RequireHibernateSupport`,
        [_xN]: _rHS
      }], [() => exports2.NetworkInterfaceCount$, {
        [_eQN]: `NetworkInterfaceCount`,
        [_xN]: _nIC
      }], [0, {
        [_eQN]: `LocalStorage`,
        [_xN]: _lSo
      }], [() => LocalStorageTypeSet, {
        [_eQN]: `LocalStorageTypeSet`,
        [_xN]: _lSTS
      }], [() => exports2.TotalLocalStorageGB$, {
        [_eQN]: `TotalLocalStorageGB`,
        [_xN]: _tLSGB
      }], [() => exports2.BaselineEbsBandwidthMbps$, {
        [_eQN]: `BaselineEbsBandwidthMbps`,
        [_xN]: _bEBM
      }], [() => AcceleratorTypeSet, {
        [_eQN]: `AcceleratorTypeSet`,
        [_xN]: _aTSc
      }], [() => exports2.AcceleratorCount$, {
        [_eQN]: `AcceleratorCount`,
        [_xN]: _aCc
      }], [() => AcceleratorManufacturerSet, {
        [_eQN]: `AcceleratorManufacturerSet`,
        [_xN]: _aMS
      }], [() => AcceleratorNameSet, {
        [_eQN]: `AcceleratorNameSet`,
        [_xN]: _aNS
      }], [() => exports2.AcceleratorTotalMemoryMiB$, {
        [_eQN]: `AcceleratorTotalMemoryMiB`,
        [_xN]: _aTMMB
      }], [() => exports2.NetworkBandwidthGbps$, {
        [_eQN]: `NetworkBandwidthGbps`,
        [_xN]: _nBGe
      }], [() => AllowedInstanceTypeSet, {
        [_eQN]: `AllowedInstanceTypeSet`,
        [_xN]: _aITS
      }], [1, {
        [_eQN]: `MaxSpotPriceAsPercentageOfOptimalOnDemandPrice`,
        [_xN]: _mSPAPOOODP
      }], [() => exports2.BaselinePerformanceFactors$, {
        [_eQN]: `BaselinePerformanceFactors`,
        [_xN]: _bPF
      }], [2, {
        [_eQN]: `RequireEncryptionInTransit`,
        [_xN]: _rEIT
      }]]
    ];
    exports2.InstanceRequirementsRequest$ = [
      3,
      n032,
      _IRR,
      0,
      [_VCC, _MMB, _CM, _MGBPVC, _EITxc, _IGns, _SMPPOLP, _ODMPPOLP, _BMa, _BP, _RHS, _NIC, _LSo, _LST, _TLSGB, _BEBM, _ATc, _AC, _AMc, _ANcc, _ATMMB, _NBGe, _AIT, _MSPAPOOODP, _BPF, _REIT],
      [() => exports2.VCpuCountRangeRequest$, () => exports2.MemoryMiBRequest$, [() => CpuManufacturerSet, { [_xN]: _CMp }], () => exports2.MemoryGiBPerVCpuRequest$, [() => ExcludedInstanceTypeSet, { [_xN]: _EITxcl }], [() => InstanceGenerationSet, { [_xN]: _IGnst }], 1, 1, 0, 0, 2, () => exports2.NetworkInterfaceCountRequest$, 0, [() => LocalStorageTypeSet, { [_xN]: _LSTo }], () => exports2.TotalLocalStorageGBRequest$, () => exports2.BaselineEbsBandwidthMbpsRequest$, [() => AcceleratorTypeSet, { [_xN]: _ATcc }], () => exports2.AcceleratorCountRequest$, [() => AcceleratorManufacturerSet, { [_xN]: _AMcc }], [() => AcceleratorNameSet, { [_xN]: _ANcce }], () => exports2.AcceleratorTotalMemoryMiBRequest$, () => exports2.NetworkBandwidthGbpsRequest$, [() => AllowedInstanceTypeSet, { [_xN]: _AITl }], 1, [() => exports2.BaselinePerformanceFactorsRequest$, 0], 2],
      2
    ];
    exports2.InstanceRequirementsWithMetadataRequest$ = [
      3,
      n032,
      _IRWMR,
      0,
      [_ATr, _VTi, _IRn],
      [[() => ArchitectureTypeSet, { [_xN]: _ATrc }], [() => VirtualizationTypeSet, { [_xN]: _VTir }], [() => exports2.InstanceRequirementsRequest$, 0]]
    ];
    exports2.InstanceSecondaryInterface$ = [
      3,
      n032,
      _ISIn,
      0,
      [_Att, _MAa, _SIIec, _OI, _PIAri, _SDC, _Sta, _SSIe, _SNI, _ITnt],
      [[() => exports2.InstanceSecondaryInterfaceAttachment$, {
        [_eQN]: `Attachment`,
        [_xN]: _at
      }], [0, {
        [_eQN]: `MacAddress`,
        [_xN]: _mAa
      }], [0, {
        [_eQN]: `SecondaryInterfaceId`,
        [_xN]: _sIIe
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [() => InstanceSecondaryInterfacePrivateIpAddressList, {
        [_eQN]: `PrivateIpAddressSet`,
        [_xN]: _pIASr
      }], [2, {
        [_eQN]: `SourceDestCheck`,
        [_xN]: _sDC
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `SecondarySubnetId`,
        [_xN]: _sSI
      }], [0, {
        [_eQN]: `SecondaryNetworkId`,
        [_xN]: _sNI
      }], [0, {
        [_eQN]: `InterfaceType`,
        [_xN]: _iTnt
      }]]
    ];
    exports2.InstanceSecondaryInterfaceAttachment$ = [
      3,
      n032,
      _ISIA,
      0,
      [_ATtt, _AItt, _DOT, _DI, _Sta, _NCI],
      [[4, {
        [_eQN]: `AttachTime`,
        [_xN]: _aTt
      }], [0, {
        [_eQN]: `AttachmentId`,
        [_xN]: _aIt
      }], [2, {
        [_eQN]: `DeleteOnTermination`,
        [_xN]: _dOT
      }], [1, {
        [_eQN]: `DeviceIndex`,
        [_xN]: _dI
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [1, {
        [_eQN]: `NetworkCardIndex`,
        [_xN]: _nCI
      }]]
    ];
    exports2.InstanceSecondaryInterfacePrivateIpAddress$ = [
      3,
      n032,
      _ISIPIA,
      0,
      [_PIAr],
      [[0, {
        [_eQN]: `PrivateIpAddress`,
        [_xN]: _pIAr
      }]]
    ];
    exports2.InstanceSecondaryInterfacePrivateIpAddressRequest$ = [
      3,
      n032,
      _ISIPIAR,
      0,
      [_PIAr],
      [0],
      1
    ];
    exports2.InstanceSecondaryInterfaceSpecificationRequest$ = [
      3,
      n032,
      _ISISR,
      0,
      [_DOT, _DI, _PIAri, _PIAC, _SSIe, _ITnt, _NCI],
      [2, 1, [() => InstanceSecondaryInterfacePrivateIpAddressListRequest, { [_xN]: _PIAr }], 1, 0, 0, 1]
    ];
    exports2.InstanceSpecification$ = [
      3,
      n032,
      _ISn,
      0,
      [_II2, _EBV, _EDVI],
      [0, 2, [() => VolumeIdStringList, { [_xN]: _EDVIx }]],
      1
    ];
    exports2.InstanceState$ = [
      3,
      n032,
      _ISnst,
      0,
      [_Co, _N],
      [[1, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Name`,
        [_xN]: _n
      }]]
    ];
    exports2.InstanceStateChange$ = [
      3,
      n032,
      _ISC,
      0,
      [_II2, _CSu, _PSr],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [() => exports2.InstanceState$, {
        [_eQN]: `CurrentState`,
        [_xN]: _cSu
      }], [() => exports2.InstanceState$, {
        [_eQN]: `PreviousState`,
        [_xN]: _pSr
      }]]
    ];
    exports2.InstanceStatus$ = [
      3,
      n032,
      _ISnsta,
      0,
      [_AZ, _AZI, _OA, _Op, _Ev, _II2, _ISnst, _ISnsta, _SSy, _AES],
      [[0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [0, {
        [_eQN]: `OutpostArn`,
        [_xN]: _oA
      }], [() => exports2.OperatorResponse$, {
        [_eQN]: `Operator`,
        [_xN]: _ope
      }], [() => InstanceStatusEventList, {
        [_eQN]: `EventsSet`,
        [_xN]: _eSv
      }], [0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [() => exports2.InstanceState$, {
        [_eQN]: `InstanceState`,
        [_xN]: _iSnst
      }], [() => exports2.InstanceStatusSummary$, {
        [_eQN]: `InstanceStatus`,
        [_xN]: _iSnsta
      }], [() => exports2.InstanceStatusSummary$, {
        [_eQN]: `SystemStatus`,
        [_xN]: _sSy
      }], [() => exports2.EbsStatusSummary$, {
        [_eQN]: `AttachedEbsStatus`,
        [_xN]: _aES
      }]]
    ];
    exports2.InstanceStatusDetails$ = [
      3,
      n032,
      _ISDn,
      0,
      [_ISm, _N, _Sta],
      [[4, {
        [_eQN]: `ImpairedSince`,
        [_xN]: _iSmp
      }], [0, {
        [_eQN]: `Name`,
        [_xN]: _n
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }]]
    ];
    exports2.InstanceStatusEvent$ = [
      3,
      n032,
      _ISE13,
      0,
      [_IEI, _Co, _De, _NAo, _NB, _NBD],
      [[0, {
        [_eQN]: `InstanceEventId`,
        [_xN]: _iEI
      }], [0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [4, {
        [_eQN]: `NotAfter`,
        [_xN]: _nAo
      }], [4, {
        [_eQN]: `NotBefore`,
        [_xN]: _nB
      }], [4, {
        [_eQN]: `NotBeforeDeadline`,
        [_xN]: _nBD
      }]]
    ];
    exports2.InstanceStatusSummary$ = [
      3,
      n032,
      _ISS,
      0,
      [_Det, _Sta],
      [[() => InstanceStatusDetailsList, {
        [_eQN]: `Details`,
        [_xN]: _det
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }]]
    ];
    exports2.InstanceStorageInfo$ = [
      3,
      n032,
      _ISIns,
      0,
      [_TSIGB, _Dis, _NS, _ESn],
      [[1, {
        [_eQN]: `TotalSizeInGB`,
        [_xN]: _tSIGB
      }], [() => DiskInfoList, {
        [_eQN]: `Disks`,
        [_xN]: _dis
      }], [0, {
        [_eQN]: `NvmeSupport`,
        [_xN]: _nS
      }], [0, {
        [_eQN]: `EncryptionSupport`,
        [_xN]: _eSn
      }]]
    ];
    exports2.InstanceTagNotificationAttribute$ = [
      3,
      n032,
      _ITNA,
      0,
      [_ITK, _IATOI],
      [[() => InstanceTagKeySet, {
        [_eQN]: `InstanceTagKeySet`,
        [_xN]: _iTKS
      }], [2, {
        [_eQN]: `IncludeAllTagsOfInstance`,
        [_xN]: _iATOI
      }]]
    ];
    exports2.InstanceTopology$ = [
      3,
      n032,
      _ITnstanc,
      0,
      [_II2, _IT4, _GN, _NN, _AZ, _ZI, _CBI],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [0, {
        [_eQN]: `GroupName`,
        [_xN]: _gN
      }], [() => NetworkNodesList, {
        [_eQN]: `NetworkNodeSet`,
        [_xN]: _nNS
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [0, {
        [_eQN]: `ZoneId`,
        [_xN]: _zI
      }], [0, {
        [_eQN]: `CapacityBlockId`,
        [_xN]: _cBI
      }]]
    ];
    exports2.InstanceTypeInfo$ = [
      3,
      n032,
      _ITIn,
      0,
      [_IT4, _CGur, _FTE, _SUC, _SRDT, _SVT, _BMa, _Hy, _PIro, _VCIpu, _MIe, _ISSn, _ISIns, _EIb, _NIetw, _GIp, _FIpga, _PGI, _IAIn, _HS, _BPS, _DHS, _ARS, _SBM, _NES, _NTS, _NTI, _MAIe, _NIeu, _PSh, _RMS],
      [[0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [2, {
        [_eQN]: `CurrentGeneration`,
        [_xN]: _cGur
      }], [2, {
        [_eQN]: `FreeTierEligible`,
        [_xN]: _fTE
      }], [() => UsageClassTypeList, {
        [_eQN]: `SupportedUsageClasses`,
        [_xN]: _sUC
      }], [() => RootDeviceTypeList, {
        [_eQN]: `SupportedRootDeviceTypes`,
        [_xN]: _sRDT
      }], [() => VirtualizationTypeList, {
        [_eQN]: `SupportedVirtualizationTypes`,
        [_xN]: _sVT
      }], [2, {
        [_eQN]: `BareMetal`,
        [_xN]: _bMa
      }], [0, {
        [_eQN]: `Hypervisor`,
        [_xN]: _h22
      }], [() => exports2.ProcessorInfo$, {
        [_eQN]: `ProcessorInfo`,
        [_xN]: _pIr
      }], [() => exports2.VCpuInfo$, {
        [_eQN]: `VCpuInfo`,
        [_xN]: _vCIp
      }], [() => exports2.MemoryInfo$, {
        [_eQN]: `MemoryInfo`,
        [_xN]: _mIe
      }], [2, {
        [_eQN]: `InstanceStorageSupported`,
        [_xN]: _iSSn
      }], [() => exports2.InstanceStorageInfo$, {
        [_eQN]: `InstanceStorageInfo`,
        [_xN]: _iSI
      }], [() => exports2.EbsInfo$, {
        [_eQN]: `EbsInfo`,
        [_xN]: _eIb
      }], [() => exports2.NetworkInfo$, {
        [_eQN]: `NetworkInfo`,
        [_xN]: _nIet
      }], [() => exports2.GpuInfo$, {
        [_eQN]: `GpuInfo`,
        [_xN]: _gIp
      }], [() => exports2.FpgaInfo$, {
        [_eQN]: `FpgaInfo`,
        [_xN]: _fIp
      }], [() => exports2.PlacementGroupInfo$, {
        [_eQN]: `PlacementGroupInfo`,
        [_xN]: _pGI
      }], [() => exports2.InferenceAcceleratorInfo$, {
        [_eQN]: `InferenceAcceleratorInfo`,
        [_xN]: _iAIn
      }], [2, {
        [_eQN]: `HibernationSupported`,
        [_xN]: _hSi
      }], [2, {
        [_eQN]: `BurstablePerformanceSupported`,
        [_xN]: _bPS
      }], [2, {
        [_eQN]: `DedicatedHostsSupported`,
        [_xN]: _dHS
      }], [2, {
        [_eQN]: `AutoRecoverySupported`,
        [_xN]: _aRSu
      }], [() => BootModeTypeList, {
        [_eQN]: `SupportedBootModes`,
        [_xN]: _sBM
      }], [0, {
        [_eQN]: `NitroEnclavesSupport`,
        [_xN]: _nES
      }], [0, {
        [_eQN]: `NitroTpmSupport`,
        [_xN]: _nTS
      }], [() => exports2.NitroTpmInfo$, {
        [_eQN]: `NitroTpmInfo`,
        [_xN]: _nTI
      }], [() => exports2.MediaAcceleratorInfo$, {
        [_eQN]: `MediaAcceleratorInfo`,
        [_xN]: _mAIe
      }], [() => exports2.NeuronInfo$, {
        [_eQN]: `NeuronInfo`,
        [_xN]: _nIeu
      }], [0, {
        [_eQN]: `PhcSupport`,
        [_xN]: _pSh
      }], [0, {
        [_eQN]: `RebootMigrationSupport`,
        [_xN]: _rMS
      }]]
    ];
    exports2.InstanceTypeInfoFromInstanceRequirements$ = [
      3,
      n032,
      _ITIFIR,
      0,
      [_IT4],
      [[0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }]]
    ];
    exports2.InstanceTypeOffering$ = [
      3,
      n032,
      _ITOn,
      0,
      [_IT4, _LTo, _Loc],
      [[0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [0, {
        [_eQN]: `LocationType`,
        [_xN]: _lTo
      }], [0, {
        [_eQN]: `Location`,
        [_xN]: _lo
      }]]
    ];
    exports2.InstanceUsage$ = [
      3,
      n032,
      _IUn,
      0,
      [_AIc, _UIC],
      [[0, {
        [_eQN]: `AccountId`,
        [_xN]: _aIc
      }], [1, {
        [_eQN]: `UsedInstanceCount`,
        [_xN]: _uIC
      }]]
    ];
    exports2.IntegrateServices$ = [
      3,
      n032,
      _ISnt,
      0,
      [_AIth],
      [[() => AthenaIntegrationsSet, { [_xN]: _AIt }]]
    ];
    exports2.InternetGateway$ = [
      3,
      n032,
      _IG,
      0,
      [_Atta, _IGI, _OI, _T10],
      [[() => InternetGatewayAttachmentList, {
        [_eQN]: `AttachmentSet`,
        [_xN]: _aSt
      }], [0, {
        [_eQN]: `InternetGatewayId`,
        [_xN]: _iGI
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.InternetGatewayAttachment$ = [
      3,
      n032,
      _IGA,
      0,
      [_St, _VI],
      [[0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }]]
    ];
    exports2.InterruptibleCapacityAllocation$ = [
      3,
      n032,
      _ICA,
      0,
      [_IC, _TICa, _Sta, _ICRI, _ITn],
      [[1, {
        [_eQN]: `InstanceCount`,
        [_xN]: _iC
      }], [1, {
        [_eQN]: `TargetInstanceCount`,
        [_xN]: _tICa
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `InterruptibleCapacityReservationId`,
        [_xN]: _iCRI
      }], [0, {
        [_eQN]: `InterruptionType`,
        [_xN]: _iTn
      }]]
    ];
    exports2.InterruptionInfo$ = [
      3,
      n032,
      _IIn,
      0,
      [_SCRI, _ITn],
      [[0, {
        [_eQN]: `SourceCapacityReservationId`,
        [_xN]: _sCRI
      }], [0, {
        [_eQN]: `InterruptionType`,
        [_xN]: _iTn
      }]]
    ];
    exports2.Ipam$ = [
      3,
      n032,
      _Ip,
      0,
      [_OI, _IIp, _IApa, _IRp, _PDSI, _PDSIr, _SCc, _De, _OR, _St, _T10, _DRDI, _DRDAI, _RDAC, _SMta, _Tie, _EPG, _MAe],
      [[0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `IpamId`,
        [_xN]: _iIp
      }], [0, {
        [_eQN]: `IpamArn`,
        [_xN]: _iApa
      }], [0, {
        [_eQN]: `IpamRegion`,
        [_xN]: _iRp
      }], [0, {
        [_eQN]: `PublicDefaultScopeId`,
        [_xN]: _pDSI
      }], [0, {
        [_eQN]: `PrivateDefaultScopeId`,
        [_xN]: _pDSIr
      }], [1, {
        [_eQN]: `ScopeCount`,
        [_xN]: _sCc
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [() => IpamOperatingRegionSet, {
        [_eQN]: `OperatingRegionSet`,
        [_xN]: _oRS
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `DefaultResourceDiscoveryId`,
        [_xN]: _dRDI
      }], [0, {
        [_eQN]: `DefaultResourceDiscoveryAssociationId`,
        [_xN]: _dRDAI
      }], [1, {
        [_eQN]: `ResourceDiscoveryAssociationCount`,
        [_xN]: _rDAC
      }], [0, {
        [_eQN]: `StateMessage`,
        [_xN]: _sMta
      }], [0, {
        [_eQN]: `Tier`,
        [_xN]: _tie
      }], [2, {
        [_eQN]: `EnablePrivateGua`,
        [_xN]: _ePG
      }], [0, {
        [_eQN]: `MeteredAccount`,
        [_xN]: _mAe
      }]]
    ];
    exports2.IpamAddressHistoryRecord$ = [
      3,
      n032,
      _IAHR,
      0,
      [_ROI, _RR, _RTe, _RIeso, _RCe, _RNes, _RCS, _ROS, _VI, _SST, _SET],
      [[0, {
        [_eQN]: `ResourceOwnerId`,
        [_xN]: _rOI
      }], [0, {
        [_eQN]: `ResourceRegion`,
        [_xN]: _rR
      }], [0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }], [0, {
        [_eQN]: `ResourceId`,
        [_xN]: _rIes
      }], [0, {
        [_eQN]: `ResourceCidr`,
        [_xN]: _rCe
      }], [0, {
        [_eQN]: `ResourceName`,
        [_xN]: _rNes
      }], [0, {
        [_eQN]: `ResourceComplianceStatus`,
        [_xN]: _rCS
      }], [0, {
        [_eQN]: `ResourceOverlapStatus`,
        [_xN]: _rOSe
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [4, {
        [_eQN]: `SampledStartTime`,
        [_xN]: _sST
      }], [4, {
        [_eQN]: `SampledEndTime`,
        [_xN]: _sET
      }]]
    ];
    exports2.IpamCidrAuthorizationContext$ = [
      3,
      n032,
      _ICAC,
      0,
      [_Me, _Si],
      [0, 0]
    ];
    exports2.IpamDiscoveredAccount$ = [
      3,
      n032,
      _IDAp,
      0,
      [_AIc, _DRi, _FR, _LADT, _LSDT, _OUI],
      [[0, {
        [_eQN]: `AccountId`,
        [_xN]: _aIc
      }], [0, {
        [_eQN]: `DiscoveryRegion`,
        [_xN]: _dRi
      }], [() => exports2.IpamDiscoveryFailureReason$, {
        [_eQN]: `FailureReason`,
        [_xN]: _fR
      }], [4, {
        [_eQN]: `LastAttemptedDiscoveryTime`,
        [_xN]: _lADT
      }], [4, {
        [_eQN]: `LastSuccessfulDiscoveryTime`,
        [_xN]: _lSDT
      }], [0, {
        [_eQN]: `OrganizationalUnitId`,
        [_xN]: _oUI
      }]]
    ];
    exports2.IpamDiscoveredPublicAddress$ = [
      3,
      n032,
      _IDPAp,
      0,
      [_IRDI, _ARd, _A10, _AOI, _AAId, _ASs, _ATddr, _Se, _SRer, _VI, _SIu, _PIPI, _NII, _NID, _II2, _T10, _NBG, _SGe, _STam],
      [[0, {
        [_eQN]: `IpamResourceDiscoveryId`,
        [_xN]: _iRDI
      }], [0, {
        [_eQN]: `AddressRegion`,
        [_xN]: _aRd
      }], [0, {
        [_eQN]: `Address`,
        [_xN]: _ad
      }], [0, {
        [_eQN]: `AddressOwnerId`,
        [_xN]: _aOI
      }], [0, {
        [_eQN]: `AddressAllocationId`,
        [_xN]: _aAId
      }], [0, {
        [_eQN]: `AssociationStatus`,
        [_xN]: _aSs
      }], [0, {
        [_eQN]: `AddressType`,
        [_xN]: _aTdd
      }], [0, {
        [_eQN]: `Service`,
        [_xN]: _se14
      }], [0, {
        [_eQN]: `ServiceResource`,
        [_xN]: _sRe
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }], [0, {
        [_eQN]: `PublicIpv4PoolId`,
        [_xN]: _pIPI
      }], [0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], [0, {
        [_eQN]: `NetworkInterfaceDescription`,
        [_xN]: _nID
      }], [0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [() => exports2.IpamPublicAddressTags$, {
        [_eQN]: `Tags`,
        [_xN]: _tag
      }], [0, {
        [_eQN]: `NetworkBorderGroup`,
        [_xN]: _nBG
      }], [() => IpamPublicAddressSecurityGroupList, {
        [_eQN]: `SecurityGroupSet`,
        [_xN]: _sGSe
      }], [4, {
        [_eQN]: `SampleTime`,
        [_xN]: _sTa
      }]]
    ];
    exports2.IpamDiscoveredResourceCidr$ = [
      3,
      n032,
      _IDRCp,
      0,
      [_IRDI, _RR, _RIeso, _ROI, _RCe, _ISpo, _RTe, _RTesou, _IUp, _VI, _SIu, _NIASet, _STam, _AZI],
      [[0, {
        [_eQN]: `IpamResourceDiscoveryId`,
        [_xN]: _iRDI
      }], [0, {
        [_eQN]: `ResourceRegion`,
        [_xN]: _rR
      }], [0, {
        [_eQN]: `ResourceId`,
        [_xN]: _rIes
      }], [0, {
        [_eQN]: `ResourceOwnerId`,
        [_xN]: _rOI
      }], [0, {
        [_eQN]: `ResourceCidr`,
        [_xN]: _rCe
      }], [0, {
        [_eQN]: `IpSource`,
        [_xN]: _iSpo
      }], [0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }], [() => IpamResourceTagList, {
        [_eQN]: `ResourceTagSet`,
        [_xN]: _rTSes
      }], [1, {
        [_eQN]: `IpUsage`,
        [_xN]: _iU
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }], [0, {
        [_eQN]: `NetworkInterfaceAttachmentStatus`,
        [_xN]: _nIASet
      }], [4, {
        [_eQN]: `SampleTime`,
        [_xN]: _sTa
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }]]
    ];
    exports2.IpamDiscoveryFailureReason$ = [
      3,
      n032,
      _IDFR,
      0,
      [_Co, _Me],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }]]
    ];
    exports2.IpamExternalResourceVerificationToken$ = [
      3,
      n032,
      _IERVT,
      0,
      [_IERVTI, _IERVTA, _IIp, _IApa, _IRp, _TVo, _TN, _NAo, _Sta, _T10, _St],
      [[0, {
        [_eQN]: `IpamExternalResourceVerificationTokenId`,
        [_xN]: _iERVTI
      }], [0, {
        [_eQN]: `IpamExternalResourceVerificationTokenArn`,
        [_xN]: _iERVTA
      }], [0, {
        [_eQN]: `IpamId`,
        [_xN]: _iIp
      }], [0, {
        [_eQN]: `IpamArn`,
        [_xN]: _iApa
      }], [0, {
        [_eQN]: `IpamRegion`,
        [_xN]: _iRp
      }], [0, {
        [_eQN]: `TokenValue`,
        [_xN]: _tV
      }], [0, {
        [_eQN]: `TokenName`,
        [_xN]: _tN
      }], [4, {
        [_eQN]: `NotAfter`,
        [_xN]: _nAo
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }]]
    ];
    exports2.IpamOperatingRegion$ = [
      3,
      n032,
      _IOR,
      0,
      [_RN],
      [[0, {
        [_eQN]: `RegionName`,
        [_xN]: _rNe
      }]]
    ];
    exports2.IpamOrganizationalUnitExclusion$ = [
      3,
      n032,
      _IOUE,
      0,
      [_OEP],
      [[0, {
        [_eQN]: `OrganizationsEntityPath`,
        [_xN]: _oEP
      }]]
    ];
    exports2.IpamPolicy$ = [
      3,
      n032,
      _IPpa,
      0,
      [_OI, _IPIp, _IPApa, _IPR, _St, _SMta, _T10, _IIp],
      [[0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `IpamPolicyId`,
        [_xN]: _iPI
      }], [0, {
        [_eQN]: `IpamPolicyArn`,
        [_xN]: _iPAp
      }], [0, {
        [_eQN]: `IpamPolicyRegion`,
        [_xN]: _iPR
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `StateMessage`,
        [_xN]: _sMta
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `IpamId`,
        [_xN]: _iIp
      }]]
    ];
    exports2.IpamPolicyAllocationRule$ = [
      3,
      n032,
      _IPAR,
      0,
      [_SIPI],
      [[0, {
        [_eQN]: `SourceIpamPoolId`,
        [_xN]: _sIPI
      }]]
    ];
    exports2.IpamPolicyAllocationRuleRequest$ = [
      3,
      n032,
      _IPARR,
      0,
      [_SIPI],
      [0]
    ];
    exports2.IpamPolicyDocument$ = [
      3,
      n032,
      _IPDp,
      0,
      [_IPIp, _Lo, _RTe, _ARllo],
      [[0, {
        [_eQN]: `IpamPolicyId`,
        [_xN]: _iPI
      }], [0, {
        [_eQN]: `Locale`,
        [_xN]: _loc
      }], [0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }], [() => IpamPolicyAllocationRuleList, {
        [_eQN]: `AllocationRuleSet`,
        [_xN]: _aRSl
      }]]
    ];
    exports2.IpamPolicyOrganizationTarget$ = [
      3,
      n032,
      _IPOT,
      0,
      [_OTI],
      [[0, {
        [_eQN]: `OrganizationTargetId`,
        [_xN]: _oTI
      }]]
    ];
    exports2.IpamPool$ = [
      3,
      n032,
      _IPpam,
      0,
      [_OI, _IPI2, _SIPI, _IPApam, _ISA, _ISTp, _IApa, _IRp, _Lo, _PDoo, _St, _SMta, _De, _AIu, _PAu, _AF, _AMNL, _AMNLl, _ADNL, _ART, _T10, _ASw, _PIS, _SRou],
      [[0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `IpamPoolId`,
        [_xN]: _iPIp
      }], [0, {
        [_eQN]: `SourceIpamPoolId`,
        [_xN]: _sIPI
      }], [0, {
        [_eQN]: `IpamPoolArn`,
        [_xN]: _iPApa
      }], [0, {
        [_eQN]: `IpamScopeArn`,
        [_xN]: _iSA
      }], [0, {
        [_eQN]: `IpamScopeType`,
        [_xN]: _iST
      }], [0, {
        [_eQN]: `IpamArn`,
        [_xN]: _iApa
      }], [0, {
        [_eQN]: `IpamRegion`,
        [_xN]: _iRp
      }], [0, {
        [_eQN]: `Locale`,
        [_xN]: _loc
      }], [1, {
        [_eQN]: `PoolDepth`,
        [_xN]: _pDoo
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `StateMessage`,
        [_xN]: _sMta
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [2, {
        [_eQN]: `AutoImport`,
        [_xN]: _aIu
      }], [2, {
        [_eQN]: `PubliclyAdvertisable`,
        [_xN]: _pAu
      }], [0, {
        [_eQN]: `AddressFamily`,
        [_xN]: _aF
      }], [1, {
        [_eQN]: `AllocationMinNetmaskLength`,
        [_xN]: _aMNL
      }], [1, {
        [_eQN]: `AllocationMaxNetmaskLength`,
        [_xN]: _aMNLl
      }], [1, {
        [_eQN]: `AllocationDefaultNetmaskLength`,
        [_xN]: _aDNL
      }], [() => IpamResourceTagList, {
        [_eQN]: `AllocationResourceTagSet`,
        [_xN]: _aRTS
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `AwsService`,
        [_xN]: _aSw
      }], [0, {
        [_eQN]: `PublicIpSource`,
        [_xN]: _pIS
      }], [() => exports2.IpamPoolSourceResource$, {
        [_eQN]: `SourceResource`,
        [_xN]: _sRo
      }]]
    ];
    exports2.IpamPoolAllocation$ = [
      3,
      n032,
      _IPA,
      0,
      [_Ci, _IPAI, _De, _RIeso, _RTe, _RR, _ROe],
      [[0, {
        [_eQN]: `Cidr`,
        [_xN]: _ci
      }], [0, {
        [_eQN]: `IpamPoolAllocationId`,
        [_xN]: _iPAI
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [0, {
        [_eQN]: `ResourceId`,
        [_xN]: _rIes
      }], [0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }], [0, {
        [_eQN]: `ResourceRegion`,
        [_xN]: _rR
      }], [0, {
        [_eQN]: `ResourceOwner`,
        [_xN]: _rO
      }]]
    ];
    exports2.IpamPoolCidr$ = [
      3,
      n032,
      _IPCpa,
      0,
      [_Ci, _St, _FR, _IPCI, _NL],
      [[0, {
        [_eQN]: `Cidr`,
        [_xN]: _ci
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [() => exports2.IpamPoolCidrFailureReason$, {
        [_eQN]: `FailureReason`,
        [_xN]: _fR
      }], [0, {
        [_eQN]: `IpamPoolCidrId`,
        [_xN]: _iPCI
      }], [1, {
        [_eQN]: `NetmaskLength`,
        [_xN]: _nL
      }]]
    ];
    exports2.IpamPoolCidrFailureReason$ = [
      3,
      n032,
      _IPCFR,
      0,
      [_Co, _Me],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }]]
    ];
    exports2.IpamPoolSourceResource$ = [
      3,
      n032,
      _IPSR,
      0,
      [_RIeso, _RTe, _RR, _ROe],
      [[0, {
        [_eQN]: `ResourceId`,
        [_xN]: _rIes
      }], [0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }], [0, {
        [_eQN]: `ResourceRegion`,
        [_xN]: _rR
      }], [0, {
        [_eQN]: `ResourceOwner`,
        [_xN]: _rO
      }]]
    ];
    exports2.IpamPoolSourceResourceRequest$ = [
      3,
      n032,
      _IPSRR,
      0,
      [_RIeso, _RTe, _RR, _ROe],
      [0, 0, 0, 0]
    ];
    exports2.IpamPrefixListResolver$ = [
      3,
      n032,
      _IPLR,
      0,
      [_OI, _IPLRI, _IPLRA, _IApa, _IRp, _De, _AF, _St, _T10, _LVCS, _LVCSM],
      [[0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `IpamPrefixListResolverId`,
        [_xN]: _iPLRI
      }], [0, {
        [_eQN]: `IpamPrefixListResolverArn`,
        [_xN]: _iPLRA
      }], [0, {
        [_eQN]: `IpamArn`,
        [_xN]: _iApa
      }], [0, {
        [_eQN]: `IpamRegion`,
        [_xN]: _iRp
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [0, {
        [_eQN]: `AddressFamily`,
        [_xN]: _aF
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `LastVersionCreationStatus`,
        [_xN]: _lVCS
      }], [0, {
        [_eQN]: `LastVersionCreationStatusMessage`,
        [_xN]: _lVCSM
      }]]
    ];
    exports2.IpamPrefixListResolverRule$ = [
      3,
      n032,
      _IPLRR,
      0,
      [_RTu, _SCt, _ISI, _RTe, _Cond],
      [[0, {
        [_eQN]: `RuleType`,
        [_xN]: _rTu
      }], [0, {
        [_eQN]: `StaticCidr`,
        [_xN]: _sCt
      }], [0, {
        [_eQN]: `IpamScopeId`,
        [_xN]: _iSIp
      }], [0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }], [() => IpamPrefixListResolverRuleConditionSet, {
        [_eQN]: `ConditionSet`,
        [_xN]: _cSo
      }]]
    ];
    exports2.IpamPrefixListResolverRuleCondition$ = [
      3,
      n032,
      _IPLRRC,
      0,
      [_Ope, _IPI2, _RIeso, _ROe, _RR, _RTeso, _Ci],
      [[0, {
        [_eQN]: `Operation`,
        [_xN]: _oper
      }], [0, {
        [_eQN]: `IpamPoolId`,
        [_xN]: _iPIp
      }], [0, {
        [_eQN]: `ResourceId`,
        [_xN]: _rIes
      }], [0, {
        [_eQN]: `ResourceOwner`,
        [_xN]: _rO
      }], [0, {
        [_eQN]: `ResourceRegion`,
        [_xN]: _rR
      }], [() => exports2.IpamResourceTag$, {
        [_eQN]: `ResourceTag`,
        [_xN]: _rTes
      }], [0, {
        [_eQN]: `Cidr`,
        [_xN]: _ci
      }]]
    ];
    exports2.IpamPrefixListResolverRuleConditionRequest$ = [
      3,
      n032,
      _IPLRRCR,
      0,
      [_Ope, _IPI2, _RIeso, _ROe, _RR, _RTeso, _Ci],
      [0, 0, 0, 0, 0, () => exports2.RequestIpamResourceTag$, 0],
      1
    ];
    exports2.IpamPrefixListResolverRuleRequest$ = [
      3,
      n032,
      _IPLRRR,
      0,
      [_RTu, _SCt, _ISI, _RTe, _Cond],
      [0, 0, 0, 0, [() => IpamPrefixListResolverRuleConditionRequestSet, { [_xN]: _Condi }]],
      1
    ];
    exports2.IpamPrefixListResolverTarget$ = [
      3,
      n032,
      _IPLRT,
      0,
      [_IPLRTI, _IPLRTA, _IPLRI, _OI, _PLI, _PLR, _DV, _LSV, _TLV, _SMta, _St, _T10],
      [[0, {
        [_eQN]: `IpamPrefixListResolverTargetId`,
        [_xN]: _iPLRTI
      }], [0, {
        [_eQN]: `IpamPrefixListResolverTargetArn`,
        [_xN]: _iPLRTA
      }], [0, {
        [_eQN]: `IpamPrefixListResolverId`,
        [_xN]: _iPLRI
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `PrefixListId`,
        [_xN]: _pLI
      }], [0, {
        [_eQN]: `PrefixListRegion`,
        [_xN]: _pLR
      }], [1, {
        [_eQN]: `DesiredVersion`,
        [_xN]: _dVe
      }], [1, {
        [_eQN]: `LastSyncedVersion`,
        [_xN]: _lSV
      }], [2, {
        [_eQN]: `TrackLatestVersion`,
        [_xN]: _tLV
      }], [0, {
        [_eQN]: `StateMessage`,
        [_xN]: _sMta
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.IpamPrefixListResolverVersion$ = [
      3,
      n032,
      _IPLRV,
      0,
      [_Ver],
      [[1, {
        [_eQN]: `Version`,
        [_xN]: _ve
      }]]
    ];
    exports2.IpamPrefixListResolverVersionEntry$ = [
      3,
      n032,
      _IPLRVE,
      0,
      [_Ci],
      [[0, {
        [_eQN]: `Cidr`,
        [_xN]: _ci
      }]]
    ];
    exports2.IpamPublicAddressSecurityGroup$ = [
      3,
      n032,
      _IPASG,
      0,
      [_GN, _GIr],
      [[0, {
        [_eQN]: `GroupName`,
        [_xN]: _gN
      }], [0, {
        [_eQN]: `GroupId`,
        [_xN]: _gIr
      }]]
    ];
    exports2.IpamPublicAddressTag$ = [
      3,
      n032,
      _IPAT,
      0,
      [_K10, _V10],
      [[0, {
        [_eQN]: `Key`,
        [_xN]: _k
      }], [0, {
        [_eQN]: `Value`,
        [_xN]: _v
      }]]
    ];
    exports2.IpamPublicAddressTags$ = [
      3,
      n032,
      _IPATp,
      0,
      [_ETi],
      [[() => IpamPublicAddressTagList, {
        [_eQN]: `EipTagSet`,
        [_xN]: _eTSi
      }]]
    ];
    exports2.IpamResourceCidr$ = [
      3,
      n032,
      _IRCp,
      0,
      [_IIp, _ISI, _IPI2, _RR, _ROI, _RIeso, _RNes, _RCe, _RTe, _RTesou, _IUp, _CSo, _MS, _OSv, _VI, _AZI],
      [[0, {
        [_eQN]: `IpamId`,
        [_xN]: _iIp
      }], [0, {
        [_eQN]: `IpamScopeId`,
        [_xN]: _iSIp
      }], [0, {
        [_eQN]: `IpamPoolId`,
        [_xN]: _iPIp
      }], [0, {
        [_eQN]: `ResourceRegion`,
        [_xN]: _rR
      }], [0, {
        [_eQN]: `ResourceOwnerId`,
        [_xN]: _rOI
      }], [0, {
        [_eQN]: `ResourceId`,
        [_xN]: _rIes
      }], [0, {
        [_eQN]: `ResourceName`,
        [_xN]: _rNes
      }], [0, {
        [_eQN]: `ResourceCidr`,
        [_xN]: _rCe
      }], [0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }], [() => IpamResourceTagList, {
        [_eQN]: `ResourceTagSet`,
        [_xN]: _rTSes
      }], [1, {
        [_eQN]: `IpUsage`,
        [_xN]: _iU
      }], [0, {
        [_eQN]: `ComplianceStatus`,
        [_xN]: _cSom
      }], [0, {
        [_eQN]: `ManagementState`,
        [_xN]: _mSa
      }], [0, {
        [_eQN]: `OverlapStatus`,
        [_xN]: _oSv
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }]]
    ];
    exports2.IpamResourceDiscovery$ = [
      3,
      n032,
      _IRD,
      0,
      [_OI, _IRDI, _IRDApa, _IRDR, _De, _OR, _IDs, _St, _T10, _OUE],
      [[0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `IpamResourceDiscoveryId`,
        [_xN]: _iRDI
      }], [0, {
        [_eQN]: `IpamResourceDiscoveryArn`,
        [_xN]: _iRDAp
      }], [0, {
        [_eQN]: `IpamResourceDiscoveryRegion`,
        [_xN]: _iRDR
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [() => IpamOperatingRegionSet, {
        [_eQN]: `OperatingRegionSet`,
        [_xN]: _oRS
      }], [2, {
        [_eQN]: `IsDefault`,
        [_xN]: _iDs
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [() => IpamOrganizationalUnitExclusionSet, {
        [_eQN]: `OrganizationalUnitExclusionSet`,
        [_xN]: _oUES
      }]]
    ];
    exports2.IpamResourceDiscoveryAssociation$ = [
      3,
      n032,
      _IRDA,
      0,
      [_OI, _IRDAIp, _IRDAA, _IRDI, _IIp, _IApa, _IRp, _IDs, _RDS, _St, _T10],
      [[0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `IpamResourceDiscoveryAssociationId`,
        [_xN]: _iRDAI
      }], [0, {
        [_eQN]: `IpamResourceDiscoveryAssociationArn`,
        [_xN]: _iRDAA
      }], [0, {
        [_eQN]: `IpamResourceDiscoveryId`,
        [_xN]: _iRDI
      }], [0, {
        [_eQN]: `IpamId`,
        [_xN]: _iIp
      }], [0, {
        [_eQN]: `IpamArn`,
        [_xN]: _iApa
      }], [0, {
        [_eQN]: `IpamRegion`,
        [_xN]: _iRp
      }], [2, {
        [_eQN]: `IsDefault`,
        [_xN]: _iDs
      }], [0, {
        [_eQN]: `ResourceDiscoveryStatus`,
        [_xN]: _rDS
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.IpamResourceTag$ = [
      3,
      n032,
      _IRTp,
      0,
      [_K10, _V10],
      [[0, {
        [_eQN]: `Key`,
        [_xN]: _k
      }], [0, {
        [_eQN]: `Value`,
        [_xN]: _v
      }]]
    ];
    exports2.IpamScope$ = [
      3,
      n032,
      _ISp,
      0,
      [_OI, _ISI, _ISA, _IApa, _IRp, _ISTp, _IDs, _De, _PCo, _St, _T10, _EAC],
      [[0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `IpamScopeId`,
        [_xN]: _iSIp
      }], [0, {
        [_eQN]: `IpamScopeArn`,
        [_xN]: _iSA
      }], [0, {
        [_eQN]: `IpamArn`,
        [_xN]: _iApa
      }], [0, {
        [_eQN]: `IpamRegion`,
        [_xN]: _iRp
      }], [0, {
        [_eQN]: `IpamScopeType`,
        [_xN]: _iST
      }], [2, {
        [_eQN]: `IsDefault`,
        [_xN]: _iDs
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [1, {
        [_eQN]: `PoolCount`,
        [_xN]: _pCo
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [() => exports2.IpamScopeExternalAuthorityConfiguration$, {
        [_eQN]: `ExternalAuthorityConfiguration`,
        [_xN]: _eAC
      }]]
    ];
    exports2.IpamScopeExternalAuthorityConfiguration$ = [
      3,
      n032,
      _ISEAC,
      0,
      [_Ty, _ERI],
      [[0, {
        [_eQN]: `Type`,
        [_xN]: _ty
      }], [0, {
        [_eQN]: `ExternalResourceIdentifier`,
        [_xN]: _eRI
      }]]
    ];
    exports2.IpPermission$ = [
      3,
      n032,
      _IPper,
      0,
      [_IPpr, _FP, _TP, _UIGP, _IRpa, _IRpv, _PLIr],
      [[0, {
        [_eQN]: `IpProtocol`,
        [_xN]: _iPp
      }], [1, {
        [_eQN]: `FromPort`,
        [_xN]: _fP
      }], [1, {
        [_eQN]: `ToPort`,
        [_xN]: _tP
      }], [() => UserIdGroupPairList, {
        [_eQN]: `Groups`,
        [_xN]: _gr
      }], [() => IpRangeList, {
        [_eQN]: `IpRanges`,
        [_xN]: _iRpa
      }], [() => Ipv6RangeList, {
        [_eQN]: `Ipv6Ranges`,
        [_xN]: _iRpv
      }], [() => PrefixListIdList, {
        [_eQN]: `PrefixListIds`,
        [_xN]: _pLIr
      }]]
    ];
    exports2.IpRange$ = [
      3,
      n032,
      _IRpan,
      0,
      [_De, _CIi],
      [[0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [0, {
        [_eQN]: `CidrIp`,
        [_xN]: _cIi
      }]]
    ];
    exports2.Ipv4PrefixSpecification$ = [
      3,
      n032,
      _IPS,
      0,
      [_IPpvre],
      [[0, {
        [_eQN]: `Ipv4Prefix`,
        [_xN]: _iPpv
      }]]
    ];
    exports2.Ipv4PrefixSpecificationRequest$ = [
      3,
      n032,
      _IPSRp,
      0,
      [_IPpvre],
      [0]
    ];
    exports2.Ipv4PrefixSpecificationResponse$ = [
      3,
      n032,
      _IPSRpv,
      0,
      [_IPpvre],
      [[0, {
        [_eQN]: `Ipv4Prefix`,
        [_xN]: _iPpv
      }]]
    ];
    exports2.Ipv6CidrAssociation$ = [
      3,
      n032,
      _ICApv,
      0,
      [_ICp, _ARss],
      [[0, {
        [_eQN]: `Ipv6Cidr`,
        [_xN]: _iCp
      }], [0, {
        [_eQN]: `AssociatedResource`,
        [_xN]: _aRs
      }]]
    ];
    exports2.Ipv6CidrBlock$ = [
      3,
      n032,
      _ICB,
      0,
      [_ICB],
      [[0, {
        [_eQN]: `Ipv6CidrBlock`,
        [_xN]: _iCB
      }]]
    ];
    exports2.Ipv6Pool$ = [
      3,
      n032,
      _IPpvo,
      0,
      [_PIo, _De, _PCB, _T10],
      [[0, {
        [_eQN]: `PoolId`,
        [_xN]: _pIo
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [() => PoolCidrBlocksSet, {
        [_eQN]: `PoolCidrBlockSet`,
        [_xN]: _pCBS
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.Ipv6PrefixSpecification$ = [
      3,
      n032,
      _IPSp,
      0,
      [_IPpv],
      [[0, {
        [_eQN]: `Ipv6Prefix`,
        [_xN]: _iPpvr
      }]]
    ];
    exports2.Ipv6PrefixSpecificationRequest$ = [
      3,
      n032,
      _IPSRpvr,
      0,
      [_IPpv],
      [0]
    ];
    exports2.Ipv6PrefixSpecificationResponse$ = [
      3,
      n032,
      _IPSRpvre,
      0,
      [_IPpv],
      [[0, {
        [_eQN]: `Ipv6Prefix`,
        [_xN]: _iPpvr
      }]]
    ];
    exports2.Ipv6Range$ = [
      3,
      n032,
      _IRpva,
      0,
      [_De, _CIid],
      [[0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [0, {
        [_eQN]: `CidrIpv6`,
        [_xN]: _cIid
      }]]
    ];
    exports2.KeyPair$ = [
      3,
      n032,
      _KPe,
      0,
      [_KPI, _T10, _KN, _KFe, _KM],
      [[0, {
        [_eQN]: `KeyPairId`,
        [_xN]: _kPI
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `KeyName`,
        [_xN]: _kN
      }], [0, {
        [_eQN]: `KeyFingerprint`,
        [_xN]: _kFe
      }], [() => SensitiveUserData, {
        [_eQN]: `KeyMaterial`,
        [_xN]: _kM
      }]]
    ];
    exports2.KeyPairInfo$ = [
      3,
      n032,
      _KPIey,
      0,
      [_KPI, _KT, _T10, _PK, _CTr, _KN, _KFe],
      [[0, {
        [_eQN]: `KeyPairId`,
        [_xN]: _kPI
      }], [0, {
        [_eQN]: `KeyType`,
        [_xN]: _kT
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `PublicKey`,
        [_xN]: _pK
      }], [4, {
        [_eQN]: `CreateTime`,
        [_xN]: _cTr
      }], [0, {
        [_eQN]: `KeyName`,
        [_xN]: _kN
      }], [0, {
        [_eQN]: `KeyFingerprint`,
        [_xN]: _kFe
      }]]
    ];
    exports2.LastError$ = [
      3,
      n032,
      _LEa,
      0,
      [_Me, _Co],
      [[0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }], [0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }]]
    ];
    exports2.LaunchPermission$ = [
      3,
      n032,
      _LPau,
      0,
      [_OArg, _OUA, _UI, _Gr],
      [[0, {
        [_eQN]: `OrganizationArn`,
        [_xN]: _oArg
      }], [0, {
        [_eQN]: `OrganizationalUnitArn`,
        [_xN]: _oUA
      }], [0, {
        [_eQN]: `UserId`,
        [_xN]: _uI
      }], [0, {
        [_eQN]: `Group`,
        [_xN]: _g
      }]]
    ];
    exports2.LaunchPermissionModifications$ = [
      3,
      n032,
      _LPM,
      0,
      [_Ad, _Rem],
      [[() => LaunchPermissionList, 0], [() => LaunchPermissionList, 0]]
    ];
    exports2.LaunchSpecification$ = [
      3,
      n032,
      _LSa,
      0,
      [_UDs, _ATddre, _BDMl, _EO, _IIP, _IIm, _IT4, _KI, _KN, _NIet, _Pla, _RIa, _SIu, _SGe, _Mon],
      [[() => SensitiveUserData, {
        [_eQN]: `UserData`,
        [_xN]: _uDs
      }], [0, {
        [_eQN]: `AddressingType`,
        [_xN]: _aTddr
      }], [() => BlockDeviceMappingList, {
        [_eQN]: `BlockDeviceMapping`,
        [_xN]: _bDM
      }], [2, {
        [_eQN]: `EbsOptimized`,
        [_xN]: _eO
      }], [() => exports2.IamInstanceProfileSpecification$, {
        [_eQN]: `IamInstanceProfile`,
        [_xN]: _iIP
      }], [0, {
        [_eQN]: `ImageId`,
        [_xN]: _iIma
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [0, {
        [_eQN]: `KernelId`,
        [_xN]: _kI
      }], [0, {
        [_eQN]: `KeyName`,
        [_xN]: _kN
      }], [() => InstanceNetworkInterfaceSpecificationList, {
        [_eQN]: `NetworkInterfaceSet`,
        [_xN]: _nIS
      }], [() => exports2.SpotPlacement$, {
        [_eQN]: `Placement`,
        [_xN]: _pla
      }], [0, {
        [_eQN]: `RamdiskId`,
        [_xN]: _rIa
      }], [0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }], [() => GroupIdentifierList, {
        [_eQN]: `GroupSet`,
        [_xN]: _gSr
      }], [() => exports2.RunInstancesMonitoringEnabled$, {
        [_eQN]: `Monitoring`,
        [_xN]: _mo
      }]]
    ];
    exports2.LaunchTemplate$ = [
      3,
      n032,
      _LT,
      0,
      [_LTI, _LTN, _CTr, _CBr, _DVN, _LVN, _T10, _Op],
      [[0, {
        [_eQN]: `LaunchTemplateId`,
        [_xN]: _lTI
      }], [0, {
        [_eQN]: `LaunchTemplateName`,
        [_xN]: _lTN
      }], [4, {
        [_eQN]: `CreateTime`,
        [_xN]: _cTr
      }], [0, {
        [_eQN]: `CreatedBy`,
        [_xN]: _cBr
      }], [1, {
        [_eQN]: `DefaultVersionNumber`,
        [_xN]: _dVN
      }], [1, {
        [_eQN]: `LatestVersionNumber`,
        [_xN]: _lVN
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [() => exports2.OperatorResponse$, {
        [_eQN]: `Operator`,
        [_xN]: _ope
      }]]
    ];
    exports2.LaunchTemplateAndOverridesResponse$ = [
      3,
      n032,
      _LTAOR,
      0,
      [_LTS, _Ov],
      [[() => exports2.FleetLaunchTemplateSpecification$, {
        [_eQN]: `LaunchTemplateSpecification`,
        [_xN]: _lTS
      }], [() => exports2.FleetLaunchTemplateOverrides$, {
        [_eQN]: `Overrides`,
        [_xN]: _ov
      }]]
    ];
    exports2.LaunchTemplateBlockDeviceMapping$ = [
      3,
      n032,
      _LTBDM,
      0,
      [_DN, _VN, _Eb, _ND],
      [[0, {
        [_eQN]: `DeviceName`,
        [_xN]: _dN
      }], [0, {
        [_eQN]: `VirtualName`,
        [_xN]: _vN
      }], [() => exports2.LaunchTemplateEbsBlockDevice$, {
        [_eQN]: `Ebs`,
        [_xN]: _eb
      }], [0, {
        [_eQN]: `NoDevice`,
        [_xN]: _nD
      }]]
    ];
    exports2.LaunchTemplateBlockDeviceMappingRequest$ = [
      3,
      n032,
      _LTBDMR,
      0,
      [_DN, _VN, _Eb, _ND],
      [0, 0, () => exports2.LaunchTemplateEbsBlockDeviceRequest$, 0]
    ];
    exports2.LaunchTemplateCapacityReservationSpecificationRequest$ = [
      3,
      n032,
      _LTCRSR,
      0,
      [_CRP, _CRT],
      [0, () => exports2.CapacityReservationTarget$]
    ];
    exports2.LaunchTemplateCapacityReservationSpecificationResponse$ = [
      3,
      n032,
      _LTCRSRa,
      0,
      [_CRP, _CRT],
      [[0, {
        [_eQN]: `CapacityReservationPreference`,
        [_xN]: _cRP
      }], [() => exports2.CapacityReservationTargetResponse$, {
        [_eQN]: `CapacityReservationTarget`,
        [_xN]: _cRT
      }]]
    ];
    exports2.LaunchTemplateConfig$ = [
      3,
      n032,
      _LTCa,
      0,
      [_LTS, _Ov],
      [[() => exports2.FleetLaunchTemplateSpecification$, {
        [_eQN]: `LaunchTemplateSpecification`,
        [_xN]: _lTS
      }], [() => LaunchTemplateOverridesList, {
        [_eQN]: `Overrides`,
        [_xN]: _ov
      }]]
    ];
    exports2.LaunchTemplateCpuOptions$ = [
      3,
      n032,
      _LTCO,
      0,
      [_CCor, _TPC, _ASS, _NV],
      [[1, {
        [_eQN]: `CoreCount`,
        [_xN]: _cCo
      }], [1, {
        [_eQN]: `ThreadsPerCore`,
        [_xN]: _tPC
      }], [0, {
        [_eQN]: `AmdSevSnp`,
        [_xN]: _aSS
      }], [0, {
        [_eQN]: `NestedVirtualization`,
        [_xN]: _nV
      }]]
    ];
    exports2.LaunchTemplateCpuOptionsRequest$ = [
      3,
      n032,
      _LTCOR,
      0,
      [_CCor, _TPC, _ASS, _NV],
      [1, 1, 0, 0]
    ];
    exports2.LaunchTemplateEbsBlockDevice$ = [
      3,
      n032,
      _LTEBD,
      0,
      [_Enc, _DOT, _Io, _KKI, _SIn, _VSo, _VT, _Th, _VIR, _ECI],
      [[2, {
        [_eQN]: `Encrypted`,
        [_xN]: _enc
      }], [2, {
        [_eQN]: `DeleteOnTermination`,
        [_xN]: _dOT
      }], [1, {
        [_eQN]: `Iops`,
        [_xN]: _io
      }], [0, {
        [_eQN]: `KmsKeyId`,
        [_xN]: _kKI
      }], [0, {
        [_eQN]: `SnapshotId`,
        [_xN]: _sIn
      }], [1, {
        [_eQN]: `VolumeSize`,
        [_xN]: _vSo
      }], [0, {
        [_eQN]: `VolumeType`,
        [_xN]: _vT
      }], [1, {
        [_eQN]: `Throughput`,
        [_xN]: _th
      }], [1, {
        [_eQN]: `VolumeInitializationRate`,
        [_xN]: _vIR
      }], [1, {
        [_eQN]: `EbsCardIndex`,
        [_xN]: _eCI
      }]]
    ];
    exports2.LaunchTemplateEbsBlockDeviceRequest$ = [
      3,
      n032,
      _LTEBDR,
      0,
      [_Enc, _DOT, _Io, _KKI, _SIn, _VSo, _VT, _Th, _VIR, _ECI],
      [2, 2, 1, 0, 0, 1, 0, 1, 1, 1]
    ];
    exports2.LaunchTemplateElasticInferenceAccelerator$ = [
      3,
      n032,
      _LTEIA,
      0,
      [_Ty, _Cou],
      [0, 1],
      1
    ];
    exports2.LaunchTemplateElasticInferenceAcceleratorResponse$ = [
      3,
      n032,
      _LTEIAR,
      0,
      [_Ty, _Cou],
      [[0, {
        [_eQN]: `Type`,
        [_xN]: _ty
      }], [1, {
        [_eQN]: `Count`,
        [_xN]: _cou
      }]]
    ];
    exports2.LaunchTemplateEnaSrdSpecification$ = [
      3,
      n032,
      _LTESS,
      0,
      [_ESE2, _ESUS],
      [[2, {
        [_eQN]: `EnaSrdEnabled`,
        [_xN]: _eSE
      }], [() => exports2.LaunchTemplateEnaSrdUdpSpecification$, {
        [_eQN]: `EnaSrdUdpSpecification`,
        [_xN]: _eSUS
      }]]
    ];
    exports2.LaunchTemplateEnaSrdUdpSpecification$ = [
      3,
      n032,
      _LTESUS,
      0,
      [_ESUE],
      [[2, {
        [_eQN]: `EnaSrdUdpEnabled`,
        [_xN]: _eSUE
      }]]
    ];
    exports2.LaunchTemplateEnclaveOptions$ = [
      3,
      n032,
      _LTEO,
      0,
      [_En],
      [[2, {
        [_eQN]: `Enabled`,
        [_xN]: _en
      }]]
    ];
    exports2.LaunchTemplateEnclaveOptionsRequest$ = [
      3,
      n032,
      _LTEOR,
      0,
      [_En],
      [2]
    ];
    exports2.LaunchTemplateHibernationOptions$ = [
      3,
      n032,
      _LTHO,
      0,
      [_Conf],
      [[2, {
        [_eQN]: `Configured`,
        [_xN]: _conf
      }]]
    ];
    exports2.LaunchTemplateHibernationOptionsRequest$ = [
      3,
      n032,
      _LTHOR,
      0,
      [_Conf],
      [2]
    ];
    exports2.LaunchTemplateIamInstanceProfileSpecification$ = [
      3,
      n032,
      _LTIIPS,
      0,
      [_Ar, _N],
      [[0, {
        [_eQN]: `Arn`,
        [_xN]: _ar
      }], [0, {
        [_eQN]: `Name`,
        [_xN]: _n
      }]]
    ];
    exports2.LaunchTemplateIamInstanceProfileSpecificationRequest$ = [
      3,
      n032,
      _LTIIPSR,
      0,
      [_Ar, _N],
      [0, 0]
    ];
    exports2.LaunchTemplateInstanceMaintenanceOptions$ = [
      3,
      n032,
      _LTIMO,
      0,
      [_ARuto],
      [[0, {
        [_eQN]: `AutoRecovery`,
        [_xN]: _aRut
      }]]
    ];
    exports2.LaunchTemplateInstanceMaintenanceOptionsRequest$ = [
      3,
      n032,
      _LTIMOR,
      0,
      [_ARuto],
      [0]
    ];
    exports2.LaunchTemplateInstanceMarketOptions$ = [
      3,
      n032,
      _LTIMOa,
      0,
      [_MT, _SO],
      [[0, {
        [_eQN]: `MarketType`,
        [_xN]: _mT
      }], [() => exports2.LaunchTemplateSpotMarketOptions$, {
        [_eQN]: `SpotOptions`,
        [_xN]: _sO
      }]]
    ];
    exports2.LaunchTemplateInstanceMarketOptionsRequest$ = [
      3,
      n032,
      _LTIMORa,
      0,
      [_MT, _SO],
      [0, () => exports2.LaunchTemplateSpotMarketOptionsRequest$]
    ];
    exports2.LaunchTemplateInstanceMetadataOptions$ = [
      3,
      n032,
      _LTIMOau,
      0,
      [_St, _HT, _HPRHL, _HE, _HPI, _IMT],
      [[0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `HttpTokens`,
        [_xN]: _hT
      }], [1, {
        [_eQN]: `HttpPutResponseHopLimit`,
        [_xN]: _hPRHL
      }], [0, {
        [_eQN]: `HttpEndpoint`,
        [_xN]: _hE32
      }], [0, {
        [_eQN]: `HttpProtocolIpv6`,
        [_xN]: _hPI
      }], [0, {
        [_eQN]: `InstanceMetadataTags`,
        [_xN]: _iMT
      }]]
    ];
    exports2.LaunchTemplateInstanceMetadataOptionsRequest$ = [
      3,
      n032,
      _LTIMORau,
      0,
      [_HT, _HPRHL, _HE, _HPI, _IMT],
      [0, 1, 0, 0, 0]
    ];
    exports2.LaunchTemplateInstanceNetworkInterfaceSpecification$ = [
      3,
      n032,
      _LTINIS,
      0,
      [_ACIA, _APIAss, _DOT, _De, _DI, _G, _ITnt, _IAC, _IA, _NII, _PIAr, _PIAri, _SPIAC, _SIu, _NCI, _IPpvr, _IPCp, _IPp, _IPC, _PIr, _ESS, _CTS, _EQC],
      [[2, {
        [_eQN]: `AssociateCarrierIpAddress`,
        [_xN]: _aCIA
      }], [2, {
        [_eQN]: `AssociatePublicIpAddress`,
        [_xN]: _aPIA
      }], [2, {
        [_eQN]: `DeleteOnTermination`,
        [_xN]: _dOT
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [1, {
        [_eQN]: `DeviceIndex`,
        [_xN]: _dI
      }], [() => GroupIdStringList, {
        [_eQN]: `GroupSet`,
        [_xN]: _gSr
      }], [0, {
        [_eQN]: `InterfaceType`,
        [_xN]: _iTnt
      }], [1, {
        [_eQN]: `Ipv6AddressCount`,
        [_xN]: _iAC
      }], [() => InstanceIpv6AddressList, {
        [_eQN]: `Ipv6AddressesSet`,
        [_xN]: _iASp
      }], [0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], [0, {
        [_eQN]: `PrivateIpAddress`,
        [_xN]: _pIAr
      }], [() => PrivateIpAddressSpecificationList, {
        [_eQN]: `PrivateIpAddressesSet`,
        [_xN]: _pIAS
      }], [1, {
        [_eQN]: `SecondaryPrivateIpAddressCount`,
        [_xN]: _sPIAC
      }], [0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }], [1, {
        [_eQN]: `NetworkCardIndex`,
        [_xN]: _nCI
      }], [() => Ipv4PrefixListResponse, {
        [_eQN]: `Ipv4PrefixSet`,
        [_xN]: _iPSpvr
      }], [1, {
        [_eQN]: `Ipv4PrefixCount`,
        [_xN]: _iPCp
      }], [() => Ipv6PrefixListResponse, {
        [_eQN]: `Ipv6PrefixSet`,
        [_xN]: _iPSpvre
      }], [1, {
        [_eQN]: `Ipv6PrefixCount`,
        [_xN]: _iPCpv
      }], [2, {
        [_eQN]: `PrimaryIpv6`,
        [_xN]: _pIri
      }], [() => exports2.LaunchTemplateEnaSrdSpecification$, {
        [_eQN]: `EnaSrdSpecification`,
        [_xN]: _eSS
      }], [() => exports2.ConnectionTrackingSpecification$, {
        [_eQN]: `ConnectionTrackingSpecification`,
        [_xN]: _cTS
      }], [1, {
        [_eQN]: `EnaQueueCount`,
        [_xN]: _eQC
      }]]
    ];
    exports2.LaunchTemplateInstanceNetworkInterfaceSpecificationRequest$ = [
      3,
      n032,
      _LTINISR,
      0,
      [_ACIA, _APIAss, _DOT, _De, _DI, _G, _ITnt, _IAC, _IA, _NII, _PIAr, _PIAri, _SPIAC, _SIu, _NCI, _IPpvr, _IPCp, _IPp, _IPC, _PIr, _ESS, _CTS, _EQC],
      [2, 2, 2, 0, 1, [() => SecurityGroupIdStringList, { [_xN]: _SGI }], 0, 1, [() => InstanceIpv6AddressListRequest, 0], 0, 0, [() => PrivateIpAddressSpecificationList, 0], 1, 0, 1, [() => Ipv4PrefixList, { [_xN]: _IPpvre }], 1, [() => Ipv6PrefixList, { [_xN]: _IPpv }], 1, 2, () => exports2.EnaSrdSpecificationRequest$, () => exports2.ConnectionTrackingSpecificationRequest$, 1]
    ];
    exports2.LaunchTemplateInstanceSecondaryInterfaceSpecification$ = [
      3,
      n032,
      _LTISIS,
      0,
      [_DOT, _DI, _PIAri, _PIAC, _SSIe, _ITnt, _NCI],
      [[2, {
        [_eQN]: `DeleteOnTermination`,
        [_xN]: _dOT
      }], [1, {
        [_eQN]: `DeviceIndex`,
        [_xN]: _dI
      }], [() => SecondaryInterfacePrivateIpAddressSpecificationList, {
        [_eQN]: `PrivateIpAddressesSet`,
        [_xN]: _pIAS
      }], [1, {
        [_eQN]: `PrivateIpAddressCount`,
        [_xN]: _pIAC
      }], [0, {
        [_eQN]: `SecondarySubnetId`,
        [_xN]: _sSI
      }], [0, {
        [_eQN]: `InterfaceType`,
        [_xN]: _iTnt
      }], [1, {
        [_eQN]: `NetworkCardIndex`,
        [_xN]: _nCI
      }]]
    ];
    exports2.LaunchTemplateInstanceSecondaryInterfaceSpecificationRequest$ = [
      3,
      n032,
      _LTISISR,
      0,
      [_DOT, _DI, _PIAri, _PIAC, _SSIe, _ITnt, _NCI],
      [2, 1, [() => SecondaryInterfacePrivateIpAddressSpecificationListRequest, { [_xN]: _PIAr }], 1, 0, 0, 1]
    ];
    exports2.LaunchTemplateLicenseConfiguration$ = [
      3,
      n032,
      _LTLC,
      0,
      [_LCA],
      [[0, {
        [_eQN]: `LicenseConfigurationArn`,
        [_xN]: _lCA
      }]]
    ];
    exports2.LaunchTemplateLicenseConfigurationRequest$ = [
      3,
      n032,
      _LTLCR,
      0,
      [_LCA],
      [0]
    ];
    exports2.LaunchTemplateNetworkPerformanceOptions$ = [
      3,
      n032,
      _LTNPO,
      0,
      [_BW],
      [[0, {
        [_eQN]: `BandwidthWeighting`,
        [_xN]: _bW
      }]]
    ];
    exports2.LaunchTemplateNetworkPerformanceOptionsRequest$ = [
      3,
      n032,
      _LTNPOR,
      0,
      [_BW],
      [0]
    ];
    exports2.LaunchTemplateOverrides$ = [
      3,
      n032,
      _LTO,
      0,
      [_IT4, _SPp, _SIu, _AZ, _WCe, _Prio, _IRn, _AZI],
      [[0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [0, {
        [_eQN]: `SpotPrice`,
        [_xN]: _sPp
      }], [0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [1, {
        [_eQN]: `WeightedCapacity`,
        [_xN]: _wC
      }], [1, {
        [_eQN]: `Priority`,
        [_xN]: _pri
      }], [() => exports2.InstanceRequirements$, {
        [_eQN]: `InstanceRequirements`,
        [_xN]: _iR
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }]]
    ];
    exports2.LaunchTemplatePlacement$ = [
      3,
      n032,
      _LTP,
      0,
      [_AZ, _AZI, _Af, _GN, _HIo, _Te, _SDp, _HRGA, _PN, _GIr],
      [[0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [0, {
        [_eQN]: `Affinity`,
        [_xN]: _af
      }], [0, {
        [_eQN]: `GroupName`,
        [_xN]: _gN
      }], [0, {
        [_eQN]: `HostId`,
        [_xN]: _hI
      }], [0, {
        [_eQN]: `Tenancy`,
        [_xN]: _t
      }], [0, {
        [_eQN]: `SpreadDomain`,
        [_xN]: _sDp
      }], [0, {
        [_eQN]: `HostResourceGroupArn`,
        [_xN]: _hRGA
      }], [1, {
        [_eQN]: `PartitionNumber`,
        [_xN]: _pN
      }], [0, {
        [_eQN]: `GroupId`,
        [_xN]: _gIr
      }]]
    ];
    exports2.LaunchTemplatePlacementRequest$ = [
      3,
      n032,
      _LTPR,
      0,
      [_AZ, _AZI, _Af, _GN, _HIo, _Te, _SDp, _HRGA, _PN, _GIr],
      [0, 0, 0, 0, 0, 0, 0, 0, 1, 0]
    ];
    exports2.LaunchTemplatePrivateDnsNameOptions$ = [
      3,
      n032,
      _LTPDNO,
      0,
      [_HTo, _ERNDAR, _ERNDAAAAR],
      [[0, {
        [_eQN]: `HostnameType`,
        [_xN]: _hTo
      }], [2, {
        [_eQN]: `EnableResourceNameDnsARecord`,
        [_xN]: _eRNDAR
      }], [2, {
        [_eQN]: `EnableResourceNameDnsAAAARecord`,
        [_xN]: _eRNDAAAAR
      }]]
    ];
    exports2.LaunchTemplatePrivateDnsNameOptionsRequest$ = [
      3,
      n032,
      _LTPDNOR,
      0,
      [_HTo, _ERNDAR, _ERNDAAAAR],
      [0, 2, 2]
    ];
    exports2.LaunchTemplatesMonitoring$ = [
      3,
      n032,
      _LTM,
      0,
      [_En],
      [[2, {
        [_eQN]: `Enabled`,
        [_xN]: _en
      }]]
    ];
    exports2.LaunchTemplatesMonitoringRequest$ = [
      3,
      n032,
      _LTMR,
      0,
      [_En],
      [2]
    ];
    exports2.LaunchTemplateSpecification$ = [
      3,
      n032,
      _LTS,
      0,
      [_LTI, _LTN, _Ver],
      [0, 0, 0]
    ];
    exports2.LaunchTemplateSpotMarketOptions$ = [
      3,
      n032,
      _LTSMO,
      0,
      [_MPax, _SIT, _BDMlo, _VU, _IIB],
      [[0, {
        [_eQN]: `MaxPrice`,
        [_xN]: _mP
      }], [0, {
        [_eQN]: `SpotInstanceType`,
        [_xN]: _sIT
      }], [1, {
        [_eQN]: `BlockDurationMinutes`,
        [_xN]: _bDMl
      }], [4, {
        [_eQN]: `ValidUntil`,
        [_xN]: _vU
      }], [0, {
        [_eQN]: `InstanceInterruptionBehavior`,
        [_xN]: _iIB
      }]]
    ];
    exports2.LaunchTemplateSpotMarketOptionsRequest$ = [
      3,
      n032,
      _LTSMOR,
      0,
      [_MPax, _SIT, _BDMlo, _VU, _IIB],
      [0, 0, 1, 4, 0]
    ];
    exports2.LaunchTemplateTagSpecification$ = [
      3,
      n032,
      _LTTS,
      0,
      [_RTe, _T10],
      [[0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.LaunchTemplateTagSpecificationRequest$ = [
      3,
      n032,
      _LTTSR,
      0,
      [_RTe, _T10],
      [0, [() => TagList, { [_xN]: _Ta10 }]]
    ];
    exports2.LaunchTemplateVersion$ = [
      3,
      n032,
      _LTV,
      0,
      [_LTI, _LTN, _VNe, _VD, _CTr, _CBr, _DVef, _LTD, _Op],
      [[0, {
        [_eQN]: `LaunchTemplateId`,
        [_xN]: _lTI
      }], [0, {
        [_eQN]: `LaunchTemplateName`,
        [_xN]: _lTN
      }], [1, {
        [_eQN]: `VersionNumber`,
        [_xN]: _vNe
      }], [0, {
        [_eQN]: `VersionDescription`,
        [_xN]: _vD
      }], [4, {
        [_eQN]: `CreateTime`,
        [_xN]: _cTr
      }], [0, {
        [_eQN]: `CreatedBy`,
        [_xN]: _cBr
      }], [2, {
        [_eQN]: `DefaultVersion`,
        [_xN]: _dVef
      }], [() => exports2.ResponseLaunchTemplateData$, {
        [_eQN]: `LaunchTemplateData`,
        [_xN]: _lTD
      }], [() => exports2.OperatorResponse$, {
        [_eQN]: `Operator`,
        [_xN]: _ope
      }]]
    ];
    exports2.LicenseConfiguration$ = [
      3,
      n032,
      _LCi,
      0,
      [_LCA],
      [[0, {
        [_eQN]: `LicenseConfigurationArn`,
        [_xN]: _lCA
      }]]
    ];
    exports2.LicenseConfigurationRequest$ = [
      3,
      n032,
      _LCR,
      0,
      [_LCA],
      [0]
    ];
    exports2.ListImagesInRecycleBinRequest$ = [
      3,
      n032,
      _LIIRBR,
      0,
      [_IIma, _NTe, _MR, _DR],
      [[() => ImageIdStringList, { [_xN]: _IIm }], 0, 1, 2]
    ];
    exports2.ListImagesInRecycleBinResult$ = [
      3,
      n032,
      _LIIRBRi,
      0,
      [_Im, _NTe],
      [[() => ImageRecycleBinInfoList, {
        [_eQN]: `ImageSet`,
        [_xN]: _iSmag
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.ListSnapshotsInRecycleBinRequest$ = [
      3,
      n032,
      _LSIRBR,
      0,
      [_MR, _NTe, _SIna, _DR],
      [1, 0, [() => SnapshotIdStringList, { [_xN]: _SIn }], 2]
    ];
    exports2.ListSnapshotsInRecycleBinResult$ = [
      3,
      n032,
      _LSIRBRi,
      0,
      [_Sn, _NTe],
      [[() => SnapshotRecycleBinInfoList, {
        [_eQN]: `SnapshotSet`,
        [_xN]: _sSn
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.ListVolumesInRecycleBinRequest$ = [
      3,
      n032,
      _LVIRBR,
      0,
      [_VIol, _DR, _MR, _NTe],
      [[() => VolumeIdStringList, { [_xN]: _VIo }], 2, 1, 0]
    ];
    exports2.ListVolumesInRecycleBinResult$ = [
      3,
      n032,
      _LVIRBRi,
      0,
      [_Vo, _NTe],
      [[() => VolumeRecycleBinInfoList, {
        [_eQN]: `VolumeSet`,
        [_xN]: _vS
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.LoadBalancersConfig$ = [
      3,
      n032,
      _LBC,
      0,
      [_CLBC, _TGCa],
      [[() => exports2.ClassicLoadBalancersConfig$, {
        [_eQN]: `ClassicLoadBalancersConfig`,
        [_xN]: _cLBC
      }], [() => exports2.TargetGroupsConfig$, {
        [_eQN]: `TargetGroupsConfig`,
        [_xN]: _tGCa
      }]]
    ];
    exports2.LoadPermission$ = [
      3,
      n032,
      _LPo,
      0,
      [_UI, _Gr],
      [[0, {
        [_eQN]: `UserId`,
        [_xN]: _uI
      }], [0, {
        [_eQN]: `Group`,
        [_xN]: _g
      }]]
    ];
    exports2.LoadPermissionModifications$ = [
      3,
      n032,
      _LPMo,
      0,
      [_Ad, _Rem],
      [[() => LoadPermissionListRequest, 0], [() => LoadPermissionListRequest, 0]]
    ];
    exports2.LoadPermissionRequest$ = [
      3,
      n032,
      _LPR,
      0,
      [_Gr, _UI],
      [0, 0]
    ];
    exports2.LocalGateway$ = [
      3,
      n032,
      _LGo,
      0,
      [_LGI, _OA, _OI, _St, _T10],
      [[0, {
        [_eQN]: `LocalGatewayId`,
        [_xN]: _lGI
      }], [0, {
        [_eQN]: `OutpostArn`,
        [_xN]: _oA
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.LocalGatewayRoute$ = [
      3,
      n032,
      _LGR,
      0,
      [_DCB, _LGVIGI, _Ty, _St, _LGRTI, _LGRTA, _OI, _SIu, _CPI, _NII, _DPLI],
      [[0, {
        [_eQN]: `DestinationCidrBlock`,
        [_xN]: _dCB
      }], [0, {
        [_eQN]: `LocalGatewayVirtualInterfaceGroupId`,
        [_xN]: _lGVIGI
      }], [0, {
        [_eQN]: `Type`,
        [_xN]: _ty
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `LocalGatewayRouteTableId`,
        [_xN]: _lGRTI
      }], [0, {
        [_eQN]: `LocalGatewayRouteTableArn`,
        [_xN]: _lGRTA
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }], [0, {
        [_eQN]: `CoipPoolId`,
        [_xN]: _cPI
      }], [0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], [0, {
        [_eQN]: `DestinationPrefixListId`,
        [_xN]: _dPLI
      }]]
    ];
    exports2.LocalGatewayRouteTable$ = [
      3,
      n032,
      _LGRT,
      0,
      [_LGRTI, _LGRTA, _LGI, _OA, _OI, _St, _T10, _Mo, _SRt],
      [[0, {
        [_eQN]: `LocalGatewayRouteTableId`,
        [_xN]: _lGRTI
      }], [0, {
        [_eQN]: `LocalGatewayRouteTableArn`,
        [_xN]: _lGRTA
      }], [0, {
        [_eQN]: `LocalGatewayId`,
        [_xN]: _lGI
      }], [0, {
        [_eQN]: `OutpostArn`,
        [_xN]: _oA
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `Mode`,
        [_xN]: _mod
      }], [() => exports2.StateReason$, {
        [_eQN]: `StateReason`,
        [_xN]: _sRt
      }]]
    ];
    exports2.LocalGatewayRouteTableVirtualInterfaceGroupAssociation$ = [
      3,
      n032,
      _LGRTVIGA,
      0,
      [_LGRTVIGAI, _LGVIGI, _LGI, _LGRTI, _LGRTA, _OI, _St, _T10],
      [[0, {
        [_eQN]: `LocalGatewayRouteTableVirtualInterfaceGroupAssociationId`,
        [_xN]: _lGRTVIGAI
      }], [0, {
        [_eQN]: `LocalGatewayVirtualInterfaceGroupId`,
        [_xN]: _lGVIGI
      }], [0, {
        [_eQN]: `LocalGatewayId`,
        [_xN]: _lGI
      }], [0, {
        [_eQN]: `LocalGatewayRouteTableId`,
        [_xN]: _lGRTI
      }], [0, {
        [_eQN]: `LocalGatewayRouteTableArn`,
        [_xN]: _lGRTA
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.LocalGatewayRouteTableVpcAssociation$ = [
      3,
      n032,
      _LGRTVA,
      0,
      [_LGRTVAI, _LGRTI, _LGRTA, _LGI, _VI, _OI, _St, _T10],
      [[0, {
        [_eQN]: `LocalGatewayRouteTableVpcAssociationId`,
        [_xN]: _lGRTVAI
      }], [0, {
        [_eQN]: `LocalGatewayRouteTableId`,
        [_xN]: _lGRTI
      }], [0, {
        [_eQN]: `LocalGatewayRouteTableArn`,
        [_xN]: _lGRTA
      }], [0, {
        [_eQN]: `LocalGatewayId`,
        [_xN]: _lGI
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.LocalGatewayVirtualInterface$ = [
      3,
      n032,
      _LGVI,
      0,
      [_LGVII, _LGI, _LGVIGI, _LGVIA, _OLI, _Vl, _LA, _PAe, _LBA, _PBA, _PBAE, _OI, _T10, _CSon],
      [[0, {
        [_eQN]: `LocalGatewayVirtualInterfaceId`,
        [_xN]: _lGVII
      }], [0, {
        [_eQN]: `LocalGatewayId`,
        [_xN]: _lGI
      }], [0, {
        [_eQN]: `LocalGatewayVirtualInterfaceGroupId`,
        [_xN]: _lGVIGI
      }], [0, {
        [_eQN]: `LocalGatewayVirtualInterfaceArn`,
        [_xN]: _lGVIA
      }], [0, {
        [_eQN]: `OutpostLagId`,
        [_xN]: _oLI
      }], [1, {
        [_eQN]: `Vlan`,
        [_xN]: _vl
      }], [0, {
        [_eQN]: `LocalAddress`,
        [_xN]: _lA
      }], [0, {
        [_eQN]: `PeerAddress`,
        [_xN]: _pAe
      }], [1, {
        [_eQN]: `LocalBgpAsn`,
        [_xN]: _lBAo
      }], [1, {
        [_eQN]: `PeerBgpAsn`,
        [_xN]: _pBA
      }], [1, {
        [_eQN]: `PeerBgpAsnExtended`,
        [_xN]: _pBAE
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `ConfigurationState`,
        [_xN]: _cSon
      }]]
    ];
    exports2.LocalGatewayVirtualInterfaceGroup$ = [
      3,
      n032,
      _LGVIG,
      0,
      [_LGVIGI, _LGVIIo, _LGI, _OI, _LBA, _LBAE, _LGVIGA, _T10, _CSon],
      [[0, {
        [_eQN]: `LocalGatewayVirtualInterfaceGroupId`,
        [_xN]: _lGVIGI
      }], [() => LocalGatewayVirtualInterfaceIdSet, {
        [_eQN]: `LocalGatewayVirtualInterfaceIdSet`,
        [_xN]: _lGVIIS
      }], [0, {
        [_eQN]: `LocalGatewayId`,
        [_xN]: _lGI
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [1, {
        [_eQN]: `LocalBgpAsn`,
        [_xN]: _lBAo
      }], [1, {
        [_eQN]: `LocalBgpAsnExtended`,
        [_xN]: _lBAE
      }], [0, {
        [_eQN]: `LocalGatewayVirtualInterfaceGroupArn`,
        [_xN]: _lGVIGA
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `ConfigurationState`,
        [_xN]: _cSon
      }]]
    ];
    exports2.LockedSnapshotsInfo$ = [
      3,
      n032,
      _LSI,
      0,
      [_OI, _SIn, _LSoc, _LDo, _COP, _COPEO, _LCO, _LDST, _LEO],
      [[0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `SnapshotId`,
        [_xN]: _sIn
      }], [0, {
        [_eQN]: `LockState`,
        [_xN]: _lSoc
      }], [1, {
        [_eQN]: `LockDuration`,
        [_xN]: _lDo
      }], [1, {
        [_eQN]: `CoolOffPeriod`,
        [_xN]: _cOP
      }], [4, {
        [_eQN]: `CoolOffPeriodExpiresOn`,
        [_xN]: _cOPEO
      }], [4, {
        [_eQN]: `LockCreatedOn`,
        [_xN]: _lCO
      }], [4, {
        [_eQN]: `LockDurationStartTime`,
        [_xN]: _lDST
      }], [4, {
        [_eQN]: `LockExpiresOn`,
        [_xN]: _lEO
      }]]
    ];
    exports2.LockSnapshotRequest$ = [
      3,
      n032,
      _LSR,
      0,
      [_SIn, _LM2, _DR, _COP, _LDo, _EDx],
      [0, 0, 2, 1, 1, 4],
      2
    ];
    exports2.LockSnapshotResult$ = [
      3,
      n032,
      _LSRo,
      0,
      [_SIn, _LSoc, _LDo, _COP, _COPEO, _LCO, _LEO, _LDST],
      [[0, {
        [_eQN]: `SnapshotId`,
        [_xN]: _sIn
      }], [0, {
        [_eQN]: `LockState`,
        [_xN]: _lSoc
      }], [1, {
        [_eQN]: `LockDuration`,
        [_xN]: _lDo
      }], [1, {
        [_eQN]: `CoolOffPeriod`,
        [_xN]: _cOP
      }], [4, {
        [_eQN]: `CoolOffPeriodExpiresOn`,
        [_xN]: _cOPEO
      }], [4, {
        [_eQN]: `LockCreatedOn`,
        [_xN]: _lCO
      }], [4, {
        [_eQN]: `LockExpiresOn`,
        [_xN]: _lEO
      }], [4, {
        [_eQN]: `LockDurationStartTime`,
        [_xN]: _lDST
      }]]
    ];
    exports2.MacHost$ = [
      3,
      n032,
      _MHa,
      0,
      [_HIo, _MOSLSV],
      [[0, {
        [_eQN]: `HostId`,
        [_xN]: _hI
      }], [() => MacOSVersionStringList, {
        [_eQN]: `MacOSLatestSupportedVersionSet`,
        [_xN]: _mOSLSVS
      }]]
    ];
    exports2.MacModificationTask$ = [
      3,
      n032,
      _MMT,
      0,
      [_II2, _MMTIa, _MSIPCa, _ST11, _T10, _TSas, _TTa],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `MacModificationTaskId`,
        [_xN]: _mMTI
      }], [() => exports2.MacSystemIntegrityProtectionConfiguration$, {
        [_eQN]: `MacSystemIntegrityProtectionConfig`,
        [_xN]: _mSIPC
      }], [4, {
        [_eQN]: `StartTime`,
        [_xN]: _sT19
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `TaskState`,
        [_xN]: _tSas
      }], [0, {
        [_eQN]: `TaskType`,
        [_xN]: _tTa
      }]]
    ];
    exports2.MacSystemIntegrityProtectionConfiguration$ = [
      3,
      n032,
      _MSIPC,
      0,
      [_AIp, _BS, _DReb, _DTRr, _FPi, _KS, _NP, _Sta],
      [[0, {
        [_eQN]: `AppleInternal`,
        [_xN]: _aIp
      }], [0, {
        [_eQN]: `BaseSystem`,
        [_xN]: _bSa
      }], [0, {
        [_eQN]: `DebuggingRestrictions`,
        [_xN]: _dReb
      }], [0, {
        [_eQN]: `DTraceRestrictions`,
        [_xN]: _dTR
      }], [0, {
        [_eQN]: `FilesystemProtections`,
        [_xN]: _fPi
      }], [0, {
        [_eQN]: `KextSigning`,
        [_xN]: _kSe
      }], [0, {
        [_eQN]: `NvramProtections`,
        [_xN]: _nP
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }]]
    ];
    exports2.MacSystemIntegrityProtectionConfigurationRequest$ = [
      3,
      n032,
      _MSIPCR,
      0,
      [_AIp, _BS, _DReb, _DTRr, _FPi, _KS, _NP],
      [0, 0, 0, 0, 0, 0, 0]
    ];
    exports2.MaintenanceDetails$ = [
      3,
      n032,
      _MDa,
      0,
      [_PM, _MAAA, _LMA],
      [[0, {
        [_eQN]: `PendingMaintenance`,
        [_xN]: _pM
      }], [4, {
        [_eQN]: `MaintenanceAutoAppliedAfter`,
        [_xN]: _mAAA
      }], [4, {
        [_eQN]: `LastMaintenanceApplied`,
        [_xN]: _lMA
      }]]
    ];
    exports2.ManagedPrefixList$ = [
      3,
      n032,
      _MPLa,
      0,
      [_PLI, _AF, _St, _SMta, _PLAr, _PLN, _ME, _Ver, _T10, _OI, _IPLRTI, _IPLRSE],
      [[0, {
        [_eQN]: `PrefixListId`,
        [_xN]: _pLI
      }], [0, {
        [_eQN]: `AddressFamily`,
        [_xN]: _aF
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `StateMessage`,
        [_xN]: _sMta
      }], [0, {
        [_eQN]: `PrefixListArn`,
        [_xN]: _pLA
      }], [0, {
        [_eQN]: `PrefixListName`,
        [_xN]: _pLN
      }], [1, {
        [_eQN]: `MaxEntries`,
        [_xN]: _mE
      }], [1, {
        [_eQN]: `Version`,
        [_xN]: _ve
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `IpamPrefixListResolverTargetId`,
        [_xN]: _iPLRTI
      }], [2, {
        [_eQN]: `IpamPrefixListResolverSyncEnabled`,
        [_xN]: _iPLRSE
      }]]
    ];
    exports2.ManagedResourceVisibilitySettings$ = [
      3,
      n032,
      _MRVS,
      0,
      [_DVefa],
      [[0, {
        [_eQN]: `DefaultVisibility`,
        [_xN]: _dVefa
      }]]
    ];
    exports2.MediaAcceleratorInfo$ = [
      3,
      n032,
      _MAIe,
      0,
      [_Acc, _TMMIMB],
      [[() => MediaDeviceInfoList, {
        [_eQN]: `Accelerators`,
        [_xN]: _acc
      }], [1, {
        [_eQN]: `TotalMediaMemoryInMiB`,
        [_xN]: _tMMIMB
      }]]
    ];
    exports2.MediaDeviceInfo$ = [
      3,
      n032,
      _MDI,
      0,
      [_Cou, _N, _Man, _MIe],
      [[1, {
        [_eQN]: `Count`,
        [_xN]: _cou
      }], [0, {
        [_eQN]: `Name`,
        [_xN]: _n
      }], [0, {
        [_eQN]: `Manufacturer`,
        [_xN]: _man
      }], [() => exports2.MediaDeviceMemoryInfo$, {
        [_eQN]: `MemoryInfo`,
        [_xN]: _mIe
      }]]
    ];
    exports2.MediaDeviceMemoryInfo$ = [
      3,
      n032,
      _MDMI,
      0,
      [_SIMB],
      [[1, {
        [_eQN]: `SizeInMiB`,
        [_xN]: _sIMB
      }]]
    ];
    exports2.MemoryGiBPerVCpu$ = [
      3,
      n032,
      _MGBPVC,
      0,
      [_M, _Ma],
      [[1, {
        [_eQN]: `Min`,
        [_xN]: _m29
      }], [1, {
        [_eQN]: `Max`,
        [_xN]: _ma
      }]]
    ];
    exports2.MemoryGiBPerVCpuRequest$ = [
      3,
      n032,
      _MGBPVCR,
      0,
      [_M, _Ma],
      [1, 1]
    ];
    exports2.MemoryInfo$ = [
      3,
      n032,
      _MIe,
      0,
      [_SIMB],
      [[1, {
        [_eQN]: `SizeInMiB`,
        [_xN]: _sIMB
      }]]
    ];
    exports2.MemoryMiB$ = [
      3,
      n032,
      _MMB,
      0,
      [_M, _Ma],
      [[1, {
        [_eQN]: `Min`,
        [_xN]: _m29
      }], [1, {
        [_eQN]: `Max`,
        [_xN]: _ma
      }]]
    ];
    exports2.MemoryMiBRequest$ = [
      3,
      n032,
      _MMBR,
      0,
      [_M, _Ma],
      [1, 1],
      1
    ];
    exports2.MetricDataResult$ = [
      3,
      n032,
      _MDRet,
      0,
      [_Dim, _Ti, _MVe],
      [[() => exports2.CapacityManagerDimension$, {
        [_eQN]: `Dimension`,
        [_xN]: _dim
      }], [4, {
        [_eQN]: `Timestamp`,
        [_xN]: _ti
      }], [() => MetricValueSet, {
        [_eQN]: `MetricValueSet`,
        [_xN]: _mVS
      }]]
    ];
    exports2.MetricPoint$ = [
      3,
      n032,
      _MPet,
      0,
      [_SD, _ED, _V10, _Sta],
      [[4, {
        [_eQN]: `StartDate`,
        [_xN]: _sD
      }], [4, {
        [_eQN]: `EndDate`,
        [_xN]: _eD
      }], [1, {
        [_eQN]: `Value`,
        [_xN]: _v
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }]]
    ];
    exports2.MetricValue$ = [
      3,
      n032,
      _MVet,
      0,
      [_Met, _V10],
      [[0, {
        [_eQN]: `Metric`,
        [_xN]: _met
      }], [1, {
        [_eQN]: `Value`,
        [_xN]: _v
      }]]
    ];
    exports2.ModifyAddressAttributeRequest$ = [
      3,
      n032,
      _MAAR,
      0,
      [_AIl, _DNo, _DR],
      [0, 0, 2],
      1
    ];
    exports2.ModifyAddressAttributeResult$ = [
      3,
      n032,
      _MAARo,
      0,
      [_A10],
      [[() => exports2.AddressAttribute$, {
        [_eQN]: `Address`,
        [_xN]: _ad
      }]]
    ];
    exports2.ModifyAvailabilityZoneGroupRequest$ = [
      3,
      n032,
      _MAZGR,
      0,
      [_GN, _OIS, _DR],
      [0, 0, 2],
      2
    ];
    exports2.ModifyAvailabilityZoneGroupResult$ = [
      3,
      n032,
      _MAZGRo,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.ModifyCapacityReservationFleetRequest$ = [
      3,
      n032,
      _MCRFR,
      0,
      [_CRFIa, _TTC, _ED, _DR, _RED],
      [0, 1, 4, 2, 2],
      1
    ];
    exports2.ModifyCapacityReservationFleetResult$ = [
      3,
      n032,
      _MCRFRo,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.ModifyCapacityReservationRequest$ = [
      3,
      n032,
      _MCRR,
      0,
      [_CRI, _IC, _ED, _EDTn, _Acce, _DR, _AId, _IMC],
      [0, 1, 4, 0, 2, 2, 0, 0],
      1
    ];
    exports2.ModifyCapacityReservationResult$ = [
      3,
      n032,
      _MCRRo,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.ModifyClientVpnEndpointRequest$ = [
      3,
      n032,
      _MCVER,
      0,
      [_CVEI, _SCA, _CLO, _DS10, _VPp, _De, _STp, _DR, _SGIe, _VI, _SSP, _CCO, _STH, _CLBO, _CREO, _DOST, _TGC],
      [0, 0, () => exports2.ConnectionLogOptions$, [() => exports2.DnsServersOptionsModifyStructure$, 0], 1, 0, 2, 2, [() => ClientVpnSecurityGroupIdSet, { [_xN]: _SGI }], 0, 0, () => exports2.ClientConnectOptions$, 1, () => exports2.ClientLoginBannerOptions$, () => exports2.ClientRouteEnforcementOptions$, 2, [() => exports2.TransitGatewayConfigurationInputStructure$, 0]],
      1
    ];
    exports2.ModifyClientVpnEndpointResult$ = [
      3,
      n032,
      _MCVERo,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.ModifyDefaultCreditSpecificationRequest$ = [
      3,
      n032,
      _MDCSR,
      0,
      [_IF, _CCp, _DR],
      [0, 0, 2],
      2
    ];
    exports2.ModifyDefaultCreditSpecificationResult$ = [
      3,
      n032,
      _MDCSRo,
      0,
      [_IFCS],
      [[() => exports2.InstanceFamilyCreditSpecification$, {
        [_eQN]: `InstanceFamilyCreditSpecification`,
        [_xN]: _iFCS
      }]]
    ];
    exports2.ModifyEbsDefaultKmsKeyIdRequest$ = [
      3,
      n032,
      _MEDKKIR,
      0,
      [_KKI, _DR],
      [0, 2],
      1
    ];
    exports2.ModifyEbsDefaultKmsKeyIdResult$ = [
      3,
      n032,
      _MEDKKIRo,
      0,
      [_KKI],
      [[0, {
        [_eQN]: `KmsKeyId`,
        [_xN]: _kKI
      }]]
    ];
    exports2.ModifyFleetRequest$ = [
      3,
      n032,
      _MFR,
      0,
      [_FIl, _DR, _ECTP, _LTC, _TCS, _Con],
      [0, 2, 0, [() => FleetLaunchTemplateConfigListRequest, { [_xN]: _LTCa }], () => exports2.TargetCapacitySpecificationRequest$, 0],
      1
    ];
    exports2.ModifyFleetResult$ = [
      3,
      n032,
      _MFRo,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.ModifyFpgaImageAttributeRequest$ = [
      3,
      n032,
      _MFIAR,
      0,
      [_FII, _DR, _At, _OTp, _UIs, _UG, _PCro, _LPo, _De, _N],
      [0, 2, 0, 0, [() => UserIdStringList, { [_xN]: _UI }], [() => UserGroupStringList, { [_xN]: _UGs }], [() => ProductCodeStringList, { [_xN]: _PCr10 }], [() => exports2.LoadPermissionModifications$, 0], 0, 0],
      1
    ];
    exports2.ModifyFpgaImageAttributeResult$ = [
      3,
      n032,
      _MFIARo,
      0,
      [_FIA],
      [[() => exports2.FpgaImageAttribute$, {
        [_eQN]: `FpgaImageAttribute`,
        [_xN]: _fIA
      }]]
    ];
    exports2.ModifyHostsRequest$ = [
      3,
      n032,
      _MHR,
      0,
      [_HI, _HR, _IT4, _IF, _HM, _APu],
      [[() => RequestHostIdList, {
        [_eQN]: `HostId`,
        [_xN]: _hI
      }], 0, 0, 0, 0, [0, {
        [_eQN]: `AutoPlacement`,
        [_xN]: _aP
      }]],
      1
    ];
    exports2.ModifyHostsResult$ = [
      3,
      n032,
      _MHRo,
      0,
      [_Suc, _U],
      [[() => ResponseHostIdList, {
        [_eQN]: `Successful`,
        [_xN]: _suc
      }], [() => UnsuccessfulItemList, {
        [_eQN]: `Unsuccessful`,
        [_xN]: _u
      }]]
    ];
    exports2.ModifyIdentityIdFormatRequest$ = [
      3,
      n032,
      _MIIFR,
      0,
      [_Reso, _ULI, _PAr10],
      [[0, {
        [_eQN]: `Resource`,
        [_xN]: _re
      }], [2, {
        [_eQN]: `UseLongIds`,
        [_xN]: _uLI
      }], [0, {
        [_eQN]: `PrincipalArn`,
        [_xN]: _pAr
      }]],
      3
    ];
    exports2.ModifyIdFormatRequest$ = [
      3,
      n032,
      _MIFR,
      0,
      [_Reso, _ULI],
      [0, 2],
      2
    ];
    exports2.ModifyImageAttributeRequest$ = [
      3,
      n032,
      _MIAR,
      0,
      [_IIm, _At, _De, _LPau, _OTp, _PCro, _UG, _UIs, _V10, _OArga, _OUAr, _ISmd, _DR],
      [0, 0, [() => exports2.AttributeValue$, 0], [() => exports2.LaunchPermissionModifications$, 0], 0, [() => ProductCodeStringList, { [_xN]: _PCr10 }], [() => UserGroupStringList, { [_xN]: _UGs }], [() => UserIdStringList, { [_xN]: _UI }], 0, [() => OrganizationArnStringList, { [_xN]: _OArg }], [() => OrganizationalUnitArnStringList, { [_xN]: _OUA }], [() => exports2.AttributeValue$, 0], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.ModifyInstanceAttributeRequest$ = [
      3,
      n032,
      _MIARo,
      0,
      [_II2, _SDC, _DASi, _DR, _At, _V10, _BDMl, _DAT, _IT4, _Ke, _Ra, _UDs, _IISB, _G, _EO, _SNS, _ESna],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [() => exports2.AttributeBooleanValue$, 0], [() => exports2.AttributeBooleanValue$, 0], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [0, {
        [_eQN]: `Attribute`,
        [_xN]: _att
      }], [() => ModifyInstanceAttributeValue, {
        [_eQN]: `Value`,
        [_xN]: _v
      }], [() => InstanceBlockDeviceMappingSpecificationList, {
        [_eQN]: `BlockDeviceMapping`,
        [_xN]: _bDM
      }], [() => exports2.AttributeBooleanValue$, {
        [_eQN]: `DisableApiTermination`,
        [_xN]: _dAT
      }], [() => exports2.AttributeValue$, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [() => exports2.AttributeValue$, {
        [_eQN]: `Kernel`,
        [_xN]: _ke
      }], [() => exports2.AttributeValue$, {
        [_eQN]: `Ramdisk`,
        [_xN]: _ra
      }], [() => exports2.BlobAttributeValue$, {
        [_eQN]: `UserData`,
        [_xN]: _uDs
      }], [() => exports2.AttributeValue$, {
        [_eQN]: `InstanceInitiatedShutdownBehavior`,
        [_xN]: _iISB
      }], [() => GroupIdStringList, { [_xN]: _GIr }], [() => exports2.AttributeBooleanValue$, {
        [_eQN]: `EbsOptimized`,
        [_xN]: _eO
      }], [() => exports2.AttributeValue$, {
        [_eQN]: `SriovNetSupport`,
        [_xN]: _sNSr
      }], [() => exports2.AttributeBooleanValue$, {
        [_eQN]: `EnaSupport`,
        [_xN]: _eSna
      }]],
      1
    ];
    exports2.ModifyInstanceCapacityReservationAttributesRequest$ = [
      3,
      n032,
      _MICRAR,
      0,
      [_II2, _CRSa, _DR],
      [0, () => exports2.CapacityReservationSpecification$, 2],
      2
    ];
    exports2.ModifyInstanceCapacityReservationAttributesResult$ = [
      3,
      n032,
      _MICRARo,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.ModifyInstanceConnectEndpointRequest$ = [
      3,
      n032,
      _MICER,
      0,
      [_ICEI, _DR, _IAT, _SGIe, _PCI],
      [0, 2, 0, [() => SecurityGroupIdStringListRequest, { [_xN]: _SGI }], 2],
      1
    ];
    exports2.ModifyInstanceConnectEndpointResult$ = [
      3,
      n032,
      _MICERo,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.ModifyInstanceCpuOptionsRequest$ = [
      3,
      n032,
      _MICOR,
      0,
      [_II2, _CCor, _TPC, _NV, _DR],
      [0, 1, 1, 0, 2],
      1
    ];
    exports2.ModifyInstanceCpuOptionsResult$ = [
      3,
      n032,
      _MICORo,
      0,
      [_II2, _CCor, _TPC, _NV],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [1, {
        [_eQN]: `CoreCount`,
        [_xN]: _cCo
      }], [1, {
        [_eQN]: `ThreadsPerCore`,
        [_xN]: _tPC
      }], [0, {
        [_eQN]: `NestedVirtualization`,
        [_xN]: _nV
      }]]
    ];
    exports2.ModifyInstanceCreditSpecificationRequest$ = [
      3,
      n032,
      _MICSR,
      0,
      [_ICS, _DR, _CT4],
      [[() => InstanceCreditSpecificationListRequest, { [_xN]: _ICSn }], 2, 0],
      1
    ];
    exports2.ModifyInstanceCreditSpecificationResult$ = [
      3,
      n032,
      _MICSRo,
      0,
      [_SICS, _UICS],
      [[() => SuccessfulInstanceCreditSpecificationSet, {
        [_eQN]: `SuccessfulInstanceCreditSpecificationSet`,
        [_xN]: _sICSS
      }], [() => UnsuccessfulInstanceCreditSpecificationSet, {
        [_eQN]: `UnsuccessfulInstanceCreditSpecificationSet`,
        [_xN]: _uICSS
      }]]
    ];
    exports2.ModifyInstanceEventStartTimeRequest$ = [
      3,
      n032,
      _MIESTR,
      0,
      [_II2, _IEI, _NB, _DR],
      [0, 0, 4, 2],
      3
    ];
    exports2.ModifyInstanceEventStartTimeResult$ = [
      3,
      n032,
      _MIESTRo,
      0,
      [_Eve],
      [[() => exports2.InstanceStatusEvent$, {
        [_eQN]: `Event`,
        [_xN]: _ev
      }]]
    ];
    exports2.ModifyInstanceEventWindowRequest$ = [
      3,
      n032,
      _MIEWR,
      0,
      [_IEWI, _DR, _N, _TRi, _CEr],
      [0, 2, 0, [() => InstanceEventWindowTimeRangeRequestSet, { [_xN]: _TRim }], 0],
      1
    ];
    exports2.ModifyInstanceEventWindowResult$ = [
      3,
      n032,
      _MIEWRo,
      0,
      [_IEW],
      [[() => exports2.InstanceEventWindow$, {
        [_eQN]: `InstanceEventWindow`,
        [_xN]: _iEW
      }]]
    ];
    exports2.ModifyInstanceMaintenanceOptionsRequest$ = [
      3,
      n032,
      _MIMOR,
      0,
      [_II2, _ARuto, _RMe, _DR],
      [0, 0, 0, 2],
      1
    ];
    exports2.ModifyInstanceMaintenanceOptionsResult$ = [
      3,
      n032,
      _MIMORo,
      0,
      [_II2, _ARuto, _RMe],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `AutoRecovery`,
        [_xN]: _aRut
      }], [0, {
        [_eQN]: `RebootMigration`,
        [_xN]: _rMe
      }]]
    ];
    exports2.ModifyInstanceMetadataDefaultsRequest$ = [
      3,
      n032,
      _MIMDR,
      0,
      [_HT, _HPRHL, _HE, _IMT, _DR, _HTE],
      [0, 1, 0, 0, 2, 0]
    ];
    exports2.ModifyInstanceMetadataDefaultsResult$ = [
      3,
      n032,
      _MIMDRo,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.ModifyInstanceMetadataOptionsRequest$ = [
      3,
      n032,
      _MIMORod,
      0,
      [_II2, _HT, _HPRHL, _HE, _DR, _HPI, _IMT],
      [0, 0, 1, 0, 2, 0, 0],
      1
    ];
    exports2.ModifyInstanceMetadataOptionsResult$ = [
      3,
      n032,
      _MIMORodi,
      0,
      [_II2, _IMOn],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [() => exports2.InstanceMetadataOptionsResponse$, {
        [_eQN]: `InstanceMetadataOptions`,
        [_xN]: _iMO
      }]]
    ];
    exports2.ModifyInstanceNetworkPerformanceRequest$ = [
      3,
      n032,
      _MINPR,
      0,
      [_II2, _BW, _DR],
      [0, 0, 2],
      2
    ];
    exports2.ModifyInstanceNetworkPerformanceResult$ = [
      3,
      n032,
      _MINPRo,
      0,
      [_II2, _BW],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `BandwidthWeighting`,
        [_xN]: _bW
      }]]
    ];
    exports2.ModifyInstancePlacementRequest$ = [
      3,
      n032,
      _MIPR,
      0,
      [_II2, _GN, _PN, _HRGA, _GIr, _Te, _Af, _HIo],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], 0, 1, 0, 0, [0, {
        [_eQN]: `Tenancy`,
        [_xN]: _t
      }], [0, {
        [_eQN]: `Affinity`,
        [_xN]: _af
      }], [0, {
        [_eQN]: `HostId`,
        [_xN]: _hI
      }]],
      1
    ];
    exports2.ModifyInstancePlacementResult$ = [
      3,
      n032,
      _MIPRo,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.ModifyIpamPolicyAllocationRulesRequest$ = [
      3,
      n032,
      _MIPARR,
      0,
      [_IPIp, _Lo, _RTe, _DR, _ARllo],
      [0, 0, 0, 2, [() => IpamPolicyAllocationRuleListRequest, { [_xN]: _ARlloc }]],
      3
    ];
    exports2.ModifyIpamPolicyAllocationRulesResult$ = [
      3,
      n032,
      _MIPARRo,
      0,
      [_IPDp],
      [[() => exports2.IpamPolicyDocument$, {
        [_eQN]: `IpamPolicyDocument`,
        [_xN]: _iPD
      }]]
    ];
    exports2.ModifyIpamPoolRequest$ = [
      3,
      n032,
      _MIPRod,
      0,
      [_IPI2, _DR, _De, _AIu, _AMNL, _AMNLl, _ADNL, _CADNL, _AART, _RART],
      [0, 2, 0, 2, 1, 1, 1, 2, [() => RequestIpamResourceTagList, { [_xN]: _AARTd }], [() => RequestIpamResourceTagList, { [_xN]: _RARTe }]],
      1
    ];
    exports2.ModifyIpamPoolResult$ = [
      3,
      n032,
      _MIPRodi,
      0,
      [_IPpam],
      [[() => exports2.IpamPool$, {
        [_eQN]: `IpamPool`,
        [_xN]: _iPpam
      }]]
    ];
    exports2.ModifyIpamPrefixListResolverRequest$ = [
      3,
      n032,
      _MIPLRR,
      0,
      [_IPLRI, _DR, _De, _Ru],
      [0, 2, 0, [() => IpamPrefixListResolverRuleRequestSet, { [_xN]: _Rul }]],
      1
    ];
    exports2.ModifyIpamPrefixListResolverResult$ = [
      3,
      n032,
      _MIPLRRo,
      0,
      [_IPLR],
      [[() => exports2.IpamPrefixListResolver$, {
        [_eQN]: `IpamPrefixListResolver`,
        [_xN]: _iPLR
      }]]
    ];
    exports2.ModifyIpamPrefixListResolverTargetRequest$ = [
      3,
      n032,
      _MIPLRTR,
      0,
      [_IPLRTI, _DR, _DV, _TLV, _CT4],
      [0, 2, 1, 2, [0, 4]],
      1
    ];
    exports2.ModifyIpamPrefixListResolverTargetResult$ = [
      3,
      n032,
      _MIPLRTRo,
      0,
      [_IPLRT],
      [[() => exports2.IpamPrefixListResolverTarget$, {
        [_eQN]: `IpamPrefixListResolverTarget`,
        [_xN]: _iPLRT
      }]]
    ];
    exports2.ModifyIpamRequest$ = [
      3,
      n032,
      _MIR,
      0,
      [_IIp, _DR, _De, _AOR, _ROR, _Tie, _EPG, _MAe],
      [0, 2, 0, [() => AddIpamOperatingRegionSet, { [_xN]: _AORd }], [() => RemoveIpamOperatingRegionSet, { [_xN]: _RORe }], 0, 2, 0],
      1
    ];
    exports2.ModifyIpamResourceCidrRequest$ = [
      3,
      n032,
      _MIRCR,
      0,
      [_RIeso, _RCe, _RR, _CISI, _Moni, _DR, _DISI],
      [0, 0, 0, 0, 2, 2, 0],
      5
    ];
    exports2.ModifyIpamResourceCidrResult$ = [
      3,
      n032,
      _MIRCRo,
      0,
      [_IRCp],
      [[() => exports2.IpamResourceCidr$, {
        [_eQN]: `IpamResourceCidr`,
        [_xN]: _iRC
      }]]
    ];
    exports2.ModifyIpamResourceDiscoveryRequest$ = [
      3,
      n032,
      _MIRDR,
      0,
      [_IRDI, _DR, _De, _AOR, _ROR, _AOUE, _ROUE],
      [0, 2, 0, [() => AddIpamOperatingRegionSet, { [_xN]: _AORd }], [() => RemoveIpamOperatingRegionSet, { [_xN]: _RORe }], [() => AddIpamOrganizationalUnitExclusionSet, { [_xN]: _AOUEd }], [() => RemoveIpamOrganizationalUnitExclusionSet, { [_xN]: _ROUEe }]],
      1
    ];
    exports2.ModifyIpamResourceDiscoveryResult$ = [
      3,
      n032,
      _MIRDRo,
      0,
      [_IRD],
      [[() => exports2.IpamResourceDiscovery$, {
        [_eQN]: `IpamResourceDiscovery`,
        [_xN]: _iRD
      }]]
    ];
    exports2.ModifyIpamResult$ = [
      3,
      n032,
      _MIRo,
      0,
      [_Ip],
      [[() => exports2.Ipam$, {
        [_eQN]: `Ipam`,
        [_xN]: _ip
      }]]
    ];
    exports2.ModifyIpamScopeRequest$ = [
      3,
      n032,
      _MISR,
      0,
      [_ISI, _DR, _De, _EAC, _REAC],
      [0, 2, 0, () => exports2.ExternalAuthorityConfiguration$, 2],
      1
    ];
    exports2.ModifyIpamScopeResult$ = [
      3,
      n032,
      _MISRo,
      0,
      [_ISp],
      [[() => exports2.IpamScope$, {
        [_eQN]: `IpamScope`,
        [_xN]: _iSp
      }]]
    ];
    exports2.ModifyLaunchTemplateRequest$ = [
      3,
      n032,
      _MLTR,
      0,
      [_DR, _CT4, _LTI, _LTN, _DVef],
      [2, [0, 4], 0, 0, [0, { [_xN]: _SDV }]]
    ];
    exports2.ModifyLaunchTemplateResult$ = [
      3,
      n032,
      _MLTRo,
      0,
      [_LT],
      [[() => exports2.LaunchTemplate$, {
        [_eQN]: `LaunchTemplate`,
        [_xN]: _lT
      }]]
    ];
    exports2.ModifyLocalGatewayRouteRequest$ = [
      3,
      n032,
      _MLGRR,
      0,
      [_LGRTI, _DCB, _LGVIGI, _NII, _DR, _DPLI],
      [0, 0, 0, 0, 2, 0],
      1
    ];
    exports2.ModifyLocalGatewayRouteResult$ = [
      3,
      n032,
      _MLGRRo,
      0,
      [_Ro],
      [[() => exports2.LocalGatewayRoute$, {
        [_eQN]: `Route`,
        [_xN]: _ro
      }]]
    ];
    exports2.ModifyManagedPrefixListRequest$ = [
      3,
      n032,
      _MMPLR,
      0,
      [_PLI, _DR, _CV4, _PLN, _AEd, _REem, _ME, _IPLRSE],
      [0, 2, 1, 0, [() => AddPrefixListEntries, { [_xN]: _AEdd }], [() => RemovePrefixListEntries, { [_xN]: _REemo }], 1, 2],
      1
    ];
    exports2.ModifyManagedPrefixListResult$ = [
      3,
      n032,
      _MMPLRo,
      0,
      [_PL],
      [[() => exports2.ManagedPrefixList$, {
        [_eQN]: `PrefixList`,
        [_xN]: _pL
      }]]
    ];
    exports2.ModifyManagedResourceVisibilityRequest$ = [
      3,
      n032,
      _MMRVR,
      0,
      [_DR, _DVefa],
      [2, 0]
    ];
    exports2.ModifyManagedResourceVisibilityResult$ = [
      3,
      n032,
      _MMRVRo,
      0,
      [_Vi],
      [[() => exports2.ManagedResourceVisibilitySettings$, {
        [_eQN]: `Visibility`,
        [_xN]: _vi
      }]]
    ];
    exports2.ModifyNetworkInterfaceAttributeRequest$ = [
      3,
      n032,
      _MNIAR,
      0,
      [_NII, _ESS, _EPI, _CTS, _APIAss, _ASI, _DR, _De, _SDC, _G, _Att],
      [[0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], () => exports2.EnaSrdSpecification$, 2, () => exports2.ConnectionTrackingSpecificationRequest$, 2, [() => SubnetIdList, { [_xN]: _ASIs }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => exports2.AttributeValue$, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [() => exports2.AttributeBooleanValue$, {
        [_eQN]: `SourceDestCheck`,
        [_xN]: _sDC
      }], [() => SecurityGroupIdStringList, { [_xN]: _SGI }], [() => exports2.NetworkInterfaceAttachmentChanges$, {
        [_eQN]: `Attachment`,
        [_xN]: _at
      }]],
      1
    ];
    exports2.ModifyPrivateDnsNameOptionsRequest$ = [
      3,
      n032,
      _MPDNOR,
      0,
      [_II2, _DR, _PDHT, _ERNDAR, _ERNDAAAAR],
      [0, 2, 0, 2, 2],
      1
    ];
    exports2.ModifyPrivateDnsNameOptionsResult$ = [
      3,
      n032,
      _MPDNORo,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.ModifyPublicIpDnsNameOptionsRequest$ = [
      3,
      n032,
      _MPIDNOR,
      0,
      [_NII, _HTo, _DR],
      [0, 0, 2],
      2
    ];
    exports2.ModifyPublicIpDnsNameOptionsResult$ = [
      3,
      n032,
      _MPIDNORo,
      0,
      [_Suc],
      [[2, {
        [_eQN]: `Successful`,
        [_xN]: _suc
      }]]
    ];
    exports2.ModifyReservedInstancesRequest$ = [
      3,
      n032,
      _MRIR,
      0,
      [_RIIese, _TC10, _CT4],
      [[() => ReservedInstancesIdStringList, { [_xN]: _RIIes }], [() => ReservedInstancesConfigurationList, { [_xN]: _RICSIT }], [0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }]],
      2
    ];
    exports2.ModifyReservedInstancesResult$ = [
      3,
      n032,
      _MRIRo,
      0,
      [_RIMIe],
      [[0, {
        [_eQN]: `ReservedInstancesModificationId`,
        [_xN]: _rIMI
      }]]
    ];
    exports2.ModifyRouteServerRequest$ = [
      3,
      n032,
      _MRSR,
      0,
      [_RSI, _PRe, _PRD, _SNE, _DR],
      [0, 0, 1, 2, 2],
      1
    ];
    exports2.ModifyRouteServerResult$ = [
      3,
      n032,
      _MRSRo,
      0,
      [_RSo],
      [[() => exports2.RouteServer$, {
        [_eQN]: `RouteServer`,
        [_xN]: _rSo
      }]]
    ];
    exports2.ModifySecurityGroupRulesRequest$ = [
      3,
      n032,
      _MSGRR,
      0,
      [_GIr, _SGR, _DR],
      [0, [() => SecurityGroupRuleUpdateList, { [_xN]: _SGRe }], 2],
      2
    ];
    exports2.ModifySecurityGroupRulesResult$ = [
      3,
      n032,
      _MSGRRo,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.ModifySnapshotAttributeRequest$ = [
      3,
      n032,
      _MSAR,
      0,
      [_SIn, _At, _CVP, _GNr, _OTp, _UIs, _DR],
      [0, 0, [() => exports2.CreateVolumePermissionModifications$, 0], [() => GroupNameStringList, { [_xN]: _UGs }], 0, [() => UserIdStringList, { [_xN]: _UI }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.ModifySnapshotTierRequest$ = [
      3,
      n032,
      _MSTR,
      0,
      [_SIn, _STt, _DR],
      [0, 0, 2],
      1
    ];
    exports2.ModifySnapshotTierResult$ = [
      3,
      n032,
      _MSTRo,
      0,
      [_SIn, _TST],
      [[0, {
        [_eQN]: `SnapshotId`,
        [_xN]: _sIn
      }], [4, {
        [_eQN]: `TieringStartTime`,
        [_xN]: _tST
      }]]
    ];
    exports2.ModifySpotFleetRequestRequest$ = [
      3,
      n032,
      _MSFRR,
      0,
      [_SFRI, _LTC, _ODTC, _Con, _TCar, _ECTP],
      [[0, {
        [_eQN]: `SpotFleetRequestId`,
        [_xN]: _sFRI
      }], [() => LaunchTemplateConfigList, { [_xN]: _LTCa }], 1, 0, [1, {
        [_eQN]: `TargetCapacity`,
        [_xN]: _tCa
      }], [0, {
        [_eQN]: `ExcessCapacityTerminationPolicy`,
        [_xN]: _eCTP
      }]],
      1
    ];
    exports2.ModifySpotFleetRequestResponse$ = [
      3,
      n032,
      _MSFRRo,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.ModifySubnetAttributeRequest$ = [
      3,
      n032,
      _MSARo,
      0,
      [_SIu, _AIAOC, _MPIOL, _MCOIOL, _COIP, _EDn, _PDHTOL, _ERNDAROL, _ERNDAAAAROL, _ELADI, _DLADI],
      [[0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }], [() => exports2.AttributeBooleanValue$, 0], [() => exports2.AttributeBooleanValue$, 0], [() => exports2.AttributeBooleanValue$, 0], 0, [() => exports2.AttributeBooleanValue$, 0], 0, [() => exports2.AttributeBooleanValue$, 0], [() => exports2.AttributeBooleanValue$, 0], 1, [() => exports2.AttributeBooleanValue$, 0]],
      1
    ];
    exports2.ModifyTrafficMirrorFilterNetworkServicesRequest$ = [
      3,
      n032,
      _MTMFNSR,
      0,
      [_TMFI, _ANS, _RNS, _DR],
      [0, [() => TrafficMirrorNetworkServiceList, { [_xN]: _ANSd }], [() => TrafficMirrorNetworkServiceList, { [_xN]: _RNSe }], 2],
      1
    ];
    exports2.ModifyTrafficMirrorFilterNetworkServicesResult$ = [
      3,
      n032,
      _MTMFNSRo,
      0,
      [_TMF],
      [[() => exports2.TrafficMirrorFilter$, {
        [_eQN]: `TrafficMirrorFilter`,
        [_xN]: _tMF
      }]]
    ];
    exports2.ModifyTrafficMirrorFilterRuleRequest$ = [
      3,
      n032,
      _MTMFRR,
      0,
      [_TMFRI, _TD, _RNu, _RA10, _DPRe, _SPRo, _Pr10, _DCB, _SCB, _De, _RF, _DR],
      [0, 0, 1, 0, () => exports2.TrafficMirrorPortRangeRequest$, () => exports2.TrafficMirrorPortRangeRequest$, 1, 0, 0, 0, [64 | 0, { [_xN]: _RFe }], 2],
      1
    ];
    exports2.ModifyTrafficMirrorFilterRuleResult$ = [
      3,
      n032,
      _MTMFRRo,
      0,
      [_TMFR],
      [[() => exports2.TrafficMirrorFilterRule$, {
        [_eQN]: `TrafficMirrorFilterRule`,
        [_xN]: _tMFR
      }]]
    ];
    exports2.ModifyTrafficMirrorSessionRequest$ = [
      3,
      n032,
      _MTMSR,
      0,
      [_TMSI, _TMTI, _TMFI, _PLa, _SNes, _VNI, _De, _RF, _DR],
      [0, 0, 0, 1, 1, 1, 0, [64 | 0, { [_xN]: _RFe }], 2],
      1
    ];
    exports2.ModifyTrafficMirrorSessionResult$ = [
      3,
      n032,
      _MTMSRo,
      0,
      [_TMS],
      [[() => exports2.TrafficMirrorSession$, {
        [_eQN]: `TrafficMirrorSession`,
        [_xN]: _tMS
      }]]
    ];
    exports2.ModifyTransitGatewayMeteringPolicyRequest$ = [
      3,
      n032,
      _MTGMPR,
      0,
      [_TGMPI, _AMAI, _RMAI, _DR],
      [0, [64 | 0, { [_xN]: _AMAId }], [64 | 0, { [_xN]: _RMAIe }], 2],
      1
    ];
    exports2.ModifyTransitGatewayMeteringPolicyResult$ = [
      3,
      n032,
      _MTGMPRo,
      0,
      [_TGMP],
      [[() => exports2.TransitGatewayMeteringPolicy$, {
        [_eQN]: `TransitGatewayMeteringPolicy`,
        [_xN]: _tGMP
      }]]
    ];
    exports2.ModifyTransitGatewayOptions$ = [
      3,
      n032,
      _MTGO,
      0,
      [_ATGCB, _RTGCB, _VESp, _DSn, _SGRS, _AASAu, _DRTA, _ADRTI, _DRTP, _PDRTI, _ASA, _ESn],
      [[() => TransitGatewayCidrBlockStringList, 0], [() => TransitGatewayCidrBlockStringList, 0], 0, 0, 0, 0, 0, 0, 0, 0, 1, 0]
    ];
    exports2.ModifyTransitGatewayPrefixListReferenceRequest$ = [
      3,
      n032,
      _MTGPLRR,
      0,
      [_TGRTI, _PLI, _TGAI, _Bl, _DR],
      [0, 0, 0, 2, 2],
      2
    ];
    exports2.ModifyTransitGatewayPrefixListReferenceResult$ = [
      3,
      n032,
      _MTGPLRRo,
      0,
      [_TGPLR],
      [[() => exports2.TransitGatewayPrefixListReference$, {
        [_eQN]: `TransitGatewayPrefixListReference`,
        [_xN]: _tGPLR
      }]]
    ];
    exports2.ModifyTransitGatewayRequest$ = [
      3,
      n032,
      _MTGR,
      0,
      [_TGI, _De, _Opt, _DR],
      [0, 0, [() => exports2.ModifyTransitGatewayOptions$, 0], 2],
      1
    ];
    exports2.ModifyTransitGatewayResult$ = [
      3,
      n032,
      _MTGRo,
      0,
      [_TG],
      [[() => exports2.TransitGateway$, {
        [_eQN]: `TransitGateway`,
        [_xN]: _tG
      }]]
    ];
    exports2.ModifyTransitGatewayVpcAttachmentRequest$ = [
      3,
      n032,
      _MTGVAR,
      0,
      [_TGAI, _ASId, _RSIe, _Opt, _DR],
      [0, [() => TransitGatewaySubnetIdList, 0], [() => TransitGatewaySubnetIdList, 0], () => exports2.ModifyTransitGatewayVpcAttachmentRequestOptions$, 2],
      1
    ];
    exports2.ModifyTransitGatewayVpcAttachmentRequestOptions$ = [
      3,
      n032,
      _MTGVARO,
      0,
      [_DSn, _SGRS, _ISpv, _AMS],
      [0, 0, 0, 0]
    ];
    exports2.ModifyTransitGatewayVpcAttachmentResult$ = [
      3,
      n032,
      _MTGVARo,
      0,
      [_TGVA],
      [[() => exports2.TransitGatewayVpcAttachment$, {
        [_eQN]: `TransitGatewayVpcAttachment`,
        [_xN]: _tGVA
      }]]
    ];
    exports2.ModifyVerifiedAccessEndpointCidrOptions$ = [
      3,
      n032,
      _MVAECO,
      0,
      [_PRor],
      [[() => ModifyVerifiedAccessEndpointPortRangeList, { [_xN]: _PRo }]]
    ];
    exports2.ModifyVerifiedAccessEndpointEniOptions$ = [
      3,
      n032,
      _MVAEEO,
      0,
      [_Pr10, _Po, _PRor],
      [0, 1, [() => ModifyVerifiedAccessEndpointPortRangeList, { [_xN]: _PRo }]]
    ];
    exports2.ModifyVerifiedAccessEndpointLoadBalancerOptions$ = [
      3,
      n032,
      _MVAELBO,
      0,
      [_SI10, _Pr10, _Po, _PRor],
      [[() => ModifyVerifiedAccessEndpointSubnetIdList, { [_xN]: _SIu }], 0, 1, [() => ModifyVerifiedAccessEndpointPortRangeList, { [_xN]: _PRo }]]
    ];
    exports2.ModifyVerifiedAccessEndpointPolicyRequest$ = [
      3,
      n032,
      _MVAEPR,
      0,
      [_VAEI, _PE, _PDo, _CT4, _DR, _SSs],
      [0, 2, 0, [0, 4], 2, () => exports2.VerifiedAccessSseSpecificationRequest$],
      1
    ];
    exports2.ModifyVerifiedAccessEndpointPolicyResult$ = [
      3,
      n032,
      _MVAEPRo,
      0,
      [_PE, _PDo, _SSs],
      [[2, {
        [_eQN]: `PolicyEnabled`,
        [_xN]: _pE
      }], [0, {
        [_eQN]: `PolicyDocument`,
        [_xN]: _pDo
      }], [() => exports2.VerifiedAccessSseSpecificationResponse$, {
        [_eQN]: `SseSpecification`,
        [_xN]: _sSs
      }]]
    ];
    exports2.ModifyVerifiedAccessEndpointPortRange$ = [
      3,
      n032,
      _MVAEPRod,
      0,
      [_FP, _TP],
      [1, 1]
    ];
    exports2.ModifyVerifiedAccessEndpointRdsOptions$ = [
      3,
      n032,
      _MVAERO,
      0,
      [_SI10, _Po, _RE],
      [[() => ModifyVerifiedAccessEndpointSubnetIdList, { [_xN]: _SIu }], 1, 0]
    ];
    exports2.ModifyVerifiedAccessEndpointRequest$ = [
      3,
      n032,
      _MVAER,
      0,
      [_VAEI, _VAGI, _LBO, _NIO, _De, _CT4, _DR, _ROd, _COi],
      [0, 0, [() => exports2.ModifyVerifiedAccessEndpointLoadBalancerOptions$, 0], [() => exports2.ModifyVerifiedAccessEndpointEniOptions$, 0], 0, [0, 4], 2, [() => exports2.ModifyVerifiedAccessEndpointRdsOptions$, 0], [() => exports2.ModifyVerifiedAccessEndpointCidrOptions$, 0]],
      1
    ];
    exports2.ModifyVerifiedAccessEndpointResult$ = [
      3,
      n032,
      _MVAERo,
      0,
      [_VAE],
      [[() => exports2.VerifiedAccessEndpoint$, {
        [_eQN]: `VerifiedAccessEndpoint`,
        [_xN]: _vAE
      }]]
    ];
    exports2.ModifyVerifiedAccessGroupPolicyRequest$ = [
      3,
      n032,
      _MVAGPR,
      0,
      [_VAGI, _PE, _PDo, _CT4, _DR, _SSs],
      [0, 2, 0, [0, 4], 2, () => exports2.VerifiedAccessSseSpecificationRequest$],
      1
    ];
    exports2.ModifyVerifiedAccessGroupPolicyResult$ = [
      3,
      n032,
      _MVAGPRo,
      0,
      [_PE, _PDo, _SSs],
      [[2, {
        [_eQN]: `PolicyEnabled`,
        [_xN]: _pE
      }], [0, {
        [_eQN]: `PolicyDocument`,
        [_xN]: _pDo
      }], [() => exports2.VerifiedAccessSseSpecificationResponse$, {
        [_eQN]: `SseSpecification`,
        [_xN]: _sSs
      }]]
    ];
    exports2.ModifyVerifiedAccessGroupRequest$ = [
      3,
      n032,
      _MVAGR,
      0,
      [_VAGI, _VAII, _De, _CT4, _DR],
      [0, 0, 0, [0, 4], 2],
      1
    ];
    exports2.ModifyVerifiedAccessGroupResult$ = [
      3,
      n032,
      _MVAGRo,
      0,
      [_VAG],
      [[() => exports2.VerifiedAccessGroup$, {
        [_eQN]: `VerifiedAccessGroup`,
        [_xN]: _vAG
      }]]
    ];
    exports2.ModifyVerifiedAccessInstanceLoggingConfigurationRequest$ = [
      3,
      n032,
      _MVAILCR,
      0,
      [_VAII, _ALc, _DR, _CT4],
      [0, () => exports2.VerifiedAccessLogOptions$, 2, [0, 4]],
      2
    ];
    exports2.ModifyVerifiedAccessInstanceLoggingConfigurationResult$ = [
      3,
      n032,
      _MVAILCRo,
      0,
      [_LCo],
      [[() => exports2.VerifiedAccessInstanceLoggingConfiguration$, {
        [_eQN]: `LoggingConfiguration`,
        [_xN]: _lC
      }]]
    ];
    exports2.ModifyVerifiedAccessInstanceRequest$ = [
      3,
      n032,
      _MVAIR,
      0,
      [_VAII, _De, _DR, _CT4, _CECSD],
      [0, 0, 2, [0, 4], 0],
      1
    ];
    exports2.ModifyVerifiedAccessInstanceResult$ = [
      3,
      n032,
      _MVAIRo,
      0,
      [_VAI],
      [[() => exports2.VerifiedAccessInstance$, {
        [_eQN]: `VerifiedAccessInstance`,
        [_xN]: _vAI
      }]]
    ];
    exports2.ModifyVerifiedAccessNativeApplicationOidcOptions$ = [
      3,
      n032,
      _MVANAOO,
      0,
      [_PSKE, _Is, _AE, _TEo, _UIE, _CIli, _CS4, _Sco],
      [0, 0, 0, 0, 0, 0, [() => ClientSecretType, 0], 0]
    ];
    exports2.ModifyVerifiedAccessTrustProviderDeviceOptions$ = [
      3,
      n032,
      _MVATPDO,
      0,
      [_PSKU],
      [0]
    ];
    exports2.ModifyVerifiedAccessTrustProviderOidcOptions$ = [
      3,
      n032,
      _MVATPOO,
      0,
      [_Is, _AE, _TEo, _UIE, _CIli, _CS4, _Sco],
      [0, 0, 0, 0, 0, [() => ClientSecretType, 0], 0]
    ];
    exports2.ModifyVerifiedAccessTrustProviderRequest$ = [
      3,
      n032,
      _MVATPR,
      0,
      [_VATPI, _OO, _DOev, _De, _DR, _CT4, _SSs, _NAOO],
      [0, [() => exports2.ModifyVerifiedAccessTrustProviderOidcOptions$, 0], () => exports2.ModifyVerifiedAccessTrustProviderDeviceOptions$, 0, 2, [0, 4], () => exports2.VerifiedAccessSseSpecificationRequest$, [() => exports2.ModifyVerifiedAccessNativeApplicationOidcOptions$, 0]],
      1
    ];
    exports2.ModifyVerifiedAccessTrustProviderResult$ = [
      3,
      n032,
      _MVATPRo,
      0,
      [_VATP],
      [[() => exports2.VerifiedAccessTrustProvider$, {
        [_eQN]: `VerifiedAccessTrustProvider`,
        [_xN]: _vATP
      }]]
    ];
    exports2.ModifyVolumeAttributeRequest$ = [
      3,
      n032,
      _MVAR,
      0,
      [_VIo, _AEIO, _DR],
      [0, [() => exports2.AttributeBooleanValue$, 0], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.ModifyVolumeRequest$ = [
      3,
      n032,
      _MVR,
      0,
      [_VIo, _DR, _Siz, _VT, _Io, _Th, _MAE],
      [0, 2, 1, 0, 1, 1, 2],
      1
    ];
    exports2.ModifyVolumeResult$ = [
      3,
      n032,
      _MVRo,
      0,
      [_VMo],
      [[() => exports2.VolumeModification$, {
        [_eQN]: `VolumeModification`,
        [_xN]: _vM
      }]]
    ];
    exports2.ModifyVpcAttributeRequest$ = [
      3,
      n032,
      _MVARo,
      0,
      [_VI, _EDH, _EDS, _ENAUM],
      [[0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [() => exports2.AttributeBooleanValue$, 0], [() => exports2.AttributeBooleanValue$, 0], [() => exports2.AttributeBooleanValue$, 0]],
      1
    ];
    exports2.ModifyVpcBlockPublicAccessExclusionRequest$ = [
      3,
      n032,
      _MVBPAER,
      0,
      [_EIx, _IGEM, _DR],
      [0, 0, 2],
      2
    ];
    exports2.ModifyVpcBlockPublicAccessExclusionResult$ = [
      3,
      n032,
      _MVBPAERo,
      0,
      [_VBPAE],
      [[() => exports2.VpcBlockPublicAccessExclusion$, {
        [_eQN]: `VpcBlockPublicAccessExclusion`,
        [_xN]: _vBPAE
      }]]
    ];
    exports2.ModifyVpcBlockPublicAccessOptionsRequest$ = [
      3,
      n032,
      _MVBPAOR,
      0,
      [_IGBM, _DR],
      [0, 2],
      1
    ];
    exports2.ModifyVpcBlockPublicAccessOptionsResult$ = [
      3,
      n032,
      _MVBPAORo,
      0,
      [_VBPAO],
      [[() => exports2.VpcBlockPublicAccessOptions$, {
        [_eQN]: `VpcBlockPublicAccessOptions`,
        [_xN]: _vBPAO
      }]]
    ];
    exports2.ModifyVpcEncryptionControlRequest$ = [
      3,
      n032,
      _MVECR,
      0,
      [_VECI, _DR, _Mo, _IGE4, _EOIGE, _NGE, _VPGE, _VPE, _LEam, _VLE, _EFSE],
      [0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0],
      1
    ];
    exports2.ModifyVpcEncryptionControlResult$ = [
      3,
      n032,
      _MVECRo,
      0,
      [_VEC],
      [[() => exports2.VpcEncryptionControl$, {
        [_eQN]: `VpcEncryptionControl`,
        [_xN]: _vEC
      }]]
    ];
    exports2.ModifyVpcEndpointConnectionNotificationRequest$ = [
      3,
      n032,
      _MVECNR,
      0,
      [_CNI, _DR, _CNAo, _CE],
      [0, 2, 0, [() => ValueStringList, 0]],
      1
    ];
    exports2.ModifyVpcEndpointConnectionNotificationResult$ = [
      3,
      n032,
      _MVECNRo,
      0,
      [_RV],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.ModifyVpcEndpointRequest$ = [
      3,
      n032,
      _MVER,
      0,
      [_VEIp, _DR, _RP, _PDo, _ARTI, _RRTI, _ASId, _RSIe, _ASGI, _RSGI, _IAT, _DOn, _PDE, _SC],
      [0, 2, 2, 0, [() => VpcEndpointRouteTableIdList, { [_xN]: _ARTId }], [() => VpcEndpointRouteTableIdList, { [_xN]: _RRTIe }], [() => VpcEndpointSubnetIdList, { [_xN]: _ASIdd }], [() => VpcEndpointSubnetIdList, { [_xN]: _RSIem }], [() => VpcEndpointSecurityGroupIdList, { [_xN]: _ASGId }], [() => VpcEndpointSecurityGroupIdList, { [_xN]: _RSGIe }], 0, [() => exports2.DnsOptionsSpecification$, 0], 2, [() => SubnetConfigurationsList, { [_xN]: _SCu }]],
      1
    ];
    exports2.ModifyVpcEndpointResult$ = [
      3,
      n032,
      _MVERo,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.ModifyVpcEndpointServiceConfigurationRequest$ = [
      3,
      n032,
      _MVESCR,
      0,
      [_SIe, _DR, _PDN, _RPDN, _ARc, _ANLBA, _RNLBA, _AGLBA, _RGLBA, _ASIAT, _RSIAT, _ASR, _RSR],
      [0, 2, 0, 2, 2, [() => ValueStringList, { [_xN]: _ANLBAd }], [() => ValueStringList, { [_xN]: _RNLBAe }], [() => ValueStringList, { [_xN]: _AGLBAd }], [() => ValueStringList, { [_xN]: _RGLBAe }], [() => ValueStringList, { [_xN]: _ASIATd }], [() => ValueStringList, { [_xN]: _RSIATe }], [() => ValueStringList, { [_xN]: _ASRd }], [() => ValueStringList, { [_xN]: _RSRe }]],
      1
    ];
    exports2.ModifyVpcEndpointServiceConfigurationResult$ = [
      3,
      n032,
      _MVESCRo,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.ModifyVpcEndpointServicePayerResponsibilityRequest$ = [
      3,
      n032,
      _MVESPRR,
      0,
      [_SIe, _PRa, _DR],
      [0, 0, 2],
      2
    ];
    exports2.ModifyVpcEndpointServicePayerResponsibilityResult$ = [
      3,
      n032,
      _MVESPRRo,
      0,
      [_RV],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.ModifyVpcEndpointServicePermissionsRequest$ = [
      3,
      n032,
      _MVESPR,
      0,
      [_SIe, _DR, _AAP, _RAP],
      [0, 2, [() => ValueStringList, 0], [() => ValueStringList, 0]],
      1
    ];
    exports2.ModifyVpcEndpointServicePermissionsResult$ = [
      3,
      n032,
      _MVESPRo,
      0,
      [_APd, _RV],
      [[() => AddedPrincipalSet, {
        [_eQN]: `AddedPrincipalSet`,
        [_xN]: _aPS
      }], [2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.ModifyVpcPeeringConnectionOptionsRequest$ = [
      3,
      n032,
      _MVPCOR,
      0,
      [_VPCI, _APCO, _DR, _RPCO],
      [0, () => exports2.PeeringConnectionOptionsRequest$, 2, () => exports2.PeeringConnectionOptionsRequest$],
      1
    ];
    exports2.ModifyVpcPeeringConnectionOptionsResult$ = [
      3,
      n032,
      _MVPCORo,
      0,
      [_APCO, _RPCO],
      [[() => exports2.PeeringConnectionOptions$, {
        [_eQN]: `AccepterPeeringConnectionOptions`,
        [_xN]: _aPCO
      }], [() => exports2.PeeringConnectionOptions$, {
        [_eQN]: `RequesterPeeringConnectionOptions`,
        [_xN]: _rPCO
      }]]
    ];
    exports2.ModifyVpcTenancyRequest$ = [
      3,
      n032,
      _MVTR,
      0,
      [_VI, _ITns, _DR],
      [0, 0, 2],
      2
    ];
    exports2.ModifyVpcTenancyResult$ = [
      3,
      n032,
      _MVTRo,
      0,
      [_RV],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.ModifyVpnConnectionOptionsRequest$ = [
      3,
      n032,
      _MVCOR,
      0,
      [_VCIp, _LINC, _RINC, _LINCo, _RINCe, _DR],
      [0, 0, 0, 0, 0, 2],
      1
    ];
    exports2.ModifyVpnConnectionOptionsResult$ = [
      3,
      n032,
      _MVCORo,
      0,
      [_VCp],
      [[() => exports2.VpnConnection$, {
        [_eQN]: `VpnConnection`,
        [_xN]: _vCp
      }]]
    ];
    exports2.ModifyVpnConnectionRequest$ = [
      3,
      n032,
      _MVCR,
      0,
      [_VCIp, _TGI, _CGIu, _VGI, _DR],
      [0, 0, 0, 0, 2],
      1
    ];
    exports2.ModifyVpnConnectionResult$ = [
      3,
      n032,
      _MVCRo,
      0,
      [_VCp],
      [[() => exports2.VpnConnection$, {
        [_eQN]: `VpnConnection`,
        [_xN]: _vCp
      }]]
    ];
    exports2.ModifyVpnTunnelCertificateRequest$ = [
      3,
      n032,
      _MVTCR,
      0,
      [_VCIp, _VTOIA, _DR],
      [0, 0, 2],
      2
    ];
    exports2.ModifyVpnTunnelCertificateResult$ = [
      3,
      n032,
      _MVTCRo,
      0,
      [_VCp],
      [[() => exports2.VpnConnection$, {
        [_eQN]: `VpnConnection`,
        [_xN]: _vCp
      }]]
    ];
    exports2.ModifyVpnTunnelOptionsRequest$ = [
      3,
      n032,
      _MVTOR,
      0,
      [_VCIp, _VTOIA, _TO, _DR, _STRk, _PSKS],
      [0, 0, [() => exports2.ModifyVpnTunnelOptionsSpecification$, 0], 2, 2, 0],
      3
    ];
    exports2.ModifyVpnTunnelOptionsResult$ = [
      3,
      n032,
      _MVTORo,
      0,
      [_VCp],
      [[() => exports2.VpnConnection$, {
        [_eQN]: `VpnConnection`,
        [_xN]: _vCp
      }]]
    ];
    exports2.ModifyVpnTunnelOptionsSpecification$ = [
      3,
      n032,
      _MVTOS,
      8,
      [_TICu, _TIIC, _PSK, _PLS, _PLSh, _RMTS, _RFP, _RWS, _DPDTS, _DPDTA, _PEAha, _PEAhas, _PIAha, _PIAhas, _PDHGN, _PDHGNh, _IKEVe, _SAt, _LO, _ETLC],
      [0, 0, [() => preSharedKey, 0], 1, 1, 1, 1, 1, 1, 0, [() => Phase1EncryptionAlgorithmsRequestList, { [_xN]: _PEA }], [() => Phase2EncryptionAlgorithmsRequestList, { [_xN]: _PEAh }], [() => Phase1IntegrityAlgorithmsRequestList, { [_xN]: _PIA }], [() => Phase2IntegrityAlgorithmsRequestList, { [_xN]: _PIAh }], [() => Phase1DHGroupNumbersRequestList, { [_xN]: _PDHGNha }], [() => Phase2DHGroupNumbersRequestList, { [_xN]: _PDHGNhas }], [() => IKEVersionsRequestList, { [_xN]: _IKEVer }], 0, () => exports2.VpnTunnelLogOptionsSpecification$, 2]
    ];
    exports2.Monitoring$ = [
      3,
      n032,
      _Mon,
      0,
      [_St],
      [[0, {
        [_eQN]: `State`,
        [_xN]: _st
      }]]
    ];
    exports2.MonitorInstancesRequest$ = [
      3,
      n032,
      _MIRon,
      0,
      [_IIns, _DR],
      [[() => InstanceIdStringList, { [_xN]: _II2 }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.MonitorInstancesResult$ = [
      3,
      n032,
      _MIRoni,
      0,
      [_IMns],
      [[() => InstanceMonitoringList, {
        [_eQN]: `InstancesSet`,
        [_xN]: _iSn
      }]]
    ];
    exports2.MoveAddressToVpcRequest$ = [
      3,
      n032,
      _MATVR,
      0,
      [_PI10, _DR],
      [[0, {
        [_eQN]: `PublicIp`,
        [_xN]: _pI
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.MoveAddressToVpcResult$ = [
      3,
      n032,
      _MATVRo,
      0,
      [_AIl, _Sta],
      [[0, {
        [_eQN]: `AllocationId`,
        [_xN]: _aI10
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }]]
    ];
    exports2.MoveByoipCidrToIpamRequest$ = [
      3,
      n032,
      _MBCTIR,
      0,
      [_Ci, _IPI2, _IPO, _DR],
      [0, 0, 0, 2],
      3
    ];
    exports2.MoveByoipCidrToIpamResult$ = [
      3,
      n032,
      _MBCTIRo,
      0,
      [_BC],
      [[() => exports2.ByoipCidr$, {
        [_eQN]: `ByoipCidr`,
        [_xN]: _bC
      }]]
    ];
    exports2.MoveCapacityReservationInstancesRequest$ = [
      3,
      n032,
      _MCRIR,
      0,
      [_SCRI, _DCRI, _IC, _DR, _CT4],
      [0, 0, 1, 2, [0, 4]],
      3
    ];
    exports2.MoveCapacityReservationInstancesResult$ = [
      3,
      n032,
      _MCRIRo,
      0,
      [_SCR, _DCR, _IC],
      [[() => exports2.CapacityReservation$, {
        [_eQN]: `SourceCapacityReservation`,
        [_xN]: _sCR
      }], [() => exports2.CapacityReservation$, {
        [_eQN]: `DestinationCapacityReservation`,
        [_xN]: _dCR
      }], [1, {
        [_eQN]: `InstanceCount`,
        [_xN]: _iC
      }]]
    ];
    exports2.MovingAddressStatus$ = [
      3,
      n032,
      _MASo,
      0,
      [_MSo, _PI10],
      [[0, {
        [_eQN]: `MoveStatus`,
        [_xN]: _mSo
      }], [0, {
        [_eQN]: `PublicIp`,
        [_xN]: _pI
      }]]
    ];
    exports2.NatGateway$ = [
      3,
      n032,
      _NG,
      0,
      [_CTr, _DTel, _FCa, _FM, _NGA, _NGI, _PB, _St, _SIu, _VI, _T10, _CTon, _AMv, _ASIu, _APZ, _AAt, _RTI],
      [[4, {
        [_eQN]: `CreateTime`,
        [_xN]: _cTr
      }], [4, {
        [_eQN]: `DeleteTime`,
        [_xN]: _dTel
      }], [0, {
        [_eQN]: `FailureCode`,
        [_xN]: _fCa
      }], [0, {
        [_eQN]: `FailureMessage`,
        [_xN]: _fM
      }], [() => NatGatewayAddressList, {
        [_eQN]: `NatGatewayAddressSet`,
        [_xN]: _nGAS
      }], [0, {
        [_eQN]: `NatGatewayId`,
        [_xN]: _nGI
      }], [() => exports2.ProvisionedBandwidth$, {
        [_eQN]: `ProvisionedBandwidth`,
        [_xN]: _pB
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `ConnectivityType`,
        [_xN]: _cTonn
      }], [0, {
        [_eQN]: `AvailabilityMode`,
        [_xN]: _aM
      }], [0, {
        [_eQN]: `AutoScalingIps`,
        [_xN]: _aSI
      }], [0, {
        [_eQN]: `AutoProvisionZones`,
        [_xN]: _aPZ
      }], [() => NatGatewayAttachedApplianceList, {
        [_eQN]: `AttachedApplianceSet`,
        [_xN]: _aASt
      }], [0, {
        [_eQN]: `RouteTableId`,
        [_xN]: _rTI
      }]]
    ];
    exports2.NatGatewayAddress$ = [
      3,
      n032,
      _NGAa,
      0,
      [_AIl, _NII, _PIri, _PI10, _AIs, _IPsr, _FM, _Sta, _AZ, _AZI],
      [[0, {
        [_eQN]: `AllocationId`,
        [_xN]: _aI10
      }], [0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], [0, {
        [_eQN]: `PrivateIp`,
        [_xN]: _pIriv
      }], [0, {
        [_eQN]: `PublicIp`,
        [_xN]: _pI
      }], [0, {
        [_eQN]: `AssociationId`,
        [_xN]: _aIs
      }], [2, {
        [_eQN]: `IsPrimary`,
        [_xN]: _iPsr
      }], [0, {
        [_eQN]: `FailureMessage`,
        [_xN]: _fM
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }]]
    ];
    exports2.NatGatewayAttachedAppliance$ = [
      3,
      n032,
      _NGAA,
      0,
      [_Ty, _AAp, _VEIp, _AStta, _MSod, _FCa, _FM],
      [[0, {
        [_eQN]: `Type`,
        [_xN]: _ty
      }], [0, {
        [_eQN]: `ApplianceArn`,
        [_xN]: _aAp
      }], [0, {
        [_eQN]: `VpcEndpointId`,
        [_xN]: _vEI
      }], [0, {
        [_eQN]: `AttachmentState`,
        [_xN]: _aStt
      }], [0, {
        [_eQN]: `ModificationState`,
        [_xN]: _mSod
      }], [0, {
        [_eQN]: `FailureCode`,
        [_xN]: _fCa
      }], [0, {
        [_eQN]: `FailureMessage`,
        [_xN]: _fM
      }]]
    ];
    exports2.NativeApplicationOidcOptions$ = [
      3,
      n032,
      _NAOO,
      0,
      [_PSKE, _Is, _AE, _TEo, _UIE, _CIli, _Sco],
      [[0, {
        [_eQN]: `PublicSigningKeyEndpoint`,
        [_xN]: _pSKE
      }], [0, {
        [_eQN]: `Issuer`,
        [_xN]: _is
      }], [0, {
        [_eQN]: `AuthorizationEndpoint`,
        [_xN]: _aE
      }], [0, {
        [_eQN]: `TokenEndpoint`,
        [_xN]: _tEo
      }], [0, {
        [_eQN]: `UserInfoEndpoint`,
        [_xN]: _uIE
      }], [0, {
        [_eQN]: `ClientId`,
        [_xN]: _cIli
      }], [0, {
        [_eQN]: `Scope`,
        [_xN]: _sco
      }]]
    ];
    exports2.NetworkAcl$ = [
      3,
      n032,
      _NA,
      0,
      [_As, _Ent, _IDs, _NAI, _T10, _VI, _OI],
      [[() => NetworkAclAssociationList, {
        [_eQN]: `AssociationSet`,
        [_xN]: _aSss
      }], [() => NetworkAclEntryList, {
        [_eQN]: `EntrySet`,
        [_xN]: _eSnt
      }], [2, {
        [_eQN]: `Default`,
        [_xN]: _def
      }], [0, {
        [_eQN]: `NetworkAclId`,
        [_xN]: _nAI
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }]]
    ];
    exports2.NetworkAclAssociation$ = [
      3,
      n032,
      _NAA,
      0,
      [_NAAI, _NAI, _SIu],
      [[0, {
        [_eQN]: `NetworkAclAssociationId`,
        [_xN]: _nAAI
      }], [0, {
        [_eQN]: `NetworkAclId`,
        [_xN]: _nAI
      }], [0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }]]
    ];
    exports2.NetworkAclEntry$ = [
      3,
      n032,
      _NAE2,
      0,
      [_CB, _E11, _ITC, _ICB, _PRo, _Pr10, _RA10, _RNu],
      [[0, {
        [_eQN]: `CidrBlock`,
        [_xN]: _cB
      }], [2, {
        [_eQN]: `Egress`,
        [_xN]: _e32
      }], [() => exports2.IcmpTypeCode$, {
        [_eQN]: `IcmpTypeCode`,
        [_xN]: _iTC
      }], [0, {
        [_eQN]: `Ipv6CidrBlock`,
        [_xN]: _iCB
      }], [() => exports2.PortRange$, {
        [_eQN]: `PortRange`,
        [_xN]: _pRo
      }], [0, {
        [_eQN]: `Protocol`,
        [_xN]: _pr
      }], [0, {
        [_eQN]: `RuleAction`,
        [_xN]: _rA
      }], [1, {
        [_eQN]: `RuleNumber`,
        [_xN]: _rN10
      }]]
    ];
    exports2.NetworkBandwidthGbps$ = [
      3,
      n032,
      _NBGe,
      0,
      [_M, _Ma],
      [[1, {
        [_eQN]: `Min`,
        [_xN]: _m29
      }], [1, {
        [_eQN]: `Max`,
        [_xN]: _ma
      }]]
    ];
    exports2.NetworkBandwidthGbpsRequest$ = [
      3,
      n032,
      _NBGR,
      0,
      [_M, _Ma],
      [1, 1]
    ];
    exports2.NetworkCardInfo$ = [
      3,
      n032,
      _NCIe,
      0,
      [_NCI, _NPe, _MNI, _AFNI, _BBIG, _PBIG, _DEQCPI, _MEQC, _MEQCPI],
      [[1, {
        [_eQN]: `NetworkCardIndex`,
        [_xN]: _nCI
      }], [0, {
        [_eQN]: `NetworkPerformance`,
        [_xN]: _nPe
      }], [1, {
        [_eQN]: `MaximumNetworkInterfaces`,
        [_xN]: _mNI
      }], [1, {
        [_eQN]: `AdditionalFlexibleNetworkInterfaces`,
        [_xN]: _aFNI
      }], [1, {
        [_eQN]: `BaselineBandwidthInGbps`,
        [_xN]: _bBIG
      }], [1, {
        [_eQN]: `PeakBandwidthInGbps`,
        [_xN]: _pBIG
      }], [1, {
        [_eQN]: `DefaultEnaQueueCountPerInterface`,
        [_xN]: _dEQCPI
      }], [1, {
        [_eQN]: `MaximumEnaQueueCount`,
        [_xN]: _mEQC
      }], [1, {
        [_eQN]: `MaximumEnaQueueCountPerInterface`,
        [_xN]: _mEQCPI
      }]]
    ];
    exports2.NetworkInfo$ = [
      3,
      n032,
      _NIetw,
      0,
      [_NPe, _MNI, _MNC, _DNCI, _NC, _IAPI, _IAPIp, _ISpvu, _ESna, _ESf, _EIf, _EITS, _ESSn, _BWa, _FEQS, _CTC, _SNSe, _MSNI, _IAPSI],
      [[0, {
        [_eQN]: `NetworkPerformance`,
        [_xN]: _nPe
      }], [1, {
        [_eQN]: `MaximumNetworkInterfaces`,
        [_xN]: _mNI
      }], [1, {
        [_eQN]: `MaximumNetworkCards`,
        [_xN]: _mNC
      }], [1, {
        [_eQN]: `DefaultNetworkCardIndex`,
        [_xN]: _dNCI
      }], [() => NetworkCardInfoList, {
        [_eQN]: `NetworkCards`,
        [_xN]: _nC
      }], [1, {
        [_eQN]: `Ipv4AddressesPerInterface`,
        [_xN]: _iAPI
      }], [1, {
        [_eQN]: `Ipv6AddressesPerInterface`,
        [_xN]: _iAPIp
      }], [2, {
        [_eQN]: `Ipv6Supported`,
        [_xN]: _iSpv
      }], [0, {
        [_eQN]: `EnaSupport`,
        [_xN]: _eSna
      }], [2, {
        [_eQN]: `EfaSupported`,
        [_xN]: _eSf
      }], [() => exports2.EfaInfo$, {
        [_eQN]: `EfaInfo`,
        [_xN]: _eIf
      }], [2, {
        [_eQN]: `EncryptionInTransitSupported`,
        [_xN]: _eITSn
      }], [2, {
        [_eQN]: `EnaSrdSupported`,
        [_xN]: _eSSn
      }], [() => BandwidthWeightingTypeList, {
        [_eQN]: `BandwidthWeightings`,
        [_xN]: _bWa
      }], [0, {
        [_eQN]: `FlexibleEnaQueuesSupport`,
        [_xN]: _fEQS
      }], [() => exports2.DefaultConnectionTrackingConfiguration$, {
        [_eQN]: `ConnectionTrackingConfiguration`,
        [_xN]: _cTC
      }], [2, {
        [_eQN]: `SecondaryNetworkSupported`,
        [_xN]: _sNSec
      }], [1, {
        [_eQN]: `MaximumSecondaryNetworkInterfaces`,
        [_xN]: _mSNI
      }], [1, {
        [_eQN]: `Ipv4AddressesPerSecondaryInterface`,
        [_xN]: _iAPSI
      }]]
    ];
    exports2.NetworkInsightsAccessScope$ = [
      3,
      n032,
      _NIAS,
      0,
      [_NIASI, _NIASAe, _CDre, _UDp, _T10],
      [[0, {
        [_eQN]: `NetworkInsightsAccessScopeId`,
        [_xN]: _nIASI
      }], [0, {
        [_eQN]: `NetworkInsightsAccessScopeArn`,
        [_xN]: _nIASA
      }], [4, {
        [_eQN]: `CreatedDate`,
        [_xN]: _cDre
      }], [4, {
        [_eQN]: `UpdatedDate`,
        [_xN]: _uDp
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.NetworkInsightsAccessScopeAnalysis$ = [
      3,
      n032,
      _NIASAet,
      0,
      [_NIASAI, _NIASAA, _NIASI, _Sta, _SMt, _WM, _SD, _ED, _FFi, _AEC, _T10],
      [[0, {
        [_eQN]: `NetworkInsightsAccessScopeAnalysisId`,
        [_xN]: _nIASAI
      }], [0, {
        [_eQN]: `NetworkInsightsAccessScopeAnalysisArn`,
        [_xN]: _nIASAA
      }], [0, {
        [_eQN]: `NetworkInsightsAccessScopeId`,
        [_xN]: _nIASI
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `StatusMessage`,
        [_xN]: _sMt
      }], [0, {
        [_eQN]: `WarningMessage`,
        [_xN]: _wM
      }], [4, {
        [_eQN]: `StartDate`,
        [_xN]: _sD
      }], [4, {
        [_eQN]: `EndDate`,
        [_xN]: _eD
      }], [0, {
        [_eQN]: `FindingsFound`,
        [_xN]: _fFi
      }], [1, {
        [_eQN]: `AnalyzedEniCount`,
        [_xN]: _aEC
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.NetworkInsightsAccessScopeContent$ = [
      3,
      n032,
      _NIASC,
      0,
      [_NIASI, _MP, _EPx],
      [[0, {
        [_eQN]: `NetworkInsightsAccessScopeId`,
        [_xN]: _nIASI
      }], [() => AccessScopePathList, {
        [_eQN]: `MatchPathSet`,
        [_xN]: _mPSa
      }], [() => AccessScopePathList, {
        [_eQN]: `ExcludePathSet`,
        [_xN]: _ePS
      }]]
    ];
    exports2.NetworkInsightsAnalysis$ = [
      3,
      n032,
      _NIAe,
      0,
      [_NIAI, _NIAA, _NIPI, _AAdd, _FIAi, _FOA, _SD, _Sta, _SMt, _WM, _NPF, _FPC, _RPC, _Exp, _APHl, _SAu, _T10],
      [[0, {
        [_eQN]: `NetworkInsightsAnalysisId`,
        [_xN]: _nIAI
      }], [0, {
        [_eQN]: `NetworkInsightsAnalysisArn`,
        [_xN]: _nIAA
      }], [0, {
        [_eQN]: `NetworkInsightsPathId`,
        [_xN]: _nIPI
      }], [() => ValueStringList, {
        [_eQN]: `AdditionalAccountSet`,
        [_xN]: _aASd
      }], [() => ArnList, {
        [_eQN]: `FilterInArnSet`,
        [_xN]: _fIAS
      }], [() => ArnList, {
        [_eQN]: `FilterOutArnSet`,
        [_xN]: _fOAS
      }], [4, {
        [_eQN]: `StartDate`,
        [_xN]: _sD
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `StatusMessage`,
        [_xN]: _sMt
      }], [0, {
        [_eQN]: `WarningMessage`,
        [_xN]: _wM
      }], [2, {
        [_eQN]: `NetworkPathFound`,
        [_xN]: _nPF
      }], [() => PathComponentList, {
        [_eQN]: `ForwardPathComponentSet`,
        [_xN]: _fPCS
      }], [() => PathComponentList, {
        [_eQN]: `ReturnPathComponentSet`,
        [_xN]: _rPCS
      }], [() => ExplanationList, {
        [_eQN]: `ExplanationSet`,
        [_xN]: _eSx
      }], [() => AlternatePathHintList, {
        [_eQN]: `AlternatePathHintSet`,
        [_xN]: _aPHS
      }], [() => ValueStringList, {
        [_eQN]: `SuggestedAccountSet`,
        [_xN]: _sASu
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.NetworkInsightsPath$ = [
      3,
      n032,
      _NIP,
      0,
      [_NIPI, _NIPA, _CDre, _S, _D, _SAo, _DAes, _SIo, _DIe, _Pr10, _DPe, _T10, _FAS, _FAD],
      [[0, {
        [_eQN]: `NetworkInsightsPathId`,
        [_xN]: _nIPI
      }], [0, {
        [_eQN]: `NetworkInsightsPathArn`,
        [_xN]: _nIPA
      }], [4, {
        [_eQN]: `CreatedDate`,
        [_xN]: _cDre
      }], [0, {
        [_eQN]: `Source`,
        [_xN]: _so
      }], [0, {
        [_eQN]: `Destination`,
        [_xN]: _d
      }], [0, {
        [_eQN]: `SourceArn`,
        [_xN]: _sA
      }], [0, {
        [_eQN]: `DestinationArn`,
        [_xN]: _dA
      }], [0, {
        [_eQN]: `SourceIp`,
        [_xN]: _sIo
      }], [0, {
        [_eQN]: `DestinationIp`,
        [_xN]: _dIe
      }], [0, {
        [_eQN]: `Protocol`,
        [_xN]: _pr
      }], [1, {
        [_eQN]: `DestinationPort`,
        [_xN]: _dPes
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [() => exports2.PathFilter$, {
        [_eQN]: `FilterAtSource`,
        [_xN]: _fAS
      }], [() => exports2.PathFilter$, {
        [_eQN]: `FilterAtDestination`,
        [_xN]: _fAD
      }]]
    ];
    exports2.NetworkInterface$ = [
      3,
      n032,
      _NIe,
      0,
      [_Ass, _Att, _AZ, _CTC, _De, _G, _ITnt, _IA, _MAa, _NII, _OA, _OI, _PDN, _PDNub, _PIDNO, _PIAr, _PIAri, _IPpvr, _IPp, _RIeq, _RMeq, _SDC, _Sta, _SIu, _TSag, _VI, _DAIT, _IN, _IApv, _Op, _ASss, _AZI],
      [[() => exports2.NetworkInterfaceAssociation$, {
        [_eQN]: `Association`,
        [_xN]: _ass
      }], [() => exports2.NetworkInterfaceAttachment$, {
        [_eQN]: `Attachment`,
        [_xN]: _at
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [() => exports2.ConnectionTrackingConfiguration$, {
        [_eQN]: `ConnectionTrackingConfiguration`,
        [_xN]: _cTC
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [() => GroupIdentifierList, {
        [_eQN]: `GroupSet`,
        [_xN]: _gSr
      }], [0, {
        [_eQN]: `InterfaceType`,
        [_xN]: _iTnt
      }], [() => NetworkInterfaceIpv6AddressesList, {
        [_eQN]: `Ipv6AddressesSet`,
        [_xN]: _iASp
      }], [0, {
        [_eQN]: `MacAddress`,
        [_xN]: _mAa
      }], [0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], [0, {
        [_eQN]: `OutpostArn`,
        [_xN]: _oA
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `PrivateDnsName`,
        [_xN]: _pDNr
      }], [0, {
        [_eQN]: `PublicDnsName`,
        [_xN]: _pDNu
      }], [() => exports2.PublicIpDnsNameOptions$, {
        [_eQN]: `PublicIpDnsNameOptions`,
        [_xN]: _pIDNO
      }], [0, {
        [_eQN]: `PrivateIpAddress`,
        [_xN]: _pIAr
      }], [() => NetworkInterfacePrivateIpAddressList, {
        [_eQN]: `PrivateIpAddressesSet`,
        [_xN]: _pIAS
      }], [() => Ipv4PrefixesList, {
        [_eQN]: `Ipv4PrefixSet`,
        [_xN]: _iPSpvr
      }], [() => Ipv6PrefixesList, {
        [_eQN]: `Ipv6PrefixSet`,
        [_xN]: _iPSpvre
      }], [0, {
        [_eQN]: `RequesterId`,
        [_xN]: _rIeq
      }], [2, {
        [_eQN]: `RequesterManaged`,
        [_xN]: _rMeq
      }], [2, {
        [_eQN]: `SourceDestCheck`,
        [_xN]: _sDC
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [2, {
        [_eQN]: `DenyAllIgwTraffic`,
        [_xN]: _dAIT
      }], [2, {
        [_eQN]: `Ipv6Native`,
        [_xN]: _iN
      }], [0, {
        [_eQN]: `Ipv6Address`,
        [_xN]: _iApv
      }], [() => exports2.OperatorResponse$, {
        [_eQN]: `Operator`,
        [_xN]: _ope
      }], [() => AssociatedSubnetList, {
        [_eQN]: `AssociatedSubnetSet`,
        [_xN]: _aSSs
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }]]
    ];
    exports2.NetworkInterfaceAssociation$ = [
      3,
      n032,
      _NIAet,
      0,
      [_AIl, _AIs, _IOI, _PDNub, _PI10, _COI, _CI],
      [[0, {
        [_eQN]: `AllocationId`,
        [_xN]: _aI10
      }], [0, {
        [_eQN]: `AssociationId`,
        [_xN]: _aIs
      }], [0, {
        [_eQN]: `IpOwnerId`,
        [_xN]: _iOIp
      }], [0, {
        [_eQN]: `PublicDnsName`,
        [_xN]: _pDNu
      }], [0, {
        [_eQN]: `PublicIp`,
        [_xN]: _pI
      }], [0, {
        [_eQN]: `CustomerOwnedIp`,
        [_xN]: _cOI
      }], [0, {
        [_eQN]: `CarrierIp`,
        [_xN]: _cI13
      }]]
    ];
    exports2.NetworkInterfaceAttachment$ = [
      3,
      n032,
      _NIAetw,
      0,
      [_ATtt, _AItt, _DOT, _DI, _NCI, _II2, _IOIn, _Sta, _ESS, _EQC],
      [[4, {
        [_eQN]: `AttachTime`,
        [_xN]: _aTt
      }], [0, {
        [_eQN]: `AttachmentId`,
        [_xN]: _aIt
      }], [2, {
        [_eQN]: `DeleteOnTermination`,
        [_xN]: _dOT
      }], [1, {
        [_eQN]: `DeviceIndex`,
        [_xN]: _dI
      }], [1, {
        [_eQN]: `NetworkCardIndex`,
        [_xN]: _nCI
      }], [0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `InstanceOwnerId`,
        [_xN]: _iOIn
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [() => exports2.AttachmentEnaSrdSpecification$, {
        [_eQN]: `EnaSrdSpecification`,
        [_xN]: _eSS
      }], [1, {
        [_eQN]: `EnaQueueCount`,
        [_xN]: _eQC
      }]]
    ];
    exports2.NetworkInterfaceAttachmentChanges$ = [
      3,
      n032,
      _NIAC,
      0,
      [_DEQC, _EQC, _AItt, _DOT],
      [2, 1, [0, {
        [_eQN]: `AttachmentId`,
        [_xN]: _aIt
      }], [2, {
        [_eQN]: `DeleteOnTermination`,
        [_xN]: _dOT
      }]]
    ];
    exports2.NetworkInterfaceCount$ = [
      3,
      n032,
      _NIC,
      0,
      [_M, _Ma],
      [[1, {
        [_eQN]: `Min`,
        [_xN]: _m29
      }], [1, {
        [_eQN]: `Max`,
        [_xN]: _ma
      }]]
    ];
    exports2.NetworkInterfaceCountRequest$ = [
      3,
      n032,
      _NICR,
      0,
      [_M, _Ma],
      [1, 1]
    ];
    exports2.NetworkInterfaceIpv6Address$ = [
      3,
      n032,
      _NIIA,
      0,
      [_IApv, _PIDN, _IPIs],
      [[0, {
        [_eQN]: `Ipv6Address`,
        [_xN]: _iApv
      }], [0, {
        [_eQN]: `PublicIpv6DnsName`,
        [_xN]: _pIDN
      }], [2, {
        [_eQN]: `IsPrimaryIpv6`,
        [_xN]: _iPIs
      }]]
    ];
    exports2.NetworkInterfacePermission$ = [
      3,
      n032,
      _NIPetw,
      0,
      [_NIPIe, _NII, _AAI, _ASw, _Pe, _PSe],
      [[0, {
        [_eQN]: `NetworkInterfacePermissionId`,
        [_xN]: _nIPIe
      }], [0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], [0, {
        [_eQN]: `AwsAccountId`,
        [_xN]: _aAI
      }], [0, {
        [_eQN]: `AwsService`,
        [_xN]: _aSw
      }], [0, {
        [_eQN]: `Permission`,
        [_xN]: _per
      }], [() => exports2.NetworkInterfacePermissionState$, {
        [_eQN]: `PermissionState`,
        [_xN]: _pSe
      }]]
    ];
    exports2.NetworkInterfacePermissionState$ = [
      3,
      n032,
      _NIPS,
      0,
      [_St, _SMt],
      [[0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `StatusMessage`,
        [_xN]: _sMt
      }]]
    ];
    exports2.NetworkInterfacePrivateIpAddress$ = [
      3,
      n032,
      _NIPIA,
      0,
      [_Ass, _Prim, _PDN, _PIAr],
      [[() => exports2.NetworkInterfaceAssociation$, {
        [_eQN]: `Association`,
        [_xN]: _ass
      }], [2, {
        [_eQN]: `Primary`,
        [_xN]: _prim
      }], [0, {
        [_eQN]: `PrivateDnsName`,
        [_xN]: _pDNr
      }], [0, {
        [_eQN]: `PrivateIpAddress`,
        [_xN]: _pIAr
      }]]
    ];
    exports2.NeuronDeviceCoreInfo$ = [
      3,
      n032,
      _NDCI,
      0,
      [_Cou, _Ver],
      [[1, {
        [_eQN]: `Count`,
        [_xN]: _cou
      }], [1, {
        [_eQN]: `Version`,
        [_xN]: _ve
      }]]
    ];
    exports2.NeuronDeviceInfo$ = [
      3,
      n032,
      _NDI,
      0,
      [_Cou, _N, _CIor, _MIe],
      [[1, {
        [_eQN]: `Count`,
        [_xN]: _cou
      }], [0, {
        [_eQN]: `Name`,
        [_xN]: _n
      }], [() => exports2.NeuronDeviceCoreInfo$, {
        [_eQN]: `CoreInfo`,
        [_xN]: _cIor
      }], [() => exports2.NeuronDeviceMemoryInfo$, {
        [_eQN]: `MemoryInfo`,
        [_xN]: _mIe
      }]]
    ];
    exports2.NeuronDeviceMemoryInfo$ = [
      3,
      n032,
      _NDMI,
      0,
      [_SIMB],
      [[1, {
        [_eQN]: `SizeInMiB`,
        [_xN]: _sIMB
      }]]
    ];
    exports2.NeuronInfo$ = [
      3,
      n032,
      _NIeu,
      0,
      [_NDe, _TNDMIMB],
      [[() => NeuronDeviceInfoList, {
        [_eQN]: `NeuronDevices`,
        [_xN]: _nDe
      }], [1, {
        [_eQN]: `TotalNeuronDeviceMemoryInMiB`,
        [_xN]: _tNDMIMB
      }]]
    ];
    exports2.NewDhcpConfiguration$ = [
      3,
      n032,
      _NDC,
      0,
      [_K10, _Va],
      [[0, {
        [_eQN]: `Key`,
        [_xN]: _k
      }], [() => ValueStringList, { [_xN]: _V10 }]]
    ];
    exports2.NitroTpmInfo$ = [
      3,
      n032,
      _NTI,
      0,
      [_SVu],
      [[() => NitroTpmSupportedVersionsList, {
        [_eQN]: `SupportedVersions`,
        [_xN]: _sVu
      }]]
    ];
    exports2.OidcOptions$ = [
      3,
      n032,
      _OO,
      0,
      [_Is, _AE, _TEo, _UIE, _CIli, _CS4, _Sco],
      [[0, {
        [_eQN]: `Issuer`,
        [_xN]: _is
      }], [0, {
        [_eQN]: `AuthorizationEndpoint`,
        [_xN]: _aE
      }], [0, {
        [_eQN]: `TokenEndpoint`,
        [_xN]: _tEo
      }], [0, {
        [_eQN]: `UserInfoEndpoint`,
        [_xN]: _uIE
      }], [0, {
        [_eQN]: `ClientId`,
        [_xN]: _cIli
      }], [() => ClientSecretType, {
        [_eQN]: `ClientSecret`,
        [_xN]: _cSl
      }], [0, {
        [_eQN]: `Scope`,
        [_xN]: _sco
      }]]
    ];
    exports2.OnDemandOptions$ = [
      3,
      n032,
      _ODO,
      0,
      [_ASl, _CRO, _SITi, _SAZ, _MTC, _MTP],
      [[0, {
        [_eQN]: `AllocationStrategy`,
        [_xN]: _aSl
      }], [() => exports2.CapacityReservationOptions$, {
        [_eQN]: `CapacityReservationOptions`,
        [_xN]: _cRO
      }], [2, {
        [_eQN]: `SingleInstanceType`,
        [_xN]: _sITi
      }], [2, {
        [_eQN]: `SingleAvailabilityZone`,
        [_xN]: _sAZ
      }], [1, {
        [_eQN]: `MinTargetCapacity`,
        [_xN]: _mTC
      }], [0, {
        [_eQN]: `MaxTotalPrice`,
        [_xN]: _mTP
      }]]
    ];
    exports2.OnDemandOptionsRequest$ = [
      3,
      n032,
      _ODOR,
      0,
      [_ASl, _CRO, _SITi, _SAZ, _MTC, _MTP],
      [0, () => exports2.CapacityReservationOptionsRequest$, 2, 2, 1, 0]
    ];
    exports2.OperatorRequest$ = [
      3,
      n032,
      _ORpe,
      0,
      [_P10],
      [0]
    ];
    exports2.OperatorResponse$ = [
      3,
      n032,
      _ORper,
      0,
      [_Mana, _P10, _HBD],
      [[2, {
        [_eQN]: `Managed`,
        [_xN]: _mana
      }], [0, {
        [_eQN]: `Principal`,
        [_xN]: _p
      }], [2, {
        [_eQN]: `HiddenByDefault`,
        [_xN]: _hBD
      }]]
    ];
    exports2.OutpostLag$ = [
      3,
      n032,
      _OLu,
      0,
      [_OA, _OI, _St, _OLI, _LGVIIo, _SLVII, _T10],
      [[0, {
        [_eQN]: `OutpostArn`,
        [_xN]: _oA
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `OutpostLagId`,
        [_xN]: _oLI
      }], [() => LocalGatewayVirtualInterfaceIdSet, {
        [_eQN]: `LocalGatewayVirtualInterfaceIdSet`,
        [_xN]: _lGVIIS
      }], [() => ServiceLinkVirtualInterfaceIdSet, {
        [_eQN]: `ServiceLinkVirtualInterfaceIdSet`,
        [_xN]: _sLVIIS
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.PacketHeaderStatement$ = [
      3,
      n032,
      _PHS,
      0,
      [_SA, _DA, _SPo, _DPes, _SPL, _DPL, _Prot],
      [[() => ValueStringList, {
        [_eQN]: `SourceAddressSet`,
        [_xN]: _sAS
      }], [() => ValueStringList, {
        [_eQN]: `DestinationAddressSet`,
        [_xN]: _dAS
      }], [() => ValueStringList, {
        [_eQN]: `SourcePortSet`,
        [_xN]: _sPS
      }], [() => ValueStringList, {
        [_eQN]: `DestinationPortSet`,
        [_xN]: _dPS
      }], [() => ValueStringList, {
        [_eQN]: `SourcePrefixListSet`,
        [_xN]: _sPLS
      }], [() => ValueStringList, {
        [_eQN]: `DestinationPrefixListSet`,
        [_xN]: _dPLS
      }], [() => ProtocolList, {
        [_eQN]: `ProtocolSet`,
        [_xN]: _pSro
      }]]
    ];
    exports2.PacketHeaderStatementRequest$ = [
      3,
      n032,
      _PHSR,
      0,
      [_SA, _DA, _SPo, _DPes, _SPL, _DPL, _Prot],
      [[() => ValueStringList, { [_xN]: _SAou }], [() => ValueStringList, { [_xN]: _DAest }], [() => ValueStringList, { [_xN]: _SPou }], [() => ValueStringList, { [_xN]: _DPe }], [() => ValueStringList, { [_xN]: _SPLo }], [() => ValueStringList, { [_xN]: _DPLe }], [() => ProtocolList, { [_xN]: _Pr10 }]]
    ];
    exports2.PathComponent$ = [
      3,
      n032,
      _PCat,
      0,
      [_SNeq, _ARcl, _ATtta, _C11, _DVe, _OH, _IHn, _RTR, _SGRe, _SVo, _Su, _Vp, _ADd, _TG, _TGRTR, _Exp, _ELBL, _FSRi, _FSRir, _SN10],
      [[1, {
        [_eQN]: `SequenceNumber`,
        [_xN]: _sNeq
      }], [() => exports2.AnalysisAclRule$, {
        [_eQN]: `AclRule`,
        [_xN]: _aRc
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `AttachedTo`,
        [_xN]: _aTtt
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `Component`,
        [_xN]: _c32
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `DestinationVpc`,
        [_xN]: _dV
      }], [() => exports2.AnalysisPacketHeader$, {
        [_eQN]: `OutboundHeader`,
        [_xN]: _oH
      }], [() => exports2.AnalysisPacketHeader$, {
        [_eQN]: `InboundHeader`,
        [_xN]: _iHn
      }], [() => exports2.AnalysisRouteTableRoute$, {
        [_eQN]: `RouteTableRoute`,
        [_xN]: _rTR
      }], [() => exports2.AnalysisSecurityGroupRule$, {
        [_eQN]: `SecurityGroupRule`,
        [_xN]: _sGR
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `SourceVpc`,
        [_xN]: _sV
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `Subnet`,
        [_xN]: _su
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `Vpc`,
        [_xN]: _vp
      }], [() => AdditionalDetailList, {
        [_eQN]: `AdditionalDetailSet`,
        [_xN]: _aDS
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `TransitGateway`,
        [_xN]: _tG
      }], [() => exports2.TransitGatewayRouteTableRoute$, {
        [_eQN]: `TransitGatewayRouteTableRoute`,
        [_xN]: _tGRTR
      }], [() => ExplanationList, {
        [_eQN]: `ExplanationSet`,
        [_xN]: _eSx
      }], [() => exports2.AnalysisComponent$, {
        [_eQN]: `ElasticLoadBalancerListener`,
        [_xN]: _eLBL
      }], [() => exports2.FirewallStatelessRule$, {
        [_eQN]: `FirewallStatelessRule`,
        [_xN]: _fSR
      }], [() => exports2.FirewallStatefulRule$, {
        [_eQN]: `FirewallStatefulRule`,
        [_xN]: _fSRi
      }], [0, {
        [_eQN]: `ServiceName`,
        [_xN]: _sN
      }]]
    ];
    exports2.PathFilter$ = [
      3,
      n032,
      _PFa,
      0,
      [_SAou, _SPRo, _DAest, _DPRe],
      [[0, {
        [_eQN]: `SourceAddress`,
        [_xN]: _sAo
      }], [() => exports2.FilterPortRange$, {
        [_eQN]: `SourcePortRange`,
        [_xN]: _sPR
      }], [0, {
        [_eQN]: `DestinationAddress`,
        [_xN]: _dAe
      }], [() => exports2.FilterPortRange$, {
        [_eQN]: `DestinationPortRange`,
        [_xN]: _dPR
      }]]
    ];
    exports2.PathRequestFilter$ = [
      3,
      n032,
      _PRF,
      0,
      [_SAou, _SPRo, _DAest, _DPRe],
      [0, () => exports2.RequestFilterPortRange$, 0, () => exports2.RequestFilterPortRange$]
    ];
    exports2.PathStatement$ = [
      3,
      n032,
      _PSa,
      0,
      [_PHS, _RSes],
      [[() => exports2.PacketHeaderStatement$, {
        [_eQN]: `PacketHeaderStatement`,
        [_xN]: _pHS
      }], [() => exports2.ResourceStatement$, {
        [_eQN]: `ResourceStatement`,
        [_xN]: _rSeso
      }]]
    ];
    exports2.PathStatementRequest$ = [
      3,
      n032,
      _PSRa,
      0,
      [_PHS, _RSes],
      [[() => exports2.PacketHeaderStatementRequest$, 0], [() => exports2.ResourceStatementRequest$, 0]]
    ];
    exports2.PciId$ = [
      3,
      n032,
      _PIc,
      0,
      [_DIev, _VIe, _SIub, _SVIu],
      [0, 0, 0, 0]
    ];
    exports2.PeeringAttachmentStatus$ = [
      3,
      n032,
      _PAS,
      0,
      [_Co, _Me],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }]]
    ];
    exports2.PeeringConnectionOptions$ = [
      3,
      n032,
      _PCO,
      0,
      [_ADRFRV, _AEFLCLTRV, _AEFLVTRCL],
      [[2, {
        [_eQN]: `AllowDnsResolutionFromRemoteVpc`,
        [_xN]: _aDRFRV
      }], [2, {
        [_eQN]: `AllowEgressFromLocalClassicLinkToRemoteVpc`,
        [_xN]: _aEFLCLTRV
      }], [2, {
        [_eQN]: `AllowEgressFromLocalVpcToRemoteClassicLink`,
        [_xN]: _aEFLVTRCL
      }]]
    ];
    exports2.PeeringConnectionOptionsRequest$ = [
      3,
      n032,
      _PCOR,
      0,
      [_ADRFRV, _AEFLCLTRV, _AEFLVTRCL],
      [2, 2, 2]
    ];
    exports2.PeeringTgwInfo$ = [
      3,
      n032,
      _PTI,
      0,
      [_TGI, _CNIor, _OI, _Regi],
      [[0, {
        [_eQN]: `TransitGatewayId`,
        [_xN]: _tGI
      }], [0, {
        [_eQN]: `CoreNetworkId`,
        [_xN]: _cNIo
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `Region`,
        [_xN]: _reg
      }]]
    ];
    exports2.PerformanceFactorReference$ = [
      3,
      n032,
      _PFR,
      0,
      [_IF],
      [[0, {
        [_eQN]: `InstanceFamily`,
        [_xN]: _iF
      }]]
    ];
    exports2.PerformanceFactorReferenceRequest$ = [
      3,
      n032,
      _PFRR,
      0,
      [_IF],
      [0]
    ];
    exports2.Phase1DHGroupNumbersListValue$ = [
      3,
      n032,
      _PDHGNLV,
      0,
      [_V10],
      [[1, {
        [_eQN]: `Value`,
        [_xN]: _v
      }]]
    ];
    exports2.Phase1DHGroupNumbersRequestListValue$ = [
      3,
      n032,
      _PDHGNRLV,
      0,
      [_V10],
      [1]
    ];
    exports2.Phase1EncryptionAlgorithmsListValue$ = [
      3,
      n032,
      _PEALV,
      0,
      [_V10],
      [[0, {
        [_eQN]: `Value`,
        [_xN]: _v
      }]]
    ];
    exports2.Phase1EncryptionAlgorithmsRequestListValue$ = [
      3,
      n032,
      _PEARLV,
      0,
      [_V10],
      [0]
    ];
    exports2.Phase1IntegrityAlgorithmsListValue$ = [
      3,
      n032,
      _PIALV,
      0,
      [_V10],
      [[0, {
        [_eQN]: `Value`,
        [_xN]: _v
      }]]
    ];
    exports2.Phase1IntegrityAlgorithmsRequestListValue$ = [
      3,
      n032,
      _PIARLV,
      0,
      [_V10],
      [0]
    ];
    exports2.Phase2DHGroupNumbersListValue$ = [
      3,
      n032,
      _PDHGNLVh,
      0,
      [_V10],
      [[1, {
        [_eQN]: `Value`,
        [_xN]: _v
      }]]
    ];
    exports2.Phase2DHGroupNumbersRequestListValue$ = [
      3,
      n032,
      _PDHGNRLVh,
      0,
      [_V10],
      [1]
    ];
    exports2.Phase2EncryptionAlgorithmsListValue$ = [
      3,
      n032,
      _PEALVh,
      0,
      [_V10],
      [[0, {
        [_eQN]: `Value`,
        [_xN]: _v
      }]]
    ];
    exports2.Phase2EncryptionAlgorithmsRequestListValue$ = [
      3,
      n032,
      _PEARLVh,
      0,
      [_V10],
      [0]
    ];
    exports2.Phase2IntegrityAlgorithmsListValue$ = [
      3,
      n032,
      _PIALVh,
      0,
      [_V10],
      [[0, {
        [_eQN]: `Value`,
        [_xN]: _v
      }]]
    ];
    exports2.Phase2IntegrityAlgorithmsRequestListValue$ = [
      3,
      n032,
      _PIARLVh,
      0,
      [_V10],
      [0]
    ];
    exports2.Placement$ = [
      3,
      n032,
      _Pla,
      0,
      [_AZI, _Af, _GN, _PN, _HIo, _Te, _SDp, _HRGA, _GIr, _AZ],
      [[0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [0, {
        [_eQN]: `Affinity`,
        [_xN]: _af
      }], [0, {
        [_eQN]: `GroupName`,
        [_xN]: _gN
      }], [1, {
        [_eQN]: `PartitionNumber`,
        [_xN]: _pN
      }], [0, {
        [_eQN]: `HostId`,
        [_xN]: _hI
      }], [0, {
        [_eQN]: `Tenancy`,
        [_xN]: _t
      }], [0, {
        [_eQN]: `SpreadDomain`,
        [_xN]: _sDp
      }], [0, {
        [_eQN]: `HostResourceGroupArn`,
        [_xN]: _hRGA
      }], [0, {
        [_eQN]: `GroupId`,
        [_xN]: _gIr
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }]]
    ];
    exports2.PlacementGroup$ = [
      3,
      n032,
      _PG,
      0,
      [_GN, _St, _Str, _PCa, _GIr, _T10, _GA, _SLp, _LGIi, _Op],
      [[0, {
        [_eQN]: `GroupName`,
        [_xN]: _gN
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `Strategy`,
        [_xN]: _str
      }], [1, {
        [_eQN]: `PartitionCount`,
        [_xN]: _pCa
      }], [0, {
        [_eQN]: `GroupId`,
        [_xN]: _gIr
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `GroupArn`,
        [_xN]: _gA
      }], [0, {
        [_eQN]: `SpreadLevel`,
        [_xN]: _sLp
      }], [0, {
        [_eQN]: `LinkedGroupId`,
        [_xN]: _lGIi
      }], [() => exports2.OperatorResponse$, {
        [_eQN]: `Operator`,
        [_xN]: _ope
      }]]
    ];
    exports2.PlacementGroupInfo$ = [
      3,
      n032,
      _PGI,
      0,
      [_SSu],
      [[() => PlacementGroupStrategyList, {
        [_eQN]: `SupportedStrategies`,
        [_xN]: _sSup
      }]]
    ];
    exports2.PlacementResponse$ = [
      3,
      n032,
      _PRl,
      0,
      [_GN],
      [[0, {
        [_eQN]: `GroupName`,
        [_xN]: _gN
      }]]
    ];
    exports2.PoolCidrBlock$ = [
      3,
      n032,
      _PCBo,
      0,
      [_Ci],
      [[0, {
        [_eQN]: `PoolCidrBlock`,
        [_xN]: _pCB
      }]]
    ];
    exports2.PortRange$ = [
      3,
      n032,
      _PRo,
      0,
      [_Fr, _To],
      [[1, {
        [_eQN]: `From`,
        [_xN]: _fr
      }], [1, {
        [_eQN]: `To`,
        [_xN]: _to
      }]]
    ];
    exports2.PrefixList$ = [
      3,
      n032,
      _PL,
      0,
      [_Cid, _PLI, _PLN],
      [[() => ValueStringList, {
        [_eQN]: `CidrSet`,
        [_xN]: _cS4
      }], [0, {
        [_eQN]: `PrefixListId`,
        [_xN]: _pLI
      }], [0, {
        [_eQN]: `PrefixListName`,
        [_xN]: _pLN
      }]]
    ];
    exports2.PrefixListAssociation$ = [
      3,
      n032,
      _PLAre,
      0,
      [_RIeso, _ROe],
      [[0, {
        [_eQN]: `ResourceId`,
        [_xN]: _rIes
      }], [0, {
        [_eQN]: `ResourceOwner`,
        [_xN]: _rO
      }]]
    ];
    exports2.PrefixListEntry$ = [
      3,
      n032,
      _PLE,
      0,
      [_Ci, _De],
      [[0, {
        [_eQN]: `Cidr`,
        [_xN]: _ci
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }]]
    ];
    exports2.PrefixListId$ = [
      3,
      n032,
      _PLI,
      0,
      [_De, _PLI],
      [[0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [0, {
        [_eQN]: `PrefixListId`,
        [_xN]: _pLI
      }]]
    ];
    exports2.PriceSchedule$ = [
      3,
      n032,
      _PSric,
      0,
      [_Act, _CC, _Pric, _Ter],
      [[2, {
        [_eQN]: `Active`,
        [_xN]: _act
      }], [0, {
        [_eQN]: `CurrencyCode`,
        [_xN]: _cC
      }], [1, {
        [_eQN]: `Price`,
        [_xN]: _pric
      }], [1, {
        [_eQN]: `Term`,
        [_xN]: _te
      }]]
    ];
    exports2.PriceScheduleSpecification$ = [
      3,
      n032,
      _PSS,
      0,
      [_Ter, _Pric, _CC],
      [[1, {
        [_eQN]: `Term`,
        [_xN]: _te
      }], [1, {
        [_eQN]: `Price`,
        [_xN]: _pric
      }], [0, {
        [_eQN]: `CurrencyCode`,
        [_xN]: _cC
      }]]
    ];
    exports2.PricingDetail$ = [
      3,
      n032,
      _PDri,
      0,
      [_Cou, _Pric],
      [[1, {
        [_eQN]: `Count`,
        [_xN]: _cou
      }], [1, {
        [_eQN]: `Price`,
        [_xN]: _pric
      }]]
    ];
    exports2.PrincipalIdFormat$ = [
      3,
      n032,
      _PIF,
      0,
      [_Ar, _Statu],
      [[0, {
        [_eQN]: `Arn`,
        [_xN]: _ar
      }], [() => IdFormatList, {
        [_eQN]: `StatusSet`,
        [_xN]: _sSt
      }]]
    ];
    exports2.PrivateDnsDetails$ = [
      3,
      n032,
      _PDD,
      0,
      [_PDN],
      [[0, {
        [_eQN]: `PrivateDnsName`,
        [_xN]: _pDNr
      }]]
    ];
    exports2.PrivateDnsNameConfiguration$ = [
      3,
      n032,
      _PDNC,
      0,
      [_St, _Ty, _V10, _N],
      [[0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `Type`,
        [_xN]: _ty
      }], [0, {
        [_eQN]: `Value`,
        [_xN]: _v
      }], [0, {
        [_eQN]: `Name`,
        [_xN]: _n
      }]]
    ];
    exports2.PrivateDnsNameOptionsOnLaunch$ = [
      3,
      n032,
      _PDNOOL,
      0,
      [_HTo, _ERNDAR, _ERNDAAAAR],
      [[0, {
        [_eQN]: `HostnameType`,
        [_xN]: _hTo
      }], [2, {
        [_eQN]: `EnableResourceNameDnsARecord`,
        [_xN]: _eRNDAR
      }], [2, {
        [_eQN]: `EnableResourceNameDnsAAAARecord`,
        [_xN]: _eRNDAAAAR
      }]]
    ];
    exports2.PrivateDnsNameOptionsRequest$ = [
      3,
      n032,
      _PDNOR,
      0,
      [_HTo, _ERNDAR, _ERNDAAAAR],
      [0, 2, 2]
    ];
    exports2.PrivateDnsNameOptionsResponse$ = [
      3,
      n032,
      _PDNORr,
      0,
      [_HTo, _ERNDAR, _ERNDAAAAR],
      [[0, {
        [_eQN]: `HostnameType`,
        [_xN]: _hTo
      }], [2, {
        [_eQN]: `EnableResourceNameDnsARecord`,
        [_xN]: _eRNDAR
      }], [2, {
        [_eQN]: `EnableResourceNameDnsAAAARecord`,
        [_xN]: _eRNDAAAAR
      }]]
    ];
    exports2.PrivateIpAddressSpecification$ = [
      3,
      n032,
      _PIAS,
      0,
      [_Prim, _PIAr],
      [[2, {
        [_eQN]: `Primary`,
        [_xN]: _prim
      }], [0, {
        [_eQN]: `PrivateIpAddress`,
        [_xN]: _pIAr
      }]]
    ];
    exports2.ProcessorInfo$ = [
      3,
      n032,
      _PIro,
      0,
      [_SAup, _SCSIG, _SF, _Man],
      [[() => ArchitectureTypeList, {
        [_eQN]: `SupportedArchitectures`,
        [_xN]: _sAu
      }], [1, {
        [_eQN]: `SustainedClockSpeedInGhz`,
        [_xN]: _sCSIG
      }], [() => SupportedAdditionalProcessorFeatureList, {
        [_eQN]: `SupportedFeatures`,
        [_xN]: _sF
      }], [0, {
        [_eQN]: `Manufacturer`,
        [_xN]: _man
      }]]
    ];
    exports2.ProductCode$ = [
      3,
      n032,
      _PCr10,
      0,
      [_PCIr, _PCT],
      [[0, {
        [_eQN]: `ProductCode`,
        [_xN]: _pCr
      }], [0, {
        [_eQN]: `Type`,
        [_xN]: _ty
      }]]
    ];
    exports2.PropagatingVgw$ = [
      3,
      n032,
      _PV,
      0,
      [_GI2],
      [[0, {
        [_eQN]: `GatewayId`,
        [_xN]: _gI
      }]]
    ];
    exports2.ProvisionByoipCidrRequest$ = [
      3,
      n032,
      _PBCR,
      0,
      [_Ci, _CAC, _PAu, _De, _DR, _PTS, _MRu, _NBG],
      [0, () => exports2.CidrAuthorizationContext$, 2, 0, 2, [() => TagSpecificationList, { [_xN]: _PTSo }], 2, 0],
      1
    ];
    exports2.ProvisionByoipCidrResult$ = [
      3,
      n032,
      _PBCRr,
      0,
      [_BC],
      [[() => exports2.ByoipCidr$, {
        [_eQN]: `ByoipCidr`,
        [_xN]: _bC
      }]]
    ];
    exports2.ProvisionedBandwidth$ = [
      3,
      n032,
      _PB,
      0,
      [_PTr, _Prov, _RTeq, _Req, _Sta],
      [[4, {
        [_eQN]: `ProvisionTime`,
        [_xN]: _pTr
      }], [0, {
        [_eQN]: `Provisioned`,
        [_xN]: _prov
      }], [4, {
        [_eQN]: `RequestTime`,
        [_xN]: _rTeq
      }], [0, {
        [_eQN]: `Requested`,
        [_xN]: _req
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }]]
    ];
    exports2.ProvisionIpamByoasnRequest$ = [
      3,
      n032,
      _PIBR,
      0,
      [_IIp, _Asn, _AAC, _DR],
      [0, 0, () => exports2.AsnAuthorizationContext$, 2],
      3
    ];
    exports2.ProvisionIpamByoasnResult$ = [
      3,
      n032,
      _PIBRr,
      0,
      [_B],
      [[() => exports2.Byoasn$, {
        [_eQN]: `Byoasn`,
        [_xN]: _by
      }]]
    ];
    exports2.ProvisionIpamPoolCidrRequest$ = [
      3,
      n032,
      _PIPCR,
      0,
      [_IPI2, _DR, _Ci, _CAC, _NL, _CT4, _VMe, _IERVTI],
      [0, 2, 0, () => exports2.IpamCidrAuthorizationContext$, 1, [0, 4], 0, 0],
      1
    ];
    exports2.ProvisionIpamPoolCidrResult$ = [
      3,
      n032,
      _PIPCRr,
      0,
      [_IPCpa],
      [[() => exports2.IpamPoolCidr$, {
        [_eQN]: `IpamPoolCidr`,
        [_xN]: _iPC
      }]]
    ];
    exports2.ProvisionPublicIpv4PoolCidrRequest$ = [
      3,
      n032,
      _PPIPCR,
      0,
      [_IPI2, _PIo, _NL, _DR, _NBG],
      [0, 0, 1, 2, 0],
      3
    ];
    exports2.ProvisionPublicIpv4PoolCidrResult$ = [
      3,
      n032,
      _PPIPCRr,
      0,
      [_PIo, _PAR],
      [[0, {
        [_eQN]: `PoolId`,
        [_xN]: _pIo
      }], [() => exports2.PublicIpv4PoolRange$, {
        [_eQN]: `PoolAddressRange`,
        [_xN]: _pAR
      }]]
    ];
    exports2.PtrUpdateStatus$ = [
      3,
      n032,
      _PUS,
      0,
      [_V10, _Sta, _Rea],
      [[0, {
        [_eQN]: `Value`,
        [_xN]: _v
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `Reason`,
        [_xN]: _rea
      }]]
    ];
    exports2.PublicIpDnsNameOptions$ = [
      3,
      n032,
      _PIDNO,
      0,
      [_DHT, _PIDNu, _PIDN, _PDSDN],
      [[0, {
        [_eQN]: `DnsHostnameType`,
        [_xN]: _dHT
      }], [0, {
        [_eQN]: `PublicIpv4DnsName`,
        [_xN]: _pIDNu
      }], [0, {
        [_eQN]: `PublicIpv6DnsName`,
        [_xN]: _pIDN
      }], [0, {
        [_eQN]: `PublicDualStackDnsName`,
        [_xN]: _pDSDN
      }]]
    ];
    exports2.PublicIpv4Pool$ = [
      3,
      n032,
      _PIP,
      0,
      [_PIo, _De, _PARo, _TACo, _TAAC, _NBG, _T10],
      [[0, {
        [_eQN]: `PoolId`,
        [_xN]: _pIo
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [() => PublicIpv4PoolRangeSet, {
        [_eQN]: `PoolAddressRangeSet`,
        [_xN]: _pARS
      }], [1, {
        [_eQN]: `TotalAddressCount`,
        [_xN]: _tACo
      }], [1, {
        [_eQN]: `TotalAvailableAddressCount`,
        [_xN]: _tAAC
      }], [0, {
        [_eQN]: `NetworkBorderGroup`,
        [_xN]: _nBG
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.PublicIpv4PoolRange$ = [
      3,
      n032,
      _PIPR,
      0,
      [_FAi, _LAa, _ACd, _AACv],
      [[0, {
        [_eQN]: `FirstAddress`,
        [_xN]: _fAi
      }], [0, {
        [_eQN]: `LastAddress`,
        [_xN]: _lAa
      }], [1, {
        [_eQN]: `AddressCount`,
        [_xN]: _aCd
      }], [1, {
        [_eQN]: `AvailableAddressCount`,
        [_xN]: _aAC
      }]]
    ];
    exports2.Purchase$ = [
      3,
      n032,
      _Pur,
      0,
      [_CC, _Du, _HIS, _HRI, _HPo, _IF, _PO, _UP],
      [[0, {
        [_eQN]: `CurrencyCode`,
        [_xN]: _cC
      }], [1, {
        [_eQN]: `Duration`,
        [_xN]: _du
      }], [() => ResponseHostIdSet, {
        [_eQN]: `HostIdSet`,
        [_xN]: _hIS
      }], [0, {
        [_eQN]: `HostReservationId`,
        [_xN]: _hRI
      }], [0, {
        [_eQN]: `HourlyPrice`,
        [_xN]: _hPo
      }], [0, {
        [_eQN]: `InstanceFamily`,
        [_xN]: _iF
      }], [0, {
        [_eQN]: `PaymentOption`,
        [_xN]: _pO
      }], [0, {
        [_eQN]: `UpfrontPrice`,
        [_xN]: _uP
      }]]
    ];
    exports2.PurchaseCapacityBlockExtensionRequest$ = [
      3,
      n032,
      _PCBER,
      0,
      [_CBEOI, _CRI, _DR],
      [0, 0, 2],
      2
    ];
    exports2.PurchaseCapacityBlockExtensionResult$ = [
      3,
      n032,
      _PCBERu,
      0,
      [_CBEa],
      [[() => CapacityBlockExtensionSet, {
        [_eQN]: `CapacityBlockExtensionSet`,
        [_xN]: _cBESa
      }]]
    ];
    exports2.PurchaseCapacityBlockRequest$ = [
      3,
      n032,
      _PCBR,
      0,
      [_CBOI, _IPn, _DR, _TS],
      [0, 0, 2, [() => TagSpecificationList, { [_xN]: _TSa }]],
      2
    ];
    exports2.PurchaseCapacityBlockResult$ = [
      3,
      n032,
      _PCBRu,
      0,
      [_CRa, _CBap],
      [[() => exports2.CapacityReservation$, {
        [_eQN]: `CapacityReservation`,
        [_xN]: _cR
      }], [() => CapacityBlockSet, {
        [_eQN]: `CapacityBlockSet`,
        [_xN]: _cBS
      }]]
    ];
    exports2.PurchaseHostReservationRequest$ = [
      3,
      n032,
      _PHRR,
      0,
      [_HIS, _OIf, _CT4, _CC, _LPi, _TS],
      [[() => RequestHostIdSet, 0], 0, 0, 0, 0, [() => TagSpecificationList, { [_xN]: _TSa }]],
      2
    ];
    exports2.PurchaseHostReservationResult$ = [
      3,
      n032,
      _PHRRu,
      0,
      [_CT4, _CC, _Pur, _THP, _TUP],
      [[0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }], [0, {
        [_eQN]: `CurrencyCode`,
        [_xN]: _cC
      }], [() => PurchaseSet, {
        [_eQN]: `Purchase`,
        [_xN]: _pur
      }], [0, {
        [_eQN]: `TotalHourlyPrice`,
        [_xN]: _tHP
      }], [0, {
        [_eQN]: `TotalUpfrontPrice`,
        [_xN]: _tUP
      }]]
    ];
    exports2.PurchaseRequest$ = [
      3,
      n032,
      _PRu,
      0,
      [_IC, _PTu],
      [1, 0],
      2
    ];
    exports2.PurchaseReservedInstancesOfferingRequest$ = [
      3,
      n032,
      _PRIOR,
      0,
      [_IC, _RIOIe, _PTur, _DR, _LPi],
      [1, 0, 4, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [() => exports2.ReservedInstanceLimitPrice$, {
        [_eQN]: `LimitPrice`,
        [_xN]: _lPi
      }]],
      2
    ];
    exports2.PurchaseReservedInstancesOfferingResult$ = [
      3,
      n032,
      _PRIORu,
      0,
      [_RIIes],
      [[0, {
        [_eQN]: `ReservedInstancesId`,
        [_xN]: _rII
      }]]
    ];
    exports2.PurchaseScheduledInstancesRequest$ = [
      3,
      n032,
      _PSIR,
      0,
      [_PRur, _CT4, _DR],
      [[() => PurchaseRequestSet, { [_xN]: _PRu }], [0, 4], 2],
      1
    ];
    exports2.PurchaseScheduledInstancesResult$ = [
      3,
      n032,
      _PSIRu,
      0,
      [_SIS],
      [[() => PurchasedScheduledInstanceSet, {
        [_eQN]: `ScheduledInstanceSet`,
        [_xN]: _sIS
      }]]
    ];
    exports2.RebootInstancesRequest$ = [
      3,
      n032,
      _RIR,
      0,
      [_IIns, _DR],
      [[() => InstanceIdStringList, { [_xN]: _II2 }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.RecurringCharge$ = [
      3,
      n032,
      _RCec,
      0,
      [_Am, _Fre],
      [[1, {
        [_eQN]: `Amount`,
        [_xN]: _am
      }], [0, {
        [_eQN]: `Frequency`,
        [_xN]: _fre
      }]]
    ];
    exports2.ReferencedSecurityGroup$ = [
      3,
      n032,
      _RSG,
      0,
      [_GIr, _PSee, _UI, _VI, _VPCI],
      [[0, {
        [_eQN]: `GroupId`,
        [_xN]: _gIr
      }], [0, {
        [_eQN]: `PeeringStatus`,
        [_xN]: _pSee
      }], [0, {
        [_eQN]: `UserId`,
        [_xN]: _uI
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [0, {
        [_eQN]: `VpcPeeringConnectionId`,
        [_xN]: _vPCI
      }]]
    ];
    exports2.Region$ = [
      3,
      n032,
      _Regi,
      0,
      [_OIS, _Ge, _RN, _Endp],
      [[0, {
        [_eQN]: `OptInStatus`,
        [_xN]: _oIS
      }], [() => RegionGeographyList, {
        [_eQN]: `GeographySet`,
        [_xN]: _gS
      }], [0, {
        [_eQN]: `RegionName`,
        [_xN]: _rNe
      }], [0, {
        [_eQN]: `RegionEndpoint`,
        [_xN]: _rEe
      }]]
    ];
    exports2.RegionalSummary$ = [
      3,
      n032,
      _RSeg,
      0,
      [_RN, _NOMA, _NOUA],
      [[0, {
        [_eQN]: `RegionName`,
        [_xN]: _rNe
      }], [1, {
        [_eQN]: `NumberOfMatchedAccounts`,
        [_xN]: _nOMA
      }], [1, {
        [_eQN]: `NumberOfUnmatchedAccounts`,
        [_xN]: _nOUA
      }]]
    ];
    exports2.RegionGeography$ = [
      3,
      n032,
      _RG,
      0,
      [_N],
      [[0, {
        [_eQN]: `Name`,
        [_xN]: _n
      }]]
    ];
    exports2.RegisteredInstance$ = [
      3,
      n032,
      _RIeg,
      0,
      [_II2, _SSLU, _HSa, _PSro, _LUTa, _SSC, _T10],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `SqlServerLicenseUsage`,
        [_xN]: _sSLU
      }], [0, {
        [_eQN]: `HaStatus`,
        [_xN]: _hSa
      }], [0, {
        [_eQN]: `ProcessingStatus`,
        [_xN]: _pSroc
      }], [4, {
        [_eQN]: `LastUpdatedTime`,
        [_xN]: _lUTa
      }], [0, {
        [_eQN]: `SqlServerCredentials`,
        [_xN]: _sSC
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.RegisterImageRequest$ = [
      3,
      n032,
      _RIRe,
      0,
      [_N, _IL, _BPi, _BM, _TSp, _UD, _ISmd, _TS, _DR, _De, _Arc, _KI, _RIa, _RDN, _BDMl, _VTir, _SNS, _ESna],
      [[0, {
        [_eQN]: `Name`,
        [_xN]: _n
      }], 0, [() => BillingProductList, { [_xN]: _BPil }], 0, 0, 0, 0, [() => TagSpecificationList, { [_xN]: _TSa }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [0, {
        [_eQN]: `Architecture`,
        [_xN]: _arc
      }], [0, {
        [_eQN]: `KernelId`,
        [_xN]: _kI
      }], [0, {
        [_eQN]: `RamdiskId`,
        [_xN]: _rIa
      }], [0, {
        [_eQN]: `RootDeviceName`,
        [_xN]: _rDN
      }], [() => BlockDeviceMappingRequestList, { [_xN]: _BDM }], [0, {
        [_eQN]: `VirtualizationType`,
        [_xN]: _vTi
      }], [0, {
        [_eQN]: `SriovNetSupport`,
        [_xN]: _sNSr
      }], [2, {
        [_eQN]: `EnaSupport`,
        [_xN]: _eSna
      }]],
      1
    ];
    exports2.RegisterImageResult$ = [
      3,
      n032,
      _RIReg,
      0,
      [_IIm],
      [[0, {
        [_eQN]: `ImageId`,
        [_xN]: _iIma
      }]]
    ];
    exports2.RegisterInstanceEventNotificationAttributesRequest$ = [
      3,
      n032,
      _RIENAR,
      0,
      [_ITA, _DR],
      [[() => exports2.RegisterInstanceTagAttributeRequest$, 0], 2],
      1
    ];
    exports2.RegisterInstanceEventNotificationAttributesResult$ = [
      3,
      n032,
      _RIENARe,
      0,
      [_ITA],
      [[() => exports2.InstanceTagNotificationAttribute$, {
        [_eQN]: `InstanceTagAttribute`,
        [_xN]: _iTA
      }]]
    ];
    exports2.RegisterInstanceTagAttributeRequest$ = [
      3,
      n032,
      _RITAR,
      0,
      [_IATOI, _ITK],
      [2, [() => InstanceTagKeySet, { [_xN]: _ITKn }]]
    ];
    exports2.RegisterTransitGatewayMulticastGroupMembersRequest$ = [
      3,
      n032,
      _RTGMGMR,
      0,
      [_TGMDI, _NIIe, _GIA, _DR],
      [0, [() => TransitGatewayNetworkInterfaceIdList, 0], 0, 2],
      2
    ];
    exports2.RegisterTransitGatewayMulticastGroupMembersResult$ = [
      3,
      n032,
      _RTGMGMRe,
      0,
      [_RMGM],
      [[() => exports2.TransitGatewayMulticastRegisteredGroupMembers$, {
        [_eQN]: `RegisteredMulticastGroupMembers`,
        [_xN]: _rMGM
      }]]
    ];
    exports2.RegisterTransitGatewayMulticastGroupSourcesRequest$ = [
      3,
      n032,
      _RTGMGSR,
      0,
      [_TGMDI, _NIIe, _GIA, _DR],
      [0, [() => TransitGatewayNetworkInterfaceIdList, 0], 0, 2],
      2
    ];
    exports2.RegisterTransitGatewayMulticastGroupSourcesResult$ = [
      3,
      n032,
      _RTGMGSRe,
      0,
      [_RMGS],
      [[() => exports2.TransitGatewayMulticastRegisteredGroupSources$, {
        [_eQN]: `RegisteredMulticastGroupSources`,
        [_xN]: _rMGS
      }]]
    ];
    exports2.RejectCapacityReservationBillingOwnershipRequest$ = [
      3,
      n032,
      _RCRBOR,
      0,
      [_CRI, _DR],
      [0, 2],
      1
    ];
    exports2.RejectCapacityReservationBillingOwnershipResult$ = [
      3,
      n032,
      _RCRBORe,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.RejectTransitGatewayClientVpnAttachmentRequest$ = [
      3,
      n032,
      _RTGCVAR,
      0,
      [_TGAI, _DR],
      [0, 2],
      1
    ];
    exports2.RejectTransitGatewayClientVpnAttachmentResult$ = [
      3,
      n032,
      _RTGCVARe,
      0,
      [_TGCVA],
      [[() => exports2.TransitGatewayClientVpnAttachment$, {
        [_eQN]: `TransitGatewayClientVpnAttachment`,
        [_xN]: _tGCVA
      }]]
    ];
    exports2.RejectTransitGatewayMulticastDomainAssociationsRequest$ = [
      3,
      n032,
      _RTGMDAR,
      0,
      [_TGMDI, _TGAI, _SI10, _DR],
      [0, 0, [() => ValueStringList, 0], 2]
    ];
    exports2.RejectTransitGatewayMulticastDomainAssociationsResult$ = [
      3,
      n032,
      _RTGMDARe,
      0,
      [_As],
      [[() => exports2.TransitGatewayMulticastDomainAssociations$, {
        [_eQN]: `Associations`,
        [_xN]: _a10
      }]]
    ];
    exports2.RejectTransitGatewayPeeringAttachmentRequest$ = [
      3,
      n032,
      _RTGPAR,
      0,
      [_TGAI, _DR],
      [0, 2],
      1
    ];
    exports2.RejectTransitGatewayPeeringAttachmentResult$ = [
      3,
      n032,
      _RTGPARe,
      0,
      [_TGPA],
      [[() => exports2.TransitGatewayPeeringAttachment$, {
        [_eQN]: `TransitGatewayPeeringAttachment`,
        [_xN]: _tGPA
      }]]
    ];
    exports2.RejectTransitGatewayVpcAttachmentRequest$ = [
      3,
      n032,
      _RTGVAR,
      0,
      [_TGAI, _DR],
      [0, 2],
      1
    ];
    exports2.RejectTransitGatewayVpcAttachmentResult$ = [
      3,
      n032,
      _RTGVARe,
      0,
      [_TGVA],
      [[() => exports2.TransitGatewayVpcAttachment$, {
        [_eQN]: `TransitGatewayVpcAttachment`,
        [_xN]: _tGVA
      }]]
    ];
    exports2.RejectVpcEndpointConnectionsRequest$ = [
      3,
      n032,
      _RVECR,
      0,
      [_SIe, _VEI, _DR],
      [0, [() => VpcEndpointIdList, { [_xN]: _VEIp }], 2],
      2
    ];
    exports2.RejectVpcEndpointConnectionsResult$ = [
      3,
      n032,
      _RVECRe,
      0,
      [_U],
      [[() => UnsuccessfulItemSet, {
        [_eQN]: `Unsuccessful`,
        [_xN]: _u
      }]]
    ];
    exports2.RejectVpcPeeringConnectionRequest$ = [
      3,
      n032,
      _RVPCR,
      0,
      [_VPCI, _DR],
      [[0, {
        [_eQN]: `VpcPeeringConnectionId`,
        [_xN]: _vPCI
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.RejectVpcPeeringConnectionResult$ = [
      3,
      n032,
      _RVPCRe,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.ReleaseAddressRequest$ = [
      3,
      n032,
      _RAR,
      0,
      [_AIl, _PI10, _NBG, _DR],
      [0, 0, 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]]
    ];
    exports2.ReleaseHostsRequest$ = [
      3,
      n032,
      _RHR,
      0,
      [_HI],
      [[() => RequestHostIdList, {
        [_eQN]: `HostId`,
        [_xN]: _hI
      }]],
      1
    ];
    exports2.ReleaseHostsResult$ = [
      3,
      n032,
      _RHRe,
      0,
      [_Suc, _U],
      [[() => ResponseHostIdList, {
        [_eQN]: `Successful`,
        [_xN]: _suc
      }], [() => UnsuccessfulItemList, {
        [_eQN]: `Unsuccessful`,
        [_xN]: _u
      }]]
    ];
    exports2.ReleaseIpamPoolAllocationRequest$ = [
      3,
      n032,
      _RIPAR,
      0,
      [_IPI2, _Ci, _IPAI, _DR],
      [0, 0, 0, 2],
      3
    ];
    exports2.ReleaseIpamPoolAllocationResult$ = [
      3,
      n032,
      _RIPARe,
      0,
      [_Succ],
      [[2, {
        [_eQN]: `Success`,
        [_xN]: _succ
      }]]
    ];
    exports2.RemoveIpamOperatingRegion$ = [
      3,
      n032,
      _RIOR,
      0,
      [_RN],
      [0]
    ];
    exports2.RemoveIpamOrganizationalUnitExclusion$ = [
      3,
      n032,
      _RIOUE,
      0,
      [_OEP],
      [0]
    ];
    exports2.RemovePrefixListEntry$ = [
      3,
      n032,
      _RPLE,
      0,
      [_Ci],
      [0],
      1
    ];
    exports2.ReplaceIamInstanceProfileAssociationRequest$ = [
      3,
      n032,
      _RIIPAR,
      0,
      [_IIP, _AIs],
      [[() => exports2.IamInstanceProfileSpecification$, 0], 0],
      2
    ];
    exports2.ReplaceIamInstanceProfileAssociationResult$ = [
      3,
      n032,
      _RIIPARe,
      0,
      [_IIPA],
      [[() => exports2.IamInstanceProfileAssociation$, {
        [_eQN]: `IamInstanceProfileAssociation`,
        [_xN]: _iIPA
      }]]
    ];
    exports2.ReplaceImageCriteriaInAllowedImagesSettingsRequest$ = [
      3,
      n032,
      _RICIAISR,
      0,
      [_ICm, _DR],
      [[() => ImageCriterionRequestList, { [_xN]: _ICma }], 2]
    ];
    exports2.ReplaceImageCriteriaInAllowedImagesSettingsResult$ = [
      3,
      n032,
      _RICIAISRe,
      0,
      [_RV],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.ReplaceNetworkAclAssociationRequest$ = [
      3,
      n032,
      _RNAAR,
      0,
      [_AIs, _NAI, _DR],
      [[0, {
        [_eQN]: `AssociationId`,
        [_xN]: _aIs
      }], [0, {
        [_eQN]: `NetworkAclId`,
        [_xN]: _nAI
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      2
    ];
    exports2.ReplaceNetworkAclAssociationResult$ = [
      3,
      n032,
      _RNAARe,
      0,
      [_NAIew],
      [[0, {
        [_eQN]: `NewAssociationId`,
        [_xN]: _nAIe
      }]]
    ];
    exports2.ReplaceNetworkAclEntryRequest$ = [
      3,
      n032,
      _RNAER,
      0,
      [_NAI, _RNu, _Pr10, _RA10, _E11, _DR, _CB, _ICB, _ITC, _PRo],
      [[0, {
        [_eQN]: `NetworkAclId`,
        [_xN]: _nAI
      }], [1, {
        [_eQN]: `RuleNumber`,
        [_xN]: _rN10
      }], [0, {
        [_eQN]: `Protocol`,
        [_xN]: _pr
      }], [0, {
        [_eQN]: `RuleAction`,
        [_xN]: _rA
      }], [2, {
        [_eQN]: `Egress`,
        [_xN]: _e32
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [0, {
        [_eQN]: `CidrBlock`,
        [_xN]: _cB
      }], [0, {
        [_eQN]: `Ipv6CidrBlock`,
        [_xN]: _iCB
      }], [() => exports2.IcmpTypeCode$, { [_xN]: _Ic }], [() => exports2.PortRange$, {
        [_eQN]: `PortRange`,
        [_xN]: _pRo
      }]],
      5
    ];
    exports2.ReplaceRootVolumeTask$ = [
      3,
      n032,
      _RRVT,
      0,
      [_RRVTIe, _II2, _TSas, _ST11, _CTom, _T10, _IIm, _SIn, _DRRV],
      [[0, {
        [_eQN]: `ReplaceRootVolumeTaskId`,
        [_xN]: _rRVTI
      }], [0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `TaskState`,
        [_xN]: _tSas
      }], [0, {
        [_eQN]: `StartTime`,
        [_xN]: _sT19
      }], [0, {
        [_eQN]: `CompleteTime`,
        [_xN]: _cTom
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `ImageId`,
        [_xN]: _iIma
      }], [0, {
        [_eQN]: `SnapshotId`,
        [_xN]: _sIn
      }], [2, {
        [_eQN]: `DeleteReplacedRootVolume`,
        [_xN]: _dRRV
      }]]
    ];
    exports2.ReplaceRouteRequest$ = [
      3,
      n032,
      _RRR,
      0,
      [_RTI, _DPLI, _VEIp, _LToc, _TGI, _LGI, _CGI, _CNA, _ONA, _DR, _DCB, _GI2, _DICB, _EOIGI, _II2, _NII, _VPCI, _NGI],
      [[0, {
        [_eQN]: `RouteTableId`,
        [_xN]: _rTI
      }], 0, 0, 2, 0, 0, 0, 0, 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [0, {
        [_eQN]: `DestinationCidrBlock`,
        [_xN]: _dCB
      }], [0, {
        [_eQN]: `GatewayId`,
        [_xN]: _gI
      }], [0, {
        [_eQN]: `DestinationIpv6CidrBlock`,
        [_xN]: _dICB
      }], [0, {
        [_eQN]: `EgressOnlyInternetGatewayId`,
        [_xN]: _eOIGI
      }], [0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], [0, {
        [_eQN]: `VpcPeeringConnectionId`,
        [_xN]: _vPCI
      }], [0, {
        [_eQN]: `NatGatewayId`,
        [_xN]: _nGI
      }]],
      1
    ];
    exports2.ReplaceRouteTableAssociationRequest$ = [
      3,
      n032,
      _RRTAR,
      0,
      [_AIs, _RTI, _DR],
      [[0, {
        [_eQN]: `AssociationId`,
        [_xN]: _aIs
      }], [0, {
        [_eQN]: `RouteTableId`,
        [_xN]: _rTI
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      2
    ];
    exports2.ReplaceRouteTableAssociationResult$ = [
      3,
      n032,
      _RRTARe,
      0,
      [_NAIew, _AS],
      [[0, {
        [_eQN]: `NewAssociationId`,
        [_xN]: _nAIe
      }], [() => exports2.RouteTableAssociationState$, {
        [_eQN]: `AssociationState`,
        [_xN]: _aS
      }]]
    ];
    exports2.ReplaceTransitGatewayRouteRequest$ = [
      3,
      n032,
      _RTGRR,
      0,
      [_DCB, _TGRTI, _TGAI, _Bl, _DR],
      [0, 0, 0, 2, 2],
      2
    ];
    exports2.ReplaceTransitGatewayRouteResult$ = [
      3,
      n032,
      _RTGRRe,
      0,
      [_Ro],
      [[() => exports2.TransitGatewayRoute$, {
        [_eQN]: `Route`,
        [_xN]: _ro
      }]]
    ];
    exports2.ReplaceVpnTunnelRequest$ = [
      3,
      n032,
      _RVTR,
      0,
      [_VCIp, _VTOIA, _APM, _DR],
      [0, 0, 2, 2],
      2
    ];
    exports2.ReplaceVpnTunnelResult$ = [
      3,
      n032,
      _RVTRe,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.ReportInstanceStatusRequest$ = [
      3,
      n032,
      _RISR,
      0,
      [_Ins, _Sta, _RCea, _DR, _ST11, _ETnd, _De],
      [[() => InstanceIdStringList, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [() => ReasonCodesList, {
        [_eQN]: `ReasonCode`,
        [_xN]: _rCea
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [4, {
        [_eQN]: `StartTime`,
        [_xN]: _sT19
      }], [4, {
        [_eQN]: `EndTime`,
        [_xN]: _eTn
      }], [() => ReportInstanceStatusRequestDescription, {
        [_eQN]: `Description`,
        [_xN]: _de
      }]],
      3
    ];
    exports2.RequestFilterPortRange$ = [
      3,
      n032,
      _RFPR,
      0,
      [_FP, _TP],
      [1, 1]
    ];
    exports2.RequestIpamResourceTag$ = [
      3,
      n032,
      _RIRT,
      0,
      [_K10, _V10],
      [0, 0]
    ];
    exports2.RequestLaunchTemplateData$ = [
      3,
      n032,
      _RLTD,
      0,
      [_KI, _EO, _IIP, _BDMl, _NIet, _IIm, _IT4, _KN, _Mon, _Pla, _RDI, _DAT, _IISB, _UDs, _TS, _EGSlas, _EIAl, _SGIe, _SGe, _IMOns, _CSr, _CO, _CRSa, _LS, _HO, _MO, _EOn, _IRn, _PDNO, _MOa, _DASi, _Op, _NPO, _SIec],
      [0, 2, () => exports2.LaunchTemplateIamInstanceProfileSpecificationRequest$, [() => LaunchTemplateBlockDeviceMappingRequestList, { [_xN]: _BDM }], [() => LaunchTemplateInstanceNetworkInterfaceSpecificationRequestList, { [_xN]: _NIe }], 0, 0, 0, () => exports2.LaunchTemplatesMonitoringRequest$, () => exports2.LaunchTemplatePlacementRequest$, 0, 2, 0, [() => SensitiveUserData, 0], [() => LaunchTemplateTagSpecificationRequestList, { [_xN]: _TSa }], [() => ElasticGpuSpecificationList, { [_xN]: _EGSla }], [() => LaunchTemplateElasticInferenceAcceleratorList, { [_xN]: _EIA }], [() => SecurityGroupIdStringList, { [_xN]: _SGI }], [() => SecurityGroupStringList, { [_xN]: _SGec }], () => exports2.LaunchTemplateInstanceMarketOptionsRequest$, () => exports2.CreditSpecificationRequest$, () => exports2.LaunchTemplateCpuOptionsRequest$, () => exports2.LaunchTemplateCapacityReservationSpecificationRequest$, [() => LaunchTemplateLicenseSpecificationListRequest, { [_xN]: _LSi }], () => exports2.LaunchTemplateHibernationOptionsRequest$, () => exports2.LaunchTemplateInstanceMetadataOptionsRequest$, () => exports2.LaunchTemplateEnclaveOptionsRequest$, [() => exports2.InstanceRequirementsRequest$, 0], () => exports2.LaunchTemplatePrivateDnsNameOptionsRequest$, () => exports2.LaunchTemplateInstanceMaintenanceOptionsRequest$, 2, () => exports2.OperatorRequest$, () => exports2.LaunchTemplateNetworkPerformanceOptionsRequest$, [() => LaunchTemplateInstanceSecondaryInterfaceSpecificationRequestList, { [_xN]: _SIeco }]]
    ];
    exports2.RequestSpotFleetRequest$ = [
      3,
      n032,
      _RSFR,
      0,
      [_SFRCp, _DR],
      [[() => exports2.SpotFleetRequestConfigData$, {
        [_eQN]: `SpotFleetRequestConfig`,
        [_xN]: _sFRC
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.RequestSpotFleetResponse$ = [
      3,
      n032,
      _RSFRe,
      0,
      [_SFRI],
      [[0, {
        [_eQN]: `SpotFleetRequestId`,
        [_xN]: _sFRI
      }]]
    ];
    exports2.RequestSpotInstancesRequest$ = [
      3,
      n032,
      _RSIR,
      0,
      [_LSa, _TS, _IIB, _DR, _SPp, _CT4, _IC, _Ty, _VF, _VU, _LGa, _AZGv, _BDMlo],
      [[() => exports2.RequestSpotLaunchSpecification$, 0], [() => TagSpecificationList, { [_xN]: _TSa }], 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [0, {
        [_eQN]: `SpotPrice`,
        [_xN]: _sPp
      }], [0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }], [1, {
        [_eQN]: `InstanceCount`,
        [_xN]: _iC
      }], [0, {
        [_eQN]: `Type`,
        [_xN]: _ty
      }], [4, {
        [_eQN]: `ValidFrom`,
        [_xN]: _vF
      }], [4, {
        [_eQN]: `ValidUntil`,
        [_xN]: _vU
      }], [0, {
        [_eQN]: `LaunchGroup`,
        [_xN]: _lG
      }], [0, {
        [_eQN]: `AvailabilityZoneGroup`,
        [_xN]: _aZG
      }], [1, {
        [_eQN]: `BlockDurationMinutes`,
        [_xN]: _bDMl
      }]]
    ];
    exports2.RequestSpotInstancesResult$ = [
      3,
      n032,
      _RSIRe,
      0,
      [_SIR],
      [[() => SpotInstanceRequestList, {
        [_eQN]: `SpotInstanceRequestSet`,
        [_xN]: _sIRS
      }]]
    ];
    exports2.RequestSpotLaunchSpecification$ = [
      3,
      n032,
      _RSLS,
      0,
      [_SGIe, _SGe, _ATddre, _BDMl, _EO, _IIP, _IIm, _IT4, _KI, _KN, _Mon, _NIet, _Pla, _RIa, _SIu, _UDs],
      [[() => RequestSpotLaunchSpecificationSecurityGroupIdList, { [_xN]: _SGI }], [() => RequestSpotLaunchSpecificationSecurityGroupList, { [_xN]: _SGec }], [0, {
        [_eQN]: `AddressingType`,
        [_xN]: _aTddr
      }], [() => BlockDeviceMappingList, {
        [_eQN]: `BlockDeviceMapping`,
        [_xN]: _bDM
      }], [2, {
        [_eQN]: `EbsOptimized`,
        [_xN]: _eO
      }], [() => exports2.IamInstanceProfileSpecification$, {
        [_eQN]: `IamInstanceProfile`,
        [_xN]: _iIP
      }], [0, {
        [_eQN]: `ImageId`,
        [_xN]: _iIma
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [0, {
        [_eQN]: `KernelId`,
        [_xN]: _kI
      }], [0, {
        [_eQN]: `KeyName`,
        [_xN]: _kN
      }], [() => exports2.RunInstancesMonitoringEnabled$, {
        [_eQN]: `Monitoring`,
        [_xN]: _mo
      }], [() => InstanceNetworkInterfaceSpecificationList, { [_xN]: _NIe }], [() => exports2.SpotPlacement$, {
        [_eQN]: `Placement`,
        [_xN]: _pla
      }], [0, {
        [_eQN]: `RamdiskId`,
        [_xN]: _rIa
      }], [0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }], [() => SensitiveUserData, {
        [_eQN]: `UserData`,
        [_xN]: _uDs
      }]]
    ];
    exports2.Reservation$ = [
      3,
      n032,
      _Reser,
      0,
      [_RIe, _OI, _RIeq, _G, _Ins],
      [[0, {
        [_eQN]: `ReservationId`,
        [_xN]: _rI
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `RequesterId`,
        [_xN]: _rIeq
      }], [() => GroupIdentifierList, {
        [_eQN]: `GroupSet`,
        [_xN]: _gSr
      }], [() => InstanceList, {
        [_eQN]: `InstancesSet`,
        [_xN]: _iSn
      }]]
    ];
    exports2.ReservationFleetInstanceSpecification$ = [
      3,
      n032,
      _RFIS,
      0,
      [_IT4, _IPn, _We, _AZ, _AZI, _EO, _Prio],
      [0, 0, 1, 0, 0, 2, 1]
    ];
    exports2.ReservationValue$ = [
      3,
      n032,
      _RVe,
      0,
      [_HPo, _RTV, _RUV],
      [[0, {
        [_eQN]: `HourlyPrice`,
        [_xN]: _hPo
      }], [0, {
        [_eQN]: `RemainingTotalValue`,
        [_xN]: _rTV
      }], [0, {
        [_eQN]: `RemainingUpfrontValue`,
        [_xN]: _rUV
      }]]
    ];
    exports2.ReservedCapacityOptions$ = [
      3,
      n032,
      _RCO,
      0,
      [_RTese],
      [[() => ReservationTypeList, {
        [_eQN]: `ReservationTypeSet`,
        [_xN]: _rTSese
      }]]
    ];
    exports2.ReservedCapacityOptionsRequest$ = [
      3,
      n032,
      _RCOR,
      0,
      [_RTese],
      [[() => ReservationTypeListRequest, { [_xN]: _RT13 }]]
    ];
    exports2.ReservedInstanceLimitPrice$ = [
      3,
      n032,
      _RILP,
      0,
      [_Am, _CC],
      [[1, {
        [_eQN]: `Amount`,
        [_xN]: _am
      }], [0, {
        [_eQN]: `CurrencyCode`,
        [_xN]: _cC
      }]]
    ];
    exports2.ReservedInstanceReservationValue$ = [
      3,
      n032,
      _RIRV,
      0,
      [_RVe, _RIIe],
      [[() => exports2.ReservationValue$, {
        [_eQN]: `ReservationValue`,
        [_xN]: _rVe
      }], [0, {
        [_eQN]: `ReservedInstanceId`,
        [_xN]: _rIIe
      }]]
    ];
    exports2.ReservedInstances$ = [
      3,
      n032,
      _RIese,
      0,
      [_CC, _ITns, _OC, _OTf, _RCecu, _Sco, _T10, _AZI, _RIIes, _IT4, _AZ, _Star, _End, _Du, _UPs, _FPix, _IC, _PDr, _St],
      [[0, {
        [_eQN]: `CurrencyCode`,
        [_xN]: _cC
      }], [0, {
        [_eQN]: `InstanceTenancy`,
        [_xN]: _iTns
      }], [0, {
        [_eQN]: `OfferingClass`,
        [_xN]: _oC
      }], [0, {
        [_eQN]: `OfferingType`,
        [_xN]: _oTf
      }], [() => RecurringChargesList, {
        [_eQN]: `RecurringCharges`,
        [_xN]: _rCec
      }], [0, {
        [_eQN]: `Scope`,
        [_xN]: _sco
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [0, {
        [_eQN]: `ReservedInstancesId`,
        [_xN]: _rII
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [4, {
        [_eQN]: `Start`,
        [_xN]: _star
      }], [4, {
        [_eQN]: `End`,
        [_xN]: _end
      }], [1, {
        [_eQN]: `Duration`,
        [_xN]: _du
      }], [1, {
        [_eQN]: `UsagePrice`,
        [_xN]: _uPs
      }], [1, {
        [_eQN]: `FixedPrice`,
        [_xN]: _fPix
      }], [1, {
        [_eQN]: `InstanceCount`,
        [_xN]: _iC
      }], [0, {
        [_eQN]: `ProductDescription`,
        [_xN]: _pDr
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }]]
    ];
    exports2.ReservedInstancesConfiguration$ = [
      3,
      n032,
      _RIC,
      0,
      [_AZ, _IC, _IT4, _Pl, _Sco, _AZI],
      [[0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [1, {
        [_eQN]: `InstanceCount`,
        [_xN]: _iC
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [0, {
        [_eQN]: `Platform`,
        [_xN]: _pl
      }], [0, {
        [_eQN]: `Scope`,
        [_xN]: _sco
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }]]
    ];
    exports2.ReservedInstancesId$ = [
      3,
      n032,
      _RIIes,
      0,
      [_RIIes],
      [[0, {
        [_eQN]: `ReservedInstancesId`,
        [_xN]: _rII
      }]]
    ];
    exports2.ReservedInstancesListing$ = [
      3,
      n032,
      _RILe,
      0,
      [_CT4, _CD, _ICns, _PSri, _RIIes, _RILI, _Sta, _SMt, _T10, _UDpd],
      [[0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }], [4, {
        [_eQN]: `CreateDate`,
        [_xN]: _cD
      }], [() => InstanceCountList, {
        [_eQN]: `InstanceCounts`,
        [_xN]: _iCn
      }], [() => PriceScheduleList, {
        [_eQN]: `PriceSchedules`,
        [_xN]: _pSri
      }], [0, {
        [_eQN]: `ReservedInstancesId`,
        [_xN]: _rII
      }], [0, {
        [_eQN]: `ReservedInstancesListingId`,
        [_xN]: _rILI
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `StatusMessage`,
        [_xN]: _sMt
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [4, {
        [_eQN]: `UpdateDate`,
        [_xN]: _uDpd
      }]]
    ];
    exports2.ReservedInstancesModification$ = [
      3,
      n032,
      _RIMe,
      0,
      [_CT4, _CD, _EDf, _MRo, _RIIese, _RIMIe, _Sta, _SMt, _UDpd],
      [[0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }], [4, {
        [_eQN]: `CreateDate`,
        [_xN]: _cD
      }], [4, {
        [_eQN]: `EffectiveDate`,
        [_xN]: _eDf
      }], [() => ReservedInstancesModificationResultList, {
        [_eQN]: `ModificationResultSet`,
        [_xN]: _mRS
      }], [() => ReservedIntancesIds, {
        [_eQN]: `ReservedInstancesSet`,
        [_xN]: _rIS
      }], [0, {
        [_eQN]: `ReservedInstancesModificationId`,
        [_xN]: _rIMI
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `StatusMessage`,
        [_xN]: _sMt
      }], [4, {
        [_eQN]: `UpdateDate`,
        [_xN]: _uDpd
      }]]
    ];
    exports2.ReservedInstancesModificationResult$ = [
      3,
      n032,
      _RIMR,
      0,
      [_RIIes, _TCa],
      [[0, {
        [_eQN]: `ReservedInstancesId`,
        [_xN]: _rII
      }], [() => exports2.ReservedInstancesConfiguration$, {
        [_eQN]: `TargetConfiguration`,
        [_xN]: _tCar
      }]]
    ];
    exports2.ReservedInstancesOffering$ = [
      3,
      n032,
      _RIOe,
      0,
      [_CC, _ITns, _Mar, _OC, _OTf, _PDric, _RCecu, _Sco, _AZI, _RIOIe, _IT4, _AZ, _Du, _UPs, _FPix, _PDr],
      [[0, {
        [_eQN]: `CurrencyCode`,
        [_xN]: _cC
      }], [0, {
        [_eQN]: `InstanceTenancy`,
        [_xN]: _iTns
      }], [2, {
        [_eQN]: `Marketplace`,
        [_xN]: _mar
      }], [0, {
        [_eQN]: `OfferingClass`,
        [_xN]: _oC
      }], [0, {
        [_eQN]: `OfferingType`,
        [_xN]: _oTf
      }], [() => PricingDetailsList, {
        [_eQN]: `PricingDetailsSet`,
        [_xN]: _pDS
      }], [() => RecurringChargesList, {
        [_eQN]: `RecurringCharges`,
        [_xN]: _rCec
      }], [0, {
        [_eQN]: `Scope`,
        [_xN]: _sco
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [0, {
        [_eQN]: `ReservedInstancesOfferingId`,
        [_xN]: _rIOI
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [1, {
        [_eQN]: `Duration`,
        [_xN]: _du
      }], [1, {
        [_eQN]: `UsagePrice`,
        [_xN]: _uPs
      }], [1, {
        [_eQN]: `FixedPrice`,
        [_xN]: _fPix
      }], [0, {
        [_eQN]: `ProductDescription`,
        [_xN]: _pDr
      }]]
    ];
    exports2.ResetAddressAttributeRequest$ = [
      3,
      n032,
      _RAAR,
      0,
      [_AIl, _At, _DR],
      [0, 0, 2],
      2
    ];
    exports2.ResetAddressAttributeResult$ = [
      3,
      n032,
      _RAARe,
      0,
      [_A10],
      [[() => exports2.AddressAttribute$, {
        [_eQN]: `Address`,
        [_xN]: _ad
      }]]
    ];
    exports2.ResetEbsDefaultKmsKeyIdRequest$ = [
      3,
      n032,
      _REDKKIR,
      0,
      [_DR],
      [2]
    ];
    exports2.ResetEbsDefaultKmsKeyIdResult$ = [
      3,
      n032,
      _REDKKIRe,
      0,
      [_KKI],
      [[0, {
        [_eQN]: `KmsKeyId`,
        [_xN]: _kKI
      }]]
    ];
    exports2.ResetFpgaImageAttributeRequest$ = [
      3,
      n032,
      _RFIAR,
      0,
      [_FII, _DR, _At],
      [0, 2, 0],
      1
    ];
    exports2.ResetFpgaImageAttributeResult$ = [
      3,
      n032,
      _RFIARe,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.ResetImageAttributeRequest$ = [
      3,
      n032,
      _RIAR,
      0,
      [_At, _IIm, _DR],
      [0, 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      2
    ];
    exports2.ResetInstanceAttributeRequest$ = [
      3,
      n032,
      _RIARe,
      0,
      [_II2, _At, _DR],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `Attribute`,
        [_xN]: _att
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      2
    ];
    exports2.ResetNetworkInterfaceAttributeRequest$ = [
      3,
      n032,
      _RNIAR,
      0,
      [_NII, _DR, _SDC],
      [[0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [0, {
        [_eQN]: `SourceDestCheck`,
        [_xN]: _sDC
      }]],
      1
    ];
    exports2.ResetSnapshotAttributeRequest$ = [
      3,
      n032,
      _RSAR,
      0,
      [_At, _SIn, _DR],
      [0, 0, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      2
    ];
    exports2.ResourceStatement$ = [
      3,
      n032,
      _RSes,
      0,
      [_Res, _RTes],
      [[() => ValueStringList, {
        [_eQN]: `ResourceSet`,
        [_xN]: _rSesou
      }], [() => ValueStringList, {
        [_eQN]: `ResourceTypeSet`,
        [_xN]: _rTSe
      }]]
    ];
    exports2.ResourceStatementRequest$ = [
      3,
      n032,
      _RSRes,
      0,
      [_Res, _RTes],
      [[() => ValueStringList, { [_xN]: _Reso }], [() => ValueStringList, { [_xN]: _RTe }]]
    ];
    exports2.ResourceTypeOption$ = [
      3,
      n032,
      _RTOe,
      0,
      [_ON, _OV],
      [0, [64 | 0, { [_xN]: _OVp }]]
    ];
    exports2.ResourceTypeRequest$ = [
      3,
      n032,
      _RTRe,
      0,
      [_RTe, _RTO],
      [0, [() => ResourceTypeOptionList, { [_xN]: _RTOe }]]
    ];
    exports2.ResponseError$ = [
      3,
      n032,
      _REe,
      0,
      [_Co, _Me],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }]]
    ];
    exports2.ResponseLaunchTemplateData$ = [
      3,
      n032,
      _RLTDe,
      0,
      [_KI, _EO, _IIP, _BDMl, _NIet, _IIm, _IT4, _KN, _Mon, _Pla, _RDI, _DAT, _IISB, _UDs, _TS, _EGSlas, _EIAl, _SGIe, _SGe, _IMOns, _CSr, _CO, _CRSa, _LS, _HO, _MO, _EOn, _IRn, _PDNO, _MOa, _DASi, _Op, _NPO, _SIec],
      [[0, {
        [_eQN]: `KernelId`,
        [_xN]: _kI
      }], [2, {
        [_eQN]: `EbsOptimized`,
        [_xN]: _eO
      }], [() => exports2.LaunchTemplateIamInstanceProfileSpecification$, {
        [_eQN]: `IamInstanceProfile`,
        [_xN]: _iIP
      }], [() => LaunchTemplateBlockDeviceMappingList, {
        [_eQN]: `BlockDeviceMappingSet`,
        [_xN]: _bDMS
      }], [() => LaunchTemplateInstanceNetworkInterfaceSpecificationList, {
        [_eQN]: `NetworkInterfaceSet`,
        [_xN]: _nIS
      }], [0, {
        [_eQN]: `ImageId`,
        [_xN]: _iIma
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [0, {
        [_eQN]: `KeyName`,
        [_xN]: _kN
      }], [() => exports2.LaunchTemplatesMonitoring$, {
        [_eQN]: `Monitoring`,
        [_xN]: _mo
      }], [() => exports2.LaunchTemplatePlacement$, {
        [_eQN]: `Placement`,
        [_xN]: _pla
      }], [0, {
        [_eQN]: `RamDiskId`,
        [_xN]: _rDI
      }], [2, {
        [_eQN]: `DisableApiTermination`,
        [_xN]: _dAT
      }], [0, {
        [_eQN]: `InstanceInitiatedShutdownBehavior`,
        [_xN]: _iISB
      }], [() => SensitiveUserData, {
        [_eQN]: `UserData`,
        [_xN]: _uDs
      }], [() => LaunchTemplateTagSpecificationList, {
        [_eQN]: `TagSpecificationSet`,
        [_xN]: _tSS
      }], [() => ElasticGpuSpecificationResponseList, {
        [_eQN]: `ElasticGpuSpecificationSet`,
        [_xN]: _eGSS
      }], [() => LaunchTemplateElasticInferenceAcceleratorResponseList, {
        [_eQN]: `ElasticInferenceAcceleratorSet`,
        [_xN]: _eIAS
      }], [() => ValueStringList, {
        [_eQN]: `SecurityGroupIdSet`,
        [_xN]: _sGIS
      }], [() => ValueStringList, {
        [_eQN]: `SecurityGroupSet`,
        [_xN]: _sGSe
      }], [() => exports2.LaunchTemplateInstanceMarketOptions$, {
        [_eQN]: `InstanceMarketOptions`,
        [_xN]: _iMOn
      }], [() => exports2.CreditSpecification$, {
        [_eQN]: `CreditSpecification`,
        [_xN]: _cSr
      }], [() => exports2.LaunchTemplateCpuOptions$, {
        [_eQN]: `CpuOptions`,
        [_xN]: _cO
      }], [() => exports2.LaunchTemplateCapacityReservationSpecificationResponse$, {
        [_eQN]: `CapacityReservationSpecification`,
        [_xN]: _cRSa
      }], [() => LaunchTemplateLicenseList, {
        [_eQN]: `LicenseSet`,
        [_xN]: _lSi
      }], [() => exports2.LaunchTemplateHibernationOptions$, {
        [_eQN]: `HibernationOptions`,
        [_xN]: _hO
      }], [() => exports2.LaunchTemplateInstanceMetadataOptions$, {
        [_eQN]: `MetadataOptions`,
        [_xN]: _mO
      }], [() => exports2.LaunchTemplateEnclaveOptions$, {
        [_eQN]: `EnclaveOptions`,
        [_xN]: _eOn
      }], [() => exports2.InstanceRequirements$, {
        [_eQN]: `InstanceRequirements`,
        [_xN]: _iR
      }], [() => exports2.LaunchTemplatePrivateDnsNameOptions$, {
        [_eQN]: `PrivateDnsNameOptions`,
        [_xN]: _pDNO
      }], [() => exports2.LaunchTemplateInstanceMaintenanceOptions$, {
        [_eQN]: `MaintenanceOptions`,
        [_xN]: _mOa
      }], [2, {
        [_eQN]: `DisableApiStop`,
        [_xN]: _dASi
      }], [() => exports2.OperatorResponse$, {
        [_eQN]: `Operator`,
        [_xN]: _ope
      }], [() => exports2.LaunchTemplateNetworkPerformanceOptions$, {
        [_eQN]: `NetworkPerformanceOptions`,
        [_xN]: _nPO
      }], [() => LaunchTemplateInstanceSecondaryInterfaceSpecificationList, {
        [_eQN]: `SecondaryInterfaceSet`,
        [_xN]: _sISe
      }]]
    ];
    exports2.RestoreAddressToClassicRequest$ = [
      3,
      n032,
      _RATCR,
      0,
      [_PI10, _DR],
      [[0, {
        [_eQN]: `PublicIp`,
        [_xN]: _pI
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.RestoreAddressToClassicResult$ = [
      3,
      n032,
      _RATCRe,
      0,
      [_PI10, _Sta],
      [[0, {
        [_eQN]: `PublicIp`,
        [_xN]: _pI
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }]]
    ];
    exports2.RestoreImageFromRecycleBinRequest$ = [
      3,
      n032,
      _RIFRBR,
      0,
      [_IIm, _DR],
      [0, 2],
      1
    ];
    exports2.RestoreImageFromRecycleBinResult$ = [
      3,
      n032,
      _RIFRBRe,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.RestoreManagedPrefixListVersionRequest$ = [
      3,
      n032,
      _RMPLVR,
      0,
      [_PLI, _PVr, _CV4, _DR],
      [0, 1, 1, 2],
      3
    ];
    exports2.RestoreManagedPrefixListVersionResult$ = [
      3,
      n032,
      _RMPLVRe,
      0,
      [_PL],
      [[() => exports2.ManagedPrefixList$, {
        [_eQN]: `PrefixList`,
        [_xN]: _pL
      }]]
    ];
    exports2.RestoreSnapshotFromRecycleBinRequest$ = [
      3,
      n032,
      _RSFRBR,
      0,
      [_SIn, _DR],
      [0, 2],
      1
    ];
    exports2.RestoreSnapshotFromRecycleBinResult$ = [
      3,
      n032,
      _RSFRBRe,
      0,
      [_SIn, _OA, _De, _Enc, _OI, _Pro, _ST11, _St, _VIo, _VSo, _STs],
      [[0, {
        [_eQN]: `SnapshotId`,
        [_xN]: _sIn
      }], [0, {
        [_eQN]: `OutpostArn`,
        [_xN]: _oA
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [2, {
        [_eQN]: `Encrypted`,
        [_xN]: _enc
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `Progress`,
        [_xN]: _pro
      }], [4, {
        [_eQN]: `StartTime`,
        [_xN]: _sT19
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `VolumeId`,
        [_xN]: _vIo
      }], [1, {
        [_eQN]: `VolumeSize`,
        [_xN]: _vSo
      }], [0, {
        [_eQN]: `SseType`,
        [_xN]: _sTs
      }]]
    ];
    exports2.RestoreSnapshotTierRequest$ = [
      3,
      n032,
      _RSTR,
      0,
      [_SIn, _TRD, _PRer, _DR],
      [0, 1, 2, 2],
      1
    ];
    exports2.RestoreSnapshotTierResult$ = [
      3,
      n032,
      _RSTRe,
      0,
      [_SIn, _RSTe, _RD, _IPRs],
      [[0, {
        [_eQN]: `SnapshotId`,
        [_xN]: _sIn
      }], [4, {
        [_eQN]: `RestoreStartTime`,
        [_xN]: _rSTe
      }], [1, {
        [_eQN]: `RestoreDuration`,
        [_xN]: _rD
      }], [2, {
        [_eQN]: `IsPermanentRestore`,
        [_xN]: _iPRs
      }]]
    ];
    exports2.RestoreVolumeFromRecycleBinRequest$ = [
      3,
      n032,
      _RVFRBR,
      0,
      [_VIo, _DR],
      [0, 2],
      1
    ];
    exports2.RestoreVolumeFromRecycleBinResult$ = [
      3,
      n032,
      _RVFRBRe,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.RevokeClientVpnIngressRequest$ = [
      3,
      n032,
      _RCVIR,
      0,
      [_CVEI, _TNC, _AGI, _RAG, _DR],
      [0, 0, 0, 2, 2],
      2
    ];
    exports2.RevokeClientVpnIngressResult$ = [
      3,
      n032,
      _RCVIRe,
      0,
      [_Sta],
      [[() => exports2.ClientVpnAuthorizationRuleStatus$, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }]]
    ];
    exports2.RevokedSecurityGroupRule$ = [
      3,
      n032,
      _RSGR,
      0,
      [_SGRIe, _GIr, _IE, _IPpr, _FP, _TP, _CIidr, _CIid, _PLI, _RGI, _De],
      [[0, {
        [_eQN]: `SecurityGroupRuleId`,
        [_xN]: _sGRI
      }], [0, {
        [_eQN]: `GroupId`,
        [_xN]: _gIr
      }], [2, {
        [_eQN]: `IsEgress`,
        [_xN]: _iEs
      }], [0, {
        [_eQN]: `IpProtocol`,
        [_xN]: _iPp
      }], [1, {
        [_eQN]: `FromPort`,
        [_xN]: _fP
      }], [1, {
        [_eQN]: `ToPort`,
        [_xN]: _tP
      }], [0, {
        [_eQN]: `CidrIpv4`,
        [_xN]: _cIidr
      }], [0, {
        [_eQN]: `CidrIpv6`,
        [_xN]: _cIid
      }], [0, {
        [_eQN]: `PrefixListId`,
        [_xN]: _pLI
      }], [0, {
        [_eQN]: `ReferencedGroupId`,
        [_xN]: _rGI
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }]]
    ];
    exports2.RevokeSecurityGroupEgressRequest$ = [
      3,
      n032,
      _RSGER,
      0,
      [_GIr, _SGRI, _DR, _SSGN, _SSGOI, _IPpr, _FP, _TP, _CIi, _IPpe],
      [[0, {
        [_eQN]: `GroupId`,
        [_xN]: _gIr
      }], [() => SecurityGroupRuleIdList, { [_xN]: _SGRIe }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [0, {
        [_eQN]: `SourceSecurityGroupName`,
        [_xN]: _sSGN
      }], [0, {
        [_eQN]: `SourceSecurityGroupOwnerId`,
        [_xN]: _sSGOI
      }], [0, {
        [_eQN]: `IpProtocol`,
        [_xN]: _iPp
      }], [1, {
        [_eQN]: `FromPort`,
        [_xN]: _fP
      }], [1, {
        [_eQN]: `ToPort`,
        [_xN]: _tP
      }], [0, {
        [_eQN]: `CidrIp`,
        [_xN]: _cIi
      }], [() => IpPermissionList, {
        [_eQN]: `IpPermissions`,
        [_xN]: _iPpe
      }]],
      1
    ];
    exports2.RevokeSecurityGroupEgressResult$ = [
      3,
      n032,
      _RSGERe,
      0,
      [_R, _UIP, _RSGRe],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }], [() => IpPermissionList, {
        [_eQN]: `UnknownIpPermissionSet`,
        [_xN]: _uIPS
      }], [() => RevokedSecurityGroupRuleList, {
        [_eQN]: `RevokedSecurityGroupRuleSet`,
        [_xN]: _rSGRS
      }]]
    ];
    exports2.RevokeSecurityGroupIngressRequest$ = [
      3,
      n032,
      _RSGIR,
      0,
      [_CIi, _FP, _GIr, _GN, _IPpe, _IPpr, _SSGN, _SSGOI, _TP, _SGRI, _DR],
      [0, 1, 0, 0, [() => IpPermissionList, 0], 0, 0, 0, 1, [() => SecurityGroupRuleIdList, { [_xN]: _SGRIe }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]]
    ];
    exports2.RevokeSecurityGroupIngressResult$ = [
      3,
      n032,
      _RSGIRe,
      0,
      [_R, _UIP, _RSGRe],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }], [() => IpPermissionList, {
        [_eQN]: `UnknownIpPermissionSet`,
        [_xN]: _uIPS
      }], [() => RevokedSecurityGroupRuleList, {
        [_eQN]: `RevokedSecurityGroupRuleSet`,
        [_xN]: _rSGRS
      }]]
    ];
    exports2.Route$ = [
      3,
      n032,
      _Ro,
      0,
      [_DCB, _DICB, _DPLI, _EOIGI, _GI2, _II2, _IOIn, _NGI, _TGI, _LGI, _CGI, _NII, _O, _St, _VPCI, _CNA, _ONA, _IAp],
      [[0, {
        [_eQN]: `DestinationCidrBlock`,
        [_xN]: _dCB
      }], [0, {
        [_eQN]: `DestinationIpv6CidrBlock`,
        [_xN]: _dICB
      }], [0, {
        [_eQN]: `DestinationPrefixListId`,
        [_xN]: _dPLI
      }], [0, {
        [_eQN]: `EgressOnlyInternetGatewayId`,
        [_xN]: _eOIGI
      }], [0, {
        [_eQN]: `GatewayId`,
        [_xN]: _gI
      }], [0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `InstanceOwnerId`,
        [_xN]: _iOIn
      }], [0, {
        [_eQN]: `NatGatewayId`,
        [_xN]: _nGI
      }], [0, {
        [_eQN]: `TransitGatewayId`,
        [_xN]: _tGI
      }], [0, {
        [_eQN]: `LocalGatewayId`,
        [_xN]: _lGI
      }], [0, {
        [_eQN]: `CarrierGatewayId`,
        [_xN]: _cGI
      }], [0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], [0, {
        [_eQN]: `Origin`,
        [_xN]: _o
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `VpcPeeringConnectionId`,
        [_xN]: _vPCI
      }], [0, {
        [_eQN]: `CoreNetworkArn`,
        [_xN]: _cNA
      }], [0, {
        [_eQN]: `OdbNetworkArn`,
        [_xN]: _oNA
      }], [0, {
        [_eQN]: `IpAddress`,
        [_xN]: _iAp
      }]]
    ];
    exports2.RouteServer$ = [
      3,
      n032,
      _RSo,
      0,
      [_RSI, _ASA, _St, _T10, _PRS, _PRD, _SNE, _STA],
      [[0, {
        [_eQN]: `RouteServerId`,
        [_xN]: _rSI
      }], [1, {
        [_eQN]: `AmazonSideAsn`,
        [_xN]: _aSA
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `PersistRoutesState`,
        [_xN]: _pRSe
      }], [1, {
        [_eQN]: `PersistRoutesDuration`,
        [_xN]: _pRD
      }], [2, {
        [_eQN]: `SnsNotificationsEnabled`,
        [_xN]: _sNE
      }], [0, {
        [_eQN]: `SnsTopicArn`,
        [_xN]: _sTA
      }]]
    ];
    exports2.RouteServerAssociation$ = [
      3,
      n032,
      _RSA,
      0,
      [_RSI, _VI, _St],
      [[0, {
        [_eQN]: `RouteServerId`,
        [_xN]: _rSI
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }]]
    ];
    exports2.RouteServerBfdStatus$ = [
      3,
      n032,
      _RSBS,
      0,
      [_Sta],
      [[0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }]]
    ];
    exports2.RouteServerBgpOptions$ = [
      3,
      n032,
      _RSBO,
      0,
      [_PAee, _PLD],
      [[1, {
        [_eQN]: `PeerAsn`,
        [_xN]: _pAee
      }], [0, {
        [_eQN]: `PeerLivenessDetection`,
        [_xN]: _pLD
      }]]
    ];
    exports2.RouteServerBgpOptionsRequest$ = [
      3,
      n032,
      _RSBOR,
      0,
      [_PAee, _PLD],
      [1, 0],
      1
    ];
    exports2.RouteServerBgpStatus$ = [
      3,
      n032,
      _RSBSo,
      0,
      [_Sta],
      [[0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }]]
    ];
    exports2.RouteServerEndpoint$ = [
      3,
      n032,
      _RSE,
      0,
      [_RSI, _RSEI, _VI, _SIu, _EIn, _EA, _St, _FR, _T10],
      [[0, {
        [_eQN]: `RouteServerId`,
        [_xN]: _rSI
      }], [0, {
        [_eQN]: `RouteServerEndpointId`,
        [_xN]: _rSEI
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }], [0, {
        [_eQN]: `EniId`,
        [_xN]: _eIn
      }], [0, {
        [_eQN]: `EniAddress`,
        [_xN]: _eA
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `FailureReason`,
        [_xN]: _fR
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.RouteServerPeer$ = [
      3,
      n032,
      _RSP,
      0,
      [_RSPI, _RSEI, _RSI, _VI, _SIu, _St, _FR, _EEI, _EEA, _PAe, _BO, _BSg, _BSf, _T10],
      [[0, {
        [_eQN]: `RouteServerPeerId`,
        [_xN]: _rSPI
      }], [0, {
        [_eQN]: `RouteServerEndpointId`,
        [_xN]: _rSEI
      }], [0, {
        [_eQN]: `RouteServerId`,
        [_xN]: _rSI
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `FailureReason`,
        [_xN]: _fR
      }], [0, {
        [_eQN]: `EndpointEniId`,
        [_xN]: _eEI
      }], [0, {
        [_eQN]: `EndpointEniAddress`,
        [_xN]: _eEA
      }], [0, {
        [_eQN]: `PeerAddress`,
        [_xN]: _pAe
      }], [() => exports2.RouteServerBgpOptions$, {
        [_eQN]: `BgpOptions`,
        [_xN]: _bO
      }], [() => exports2.RouteServerBgpStatus$, {
        [_eQN]: `BgpStatus`,
        [_xN]: _bSg
      }], [() => exports2.RouteServerBfdStatus$, {
        [_eQN]: `BfdStatus`,
        [_xN]: _bSf
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.RouteServerPropagation$ = [
      3,
      n032,
      _RSPou,
      0,
      [_RSI, _RTI, _St],
      [[0, {
        [_eQN]: `RouteServerId`,
        [_xN]: _rSI
      }], [0, {
        [_eQN]: `RouteTableId`,
        [_xN]: _rTI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }]]
    ];
    exports2.RouteServerRoute$ = [
      3,
      n032,
      _RSRo,
      0,
      [_RSEI, _RSPI, _RID, _RSout, _Pre, _APs, _Med, _NHI],
      [[0, {
        [_eQN]: `RouteServerEndpointId`,
        [_xN]: _rSEI
      }], [0, {
        [_eQN]: `RouteServerPeerId`,
        [_xN]: _rSPI
      }], [() => RouteServerRouteInstallationDetails, {
        [_eQN]: `RouteInstallationDetailSet`,
        [_xN]: _rIDS
      }], [0, {
        [_eQN]: `RouteStatus`,
        [_xN]: _rSout
      }], [0, {
        [_eQN]: `Prefix`,
        [_xN]: _pre
      }], [() => AsPath, {
        [_eQN]: `AsPathSet`,
        [_xN]: _aPSs
      }], [1, {
        [_eQN]: `Med`,
        [_xN]: _med
      }], [0, {
        [_eQN]: `NextHopIp`,
        [_xN]: _nHI
      }]]
    ];
    exports2.RouteServerRouteInstallationDetail$ = [
      3,
      n032,
      _RSRID,
      0,
      [_RTI, _RIS, _RISRo],
      [[0, {
        [_eQN]: `RouteTableId`,
        [_xN]: _rTI
      }], [0, {
        [_eQN]: `RouteInstallationStatus`,
        [_xN]: _rISo
      }], [0, {
        [_eQN]: `RouteInstallationStatusReason`,
        [_xN]: _rISR
      }]]
    ];
    exports2.RouteTable$ = [
      3,
      n032,
      _RTo,
      0,
      [_As, _PVro, _RTI, _Rou, _T10, _VI, _OI],
      [[() => RouteTableAssociationList, {
        [_eQN]: `AssociationSet`,
        [_xN]: _aSss
      }], [() => PropagatingVgwList, {
        [_eQN]: `PropagatingVgwSet`,
        [_xN]: _pVS
      }], [0, {
        [_eQN]: `RouteTableId`,
        [_xN]: _rTI
      }], [() => RouteList, {
        [_eQN]: `RouteSet`,
        [_xN]: _rSou
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }]]
    ];
    exports2.RouteTableAssociation$ = [
      3,
      n032,
      _RTA,
      0,
      [_Mai, _RTAI, _RTI, _SIu, _GI2, _PIP, _AS],
      [[2, {
        [_eQN]: `Main`,
        [_xN]: _mai
      }], [0, {
        [_eQN]: `RouteTableAssociationId`,
        [_xN]: _rTAI
      }], [0, {
        [_eQN]: `RouteTableId`,
        [_xN]: _rTI
      }], [0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }], [0, {
        [_eQN]: `GatewayId`,
        [_xN]: _gI
      }], [0, {
        [_eQN]: `PublicIpv4Pool`,
        [_xN]: _pIP
      }], [() => exports2.RouteTableAssociationState$, {
        [_eQN]: `AssociationState`,
        [_xN]: _aS
      }]]
    ];
    exports2.RouteTableAssociationState$ = [
      3,
      n032,
      _RTAS,
      0,
      [_St, _SMt],
      [[0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `StatusMessage`,
        [_xN]: _sMt
      }]]
    ];
    exports2.RuleGroupRuleOptionsPair$ = [
      3,
      n032,
      _RGROPu,
      0,
      [_RGA, _RO],
      [[0, {
        [_eQN]: `RuleGroupArn`,
        [_xN]: _rGA
      }], [() => RuleOptionList, {
        [_eQN]: `RuleOptionSet`,
        [_xN]: _rOS
      }]]
    ];
    exports2.RuleGroupTypePair$ = [
      3,
      n032,
      _RGTPu,
      0,
      [_RGA, _RGT],
      [[0, {
        [_eQN]: `RuleGroupArn`,
        [_xN]: _rGA
      }], [0, {
        [_eQN]: `RuleGroupType`,
        [_xN]: _rGT
      }]]
    ];
    exports2.RuleOption$ = [
      3,
      n032,
      _ROu,
      0,
      [_Key, _Set],
      [[0, {
        [_eQN]: `Keyword`,
        [_xN]: _key
      }], [() => StringList, {
        [_eQN]: `SettingSet`,
        [_xN]: _sSe
      }]]
    ];
    exports2.RunInstancesMonitoringEnabled$ = [
      3,
      n032,
      _RIME,
      0,
      [_En],
      [[2, {
        [_eQN]: `Enabled`,
        [_xN]: _en
      }]],
      1
    ];
    exports2.RunInstancesRequest$ = [
      3,
      n032,
      _RIRu,
      0,
      [_MCa, _MCin, _BDMl, _IIm, _IT4, _IAC, _IA, _KI, _KN, _Mon, _Pla, _RIa, _SGIe, _SGe, _SIu, _UDs, _EGSla, _EIAl, _TS, _LT, _IMOns, _CSr, _CO, _CRSa, _HO, _LS, _MO, _EOn, _PDNO, _MOa, _DASi, _EPI, _NPO, _Op, _SIec, _DR, _DAT, _IISB, _PIAr, _CT4, _AId, _NIet, _IIP, _EO],
      [1, 1, [() => BlockDeviceMappingRequestList, { [_xN]: _BDM }], 0, 0, 1, [() => InstanceIpv6AddressList, { [_xN]: _IApv }], 0, 0, [() => exports2.RunInstancesMonitoringEnabled$, 0], [() => exports2.Placement$, 0], 0, [() => SecurityGroupIdStringList, { [_xN]: _SGI }], [() => SecurityGroupStringList, { [_xN]: _SGec }], 0, [() => RunInstancesUserData, 0], [() => ElasticGpuSpecifications, 0], [() => ElasticInferenceAccelerators, { [_xN]: _EIA }], [() => TagSpecificationList, { [_xN]: _TSa }], () => exports2.LaunchTemplateSpecification$, () => exports2.InstanceMarketOptionsRequest$, () => exports2.CreditSpecificationRequest$, () => exports2.CpuOptionsRequest$, () => exports2.CapacityReservationSpecification$, () => exports2.HibernationOptionsRequest$, [() => LicenseSpecificationListRequest, { [_xN]: _LSi }], () => exports2.InstanceMetadataOptionsRequest$, () => exports2.EnclaveOptionsRequest$, () => exports2.PrivateDnsNameOptionsRequest$, () => exports2.InstanceMaintenanceOptionsRequest$, 2, 2, () => exports2.InstanceNetworkPerformanceOptionsRequest$, () => exports2.OperatorRequest$, [() => InstanceSecondaryInterfaceSpecificationListRequest, { [_xN]: _SIeco }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [2, {
        [_eQN]: `DisableApiTermination`,
        [_xN]: _dAT
      }], [0, {
        [_eQN]: `InstanceInitiatedShutdownBehavior`,
        [_xN]: _iISB
      }], [0, {
        [_eQN]: `PrivateIpAddress`,
        [_xN]: _pIAr
      }], [0, {
        [_eQN]: `ClientToken`,
        [_iTd]: 1,
        [_xN]: _cT
      }], [0, {
        [_eQN]: `AdditionalInfo`,
        [_xN]: _aId
      }], [() => InstanceNetworkInterfaceSpecificationList, {
        [_eQN]: `NetworkInterface`,
        [_xN]: _nIe
      }], [() => exports2.IamInstanceProfileSpecification$, {
        [_eQN]: `IamInstanceProfile`,
        [_xN]: _iIP
      }], [2, {
        [_eQN]: `EbsOptimized`,
        [_xN]: _eO
      }]],
      2
    ];
    exports2.RunScheduledInstancesRequest$ = [
      3,
      n032,
      _RSIRu,
      0,
      [_LSa, _SIIch, _CT4, _DR, _IC],
      [[() => exports2.ScheduledInstancesLaunchSpecification$, 0], 0, [0, 4], 2, 1],
      2
    ];
    exports2.RunScheduledInstancesResult$ = [
      3,
      n032,
      _RSIRun,
      0,
      [_IIS],
      [[() => InstanceIdSet, {
        [_eQN]: `InstanceIdSet`,
        [_xN]: _iIS
      }]]
    ];
    exports2.S3ObjectTag$ = [
      3,
      n032,
      _SOTb,
      0,
      [_K10, _V10],
      [0, 0]
    ];
    exports2.S3Storage$ = [
      3,
      n032,
      _SSt,
      0,
      [_AWSAKI, _Bu, _Pre, _UPp, _UPS],
      [0, [0, {
        [_eQN]: `Bucket`,
        [_xN]: _b
      }], [0, {
        [_eQN]: `Prefix`,
        [_xN]: _pre
      }], [21, {
        [_eQN]: `UploadPolicy`,
        [_xN]: _uPp
      }], [() => S3StorageUploadPolicySignature, {
        [_eQN]: `UploadPolicySignature`,
        [_xN]: _uPS
      }]]
    ];
    exports2.ScheduledInstance$ = [
      3,
      n032,
      _SIc,
      0,
      [_AZ, _CD, _HPo, _IC, _IT4, _NPet, _NSST, _Pl, _PSET, _Rec, _SIIch, _SDIH, _TED, _TSD, _TSIH],
      [[0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [4, {
        [_eQN]: `CreateDate`,
        [_xN]: _cD
      }], [0, {
        [_eQN]: `HourlyPrice`,
        [_xN]: _hPo
      }], [1, {
        [_eQN]: `InstanceCount`,
        [_xN]: _iC
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [0, {
        [_eQN]: `NetworkPlatform`,
        [_xN]: _nPet
      }], [4, {
        [_eQN]: `NextSlotStartTime`,
        [_xN]: _nSST
      }], [0, {
        [_eQN]: `Platform`,
        [_xN]: _pl
      }], [4, {
        [_eQN]: `PreviousSlotEndTime`,
        [_xN]: _pSET
      }], [() => exports2.ScheduledInstanceRecurrence$, {
        [_eQN]: `Recurrence`,
        [_xN]: _rec
      }], [0, {
        [_eQN]: `ScheduledInstanceId`,
        [_xN]: _sIIc
      }], [1, {
        [_eQN]: `SlotDurationInHours`,
        [_xN]: _sDIH
      }], [4, {
        [_eQN]: `TermEndDate`,
        [_xN]: _tED
      }], [4, {
        [_eQN]: `TermStartDate`,
        [_xN]: _tSD
      }], [1, {
        [_eQN]: `TotalScheduledInstanceHours`,
        [_xN]: _tSIH
      }]]
    ];
    exports2.ScheduledInstanceAvailability$ = [
      3,
      n032,
      _SIA,
      0,
      [_AZ, _AICv, _FSST, _HPo, _IT4, _MTDID, _MTDIDi, _NPet, _Pl, _PTu, _Rec, _SDIH, _TSIH],
      [[0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [1, {
        [_eQN]: `AvailableInstanceCount`,
        [_xN]: _aICv
      }], [4, {
        [_eQN]: `FirstSlotStartTime`,
        [_xN]: _fSST
      }], [0, {
        [_eQN]: `HourlyPrice`,
        [_xN]: _hPo
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [1, {
        [_eQN]: `MaxTermDurationInDays`,
        [_xN]: _mTDID
      }], [1, {
        [_eQN]: `MinTermDurationInDays`,
        [_xN]: _mTDIDi
      }], [0, {
        [_eQN]: `NetworkPlatform`,
        [_xN]: _nPet
      }], [0, {
        [_eQN]: `Platform`,
        [_xN]: _pl
      }], [0, {
        [_eQN]: `PurchaseToken`,
        [_xN]: _pTu
      }], [() => exports2.ScheduledInstanceRecurrence$, {
        [_eQN]: `Recurrence`,
        [_xN]: _rec
      }], [1, {
        [_eQN]: `SlotDurationInHours`,
        [_xN]: _sDIH
      }], [1, {
        [_eQN]: `TotalScheduledInstanceHours`,
        [_xN]: _tSIH
      }]]
    ];
    exports2.ScheduledInstanceRecurrence$ = [
      3,
      n032,
      _SIRc,
      0,
      [_Fre, _Inte, _ODS, _ORTE, _OU],
      [[0, {
        [_eQN]: `Frequency`,
        [_xN]: _fre
      }], [1, {
        [_eQN]: `Interval`,
        [_xN]: _inte
      }], [() => OccurrenceDaySet, {
        [_eQN]: `OccurrenceDaySet`,
        [_xN]: _oDS
      }], [2, {
        [_eQN]: `OccurrenceRelativeToEnd`,
        [_xN]: _oRTE
      }], [0, {
        [_eQN]: `OccurrenceUnit`,
        [_xN]: _oU
      }]]
    ];
    exports2.ScheduledInstanceRecurrenceRequest$ = [
      3,
      n032,
      _SIRR,
      0,
      [_Fre, _Inte, _OD, _ORTE, _OU],
      [0, 1, [() => OccurrenceDayRequestSet, { [_xN]: _ODc }], 2, 0]
    ];
    exports2.ScheduledInstancesBlockDeviceMapping$ = [
      3,
      n032,
      _SIBDM,
      0,
      [_DN, _Eb, _ND, _VN],
      [0, () => exports2.ScheduledInstancesEbs$, 0, 0]
    ];
    exports2.ScheduledInstancesEbs$ = [
      3,
      n032,
      _SIE,
      0,
      [_DOT, _Enc, _Io, _SIn, _VSo, _VT],
      [2, 2, 1, 0, 1, 0]
    ];
    exports2.ScheduledInstancesIamInstanceProfile$ = [
      3,
      n032,
      _SIIIP,
      0,
      [_Ar, _N],
      [0, 0]
    ];
    exports2.ScheduledInstancesIpv6Address$ = [
      3,
      n032,
      _SIIA,
      0,
      [_IApv],
      [0]
    ];
    exports2.ScheduledInstancesLaunchSpecification$ = [
      3,
      n032,
      _SILS,
      8,
      [_IIm, _BDMl, _EO, _IIP, _IT4, _KI, _KN, _Mon, _NIet, _Pla, _RIa, _SGIe, _SIu, _UDs],
      [0, [() => ScheduledInstancesBlockDeviceMappingSet, { [_xN]: _BDM }], 2, () => exports2.ScheduledInstancesIamInstanceProfile$, 0, 0, 0, () => exports2.ScheduledInstancesMonitoring$, [() => ScheduledInstancesNetworkInterfaceSet, { [_xN]: _NIe }], () => exports2.ScheduledInstancesPlacement$, 0, [() => ScheduledInstancesSecurityGroupIdSet, { [_xN]: _SGI }], 0, 0],
      1
    ];
    exports2.ScheduledInstancesMonitoring$ = [
      3,
      n032,
      _SIM,
      0,
      [_En],
      [2]
    ];
    exports2.ScheduledInstancesNetworkInterface$ = [
      3,
      n032,
      _SINI,
      0,
      [_APIAss, _DOT, _De, _DI, _G, _IAC, _IA, _NII, _PIAr, _PIACr, _SPIAC, _SIu],
      [2, 2, 0, 1, [() => ScheduledInstancesSecurityGroupIdSet, { [_xN]: _Gr }], 1, [() => ScheduledInstancesIpv6AddressList, { [_xN]: _IApv }], 0, 0, [() => PrivateIpAddressConfigSet, { [_xN]: _PIACri }], 1, 0]
    ];
    exports2.ScheduledInstancesPlacement$ = [
      3,
      n032,
      _SIP,
      0,
      [_AZ, _GN],
      [0, 0]
    ];
    exports2.ScheduledInstancesPrivateIpAddressConfig$ = [
      3,
      n032,
      _SIPIAC,
      0,
      [_Prim, _PIAr],
      [2, 0]
    ];
    exports2.SearchLocalGatewayRoutesRequest$ = [
      3,
      n032,
      _SLGRR,
      0,
      [_LGRTI, _Fi, _MR, _NTe, _DR],
      [0, [() => FilterList, { [_xN]: _Fil }], 1, 0, 2],
      1
    ];
    exports2.SearchLocalGatewayRoutesResult$ = [
      3,
      n032,
      _SLGRRe,
      0,
      [_Rou, _NTe],
      [[() => LocalGatewayRouteList, {
        [_eQN]: `RouteSet`,
        [_xN]: _rSou
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.SearchTransitGatewayMulticastGroupsRequest$ = [
      3,
      n032,
      _STGMGR,
      0,
      [_TGMDI, _Fi, _MR, _NTe, _DR],
      [0, [() => FilterList, { [_xN]: _Fil }], 1, 0, 2],
      1
    ];
    exports2.SearchTransitGatewayMulticastGroupsResult$ = [
      3,
      n032,
      _STGMGRe,
      0,
      [_MG, _NTe],
      [[() => TransitGatewayMulticastGroupList, {
        [_eQN]: `MulticastGroups`,
        [_xN]: _mG
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.SearchTransitGatewayRoutesRequest$ = [
      3,
      n032,
      _STGRR,
      0,
      [_TGRTI, _Fi, _MR, _DR, _NTe],
      [0, [() => FilterList, { [_xN]: _Fil }], 1, 2, 0],
      2
    ];
    exports2.SearchTransitGatewayRoutesResult$ = [
      3,
      n032,
      _STGRRe,
      0,
      [_Rou, _ARAd, _NTe],
      [[() => TransitGatewayRouteList, {
        [_eQN]: `RouteSet`,
        [_xN]: _rSou
      }], [2, {
        [_eQN]: `AdditionalRoutesAvailable`,
        [_xN]: _aRAd
      }], [0, {
        [_eQN]: `NextToken`,
        [_xN]: _nTe
      }]]
    ];
    exports2.SecondaryInterface$ = [
      3,
      n032,
      _SIeco,
      0,
      [_AZ, _AZI, _Att, _MAa, _OI, _PIAriv, _SIIec, _SIAe, _SITe, _SSIe, _SNI, _SNT, _SDC, _Sta, _T10],
      [[0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [() => exports2.SecondaryInterfaceAttachment$, {
        [_eQN]: `Attachment`,
        [_xN]: _at
      }], [0, {
        [_eQN]: `MacAddress`,
        [_xN]: _mAa
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [() => SecondaryInterfaceIpv4AddressList, {
        [_eQN]: `PrivateIpv4AddressSet`,
        [_xN]: _pIASri
      }], [0, {
        [_eQN]: `SecondaryInterfaceId`,
        [_xN]: _sIIe
      }], [0, {
        [_eQN]: `SecondaryInterfaceArn`,
        [_xN]: _sIA
      }], [0, {
        [_eQN]: `SecondaryInterfaceType`,
        [_xN]: _sITe
      }], [0, {
        [_eQN]: `SecondarySubnetId`,
        [_xN]: _sSI
      }], [0, {
        [_eQN]: `SecondaryNetworkId`,
        [_xN]: _sNI
      }], [0, {
        [_eQN]: `SecondaryNetworkType`,
        [_xN]: _sNT
      }], [2, {
        [_eQN]: `SourceDestCheck`,
        [_xN]: _sDC
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.SecondaryInterfaceAttachment$ = [
      3,
      n032,
      _SIAec,
      0,
      [_AItt, _ATtt, _DOT, _DI, _II2, _IOIn, _NCI, _Sta],
      [[0, {
        [_eQN]: `AttachmentId`,
        [_xN]: _aIt
      }], [4, {
        [_eQN]: `AttachTime`,
        [_xN]: _aTt
      }], [2, {
        [_eQN]: `DeleteOnTermination`,
        [_xN]: _dOT
      }], [1, {
        [_eQN]: `DeviceIndex`,
        [_xN]: _dI
      }], [0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `InstanceOwnerId`,
        [_xN]: _iOIn
      }], [1, {
        [_eQN]: `NetworkCardIndex`,
        [_xN]: _nCI
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }]]
    ];
    exports2.SecondaryInterfaceIpv4Address$ = [
      3,
      n032,
      _SIIAe,
      0,
      [_PIAr],
      [[0, {
        [_eQN]: `PrivateIpAddress`,
        [_xN]: _pIAr
      }]]
    ];
    exports2.SecondaryInterfacePrivateIpAddressSpecification$ = [
      3,
      n032,
      _SIPIAS,
      0,
      [_PIAr],
      [[0, {
        [_eQN]: `PrivateIpAddress`,
        [_xN]: _pIAr
      }]]
    ];
    exports2.SecondaryInterfacePrivateIpAddressSpecificationRequest$ = [
      3,
      n032,
      _SIPIASR,
      0,
      [_PIAr],
      [0]
    ];
    exports2.SecondaryNetwork$ = [
      3,
      n032,
      _SNe,
      0,
      [_SNI, _SNAe, _OI, _Ty, _St, _SRt, _ICBAp, _T10],
      [[0, {
        [_eQN]: `SecondaryNetworkId`,
        [_xN]: _sNI
      }], [0, {
        [_eQN]: `SecondaryNetworkArn`,
        [_xN]: _sNA
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `Type`,
        [_xN]: _ty
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `StateReason`,
        [_xN]: _sRt
      }], [() => SecondaryNetworkIpv4CidrBlockAssociationList, {
        [_eQN]: `Ipv4CidrBlockAssociationSet`,
        [_xN]: _iCBAS
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.SecondaryNetworkIpv4CidrBlockAssociation$ = [
      3,
      n032,
      _SNICBA,
      0,
      [_AIs, _CB, _St, _SRt],
      [[0, {
        [_eQN]: `AssociationId`,
        [_xN]: _aIs
      }], [0, {
        [_eQN]: `CidrBlock`,
        [_xN]: _cB
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `StateReason`,
        [_xN]: _sRt
      }]]
    ];
    exports2.SecondarySubnet$ = [
      3,
      n032,
      _SS,
      0,
      [_SSIe, _SSA, _SNI, _SNT, _OI, _AZI, _AZ, _ICBAp, _St, _SRt, _T10],
      [[0, {
        [_eQN]: `SecondarySubnetId`,
        [_xN]: _sSI
      }], [0, {
        [_eQN]: `SecondarySubnetArn`,
        [_xN]: _sSA
      }], [0, {
        [_eQN]: `SecondaryNetworkId`,
        [_xN]: _sNI
      }], [0, {
        [_eQN]: `SecondaryNetworkType`,
        [_xN]: _sNT
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [() => SecondarySubnetIpv4CidrBlockAssociationList, {
        [_eQN]: `Ipv4CidrBlockAssociationSet`,
        [_xN]: _iCBAS
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `StateReason`,
        [_xN]: _sRt
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.SecondarySubnetIpv4CidrBlockAssociation$ = [
      3,
      n032,
      _SSICBA,
      0,
      [_AIs, _CB, _St, _SRt],
      [[0, {
        [_eQN]: `AssociationId`,
        [_xN]: _aIs
      }], [0, {
        [_eQN]: `CidrBlock`,
        [_xN]: _cB
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `StateReason`,
        [_xN]: _sRt
      }]]
    ];
    exports2.SecurityGroup$ = [
      3,
      n032,
      _SGec,
      0,
      [_GIr, _IPEp, _T10, _VI, _SGA, _OI, _GN, _De, _IPpe],
      [[0, {
        [_eQN]: `GroupId`,
        [_xN]: _gIr
      }], [() => IpPermissionList, {
        [_eQN]: `IpPermissionsEgress`,
        [_xN]: _iPEp
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [0, {
        [_eQN]: `SecurityGroupArn`,
        [_xN]: _sGA
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `GroupName`,
        [_xN]: _gN
      }], [0, {
        [_eQN]: `GroupDescription`,
        [_xN]: _gD
      }], [() => IpPermissionList, {
        [_eQN]: `IpPermissions`,
        [_xN]: _iPpe
      }]]
    ];
    exports2.SecurityGroupForVpc$ = [
      3,
      n032,
      _SGFVe,
      0,
      [_De, _GN, _OI, _GIr, _T10, _PVIr],
      [[0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [0, {
        [_eQN]: `GroupName`,
        [_xN]: _gN
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `GroupId`,
        [_xN]: _gIr
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `PrimaryVpcId`,
        [_xN]: _pVIr
      }]]
    ];
    exports2.SecurityGroupIdentifier$ = [
      3,
      n032,
      _SGIec,
      0,
      [_GIr, _GN],
      [[0, {
        [_eQN]: `GroupId`,
        [_xN]: _gIr
      }], [0, {
        [_eQN]: `GroupName`,
        [_xN]: _gN
      }]]
    ];
    exports2.SecurityGroupReference$ = [
      3,
      n032,
      _SGRec,
      0,
      [_GIr, _RVI, _VPCI, _TGI],
      [[0, {
        [_eQN]: `GroupId`,
        [_xN]: _gIr
      }], [0, {
        [_eQN]: `ReferencingVpcId`,
        [_xN]: _rVI
      }], [0, {
        [_eQN]: `VpcPeeringConnectionId`,
        [_xN]: _vPCI
      }], [0, {
        [_eQN]: `TransitGatewayId`,
        [_xN]: _tGI
      }]]
    ];
    exports2.SecurityGroupRule$ = [
      3,
      n032,
      _SGRe,
      0,
      [_SGRIe, _GIr, _GOI, _IE, _IPpr, _FP, _TP, _CIidr, _CIid, _PLI, _RGIe, _De, _T10, _SGRA],
      [[0, {
        [_eQN]: `SecurityGroupRuleId`,
        [_xN]: _sGRI
      }], [0, {
        [_eQN]: `GroupId`,
        [_xN]: _gIr
      }], [0, {
        [_eQN]: `GroupOwnerId`,
        [_xN]: _gOI
      }], [2, {
        [_eQN]: `IsEgress`,
        [_xN]: _iEs
      }], [0, {
        [_eQN]: `IpProtocol`,
        [_xN]: _iPp
      }], [1, {
        [_eQN]: `FromPort`,
        [_xN]: _fP
      }], [1, {
        [_eQN]: `ToPort`,
        [_xN]: _tP
      }], [0, {
        [_eQN]: `CidrIpv4`,
        [_xN]: _cIidr
      }], [0, {
        [_eQN]: `CidrIpv6`,
        [_xN]: _cIid
      }], [0, {
        [_eQN]: `PrefixListId`,
        [_xN]: _pLI
      }], [() => exports2.ReferencedSecurityGroup$, {
        [_eQN]: `ReferencedGroupInfo`,
        [_xN]: _rGIe
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `SecurityGroupRuleArn`,
        [_xN]: _sGRA
      }]]
    ];
    exports2.SecurityGroupRuleDescription$ = [
      3,
      n032,
      _SGRD,
      0,
      [_SGRIe, _De],
      [0, 0]
    ];
    exports2.SecurityGroupRuleRequest$ = [
      3,
      n032,
      _SGRR,
      0,
      [_IPpr, _FP, _TP, _CIidr, _CIid, _PLI, _RGI, _De],
      [0, 1, 1, 0, 0, 0, 0, 0]
    ];
    exports2.SecurityGroupRuleUpdate$ = [
      3,
      n032,
      _SGRU,
      0,
      [_SGRIe, _SGRe],
      [0, () => exports2.SecurityGroupRuleRequest$],
      1
    ];
    exports2.SecurityGroupVpcAssociation$ = [
      3,
      n032,
      _SGVAe,
      0,
      [_GIr, _VI, _VOIp, _St, _SRt, _GOI],
      [[0, {
        [_eQN]: `GroupId`,
        [_xN]: _gIr
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [0, {
        [_eQN]: `VpcOwnerId`,
        [_xN]: _vOIp
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `StateReason`,
        [_xN]: _sRt
      }], [0, {
        [_eQN]: `GroupOwnerId`,
        [_xN]: _gOI
      }]]
    ];
    exports2.SendDiagnosticInterruptRequest$ = [
      3,
      n032,
      _SDIR,
      0,
      [_II2, _DR],
      [0, 2],
      1
    ];
    exports2.ServiceConfiguration$ = [
      3,
      n032,
      _SCe,
      0,
      [_STe, _SIe, _SN10, _SSer, _AZIv, _AZv, _ARc, _MVE, _NLBAe, _GLBA, _SIAT, _BEDN, _PDN, _PDNC, _PRa, _T10, _SRu, _RAE],
      [[() => ServiceTypeDetailSet, {
        [_eQN]: `ServiceType`,
        [_xN]: _sTe
      }], [0, {
        [_eQN]: `ServiceId`,
        [_xN]: _sI
      }], [0, {
        [_eQN]: `ServiceName`,
        [_xN]: _sN
      }], [0, {
        [_eQN]: `ServiceState`,
        [_xN]: _sSer
      }], [() => ValueStringList, {
        [_eQN]: `AvailabilityZoneIdSet`,
        [_xN]: _aZIS
      }], [() => ValueStringList, {
        [_eQN]: `AvailabilityZoneSet`,
        [_xN]: _aZS
      }], [2, {
        [_eQN]: `AcceptanceRequired`,
        [_xN]: _aRcc
      }], [2, {
        [_eQN]: `ManagesVpcEndpoints`,
        [_xN]: _mVE
      }], [() => ValueStringList, {
        [_eQN]: `NetworkLoadBalancerArnSet`,
        [_xN]: _nLBAS
      }], [() => ValueStringList, {
        [_eQN]: `GatewayLoadBalancerArnSet`,
        [_xN]: _gLBAS
      }], [() => SupportedIpAddressTypes, {
        [_eQN]: `SupportedIpAddressTypeSet`,
        [_xN]: _sIATS
      }], [() => ValueStringList, {
        [_eQN]: `BaseEndpointDnsNameSet`,
        [_xN]: _bEDNS
      }], [0, {
        [_eQN]: `PrivateDnsName`,
        [_xN]: _pDNr
      }], [() => exports2.PrivateDnsNameConfiguration$, {
        [_eQN]: `PrivateDnsNameConfiguration`,
        [_xN]: _pDNC
      }], [0, {
        [_eQN]: `PayerResponsibility`,
        [_xN]: _pRa
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [() => SupportedRegionSet, {
        [_eQN]: `SupportedRegionSet`,
        [_xN]: _sRS
      }], [2, {
        [_eQN]: `RemoteAccessEnabled`,
        [_xN]: _rAE
      }]]
    ];
    exports2.ServiceDetail$ = [
      3,
      n032,
      _SDer,
      0,
      [_SN10, _SIe, _STe, _SR, _AZIv, _AZv, _Own, _BEDN, _PDN, _PDNr, _VEPS, _ARc, _MVE, _PRa, _T10, _PDNVS, _SIAT],
      [[0, {
        [_eQN]: `ServiceName`,
        [_xN]: _sN
      }], [0, {
        [_eQN]: `ServiceId`,
        [_xN]: _sI
      }], [() => ServiceTypeDetailSet, {
        [_eQN]: `ServiceType`,
        [_xN]: _sTe
      }], [0, {
        [_eQN]: `ServiceRegion`,
        [_xN]: _sR
      }], [() => ValueStringList, {
        [_eQN]: `AvailabilityZoneIdSet`,
        [_xN]: _aZIS
      }], [() => ValueStringList, {
        [_eQN]: `AvailabilityZoneSet`,
        [_xN]: _aZS
      }], [0, {
        [_eQN]: `Owner`,
        [_xN]: _ow
      }], [() => ValueStringList, {
        [_eQN]: `BaseEndpointDnsNameSet`,
        [_xN]: _bEDNS
      }], [0, {
        [_eQN]: `PrivateDnsName`,
        [_xN]: _pDNr
      }], [() => PrivateDnsDetailsSet, {
        [_eQN]: `PrivateDnsNameSet`,
        [_xN]: _pDNS
      }], [2, {
        [_eQN]: `VpcEndpointPolicySupported`,
        [_xN]: _vEPS
      }], [2, {
        [_eQN]: `AcceptanceRequired`,
        [_xN]: _aRcc
      }], [2, {
        [_eQN]: `ManagesVpcEndpoints`,
        [_xN]: _mVE
      }], [0, {
        [_eQN]: `PayerResponsibility`,
        [_xN]: _pRa
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `PrivateDnsNameVerificationState`,
        [_xN]: _pDNVS
      }], [() => SupportedIpAddressTypes, {
        [_eQN]: `SupportedIpAddressTypeSet`,
        [_xN]: _sIATS
      }]]
    ];
    exports2.ServiceLinkVirtualInterface$ = [
      3,
      n032,
      _SLVIe,
      0,
      [_SLVIIe, _SLVIA, _OIu, _OA, _OI, _LA, _PAe, _PBA, _Vl, _OLI, _T10, _CSon],
      [[0, {
        [_eQN]: `ServiceLinkVirtualInterfaceId`,
        [_xN]: _sLVII
      }], [0, {
        [_eQN]: `ServiceLinkVirtualInterfaceArn`,
        [_xN]: _sLVIA
      }], [0, {
        [_eQN]: `OutpostId`,
        [_xN]: _oIu
      }], [0, {
        [_eQN]: `OutpostArn`,
        [_xN]: _oA
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `LocalAddress`,
        [_xN]: _lA
      }], [0, {
        [_eQN]: `PeerAddress`,
        [_xN]: _pAe
      }], [1, {
        [_eQN]: `PeerBgpAsn`,
        [_xN]: _pBA
      }], [1, {
        [_eQN]: `Vlan`,
        [_xN]: _vl
      }], [0, {
        [_eQN]: `OutpostLagId`,
        [_xN]: _oLI
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `ConfigurationState`,
        [_xN]: _cSon
      }]]
    ];
    exports2.ServiceTypeDetail$ = [
      3,
      n032,
      _STDe,
      0,
      [_STe],
      [[0, {
        [_eQN]: `ServiceType`,
        [_xN]: _sTe
      }]]
    ];
    exports2.SlotDateTimeRangeRequest$ = [
      3,
      n032,
      _SDTRR,
      0,
      [_ETa, _LTat],
      [4, 4],
      2
    ];
    exports2.SlotStartTimeRangeRequest$ = [
      3,
      n032,
      _SSTRR,
      0,
      [_ETa, _LTat],
      [4, 4]
    ];
    exports2.Snapshot$ = [
      3,
      n032,
      _Sna,
      0,
      [_OAw, _OA, _T10, _STt, _RETe, _STs, _AZ, _TTr, _CDM, _CTomp, _FSSIB, _SIn, _VIo, _St, _SMta, _ST11, _Pro, _OI, _De, _VSo, _Enc, _KKI, _DEKI],
      [[0, {
        [_eQN]: `OwnerAlias`,
        [_xN]: _oAw
      }], [0, {
        [_eQN]: `OutpostArn`,
        [_xN]: _oA
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `StorageTier`,
        [_xN]: _sTt
      }], [4, {
        [_eQN]: `RestoreExpiryTime`,
        [_xN]: _rETe
      }], [0, {
        [_eQN]: `SseType`,
        [_xN]: _sTs
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [0, {
        [_eQN]: `TransferType`,
        [_xN]: _tTr
      }], [1, {
        [_eQN]: `CompletionDurationMinutes`,
        [_xN]: _cDM
      }], [4, {
        [_eQN]: `CompletionTime`,
        [_xN]: _cTomp
      }], [1, {
        [_eQN]: `FullSnapshotSizeInBytes`,
        [_xN]: _fSSIB
      }], [0, {
        [_eQN]: `SnapshotId`,
        [_xN]: _sIn
      }], [0, {
        [_eQN]: `VolumeId`,
        [_xN]: _vIo
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `StatusMessage`,
        [_xN]: _sMt
      }], [4, {
        [_eQN]: `StartTime`,
        [_xN]: _sT19
      }], [0, {
        [_eQN]: `Progress`,
        [_xN]: _pro
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [1, {
        [_eQN]: `VolumeSize`,
        [_xN]: _vSo
      }], [2, {
        [_eQN]: `Encrypted`,
        [_xN]: _enc
      }], [0, {
        [_eQN]: `KmsKeyId`,
        [_xN]: _kKI
      }], [0, {
        [_eQN]: `DataEncryptionKeyId`,
        [_xN]: _dEKI
      }]]
    ];
    exports2.SnapshotDetail$ = [
      3,
      n032,
      _SDna,
      0,
      [_De, _DN, _DIS, _Fo, _Pro, _SIn, _Sta, _SMt, _Ur, _UB],
      [[0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [0, {
        [_eQN]: `DeviceName`,
        [_xN]: _dN
      }], [1, {
        [_eQN]: `DiskImageSize`,
        [_xN]: _dIS
      }], [0, {
        [_eQN]: `Format`,
        [_xN]: _for
      }], [0, {
        [_eQN]: `Progress`,
        [_xN]: _pro
      }], [0, {
        [_eQN]: `SnapshotId`,
        [_xN]: _sIn
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `StatusMessage`,
        [_xN]: _sMt
      }], [() => SensitiveUrl, {
        [_eQN]: `Url`,
        [_xN]: _ur
      }], [() => exports2.UserBucketDetails$, {
        [_eQN]: `UserBucket`,
        [_xN]: _uB
      }]]
    ];
    exports2.SnapshotDiskContainer$ = [
      3,
      n032,
      _SDCn,
      0,
      [_De, _Fo, _Ur, _UB],
      [0, 0, [() => SensitiveUrl, 0], () => exports2.UserBucket$]
    ];
    exports2.SnapshotInfo$ = [
      3,
      n032,
      _SInap,
      0,
      [_De, _T10, _Enc, _VIo, _St, _VSo, _ST11, _Pro, _OI, _SIn, _OA, _STs, _AZ],
      [[0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [2, {
        [_eQN]: `Encrypted`,
        [_xN]: _enc
      }], [0, {
        [_eQN]: `VolumeId`,
        [_xN]: _vIo
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [1, {
        [_eQN]: `VolumeSize`,
        [_xN]: _vSo
      }], [4, {
        [_eQN]: `StartTime`,
        [_xN]: _sT19
      }], [0, {
        [_eQN]: `Progress`,
        [_xN]: _pro
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `SnapshotId`,
        [_xN]: _sIn
      }], [0, {
        [_eQN]: `OutpostArn`,
        [_xN]: _oA
      }], [0, {
        [_eQN]: `SseType`,
        [_xN]: _sTs
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }]]
    ];
    exports2.SnapshotRecycleBinInfo$ = [
      3,
      n032,
      _SRBI,
      0,
      [_SIn, _RBET, _RBETe, _De, _VIo],
      [[0, {
        [_eQN]: `SnapshotId`,
        [_xN]: _sIn
      }], [4, {
        [_eQN]: `RecycleBinEnterTime`,
        [_xN]: _rBET
      }], [4, {
        [_eQN]: `RecycleBinExitTime`,
        [_xN]: _rBETe
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [0, {
        [_eQN]: `VolumeId`,
        [_xN]: _vIo
      }]]
    ];
    exports2.SnapshotTaskDetail$ = [
      3,
      n032,
      _STD,
      0,
      [_De, _DIS, _Enc, _Fo, _KKI, _Pro, _SIn, _Sta, _SMt, _Ur, _UB],
      [[0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [1, {
        [_eQN]: `DiskImageSize`,
        [_xN]: _dIS
      }], [2, {
        [_eQN]: `Encrypted`,
        [_xN]: _enc
      }], [0, {
        [_eQN]: `Format`,
        [_xN]: _for
      }], [0, {
        [_eQN]: `KmsKeyId`,
        [_xN]: _kKI
      }], [0, {
        [_eQN]: `Progress`,
        [_xN]: _pro
      }], [0, {
        [_eQN]: `SnapshotId`,
        [_xN]: _sIn
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `StatusMessage`,
        [_xN]: _sMt
      }], [() => SensitiveUrl, {
        [_eQN]: `Url`,
        [_xN]: _ur
      }], [() => exports2.UserBucketDetails$, {
        [_eQN]: `UserBucket`,
        [_xN]: _uB
      }]]
    ];
    exports2.SnapshotTierStatus$ = [
      3,
      n032,
      _STSn,
      0,
      [_SIn, _VIo, _Sta, _OI, _T10, _STt, _LTST, _LTPa, _LTOS, _LTOSD, _ACT, _RETe],
      [[0, {
        [_eQN]: `SnapshotId`,
        [_xN]: _sIn
      }], [0, {
        [_eQN]: `VolumeId`,
        [_xN]: _vIo
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `StorageTier`,
        [_xN]: _sTt
      }], [4, {
        [_eQN]: `LastTieringStartTime`,
        [_xN]: _lTST
      }], [1, {
        [_eQN]: `LastTieringProgress`,
        [_xN]: _lTP
      }], [0, {
        [_eQN]: `LastTieringOperationStatus`,
        [_xN]: _lTOS
      }], [0, {
        [_eQN]: `LastTieringOperationStatusDetail`,
        [_xN]: _lTOSD
      }], [4, {
        [_eQN]: `ArchivalCompleteTime`,
        [_xN]: _aCT
      }], [4, {
        [_eQN]: `RestoreExpiryTime`,
        [_xN]: _rETe
      }]]
    ];
    exports2.SpotCapacityRebalance$ = [
      3,
      n032,
      _SCRp,
      0,
      [_RSep, _TDe],
      [[0, {
        [_eQN]: `ReplacementStrategy`,
        [_xN]: _rSepl
      }], [1, {
        [_eQN]: `TerminationDelay`,
        [_xN]: _tD
      }]]
    ];
    exports2.SpotDatafeedSubscription$ = [
      3,
      n032,
      _SDS,
      0,
      [_Bu, _Fa, _OI, _Pre, _St],
      [[0, {
        [_eQN]: `Bucket`,
        [_xN]: _b
      }], [() => exports2.SpotInstanceStateFault$, {
        [_eQN]: `Fault`,
        [_xN]: _fa
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `Prefix`,
        [_xN]: _pre
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }]]
    ];
    exports2.SpotFleetLaunchSpecification$ = [
      3,
      n032,
      _SFLS,
      0,
      [_ATddre, _BDMl, _EO, _IIP, _IIm, _IT4, _KI, _KN, _Mon, _NIet, _Pla, _RIa, _SPp, _SIu, _UDs, _WCe, _TS, _IRn, _SGe],
      [[0, {
        [_eQN]: `AddressingType`,
        [_xN]: _aTddr
      }], [() => BlockDeviceMappingList, {
        [_eQN]: `BlockDeviceMapping`,
        [_xN]: _bDM
      }], [2, {
        [_eQN]: `EbsOptimized`,
        [_xN]: _eO
      }], [() => exports2.IamInstanceProfileSpecification$, {
        [_eQN]: `IamInstanceProfile`,
        [_xN]: _iIP
      }], [0, {
        [_eQN]: `ImageId`,
        [_xN]: _iIma
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [0, {
        [_eQN]: `KernelId`,
        [_xN]: _kI
      }], [0, {
        [_eQN]: `KeyName`,
        [_xN]: _kN
      }], [() => exports2.SpotFleetMonitoring$, {
        [_eQN]: `Monitoring`,
        [_xN]: _mo
      }], [() => InstanceNetworkInterfaceSpecificationList, {
        [_eQN]: `NetworkInterfaceSet`,
        [_xN]: _nIS
      }], [() => exports2.SpotPlacement$, {
        [_eQN]: `Placement`,
        [_xN]: _pla
      }], [0, {
        [_eQN]: `RamdiskId`,
        [_xN]: _rIa
      }], [0, {
        [_eQN]: `SpotPrice`,
        [_xN]: _sPp
      }], [0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }], [() => SensitiveUserData, {
        [_eQN]: `UserData`,
        [_xN]: _uDs
      }], [1, {
        [_eQN]: `WeightedCapacity`,
        [_xN]: _wC
      }], [() => SpotFleetTagSpecificationList, {
        [_eQN]: `TagSpecificationSet`,
        [_xN]: _tSS
      }], [() => exports2.InstanceRequirements$, {
        [_eQN]: `InstanceRequirements`,
        [_xN]: _iR
      }], [() => GroupIdentifierList, {
        [_eQN]: `GroupSet`,
        [_xN]: _gSr
      }]]
    ];
    exports2.SpotFleetMonitoring$ = [
      3,
      n032,
      _SFM,
      0,
      [_En],
      [[2, {
        [_eQN]: `Enabled`,
        [_xN]: _en
      }]]
    ];
    exports2.SpotFleetRequestConfig$ = [
      3,
      n032,
      _SFRCp,
      0,
      [_ASc, _CTr, _SFRCp, _SFRI, _SFRS, _T10],
      [[0, {
        [_eQN]: `ActivityStatus`,
        [_xN]: _aSc
      }], [4, {
        [_eQN]: `CreateTime`,
        [_xN]: _cTr
      }], [() => exports2.SpotFleetRequestConfigData$, {
        [_eQN]: `SpotFleetRequestConfig`,
        [_xN]: _sFRC
      }], [0, {
        [_eQN]: `SpotFleetRequestId`,
        [_xN]: _sFRI
      }], [0, {
        [_eQN]: `SpotFleetRequestState`,
        [_xN]: _sFRSp
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.SpotFleetRequestConfigData$ = [
      3,
      n032,
      _SFRCD,
      0,
      [_IFR, _TCar, _ASl, _ODAS, _SMS, _CT4, _ECTP, _FCu, _ODFC, _LSau, _LTC, _SPp, _ODTC, _ODMTP, _SMTP, _TIWE, _Ty, _VF, _VU, _RUI, _IIB, _LBC, _IPTUC, _Con, _TCUT, _TS],
      [[0, {
        [_eQN]: `IamFleetRole`,
        [_xN]: _iFR
      }], [1, {
        [_eQN]: `TargetCapacity`,
        [_xN]: _tCa
      }], [0, {
        [_eQN]: `AllocationStrategy`,
        [_xN]: _aSl
      }], [0, {
        [_eQN]: `OnDemandAllocationStrategy`,
        [_xN]: _oDAS
      }], [() => exports2.SpotMaintenanceStrategies$, {
        [_eQN]: `SpotMaintenanceStrategies`,
        [_xN]: _sMS
      }], [0, {
        [_eQN]: `ClientToken`,
        [_xN]: _cT
      }], [0, {
        [_eQN]: `ExcessCapacityTerminationPolicy`,
        [_xN]: _eCTP
      }], [1, {
        [_eQN]: `FulfilledCapacity`,
        [_xN]: _fC
      }], [1, {
        [_eQN]: `OnDemandFulfilledCapacity`,
        [_xN]: _oDFC
      }], [() => LaunchSpecsList, {
        [_eQN]: `LaunchSpecifications`,
        [_xN]: _lSau
      }], [() => LaunchTemplateConfigList, {
        [_eQN]: `LaunchTemplateConfigs`,
        [_xN]: _lTC
      }], [0, {
        [_eQN]: `SpotPrice`,
        [_xN]: _sPp
      }], [1, {
        [_eQN]: `OnDemandTargetCapacity`,
        [_xN]: _oDTC
      }], [0, {
        [_eQN]: `OnDemandMaxTotalPrice`,
        [_xN]: _oDMTP
      }], [0, {
        [_eQN]: `SpotMaxTotalPrice`,
        [_xN]: _sMTP
      }], [2, {
        [_eQN]: `TerminateInstancesWithExpiration`,
        [_xN]: _tIWE
      }], [0, {
        [_eQN]: `Type`,
        [_xN]: _ty
      }], [4, {
        [_eQN]: `ValidFrom`,
        [_xN]: _vF
      }], [4, {
        [_eQN]: `ValidUntil`,
        [_xN]: _vU
      }], [2, {
        [_eQN]: `ReplaceUnhealthyInstances`,
        [_xN]: _rUI
      }], [0, {
        [_eQN]: `InstanceInterruptionBehavior`,
        [_xN]: _iIB
      }], [() => exports2.LoadBalancersConfig$, {
        [_eQN]: `LoadBalancersConfig`,
        [_xN]: _lBC
      }], [1, {
        [_eQN]: `InstancePoolsToUseCount`,
        [_xN]: _iPTUC
      }], [0, {
        [_eQN]: `Context`,
        [_xN]: _cont
      }], [0, {
        [_eQN]: `TargetCapacityUnitType`,
        [_xN]: _tCUT
      }], [() => TagSpecificationList, { [_xN]: _TSa }]],
      2
    ];
    exports2.SpotFleetTagSpecification$ = [
      3,
      n032,
      _SFTS,
      0,
      [_RTe, _T10],
      [[0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }], [() => TagList, {
        [_eQN]: `Tag`,
        [_xN]: _ta
      }]]
    ];
    exports2.SpotInstanceRequest$ = [
      3,
      n032,
      _SIRp,
      0,
      [_ABHP, _AZGv, _BDMlo, _CTr, _Fa, _II2, _LGa, _LSa, _LAZ, _LAZI, _PDr, _SIRI, _SPp, _St, _Sta, _T10, _Ty, _VF, _VU, _IIB],
      [[0, {
        [_eQN]: `ActualBlockHourlyPrice`,
        [_xN]: _aBHP
      }], [0, {
        [_eQN]: `AvailabilityZoneGroup`,
        [_xN]: _aZG
      }], [1, {
        [_eQN]: `BlockDurationMinutes`,
        [_xN]: _bDMl
      }], [4, {
        [_eQN]: `CreateTime`,
        [_xN]: _cTr
      }], [() => exports2.SpotInstanceStateFault$, {
        [_eQN]: `Fault`,
        [_xN]: _fa
      }], [0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `LaunchGroup`,
        [_xN]: _lG
      }], [() => exports2.LaunchSpecification$, {
        [_eQN]: `LaunchSpecification`,
        [_xN]: _lSa
      }], [0, {
        [_eQN]: `LaunchedAvailabilityZone`,
        [_xN]: _lAZ
      }], [0, {
        [_eQN]: `LaunchedAvailabilityZoneId`,
        [_xN]: _lAZI
      }], [0, {
        [_eQN]: `ProductDescription`,
        [_xN]: _pDr
      }], [0, {
        [_eQN]: `SpotInstanceRequestId`,
        [_xN]: _sIRI
      }], [0, {
        [_eQN]: `SpotPrice`,
        [_xN]: _sPp
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [() => exports2.SpotInstanceStatus$, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `Type`,
        [_xN]: _ty
      }], [4, {
        [_eQN]: `ValidFrom`,
        [_xN]: _vF
      }], [4, {
        [_eQN]: `ValidUntil`,
        [_xN]: _vU
      }], [0, {
        [_eQN]: `InstanceInterruptionBehavior`,
        [_xN]: _iIB
      }]]
    ];
    exports2.SpotInstanceStateFault$ = [
      3,
      n032,
      _SISF,
      0,
      [_Co, _Me],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }]]
    ];
    exports2.SpotInstanceStatus$ = [
      3,
      n032,
      _SISp,
      0,
      [_Co, _Me, _UT],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }], [4, {
        [_eQN]: `UpdateTime`,
        [_xN]: _uT
      }]]
    ];
    exports2.SpotMaintenanceStrategies$ = [
      3,
      n032,
      _SMS,
      0,
      [_CRapa],
      [[() => exports2.SpotCapacityRebalance$, {
        [_eQN]: `CapacityRebalance`,
        [_xN]: _cRa
      }]]
    ];
    exports2.SpotMarketOptions$ = [
      3,
      n032,
      _SMO,
      0,
      [_MPax, _SIT, _BDMlo, _VU, _IIB],
      [0, 0, 1, 4, 0]
    ];
    exports2.SpotOptions$ = [
      3,
      n032,
      _SO,
      0,
      [_ASl, _MSa, _IIB, _IPTUC, _SITi, _SAZ, _MTC, _MTP],
      [[0, {
        [_eQN]: `AllocationStrategy`,
        [_xN]: _aSl
      }], [() => exports2.FleetSpotMaintenanceStrategies$, {
        [_eQN]: `MaintenanceStrategies`,
        [_xN]: _mSai
      }], [0, {
        [_eQN]: `InstanceInterruptionBehavior`,
        [_xN]: _iIB
      }], [1, {
        [_eQN]: `InstancePoolsToUseCount`,
        [_xN]: _iPTUC
      }], [2, {
        [_eQN]: `SingleInstanceType`,
        [_xN]: _sITi
      }], [2, {
        [_eQN]: `SingleAvailabilityZone`,
        [_xN]: _sAZ
      }], [1, {
        [_eQN]: `MinTargetCapacity`,
        [_xN]: _mTC
      }], [0, {
        [_eQN]: `MaxTotalPrice`,
        [_xN]: _mTP
      }]]
    ];
    exports2.SpotOptionsRequest$ = [
      3,
      n032,
      _SOR,
      0,
      [_ASl, _MSa, _IIB, _IPTUC, _SITi, _SAZ, _MTC, _MTP],
      [0, () => exports2.FleetSpotMaintenanceStrategiesRequest$, 0, 1, 2, 2, 1, 0]
    ];
    exports2.SpotPlacement$ = [
      3,
      n032,
      _SPpo,
      0,
      [_AZ, _GN, _Te, _AZI],
      [[0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [0, {
        [_eQN]: `GroupName`,
        [_xN]: _gN
      }], [0, {
        [_eQN]: `Tenancy`,
        [_xN]: _t
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }]]
    ];
    exports2.SpotPlacementScore$ = [
      3,
      n032,
      _SPSp,
      0,
      [_Regi, _AZI, _Scor],
      [[0, {
        [_eQN]: `Region`,
        [_xN]: _reg
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [1, {
        [_eQN]: `Score`,
        [_xN]: _scor
      }]]
    ];
    exports2.SpotPrice$ = [
      3,
      n032,
      _SPp,
      0,
      [_AZ, _AZI, _IT4, _PDr, _SPp, _Ti],
      [[0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [0, {
        [_eQN]: `InstanceType`,
        [_xN]: _iT13
      }], [0, {
        [_eQN]: `ProductDescription`,
        [_xN]: _pDr
      }], [0, {
        [_eQN]: `SpotPrice`,
        [_xN]: _sPp
      }], [4, {
        [_eQN]: `Timestamp`,
        [_xN]: _ti
      }]]
    ];
    exports2.StaleIpPermission$ = [
      3,
      n032,
      _SIPt,
      0,
      [_FP, _IPpr, _IRpa, _PLIr, _TP, _UIGP],
      [[1, {
        [_eQN]: `FromPort`,
        [_xN]: _fP
      }], [0, {
        [_eQN]: `IpProtocol`,
        [_xN]: _iPp
      }], [() => IpRanges, {
        [_eQN]: `IpRanges`,
        [_xN]: _iRpa
      }], [() => PrefixListIdSet, {
        [_eQN]: `PrefixListIds`,
        [_xN]: _pLIr
      }], [1, {
        [_eQN]: `ToPort`,
        [_xN]: _tP
      }], [() => UserIdGroupPairSet, {
        [_eQN]: `Groups`,
        [_xN]: _gr
      }]]
    ];
    exports2.StaleSecurityGroup$ = [
      3,
      n032,
      _SSG,
      0,
      [_De, _GIr, _GN, _SIPta, _SIPE, _VI],
      [[0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [0, {
        [_eQN]: `GroupId`,
        [_xN]: _gIr
      }], [0, {
        [_eQN]: `GroupName`,
        [_xN]: _gN
      }], [() => StaleIpPermissionSet, {
        [_eQN]: `StaleIpPermissions`,
        [_xN]: _sIP
      }], [() => StaleIpPermissionSet, {
        [_eQN]: `StaleIpPermissionsEgress`,
        [_xN]: _sIPE
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }]]
    ];
    exports2.StartDeclarativePoliciesReportRequest$ = [
      3,
      n032,
      _SDPRR,
      0,
      [_SB, _TIa, _DR, _SP, _TS],
      [0, 0, 2, 0, [() => TagSpecificationList, { [_xN]: _TSa }]],
      2
    ];
    exports2.StartDeclarativePoliciesReportResult$ = [
      3,
      n032,
      _SDPRRt,
      0,
      [_RI],
      [[0, {
        [_eQN]: `ReportId`,
        [_xN]: _rIe
      }]]
    ];
    exports2.StartInstancesRequest$ = [
      3,
      n032,
      _SIRt,
      0,
      [_IIns, _AId, _DR],
      [[() => InstanceIdStringList, { [_xN]: _II2 }], [0, {
        [_eQN]: `AdditionalInfo`,
        [_xN]: _aId
      }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.StartInstancesResult$ = [
      3,
      n032,
      _SIRta,
      0,
      [_SIt],
      [[() => InstanceStateChangeList, {
        [_eQN]: `InstancesSet`,
        [_xN]: _iSn
      }]]
    ];
    exports2.StartNetworkInsightsAccessScopeAnalysisRequest$ = [
      3,
      n032,
      _SNIASAR,
      0,
      [_NIASI, _DR, _TS, _CT4],
      [0, 2, [() => TagSpecificationList, { [_xN]: _TSa }], [0, 4]],
      1
    ];
    exports2.StartNetworkInsightsAccessScopeAnalysisResult$ = [
      3,
      n032,
      _SNIASARt,
      0,
      [_NIASAet],
      [[() => exports2.NetworkInsightsAccessScopeAnalysis$, {
        [_eQN]: `NetworkInsightsAccessScopeAnalysis`,
        [_xN]: _nIASAe
      }]]
    ];
    exports2.StartNetworkInsightsAnalysisRequest$ = [
      3,
      n032,
      _SNIAR,
      0,
      [_NIPI, _AAdd, _FIAi, _FOA, _DR, _TS, _CT4],
      [0, [() => ValueStringList, { [_xN]: _AAddi }], [() => ArnList, { [_xN]: _FIAil }], [() => ArnList, { [_xN]: _FOAi }], 2, [() => TagSpecificationList, { [_xN]: _TSa }], [0, 4]],
      1
    ];
    exports2.StartNetworkInsightsAnalysisResult$ = [
      3,
      n032,
      _SNIARt,
      0,
      [_NIAe],
      [[() => exports2.NetworkInsightsAnalysis$, {
        [_eQN]: `NetworkInsightsAnalysis`,
        [_xN]: _nIA
      }]]
    ];
    exports2.StartVpcEndpointServicePrivateDnsVerificationRequest$ = [
      3,
      n032,
      _SVESPDVR,
      0,
      [_SIe, _DR],
      [0, 2],
      1
    ];
    exports2.StartVpcEndpointServicePrivateDnsVerificationResult$ = [
      3,
      n032,
      _SVESPDVRt,
      0,
      [_RV],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.StateReason$ = [
      3,
      n032,
      _SRt,
      0,
      [_Co, _Me],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }]]
    ];
    exports2.StopInstancesRequest$ = [
      3,
      n032,
      _SIRto,
      0,
      [_IIns, _Hi, _SOS, _DR, _F],
      [[() => InstanceIdStringList, { [_xN]: _II2 }], 2, 2, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }], [2, {
        [_eQN]: `Force`,
        [_xN]: _fo
      }]],
      1
    ];
    exports2.StopInstancesResult$ = [
      3,
      n032,
      _SIRtop,
      0,
      [_SIto],
      [[() => InstanceStateChangeList, {
        [_eQN]: `InstancesSet`,
        [_xN]: _iSn
      }]]
    ];
    exports2.Storage$ = [
      3,
      n032,
      _Sto,
      0,
      [_S_],
      [[() => exports2.S3Storage$, { [_xN]: _S_ }]]
    ];
    exports2.StorageLocation$ = [
      3,
      n032,
      _SLt,
      0,
      [_Bu, _K10],
      [0, 0]
    ];
    exports2.StoreImageTaskResult$ = [
      3,
      n032,
      _SITRt,
      0,
      [_AIm, _TSTa, _Bu, _SKo, _PP, _STSt, _STFR],
      [[0, {
        [_eQN]: `AmiId`,
        [_xN]: _aIm
      }], [4, {
        [_eQN]: `TaskStartTime`,
        [_xN]: _tSTa
      }], [0, {
        [_eQN]: `Bucket`,
        [_xN]: _b
      }], [0, {
        [_eQN]: `S3objectKey`,
        [_xN]: _sKo
      }], [1, {
        [_eQN]: `ProgressPercentage`,
        [_xN]: _pP
      }], [0, {
        [_eQN]: `StoreTaskState`,
        [_xN]: _sTS
      }], [0, {
        [_eQN]: `StoreTaskFailureReason`,
        [_xN]: _sTFR
      }]]
    ];
    exports2.Subnet$ = [
      3,
      n032,
      _Su,
      0,
      [_AZI, _ELADI, _MCOIOL, _COIP, _OI, _AIAOC, _ICBAS, _T10, _SAub, _OA, _EDn, _IN, _PDNOOL, _BPAS, _Ty, _SIu, _St, _VI, _CB, _AIAC, _AZ, _DFA, _MPIOL],
      [[0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [1, {
        [_eQN]: `EnableLniAtDeviceIndex`,
        [_xN]: _eLADI
      }], [2, {
        [_eQN]: `MapCustomerOwnedIpOnLaunch`,
        [_xN]: _mCOIOL
      }], [0, {
        [_eQN]: `CustomerOwnedIpv4Pool`,
        [_xN]: _cOIP
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [2, {
        [_eQN]: `AssignIpv6AddressOnCreation`,
        [_xN]: _aIAOC
      }], [() => SubnetIpv6CidrBlockAssociationSet, {
        [_eQN]: `Ipv6CidrBlockAssociationSet`,
        [_xN]: _iCBASp
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `SubnetArn`,
        [_xN]: _sAub
      }], [0, {
        [_eQN]: `OutpostArn`,
        [_xN]: _oA
      }], [2, {
        [_eQN]: `EnableDns64`,
        [_xN]: _eDn
      }], [2, {
        [_eQN]: `Ipv6Native`,
        [_xN]: _iN
      }], [() => exports2.PrivateDnsNameOptionsOnLaunch$, {
        [_eQN]: `PrivateDnsNameOptionsOnLaunch`,
        [_xN]: _pDNOOL
      }], [() => exports2.BlockPublicAccessStates$, {
        [_eQN]: `BlockPublicAccessStates`,
        [_xN]: _bPAS
      }], [0, {
        [_eQN]: `Type`,
        [_xN]: _ty
      }], [0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [0, {
        [_eQN]: `CidrBlock`,
        [_xN]: _cB
      }], [1, {
        [_eQN]: `AvailableIpAddressCount`,
        [_xN]: _aIAC
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [2, {
        [_eQN]: `DefaultForAz`,
        [_xN]: _dFA
      }], [2, {
        [_eQN]: `MapPublicIpOnLaunch`,
        [_xN]: _mPIOL
      }]]
    ];
    exports2.SubnetAssociation$ = [
      3,
      n032,
      _SAubn,
      0,
      [_SIu, _St],
      [[0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }]]
    ];
    exports2.SubnetCidrBlockState$ = [
      3,
      n032,
      _SCBS,
      0,
      [_St, _SMt],
      [[0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `StatusMessage`,
        [_xN]: _sMt
      }]]
    ];
    exports2.SubnetCidrReservation$ = [
      3,
      n032,
      _SCRu,
      0,
      [_SCRIu, _SIu, _Ci, _RT13, _OI, _De, _T10],
      [[0, {
        [_eQN]: `SubnetCidrReservationId`,
        [_xN]: _sCRIu
      }], [0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }], [0, {
        [_eQN]: `Cidr`,
        [_xN]: _ci
      }], [0, {
        [_eQN]: `ReservationType`,
        [_xN]: _rT13
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.SubnetConfiguration$ = [
      3,
      n032,
      _SCu,
      0,
      [_SIu, _Ipv, _Ipv_],
      [0, 0, 0]
    ];
    exports2.SubnetIpPrefixes$ = [
      3,
      n032,
      _SIPu,
      0,
      [_SIu, _IPpre],
      [[0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }], [() => ValueStringList, {
        [_eQN]: `IpPrefixSet`,
        [_xN]: _iPSpr
      }]]
    ];
    exports2.SubnetIpv6CidrBlockAssociation$ = [
      3,
      n032,
      _SICBA,
      0,
      [_AIs, _ICB, _ICBS, _IAA, _ISpo],
      [[0, {
        [_eQN]: `AssociationId`,
        [_xN]: _aIs
      }], [0, {
        [_eQN]: `Ipv6CidrBlock`,
        [_xN]: _iCB
      }], [() => exports2.SubnetCidrBlockState$, {
        [_eQN]: `Ipv6CidrBlockState`,
        [_xN]: _iCBS
      }], [0, {
        [_eQN]: `Ipv6AddressAttribute`,
        [_xN]: _iAA
      }], [0, {
        [_eQN]: `IpSource`,
        [_xN]: _iSpo
      }]]
    ];
    exports2.Subscription$ = [
      3,
      n032,
      _Subs,
      0,
      [_S, _D, _Met, _Stat, _Per],
      [[0, {
        [_eQN]: `Source`,
        [_xN]: _so
      }], [0, {
        [_eQN]: `Destination`,
        [_xN]: _d
      }], [0, {
        [_eQN]: `Metric`,
        [_xN]: _met
      }], [0, {
        [_eQN]: `Statistic`,
        [_xN]: _stat
      }], [0, {
        [_eQN]: `Period`,
        [_xN]: _pe
      }]]
    ];
    exports2.SuccessfulInstanceCreditSpecificationItem$ = [
      3,
      n032,
      _SICSI,
      0,
      [_II2],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }]]
    ];
    exports2.SuccessfulQueuedPurchaseDeletion$ = [
      3,
      n032,
      _SQPDu,
      0,
      [_RIIes],
      [[0, {
        [_eQN]: `ReservedInstancesId`,
        [_xN]: _rII
      }]]
    ];
    exports2.SupportedRegionDetail$ = [
      3,
      n032,
      _SRD,
      0,
      [_Regi, _SSer],
      [[0, {
        [_eQN]: `Region`,
        [_xN]: _reg
      }], [0, {
        [_eQN]: `ServiceState`,
        [_xN]: _sSer
      }]]
    ];
    exports2.Tag$ = [
      3,
      n032,
      _Ta10,
      0,
      [_K10, _V10],
      [[0, {
        [_eQN]: `Key`,
        [_xN]: _k
      }], [0, {
        [_eQN]: `Value`,
        [_xN]: _v
      }]]
    ];
    exports2.TagDescription$ = [
      3,
      n032,
      _TDa,
      0,
      [_K10, _RIeso, _RTe, _V10],
      [[0, {
        [_eQN]: `Key`,
        [_xN]: _k
      }], [0, {
        [_eQN]: `ResourceId`,
        [_xN]: _rIes
      }], [0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }], [0, {
        [_eQN]: `Value`,
        [_xN]: _v
      }]]
    ];
    exports2.TagSpecification$ = [
      3,
      n032,
      _TSa,
      0,
      [_RTe, _T10],
      [[0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }], [() => TagList, { [_xN]: _Ta10 }]]
    ];
    exports2.TargetCapacitySpecification$ = [
      3,
      n032,
      _TCS,
      0,
      [_TTC, _ODTC, _STC, _DTCT, _TCUT],
      [[1, {
        [_eQN]: `TotalTargetCapacity`,
        [_xN]: _tTC
      }], [1, {
        [_eQN]: `OnDemandTargetCapacity`,
        [_xN]: _oDTC
      }], [1, {
        [_eQN]: `SpotTargetCapacity`,
        [_xN]: _sTC
      }], [0, {
        [_eQN]: `DefaultTargetCapacityType`,
        [_xN]: _dTCT
      }], [0, {
        [_eQN]: `TargetCapacityUnitType`,
        [_xN]: _tCUT
      }]]
    ];
    exports2.TargetCapacitySpecificationRequest$ = [
      3,
      n032,
      _TCSR,
      0,
      [_TTC, _ODTC, _STC, _DTCT, _TCUT],
      [1, 1, 1, 0, 0],
      1
    ];
    exports2.TargetConfiguration$ = [
      3,
      n032,
      _TCa,
      0,
      [_IC, _OIf],
      [[1, {
        [_eQN]: `InstanceCount`,
        [_xN]: _iC
      }], [0, {
        [_eQN]: `OfferingId`,
        [_xN]: _oIf
      }]]
    ];
    exports2.TargetConfigurationRequest$ = [
      3,
      n032,
      _TCR,
      0,
      [_OIf, _IC],
      [0, 1],
      1
    ];
    exports2.TargetGroup$ = [
      3,
      n032,
      _TGa,
      0,
      [_Ar],
      [[0, {
        [_eQN]: `Arn`,
        [_xN]: _ar
      }]]
    ];
    exports2.TargetGroupsConfig$ = [
      3,
      n032,
      _TGCa,
      0,
      [_TGar],
      [[() => TargetGroups, {
        [_eQN]: `TargetGroups`,
        [_xN]: _tGa
      }]]
    ];
    exports2.TargetNetwork$ = [
      3,
      n032,
      _TNa,
      0,
      [_AIs, _VI, _TNI, _CVEI, _Sta, _SGe, _AZv, _AZIv],
      [[0, {
        [_eQN]: `AssociationId`,
        [_xN]: _aIs
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [0, {
        [_eQN]: `TargetNetworkId`,
        [_xN]: _tNI
      }], [0, {
        [_eQN]: `ClientVpnEndpointId`,
        [_xN]: _cVEI
      }], [() => exports2.AssociationStatus$, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [() => ValueStringList, {
        [_eQN]: `SecurityGroups`,
        [_xN]: _sGe
      }], [() => ClientVpnAvailabilityZoneSet, {
        [_eQN]: `AvailabilityZoneSet`,
        [_xN]: _aZS
      }], [() => ClientVpnAvailabilityZoneIdSet, {
        [_eQN]: `AvailabilityZoneIdSet`,
        [_xN]: _aZIS
      }]]
    ];
    exports2.TargetReservationValue$ = [
      3,
      n032,
      _TRV,
      0,
      [_RVe, _TCa],
      [[() => exports2.ReservationValue$, {
        [_eQN]: `ReservationValue`,
        [_xN]: _rVe
      }], [() => exports2.TargetConfiguration$, {
        [_eQN]: `TargetConfiguration`,
        [_xN]: _tCar
      }]]
    ];
    exports2.TerminateClientVpnConnectionsRequest$ = [
      3,
      n032,
      _TCVCR,
      0,
      [_CVEI, _CIon, _Us, _DR],
      [0, 0, 0, 2],
      1
    ];
    exports2.TerminateClientVpnConnectionsResult$ = [
      3,
      n032,
      _TCVCRe,
      0,
      [_CVEI, _Us, _CSonn],
      [[0, {
        [_eQN]: `ClientVpnEndpointId`,
        [_xN]: _cVEI
      }], [0, {
        [_eQN]: `Username`,
        [_xN]: _us
      }], [() => TerminateConnectionStatusSet, {
        [_eQN]: `ConnectionStatuses`,
        [_xN]: _cSonn
      }]]
    ];
    exports2.TerminateConnectionStatus$ = [
      3,
      n032,
      _TCSe,
      0,
      [_CIon, _PSre, _CSur],
      [[0, {
        [_eQN]: `ConnectionId`,
        [_xN]: _cIon
      }], [() => exports2.ClientVpnConnectionStatus$, {
        [_eQN]: `PreviousStatus`,
        [_xN]: _pSre
      }], [() => exports2.ClientVpnConnectionStatus$, {
        [_eQN]: `CurrentStatus`,
        [_xN]: _cSur
      }]]
    ];
    exports2.TerminateInstancesRequest$ = [
      3,
      n032,
      _TIR,
      0,
      [_IIns, _F, _SOS, _DR],
      [[() => InstanceIdStringList, { [_xN]: _II2 }], 2, 2, [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.TerminateInstancesResult$ = [
      3,
      n032,
      _TIRe,
      0,
      [_TIer],
      [[() => InstanceStateChangeList, {
        [_eQN]: `InstancesSet`,
        [_xN]: _iSn
      }]]
    ];
    exports2.ThroughResourcesStatement$ = [
      3,
      n032,
      _TRS,
      0,
      [_RSes],
      [[() => exports2.ResourceStatement$, {
        [_eQN]: `ResourceStatement`,
        [_xN]: _rSeso
      }]]
    ];
    exports2.ThroughResourcesStatementRequest$ = [
      3,
      n032,
      _TRSR,
      0,
      [_RSes],
      [[() => exports2.ResourceStatementRequest$, 0]]
    ];
    exports2.TotalLocalStorageGB$ = [
      3,
      n032,
      _TLSGB,
      0,
      [_M, _Ma],
      [[1, {
        [_eQN]: `Min`,
        [_xN]: _m29
      }], [1, {
        [_eQN]: `Max`,
        [_xN]: _ma
      }]]
    ];
    exports2.TotalLocalStorageGBRequest$ = [
      3,
      n032,
      _TLSGBR,
      0,
      [_M, _Ma],
      [1, 1]
    ];
    exports2.TrafficMirrorFilter$ = [
      3,
      n032,
      _TMF,
      0,
      [_TMFI, _IFRn, _EFR, _NSe, _De, _T10],
      [[0, {
        [_eQN]: `TrafficMirrorFilterId`,
        [_xN]: _tMFI
      }], [() => TrafficMirrorFilterRuleList, {
        [_eQN]: `IngressFilterRuleSet`,
        [_xN]: _iFRS
      }], [() => TrafficMirrorFilterRuleList, {
        [_eQN]: `EgressFilterRuleSet`,
        [_xN]: _eFRS
      }], [() => TrafficMirrorNetworkServiceList, {
        [_eQN]: `NetworkServiceSet`,
        [_xN]: _nSS
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.TrafficMirrorFilterRule$ = [
      3,
      n032,
      _TMFR,
      0,
      [_TMFRI, _TMFI, _TD, _RNu, _RA10, _Pr10, _DPRe, _SPRo, _DCB, _SCB, _De, _T10],
      [[0, {
        [_eQN]: `TrafficMirrorFilterRuleId`,
        [_xN]: _tMFRI
      }], [0, {
        [_eQN]: `TrafficMirrorFilterId`,
        [_xN]: _tMFI
      }], [0, {
        [_eQN]: `TrafficDirection`,
        [_xN]: _tDr
      }], [1, {
        [_eQN]: `RuleNumber`,
        [_xN]: _rN10
      }], [0, {
        [_eQN]: `RuleAction`,
        [_xN]: _rA
      }], [1, {
        [_eQN]: `Protocol`,
        [_xN]: _pr
      }], [() => exports2.TrafficMirrorPortRange$, {
        [_eQN]: `DestinationPortRange`,
        [_xN]: _dPR
      }], [() => exports2.TrafficMirrorPortRange$, {
        [_eQN]: `SourcePortRange`,
        [_xN]: _sPR
      }], [0, {
        [_eQN]: `DestinationCidrBlock`,
        [_xN]: _dCB
      }], [0, {
        [_eQN]: `SourceCidrBlock`,
        [_xN]: _sCB
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.TrafficMirrorPortRange$ = [
      3,
      n032,
      _TMPR,
      0,
      [_FP, _TP],
      [[1, {
        [_eQN]: `FromPort`,
        [_xN]: _fP
      }], [1, {
        [_eQN]: `ToPort`,
        [_xN]: _tP
      }]]
    ];
    exports2.TrafficMirrorPortRangeRequest$ = [
      3,
      n032,
      _TMPRR,
      0,
      [_FP, _TP],
      [1, 1]
    ];
    exports2.TrafficMirrorSession$ = [
      3,
      n032,
      _TMS,
      0,
      [_TMSI, _TMTI, _TMFI, _NII, _OI, _PLa, _SNes, _VNI, _De, _T10],
      [[0, {
        [_eQN]: `TrafficMirrorSessionId`,
        [_xN]: _tMSI
      }], [0, {
        [_eQN]: `TrafficMirrorTargetId`,
        [_xN]: _tMTI
      }], [0, {
        [_eQN]: `TrafficMirrorFilterId`,
        [_xN]: _tMFI
      }], [0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [1, {
        [_eQN]: `PacketLength`,
        [_xN]: _pLa
      }], [1, {
        [_eQN]: `SessionNumber`,
        [_xN]: _sNes
      }], [1, {
        [_eQN]: `VirtualNetworkId`,
        [_xN]: _vNI
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.TrafficMirrorTarget$ = [
      3,
      n032,
      _TMT,
      0,
      [_TMTI, _NII, _NLBA, _Ty, _De, _OI, _T10, _GLBEI],
      [[0, {
        [_eQN]: `TrafficMirrorTargetId`,
        [_xN]: _tMTI
      }], [0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], [0, {
        [_eQN]: `NetworkLoadBalancerArn`,
        [_xN]: _nLBA
      }], [0, {
        [_eQN]: `Type`,
        [_xN]: _ty
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `GatewayLoadBalancerEndpointId`,
        [_xN]: _gLBEI
      }]]
    ];
    exports2.TransitGateway$ = [
      3,
      n032,
      _TG,
      0,
      [_TGI, _TGAran, _St, _OI, _De, _CTre, _Opt, _T10],
      [[0, {
        [_eQN]: `TransitGatewayId`,
        [_xN]: _tGI
      }], [0, {
        [_eQN]: `TransitGatewayArn`,
        [_xN]: _tGAra
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [4, {
        [_eQN]: `CreationTime`,
        [_xN]: _cTre
      }], [() => exports2.TransitGatewayOptions$, {
        [_eQN]: `Options`,
        [_xN]: _op
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.TransitGatewayAssociation$ = [
      3,
      n032,
      _TGArans,
      0,
      [_TGRTI, _TGAI, _RIeso, _RTe, _St],
      [[0, {
        [_eQN]: `TransitGatewayRouteTableId`,
        [_xN]: _tGRTI
      }], [0, {
        [_eQN]: `TransitGatewayAttachmentId`,
        [_xN]: _tGAI
      }], [0, {
        [_eQN]: `ResourceId`,
        [_xN]: _rIes
      }], [0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }]]
    ];
    exports2.TransitGatewayAttachment$ = [
      3,
      n032,
      _TGAra,
      0,
      [_TGAI, _TGI, _TGOI, _ROI, _RTe, _RIeso, _St, _Ass, _CTre, _T10],
      [[0, {
        [_eQN]: `TransitGatewayAttachmentId`,
        [_xN]: _tGAI
      }], [0, {
        [_eQN]: `TransitGatewayId`,
        [_xN]: _tGI
      }], [0, {
        [_eQN]: `TransitGatewayOwnerId`,
        [_xN]: _tGOI
      }], [0, {
        [_eQN]: `ResourceOwnerId`,
        [_xN]: _rOI
      }], [0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }], [0, {
        [_eQN]: `ResourceId`,
        [_xN]: _rIes
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [() => exports2.TransitGatewayAttachmentAssociation$, {
        [_eQN]: `Association`,
        [_xN]: _ass
      }], [4, {
        [_eQN]: `CreationTime`,
        [_xN]: _cTre
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.TransitGatewayAttachmentAssociation$ = [
      3,
      n032,
      _TGAA,
      0,
      [_TGRTI, _St],
      [[0, {
        [_eQN]: `TransitGatewayRouteTableId`,
        [_xN]: _tGRTI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }]]
    ];
    exports2.TransitGatewayAttachmentBgpConfiguration$ = [
      3,
      n032,
      _TGABC,
      0,
      [_TGAransi, _PAee, _TGA, _PAe, _BSg],
      [[1, {
        [_eQN]: `TransitGatewayAsn`,
        [_xN]: _tGAran
      }], [1, {
        [_eQN]: `PeerAsn`,
        [_xN]: _pAee
      }], [0, {
        [_eQN]: `TransitGatewayAddress`,
        [_xN]: _tGArans
      }], [0, {
        [_eQN]: `PeerAddress`,
        [_xN]: _pAe
      }], [0, {
        [_eQN]: `BgpStatus`,
        [_xN]: _bSg
      }]]
    ];
    exports2.TransitGatewayAttachmentPropagation$ = [
      3,
      n032,
      _TGAPr,
      0,
      [_TGRTI, _St],
      [[0, {
        [_eQN]: `TransitGatewayRouteTableId`,
        [_xN]: _tGRTI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }]]
    ];
    exports2.TransitGatewayClientVpnAttachment$ = [
      3,
      n032,
      _TGCVA,
      0,
      [_TGAI, _TGI, _CVEI, _CVOI, _St, _CTre],
      [[0, {
        [_eQN]: `TransitGatewayAttachmentId`,
        [_xN]: _tGAI
      }], [0, {
        [_eQN]: `TransitGatewayId`,
        [_xN]: _tGI
      }], [0, {
        [_eQN]: `ClientVpnEndpointId`,
        [_xN]: _cVEI
      }], [0, {
        [_eQN]: `ClientVpnOwnerId`,
        [_xN]: _cVOI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `CreationTime`,
        [_xN]: _cTre
      }]]
    ];
    exports2.TransitGatewayConfigurationDescribeEndpointStructure$ = [
      3,
      n032,
      _TGCDES,
      0,
      [_TGI, _TGAI, _AZv, _AZIv],
      [[0, {
        [_eQN]: `TransitGatewayId`,
        [_xN]: _tGI
      }], [0, {
        [_eQN]: `TransitGatewayAttachmentId`,
        [_xN]: _tGAI
      }], [() => ClientVpnAvailabilityZoneSet, {
        [_eQN]: `AvailabilityZoneSet`,
        [_xN]: _aZS
      }], [() => ClientVpnAvailabilityZoneIdSet, {
        [_eQN]: `AvailabilityZoneIdSet`,
        [_xN]: _aZIS
      }]]
    ];
    exports2.TransitGatewayConfigurationInputStructure$ = [
      3,
      n032,
      _TGCIS,
      0,
      [_TGI, _AZv, _AZIv],
      [0, [() => ClientVpnAvailabilityZoneSet, { [_xN]: _AZ }], [() => ClientVpnAvailabilityZoneIdSet, { [_xN]: _AZI }]]
    ];
    exports2.TransitGatewayConnect$ = [
      3,
      n032,
      _TGCr,
      0,
      [_TGAI, _TTGAI, _TGI, _St, _CTre, _Opt, _T10],
      [[0, {
        [_eQN]: `TransitGatewayAttachmentId`,
        [_xN]: _tGAI
      }], [0, {
        [_eQN]: `TransportTransitGatewayAttachmentId`,
        [_xN]: _tTGAI
      }], [0, {
        [_eQN]: `TransitGatewayId`,
        [_xN]: _tGI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [4, {
        [_eQN]: `CreationTime`,
        [_xN]: _cTre
      }], [() => exports2.TransitGatewayConnectOptions$, {
        [_eQN]: `Options`,
        [_xN]: _op
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.TransitGatewayConnectOptions$ = [
      3,
      n032,
      _TGCO,
      0,
      [_Pr10],
      [[0, {
        [_eQN]: `Protocol`,
        [_xN]: _pr
      }]]
    ];
    exports2.TransitGatewayConnectPeer$ = [
      3,
      n032,
      _TGCP,
      0,
      [_TGAI, _TGCPI, _St, _CTre, _CPC, _T10],
      [[0, {
        [_eQN]: `TransitGatewayAttachmentId`,
        [_xN]: _tGAI
      }], [0, {
        [_eQN]: `TransitGatewayConnectPeerId`,
        [_xN]: _tGCPI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [4, {
        [_eQN]: `CreationTime`,
        [_xN]: _cTre
      }], [() => exports2.TransitGatewayConnectPeerConfiguration$, {
        [_eQN]: `ConnectPeerConfiguration`,
        [_xN]: _cPC
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.TransitGatewayConnectPeerConfiguration$ = [
      3,
      n032,
      _TGCPC,
      0,
      [_TGA, _PAe, _ICBn, _Pr10, _BCg],
      [[0, {
        [_eQN]: `TransitGatewayAddress`,
        [_xN]: _tGArans
      }], [0, {
        [_eQN]: `PeerAddress`,
        [_xN]: _pAe
      }], [() => InsideCidrBlocksStringList, {
        [_eQN]: `InsideCidrBlocks`,
        [_xN]: _iCBn
      }], [0, {
        [_eQN]: `Protocol`,
        [_xN]: _pr
      }], [() => TransitGatewayAttachmentBgpConfigurationList, {
        [_eQN]: `BgpConfigurations`,
        [_xN]: _bCg
      }]]
    ];
    exports2.TransitGatewayConnectRequestBgpOptions$ = [
      3,
      n032,
      _TGCRBO,
      0,
      [_PAee],
      [1]
    ];
    exports2.TransitGatewayMeteringPolicy$ = [
      3,
      n032,
      _TGMP,
      0,
      [_TGMPI, _TGI, _MAIi, _St, _UEA, _T10],
      [[0, {
        [_eQN]: `TransitGatewayMeteringPolicyId`,
        [_xN]: _tGMPI
      }], [0, {
        [_eQN]: `TransitGatewayId`,
        [_xN]: _tGI
      }], [() => ValueStringList, {
        [_eQN]: `MiddleboxAttachmentIdSet`,
        [_xN]: _mAIS
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [4, {
        [_eQN]: `UpdateEffectiveAt`,
        [_xN]: _uEA
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.TransitGatewayMeteringPolicyEntry$ = [
      3,
      n032,
      _TGMPE,
      0,
      [_PRN, _MAe, _St, _UA, _UEA, _MPR],
      [[0, {
        [_eQN]: `PolicyRuleNumber`,
        [_xN]: _pRN
      }], [0, {
        [_eQN]: `MeteredAccount`,
        [_xN]: _mAe
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [4, {
        [_eQN]: `UpdatedAt`,
        [_xN]: _uA
      }], [4, {
        [_eQN]: `UpdateEffectiveAt`,
        [_xN]: _uEA
      }], [() => exports2.TransitGatewayMeteringPolicyRule$, {
        [_eQN]: `MeteringPolicyRule`,
        [_xN]: _mPR
      }]]
    ];
    exports2.TransitGatewayMeteringPolicyRule$ = [
      3,
      n032,
      _TGMPR,
      0,
      [_STGAI, _STGAT, _SCB, _SPRo, _DTGAI, _DTGAT, _DCB, _DPRe, _Pr10],
      [[0, {
        [_eQN]: `SourceTransitGatewayAttachmentId`,
        [_xN]: _sTGAI
      }], [0, {
        [_eQN]: `SourceTransitGatewayAttachmentType`,
        [_xN]: _sTGAT
      }], [0, {
        [_eQN]: `SourceCidrBlock`,
        [_xN]: _sCB
      }], [0, {
        [_eQN]: `SourcePortRange`,
        [_xN]: _sPR
      }], [0, {
        [_eQN]: `DestinationTransitGatewayAttachmentId`,
        [_xN]: _dTGAI
      }], [0, {
        [_eQN]: `DestinationTransitGatewayAttachmentType`,
        [_xN]: _dTGAT
      }], [0, {
        [_eQN]: `DestinationCidrBlock`,
        [_xN]: _dCB
      }], [0, {
        [_eQN]: `DestinationPortRange`,
        [_xN]: _dPR
      }], [0, {
        [_eQN]: `Protocol`,
        [_xN]: _pr
      }]]
    ];
    exports2.TransitGatewayMulticastDeregisteredGroupMembers$ = [
      3,
      n032,
      _TGMDGM,
      0,
      [_TGMDI, _DNII, _GIA],
      [[0, {
        [_eQN]: `TransitGatewayMulticastDomainId`,
        [_xN]: _tGMDI
      }], [() => ValueStringList, {
        [_eQN]: `DeregisteredNetworkInterfaceIds`,
        [_xN]: _dNII
      }], [0, {
        [_eQN]: `GroupIpAddress`,
        [_xN]: _gIA
      }]]
    ];
    exports2.TransitGatewayMulticastDeregisteredGroupSources$ = [
      3,
      n032,
      _TGMDGS,
      0,
      [_TGMDI, _DNII, _GIA],
      [[0, {
        [_eQN]: `TransitGatewayMulticastDomainId`,
        [_xN]: _tGMDI
      }], [() => ValueStringList, {
        [_eQN]: `DeregisteredNetworkInterfaceIds`,
        [_xN]: _dNII
      }], [0, {
        [_eQN]: `GroupIpAddress`,
        [_xN]: _gIA
      }]]
    ];
    exports2.TransitGatewayMulticastDomain$ = [
      3,
      n032,
      _TGMD,
      0,
      [_TGMDI, _TGI, _TGMDA, _OI, _Opt, _St, _CTre, _T10],
      [[0, {
        [_eQN]: `TransitGatewayMulticastDomainId`,
        [_xN]: _tGMDI
      }], [0, {
        [_eQN]: `TransitGatewayId`,
        [_xN]: _tGI
      }], [0, {
        [_eQN]: `TransitGatewayMulticastDomainArn`,
        [_xN]: _tGMDA
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [() => exports2.TransitGatewayMulticastDomainOptions$, {
        [_eQN]: `Options`,
        [_xN]: _op
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [4, {
        [_eQN]: `CreationTime`,
        [_xN]: _cTre
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.TransitGatewayMulticastDomainAssociation$ = [
      3,
      n032,
      _TGMDAr,
      0,
      [_TGAI, _RIeso, _RTe, _ROI, _Su],
      [[0, {
        [_eQN]: `TransitGatewayAttachmentId`,
        [_xN]: _tGAI
      }], [0, {
        [_eQN]: `ResourceId`,
        [_xN]: _rIes
      }], [0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }], [0, {
        [_eQN]: `ResourceOwnerId`,
        [_xN]: _rOI
      }], [() => exports2.SubnetAssociation$, {
        [_eQN]: `Subnet`,
        [_xN]: _su
      }]]
    ];
    exports2.TransitGatewayMulticastDomainAssociations$ = [
      3,
      n032,
      _TGMDAra,
      0,
      [_TGMDI, _TGAI, _RIeso, _RTe, _ROI, _Subn],
      [[0, {
        [_eQN]: `TransitGatewayMulticastDomainId`,
        [_xN]: _tGMDI
      }], [0, {
        [_eQN]: `TransitGatewayAttachmentId`,
        [_xN]: _tGAI
      }], [0, {
        [_eQN]: `ResourceId`,
        [_xN]: _rIes
      }], [0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }], [0, {
        [_eQN]: `ResourceOwnerId`,
        [_xN]: _rOI
      }], [() => SubnetAssociationList, {
        [_eQN]: `Subnets`,
        [_xN]: _sub
      }]]
    ];
    exports2.TransitGatewayMulticastDomainOptions$ = [
      3,
      n032,
      _TGMDO,
      0,
      [_ISg, _SSS, _AASA],
      [[0, {
        [_eQN]: `Igmpv2Support`,
        [_xN]: _iSg
      }], [0, {
        [_eQN]: `StaticSourcesSupport`,
        [_xN]: _sSSt
      }], [0, {
        [_eQN]: `AutoAcceptSharedAssociations`,
        [_xN]: _aASA
      }]]
    ];
    exports2.TransitGatewayMulticastGroup$ = [
      3,
      n032,
      _TGMG,
      0,
      [_GIA, _TGAI, _SIu, _RIeso, _RTe, _ROI, _NII, _GM, _GS, _MTe, _STo],
      [[0, {
        [_eQN]: `GroupIpAddress`,
        [_xN]: _gIA
      }], [0, {
        [_eQN]: `TransitGatewayAttachmentId`,
        [_xN]: _tGAI
      }], [0, {
        [_eQN]: `SubnetId`,
        [_xN]: _sIu
      }], [0, {
        [_eQN]: `ResourceId`,
        [_xN]: _rIes
      }], [0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }], [0, {
        [_eQN]: `ResourceOwnerId`,
        [_xN]: _rOI
      }], [0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], [2, {
        [_eQN]: `GroupMember`,
        [_xN]: _gM
      }], [2, {
        [_eQN]: `GroupSource`,
        [_xN]: _gSro
      }], [0, {
        [_eQN]: `MemberType`,
        [_xN]: _mTe
      }], [0, {
        [_eQN]: `SourceType`,
        [_xN]: _sTo
      }]]
    ];
    exports2.TransitGatewayMulticastRegisteredGroupMembers$ = [
      3,
      n032,
      _TGMRGM,
      0,
      [_TGMDI, _RNII, _GIA],
      [[0, {
        [_eQN]: `TransitGatewayMulticastDomainId`,
        [_xN]: _tGMDI
      }], [() => ValueStringList, {
        [_eQN]: `RegisteredNetworkInterfaceIds`,
        [_xN]: _rNII
      }], [0, {
        [_eQN]: `GroupIpAddress`,
        [_xN]: _gIA
      }]]
    ];
    exports2.TransitGatewayMulticastRegisteredGroupSources$ = [
      3,
      n032,
      _TGMRGS,
      0,
      [_TGMDI, _RNII, _GIA],
      [[0, {
        [_eQN]: `TransitGatewayMulticastDomainId`,
        [_xN]: _tGMDI
      }], [() => ValueStringList, {
        [_eQN]: `RegisteredNetworkInterfaceIds`,
        [_xN]: _rNII
      }], [0, {
        [_eQN]: `GroupIpAddress`,
        [_xN]: _gIA
      }]]
    ];
    exports2.TransitGatewayOptions$ = [
      3,
      n032,
      _TGO,
      0,
      [_ASA, _TGCB, _AASAu, _DRTA, _ADRTI, _DRTP, _PDRTI, _VESp, _DSn, _SGRS, _MSu, _ESn],
      [[1, {
        [_eQN]: `AmazonSideAsn`,
        [_xN]: _aSA
      }], [() => ValueStringList, {
        [_eQN]: `TransitGatewayCidrBlocks`,
        [_xN]: _tGCB
      }], [0, {
        [_eQN]: `AutoAcceptSharedAttachments`,
        [_xN]: _aASAu
      }], [0, {
        [_eQN]: `DefaultRouteTableAssociation`,
        [_xN]: _dRTA
      }], [0, {
        [_eQN]: `AssociationDefaultRouteTableId`,
        [_xN]: _aDRTI
      }], [0, {
        [_eQN]: `DefaultRouteTablePropagation`,
        [_xN]: _dRTP
      }], [0, {
        [_eQN]: `PropagationDefaultRouteTableId`,
        [_xN]: _pDRTI
      }], [0, {
        [_eQN]: `VpnEcmpSupport`,
        [_xN]: _vESpn
      }], [0, {
        [_eQN]: `DnsSupport`,
        [_xN]: _dSn
      }], [0, {
        [_eQN]: `SecurityGroupReferencingSupport`,
        [_xN]: _sGRSec
      }], [0, {
        [_eQN]: `MulticastSupport`,
        [_xN]: _mSu
      }], [() => exports2.EncryptionSupport$, {
        [_eQN]: `EncryptionSupport`,
        [_xN]: _eSn
      }]]
    ];
    exports2.TransitGatewayPeeringAttachment$ = [
      3,
      n032,
      _TGPA,
      0,
      [_TGAI, _ATGAI, _RTIe, _ATI, _Opt, _Sta, _St, _CTre, _T10],
      [[0, {
        [_eQN]: `TransitGatewayAttachmentId`,
        [_xN]: _tGAI
      }], [0, {
        [_eQN]: `AccepterTransitGatewayAttachmentId`,
        [_xN]: _aTGAI
      }], [() => exports2.PeeringTgwInfo$, {
        [_eQN]: `RequesterTgwInfo`,
        [_xN]: _rTIe
      }], [() => exports2.PeeringTgwInfo$, {
        [_eQN]: `AccepterTgwInfo`,
        [_xN]: _aTI
      }], [() => exports2.TransitGatewayPeeringAttachmentOptions$, {
        [_eQN]: `Options`,
        [_xN]: _op
      }], [() => exports2.PeeringAttachmentStatus$, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [4, {
        [_eQN]: `CreationTime`,
        [_xN]: _cTre
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.TransitGatewayPeeringAttachmentOptions$ = [
      3,
      n032,
      _TGPAO,
      0,
      [_DRy],
      [[0, {
        [_eQN]: `DynamicRouting`,
        [_xN]: _dRy
      }]]
    ];
    exports2.TransitGatewayPolicyRule$ = [
      3,
      n032,
      _TGPR,
      0,
      [_SCB, _SPRo, _DCB, _DPRe, _Pr10, _MDe],
      [[0, {
        [_eQN]: `SourceCidrBlock`,
        [_xN]: _sCB
      }], [0, {
        [_eQN]: `SourcePortRange`,
        [_xN]: _sPR
      }], [0, {
        [_eQN]: `DestinationCidrBlock`,
        [_xN]: _dCB
      }], [0, {
        [_eQN]: `DestinationPortRange`,
        [_xN]: _dPR
      }], [0, {
        [_eQN]: `Protocol`,
        [_xN]: _pr
      }], [() => exports2.TransitGatewayPolicyRuleMetaData$, {
        [_eQN]: `MetaData`,
        [_xN]: _mDe
      }]]
    ];
    exports2.TransitGatewayPolicyRuleMetaData$ = [
      3,
      n032,
      _TGPRMD,
      0,
      [_MDK, _MDV],
      [[0, {
        [_eQN]: `MetaDataKey`,
        [_xN]: _mDK
      }], [0, {
        [_eQN]: `MetaDataValue`,
        [_xN]: _mDV
      }]]
    ];
    exports2.TransitGatewayPolicyTable$ = [
      3,
      n032,
      _TGPT,
      0,
      [_TGPTI, _TGI, _St, _CTre, _T10],
      [[0, {
        [_eQN]: `TransitGatewayPolicyTableId`,
        [_xN]: _tGPTI
      }], [0, {
        [_eQN]: `TransitGatewayId`,
        [_xN]: _tGI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [4, {
        [_eQN]: `CreationTime`,
        [_xN]: _cTre
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.TransitGatewayPolicyTableAssociation$ = [
      3,
      n032,
      _TGPTA,
      0,
      [_TGPTI, _TGAI, _RIeso, _RTe, _St],
      [[0, {
        [_eQN]: `TransitGatewayPolicyTableId`,
        [_xN]: _tGPTI
      }], [0, {
        [_eQN]: `TransitGatewayAttachmentId`,
        [_xN]: _tGAI
      }], [0, {
        [_eQN]: `ResourceId`,
        [_xN]: _rIes
      }], [0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }]]
    ];
    exports2.TransitGatewayPolicyTableEntry$ = [
      3,
      n032,
      _TGPTEr,
      0,
      [_PRN, _PRol, _TRTI],
      [[0, {
        [_eQN]: `PolicyRuleNumber`,
        [_xN]: _pRN
      }], [() => exports2.TransitGatewayPolicyRule$, {
        [_eQN]: `PolicyRule`,
        [_xN]: _pRol
      }], [0, {
        [_eQN]: `TargetRouteTableId`,
        [_xN]: _tRTI
      }]]
    ];
    exports2.TransitGatewayPrefixListAttachment$ = [
      3,
      n032,
      _TGPLA,
      0,
      [_TGAI, _RTe, _RIeso],
      [[0, {
        [_eQN]: `TransitGatewayAttachmentId`,
        [_xN]: _tGAI
      }], [0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }], [0, {
        [_eQN]: `ResourceId`,
        [_xN]: _rIes
      }]]
    ];
    exports2.TransitGatewayPrefixListReference$ = [
      3,
      n032,
      _TGPLR,
      0,
      [_TGRTI, _PLI, _PLOI, _St, _Bl, _TGAra],
      [[0, {
        [_eQN]: `TransitGatewayRouteTableId`,
        [_xN]: _tGRTI
      }], [0, {
        [_eQN]: `PrefixListId`,
        [_xN]: _pLI
      }], [0, {
        [_eQN]: `PrefixListOwnerId`,
        [_xN]: _pLOI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [2, {
        [_eQN]: `Blackhole`,
        [_xN]: _bl
      }], [() => exports2.TransitGatewayPrefixListAttachment$, {
        [_eQN]: `TransitGatewayAttachment`,
        [_xN]: _tGAr
      }]]
    ];
    exports2.TransitGatewayPropagation$ = [
      3,
      n032,
      _TGP,
      0,
      [_TGAI, _RIeso, _RTe, _TGRTI, _St, _TGRTAI],
      [[0, {
        [_eQN]: `TransitGatewayAttachmentId`,
        [_xN]: _tGAI
      }], [0, {
        [_eQN]: `ResourceId`,
        [_xN]: _rIes
      }], [0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }], [0, {
        [_eQN]: `TransitGatewayRouteTableId`,
        [_xN]: _tGRTI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `TransitGatewayRouteTableAnnouncementId`,
        [_xN]: _tGRTAI
      }]]
    ];
    exports2.TransitGatewayRequestOptions$ = [
      3,
      n032,
      _TGRO,
      0,
      [_ASA, _AASAu, _DRTA, _DRTP, _VESp, _DSn, _SGRS, _MSu, _TGCB],
      [1, 0, 0, 0, 0, 0, 0, 0, [() => TransitGatewayCidrBlockStringList, 0]]
    ];
    exports2.TransitGatewayRoute$ = [
      3,
      n032,
      _TGR,
      0,
      [_DCB, _PLI, _TGRTAI, _TGAr, _Ty, _St],
      [[0, {
        [_eQN]: `DestinationCidrBlock`,
        [_xN]: _dCB
      }], [0, {
        [_eQN]: `PrefixListId`,
        [_xN]: _pLI
      }], [0, {
        [_eQN]: `TransitGatewayRouteTableAnnouncementId`,
        [_xN]: _tGRTAI
      }], [() => TransitGatewayRouteAttachmentList, {
        [_eQN]: `TransitGatewayAttachments`,
        [_xN]: _tGA
      }], [0, {
        [_eQN]: `Type`,
        [_xN]: _ty
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }]]
    ];
    exports2.TransitGatewayRouteAttachment$ = [
      3,
      n032,
      _TGRA,
      0,
      [_RIeso, _TGAI, _RTe],
      [[0, {
        [_eQN]: `ResourceId`,
        [_xN]: _rIes
      }], [0, {
        [_eQN]: `TransitGatewayAttachmentId`,
        [_xN]: _tGAI
      }], [0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }]]
    ];
    exports2.TransitGatewayRouteTable$ = [
      3,
      n032,
      _TGRT,
      0,
      [_TGRTI, _TGI, _St, _DART, _DPRT, _CTre, _T10],
      [[0, {
        [_eQN]: `TransitGatewayRouteTableId`,
        [_xN]: _tGRTI
      }], [0, {
        [_eQN]: `TransitGatewayId`,
        [_xN]: _tGI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [2, {
        [_eQN]: `DefaultAssociationRouteTable`,
        [_xN]: _dART
      }], [2, {
        [_eQN]: `DefaultPropagationRouteTable`,
        [_xN]: _dPRT
      }], [4, {
        [_eQN]: `CreationTime`,
        [_xN]: _cTre
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.TransitGatewayRouteTableAnnouncement$ = [
      3,
      n032,
      _TGRTA,
      0,
      [_TGRTAI, _TGI, _CNIor, _PTGI, _PCNI, _PAIe, _ADn, _TGRTI, _St, _CTre, _T10],
      [[0, {
        [_eQN]: `TransitGatewayRouteTableAnnouncementId`,
        [_xN]: _tGRTAI
      }], [0, {
        [_eQN]: `TransitGatewayId`,
        [_xN]: _tGI
      }], [0, {
        [_eQN]: `CoreNetworkId`,
        [_xN]: _cNIo
      }], [0, {
        [_eQN]: `PeerTransitGatewayId`,
        [_xN]: _pTGI
      }], [0, {
        [_eQN]: `PeerCoreNetworkId`,
        [_xN]: _pCNI
      }], [0, {
        [_eQN]: `PeeringAttachmentId`,
        [_xN]: _pAI
      }], [0, {
        [_eQN]: `AnnouncementDirection`,
        [_xN]: _aDn
      }], [0, {
        [_eQN]: `TransitGatewayRouteTableId`,
        [_xN]: _tGRTI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [4, {
        [_eQN]: `CreationTime`,
        [_xN]: _cTre
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.TransitGatewayRouteTableAssociation$ = [
      3,
      n032,
      _TGRTAra,
      0,
      [_TGAI, _RIeso, _RTe, _St],
      [[0, {
        [_eQN]: `TransitGatewayAttachmentId`,
        [_xN]: _tGAI
      }], [0, {
        [_eQN]: `ResourceId`,
        [_xN]: _rIes
      }], [0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }]]
    ];
    exports2.TransitGatewayRouteTablePropagation$ = [
      3,
      n032,
      _TGRTPr,
      0,
      [_TGAI, _RIeso, _RTe, _St, _TGRTAI],
      [[0, {
        [_eQN]: `TransitGatewayAttachmentId`,
        [_xN]: _tGAI
      }], [0, {
        [_eQN]: `ResourceId`,
        [_xN]: _rIes
      }], [0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `TransitGatewayRouteTableAnnouncementId`,
        [_xN]: _tGRTAI
      }]]
    ];
    exports2.TransitGatewayRouteTableRoute$ = [
      3,
      n032,
      _TGRTR,
      0,
      [_DCe, _St, _ROo, _PLI, _AItt, _RIeso, _RTe],
      [[0, {
        [_eQN]: `DestinationCidr`,
        [_xN]: _dC4
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `RouteOrigin`,
        [_xN]: _rOo
      }], [0, {
        [_eQN]: `PrefixListId`,
        [_xN]: _pLI
      }], [0, {
        [_eQN]: `AttachmentId`,
        [_xN]: _aIt
      }], [0, {
        [_eQN]: `ResourceId`,
        [_xN]: _rIes
      }], [0, {
        [_eQN]: `ResourceType`,
        [_xN]: _rTe
      }]]
    ];
    exports2.TransitGatewayVpcAttachment$ = [
      3,
      n032,
      _TGVA,
      0,
      [_TGAI, _TGI, _VI, _VOIp, _St, _SI10, _CTre, _Opt, _T10],
      [[0, {
        [_eQN]: `TransitGatewayAttachmentId`,
        [_xN]: _tGAI
      }], [0, {
        [_eQN]: `TransitGatewayId`,
        [_xN]: _tGI
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [0, {
        [_eQN]: `VpcOwnerId`,
        [_xN]: _vOIp
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [() => ValueStringList, {
        [_eQN]: `SubnetIds`,
        [_xN]: _sIub
      }], [4, {
        [_eQN]: `CreationTime`,
        [_xN]: _cTre
      }], [() => exports2.TransitGatewayVpcAttachmentOptions$, {
        [_eQN]: `Options`,
        [_xN]: _op
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.TransitGatewayVpcAttachmentOptions$ = [
      3,
      n032,
      _TGVAO,
      0,
      [_DSn, _SGRS, _ISpv, _AMS],
      [[0, {
        [_eQN]: `DnsSupport`,
        [_xN]: _dSn
      }], [0, {
        [_eQN]: `SecurityGroupReferencingSupport`,
        [_xN]: _sGRSec
      }], [0, {
        [_eQN]: `Ipv6Support`,
        [_xN]: _iSpvu
      }], [0, {
        [_eQN]: `ApplianceModeSupport`,
        [_xN]: _aMSp
      }]]
    ];
    exports2.TrunkInterfaceAssociation$ = [
      3,
      n032,
      _TIA,
      0,
      [_AIs, _BII, _TII, _IPnte, _VIl, _GK, _T10],
      [[0, {
        [_eQN]: `AssociationId`,
        [_xN]: _aIs
      }], [0, {
        [_eQN]: `BranchInterfaceId`,
        [_xN]: _bII
      }], [0, {
        [_eQN]: `TrunkInterfaceId`,
        [_xN]: _tII
      }], [0, {
        [_eQN]: `InterfaceProtocol`,
        [_xN]: _iPnte
      }], [1, {
        [_eQN]: `VlanId`,
        [_xN]: _vIl
      }], [1, {
        [_eQN]: `GreKey`,
        [_xN]: _gK
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.TunnelOption$ = [
      3,
      n032,
      _TOu,
      0,
      [_OIA, _TICu, _TIIC, _PSK, _PLS, _PLSh, _RMTS, _RFP, _RWS, _DTS, _DTA, _PEAha, _PEAhas, _PIAha, _PIAhas, _PDHGN, _PDHGNh, _IVk, _SAt, _LO, _ETLC],
      [[0, {
        [_eQN]: `OutsideIpAddress`,
        [_xN]: _oIA
      }], [0, {
        [_eQN]: `TunnelInsideCidr`,
        [_xN]: _tICu
      }], [0, {
        [_eQN]: `TunnelInsideIpv6Cidr`,
        [_xN]: _tIIC
      }], [() => preSharedKey, {
        [_eQN]: `PreSharedKey`,
        [_xN]: _pSK
      }], [1, {
        [_eQN]: `Phase1LifetimeSeconds`,
        [_xN]: _pLSh
      }], [1, {
        [_eQN]: `Phase2LifetimeSeconds`,
        [_xN]: _pLSha
      }], [1, {
        [_eQN]: `RekeyMarginTimeSeconds`,
        [_xN]: _rMTS
      }], [1, {
        [_eQN]: `RekeyFuzzPercentage`,
        [_xN]: _rFP
      }], [1, {
        [_eQN]: `ReplayWindowSize`,
        [_xN]: _rWS
      }], [1, {
        [_eQN]: `DpdTimeoutSeconds`,
        [_xN]: _dTS
      }], [0, {
        [_eQN]: `DpdTimeoutAction`,
        [_xN]: _dTA
      }], [() => Phase1EncryptionAlgorithmsList, {
        [_eQN]: `Phase1EncryptionAlgorithmSet`,
        [_xN]: _pEAS
      }], [() => Phase2EncryptionAlgorithmsList, {
        [_eQN]: `Phase2EncryptionAlgorithmSet`,
        [_xN]: _pEASh
      }], [() => Phase1IntegrityAlgorithmsList, {
        [_eQN]: `Phase1IntegrityAlgorithmSet`,
        [_xN]: _pIASh
      }], [() => Phase2IntegrityAlgorithmsList, {
        [_eQN]: `Phase2IntegrityAlgorithmSet`,
        [_xN]: _pIASha
      }], [() => Phase1DHGroupNumbersList, {
        [_eQN]: `Phase1DHGroupNumberSet`,
        [_xN]: _pDHGNS
      }], [() => Phase2DHGroupNumbersList, {
        [_eQN]: `Phase2DHGroupNumberSet`,
        [_xN]: _pDHGNSh
      }], [() => IKEVersionsList, {
        [_eQN]: `IkeVersionSet`,
        [_xN]: _iVS
      }], [0, {
        [_eQN]: `StartupAction`,
        [_xN]: _sAt
      }], [() => exports2.VpnTunnelLogOptions$, {
        [_eQN]: `LogOptions`,
        [_xN]: _lO
      }], [2, {
        [_eQN]: `EnableTunnelLifecycleControl`,
        [_xN]: _eTLC
      }]]
    ];
    exports2.UnassignIpv6AddressesRequest$ = [
      3,
      n032,
      _UIAR,
      0,
      [_NII, _IPp, _IA],
      [[0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], [() => IpPrefixList, { [_xN]: _IPpv }], [() => Ipv6AddressList, {
        [_eQN]: `Ipv6Addresses`,
        [_xN]: _iA
      }]],
      1
    ];
    exports2.UnassignIpv6AddressesResult$ = [
      3,
      n032,
      _UIARn,
      0,
      [_NII, _UIA, _UIPn],
      [[0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], [() => Ipv6AddressList, {
        [_eQN]: `UnassignedIpv6Addresses`,
        [_xN]: _uIA
      }], [() => IpPrefixList, {
        [_eQN]: `UnassignedIpv6PrefixSet`,
        [_xN]: _uIPSn
      }]]
    ];
    exports2.UnassignPrivateIpAddressesRequest$ = [
      3,
      n032,
      _UPIAR,
      0,
      [_NII, _IPpvr, _PIAri],
      [[0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], [() => IpPrefixList, { [_xN]: _IPpvre }], [() => PrivateIpAddressStringList, {
        [_eQN]: `PrivateIpAddress`,
        [_xN]: _pIAr
      }]],
      1
    ];
    exports2.UnassignPrivateNatGatewayAddressRequest$ = [
      3,
      n032,
      _UPNGAR,
      0,
      [_NGI, _PIAri, _MDDS, _DR],
      [0, [() => IpList, { [_xN]: _PIAr }], 1, 2],
      2
    ];
    exports2.UnassignPrivateNatGatewayAddressResult$ = [
      3,
      n032,
      _UPNGARn,
      0,
      [_NGI, _NGA],
      [[0, {
        [_eQN]: `NatGatewayId`,
        [_xN]: _nGI
      }], [() => NatGatewayAddressList, {
        [_eQN]: `NatGatewayAddressSet`,
        [_xN]: _nGAS
      }]]
    ];
    exports2.UnlockSnapshotRequest$ = [
      3,
      n032,
      _USR,
      0,
      [_SIn, _DR],
      [0, 2],
      1
    ];
    exports2.UnlockSnapshotResult$ = [
      3,
      n032,
      _USRn,
      0,
      [_SIn],
      [[0, {
        [_eQN]: `SnapshotId`,
        [_xN]: _sIn
      }]]
    ];
    exports2.UnmonitorInstancesRequest$ = [
      3,
      n032,
      _UIR,
      0,
      [_IIns, _DR],
      [[() => InstanceIdStringList, { [_xN]: _II2 }], [2, {
        [_eQN]: `DryRun`,
        [_xN]: _dR
      }]],
      1
    ];
    exports2.UnmonitorInstancesResult$ = [
      3,
      n032,
      _UIRn,
      0,
      [_IMns],
      [[() => InstanceMonitoringList, {
        [_eQN]: `InstancesSet`,
        [_xN]: _iSn
      }]]
    ];
    exports2.UnsuccessfulInstanceCreditSpecificationItem$ = [
      3,
      n032,
      _UICSI,
      0,
      [_II2, _Er],
      [[0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [() => exports2.UnsuccessfulInstanceCreditSpecificationItemError$, {
        [_eQN]: `Error`,
        [_xN]: _er
      }]]
    ];
    exports2.UnsuccessfulInstanceCreditSpecificationItemError$ = [
      3,
      n032,
      _UICSIE,
      0,
      [_Co, _Me],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }]]
    ];
    exports2.UnsuccessfulItem$ = [
      3,
      n032,
      _UIn,
      0,
      [_Er, _RIeso],
      [[() => exports2.UnsuccessfulItemError$, {
        [_eQN]: `Error`,
        [_xN]: _er
      }], [0, {
        [_eQN]: `ResourceId`,
        [_xN]: _rIes
      }]]
    ];
    exports2.UnsuccessfulItemError$ = [
      3,
      n032,
      _UIEn,
      0,
      [_Co, _Me],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }]]
    ];
    exports2.UpdateCapacityManagerMonitoredTagKeysRequest$ = [
      3,
      n032,
      _UCMMTKR,
      0,
      [_ATK, _DTK, _DR, _CT4],
      [[() => ValueStringList, { [_xN]: _ATKc }], [() => ValueStringList, { [_xN]: _DTKe }], 2, [0, 4]]
    ];
    exports2.UpdateCapacityManagerMonitoredTagKeysResult$ = [
      3,
      n032,
      _UCMMTKRp,
      0,
      [_CMTK],
      [[() => CapacityManagerMonitoredTagKeyList, {
        [_eQN]: `CapacityManagerTagKeySet`,
        [_xN]: _cMTKS
      }]]
    ];
    exports2.UpdateCapacityManagerOrganizationsAccessRequest$ = [
      3,
      n032,
      _UCMOAR,
      0,
      [_OAr, _DR, _CT4],
      [2, 2, [0, 4]],
      1
    ];
    exports2.UpdateCapacityManagerOrganizationsAccessResult$ = [
      3,
      n032,
      _UCMOARp,
      0,
      [_CMS, _OAr],
      [[0, {
        [_eQN]: `CapacityManagerStatus`,
        [_xN]: _cMS
      }], [2, {
        [_eQN]: `OrganizationsAccess`,
        [_xN]: _oAr
      }]]
    ];
    exports2.UpdateInterruptibleCapacityReservationAllocationRequest$ = [
      3,
      n032,
      _UICRAR,
      0,
      [_CRI, _TICa, _DR],
      [0, 1, 2],
      2
    ];
    exports2.UpdateInterruptibleCapacityReservationAllocationResult$ = [
      3,
      n032,
      _UICRARp,
      0,
      [_ICRI, _SCRI, _IC, _TICa, _Sta, _ITn],
      [[0, {
        [_eQN]: `InterruptibleCapacityReservationId`,
        [_xN]: _iCRI
      }], [0, {
        [_eQN]: `SourceCapacityReservationId`,
        [_xN]: _sCRI
      }], [1, {
        [_eQN]: `InstanceCount`,
        [_xN]: _iC
      }], [1, {
        [_eQN]: `TargetInstanceCount`,
        [_xN]: _tICa
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `InterruptionType`,
        [_xN]: _iTn
      }]]
    ];
    exports2.UpdateSecurityGroupRuleDescriptionsEgressRequest$ = [
      3,
      n032,
      _USGRDER,
      0,
      [_DR, _GIr, _GN, _IPpe, _SGRDe],
      [2, 0, 0, [() => IpPermissionList, 0], [() => SecurityGroupRuleDescriptionList, { [_xN]: _SGRD }]]
    ];
    exports2.UpdateSecurityGroupRuleDescriptionsEgressResult$ = [
      3,
      n032,
      _USGRDERp,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.UpdateSecurityGroupRuleDescriptionsIngressRequest$ = [
      3,
      n032,
      _USGRDIR,
      0,
      [_DR, _GIr, _GN, _IPpe, _SGRDe],
      [2, 0, 0, [() => IpPermissionList, 0], [() => SecurityGroupRuleDescriptionList, { [_xN]: _SGRD }]]
    ];
    exports2.UpdateSecurityGroupRuleDescriptionsIngressResult$ = [
      3,
      n032,
      _USGRDIRp,
      0,
      [_R],
      [[2, {
        [_eQN]: `Return`,
        [_xN]: _r4
      }]]
    ];
    exports2.UserBucket$ = [
      3,
      n032,
      _UB,
      0,
      [_SB, _SK2],
      [0, 0]
    ];
    exports2.UserBucketDetails$ = [
      3,
      n032,
      _UBD,
      0,
      [_SB, _SK2],
      [[0, {
        [_eQN]: `S3Bucket`,
        [_xN]: _sB
      }], [0, {
        [_eQN]: `S3Key`,
        [_xN]: _sK
      }]]
    ];
    exports2.UserData$ = [
      3,
      n032,
      _UDs,
      8,
      [_Da],
      [[0, {
        [_eQN]: `Data`,
        [_xN]: _da
      }]]
    ];
    exports2.UserIdGroupPair$ = [
      3,
      n032,
      _UIGPs,
      0,
      [_De, _UI, _GN, _GIr, _VI, _VPCI, _PSee],
      [[0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [0, {
        [_eQN]: `UserId`,
        [_xN]: _uI
      }], [0, {
        [_eQN]: `GroupName`,
        [_xN]: _gN
      }], [0, {
        [_eQN]: `GroupId`,
        [_xN]: _gIr
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [0, {
        [_eQN]: `VpcPeeringConnectionId`,
        [_xN]: _vPCI
      }], [0, {
        [_eQN]: `PeeringStatus`,
        [_xN]: _pSee
      }]]
    ];
    exports2.ValidationError$ = [
      3,
      n032,
      _VEa,
      0,
      [_Co, _Me],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }]]
    ];
    exports2.ValidationWarning$ = [
      3,
      n032,
      _VW,
      0,
      [_Err],
      [[() => ErrorSet, {
        [_eQN]: `ErrorSet`,
        [_xN]: _eSr
      }]]
    ];
    exports2.VCpuCountRange$ = [
      3,
      n032,
      _VCCR,
      0,
      [_M, _Ma],
      [[1, {
        [_eQN]: `Min`,
        [_xN]: _m29
      }], [1, {
        [_eQN]: `Max`,
        [_xN]: _ma
      }]]
    ];
    exports2.VCpuCountRangeRequest$ = [
      3,
      n032,
      _VCCRR,
      0,
      [_M, _Ma],
      [1, 1],
      1
    ];
    exports2.VCpuInfo$ = [
      3,
      n032,
      _VCIpu,
      0,
      [_DVC, _DCef, _DTPC, _VCa, _VTPC],
      [[1, {
        [_eQN]: `DefaultVCpus`,
        [_xN]: _dVC
      }], [1, {
        [_eQN]: `DefaultCores`,
        [_xN]: _dCe
      }], [1, {
        [_eQN]: `DefaultThreadsPerCore`,
        [_xN]: _dTPC
      }], [() => CoreCountList, {
        [_eQN]: `ValidCores`,
        [_xN]: _vCa
      }], [() => ThreadsPerCoreList, {
        [_eQN]: `ValidThreadsPerCore`,
        [_xN]: _vTPC
      }]]
    ];
    exports2.VerifiedAccessEndpoint$ = [
      3,
      n032,
      _VAE,
      0,
      [_VAII, _VAGI, _VAEI, _ADp, _ETn, _ATt, _DCA, _EDnd, _DVD, _SGIe, _LBO, _NIO, _Sta, _De, _CTre, _LUTa, _DT, _T10, _SSs, _ROd, _COi],
      [[0, {
        [_eQN]: `VerifiedAccessInstanceId`,
        [_xN]: _vAII
      }], [0, {
        [_eQN]: `VerifiedAccessGroupId`,
        [_xN]: _vAGI
      }], [0, {
        [_eQN]: `VerifiedAccessEndpointId`,
        [_xN]: _vAEI
      }], [0, {
        [_eQN]: `ApplicationDomain`,
        [_xN]: _aDp
      }], [0, {
        [_eQN]: `EndpointType`,
        [_xN]: _eTnd
      }], [0, {
        [_eQN]: `AttachmentType`,
        [_xN]: _aTtta
      }], [0, {
        [_eQN]: `DomainCertificateArn`,
        [_xN]: _dCA
      }], [0, {
        [_eQN]: `EndpointDomain`,
        [_xN]: _eDnd
      }], [0, {
        [_eQN]: `DeviceValidationDomain`,
        [_xN]: _dVD
      }], [() => SecurityGroupIdList, {
        [_eQN]: `SecurityGroupIdSet`,
        [_xN]: _sGIS
      }], [() => exports2.VerifiedAccessEndpointLoadBalancerOptions$, {
        [_eQN]: `LoadBalancerOptions`,
        [_xN]: _lBO
      }], [() => exports2.VerifiedAccessEndpointEniOptions$, {
        [_eQN]: `NetworkInterfaceOptions`,
        [_xN]: _nIO
      }], [() => exports2.VerifiedAccessEndpointStatus$, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [0, {
        [_eQN]: `CreationTime`,
        [_xN]: _cTre
      }], [0, {
        [_eQN]: `LastUpdatedTime`,
        [_xN]: _lUTa
      }], [0, {
        [_eQN]: `DeletionTime`,
        [_xN]: _dT
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [() => exports2.VerifiedAccessSseSpecificationResponse$, {
        [_eQN]: `SseSpecification`,
        [_xN]: _sSs
      }], [() => exports2.VerifiedAccessEndpointRdsOptions$, {
        [_eQN]: `RdsOptions`,
        [_xN]: _rOd
      }], [() => exports2.VerifiedAccessEndpointCidrOptions$, {
        [_eQN]: `CidrOptions`,
        [_xN]: _cOi
      }]]
    ];
    exports2.VerifiedAccessEndpointCidrOptions$ = [
      3,
      n032,
      _VAECO,
      0,
      [_Ci, _PRor, _Pr10, _SI10],
      [[0, {
        [_eQN]: `Cidr`,
        [_xN]: _ci
      }], [() => VerifiedAccessEndpointPortRangeList, {
        [_eQN]: `PortRangeSet`,
        [_xN]: _pRS
      }], [0, {
        [_eQN]: `Protocol`,
        [_xN]: _pr
      }], [() => VerifiedAccessEndpointSubnetIdList, {
        [_eQN]: `SubnetIdSet`,
        [_xN]: _sISu
      }]]
    ];
    exports2.VerifiedAccessEndpointEniOptions$ = [
      3,
      n032,
      _VAEEO,
      0,
      [_NII, _Pr10, _Po, _PRor],
      [[0, {
        [_eQN]: `NetworkInterfaceId`,
        [_xN]: _nII
      }], [0, {
        [_eQN]: `Protocol`,
        [_xN]: _pr
      }], [1, {
        [_eQN]: `Port`,
        [_xN]: _po
      }], [() => VerifiedAccessEndpointPortRangeList, {
        [_eQN]: `PortRangeSet`,
        [_xN]: _pRS
      }]]
    ];
    exports2.VerifiedAccessEndpointLoadBalancerOptions$ = [
      3,
      n032,
      _VAELBO,
      0,
      [_Pr10, _Po, _LBAo, _SI10, _PRor],
      [[0, {
        [_eQN]: `Protocol`,
        [_xN]: _pr
      }], [1, {
        [_eQN]: `Port`,
        [_xN]: _po
      }], [0, {
        [_eQN]: `LoadBalancerArn`,
        [_xN]: _lBA
      }], [() => VerifiedAccessEndpointSubnetIdList, {
        [_eQN]: `SubnetIdSet`,
        [_xN]: _sISu
      }], [() => VerifiedAccessEndpointPortRangeList, {
        [_eQN]: `PortRangeSet`,
        [_xN]: _pRS
      }]]
    ];
    exports2.VerifiedAccessEndpointPortRange$ = [
      3,
      n032,
      _VAEPR,
      0,
      [_FP, _TP],
      [[1, {
        [_eQN]: `FromPort`,
        [_xN]: _fP
      }], [1, {
        [_eQN]: `ToPort`,
        [_xN]: _tP
      }]]
    ];
    exports2.VerifiedAccessEndpointRdsOptions$ = [
      3,
      n032,
      _VAERO,
      0,
      [_Pr10, _Po, _RDIA, _RDCA, _RDPA, _RE, _SI10],
      [[0, {
        [_eQN]: `Protocol`,
        [_xN]: _pr
      }], [1, {
        [_eQN]: `Port`,
        [_xN]: _po
      }], [0, {
        [_eQN]: `RdsDbInstanceArn`,
        [_xN]: _rDIA
      }], [0, {
        [_eQN]: `RdsDbClusterArn`,
        [_xN]: _rDCA
      }], [0, {
        [_eQN]: `RdsDbProxyArn`,
        [_xN]: _rDPA
      }], [0, {
        [_eQN]: `RdsEndpoint`,
        [_xN]: _rEd
      }], [() => VerifiedAccessEndpointSubnetIdList, {
        [_eQN]: `SubnetIdSet`,
        [_xN]: _sISu
      }]]
    ];
    exports2.VerifiedAccessEndpointStatus$ = [
      3,
      n032,
      _VAES,
      0,
      [_Co, _Me],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }]]
    ];
    exports2.VerifiedAccessEndpointTarget$ = [
      3,
      n032,
      _VAETe,
      0,
      [_VAEI, _VAETIA, _VAETD],
      [[0, {
        [_eQN]: `VerifiedAccessEndpointId`,
        [_xN]: _vAEI
      }], [0, {
        [_eQN]: `VerifiedAccessEndpointTargetIpAddress`,
        [_xN]: _vAETIA
      }], [0, {
        [_eQN]: `VerifiedAccessEndpointTargetDns`,
        [_xN]: _vAETD
      }]]
    ];
    exports2.VerifiedAccessGroup$ = [
      3,
      n032,
      _VAG,
      0,
      [_VAGI, _VAII, _De, _Own, _VAGA, _CTre, _LUTa, _DT, _T10, _SSs],
      [[0, {
        [_eQN]: `VerifiedAccessGroupId`,
        [_xN]: _vAGI
      }], [0, {
        [_eQN]: `VerifiedAccessInstanceId`,
        [_xN]: _vAII
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [0, {
        [_eQN]: `Owner`,
        [_xN]: _ow
      }], [0, {
        [_eQN]: `VerifiedAccessGroupArn`,
        [_xN]: _vAGA
      }], [0, {
        [_eQN]: `CreationTime`,
        [_xN]: _cTre
      }], [0, {
        [_eQN]: `LastUpdatedTime`,
        [_xN]: _lUTa
      }], [0, {
        [_eQN]: `DeletionTime`,
        [_xN]: _dT
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [() => exports2.VerifiedAccessSseSpecificationResponse$, {
        [_eQN]: `SseSpecification`,
        [_xN]: _sSs
      }]]
    ];
    exports2.VerifiedAccessInstance$ = [
      3,
      n032,
      _VAI,
      0,
      [_VAII, _De, _VATPe, _CTre, _LUTa, _T10, _FE, _CECSD],
      [[0, {
        [_eQN]: `VerifiedAccessInstanceId`,
        [_xN]: _vAII
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [() => VerifiedAccessTrustProviderCondensedList, {
        [_eQN]: `VerifiedAccessTrustProviderSet`,
        [_xN]: _vATPS
      }], [0, {
        [_eQN]: `CreationTime`,
        [_xN]: _cTre
      }], [0, {
        [_eQN]: `LastUpdatedTime`,
        [_xN]: _lUTa
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [2, {
        [_eQN]: `FipsEnabled`,
        [_xN]: _fE
      }], [() => exports2.VerifiedAccessInstanceCustomSubDomain$, {
        [_eQN]: `CidrEndpointsCustomSubDomain`,
        [_xN]: _cECSD
      }]]
    ];
    exports2.VerifiedAccessInstanceCustomSubDomain$ = [
      3,
      n032,
      _VAICSD,
      0,
      [_SDu, _Na],
      [[0, {
        [_eQN]: `SubDomain`,
        [_xN]: _sDu
      }], [() => ValueStringList, {
        [_eQN]: `NameserverSet`,
        [_xN]: _nSa
      }]]
    ];
    exports2.VerifiedAccessInstanceLoggingConfiguration$ = [
      3,
      n032,
      _VAILC,
      0,
      [_VAII, _ALc],
      [[0, {
        [_eQN]: `VerifiedAccessInstanceId`,
        [_xN]: _vAII
      }], [() => exports2.VerifiedAccessLogs$, {
        [_eQN]: `AccessLogs`,
        [_xN]: _aLc
      }]]
    ];
    exports2.VerifiedAccessInstanceOpenVpnClientConfiguration$ = [
      3,
      n032,
      _VAIOVCC,
      0,
      [_Confi, _Rou],
      [[0, {
        [_eQN]: `Config`,
        [_xN]: _confi
      }], [() => VerifiedAccessInstanceOpenVpnClientConfigurationRouteList, {
        [_eQN]: `RouteSet`,
        [_xN]: _rSou
      }]]
    ];
    exports2.VerifiedAccessInstanceOpenVpnClientConfigurationRoute$ = [
      3,
      n032,
      _VAIOVCCR,
      0,
      [_Ci],
      [[0, {
        [_eQN]: `Cidr`,
        [_xN]: _ci
      }]]
    ];
    exports2.VerifiedAccessInstanceUserTrustProviderClientConfiguration$ = [
      3,
      n032,
      _VAIUTPCC,
      0,
      [_Ty, _Scop, _Is, _AE, _PSKE, _TEo, _UIE, _CIli, _CS4, _PEk],
      [[0, {
        [_eQN]: `Type`,
        [_xN]: _ty
      }], [0, {
        [_eQN]: `Scopes`,
        [_xN]: _scop
      }], [0, {
        [_eQN]: `Issuer`,
        [_xN]: _is
      }], [0, {
        [_eQN]: `AuthorizationEndpoint`,
        [_xN]: _aE
      }], [0, {
        [_eQN]: `PublicSigningKeyEndpoint`,
        [_xN]: _pSKE
      }], [0, {
        [_eQN]: `TokenEndpoint`,
        [_xN]: _tEo
      }], [0, {
        [_eQN]: `UserInfoEndpoint`,
        [_xN]: _uIE
      }], [0, {
        [_eQN]: `ClientId`,
        [_xN]: _cIli
      }], [() => ClientSecretType, {
        [_eQN]: `ClientSecret`,
        [_xN]: _cSl
      }], [2, {
        [_eQN]: `PkceEnabled`,
        [_xN]: _pEk
      }]]
    ];
    exports2.VerifiedAccessLogCloudWatchLogsDestination$ = [
      3,
      n032,
      _VALCWLD,
      0,
      [_En, _DSe, _LGog],
      [[2, {
        [_eQN]: `Enabled`,
        [_xN]: _en
      }], [() => exports2.VerifiedAccessLogDeliveryStatus$, {
        [_eQN]: `DeliveryStatus`,
        [_xN]: _dSel
      }], [0, {
        [_eQN]: `LogGroup`,
        [_xN]: _lGo
      }]]
    ];
    exports2.VerifiedAccessLogCloudWatchLogsDestinationOptions$ = [
      3,
      n032,
      _VALCWLDO,
      0,
      [_En, _LGog],
      [2, 0],
      1
    ];
    exports2.VerifiedAccessLogDeliveryStatus$ = [
      3,
      n032,
      _VALDS,
      0,
      [_Co, _Me],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }]]
    ];
    exports2.VerifiedAccessLogKinesisDataFirehoseDestination$ = [
      3,
      n032,
      _VALKDFD,
      0,
      [_En, _DSe, _DSel],
      [[2, {
        [_eQN]: `Enabled`,
        [_xN]: _en
      }], [() => exports2.VerifiedAccessLogDeliveryStatus$, {
        [_eQN]: `DeliveryStatus`,
        [_xN]: _dSel
      }], [0, {
        [_eQN]: `DeliveryStream`,
        [_xN]: _dSeli
      }]]
    ];
    exports2.VerifiedAccessLogKinesisDataFirehoseDestinationOptions$ = [
      3,
      n032,
      _VALKDFDO,
      0,
      [_En, _DSel],
      [2, 0],
      1
    ];
    exports2.VerifiedAccessLogOptions$ = [
      3,
      n032,
      _VALO,
      0,
      [_S_, _CWL, _KDF, _LV, _ITCn],
      [() => exports2.VerifiedAccessLogS3DestinationOptions$, () => exports2.VerifiedAccessLogCloudWatchLogsDestinationOptions$, () => exports2.VerifiedAccessLogKinesisDataFirehoseDestinationOptions$, 0, 2]
    ];
    exports2.VerifiedAccessLogs$ = [
      3,
      n032,
      _VAL,
      0,
      [_S_, _CWL, _KDF, _LV, _ITCn],
      [[() => exports2.VerifiedAccessLogS3Destination$, {
        [_eQN]: `S3`,
        [_xN]: _s_
      }], [() => exports2.VerifiedAccessLogCloudWatchLogsDestination$, {
        [_eQN]: `CloudWatchLogs`,
        [_xN]: _cWL
      }], [() => exports2.VerifiedAccessLogKinesisDataFirehoseDestination$, {
        [_eQN]: `KinesisDataFirehose`,
        [_xN]: _kDF
      }], [0, {
        [_eQN]: `LogVersion`,
        [_xN]: _lV
      }], [2, {
        [_eQN]: `IncludeTrustContext`,
        [_xN]: _iTCn
      }]]
    ];
    exports2.VerifiedAccessLogS3Destination$ = [
      3,
      n032,
      _VALSD,
      0,
      [_En, _DSe, _BN, _Pre, _BOu],
      [[2, {
        [_eQN]: `Enabled`,
        [_xN]: _en
      }], [() => exports2.VerifiedAccessLogDeliveryStatus$, {
        [_eQN]: `DeliveryStatus`,
        [_xN]: _dSel
      }], [0, {
        [_eQN]: `BucketName`,
        [_xN]: _bN
      }], [0, {
        [_eQN]: `Prefix`,
        [_xN]: _pre
      }], [0, {
        [_eQN]: `BucketOwner`,
        [_xN]: _bOu
      }]]
    ];
    exports2.VerifiedAccessLogS3DestinationOptions$ = [
      3,
      n032,
      _VALSDO,
      0,
      [_En, _BN, _Pre, _BOu],
      [2, 0, 0, 0],
      1
    ];
    exports2.VerifiedAccessSseSpecificationRequest$ = [
      3,
      n032,
      _VASSR,
      0,
      [_CMKE, _KKA],
      [2, 0]
    ];
    exports2.VerifiedAccessSseSpecificationResponse$ = [
      3,
      n032,
      _VASSRe,
      0,
      [_CMKE, _KKA],
      [[2, {
        [_eQN]: `CustomerManagedKeyEnabled`,
        [_xN]: _cMKE
      }], [0, {
        [_eQN]: `KmsKeyArn`,
        [_xN]: _kKA
      }]]
    ];
    exports2.VerifiedAccessTrustProvider$ = [
      3,
      n032,
      _VATP,
      0,
      [_VATPI, _De, _TPT, _UTPT, _DTPT, _OO, _DOev, _PRNo, _CTre, _LUTa, _T10, _SSs, _NAOO],
      [[0, {
        [_eQN]: `VerifiedAccessTrustProviderId`,
        [_xN]: _vATPI
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [0, {
        [_eQN]: `TrustProviderType`,
        [_xN]: _tPT
      }], [0, {
        [_eQN]: `UserTrustProviderType`,
        [_xN]: _uTPT
      }], [0, {
        [_eQN]: `DeviceTrustProviderType`,
        [_xN]: _dTPT
      }], [() => exports2.OidcOptions$, {
        [_eQN]: `OidcOptions`,
        [_xN]: _oO
      }], [() => exports2.DeviceOptions$, {
        [_eQN]: `DeviceOptions`,
        [_xN]: _dOev
      }], [0, {
        [_eQN]: `PolicyReferenceName`,
        [_xN]: _pRNo
      }], [0, {
        [_eQN]: `CreationTime`,
        [_xN]: _cTre
      }], [0, {
        [_eQN]: `LastUpdatedTime`,
        [_xN]: _lUTa
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [() => exports2.VerifiedAccessSseSpecificationResponse$, {
        [_eQN]: `SseSpecification`,
        [_xN]: _sSs
      }], [() => exports2.NativeApplicationOidcOptions$, {
        [_eQN]: `NativeApplicationOidcOptions`,
        [_xN]: _nAOO
      }]]
    ];
    exports2.VerifiedAccessTrustProviderCondensed$ = [
      3,
      n032,
      _VATPC,
      0,
      [_VATPI, _De, _TPT, _UTPT, _DTPT],
      [[0, {
        [_eQN]: `VerifiedAccessTrustProviderId`,
        [_xN]: _vATPI
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [0, {
        [_eQN]: `TrustProviderType`,
        [_xN]: _tPT
      }], [0, {
        [_eQN]: `UserTrustProviderType`,
        [_xN]: _uTPT
      }], [0, {
        [_eQN]: `DeviceTrustProviderType`,
        [_xN]: _dTPT
      }]]
    ];
    exports2.VgwTelemetry$ = [
      3,
      n032,
      _VTg,
      0,
      [_ARC, _LSC, _OIA, _Sta, _SMt, _CAe],
      [[1, {
        [_eQN]: `AcceptedRouteCount`,
        [_xN]: _aRC
      }], [4, {
        [_eQN]: `LastStatusChange`,
        [_xN]: _lSC
      }], [0, {
        [_eQN]: `OutsideIpAddress`,
        [_xN]: _oIA
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [0, {
        [_eQN]: `StatusMessage`,
        [_xN]: _sMt
      }], [0, {
        [_eQN]: `CertificateArn`,
        [_xN]: _cAe
      }]]
    ];
    exports2.Volume$ = [
      3,
      n032,
      _Vol,
      0,
      [_AZI, _OA, _SVI, _Io, _T10, _VT, _FRa, _MAE, _Th, _STs, _Op, _VIR, _VIo, _Siz, _SIn, _AZ, _St, _CTr, _Atta, _Enc, _KKI],
      [[0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [0, {
        [_eQN]: `OutpostArn`,
        [_xN]: _oA
      }], [0, {
        [_eQN]: `SourceVolumeId`,
        [_xN]: _sVI
      }], [1, {
        [_eQN]: `Iops`,
        [_xN]: _io
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `VolumeType`,
        [_xN]: _vT
      }], [2, {
        [_eQN]: `FastRestored`,
        [_xN]: _fRa
      }], [2, {
        [_eQN]: `MultiAttachEnabled`,
        [_xN]: _mAE
      }], [1, {
        [_eQN]: `Throughput`,
        [_xN]: _th
      }], [0, {
        [_eQN]: `SseType`,
        [_xN]: _sTs
      }], [() => exports2.OperatorResponse$, {
        [_eQN]: `Operator`,
        [_xN]: _ope
      }], [1, {
        [_eQN]: `VolumeInitializationRate`,
        [_xN]: _vIR
      }], [0, {
        [_eQN]: `VolumeId`,
        [_xN]: _vIo
      }], [1, {
        [_eQN]: `Size`,
        [_xN]: _si
      }], [0, {
        [_eQN]: `SnapshotId`,
        [_xN]: _sIn
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [4, {
        [_eQN]: `CreateTime`,
        [_xN]: _cTr
      }], [() => VolumeAttachmentList, {
        [_eQN]: `AttachmentSet`,
        [_xN]: _aSt
      }], [2, {
        [_eQN]: `Encrypted`,
        [_xN]: _enc
      }], [0, {
        [_eQN]: `KmsKeyId`,
        [_xN]: _kKI
      }]]
    ];
    exports2.VolumeAttachment$ = [
      3,
      n032,
      _VAo,
      0,
      [_DOT, _ARss, _IOS, _ECI, _VIo, _II2, _Dev, _St, _ATtt],
      [[2, {
        [_eQN]: `DeleteOnTermination`,
        [_xN]: _dOT
      }], [0, {
        [_eQN]: `AssociatedResource`,
        [_xN]: _aRs
      }], [0, {
        [_eQN]: `InstanceOwningService`,
        [_xN]: _iOS
      }], [1, {
        [_eQN]: `EbsCardIndex`,
        [_xN]: _eCI
      }], [0, {
        [_eQN]: `VolumeId`,
        [_xN]: _vIo
      }], [0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }], [0, {
        [_eQN]: `Device`,
        [_xN]: _dev
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [4, {
        [_eQN]: `AttachTime`,
        [_xN]: _aTt
      }]]
    ];
    exports2.VolumeDetail$ = [
      3,
      n032,
      _VDo,
      0,
      [_Siz],
      [[1, {
        [_eQN]: `Size`,
        [_xN]: _si
      }]],
      1
    ];
    exports2.VolumeModification$ = [
      3,
      n032,
      _VMo,
      0,
      [_VIo, _MSod, _SMt, _TSarg, _TIar, _TVT, _TTar, _TMAE, _OSr, _OIr, _OVT, _OTri, _OMAE, _Pro, _ST11, _ETnd, _Op],
      [[0, {
        [_eQN]: `VolumeId`,
        [_xN]: _vIo
      }], [0, {
        [_eQN]: `ModificationState`,
        [_xN]: _mSod
      }], [0, {
        [_eQN]: `StatusMessage`,
        [_xN]: _sMt
      }], [1, {
        [_eQN]: `TargetSize`,
        [_xN]: _tSar
      }], [1, {
        [_eQN]: `TargetIops`,
        [_xN]: _tIar
      }], [0, {
        [_eQN]: `TargetVolumeType`,
        [_xN]: _tVT
      }], [1, {
        [_eQN]: `TargetThroughput`,
        [_xN]: _tTar
      }], [2, {
        [_eQN]: `TargetMultiAttachEnabled`,
        [_xN]: _tMAE
      }], [1, {
        [_eQN]: `OriginalSize`,
        [_xN]: _oSr
      }], [1, {
        [_eQN]: `OriginalIops`,
        [_xN]: _oIr
      }], [0, {
        [_eQN]: `OriginalVolumeType`,
        [_xN]: _oVT
      }], [1, {
        [_eQN]: `OriginalThroughput`,
        [_xN]: _oTr
      }], [2, {
        [_eQN]: `OriginalMultiAttachEnabled`,
        [_xN]: _oMAE
      }], [1, {
        [_eQN]: `Progress`,
        [_xN]: _pro
      }], [4, {
        [_eQN]: `StartTime`,
        [_xN]: _sT19
      }], [4, {
        [_eQN]: `EndTime`,
        [_xN]: _eTn
      }], [() => exports2.OperatorResponse$, {
        [_eQN]: `Operator`,
        [_xN]: _ope
      }]]
    ];
    exports2.VolumeRecycleBinInfo$ = [
      3,
      n032,
      _VRBI,
      0,
      [_VIo, _VT, _St, _Siz, _Io, _Th, _OA, _AZ, _AZI, _SVI, _SIn, _Op, _CTr, _RBET, _RBETe],
      [[0, {
        [_eQN]: `VolumeId`,
        [_xN]: _vIo
      }], [0, {
        [_eQN]: `VolumeType`,
        [_xN]: _vT
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [1, {
        [_eQN]: `Size`,
        [_xN]: _si
      }], [1, {
        [_eQN]: `Iops`,
        [_xN]: _io
      }], [1, {
        [_eQN]: `Throughput`,
        [_xN]: _th
      }], [0, {
        [_eQN]: `OutpostArn`,
        [_xN]: _oA
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [0, {
        [_eQN]: `SourceVolumeId`,
        [_xN]: _sVI
      }], [0, {
        [_eQN]: `SnapshotId`,
        [_xN]: _sIn
      }], [() => exports2.OperatorResponse$, {
        [_eQN]: `Operator`,
        [_xN]: _ope
      }], [4, {
        [_eQN]: `CreateTime`,
        [_xN]: _cTr
      }], [4, {
        [_eQN]: `RecycleBinEnterTime`,
        [_xN]: _rBET
      }], [4, {
        [_eQN]: `RecycleBinExitTime`,
        [_xN]: _rBETe
      }]]
    ];
    exports2.VolumeStatusAction$ = [
      3,
      n032,
      _VSA,
      0,
      [_Co, _De, _EIve, _ETv],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [0, {
        [_eQN]: `EventId`,
        [_xN]: _eIve
      }], [0, {
        [_eQN]: `EventType`,
        [_xN]: _eTv
      }]]
    ];
    exports2.VolumeStatusAttachmentStatus$ = [
      3,
      n032,
      _VSAS,
      0,
      [_IPo, _II2],
      [[0, {
        [_eQN]: `IoPerformance`,
        [_xN]: _iPo
      }], [0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }]]
    ];
    exports2.VolumeStatusDetails$ = [
      3,
      n032,
      _VSD,
      0,
      [_N, _Sta],
      [[0, {
        [_eQN]: `Name`,
        [_xN]: _n
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }]]
    ];
    exports2.VolumeStatusEvent$ = [
      3,
      n032,
      _VSE,
      0,
      [_De, _EIve, _ETv, _NAo, _NB, _II2],
      [[0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [0, {
        [_eQN]: `EventId`,
        [_xN]: _eIve
      }], [0, {
        [_eQN]: `EventType`,
        [_xN]: _eTv
      }], [4, {
        [_eQN]: `NotAfter`,
        [_xN]: _nAo
      }], [4, {
        [_eQN]: `NotBefore`,
        [_xN]: _nB
      }], [0, {
        [_eQN]: `InstanceId`,
        [_xN]: _iI
      }]]
    ];
    exports2.VolumeStatusInfo$ = [
      3,
      n032,
      _VSI,
      0,
      [_Det, _Sta],
      [[() => VolumeStatusDetailsList, {
        [_eQN]: `Details`,
        [_xN]: _det
      }], [0, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }]]
    ];
    exports2.VolumeStatusItem$ = [
      3,
      n032,
      _VSIo,
      0,
      [_Acti, _AZ, _OA, _Ev, _VIo, _VSol, _ASttac, _ISD, _AZI, _Op],
      [[() => VolumeStatusActionsList, {
        [_eQN]: `ActionsSet`,
        [_xN]: _aSct
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [0, {
        [_eQN]: `OutpostArn`,
        [_xN]: _oA
      }], [() => VolumeStatusEventsList, {
        [_eQN]: `EventsSet`,
        [_xN]: _eSv
      }], [0, {
        [_eQN]: `VolumeId`,
        [_xN]: _vIo
      }], [() => exports2.VolumeStatusInfo$, {
        [_eQN]: `VolumeStatus`,
        [_xN]: _vSol
      }], [() => VolumeStatusAttachmentStatusList, {
        [_eQN]: `AttachmentStatuses`,
        [_xN]: _aStta
      }], [() => exports2.InitializationStatusDetails$, {
        [_eQN]: `InitializationStatusDetails`,
        [_xN]: _iSD
      }], [0, {
        [_eQN]: `AvailabilityZoneId`,
        [_xN]: _aZI
      }], [() => exports2.OperatorResponse$, {
        [_eQN]: `Operator`,
        [_xN]: _ope
      }]]
    ];
    exports2.Vpc$ = [
      3,
      n032,
      _Vp,
      0,
      [_OI, _ITns, _ICBAS, _CBAS, _IDs, _ECn, _T10, _BPAS, _VI, _St, _CB, _DOI],
      [[0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [0, {
        [_eQN]: `InstanceTenancy`,
        [_xN]: _iTns
      }], [() => VpcIpv6CidrBlockAssociationSet, {
        [_eQN]: `Ipv6CidrBlockAssociationSet`,
        [_xN]: _iCBASp
      }], [() => VpcCidrBlockAssociationSet, {
        [_eQN]: `CidrBlockAssociationSet`,
        [_xN]: _cBAS
      }], [2, {
        [_eQN]: `IsDefault`,
        [_xN]: _iDs
      }], [() => exports2.VpcEncryptionControl$, {
        [_eQN]: `EncryptionControl`,
        [_xN]: _eCn
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [() => exports2.BlockPublicAccessStates$, {
        [_eQN]: `BlockPublicAccessStates`,
        [_xN]: _bPAS
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `CidrBlock`,
        [_xN]: _cB
      }], [0, {
        [_eQN]: `DhcpOptionsId`,
        [_xN]: _dOI
      }]]
    ];
    exports2.VpcAttachment$ = [
      3,
      n032,
      _VA,
      0,
      [_VI, _St],
      [[0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }]]
    ];
    exports2.VpcBlockPublicAccessExclusion$ = [
      3,
      n032,
      _VBPAE,
      0,
      [_EIx, _IGEM, _RAeso, _St, _Rea, _CTrea, _LUTas, _DTele, _T10],
      [[0, {
        [_eQN]: `ExclusionId`,
        [_xN]: _eIx
      }], [0, {
        [_eQN]: `InternetGatewayExclusionMode`,
        [_xN]: _iGEM
      }], [0, {
        [_eQN]: `ResourceArn`,
        [_xN]: _rAes
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `Reason`,
        [_xN]: _rea
      }], [4, {
        [_eQN]: `CreationTimestamp`,
        [_xN]: _cTrea
      }], [4, {
        [_eQN]: `LastUpdateTimestamp`,
        [_xN]: _lUTas
      }], [4, {
        [_eQN]: `DeletionTimestamp`,
        [_xN]: _dTele
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.VpcBlockPublicAccessOptions$ = [
      3,
      n032,
      _VBPAO,
      0,
      [_AAI, _ARw, _St, _IGBM, _Rea, _LUTas, _MB, _EAx],
      [[0, {
        [_eQN]: `AwsAccountId`,
        [_xN]: _aAI
      }], [0, {
        [_eQN]: `AwsRegion`,
        [_xN]: _aRw
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `InternetGatewayBlockMode`,
        [_xN]: _iGBM
      }], [0, {
        [_eQN]: `Reason`,
        [_xN]: _rea
      }], [4, {
        [_eQN]: `LastUpdateTimestamp`,
        [_xN]: _lUTas
      }], [0, {
        [_eQN]: `ManagedBy`,
        [_xN]: _mB
      }], [0, {
        [_eQN]: `ExclusionsAllowed`,
        [_xN]: _eAx
      }]]
    ];
    exports2.VpcCidrBlockAssociation$ = [
      3,
      n032,
      _VCBA,
      0,
      [_AIs, _CB, _CBSi],
      [[0, {
        [_eQN]: `AssociationId`,
        [_xN]: _aIs
      }], [0, {
        [_eQN]: `CidrBlock`,
        [_xN]: _cB
      }], [() => exports2.VpcCidrBlockState$, {
        [_eQN]: `CidrBlockState`,
        [_xN]: _cBSi
      }]]
    ];
    exports2.VpcCidrBlockState$ = [
      3,
      n032,
      _VCBS,
      0,
      [_St, _SMt],
      [[0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `StatusMessage`,
        [_xN]: _sMt
      }]]
    ];
    exports2.VpcClassicLink$ = [
      3,
      n032,
      _VCL,
      0,
      [_CLE, _T10, _VI],
      [[2, {
        [_eQN]: `ClassicLinkEnabled`,
        [_xN]: _cLE
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }]]
    ];
    exports2.VpcEncryptionControl$ = [
      3,
      n032,
      _VEC,
      0,
      [_VI, _VECI, _Mo, _St, _SMta, _REes, _T10],
      [[0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [0, {
        [_eQN]: `VpcEncryptionControlId`,
        [_xN]: _vECI
      }], [0, {
        [_eQN]: `Mode`,
        [_xN]: _mod
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `StateMessage`,
        [_xN]: _sMta
      }], [() => exports2.VpcEncryptionControlExclusions$, {
        [_eQN]: `ResourceExclusions`,
        [_xN]: _rEes
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.VpcEncryptionControlConfiguration$ = [
      3,
      n032,
      _VECC,
      0,
      [_Mo, _IGE4, _EOIGE, _NGE, _VPGE, _VPE, _LEam, _VLE, _EFSE],
      [0, 0, 0, 0, 0, 0, 0, 0, 0],
      1
    ];
    exports2.VpcEncryptionControlExclusion$ = [
      3,
      n032,
      _VECE,
      0,
      [_St, _SMta],
      [[0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `StateMessage`,
        [_xN]: _sMta
      }]]
    ];
    exports2.VpcEncryptionControlExclusions$ = [
      3,
      n032,
      _VECEp,
      0,
      [_IG, _EOIG, _NG, _VPG, _VPpc, _Lam, _VL, _EFS],
      [[() => exports2.VpcEncryptionControlExclusion$, {
        [_eQN]: `InternetGateway`,
        [_xN]: _iG
      }], [() => exports2.VpcEncryptionControlExclusion$, {
        [_eQN]: `EgressOnlyInternetGateway`,
        [_xN]: _eOIG
      }], [() => exports2.VpcEncryptionControlExclusion$, {
        [_eQN]: `NatGateway`,
        [_xN]: _nG
      }], [() => exports2.VpcEncryptionControlExclusion$, {
        [_eQN]: `VirtualPrivateGateway`,
        [_xN]: _vPG
      }], [() => exports2.VpcEncryptionControlExclusion$, {
        [_eQN]: `VpcPeering`,
        [_xN]: _vPpc
      }], [() => exports2.VpcEncryptionControlExclusion$, {
        [_eQN]: `Lambda`,
        [_xN]: _la
      }], [() => exports2.VpcEncryptionControlExclusion$, {
        [_eQN]: `VpcLattice`,
        [_xN]: _vL
      }], [() => exports2.VpcEncryptionControlExclusion$, {
        [_eQN]: `ElasticFileSystem`,
        [_xN]: _eFS
      }]]
    ];
    exports2.VpcEncryptionNonCompliantResource$ = [
      3,
      n032,
      _VENCR,
      0,
      [_I, _Ty, _De, _IEs],
      [[0, {
        [_eQN]: `Id`,
        [_xN]: _i
      }], [0, {
        [_eQN]: `Type`,
        [_xN]: _ty
      }], [0, {
        [_eQN]: `Description`,
        [_xN]: _de
      }], [2, {
        [_eQN]: `IsExcludable`,
        [_xN]: _iEsx
      }]]
    ];
    exports2.VpcEndpoint$ = [
      3,
      n032,
      _VE10,
      0,
      [_VEIp, _VET, _VI, _SN10, _St, _PDo, _RTIo, _SI10, _G, _IAT, _DOn, _PDE, _RMeq, _NIIe, _DEn, _CTrea, _T10, _OI, _LEa, _IPpvr, _IPp, _FR, _SNA, _RCA, _SR],
      [[0, {
        [_eQN]: `VpcEndpointId`,
        [_xN]: _vEI
      }], [0, {
        [_eQN]: `VpcEndpointType`,
        [_xN]: _vET
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [0, {
        [_eQN]: `ServiceName`,
        [_xN]: _sN
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `PolicyDocument`,
        [_xN]: _pDo
      }], [() => ValueStringList, {
        [_eQN]: `RouteTableIdSet`,
        [_xN]: _rTIS
      }], [() => ValueStringList, {
        [_eQN]: `SubnetIdSet`,
        [_xN]: _sISu
      }], [() => GroupIdentifierSet, {
        [_eQN]: `GroupSet`,
        [_xN]: _gSr
      }], [0, {
        [_eQN]: `IpAddressType`,
        [_xN]: _iAT
      }], [() => exports2.DnsOptions$, {
        [_eQN]: `DnsOptions`,
        [_xN]: _dOn
      }], [2, {
        [_eQN]: `PrivateDnsEnabled`,
        [_xN]: _pDE
      }], [2, {
        [_eQN]: `RequesterManaged`,
        [_xN]: _rMeq
      }], [() => ValueStringList, {
        [_eQN]: `NetworkInterfaceIdSet`,
        [_xN]: _nIIS
      }], [() => DnsEntrySet, {
        [_eQN]: `DnsEntrySet`,
        [_xN]: _dES
      }], [4, {
        [_eQN]: `CreationTimestamp`,
        [_xN]: _cTrea
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [() => exports2.LastError$, {
        [_eQN]: `LastError`,
        [_xN]: _lEa
      }], [() => SubnetIpPrefixesList, {
        [_eQN]: `Ipv4PrefixSet`,
        [_xN]: _iPSpvr
      }], [() => SubnetIpPrefixesList, {
        [_eQN]: `Ipv6PrefixSet`,
        [_xN]: _iPSpvre
      }], [0, {
        [_eQN]: `FailureReason`,
        [_xN]: _fR
      }], [0, {
        [_eQN]: `ServiceNetworkArn`,
        [_xN]: _sNAe
      }], [0, {
        [_eQN]: `ResourceConfigurationArn`,
        [_xN]: _rCA
      }], [0, {
        [_eQN]: `ServiceRegion`,
        [_xN]: _sR
      }]]
    ];
    exports2.VpcEndpointAssociation$ = [
      3,
      n032,
      _VEAp,
      0,
      [_I, _VEIp, _SNA, _SNN, _ARAs, _FR, _FCa, _DE, _PDEr, _ARAss, _RCGA, _T10],
      [[0, {
        [_eQN]: `Id`,
        [_xN]: _i
      }], [0, {
        [_eQN]: `VpcEndpointId`,
        [_xN]: _vEI
      }], [0, {
        [_eQN]: `ServiceNetworkArn`,
        [_xN]: _sNAe
      }], [0, {
        [_eQN]: `ServiceNetworkName`,
        [_xN]: _sNN
      }], [0, {
        [_eQN]: `AssociatedResourceAccessibility`,
        [_xN]: _aRAs
      }], [0, {
        [_eQN]: `FailureReason`,
        [_xN]: _fR
      }], [0, {
        [_eQN]: `FailureCode`,
        [_xN]: _fCa
      }], [() => exports2.DnsEntry$, {
        [_eQN]: `DnsEntry`,
        [_xN]: _dE
      }], [() => exports2.DnsEntry$, {
        [_eQN]: `PrivateDnsEntry`,
        [_xN]: _pDEr
      }], [0, {
        [_eQN]: `AssociatedResourceArn`,
        [_xN]: _aRAss
      }], [0, {
        [_eQN]: `ResourceConfigurationGroupArn`,
        [_xN]: _rCGA
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.VpcEndpointConnection$ = [
      3,
      n032,
      _VECpcn,
      0,
      [_SIe, _VEIp, _VEO, _VESpc, _CTrea, _DEn, _NLBAe, _GLBA, _IAT, _VECIpc, _T10, _VER],
      [[0, {
        [_eQN]: `ServiceId`,
        [_xN]: _sI
      }], [0, {
        [_eQN]: `VpcEndpointId`,
        [_xN]: _vEI
      }], [0, {
        [_eQN]: `VpcEndpointOwner`,
        [_xN]: _vEO
      }], [0, {
        [_eQN]: `VpcEndpointState`,
        [_xN]: _vESpc
      }], [4, {
        [_eQN]: `CreationTimestamp`,
        [_xN]: _cTrea
      }], [() => DnsEntrySet, {
        [_eQN]: `DnsEntrySet`,
        [_xN]: _dES
      }], [() => ValueStringList, {
        [_eQN]: `NetworkLoadBalancerArnSet`,
        [_xN]: _nLBAS
      }], [() => ValueStringList, {
        [_eQN]: `GatewayLoadBalancerArnSet`,
        [_xN]: _gLBAS
      }], [0, {
        [_eQN]: `IpAddressType`,
        [_xN]: _iAT
      }], [0, {
        [_eQN]: `VpcEndpointConnectionId`,
        [_xN]: _vECIp
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `VpcEndpointRegion`,
        [_xN]: _vER
      }]]
    ];
    exports2.VpcIpv6CidrBlockAssociation$ = [
      3,
      n032,
      _VICBA,
      0,
      [_AIs, _ICB, _ICBS, _NBG, _IPpvo, _IAA, _ISpo],
      [[0, {
        [_eQN]: `AssociationId`,
        [_xN]: _aIs
      }], [0, {
        [_eQN]: `Ipv6CidrBlock`,
        [_xN]: _iCB
      }], [() => exports2.VpcCidrBlockState$, {
        [_eQN]: `Ipv6CidrBlockState`,
        [_xN]: _iCBS
      }], [0, {
        [_eQN]: `NetworkBorderGroup`,
        [_xN]: _nBG
      }], [0, {
        [_eQN]: `Ipv6Pool`,
        [_xN]: _iPpvo
      }], [0, {
        [_eQN]: `Ipv6AddressAttribute`,
        [_xN]: _iAA
      }], [0, {
        [_eQN]: `IpSource`,
        [_xN]: _iSpo
      }]]
    ];
    exports2.VpcPeeringConnection$ = [
      3,
      n032,
      _VPC,
      0,
      [_AVI, _ET, _RVIe, _Sta, _T10, _VPCI],
      [[() => exports2.VpcPeeringConnectionVpcInfo$, {
        [_eQN]: `AccepterVpcInfo`,
        [_xN]: _aVI
      }], [4, {
        [_eQN]: `ExpirationTime`,
        [_xN]: _eT
      }], [() => exports2.VpcPeeringConnectionVpcInfo$, {
        [_eQN]: `RequesterVpcInfo`,
        [_xN]: _rVIe
      }], [() => exports2.VpcPeeringConnectionStateReason$, {
        [_eQN]: `Status`,
        [_xN]: _sta
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `VpcPeeringConnectionId`,
        [_xN]: _vPCI
      }]]
    ];
    exports2.VpcPeeringConnectionOptionsDescription$ = [
      3,
      n032,
      _VPCOD,
      0,
      [_ADRFRV, _AEFLCLTRV, _AEFLVTRCL],
      [[2, {
        [_eQN]: `AllowDnsResolutionFromRemoteVpc`,
        [_xN]: _aDRFRV
      }], [2, {
        [_eQN]: `AllowEgressFromLocalClassicLinkToRemoteVpc`,
        [_xN]: _aEFLCLTRV
      }], [2, {
        [_eQN]: `AllowEgressFromLocalVpcToRemoteClassicLink`,
        [_xN]: _aEFLVTRCL
      }]]
    ];
    exports2.VpcPeeringConnectionStateReason$ = [
      3,
      n032,
      _VPCSR,
      0,
      [_Co, _Me],
      [[0, {
        [_eQN]: `Code`,
        [_xN]: _co13
      }], [0, {
        [_eQN]: `Message`,
        [_xN]: _me
      }]]
    ];
    exports2.VpcPeeringConnectionVpcInfo$ = [
      3,
      n032,
      _VPCVI,
      0,
      [_CB, _ICBSp, _CBSid, _OI, _POe, _VI, _Regi],
      [[0, {
        [_eQN]: `CidrBlock`,
        [_xN]: _cB
      }], [() => Ipv6CidrBlockSet, {
        [_eQN]: `Ipv6CidrBlockSet`,
        [_xN]: _iCBSp
      }], [() => CidrBlockSet, {
        [_eQN]: `CidrBlockSet`,
        [_xN]: _cBSid
      }], [0, {
        [_eQN]: `OwnerId`,
        [_xN]: _oI
      }], [() => exports2.VpcPeeringConnectionOptionsDescription$, {
        [_eQN]: `PeeringOptions`,
        [_xN]: _pOe
      }], [0, {
        [_eQN]: `VpcId`,
        [_xN]: _vI
      }], [0, {
        [_eQN]: `Region`,
        [_xN]: _reg
      }]]
    ];
    exports2.VpnConcentrator$ = [
      3,
      n032,
      _VC,
      0,
      [_VCI, _St, _TGI, _TGAI, _Ty, _T10],
      [[0, {
        [_eQN]: `VpnConcentratorId`,
        [_xN]: _vCIpn
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `TransitGatewayId`,
        [_xN]: _tGI
      }], [0, {
        [_eQN]: `TransitGatewayAttachmentId`,
        [_xN]: _tGAI
      }], [0, {
        [_eQN]: `Type`,
        [_xN]: _ty
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }]]
    ];
    exports2.VpnConnection$ = [
      3,
      n032,
      _VCp,
      0,
      [_Cat, _TGI, _VCI, _CNA, _CNAA, _GAS, _Opt, _Rou, _T10, _VTg, _PSKA, _VCIp, _St, _CGC, _Ty, _CGIu, _VGI],
      [[0, {
        [_eQN]: `Category`,
        [_xN]: _ca
      }], [0, {
        [_eQN]: `TransitGatewayId`,
        [_xN]: _tGI
      }], [0, {
        [_eQN]: `VpnConcentratorId`,
        [_xN]: _vCIpn
      }], [0, {
        [_eQN]: `CoreNetworkArn`,
        [_xN]: _cNA
      }], [0, {
        [_eQN]: `CoreNetworkAttachmentArn`,
        [_xN]: _cNAA
      }], [0, {
        [_eQN]: `GatewayAssociationState`,
        [_xN]: _gAS
      }], [() => exports2.VpnConnectionOptions$, {
        [_eQN]: `Options`,
        [_xN]: _op
      }], [() => VpnStaticRouteList, {
        [_eQN]: `Routes`,
        [_xN]: _rou
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [() => VgwTelemetryList, {
        [_eQN]: `VgwTelemetry`,
        [_xN]: _vTg
      }], [0, {
        [_eQN]: `PreSharedKeyArn`,
        [_xN]: _pSKA
      }], [0, {
        [_eQN]: `VpnConnectionId`,
        [_xN]: _vCI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [() => customerGatewayConfiguration, {
        [_eQN]: `CustomerGatewayConfiguration`,
        [_xN]: _cGC
      }], [0, {
        [_eQN]: `Type`,
        [_xN]: _ty
      }], [0, {
        [_eQN]: `CustomerGatewayId`,
        [_xN]: _cGIu
      }], [0, {
        [_eQN]: `VpnGatewayId`,
        [_xN]: _vGI
      }]]
    ];
    exports2.VpnConnectionDeviceType$ = [
      3,
      n032,
      _VCDTp,
      0,
      [_VCDTI, _Ven, _Pl, _Sof],
      [[0, {
        [_eQN]: `VpnConnectionDeviceTypeId`,
        [_xN]: _vCDTI
      }], [0, {
        [_eQN]: `Vendor`,
        [_xN]: _ven
      }], [0, {
        [_eQN]: `Platform`,
        [_xN]: _pl
      }], [0, {
        [_eQN]: `Software`,
        [_xN]: _sof
      }]]
    ];
    exports2.VpnConnectionOptions$ = [
      3,
      n032,
      _VCO,
      0,
      [_EAn, _SRO, _LINC, _RINC, _LINCo, _RINCe, _OIAT, _TTGAI, _TIIV, _TO, _TB],
      [[2, {
        [_eQN]: `EnableAcceleration`,
        [_xN]: _eAn
      }], [2, {
        [_eQN]: `StaticRoutesOnly`,
        [_xN]: _sRO
      }], [0, {
        [_eQN]: `LocalIpv4NetworkCidr`,
        [_xN]: _lINC
      }], [0, {
        [_eQN]: `RemoteIpv4NetworkCidr`,
        [_xN]: _rINC
      }], [0, {
        [_eQN]: `LocalIpv6NetworkCidr`,
        [_xN]: _lINCo
      }], [0, {
        [_eQN]: `RemoteIpv6NetworkCidr`,
        [_xN]: _rINCe
      }], [0, {
        [_eQN]: `OutsideIpAddressType`,
        [_xN]: _oIAT
      }], [0, {
        [_eQN]: `TransportTransitGatewayAttachmentId`,
        [_xN]: _tTGAI
      }], [0, {
        [_eQN]: `TunnelInsideIpVersion`,
        [_xN]: _tIIV
      }], [() => TunnelOptionsList, {
        [_eQN]: `TunnelOptionSet`,
        [_xN]: _tOS
      }], [0, {
        [_eQN]: `TunnelBandwidth`,
        [_xN]: _tB
      }]]
    ];
    exports2.VpnConnectionOptionsSpecification$ = [
      3,
      n032,
      _VCOS,
      0,
      [_EAn, _TIIV, _TO, _LINC, _RINC, _LINCo, _RINCe, _OIAT, _TTGAI, _TB, _SRO],
      [2, 0, [() => VpnTunnelOptionsSpecificationsList, 0], 0, 0, 0, 0, 0, 0, 0, [2, {
        [_eQN]: `StaticRoutesOnly`,
        [_xN]: _sRO
      }]]
    ];
    exports2.VpnGateway$ = [
      3,
      n032,
      _VG,
      0,
      [_ASA, _T10, _VGI, _St, _Ty, _AZ, _VAp],
      [[1, {
        [_eQN]: `AmazonSideAsn`,
        [_xN]: _aSA
      }], [() => TagList, {
        [_eQN]: `TagSet`,
        [_xN]: _tS
      }], [0, {
        [_eQN]: `VpnGatewayId`,
        [_xN]: _vGI
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }], [0, {
        [_eQN]: `Type`,
        [_xN]: _ty
      }], [0, {
        [_eQN]: `AvailabilityZone`,
        [_xN]: _aZ
      }], [() => VpcAttachmentList, {
        [_eQN]: `Attachments`,
        [_xN]: _atta
      }]]
    ];
    exports2.VpnStaticRoute$ = [
      3,
      n032,
      _VSR,
      0,
      [_DCB, _S, _St],
      [[0, {
        [_eQN]: `DestinationCidrBlock`,
        [_xN]: _dCB
      }], [0, {
        [_eQN]: `Source`,
        [_xN]: _so
      }], [0, {
        [_eQN]: `State`,
        [_xN]: _st
      }]]
    ];
    exports2.VpnTunnelLogOptions$ = [
      3,
      n032,
      _VTLO,
      0,
      [_CWLO],
      [[() => exports2.CloudWatchLogOptions$, {
        [_eQN]: `CloudWatchLogOptions`,
        [_xN]: _cWLO
      }]]
    ];
    exports2.VpnTunnelLogOptionsSpecification$ = [
      3,
      n032,
      _VTLOS,
      0,
      [_CWLO],
      [() => exports2.CloudWatchLogOptionsSpecification$]
    ];
    exports2.VpnTunnelOptionsSpecification$ = [
      3,
      n032,
      _VTOS,
      0,
      [_TICu, _TIIC, _PSK, _PLS, _PLSh, _RMTS, _RFP, _RWS, _DPDTS, _DPDTA, _PEAha, _PEAhas, _PIAha, _PIAhas, _PDHGN, _PDHGNh, _IKEVe, _SAt, _LO, _ETLC],
      [0, 0, [() => preSharedKey, 0], 1, 1, 1, 1, 1, 1, 0, [() => Phase1EncryptionAlgorithmsRequestList, { [_xN]: _PEA }], [() => Phase2EncryptionAlgorithmsRequestList, { [_xN]: _PEAh }], [() => Phase1IntegrityAlgorithmsRequestList, { [_xN]: _PIA }], [() => Phase2IntegrityAlgorithmsRequestList, { [_xN]: _PIAh }], [() => Phase1DHGroupNumbersRequestList, { [_xN]: _PDHGNha }], [() => Phase2DHGroupNumbersRequestList, { [_xN]: _PDHGNhas }], [() => IKEVersionsRequestList, { [_xN]: _IKEVer }], 0, () => exports2.VpnTunnelLogOptionsSpecification$, 2]
    ];
    exports2.WithdrawByoipCidrRequest$ = [
      3,
      n032,
      _WBCR,
      0,
      [_Ci, _DR],
      [0, 2],
      1
    ];
    exports2.WithdrawByoipCidrResult$ = [
      3,
      n032,
      _WBCRi,
      0,
      [_BC],
      [[() => exports2.ByoipCidr$, {
        [_eQN]: `ByoipCidr`,
        [_xN]: _bC
      }]]
    ];
    var __Unit = "unit";
    var AcceleratorManufacturerSet = [
      1,
      n032,
      _AMSc,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var AcceleratorNameSet = [
      1,
      n032,
      _ANSc,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var AcceleratorTypeSet = [
      1,
      n032,
      _ATSc,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var AccessScopeAnalysisFindingList = [
      1,
      n032,
      _ASAFL,
      0,
      [
        () => exports2.AccessScopeAnalysisFinding$,
        { [_xN]: _it }
      ]
    ];
    var AccessScopePathList = [
      1,
      n032,
      _ASPL,
      0,
      [
        () => exports2.AccessScopePath$,
        { [_xN]: _it }
      ]
    ];
    var AccessScopePathListRequest = [
      1,
      n032,
      _ASPLR,
      0,
      [
        () => exports2.AccessScopePathRequest$,
        { [_xN]: _it }
      ]
    ];
    var AccountAttributeList = [
      1,
      n032,
      _AAL,
      0,
      [
        () => exports2.AccountAttribute$,
        { [_xN]: _it }
      ]
    ];
    var AccountAttributeNameStringList = [
      1,
      n032,
      _AANSL,
      0,
      [
        0,
        { [_xN]: _aN }
      ]
    ];
    var AccountAttributeValueList = [
      1,
      n032,
      _AAVL,
      0,
      [
        () => exports2.AccountAttributeValue$,
        { [_xN]: _it }
      ]
    ];
    var ActiveInstanceSet = [
      1,
      n032,
      _AIS,
      0,
      [
        () => exports2.ActiveInstance$,
        { [_xN]: _it }
      ]
    ];
    var AddedPrincipalSet = [
      1,
      n032,
      _APS,
      0,
      [
        () => exports2.AddedPrincipal$,
        { [_xN]: _it }
      ]
    ];
    var AddIpamOperatingRegionSet = [
      1,
      n032,
      _AIORS,
      0,
      () => exports2.AddIpamOperatingRegion$
    ];
    var AddIpamOrganizationalUnitExclusionSet = [
      1,
      n032,
      _AIOUES,
      0,
      () => exports2.AddIpamOrganizationalUnitExclusion$
    ];
    var AdditionalDetailList = [
      1,
      n032,
      _ADL,
      0,
      [
        () => exports2.AdditionalDetail$,
        { [_xN]: _it }
      ]
    ];
    var AddPrefixListEntries = [
      1,
      n032,
      _APLEd,
      0,
      () => exports2.AddPrefixListEntry$
    ];
    var AddressList = [
      1,
      n032,
      _ALd,
      0,
      [
        () => exports2.Address$,
        { [_xN]: _it }
      ]
    ];
    var AddressSet = [
      1,
      n032,
      _ASd,
      0,
      [
        () => exports2.AddressAttribute$,
        { [_xN]: _it }
      ]
    ];
    var AddressTransferList = [
      1,
      n032,
      _ATL,
      0,
      [
        () => exports2.AddressTransfer$,
        { [_xN]: _it }
      ]
    ];
    var AllocationIdList = [
      1,
      n032,
      _AIL,
      0,
      [
        0,
        { [_xN]: _AIl }
      ]
    ];
    var AllocationIds = [
      1,
      n032,
      _AIll,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var AllowedInstanceTypeSet = [
      1,
      n032,
      _AITS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var AllowedPrincipalSet = [
      1,
      n032,
      _APSl,
      0,
      [
        () => exports2.AllowedPrincipal$,
        { [_xN]: _it }
      ]
    ];
    var AlternatePathHintList = [
      1,
      n032,
      _APHL,
      0,
      [
        () => exports2.AlternatePathHint$,
        { [_xN]: _it }
      ]
    ];
    var AnalysisComponentList = [
      1,
      n032,
      _ACL,
      0,
      [
        () => exports2.AnalysisComponent$,
        { [_xN]: _it }
      ]
    ];
    var ArchitectureTypeList = [
      1,
      n032,
      _ATLr,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var ArchitectureTypeSet = [
      1,
      n032,
      _ATSr,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var ArnList = [
      1,
      n032,
      _ALr,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var AsnAssociationSet = [
      1,
      n032,
      _AAS,
      0,
      [
        () => exports2.AsnAssociation$,
        { [_xN]: _it }
      ]
    ];
    var AsPath = [
      1,
      n032,
      _APsa,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var AssetIdList = 64 | 0;
    var AssignedPrivateIpAddressList = [
      1,
      n032,
      _APIAL,
      0,
      [
        () => exports2.AssignedPrivateIpAddress$,
        { [_xN]: _it }
      ]
    ];
    var AssociatedRolesList = [
      1,
      n032,
      _ARL,
      0,
      [
        () => exports2.AssociatedRole$,
        { [_xN]: _it }
      ]
    ];
    var AssociatedSubnetList = [
      1,
      n032,
      _ASL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var AssociatedTargetNetworkSet = [
      1,
      n032,
      _ATNS,
      0,
      [
        () => exports2.AssociatedTargetNetwork$,
        { [_xN]: _it }
      ]
    ];
    var AssociationIdList = [
      1,
      n032,
      _AILs,
      0,
      [
        0,
        { [_xN]: _AIs }
      ]
    ];
    var AthenaIntegrationsSet = [
      1,
      n032,
      _AISt,
      0,
      [
        () => exports2.AthenaIntegration$,
        { [_xN]: _it }
      ]
    ];
    var AttributeSummaryList = [
      1,
      n032,
      _ASLt,
      0,
      [
        () => exports2.AttributeSummary$,
        { [_xN]: _it }
      ]
    ];
    var AuthorizationRuleSet = [
      1,
      n032,
      _ARSu,
      0,
      [
        () => exports2.AuthorizationRule$,
        { [_xN]: _it }
      ]
    ];
    var AvailabilityZoneAddresses = [
      1,
      n032,
      _AZAv,
      0,
      [
        () => exports2.AvailabilityZoneAddress$,
        { [_xN]: _AZA }
      ]
    ];
    var AvailabilityZoneGeographyList = [
      1,
      n032,
      _AZGL,
      0,
      [
        () => exports2.AvailabilityZoneGeography$,
        { [_xN]: _it }
      ]
    ];
    var AvailabilityZoneIdStringList = [
      1,
      n032,
      _AZISL,
      0,
      [
        0,
        { [_xN]: _AZI }
      ]
    ];
    var AvailabilityZoneList = [
      1,
      n032,
      _AZL,
      0,
      [
        () => exports2.AvailabilityZone$,
        { [_xN]: _it }
      ]
    ];
    var AvailabilityZoneMessageList = [
      1,
      n032,
      _AZML,
      0,
      [
        () => exports2.AvailabilityZoneMessage$,
        { [_xN]: _it }
      ]
    ];
    var AvailabilityZoneStringList = [
      1,
      n032,
      _AZSL,
      0,
      [
        0,
        { [_xN]: _AZ }
      ]
    ];
    var AvailabilityZoneSubGeographyList = [
      1,
      n032,
      _AZSGL,
      0,
      [
        () => exports2.AvailabilityZoneSubGeography$,
        { [_xN]: _it }
      ]
    ];
    var AvailableInstanceCapacityList = [
      1,
      n032,
      _AICL,
      0,
      [
        () => exports2.InstanceCapacity$,
        { [_xN]: _it }
      ]
    ];
    var BandwidthWeightingTypeList = [
      1,
      n032,
      _BWTL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var BillingProductList = [
      1,
      n032,
      _BPL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var BlockDeviceMappingList = [
      1,
      n032,
      _BDML,
      0,
      [
        () => exports2.BlockDeviceMapping$,
        { [_xN]: _it }
      ]
    ];
    var BlockDeviceMappingRequestList = [
      1,
      n032,
      _BDMRL,
      0,
      [
        () => exports2.BlockDeviceMapping$,
        { [_xN]: _BDM }
      ]
    ];
    var BlockDeviceMappingResponseList = [
      1,
      n032,
      _BDMRLl,
      0,
      [
        () => exports2.BlockDeviceMappingResponse$,
        { [_xN]: _it }
      ]
    ];
    var BootModeTypeList = [
      1,
      n032,
      _BMTL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var BundleIdStringList = [
      1,
      n032,
      _BISL,
      0,
      [
        0,
        { [_xN]: _BI }
      ]
    ];
    var BundleTaskList = [
      1,
      n032,
      _BTL,
      0,
      [
        () => exports2.BundleTask$,
        { [_xN]: _it }
      ]
    ];
    var ByoasnSet = [
      1,
      n032,
      _BSy,
      0,
      [
        () => exports2.Byoasn$,
        { [_xN]: _it }
      ]
    ];
    var ByoipCidrSet = [
      1,
      n032,
      _BCS,
      0,
      [
        () => exports2.ByoipCidr$,
        { [_xN]: _it }
      ]
    ];
    var CancelledSpotInstanceRequestList = [
      1,
      n032,
      _CSIRL,
      0,
      [
        () => exports2.CancelledSpotInstanceRequest$,
        { [_xN]: _it }
      ]
    ];
    var CancelSpotFleetRequestsErrorSet = [
      1,
      n032,
      _CSFRES,
      0,
      [
        () => exports2.CancelSpotFleetRequestsErrorItem$,
        { [_xN]: _it }
      ]
    ];
    var CancelSpotFleetRequestsSuccessSet = [
      1,
      n032,
      _CSFRSS,
      0,
      [
        () => exports2.CancelSpotFleetRequestsSuccessItem$,
        { [_xN]: _it }
      ]
    ];
    var CapacityAllocationMetadataList = [
      1,
      n032,
      _CAML,
      0,
      [
        () => exports2.CapacityAllocationMetadataEntry$,
        { [_xN]: _it }
      ]
    ];
    var CapacityAllocations = [
      1,
      n032,
      _CAap,
      0,
      [
        () => exports2.CapacityAllocation$,
        { [_xN]: _it }
      ]
    ];
    var CapacityBlockExtensionOfferingSet = [
      1,
      n032,
      _CBEOS,
      0,
      [
        () => exports2.CapacityBlockExtensionOffering$,
        { [_xN]: _it }
      ]
    ];
    var CapacityBlockExtensionSet = [
      1,
      n032,
      _CBESa,
      0,
      [
        () => exports2.CapacityBlockExtension$,
        { [_xN]: _it }
      ]
    ];
    var CapacityBlockIds = [
      1,
      n032,
      _CBIa,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var CapacityBlockOfferingSet = [
      1,
      n032,
      _CBOS,
      0,
      [
        () => exports2.CapacityBlockOffering$,
        { [_xN]: _it }
      ]
    ];
    var CapacityBlockSet = [
      1,
      n032,
      _CBSap,
      0,
      [
        () => exports2.CapacityBlock$,
        { [_xN]: _it }
      ]
    ];
    var CapacityBlockStatusSet = [
      1,
      n032,
      _CBSS,
      0,
      [
        () => exports2.CapacityBlockStatus$,
        { [_xN]: _it }
      ]
    ];
    var CapacityManagerConditionSet = [
      1,
      n032,
      _CMCS,
      0,
      [
        () => exports2.CapacityManagerCondition$,
        { [_xN]: _it }
      ]
    ];
    var CapacityManagerDataExportIdSet = [
      1,
      n032,
      _CMDEIS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var CapacityManagerDataExportResponseSet = [
      1,
      n032,
      _CMDERS,
      0,
      [
        () => exports2.CapacityManagerDataExportResponse$,
        { [_xN]: _it }
      ]
    ];
    var CapacityManagerMonitoredTagKeyList = [
      1,
      n032,
      _CMMTKL,
      0,
      [
        () => exports2.CapacityManagerMonitoredTagKey$,
        { [_xN]: _it }
      ]
    ];
    var CapacityManagerTagDimensionSet = [
      1,
      n032,
      _CMTDS,
      0,
      [
        () => exports2.CapacityManagerTagDimension$,
        { [_xN]: _it }
      ]
    ];
    var CapacityReservationBillingRequestSet = [
      1,
      n032,
      _CRBRS,
      0,
      [
        () => exports2.CapacityReservationBillingRequest$,
        { [_xN]: _it }
      ]
    ];
    var CapacityReservationFleetCancellationStateSet = [
      1,
      n032,
      _CRFCSS,
      0,
      [
        () => exports2.CapacityReservationFleetCancellationState$,
        { [_xN]: _it }
      ]
    ];
    var CapacityReservationFleetIdSet = [
      1,
      n032,
      _CRFIS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var CapacityReservationFleetSet = [
      1,
      n032,
      _CRFS,
      0,
      [
        () => exports2.CapacityReservationFleet$,
        { [_xN]: _it }
      ]
    ];
    var CapacityReservationGroupSet = [
      1,
      n032,
      _CRGS,
      0,
      [
        () => exports2.CapacityReservationGroup$,
        { [_xN]: _it }
      ]
    ];
    var CapacityReservationIdSet = [
      1,
      n032,
      _CRIS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var CapacityReservationSet = [
      1,
      n032,
      _CRSapa,
      0,
      [
        () => exports2.CapacityReservation$,
        { [_xN]: _it }
      ]
    ];
    var CapacityReservationStatusSet = [
      1,
      n032,
      _CRSS,
      0,
      [
        () => exports2.CapacityReservationStatus$,
        { [_xN]: _it }
      ]
    ];
    var CapacityReservationTopologySet = [
      1,
      n032,
      _CRTS,
      0,
      [
        () => exports2.CapacityReservationTopology$,
        { [_xN]: _it }
      ]
    ];
    var CarrierGatewayIdSet = 64 | 0;
    var CarrierGatewaySet = [
      1,
      n032,
      _CGS,
      0,
      [
        () => exports2.CarrierGateway$,
        { [_xN]: _it }
      ]
    ];
    var CidrBlockSet = [
      1,
      n032,
      _CBSid,
      0,
      [
        () => exports2.CidrBlock$,
        { [_xN]: _it }
      ]
    ];
    var ClassicLinkDnsSupportList = [
      1,
      n032,
      _CLDSL,
      0,
      [
        () => exports2.ClassicLinkDnsSupport$,
        { [_xN]: _it }
      ]
    ];
    var ClassicLinkInstanceList = [
      1,
      n032,
      _CLIL,
      0,
      [
        () => exports2.ClassicLinkInstance$,
        { [_xN]: _it }
      ]
    ];
    var ClassicLoadBalancers = [
      1,
      n032,
      _CLBl,
      0,
      [
        () => exports2.ClassicLoadBalancer$,
        { [_xN]: _it }
      ]
    ];
    var ClientVpnAuthenticationList = [
      1,
      n032,
      _CVAL,
      0,
      [
        () => exports2.ClientVpnAuthentication$,
        { [_xN]: _it }
      ]
    ];
    var ClientVpnAuthenticationRequestList = [
      1,
      n032,
      _CVARL,
      0,
      () => exports2.ClientVpnAuthenticationRequest$
    ];
    var ClientVpnAvailabilityZoneIdSet = [
      1,
      n032,
      _CVAZIS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var ClientVpnAvailabilityZoneSet = [
      1,
      n032,
      _CVAZS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var ClientVpnConnectionSet = [
      1,
      n032,
      _CVCSl,
      0,
      [
        () => exports2.ClientVpnConnection$,
        { [_xN]: _it }
      ]
    ];
    var ClientVpnEndpointIdList = [
      1,
      n032,
      _CVEIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var ClientVpnRouteSet = [
      1,
      n032,
      _CVRSl,
      0,
      [
        () => exports2.ClientVpnRoute$,
        { [_xN]: _it }
      ]
    ];
    var ClientVpnSecurityGroupIdSet = [
      1,
      n032,
      _CVSGIS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var CoipAddressUsageSet = [
      1,
      n032,
      _CAUS,
      0,
      [
        () => exports2.CoipAddressUsage$,
        { [_xN]: _it }
      ]
    ];
    var CoipPoolIdSet = [
      1,
      n032,
      _CPIS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var CoipPoolSet = [
      1,
      n032,
      _CPS,
      0,
      [
        () => exports2.CoipPool$,
        { [_xN]: _it }
      ]
    ];
    var ConditionValueList = [
      1,
      n032,
      _CVL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var ConnectionNotificationIdsList = [
      1,
      n032,
      _CNIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var ConnectionNotificationSet = [
      1,
      n032,
      _CNSo,
      0,
      [
        () => exports2.ConnectionNotification$,
        { [_xN]: _it }
      ]
    ];
    var ConversionIdStringList = [
      1,
      n032,
      _CISL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var CoreCountList = [
      1,
      n032,
      _CCL,
      0,
      [
        1,
        { [_xN]: _it }
      ]
    ];
    var CpuManufacturerSet = [
      1,
      n032,
      _CMSp,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var CreateFleetErrorsSet = [
      1,
      n032,
      _CFES,
      0,
      [
        () => exports2.CreateFleetError$,
        { [_xN]: _it }
      ]
    ];
    var CreateFleetInstancesSet = [
      1,
      n032,
      _CFIS,
      0,
      [
        () => exports2.CreateFleetInstance$,
        { [_xN]: _it }
      ]
    ];
    var CreateVerifiedAccessEndpointPortRangeList = [
      1,
      n032,
      _CVAEPRL,
      0,
      [
        () => exports2.CreateVerifiedAccessEndpointPortRange$,
        { [_xN]: _it }
      ]
    ];
    var CreateVerifiedAccessEndpointSubnetIdList = [
      1,
      n032,
      _CVAESIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var CreateVolumePermissionList = [
      1,
      n032,
      _CVPL,
      0,
      [
        () => exports2.CreateVolumePermission$,
        { [_xN]: _it }
      ]
    ];
    var CustomerGatewayIdStringList = [
      1,
      n032,
      _CGISL,
      0,
      [
        0,
        { [_xN]: _CGIu }
      ]
    ];
    var CustomerGatewayList = [
      1,
      n032,
      _CGL,
      0,
      [
        () => exports2.CustomerGateway$,
        { [_xN]: _it }
      ]
    ];
    var DataQueries = [
      1,
      n032,
      _DQa,
      0,
      () => exports2.DataQuery$
    ];
    var DataResponses = [
      1,
      n032,
      _DRat,
      0,
      [
        () => exports2.DataResponse$,
        { [_xN]: _it }
      ]
    ];
    var DeclarativePoliciesReportList = [
      1,
      n032,
      _DPRL,
      0,
      [
        () => exports2.DeclarativePoliciesReport$,
        { [_xN]: _it }
      ]
    ];
    var DedicatedHostIdList = [
      1,
      n032,
      _DHIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var DeleteFleetErrorSet = [
      1,
      n032,
      _DFES,
      0,
      [
        () => exports2.DeleteFleetErrorItem$,
        { [_xN]: _it }
      ]
    ];
    var DeleteFleetSuccessSet = [
      1,
      n032,
      _DFSS,
      0,
      [
        () => exports2.DeleteFleetSuccessItem$,
        { [_xN]: _it }
      ]
    ];
    var DeleteLaunchTemplateVersionsResponseErrorSet = [
      1,
      n032,
      _DLTVRES,
      0,
      [
        () => exports2.DeleteLaunchTemplateVersionsResponseErrorItem$,
        { [_xN]: _it }
      ]
    ];
    var DeleteLaunchTemplateVersionsResponseSuccessSet = [
      1,
      n032,
      _DLTVRSS,
      0,
      [
        () => exports2.DeleteLaunchTemplateVersionsResponseSuccessItem$,
        { [_xN]: _it }
      ]
    ];
    var DeleteQueuedReservedInstancesIdList = [
      1,
      n032,
      _DQRIIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var DeleteSnapshotResultSet = [
      1,
      n032,
      _DSRS,
      0,
      [
        () => exports2.DeleteSnapshotReturnCode$,
        { [_xN]: _it }
      ]
    ];
    var DeprovisionedAddressSet = [
      1,
      n032,
      _DASe,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var DescribeConversionTaskList = [
      1,
      n032,
      _DCTL,
      0,
      [
        () => exports2.ConversionTask$,
        { [_xN]: _it }
      ]
    ];
    var DescribeFastLaunchImagesSuccessSet = [
      1,
      n032,
      _DFLISS,
      0,
      [
        () => exports2.DescribeFastLaunchImagesSuccessItem$,
        { [_xN]: _it }
      ]
    ];
    var DescribeFastSnapshotRestoreSuccessSet = [
      1,
      n032,
      _DFSRSS,
      0,
      [
        () => exports2.DescribeFastSnapshotRestoreSuccessItem$,
        { [_xN]: _it }
      ]
    ];
    var DescribeFleetsErrorSet = [
      1,
      n032,
      _DFESe,
      0,
      [
        () => exports2.DescribeFleetError$,
        { [_xN]: _it }
      ]
    ];
    var DescribeFleetsInstancesSet = [
      1,
      n032,
      _DFIS,
      0,
      [
        () => exports2.DescribeFleetsInstances$,
        { [_xN]: _it }
      ]
    ];
    var DescribeImageReferencesImageIdStringList = 64 | 0;
    var DescribeImageUsageReportsImageIdStringList = 64 | 0;
    var DescribeInstanceTopologyGroupNameSet = 64 | 0;
    var DescribeInstanceTopologyInstanceIdSet = 64 | 0;
    var DeviceTrustProviderTypeList = [
      1,
      n032,
      _DTPTL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var DhcpConfigurationList = [
      1,
      n032,
      _DCL,
      0,
      [
        () => exports2.DhcpConfiguration$,
        { [_xN]: _it }
      ]
    ];
    var DhcpConfigurationValueList = [
      1,
      n032,
      _DCVL,
      0,
      [
        () => exports2.AttributeValue$,
        { [_xN]: _it }
      ]
    ];
    var DhcpOptionsIdStringList = [
      1,
      n032,
      _DOISL,
      0,
      [
        0,
        { [_xN]: _DOI }
      ]
    ];
    var DhcpOptionsList = [
      1,
      n032,
      _DOL,
      0,
      [
        () => exports2.DhcpOptions$,
        { [_xN]: _it }
      ]
    ];
    var DisableFastSnapshotRestoreErrorSet = [
      1,
      n032,
      _DFSRES,
      0,
      [
        () => exports2.DisableFastSnapshotRestoreErrorItem$,
        { [_xN]: _it }
      ]
    ];
    var DisableFastSnapshotRestoreStateErrorSet = [
      1,
      n032,
      _DFSRSES,
      0,
      [
        () => exports2.DisableFastSnapshotRestoreStateErrorItem$,
        { [_xN]: _it }
      ]
    ];
    var DisableFastSnapshotRestoreSuccessSet = [
      1,
      n032,
      _DFSRSSi,
      0,
      [
        () => exports2.DisableFastSnapshotRestoreSuccessItem$,
        { [_xN]: _it }
      ]
    ];
    var DiskImageList = [
      1,
      n032,
      _DIL,
      0,
      [
        () => exports2.DiskImage$,
        0
      ]
    ];
    var DiskInfoList = [
      1,
      n032,
      _DILi,
      0,
      [
        () => exports2.DiskInfo$,
        { [_xN]: _it }
      ]
    ];
    var DnsEntrySet = [
      1,
      n032,
      _DES,
      0,
      [
        () => exports2.DnsEntry$,
        { [_xN]: _it }
      ]
    ];
    var EbsCardInfoList = [
      1,
      n032,
      _ECIL,
      0,
      [
        () => exports2.EbsCardInfo$,
        { [_xN]: _it }
      ]
    ];
    var EbsStatusDetailsList = [
      1,
      n032,
      _ESDL,
      0,
      [
        () => exports2.EbsStatusDetails$,
        { [_xN]: _it }
      ]
    ];
    var EgressOnlyInternetGatewayIdList = [
      1,
      n032,
      _EOIGIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var EgressOnlyInternetGatewayList = [
      1,
      n032,
      _EOIGL,
      0,
      [
        () => exports2.EgressOnlyInternetGateway$,
        { [_xN]: _it }
      ]
    ];
    var EipAssociationIdList = [
      1,
      n032,
      _EAIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var ElasticGpuAssociationList = [
      1,
      n032,
      _EGAL,
      0,
      [
        () => exports2.ElasticGpuAssociation$,
        { [_xN]: _it }
      ]
    ];
    var ElasticGpuIdSet = [
      1,
      n032,
      _EGIS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var ElasticGpuSet = [
      1,
      n032,
      _EGS,
      0,
      [
        () => exports2.ElasticGpus$,
        { [_xN]: _it }
      ]
    ];
    var ElasticGpuSpecificationList = [
      1,
      n032,
      _EGSL,
      0,
      [
        () => exports2.ElasticGpuSpecification$,
        { [_xN]: _EGSla }
      ]
    ];
    var ElasticGpuSpecificationResponseList = [
      1,
      n032,
      _EGSRL,
      0,
      [
        () => exports2.ElasticGpuSpecificationResponse$,
        { [_xN]: _it }
      ]
    ];
    var ElasticGpuSpecifications = [
      1,
      n032,
      _EGSlas,
      0,
      [
        () => exports2.ElasticGpuSpecification$,
        { [_xN]: _it }
      ]
    ];
    var ElasticInferenceAcceleratorAssociationList = [
      1,
      n032,
      _EIAAL,
      0,
      [
        () => exports2.ElasticInferenceAcceleratorAssociation$,
        { [_xN]: _it }
      ]
    ];
    var ElasticInferenceAccelerators = [
      1,
      n032,
      _EIAl,
      0,
      [
        () => exports2.ElasticInferenceAccelerator$,
        { [_xN]: _it }
      ]
    ];
    var EnableFastSnapshotRestoreErrorSet = [
      1,
      n032,
      _EFSRES,
      0,
      [
        () => exports2.EnableFastSnapshotRestoreErrorItem$,
        { [_xN]: _it }
      ]
    ];
    var EnableFastSnapshotRestoreStateErrorSet = [
      1,
      n032,
      _EFSRSES,
      0,
      [
        () => exports2.EnableFastSnapshotRestoreStateErrorItem$,
        { [_xN]: _it }
      ]
    ];
    var EnableFastSnapshotRestoreSuccessSet = [
      1,
      n032,
      _EFSRSS,
      0,
      [
        () => exports2.EnableFastSnapshotRestoreSuccessItem$,
        { [_xN]: _it }
      ]
    ];
    var EndpointSet = [
      1,
      n032,
      _ESnd,
      0,
      [
        () => exports2.ClientVpnEndpoint$,
        { [_xN]: _it }
      ]
    ];
    var ErrorSet = [
      1,
      n032,
      _ESr,
      0,
      [
        () => exports2.ValidationError$,
        { [_xN]: _it }
      ]
    ];
    var ExcludedInstanceTypeSet = [
      1,
      n032,
      _EITSx,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var ExecutableByStringList = [
      1,
      n032,
      _EBSL,
      0,
      [
        0,
        { [_xN]: _EBx }
      ]
    ];
    var ExplanationList = [
      1,
      n032,
      _EL,
      0,
      [
        () => exports2.Explanation$,
        { [_xN]: _it }
      ]
    ];
    var ExportImageTaskIdList = [
      1,
      n032,
      _EITIL,
      0,
      [
        0,
        { [_xN]: _EITIx }
      ]
    ];
    var ExportImageTaskList = [
      1,
      n032,
      _EITL,
      0,
      [
        () => exports2.ExportImageTask$,
        { [_xN]: _it }
      ]
    ];
    var ExportTaskIdStringList = [
      1,
      n032,
      _ETISL,
      0,
      [
        0,
        { [_xN]: _ETI }
      ]
    ];
    var ExportTaskList = [
      1,
      n032,
      _ETL,
      0,
      [
        () => exports2.ExportTask$,
        { [_xN]: _it }
      ]
    ];
    var FailedCapacityReservationFleetCancellationResultSet = [
      1,
      n032,
      _FCRFCRS,
      0,
      [
        () => exports2.FailedCapacityReservationFleetCancellationResult$,
        { [_xN]: _it }
      ]
    ];
    var FailedQueuedPurchaseDeletionSet = [
      1,
      n032,
      _FQPDS,
      0,
      [
        () => exports2.FailedQueuedPurchaseDeletion$,
        { [_xN]: _it }
      ]
    ];
    var FastLaunchImageIdList = [
      1,
      n032,
      _FLIIL,
      0,
      [
        0,
        { [_xN]: _IIm }
      ]
    ];
    var FilterList = [
      1,
      n032,
      _FLi,
      0,
      [
        () => exports2.Filter$,
        { [_xN]: _Fil }
      ]
    ];
    var FleetBlockDeviceMappingRequestList = [
      1,
      n032,
      _FBDMRL,
      0,
      [
        () => exports2.FleetBlockDeviceMappingRequest$,
        { [_xN]: _BDM }
      ]
    ];
    var FleetCapacityReservationSet = [
      1,
      n032,
      _FCRS,
      0,
      [
        () => exports2.FleetCapacityReservation$,
        { [_xN]: _it }
      ]
    ];
    var FleetIdSet = 64 | 0;
    var FleetLaunchTemplateConfigList = [
      1,
      n032,
      _FLTCL,
      0,
      [
        () => exports2.FleetLaunchTemplateConfig$,
        { [_xN]: _it }
      ]
    ];
    var FleetLaunchTemplateConfigListRequest = [
      1,
      n032,
      _FLTCLR,
      0,
      [
        () => exports2.FleetLaunchTemplateConfigRequest$,
        { [_xN]: _it }
      ]
    ];
    var FleetLaunchTemplateOverridesList = [
      1,
      n032,
      _FLTOL,
      0,
      [
        () => exports2.FleetLaunchTemplateOverrides$,
        { [_xN]: _it }
      ]
    ];
    var FleetLaunchTemplateOverridesListRequest = [
      1,
      n032,
      _FLTOLR,
      0,
      [
        () => exports2.FleetLaunchTemplateOverridesRequest$,
        { [_xN]: _it }
      ]
    ];
    var FleetSet = [
      1,
      n032,
      _FSl,
      0,
      [
        () => exports2.FleetData$,
        { [_xN]: _it }
      ]
    ];
    var FlowLogIdList = [
      1,
      n032,
      _FLIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var FlowLogResourceIds = [
      1,
      n032,
      _FLRI,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var FlowLogSet = [
      1,
      n032,
      _FLSl,
      0,
      [
        () => exports2.FlowLog$,
        { [_xN]: _it }
      ]
    ];
    var FpgaDeviceInfoList = [
      1,
      n032,
      _FDIL,
      0,
      [
        () => exports2.FpgaDeviceInfo$,
        { [_xN]: _it }
      ]
    ];
    var FpgaImageIdList = [
      1,
      n032,
      _FIIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var FpgaImageList = [
      1,
      n032,
      _FIL,
      0,
      [
        () => exports2.FpgaImage$,
        { [_xN]: _it }
      ]
    ];
    var GpuDeviceInfoList = [
      1,
      n032,
      _GDIL,
      0,
      [
        () => exports2.GpuDeviceInfo$,
        { [_xN]: _it }
      ]
    ];
    var GroupBySet = [
      1,
      n032,
      _GBS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var GroupIdentifierList = [
      1,
      n032,
      _GIL,
      0,
      [
        () => exports2.GroupIdentifier$,
        { [_xN]: _it }
      ]
    ];
    var GroupIdentifierSet = [
      1,
      n032,
      _GIS,
      0,
      [
        () => exports2.SecurityGroupIdentifier$,
        { [_xN]: _it }
      ]
    ];
    var GroupIds = [
      1,
      n032,
      _GIro,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var GroupIdStringList = [
      1,
      n032,
      _GISL,
      0,
      [
        0,
        { [_xN]: _gIr }
      ]
    ];
    var GroupNameStringList = [
      1,
      n032,
      _GNSL,
      0,
      [
        0,
        { [_xN]: _GN }
      ]
    ];
    var HistoryRecords = [
      1,
      n032,
      _HRi,
      0,
      [
        () => exports2.HistoryRecord$,
        { [_xN]: _it }
      ]
    ];
    var HistoryRecordSet = [
      1,
      n032,
      _HRSi,
      0,
      [
        () => exports2.HistoryRecordEntry$,
        { [_xN]: _it }
      ]
    ];
    var HostInstanceList = [
      1,
      n032,
      _HIL,
      0,
      [
        () => exports2.HostInstance$,
        { [_xN]: _it }
      ]
    ];
    var HostList = [
      1,
      n032,
      _HL,
      0,
      [
        () => exports2.Host$,
        { [_xN]: _it }
      ]
    ];
    var HostOfferingSet = [
      1,
      n032,
      _HOS,
      0,
      [
        () => exports2.HostOffering$,
        { [_xN]: _it }
      ]
    ];
    var HostReservationIdSet = [
      1,
      n032,
      _HRIS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var HostReservationSet = [
      1,
      n032,
      _HRS,
      0,
      [
        () => exports2.HostReservation$,
        { [_xN]: _it }
      ]
    ];
    var IamInstanceProfileAssociationSet = [
      1,
      n032,
      _IIPAS,
      0,
      [
        () => exports2.IamInstanceProfileAssociation$,
        { [_xN]: _it }
      ]
    ];
    var IdFormatList = [
      1,
      n032,
      _IFL,
      0,
      [
        () => exports2.IdFormat$,
        { [_xN]: _it }
      ]
    ];
    var IKEVersionsList = [
      1,
      n032,
      _IKEVL,
      0,
      [
        () => exports2.IKEVersionsListValue$,
        { [_xN]: _it }
      ]
    ];
    var IKEVersionsRequestList = [
      1,
      n032,
      _IKEVRL,
      0,
      [
        () => exports2.IKEVersionsRequestListValue$,
        { [_xN]: _it }
      ]
    ];
    var ImageAncestryEntryList = [
      1,
      n032,
      _IAEL,
      0,
      [
        () => exports2.ImageAncestryEntry$,
        { [_xN]: _it }
      ]
    ];
    var ImageCriterionList = [
      1,
      n032,
      _ICL,
      0,
      [
        () => exports2.ImageCriterion$,
        { [_xN]: _it }
      ]
    ];
    var ImageCriterionRequestList = [
      1,
      n032,
      _ICRL,
      0,
      [
        () => exports2.ImageCriterionRequest$,
        { [_xN]: _ICma }
      ]
    ];
    var ImageDiskContainerList = [
      1,
      n032,
      _IDCL,
      0,
      [
        () => exports2.ImageDiskContainer$,
        { [_xN]: _it }
      ]
    ];
    var ImageIdList = [
      1,
      n032,
      _IIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var ImageIdStringList = [
      1,
      n032,
      _IISL,
      0,
      [
        0,
        { [_xN]: _IIm }
      ]
    ];
    var ImageList = [
      1,
      n032,
      _ILm,
      0,
      [
        () => exports2.Image$,
        { [_xN]: _it }
      ]
    ];
    var ImageNameList = [
      1,
      n032,
      _INLm,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var ImageNameRequestList = [
      1,
      n032,
      _INRL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var ImageProviderList = [
      1,
      n032,
      _IPL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var ImageProviderRequestList = [
      1,
      n032,
      _IPRL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var ImageRecycleBinInfoList = [
      1,
      n032,
      _IRBIL,
      0,
      [
        () => exports2.ImageRecycleBinInfo$,
        { [_xN]: _it }
      ]
    ];
    var ImageReferenceList = [
      1,
      n032,
      _IRL,
      0,
      [
        () => exports2.ImageReference$,
        { [_xN]: _it }
      ]
    ];
    var ImageUsageReportEntryList = [
      1,
      n032,
      _IUREL,
      0,
      [
        () => exports2.ImageUsageReportEntry$,
        { [_xN]: _it }
      ]
    ];
    var ImageUsageReportIdStringList = 64 | 0;
    var ImageUsageReportList = [
      1,
      n032,
      _IURL,
      0,
      [
        () => exports2.ImageUsageReport$,
        { [_xN]: _it }
      ]
    ];
    var ImageUsageReportUserIdStringList = [
      1,
      n032,
      _IURUISL,
      0,
      [
        0,
        { [_xN]: _UI }
      ]
    ];
    var ImageUsageResourceTypeList = [
      1,
      n032,
      _IURTL,
      0,
      [
        () => exports2.ImageUsageResourceType$,
        { [_xN]: _it }
      ]
    ];
    var ImageUsageResourceTypeOptionList = [
      1,
      n032,
      _IURTOL,
      0,
      [
        () => exports2.ImageUsageResourceTypeOption$,
        { [_xN]: _it }
      ]
    ];
    var ImageUsageResourceTypeOptionRequestList = [
      1,
      n032,
      _IURTORL,
      0,
      [
        () => exports2.ImageUsageResourceTypeOptionRequest$,
        0
      ]
    ];
    var ImageUsageResourceTypeOptionValuesList = [
      1,
      n032,
      _IURTOVL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var ImageUsageResourceTypeRequestList = [
      1,
      n032,
      _IURTRL,
      0,
      [
        () => exports2.ImageUsageResourceTypeRequest$,
        0
      ]
    ];
    var ImportImageLicenseSpecificationListRequest = [
      1,
      n032,
      _IILSLR,
      0,
      [
        () => exports2.ImportImageLicenseConfigurationRequest$,
        { [_xN]: _it }
      ]
    ];
    var ImportImageLicenseSpecificationListResponse = [
      1,
      n032,
      _IILSLRm,
      0,
      [
        () => exports2.ImportImageLicenseConfigurationResponse$,
        { [_xN]: _it }
      ]
    ];
    var ImportImageTaskList = [
      1,
      n032,
      _IITL,
      0,
      [
        () => exports2.ImportImageTask$,
        { [_xN]: _it }
      ]
    ];
    var ImportInstanceVolumeDetailSet = [
      1,
      n032,
      _IIVDS,
      0,
      [
        () => exports2.ImportInstanceVolumeDetailItem$,
        { [_xN]: _it }
      ]
    ];
    var ImportSnapshotTaskIdList = [
      1,
      n032,
      _ISTIL,
      0,
      [
        0,
        { [_xN]: _ITI }
      ]
    ];
    var ImportSnapshotTaskList = [
      1,
      n032,
      _ISTL,
      0,
      [
        () => exports2.ImportSnapshotTask$,
        { [_xN]: _it }
      ]
    ];
    var ImportTaskIdList = [
      1,
      n032,
      _ITIL,
      0,
      [
        0,
        { [_xN]: _ITI }
      ]
    ];
    var InferenceDeviceInfoList = [
      1,
      n032,
      _IDIL,
      0,
      [
        () => exports2.InferenceDeviceInfo$,
        0
      ]
    ];
    var InsideCidrBlocksStringList = [
      1,
      n032,
      _ICBSL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var InstanceBlockDeviceMappingList = [
      1,
      n032,
      _IBDML,
      0,
      [
        () => exports2.InstanceBlockDeviceMapping$,
        { [_xN]: _it }
      ]
    ];
    var InstanceBlockDeviceMappingSpecificationList = [
      1,
      n032,
      _IBDMSL,
      0,
      [
        () => exports2.InstanceBlockDeviceMappingSpecification$,
        { [_xN]: _it }
      ]
    ];
    var InstanceConnectEndpointSet = [
      1,
      n032,
      _ICES,
      0,
      [
        () => exports2.Ec2InstanceConnectEndpoint$,
        { [_xN]: _it }
      ]
    ];
    var InstanceCountList = [
      1,
      n032,
      _ICLn,
      0,
      [
        () => exports2.InstanceCount$,
        { [_xN]: _it }
      ]
    ];
    var InstanceCreditSpecificationList = [
      1,
      n032,
      _ICSL,
      0,
      [
        () => exports2.InstanceCreditSpecification$,
        { [_xN]: _it }
      ]
    ];
    var InstanceCreditSpecificationListRequest = [
      1,
      n032,
      _ICSLR,
      0,
      [
        () => exports2.InstanceCreditSpecificationRequest$,
        { [_xN]: _it }
      ]
    ];
    var InstanceEventWindowIdSet = [
      1,
      n032,
      _IEWIS,
      0,
      [
        0,
        { [_xN]: _IEWI }
      ]
    ];
    var InstanceEventWindowSet = [
      1,
      n032,
      _IEWSn,
      0,
      [
        () => exports2.InstanceEventWindow$,
        { [_xN]: _it }
      ]
    ];
    var InstanceEventWindowTimeRangeList = [
      1,
      n032,
      _IEWTRL,
      0,
      [
        () => exports2.InstanceEventWindowTimeRange$,
        { [_xN]: _it }
      ]
    ];
    var InstanceEventWindowTimeRangeRequestSet = [
      1,
      n032,
      _IEWTRRS,
      0,
      () => exports2.InstanceEventWindowTimeRangeRequest$
    ];
    var InstanceGenerationSet = [
      1,
      n032,
      _IGS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var InstanceIdList = [
      1,
      n032,
      _IILn,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var InstanceIdSet = [
      1,
      n032,
      _IIS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var InstanceIdsSet = [
      1,
      n032,
      _IISn,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var InstanceIdStringList = [
      1,
      n032,
      _IISLn,
      0,
      [
        0,
        { [_xN]: _II2 }
      ]
    ];
    var InstanceIdUpdateStringList = [
      1,
      n032,
      _IIUSL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var InstanceImageMetadataList = [
      1,
      n032,
      _IIML,
      0,
      [
        () => exports2.InstanceImageMetadata$,
        { [_xN]: _it }
      ]
    ];
    var InstanceIpv4PrefixList = [
      1,
      n032,
      _IIPL,
      0,
      [
        () => exports2.InstanceIpv4Prefix$,
        { [_xN]: _it }
      ]
    ];
    var InstanceIpv6AddressList = [
      1,
      n032,
      _IIAL,
      0,
      [
        () => exports2.InstanceIpv6Address$,
        { [_xN]: _it }
      ]
    ];
    var InstanceIpv6AddressListRequest = [
      1,
      n032,
      _IIALR,
      0,
      [
        () => exports2.InstanceIpv6AddressRequest$,
        { [_xN]: _IIA }
      ]
    ];
    var InstanceIpv6PrefixList = [
      1,
      n032,
      _IIPLn,
      0,
      [
        () => exports2.InstanceIpv6Prefix$,
        { [_xN]: _it }
      ]
    ];
    var InstanceList = [
      1,
      n032,
      _ILns,
      0,
      [
        () => exports2.Instance$,
        { [_xN]: _it }
      ]
    ];
    var InstanceMonitoringList = [
      1,
      n032,
      _IML,
      0,
      [
        () => exports2.InstanceMonitoring$,
        { [_xN]: _it }
      ]
    ];
    var InstanceNetworkInterfaceList = [
      1,
      n032,
      _INIL,
      0,
      [
        () => exports2.InstanceNetworkInterface$,
        { [_xN]: _it }
      ]
    ];
    var InstanceNetworkInterfaceSpecificationList = [
      1,
      n032,
      _INISL,
      0,
      [
        () => exports2.InstanceNetworkInterfaceSpecification$,
        { [_xN]: _it }
      ]
    ];
    var InstancePrivateIpAddressList = [
      1,
      n032,
      _IPIAL,
      0,
      [
        () => exports2.InstancePrivateIpAddress$,
        { [_xN]: _it }
      ]
    ];
    var InstanceSecondaryInterfaceList = [
      1,
      n032,
      _ISIL,
      0,
      [
        () => exports2.InstanceSecondaryInterface$,
        { [_xN]: _it }
      ]
    ];
    var InstanceSecondaryInterfacePrivateIpAddressList = [
      1,
      n032,
      _ISIPIAL,
      0,
      [
        () => exports2.InstanceSecondaryInterfacePrivateIpAddress$,
        { [_xN]: _it }
      ]
    ];
    var InstanceSecondaryInterfacePrivateIpAddressListRequest = [
      1,
      n032,
      _ISIPIALR,
      0,
      [
        () => exports2.InstanceSecondaryInterfacePrivateIpAddressRequest$,
        { [_xN]: _it }
      ]
    ];
    var InstanceSecondaryInterfaceSpecificationListRequest = [
      1,
      n032,
      _ISISLR,
      0,
      [
        () => exports2.InstanceSecondaryInterfaceSpecificationRequest$,
        { [_xN]: _it }
      ]
    ];
    var InstanceSet = [
      1,
      n032,
      _ISnstan,
      0,
      [
        () => exports2.InstanceTopology$,
        { [_xN]: _it }
      ]
    ];
    var InstanceStateChangeList = [
      1,
      n032,
      _ISCL,
      0,
      [
        () => exports2.InstanceStateChange$,
        { [_xN]: _it }
      ]
    ];
    var InstanceStatusDetailsList = [
      1,
      n032,
      _ISDL,
      0,
      [
        () => exports2.InstanceStatusDetails$,
        { [_xN]: _it }
      ]
    ];
    var InstanceStatusEventList = [
      1,
      n032,
      _ISEL,
      0,
      [
        () => exports2.InstanceStatusEvent$,
        { [_xN]: _it }
      ]
    ];
    var InstanceStatusList = [
      1,
      n032,
      _ISLn,
      0,
      [
        () => exports2.InstanceStatus$,
        { [_xN]: _it }
      ]
    ];
    var InstanceTagKeySet = [
      1,
      n032,
      _ITKS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var InstanceTypeInfoFromInstanceRequirementsSet = [
      1,
      n032,
      _ITIFIRS,
      0,
      [
        () => exports2.InstanceTypeInfoFromInstanceRequirements$,
        { [_xN]: _it }
      ]
    ];
    var InstanceTypeInfoList = [
      1,
      n032,
      _ITILn,
      0,
      [
        () => exports2.InstanceTypeInfo$,
        { [_xN]: _it }
      ]
    ];
    var InstanceTypeList = 64 | 0;
    var InstanceTypeOfferingsList = [
      1,
      n032,
      _ITOL,
      0,
      [
        () => exports2.InstanceTypeOffering$,
        { [_xN]: _it }
      ]
    ];
    var InstanceTypes = 64 | 0;
    var InstanceTypesList = [
      1,
      n032,
      _ITL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var InstanceUsageSet = [
      1,
      n032,
      _IUS,
      0,
      [
        () => exports2.InstanceUsage$,
        { [_xN]: _it }
      ]
    ];
    var InternetGatewayAttachmentList = [
      1,
      n032,
      _IGAL,
      0,
      [
        () => exports2.InternetGatewayAttachment$,
        { [_xN]: _it }
      ]
    ];
    var InternetGatewayIdList = [
      1,
      n032,
      _IGIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var InternetGatewayList = [
      1,
      n032,
      _IGL,
      0,
      [
        () => exports2.InternetGateway$,
        { [_xN]: _it }
      ]
    ];
    var IpAddressList = [
      1,
      n032,
      _IAL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var IpamAddressHistoryRecordSet = [
      1,
      n032,
      _IAHRS,
      0,
      [
        () => exports2.IpamAddressHistoryRecord$,
        { [_xN]: _it }
      ]
    ];
    var IpamDiscoveredAccountSet = [
      1,
      n032,
      _IDAS,
      0,
      [
        () => exports2.IpamDiscoveredAccount$,
        { [_xN]: _it }
      ]
    ];
    var IpamDiscoveredPublicAddressSet = [
      1,
      n032,
      _IDPAS,
      0,
      [
        () => exports2.IpamDiscoveredPublicAddress$,
        { [_xN]: _it }
      ]
    ];
    var IpamDiscoveredResourceCidrSet = [
      1,
      n032,
      _IDRCS,
      0,
      [
        () => exports2.IpamDiscoveredResourceCidr$,
        { [_xN]: _it }
      ]
    ];
    var IpamExternalResourceVerificationTokenSet = [
      1,
      n032,
      _IERVTS,
      0,
      [
        () => exports2.IpamExternalResourceVerificationToken$,
        { [_xN]: _it }
      ]
    ];
    var IpamOperatingRegionSet = [
      1,
      n032,
      _IORS,
      0,
      [
        () => exports2.IpamOperatingRegion$,
        { [_xN]: _it }
      ]
    ];
    var IpamOrganizationalUnitExclusionSet = [
      1,
      n032,
      _IOUES,
      0,
      [
        () => exports2.IpamOrganizationalUnitExclusion$,
        { [_xN]: _it }
      ]
    ];
    var IpamPolicyAllocationRuleList = [
      1,
      n032,
      _IPARL,
      0,
      [
        () => exports2.IpamPolicyAllocationRule$,
        { [_xN]: _it }
      ]
    ];
    var IpamPolicyAllocationRuleListRequest = [
      1,
      n032,
      _IPARLR,
      0,
      [
        () => exports2.IpamPolicyAllocationRuleRequest$,
        { [_xN]: _it }
      ]
    ];
    var IpamPolicyDocumentSet = [
      1,
      n032,
      _IPDS,
      0,
      [
        () => exports2.IpamPolicyDocument$,
        { [_xN]: _it }
      ]
    ];
    var IpamPolicyOrganizationTargetSet = [
      1,
      n032,
      _IPOTS,
      0,
      [
        () => exports2.IpamPolicyOrganizationTarget$,
        { [_xN]: _it }
      ]
    ];
    var IpamPolicySet = [
      1,
      n032,
      _IPSpa,
      0,
      [
        () => exports2.IpamPolicy$,
        { [_xN]: _it }
      ]
    ];
    var IpamPoolAllocationAllowedCidrs = [
      1,
      n032,
      _IPAAC,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var IpamPoolAllocationDisallowedCidrs = [
      1,
      n032,
      _IPADC,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var IpamPoolAllocationSet = [
      1,
      n032,
      _IPAS,
      0,
      [
        () => exports2.IpamPoolAllocation$,
        { [_xN]: _it }
      ]
    ];
    var IpamPoolCidrSet = [
      1,
      n032,
      _IPCS,
      0,
      [
        () => exports2.IpamPoolCidr$,
        { [_xN]: _it }
      ]
    ];
    var IpamPoolSet = [
      1,
      n032,
      _IPSpam,
      0,
      [
        () => exports2.IpamPool$,
        { [_xN]: _it }
      ]
    ];
    var IpamPrefixListResolverRuleConditionRequestSet = [
      1,
      n032,
      _IPLRRCRS,
      0,
      [
        () => exports2.IpamPrefixListResolverRuleConditionRequest$,
        { [_xN]: _Condi }
      ]
    ];
    var IpamPrefixListResolverRuleConditionSet = [
      1,
      n032,
      _IPLRRCS,
      0,
      [
        () => exports2.IpamPrefixListResolverRuleCondition$,
        { [_xN]: _it }
      ]
    ];
    var IpamPrefixListResolverRuleRequestSet = [
      1,
      n032,
      _IPLRRRS,
      0,
      [
        () => exports2.IpamPrefixListResolverRuleRequest$,
        { [_xN]: _Rul }
      ]
    ];
    var IpamPrefixListResolverRuleSet = [
      1,
      n032,
      _IPLRRS,
      0,
      [
        () => exports2.IpamPrefixListResolverRule$,
        { [_xN]: _it }
      ]
    ];
    var IpamPrefixListResolverSet = [
      1,
      n032,
      _IPLRS,
      0,
      [
        () => exports2.IpamPrefixListResolver$,
        { [_xN]: _it }
      ]
    ];
    var IpamPrefixListResolverTargetSet = [
      1,
      n032,
      _IPLRTS,
      0,
      [
        () => exports2.IpamPrefixListResolverTarget$,
        { [_xN]: _it }
      ]
    ];
    var IpamPrefixListResolverVersionEntrySet = [
      1,
      n032,
      _IPLRVES,
      0,
      [
        () => exports2.IpamPrefixListResolverVersionEntry$,
        { [_xN]: _it }
      ]
    ];
    var IpamPrefixListResolverVersionNumberSet = [
      1,
      n032,
      _IPLRVNS,
      0,
      [
        1,
        { [_xN]: _it }
      ]
    ];
    var IpamPrefixListResolverVersionSet = [
      1,
      n032,
      _IPLRVS,
      0,
      [
        () => exports2.IpamPrefixListResolverVersion$,
        { [_xN]: _it }
      ]
    ];
    var IpamPublicAddressSecurityGroupList = [
      1,
      n032,
      _IPASGL,
      0,
      [
        () => exports2.IpamPublicAddressSecurityGroup$,
        { [_xN]: _it }
      ]
    ];
    var IpamPublicAddressTagList = [
      1,
      n032,
      _IPATL,
      0,
      [
        () => exports2.IpamPublicAddressTag$,
        { [_xN]: _it }
      ]
    ];
    var IpamResourceCidrSet = [
      1,
      n032,
      _IRCS,
      0,
      [
        () => exports2.IpamResourceCidr$,
        { [_xN]: _it }
      ]
    ];
    var IpamResourceDiscoveryAssociationSet = [
      1,
      n032,
      _IRDAS,
      0,
      [
        () => exports2.IpamResourceDiscoveryAssociation$,
        { [_xN]: _it }
      ]
    ];
    var IpamResourceDiscoverySet = [
      1,
      n032,
      _IRDS,
      0,
      [
        () => exports2.IpamResourceDiscovery$,
        { [_xN]: _it }
      ]
    ];
    var IpamResourceTagList = [
      1,
      n032,
      _IRTL,
      0,
      [
        () => exports2.IpamResourceTag$,
        { [_xN]: _it }
      ]
    ];
    var IpamScopeSet = [
      1,
      n032,
      _ISSp,
      0,
      [
        () => exports2.IpamScope$,
        { [_xN]: _it }
      ]
    ];
    var IpamSet = [
      1,
      n032,
      _ISpam,
      0,
      [
        () => exports2.Ipam$,
        { [_xN]: _it }
      ]
    ];
    var IpList = [
      1,
      n032,
      _ILp,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var IpPermissionList = [
      1,
      n032,
      _IPLp,
      0,
      [
        () => exports2.IpPermission$,
        { [_xN]: _it }
      ]
    ];
    var IpPrefixList = [
      1,
      n032,
      _IPLpr,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var IpRangeList = [
      1,
      n032,
      _IRLp,
      0,
      [
        () => exports2.IpRange$,
        { [_xN]: _it }
      ]
    ];
    var IpRanges = [
      1,
      n032,
      _IRpa,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var Ipv4PrefixesList = [
      1,
      n032,
      _IPLpv,
      0,
      [
        () => exports2.Ipv4PrefixSpecification$,
        { [_xN]: _it }
      ]
    ];
    var Ipv4PrefixList = [
      1,
      n032,
      _IPLpvr,
      0,
      [
        () => exports2.Ipv4PrefixSpecificationRequest$,
        { [_xN]: _it }
      ]
    ];
    var Ipv4PrefixListResponse = [
      1,
      n032,
      _IPLRpv,
      0,
      [
        () => exports2.Ipv4PrefixSpecificationResponse$,
        { [_xN]: _it }
      ]
    ];
    var Ipv6AddressList = [
      1,
      n032,
      _IALp,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var Ipv6CidrAssociationSet = [
      1,
      n032,
      _ICAS,
      0,
      [
        () => exports2.Ipv6CidrAssociation$,
        { [_xN]: _it }
      ]
    ];
    var Ipv6CidrBlockSet = [
      1,
      n032,
      _ICBSp,
      0,
      [
        () => exports2.Ipv6CidrBlock$,
        { [_xN]: _it }
      ]
    ];
    var Ipv6PoolIdList = [
      1,
      n032,
      _IPIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var Ipv6PoolSet = [
      1,
      n032,
      _IPSpv,
      0,
      [
        () => exports2.Ipv6Pool$,
        { [_xN]: _it }
      ]
    ];
    var Ipv6PrefixesList = [
      1,
      n032,
      _IPLpvre,
      0,
      [
        () => exports2.Ipv6PrefixSpecification$,
        { [_xN]: _it }
      ]
    ];
    var Ipv6PrefixList = [
      1,
      n032,
      _IPLpvref,
      0,
      [
        () => exports2.Ipv6PrefixSpecificationRequest$,
        { [_xN]: _it }
      ]
    ];
    var Ipv6PrefixListResponse = [
      1,
      n032,
      _IPLRpvr,
      0,
      [
        () => exports2.Ipv6PrefixSpecificationResponse$,
        { [_xN]: _it }
      ]
    ];
    var Ipv6RangeList = [
      1,
      n032,
      _IRLpv,
      0,
      [
        () => exports2.Ipv6Range$,
        { [_xN]: _it }
      ]
    ];
    var KeyNameStringList = [
      1,
      n032,
      _KNSL,
      0,
      [
        0,
        { [_xN]: _KN }
      ]
    ];
    var KeyPairIdStringList = [
      1,
      n032,
      _KPISL,
      0,
      [
        0,
        { [_xN]: _KPI }
      ]
    ];
    var KeyPairList = [
      1,
      n032,
      _KPL,
      0,
      [
        () => exports2.KeyPairInfo$,
        { [_xN]: _it }
      ]
    ];
    var LaunchPermissionList = [
      1,
      n032,
      _LPL,
      0,
      [
        () => exports2.LaunchPermission$,
        { [_xN]: _it }
      ]
    ];
    var LaunchSpecsList = [
      1,
      n032,
      _LSLa,
      0,
      [
        () => exports2.SpotFleetLaunchSpecification$,
        { [_xN]: _it }
      ]
    ];
    var LaunchTemplateBlockDeviceMappingList = [
      1,
      n032,
      _LTBDML,
      0,
      [
        () => exports2.LaunchTemplateBlockDeviceMapping$,
        { [_xN]: _it }
      ]
    ];
    var LaunchTemplateBlockDeviceMappingRequestList = [
      1,
      n032,
      _LTBDMRL,
      0,
      [
        () => exports2.LaunchTemplateBlockDeviceMappingRequest$,
        { [_xN]: _BDM }
      ]
    ];
    var LaunchTemplateConfigList = [
      1,
      n032,
      _LTCL,
      0,
      [
        () => exports2.LaunchTemplateConfig$,
        { [_xN]: _it }
      ]
    ];
    var LaunchTemplateElasticInferenceAcceleratorList = [
      1,
      n032,
      _LTEIAL,
      0,
      [
        () => exports2.LaunchTemplateElasticInferenceAccelerator$,
        { [_xN]: _it }
      ]
    ];
    var LaunchTemplateElasticInferenceAcceleratorResponseList = [
      1,
      n032,
      _LTEIARL,
      0,
      [
        () => exports2.LaunchTemplateElasticInferenceAcceleratorResponse$,
        { [_xN]: _it }
      ]
    ];
    var LaunchTemplateIdStringList = [
      1,
      n032,
      _LTISL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var LaunchTemplateInstanceNetworkInterfaceSpecificationList = [
      1,
      n032,
      _LTINISL,
      0,
      [
        () => exports2.LaunchTemplateInstanceNetworkInterfaceSpecification$,
        { [_xN]: _it }
      ]
    ];
    var LaunchTemplateInstanceNetworkInterfaceSpecificationRequestList = [
      1,
      n032,
      _LTINISRL,
      0,
      [
        () => exports2.LaunchTemplateInstanceNetworkInterfaceSpecificationRequest$,
        { [_xN]: _INIS }
      ]
    ];
    var LaunchTemplateInstanceSecondaryInterfaceSpecificationList = [
      1,
      n032,
      _LTISISL,
      0,
      [
        () => exports2.LaunchTemplateInstanceSecondaryInterfaceSpecification$,
        { [_xN]: _it }
      ]
    ];
    var LaunchTemplateInstanceSecondaryInterfaceSpecificationRequestList = [
      1,
      n032,
      _LTISISRL,
      0,
      [
        () => exports2.LaunchTemplateInstanceSecondaryInterfaceSpecificationRequest$,
        { [_xN]: _ISIS }
      ]
    ];
    var LaunchTemplateLicenseList = [
      1,
      n032,
      _LTLL,
      0,
      [
        () => exports2.LaunchTemplateLicenseConfiguration$,
        { [_xN]: _it }
      ]
    ];
    var LaunchTemplateLicenseSpecificationListRequest = [
      1,
      n032,
      _LTLSLR,
      0,
      [
        () => exports2.LaunchTemplateLicenseConfigurationRequest$,
        { [_xN]: _it }
      ]
    ];
    var LaunchTemplateNameStringList = [
      1,
      n032,
      _LTNSL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var LaunchTemplateOverridesList = [
      1,
      n032,
      _LTOL,
      0,
      [
        () => exports2.LaunchTemplateOverrides$,
        { [_xN]: _it }
      ]
    ];
    var LaunchTemplateSet = [
      1,
      n032,
      _LTSa,
      0,
      [
        () => exports2.LaunchTemplate$,
        { [_xN]: _it }
      ]
    ];
    var LaunchTemplateTagSpecificationList = [
      1,
      n032,
      _LTTSL,
      0,
      [
        () => exports2.LaunchTemplateTagSpecification$,
        { [_xN]: _it }
      ]
    ];
    var LaunchTemplateTagSpecificationRequestList = [
      1,
      n032,
      _LTTSRL,
      0,
      [
        () => exports2.LaunchTemplateTagSpecificationRequest$,
        { [_xN]: _LTTSR }
      ]
    ];
    var LaunchTemplateVersionSet = [
      1,
      n032,
      _LTVS,
      0,
      [
        () => exports2.LaunchTemplateVersion$,
        { [_xN]: _it }
      ]
    ];
    var LicenseList = [
      1,
      n032,
      _LL,
      0,
      [
        () => exports2.LicenseConfiguration$,
        { [_xN]: _it }
      ]
    ];
    var LicenseSpecificationListRequest = [
      1,
      n032,
      _LSLR,
      0,
      [
        () => exports2.LicenseConfigurationRequest$,
        { [_xN]: _it }
      ]
    ];
    var LoadPermissionList = [
      1,
      n032,
      _LPLo,
      0,
      [
        () => exports2.LoadPermission$,
        { [_xN]: _it }
      ]
    ];
    var LoadPermissionListRequest = [
      1,
      n032,
      _LPLR,
      0,
      [
        () => exports2.LoadPermissionRequest$,
        { [_xN]: _it }
      ]
    ];
    var LocalGatewayIdSet = [
      1,
      n032,
      _LGIS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var LocalGatewayRouteList = [
      1,
      n032,
      _LGRL,
      0,
      [
        () => exports2.LocalGatewayRoute$,
        { [_xN]: _it }
      ]
    ];
    var LocalGatewayRouteTableIdSet = [
      1,
      n032,
      _LGRTIS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var LocalGatewayRouteTableSet = [
      1,
      n032,
      _LGRTS,
      0,
      [
        () => exports2.LocalGatewayRouteTable$,
        { [_xN]: _it }
      ]
    ];
    var LocalGatewayRouteTableVirtualInterfaceGroupAssociationIdSet = [
      1,
      n032,
      _LGRTVIGAIS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var LocalGatewayRouteTableVirtualInterfaceGroupAssociationSet = [
      1,
      n032,
      _LGRTVIGAS,
      0,
      [
        () => exports2.LocalGatewayRouteTableVirtualInterfaceGroupAssociation$,
        { [_xN]: _it }
      ]
    ];
    var LocalGatewayRouteTableVpcAssociationIdSet = [
      1,
      n032,
      _LGRTVAIS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var LocalGatewayRouteTableVpcAssociationSet = [
      1,
      n032,
      _LGRTVAS,
      0,
      [
        () => exports2.LocalGatewayRouteTableVpcAssociation$,
        { [_xN]: _it }
      ]
    ];
    var LocalGatewaySet = [
      1,
      n032,
      _LGS,
      0,
      [
        () => exports2.LocalGateway$,
        { [_xN]: _it }
      ]
    ];
    var LocalGatewayVirtualInterfaceGroupIdSet = [
      1,
      n032,
      _LGVIGIS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var LocalGatewayVirtualInterfaceGroupSet = [
      1,
      n032,
      _LGVIGS,
      0,
      [
        () => exports2.LocalGatewayVirtualInterfaceGroup$,
        { [_xN]: _it }
      ]
    ];
    var LocalGatewayVirtualInterfaceIdSet = [
      1,
      n032,
      _LGVIIS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var LocalGatewayVirtualInterfaceSet = [
      1,
      n032,
      _LGVIS,
      0,
      [
        () => exports2.LocalGatewayVirtualInterface$,
        { [_xN]: _it }
      ]
    ];
    var LocalStorageTypeSet = [
      1,
      n032,
      _LSTS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var LockedSnapshotsInfoList = [
      1,
      n032,
      _LSIL,
      0,
      [
        () => exports2.LockedSnapshotsInfo$,
        { [_xN]: _it }
      ]
    ];
    var MacHostList = [
      1,
      n032,
      _MHL,
      0,
      [
        () => exports2.MacHost$,
        { [_xN]: _it }
      ]
    ];
    var MacModificationTaskIdList = [
      1,
      n032,
      _MMTIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var MacModificationTaskList = [
      1,
      n032,
      _MMTL,
      0,
      [
        () => exports2.MacModificationTask$,
        { [_xN]: _it }
      ]
    ];
    var MacOSVersionStringList = [
      1,
      n032,
      _MOSVSL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var ManagedPrefixListSet = [
      1,
      n032,
      _MPLS,
      0,
      [
        () => exports2.ManagedPrefixList$,
        { [_xN]: _it }
      ]
    ];
    var MarketplaceProductCodeList = [
      1,
      n032,
      _MPCL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var MarketplaceProductCodeRequestList = [
      1,
      n032,
      _MPCRL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var MediaDeviceInfoList = [
      1,
      n032,
      _MDIL,
      0,
      [
        () => exports2.MediaDeviceInfo$,
        { [_xN]: _it }
      ]
    ];
    var MetricDataResultSet = [
      1,
      n032,
      _MDRS,
      0,
      [
        () => exports2.MetricDataResult$,
        { [_xN]: _it }
      ]
    ];
    var MetricDimensionResultSet = [
      1,
      n032,
      _MDRSe,
      0,
      [
        () => exports2.CapacityManagerDimension$,
        { [_xN]: _it }
      ]
    ];
    var MetricPoints = [
      1,
      n032,
      _MPe,
      0,
      [
        () => exports2.MetricPoint$,
        { [_xN]: _it }
      ]
    ];
    var MetricSet = [
      1,
      n032,
      _MSe,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var MetricValueSet = [
      1,
      n032,
      _MVS,
      0,
      [
        () => exports2.MetricValue$,
        { [_xN]: _it }
      ]
    ];
    var ModifyVerifiedAccessEndpointPortRangeList = [
      1,
      n032,
      _MVAEPRL,
      0,
      [
        () => exports2.ModifyVerifiedAccessEndpointPortRange$,
        { [_xN]: _it }
      ]
    ];
    var ModifyVerifiedAccessEndpointSubnetIdList = [
      1,
      n032,
      _MVAESIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var MovingAddressStatusSet = [
      1,
      n032,
      _MASS,
      0,
      [
        () => exports2.MovingAddressStatus$,
        { [_xN]: _it }
      ]
    ];
    var NatGatewayAddressList = [
      1,
      n032,
      _NGAL,
      0,
      [
        () => exports2.NatGatewayAddress$,
        { [_xN]: _it }
      ]
    ];
    var NatGatewayAttachedApplianceList = [
      1,
      n032,
      _NGAAL,
      0,
      [
        () => exports2.NatGatewayAttachedAppliance$,
        { [_xN]: _it }
      ]
    ];
    var NatGatewayIdStringList = [
      1,
      n032,
      _NGISL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var NatGatewayList = [
      1,
      n032,
      _NGL,
      0,
      [
        () => exports2.NatGateway$,
        { [_xN]: _it }
      ]
    ];
    var NetworkAclAssociationList = [
      1,
      n032,
      _NAAL,
      0,
      [
        () => exports2.NetworkAclAssociation$,
        { [_xN]: _it }
      ]
    ];
    var NetworkAclEntryList = [
      1,
      n032,
      _NAEL,
      0,
      [
        () => exports2.NetworkAclEntry$,
        { [_xN]: _it }
      ]
    ];
    var NetworkAclIdStringList = [
      1,
      n032,
      _NAISL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var NetworkAclList = [
      1,
      n032,
      _NAL,
      0,
      [
        () => exports2.NetworkAcl$,
        { [_xN]: _it }
      ]
    ];
    var NetworkCardInfoList = [
      1,
      n032,
      _NCIL,
      0,
      [
        () => exports2.NetworkCardInfo$,
        { [_xN]: _it }
      ]
    ];
    var NetworkInsightsAccessScopeAnalysisIdList = [
      1,
      n032,
      _NIASAIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var NetworkInsightsAccessScopeAnalysisList = [
      1,
      n032,
      _NIASAL,
      0,
      [
        () => exports2.NetworkInsightsAccessScopeAnalysis$,
        { [_xN]: _it }
      ]
    ];
    var NetworkInsightsAccessScopeIdList = [
      1,
      n032,
      _NIASIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var NetworkInsightsAccessScopeList = [
      1,
      n032,
      _NIASL,
      0,
      [
        () => exports2.NetworkInsightsAccessScope$,
        { [_xN]: _it }
      ]
    ];
    var NetworkInsightsAnalysisIdList = [
      1,
      n032,
      _NIAIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var NetworkInsightsAnalysisList = [
      1,
      n032,
      _NIAL,
      0,
      [
        () => exports2.NetworkInsightsAnalysis$,
        { [_xN]: _it }
      ]
    ];
    var NetworkInsightsPathIdList = [
      1,
      n032,
      _NIPIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var NetworkInsightsPathList = [
      1,
      n032,
      _NIPL,
      0,
      [
        () => exports2.NetworkInsightsPath$,
        { [_xN]: _it }
      ]
    ];
    var NetworkInterfaceIdList = [
      1,
      n032,
      _NIIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var NetworkInterfaceIdSet = [
      1,
      n032,
      _NIIS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var NetworkInterfaceIpv6AddressesList = [
      1,
      n032,
      _NIIAL,
      0,
      [
        () => exports2.NetworkInterfaceIpv6Address$,
        { [_xN]: _it }
      ]
    ];
    var NetworkInterfaceList = [
      1,
      n032,
      _NIL,
      0,
      [
        () => exports2.NetworkInterface$,
        { [_xN]: _it }
      ]
    ];
    var NetworkInterfacePermissionIdList = 64 | 0;
    var NetworkInterfacePermissionList = [
      1,
      n032,
      _NIPLe,
      0,
      [
        () => exports2.NetworkInterfacePermission$,
        { [_xN]: _it }
      ]
    ];
    var NetworkInterfacePrivateIpAddressList = [
      1,
      n032,
      _NIPIAL,
      0,
      [
        () => exports2.NetworkInterfacePrivateIpAddress$,
        { [_xN]: _it }
      ]
    ];
    var NetworkNodeSet = [
      1,
      n032,
      _NNS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var NetworkNodesList = [
      1,
      n032,
      _NNL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var NeuronDeviceInfoList = [
      1,
      n032,
      _NDIL,
      0,
      [
        () => exports2.NeuronDeviceInfo$,
        { [_xN]: _it }
      ]
    ];
    var NewDhcpConfigurationList = [
      1,
      n032,
      _NDCL,
      0,
      [
        () => exports2.NewDhcpConfiguration$,
        { [_xN]: _it }
      ]
    ];
    var NitroTpmSupportedVersionsList = [
      1,
      n032,
      _NTSVL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var OccurrenceDayRequestSet = [
      1,
      n032,
      _ODRS,
      0,
      [
        1,
        { [_xN]: _ODcc }
      ]
    ];
    var OccurrenceDaySet = [
      1,
      n032,
      _ODS,
      0,
      [
        1,
        { [_xN]: _it }
      ]
    ];
    var OrganizationalUnitArnStringList = [
      1,
      n032,
      _OUASL,
      0,
      [
        0,
        { [_xN]: _OUA }
      ]
    ];
    var OrganizationArnStringList = [
      1,
      n032,
      _OASL,
      0,
      [
        0,
        { [_xN]: _OArg }
      ]
    ];
    var OutpostLagIdSet = [
      1,
      n032,
      _OLIS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var OutpostLagSet = [
      1,
      n032,
      _OLS,
      0,
      [
        () => exports2.OutpostLag$,
        { [_xN]: _it }
      ]
    ];
    var OwnerStringList = [
      1,
      n032,
      _OSL,
      0,
      [
        0,
        { [_xN]: _Own }
      ]
    ];
    var PathComponentList = [
      1,
      n032,
      _PCL,
      0,
      [
        () => exports2.PathComponent$,
        { [_xN]: _it }
      ]
    ];
    var PerformanceFactorReferenceSet = [
      1,
      n032,
      _PFRS,
      0,
      [
        () => exports2.PerformanceFactorReference$,
        { [_xN]: _it }
      ]
    ];
    var PerformanceFactorReferenceSetRequest = [
      1,
      n032,
      _PFRSR,
      0,
      [
        () => exports2.PerformanceFactorReferenceRequest$,
        { [_xN]: _it }
      ]
    ];
    var Phase1DHGroupNumbersList = [
      1,
      n032,
      _PDHGNL,
      0,
      [
        () => exports2.Phase1DHGroupNumbersListValue$,
        { [_xN]: _it }
      ]
    ];
    var Phase1DHGroupNumbersRequestList = [
      1,
      n032,
      _PDHGNRL,
      0,
      [
        () => exports2.Phase1DHGroupNumbersRequestListValue$,
        { [_xN]: _it }
      ]
    ];
    var Phase1EncryptionAlgorithmsList = [
      1,
      n032,
      _PEAL,
      0,
      [
        () => exports2.Phase1EncryptionAlgorithmsListValue$,
        { [_xN]: _it }
      ]
    ];
    var Phase1EncryptionAlgorithmsRequestList = [
      1,
      n032,
      _PEARL,
      0,
      [
        () => exports2.Phase1EncryptionAlgorithmsRequestListValue$,
        { [_xN]: _it }
      ]
    ];
    var Phase1IntegrityAlgorithmsList = [
      1,
      n032,
      _PIAL,
      0,
      [
        () => exports2.Phase1IntegrityAlgorithmsListValue$,
        { [_xN]: _it }
      ]
    ];
    var Phase1IntegrityAlgorithmsRequestList = [
      1,
      n032,
      _PIARL,
      0,
      [
        () => exports2.Phase1IntegrityAlgorithmsRequestListValue$,
        { [_xN]: _it }
      ]
    ];
    var Phase2DHGroupNumbersList = [
      1,
      n032,
      _PDHGNLh,
      0,
      [
        () => exports2.Phase2DHGroupNumbersListValue$,
        { [_xN]: _it }
      ]
    ];
    var Phase2DHGroupNumbersRequestList = [
      1,
      n032,
      _PDHGNRLh,
      0,
      [
        () => exports2.Phase2DHGroupNumbersRequestListValue$,
        { [_xN]: _it }
      ]
    ];
    var Phase2EncryptionAlgorithmsList = [
      1,
      n032,
      _PEALh,
      0,
      [
        () => exports2.Phase2EncryptionAlgorithmsListValue$,
        { [_xN]: _it }
      ]
    ];
    var Phase2EncryptionAlgorithmsRequestList = [
      1,
      n032,
      _PEARLh,
      0,
      [
        () => exports2.Phase2EncryptionAlgorithmsRequestListValue$,
        { [_xN]: _it }
      ]
    ];
    var Phase2IntegrityAlgorithmsList = [
      1,
      n032,
      _PIALh,
      0,
      [
        () => exports2.Phase2IntegrityAlgorithmsListValue$,
        { [_xN]: _it }
      ]
    ];
    var Phase2IntegrityAlgorithmsRequestList = [
      1,
      n032,
      _PIARLh,
      0,
      [
        () => exports2.Phase2IntegrityAlgorithmsRequestListValue$,
        { [_xN]: _it }
      ]
    ];
    var PlacementGroupIdStringList = [
      1,
      n032,
      _PGISL,
      0,
      [
        0,
        { [_xN]: _GIr }
      ]
    ];
    var PlacementGroupList = [
      1,
      n032,
      _PGL,
      0,
      [
        () => exports2.PlacementGroup$,
        { [_xN]: _it }
      ]
    ];
    var PlacementGroupStrategyList = [
      1,
      n032,
      _PGSL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var PlacementGroupStringList = 64 | 0;
    var PoolCidrBlocksSet = [
      1,
      n032,
      _PCBS,
      0,
      [
        () => exports2.PoolCidrBlock$,
        { [_xN]: _it }
      ]
    ];
    var PortRangeList = [
      1,
      n032,
      _PRL,
      0,
      [
        () => exports2.PortRange$,
        { [_xN]: _it }
      ]
    ];
    var PrefixListAssociationSet = [
      1,
      n032,
      _PLAS,
      0,
      [
        () => exports2.PrefixListAssociation$,
        { [_xN]: _it }
      ]
    ];
    var PrefixListEntrySet = [
      1,
      n032,
      _PLES,
      0,
      [
        () => exports2.PrefixListEntry$,
        { [_xN]: _it }
      ]
    ];
    var PrefixListIdList = [
      1,
      n032,
      _PLIL,
      0,
      [
        () => exports2.PrefixListId$,
        { [_xN]: _it }
      ]
    ];
    var PrefixListIdSet = [
      1,
      n032,
      _PLIS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var PrefixListResourceIdStringList = [
      1,
      n032,
      _PLRISL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var PrefixListSet = [
      1,
      n032,
      _PLSr,
      0,
      [
        () => exports2.PrefixList$,
        { [_xN]: _it }
      ]
    ];
    var PriceScheduleList = [
      1,
      n032,
      _PSL,
      0,
      [
        () => exports2.PriceSchedule$,
        { [_xN]: _it }
      ]
    ];
    var PriceScheduleSpecificationList = [
      1,
      n032,
      _PSSL,
      0,
      [
        () => exports2.PriceScheduleSpecification$,
        { [_xN]: _it }
      ]
    ];
    var PricingDetailsList = [
      1,
      n032,
      _PDL,
      0,
      [
        () => exports2.PricingDetail$,
        { [_xN]: _it }
      ]
    ];
    var PrincipalIdFormatList = [
      1,
      n032,
      _PIFL,
      0,
      [
        () => exports2.PrincipalIdFormat$,
        { [_xN]: _it }
      ]
    ];
    var PrivateDnsDetailsSet = [
      1,
      n032,
      _PDDS,
      0,
      [
        () => exports2.PrivateDnsDetails$,
        { [_xN]: _it }
      ]
    ];
    var PrivateDnsSpecifiedDomainSet = [
      1,
      n032,
      _PDSDS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var PrivateIpAddressConfigSet = [
      1,
      n032,
      _PIACS,
      0,
      [
        () => exports2.ScheduledInstancesPrivateIpAddressConfig$,
        { [_xN]: _PIACS }
      ]
    ];
    var PrivateIpAddressSpecificationList = [
      1,
      n032,
      _PIASL,
      0,
      [
        () => exports2.PrivateIpAddressSpecification$,
        { [_xN]: _it }
      ]
    ];
    var PrivateIpAddressStringList = [
      1,
      n032,
      _PIASLr,
      0,
      [
        0,
        { [_xN]: _PIAr }
      ]
    ];
    var ProductCodeList = [
      1,
      n032,
      _PCLr,
      0,
      [
        () => exports2.ProductCode$,
        { [_xN]: _it }
      ]
    ];
    var ProductCodeStringList = [
      1,
      n032,
      _PCSL,
      0,
      [
        0,
        { [_xN]: _PCr10 }
      ]
    ];
    var ProductDescriptionList = 64 | 0;
    var PropagatingVgwList = [
      1,
      n032,
      _PVL,
      0,
      [
        () => exports2.PropagatingVgw$,
        { [_xN]: _it }
      ]
    ];
    var ProtocolIntList = [
      1,
      n032,
      _PIL,
      0,
      [
        1,
        { [_xN]: _it }
      ]
    ];
    var ProtocolList = [
      1,
      n032,
      _PLro,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var PublicIpStringList = [
      1,
      n032,
      _PISL,
      0,
      [
        0,
        { [_xN]: _PI10 }
      ]
    ];
    var PublicIpv4PoolIdStringList = [
      1,
      n032,
      _PIPISL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var PublicIpv4PoolRangeSet = [
      1,
      n032,
      _PIPRS,
      0,
      [
        () => exports2.PublicIpv4PoolRange$,
        { [_xN]: _it }
      ]
    ];
    var PublicIpv4PoolSet = [
      1,
      n032,
      _PIPS,
      0,
      [
        () => exports2.PublicIpv4Pool$,
        { [_xN]: _it }
      ]
    ];
    var PurchasedScheduledInstanceSet = [
      1,
      n032,
      _PSIS,
      0,
      [
        () => exports2.ScheduledInstance$,
        { [_xN]: _it }
      ]
    ];
    var PurchaseRequestSet = [
      1,
      n032,
      _PRSu,
      0,
      [
        () => exports2.PurchaseRequest$,
        { [_xN]: _PRu }
      ]
    ];
    var PurchaseSet = [
      1,
      n032,
      _PSu,
      0,
      [
        () => exports2.Purchase$,
        { [_xN]: _it }
      ]
    ];
    var ReasonCodesList = [
      1,
      n032,
      _RCL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var RecurringChargesList = [
      1,
      n032,
      _RCLe,
      0,
      [
        () => exports2.RecurringCharge$,
        { [_xN]: _it }
      ]
    ];
    var RegionalSummaryList = [
      1,
      n032,
      _RSL,
      0,
      [
        () => exports2.RegionalSummary$,
        { [_xN]: _it }
      ]
    ];
    var RegionGeographyList = [
      1,
      n032,
      _RGL,
      0,
      [
        () => exports2.RegionGeography$,
        { [_xN]: _it }
      ]
    ];
    var RegionList = [
      1,
      n032,
      _RL,
      0,
      [
        () => exports2.Region$,
        { [_xN]: _it }
      ]
    ];
    var RegionNames = 64 | 0;
    var RegionNameStringList = [
      1,
      n032,
      _RNSL,
      0,
      [
        0,
        { [_xN]: _RN }
      ]
    ];
    var RegisteredInstanceList = [
      1,
      n032,
      _RILeg,
      0,
      [
        () => exports2.RegisteredInstance$,
        { [_xN]: _it }
      ]
    ];
    var RemoveIpamOperatingRegionSet = [
      1,
      n032,
      _RIORS,
      0,
      () => exports2.RemoveIpamOperatingRegion$
    ];
    var RemoveIpamOrganizationalUnitExclusionSet = [
      1,
      n032,
      _RIOUES,
      0,
      () => exports2.RemoveIpamOrganizationalUnitExclusion$
    ];
    var RemovePrefixListEntries = [
      1,
      n032,
      _RPLEe,
      0,
      () => exports2.RemovePrefixListEntry$
    ];
    var ReplaceRootVolumeTaskIds = [
      1,
      n032,
      _RRVTI,
      0,
      [
        0,
        { [_xN]: _RRVTIe }
      ]
    ];
    var ReplaceRootVolumeTasks = [
      1,
      n032,
      _RRVTe,
      0,
      [
        () => exports2.ReplaceRootVolumeTask$,
        { [_xN]: _it }
      ]
    ];
    var RequestHostIdList = [
      1,
      n032,
      _RHIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var RequestHostIdSet = [
      1,
      n032,
      _RHIS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var RequestInstanceTypeList = 64 | 0;
    var RequestIpamResourceTagList = [
      1,
      n032,
      _RIRTL,
      0,
      [
        () => exports2.RequestIpamResourceTag$,
        { [_xN]: _it }
      ]
    ];
    var RequestSpotLaunchSpecificationSecurityGroupIdList = [
      1,
      n032,
      _RSLSSGIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var RequestSpotLaunchSpecificationSecurityGroupList = [
      1,
      n032,
      _RSLSSGL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var ReservationFleetInstanceSpecificationList = [
      1,
      n032,
      _RFISL,
      0,
      () => exports2.ReservationFleetInstanceSpecification$
    ];
    var ReservationList = [
      1,
      n032,
      _RLe,
      0,
      [
        () => exports2.Reservation$,
        { [_xN]: _it }
      ]
    ];
    var ReservationTypeList = [
      1,
      n032,
      _RTL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var ReservationTypeListRequest = [
      1,
      n032,
      _RTLR,
      0,
      [
        0,
        { [_xN]: _RT13 }
      ]
    ];
    var ReservedInstanceIdSet = [
      1,
      n032,
      _RIIS,
      0,
      [
        0,
        { [_xN]: _RIIe }
      ]
    ];
    var ReservedInstanceReservationValueSet = [
      1,
      n032,
      _RIRVS,
      0,
      [
        () => exports2.ReservedInstanceReservationValue$,
        { [_xN]: _it }
      ]
    ];
    var ReservedInstancesConfigurationList = [
      1,
      n032,
      _RICL,
      0,
      [
        () => exports2.ReservedInstancesConfiguration$,
        { [_xN]: _it }
      ]
    ];
    var ReservedInstancesIdStringList = [
      1,
      n032,
      _RIISL,
      0,
      [
        0,
        { [_xN]: _RIIes }
      ]
    ];
    var ReservedInstancesList = [
      1,
      n032,
      _RILes,
      0,
      [
        () => exports2.ReservedInstances$,
        { [_xN]: _it }
      ]
    ];
    var ReservedInstancesListingList = [
      1,
      n032,
      _RILL,
      0,
      [
        () => exports2.ReservedInstancesListing$,
        { [_xN]: _it }
      ]
    ];
    var ReservedInstancesModificationIdStringList = [
      1,
      n032,
      _RIMISL,
      0,
      [
        0,
        { [_xN]: _RIMIe }
      ]
    ];
    var ReservedInstancesModificationList = [
      1,
      n032,
      _RIML,
      0,
      [
        () => exports2.ReservedInstancesModification$,
        { [_xN]: _it }
      ]
    ];
    var ReservedInstancesModificationResultList = [
      1,
      n032,
      _RIMRL,
      0,
      [
        () => exports2.ReservedInstancesModificationResult$,
        { [_xN]: _it }
      ]
    ];
    var ReservedInstancesOfferingIdStringList = 64 | 0;
    var ReservedInstancesOfferingList = [
      1,
      n032,
      _RIOL,
      0,
      [
        () => exports2.ReservedInstancesOffering$,
        { [_xN]: _it }
      ]
    ];
    var ReservedIntancesIds = [
      1,
      n032,
      _RIIeser,
      0,
      [
        () => exports2.ReservedInstancesId$,
        { [_xN]: _it }
      ]
    ];
    var ResourceIdList = 64 | 0;
    var ResourceList = [
      1,
      n032,
      _RLes,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var ResourceTypeOptionList = [
      1,
      n032,
      _RTOL,
      0,
      [
        () => exports2.ResourceTypeOption$,
        0
      ]
    ];
    var ResourceTypeOptionValuesList = 64 | 0;
    var ResourceTypeRequestList = [
      1,
      n032,
      _RTRL,
      0,
      [
        () => exports2.ResourceTypeRequest$,
        0
      ]
    ];
    var ResponseHostIdList = [
      1,
      n032,
      _RHILe,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var ResponseHostIdSet = [
      1,
      n032,
      _RHISe,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var RestorableByStringList = 64 | 0;
    var RevokedSecurityGroupRuleList = [
      1,
      n032,
      _RSGRL,
      0,
      [
        () => exports2.RevokedSecurityGroupRule$,
        { [_xN]: _it }
      ]
    ];
    var RootDeviceTypeList = [
      1,
      n032,
      _RDTL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var RouteList = [
      1,
      n032,
      _RLo,
      0,
      [
        () => exports2.Route$,
        { [_xN]: _it }
      ]
    ];
    var RouteServerAssociationsList = [
      1,
      n032,
      _RSAL,
      0,
      [
        () => exports2.RouteServerAssociation$,
        { [_xN]: _it }
      ]
    ];
    var RouteServerEndpointIdsList = 64 | 0;
    var RouteServerEndpointsList = [
      1,
      n032,
      _RSEL,
      0,
      [
        () => exports2.RouteServerEndpoint$,
        { [_xN]: _it }
      ]
    ];
    var RouteServerIdsList = 64 | 0;
    var RouteServerPeerIdsList = 64 | 0;
    var RouteServerPeersList = [
      1,
      n032,
      _RSPL,
      0,
      [
        () => exports2.RouteServerPeer$,
        { [_xN]: _it }
      ]
    ];
    var RouteServerPropagationsList = [
      1,
      n032,
      _RSPLo,
      0,
      [
        () => exports2.RouteServerPropagation$,
        { [_xN]: _it }
      ]
    ];
    var RouteServerRouteInstallationDetails = [
      1,
      n032,
      _RSRIDo,
      0,
      [
        () => exports2.RouteServerRouteInstallationDetail$,
        { [_xN]: _it }
      ]
    ];
    var RouteServerRouteList = [
      1,
      n032,
      _RSRL,
      0,
      [
        () => exports2.RouteServerRoute$,
        { [_xN]: _it }
      ]
    ];
    var RouteServersList = [
      1,
      n032,
      _RSLo,
      0,
      [
        () => exports2.RouteServer$,
        { [_xN]: _it }
      ]
    ];
    var RouteTableAssociationList = [
      1,
      n032,
      _RTAL,
      0,
      [
        () => exports2.RouteTableAssociation$,
        { [_xN]: _it }
      ]
    ];
    var RouteTableIdStringList = [
      1,
      n032,
      _RTISL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var RouteTableList = [
      1,
      n032,
      _RTLo,
      0,
      [
        () => exports2.RouteTable$,
        { [_xN]: _it }
      ]
    ];
    var RuleGroupRuleOptionsPairList = [
      1,
      n032,
      _RGROPL,
      0,
      [
        () => exports2.RuleGroupRuleOptionsPair$,
        { [_xN]: _it }
      ]
    ];
    var RuleGroupTypePairList = [
      1,
      n032,
      _RGTPL,
      0,
      [
        () => exports2.RuleGroupTypePair$,
        { [_xN]: _it }
      ]
    ];
    var RuleOptionList = [
      1,
      n032,
      _ROL,
      0,
      [
        () => exports2.RuleOption$,
        { [_xN]: _it }
      ]
    ];
    var S3ObjectTagList = [
      1,
      n032,
      _SOTL,
      0,
      [
        () => exports2.S3ObjectTag$,
        { [_xN]: _it }
      ]
    ];
    var ScheduledInstanceAvailabilitySet = [
      1,
      n032,
      _SIAS,
      0,
      [
        () => exports2.ScheduledInstanceAvailability$,
        { [_xN]: _it }
      ]
    ];
    var ScheduledInstanceIdRequestSet = [
      1,
      n032,
      _SIIRS,
      0,
      [
        0,
        { [_xN]: _SIIch }
      ]
    ];
    var ScheduledInstancesBlockDeviceMappingSet = [
      1,
      n032,
      _SIBDMS,
      0,
      [
        () => exports2.ScheduledInstancesBlockDeviceMapping$,
        { [_xN]: _BDM }
      ]
    ];
    var ScheduledInstanceSet = [
      1,
      n032,
      _SIS,
      0,
      [
        () => exports2.ScheduledInstance$,
        { [_xN]: _it }
      ]
    ];
    var ScheduledInstancesIpv6AddressList = [
      1,
      n032,
      _SIIAL,
      0,
      [
        () => exports2.ScheduledInstancesIpv6Address$,
        { [_xN]: _IApv }
      ]
    ];
    var ScheduledInstancesNetworkInterfaceSet = [
      1,
      n032,
      _SINIS,
      0,
      [
        () => exports2.ScheduledInstancesNetworkInterface$,
        { [_xN]: _NIe }
      ]
    ];
    var ScheduledInstancesSecurityGroupIdSet = [
      1,
      n032,
      _SISGIS,
      0,
      [
        0,
        { [_xN]: _SGI }
      ]
    ];
    var SecondaryInterfaceIdList = [
      1,
      n032,
      _SIIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var SecondaryInterfaceIpv4AddressList = [
      1,
      n032,
      _SIIALe,
      0,
      [
        () => exports2.SecondaryInterfaceIpv4Address$,
        { [_xN]: _it }
      ]
    ];
    var SecondaryInterfaceList = [
      1,
      n032,
      _SIL,
      0,
      [
        () => exports2.SecondaryInterface$,
        { [_xN]: _it }
      ]
    ];
    var SecondaryInterfacePrivateIpAddressSpecificationList = [
      1,
      n032,
      _SIPIASL,
      0,
      [
        () => exports2.SecondaryInterfacePrivateIpAddressSpecification$,
        { [_xN]: _it }
      ]
    ];
    var SecondaryInterfacePrivateIpAddressSpecificationListRequest = [
      1,
      n032,
      _SIPIASLR,
      0,
      [
        () => exports2.SecondaryInterfacePrivateIpAddressSpecificationRequest$,
        { [_xN]: _SIPIAS }
      ]
    ];
    var SecondaryNetworkIdList = [
      1,
      n032,
      _SNIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var SecondaryNetworkIpv4CidrBlockAssociationList = [
      1,
      n032,
      _SNICBAL,
      0,
      [
        () => exports2.SecondaryNetworkIpv4CidrBlockAssociation$,
        { [_xN]: _it }
      ]
    ];
    var SecondaryNetworkList = [
      1,
      n032,
      _SNL,
      0,
      [
        () => exports2.SecondaryNetwork$,
        { [_xN]: _it }
      ]
    ];
    var SecondarySubnetIdList = [
      1,
      n032,
      _SSIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var SecondarySubnetIpv4CidrBlockAssociationList = [
      1,
      n032,
      _SSICBAL,
      0,
      [
        () => exports2.SecondarySubnetIpv4CidrBlockAssociation$,
        { [_xN]: _it }
      ]
    ];
    var SecondarySubnetList = [
      1,
      n032,
      _SSL,
      0,
      [
        () => exports2.SecondarySubnet$,
        { [_xN]: _it }
      ]
    ];
    var SecurityGroupForVpcList = [
      1,
      n032,
      _SGFVL,
      0,
      [
        () => exports2.SecurityGroupForVpc$,
        { [_xN]: _it }
      ]
    ];
    var SecurityGroupIdList = [
      1,
      n032,
      _SGIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var SecurityGroupIdSet = [
      1,
      n032,
      _SGIS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var SecurityGroupIdStringList = [
      1,
      n032,
      _SGISL,
      0,
      [
        0,
        { [_xN]: _SGI }
      ]
    ];
    var SecurityGroupIdStringListRequest = [
      1,
      n032,
      _SGISLR,
      0,
      [
        0,
        { [_xN]: _SGI }
      ]
    ];
    var SecurityGroupList = [
      1,
      n032,
      _SGL,
      0,
      [
        () => exports2.SecurityGroup$,
        { [_xN]: _it }
      ]
    ];
    var SecurityGroupReferences = [
      1,
      n032,
      _SGRecu,
      0,
      [
        () => exports2.SecurityGroupReference$,
        { [_xN]: _it }
      ]
    ];
    var SecurityGroupRuleDescriptionList = [
      1,
      n032,
      _SGRDL,
      0,
      [
        () => exports2.SecurityGroupRuleDescription$,
        { [_xN]: _it }
      ]
    ];
    var SecurityGroupRuleIdList = [
      1,
      n032,
      _SGRIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var SecurityGroupRuleList = [
      1,
      n032,
      _SGRL,
      0,
      [
        () => exports2.SecurityGroupRule$,
        { [_xN]: _it }
      ]
    ];
    var SecurityGroupRuleUpdateList = [
      1,
      n032,
      _SGRUL,
      0,
      [
        () => exports2.SecurityGroupRuleUpdate$,
        { [_xN]: _it }
      ]
    ];
    var SecurityGroupStringList = [
      1,
      n032,
      _SGSL,
      0,
      [
        0,
        { [_xN]: _SGec }
      ]
    ];
    var SecurityGroupVpcAssociationList = [
      1,
      n032,
      _SGVAL,
      0,
      [
        () => exports2.SecurityGroupVpcAssociation$,
        { [_xN]: _it }
      ]
    ];
    var ServiceConfigurationSet = [
      1,
      n032,
      _SCS,
      0,
      [
        () => exports2.ServiceConfiguration$,
        { [_xN]: _it }
      ]
    ];
    var ServiceDetailSet = [
      1,
      n032,
      _SDSe,
      0,
      [
        () => exports2.ServiceDetail$,
        { [_xN]: _it }
      ]
    ];
    var ServiceLinkVirtualInterfaceIdSet = [
      1,
      n032,
      _SLVIIS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var ServiceLinkVirtualInterfaceSet = [
      1,
      n032,
      _SLVIS,
      0,
      [
        () => exports2.ServiceLinkVirtualInterface$,
        { [_xN]: _it }
      ]
    ];
    var ServiceTypeDetailSet = [
      1,
      n032,
      _STDS,
      0,
      [
        () => exports2.ServiceTypeDetail$,
        { [_xN]: _it }
      ]
    ];
    var SnapshotDetailList = [
      1,
      n032,
      _SDL,
      0,
      [
        () => exports2.SnapshotDetail$,
        { [_xN]: _it }
      ]
    ];
    var SnapshotIdStringList = [
      1,
      n032,
      _SISL,
      0,
      [
        0,
        { [_xN]: _SIn }
      ]
    ];
    var SnapshotList = [
      1,
      n032,
      _SLn,
      0,
      [
        () => exports2.Snapshot$,
        { [_xN]: _it }
      ]
    ];
    var SnapshotRecycleBinInfoList = [
      1,
      n032,
      _SRBIL,
      0,
      [
        () => exports2.SnapshotRecycleBinInfo$,
        { [_xN]: _it }
      ]
    ];
    var SnapshotSet = [
      1,
      n032,
      _SSn,
      0,
      [
        () => exports2.SnapshotInfo$,
        { [_xN]: _it }
      ]
    ];
    var snapshotTierStatusSet = [
      1,
      n032,
      _sTSS,
      0,
      [
        () => exports2.SnapshotTierStatus$,
        { [_xN]: _it }
      ]
    ];
    var SpotFleetRequestConfigSet = [
      1,
      n032,
      _SFRCS,
      0,
      [
        () => exports2.SpotFleetRequestConfig$,
        { [_xN]: _it }
      ]
    ];
    var SpotFleetRequestIdList = [
      1,
      n032,
      _SFRIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var SpotFleetTagSpecificationList = [
      1,
      n032,
      _SFTSL,
      0,
      [
        () => exports2.SpotFleetTagSpecification$,
        { [_xN]: _it }
      ]
    ];
    var SpotInstanceRequestIdList = [
      1,
      n032,
      _SIRIL,
      0,
      [
        0,
        { [_xN]: _SIRI }
      ]
    ];
    var SpotInstanceRequestList = [
      1,
      n032,
      _SIRL,
      0,
      [
        () => exports2.SpotInstanceRequest$,
        { [_xN]: _it }
      ]
    ];
    var SpotPlacementScores = [
      1,
      n032,
      _SPS,
      0,
      [
        () => exports2.SpotPlacementScore$,
        { [_xN]: _it }
      ]
    ];
    var SpotPriceHistoryList = [
      1,
      n032,
      _SPHL,
      0,
      [
        () => exports2.SpotPrice$,
        { [_xN]: _it }
      ]
    ];
    var StaleIpPermissionSet = [
      1,
      n032,
      _SIPS,
      0,
      [
        () => exports2.StaleIpPermission$,
        { [_xN]: _it }
      ]
    ];
    var StaleSecurityGroupSet = [
      1,
      n032,
      _SSGS,
      0,
      [
        () => exports2.StaleSecurityGroup$,
        { [_xN]: _it }
      ]
    ];
    var StoreImageTaskResultSet = [
      1,
      n032,
      _SITRS,
      0,
      [
        () => exports2.StoreImageTaskResult$,
        { [_xN]: _it }
      ]
    ];
    var StringList = [
      1,
      n032,
      _SLtr,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var SubnetAssociationList = [
      1,
      n032,
      _SAL,
      0,
      [
        () => exports2.SubnetAssociation$,
        { [_xN]: _it }
      ]
    ];
    var SubnetCidrReservationList = [
      1,
      n032,
      _SCRL,
      0,
      [
        () => exports2.SubnetCidrReservation$,
        { [_xN]: _it }
      ]
    ];
    var SubnetConfigurationsList = [
      1,
      n032,
      _SCL,
      0,
      [
        () => exports2.SubnetConfiguration$,
        { [_xN]: _it }
      ]
    ];
    var SubnetIdList = [
      1,
      n032,
      _SILu,
      0,
      [
        0,
        { [_xN]: _ASIs }
      ]
    ];
    var SubnetIdStringList = [
      1,
      n032,
      _SISLu,
      0,
      [
        0,
        { [_xN]: _SIu }
      ]
    ];
    var SubnetIpPrefixesList = [
      1,
      n032,
      _SIPL,
      0,
      [
        () => exports2.SubnetIpPrefixes$,
        { [_xN]: _it }
      ]
    ];
    var SubnetIpv6CidrBlockAssociationSet = [
      1,
      n032,
      _SICBAS,
      0,
      [
        () => exports2.SubnetIpv6CidrBlockAssociation$,
        { [_xN]: _it }
      ]
    ];
    var SubnetList = [
      1,
      n032,
      _SLu,
      0,
      [
        () => exports2.Subnet$,
        { [_xN]: _it }
      ]
    ];
    var SubscriptionList = [
      1,
      n032,
      _SLub,
      0,
      [
        () => exports2.Subscription$,
        { [_xN]: _it }
      ]
    ];
    var SuccessfulInstanceCreditSpecificationSet = [
      1,
      n032,
      _SICSS,
      0,
      [
        () => exports2.SuccessfulInstanceCreditSpecificationItem$,
        { [_xN]: _it }
      ]
    ];
    var SuccessfulQueuedPurchaseDeletionSet = [
      1,
      n032,
      _SQPDS,
      0,
      [
        () => exports2.SuccessfulQueuedPurchaseDeletion$,
        { [_xN]: _it }
      ]
    ];
    var SupportedAdditionalProcessorFeatureList = [
      1,
      n032,
      _SAPFL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var SupportedIpAddressTypes = [
      1,
      n032,
      _SIAT,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var SupportedRegionSet = [
      1,
      n032,
      _SRS,
      0,
      [
        () => exports2.SupportedRegionDetail$,
        { [_xN]: _it }
      ]
    ];
    var TagDescriptionList = [
      1,
      n032,
      _TDL,
      0,
      [
        () => exports2.TagDescription$,
        { [_xN]: _it }
      ]
    ];
    var TagList = [
      1,
      n032,
      _TL,
      0,
      [
        () => exports2.Tag$,
        { [_xN]: _it }
      ]
    ];
    var TagSpecificationList = [
      1,
      n032,
      _TSL,
      0,
      [
        () => exports2.TagSpecification$,
        { [_xN]: _it }
      ]
    ];
    var TargetConfigurationRequestSet = [
      1,
      n032,
      _TCRS,
      0,
      [
        () => exports2.TargetConfigurationRequest$,
        { [_xN]: _TCR }
      ]
    ];
    var TargetGroups = [
      1,
      n032,
      _TGar,
      0,
      [
        () => exports2.TargetGroup$,
        { [_xN]: _it }
      ]
    ];
    var TargetNetworkSet = [
      1,
      n032,
      _TNS,
      0,
      [
        () => exports2.TargetNetwork$,
        { [_xN]: _it }
      ]
    ];
    var TargetReservationValueSet = [
      1,
      n032,
      _TRVS,
      0,
      [
        () => exports2.TargetReservationValue$,
        { [_xN]: _it }
      ]
    ];
    var TerminateConnectionStatusSet = [
      1,
      n032,
      _TCSS,
      0,
      [
        () => exports2.TerminateConnectionStatus$,
        { [_xN]: _it }
      ]
    ];
    var ThreadsPerCoreList = [
      1,
      n032,
      _TPCL,
      0,
      [
        1,
        { [_xN]: _it }
      ]
    ];
    var ThroughResourcesStatementList = [
      1,
      n032,
      _TRSL,
      0,
      [
        () => exports2.ThroughResourcesStatement$,
        { [_xN]: _it }
      ]
    ];
    var ThroughResourcesStatementRequestList = [
      1,
      n032,
      _TRSRL,
      0,
      [
        () => exports2.ThroughResourcesStatementRequest$,
        { [_xN]: _it }
      ]
    ];
    var TrafficMirrorFilterIdList = [
      1,
      n032,
      _TMFIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var TrafficMirrorFilterRuleFieldList = 64 | 0;
    var TrafficMirrorFilterRuleIdList = [
      1,
      n032,
      _TMFRIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var TrafficMirrorFilterRuleList = [
      1,
      n032,
      _TMFRL,
      0,
      [
        () => exports2.TrafficMirrorFilterRule$,
        { [_xN]: _it }
      ]
    ];
    var TrafficMirrorFilterRuleSet = [
      1,
      n032,
      _TMFRS,
      0,
      [
        () => exports2.TrafficMirrorFilterRule$,
        { [_xN]: _it }
      ]
    ];
    var TrafficMirrorFilterSet = [
      1,
      n032,
      _TMFS,
      0,
      [
        () => exports2.TrafficMirrorFilter$,
        { [_xN]: _it }
      ]
    ];
    var TrafficMirrorNetworkServiceList = [
      1,
      n032,
      _TMNSL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var TrafficMirrorSessionFieldList = 64 | 0;
    var TrafficMirrorSessionIdList = [
      1,
      n032,
      _TMSIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var TrafficMirrorSessionSet = [
      1,
      n032,
      _TMSS,
      0,
      [
        () => exports2.TrafficMirrorSession$,
        { [_xN]: _it }
      ]
    ];
    var TrafficMirrorTargetIdList = [
      1,
      n032,
      _TMTIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var TrafficMirrorTargetSet = [
      1,
      n032,
      _TMTS,
      0,
      [
        () => exports2.TrafficMirrorTarget$,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayAttachmentBgpConfigurationList = [
      1,
      n032,
      _TGABCL,
      0,
      [
        () => exports2.TransitGatewayAttachmentBgpConfiguration$,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayAttachmentIdStringList = 64 | 0;
    var TransitGatewayAttachmentList = [
      1,
      n032,
      _TGAL,
      0,
      [
        () => exports2.TransitGatewayAttachment$,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayAttachmentPropagationList = [
      1,
      n032,
      _TGAPL,
      0,
      [
        () => exports2.TransitGatewayAttachmentPropagation$,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayCidrBlockStringList = [
      1,
      n032,
      _TGCBSL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayConnectList = [
      1,
      n032,
      _TGCL,
      0,
      [
        () => exports2.TransitGatewayConnect$,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayConnectPeerIdStringList = [
      1,
      n032,
      _TGCPISL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayConnectPeerList = [
      1,
      n032,
      _TGCPL,
      0,
      [
        () => exports2.TransitGatewayConnectPeer$,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayIdStringList = [
      1,
      n032,
      _TGISL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayList = [
      1,
      n032,
      _TGL,
      0,
      [
        () => exports2.TransitGateway$,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayMeteringPolicyEntryList = [
      1,
      n032,
      _TGMPEL,
      0,
      [
        () => exports2.TransitGatewayMeteringPolicyEntry$,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayMeteringPolicyIdStringList = [
      1,
      n032,
      _TGMPISL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayMeteringPolicyList = [
      1,
      n032,
      _TGMPL,
      0,
      [
        () => exports2.TransitGatewayMeteringPolicy$,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayMulticastDomainAssociationList = [
      1,
      n032,
      _TGMDAL,
      0,
      [
        () => exports2.TransitGatewayMulticastDomainAssociation$,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayMulticastDomainIdStringList = [
      1,
      n032,
      _TGMDISL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayMulticastDomainList = [
      1,
      n032,
      _TGMDL,
      0,
      [
        () => exports2.TransitGatewayMulticastDomain$,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayMulticastGroupList = [
      1,
      n032,
      _TGMGL,
      0,
      [
        () => exports2.TransitGatewayMulticastGroup$,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayNetworkInterfaceIdList = [
      1,
      n032,
      _TGNIIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayPeeringAttachmentList = [
      1,
      n032,
      _TGPAL,
      0,
      [
        () => exports2.TransitGatewayPeeringAttachment$,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayPolicyTableAssociationList = [
      1,
      n032,
      _TGPTAL,
      0,
      [
        () => exports2.TransitGatewayPolicyTableAssociation$,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayPolicyTableEntryList = [
      1,
      n032,
      _TGPTEL,
      0,
      [
        () => exports2.TransitGatewayPolicyTableEntry$,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayPolicyTableIdStringList = [
      1,
      n032,
      _TGPTISL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayPolicyTableList = [
      1,
      n032,
      _TGPTL,
      0,
      [
        () => exports2.TransitGatewayPolicyTable$,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayPrefixListReferenceSet = [
      1,
      n032,
      _TGPLRS,
      0,
      [
        () => exports2.TransitGatewayPrefixListReference$,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayRouteAttachmentList = [
      1,
      n032,
      _TGRAL,
      0,
      [
        () => exports2.TransitGatewayRouteAttachment$,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayRouteList = [
      1,
      n032,
      _TGRL,
      0,
      [
        () => exports2.TransitGatewayRoute$,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayRouteTableAnnouncementIdStringList = [
      1,
      n032,
      _TGRTAISL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayRouteTableAnnouncementList = [
      1,
      n032,
      _TGRTAL,
      0,
      [
        () => exports2.TransitGatewayRouteTableAnnouncement$,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayRouteTableAssociationList = [
      1,
      n032,
      _TGRTALr,
      0,
      [
        () => exports2.TransitGatewayRouteTableAssociation$,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayRouteTableIdStringList = [
      1,
      n032,
      _TGRTISL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayRouteTableList = [
      1,
      n032,
      _TGRTL,
      0,
      [
        () => exports2.TransitGatewayRouteTable$,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayRouteTablePropagationList = [
      1,
      n032,
      _TGRTPL,
      0,
      [
        () => exports2.TransitGatewayRouteTablePropagation$,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewaySubnetIdList = [
      1,
      n032,
      _TGSIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var TransitGatewayVpcAttachmentList = [
      1,
      n032,
      _TGVAL,
      0,
      [
        () => exports2.TransitGatewayVpcAttachment$,
        { [_xN]: _it }
      ]
    ];
    var TrunkInterfaceAssociationIdList = [
      1,
      n032,
      _TIAIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var TrunkInterfaceAssociationList = [
      1,
      n032,
      _TIAL,
      0,
      [
        () => exports2.TrunkInterfaceAssociation$,
        { [_xN]: _it }
      ]
    ];
    var TunnelOptionsList = [
      1,
      n032,
      _TOL,
      0,
      [
        () => exports2.TunnelOption$,
        { [_xN]: _it }
      ]
    ];
    var UnsuccessfulInstanceCreditSpecificationSet = [
      1,
      n032,
      _UICSS,
      0,
      [
        () => exports2.UnsuccessfulInstanceCreditSpecificationItem$,
        { [_xN]: _it }
      ]
    ];
    var UnsuccessfulItemList = [
      1,
      n032,
      _UIL,
      0,
      [
        () => exports2.UnsuccessfulItem$,
        { [_xN]: _it }
      ]
    ];
    var UnsuccessfulItemSet = [
      1,
      n032,
      _UIS,
      0,
      [
        () => exports2.UnsuccessfulItem$,
        { [_xN]: _it }
      ]
    ];
    var UsageClassTypeList = [
      1,
      n032,
      _UCTL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var UserGroupStringList = [
      1,
      n032,
      _UGSL,
      0,
      [
        0,
        { [_xN]: _UGs }
      ]
    ];
    var UserIdGroupPairList = [
      1,
      n032,
      _UIGPL,
      0,
      [
        () => exports2.UserIdGroupPair$,
        { [_xN]: _it }
      ]
    ];
    var UserIdGroupPairSet = [
      1,
      n032,
      _UIGPS,
      0,
      [
        () => exports2.UserIdGroupPair$,
        { [_xN]: _it }
      ]
    ];
    var UserIdList = [
      1,
      n032,
      _UILs,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var UserIdStringList = [
      1,
      n032,
      _UISL,
      0,
      [
        0,
        { [_xN]: _UI }
      ]
    ];
    var ValueStringList = [
      1,
      n032,
      _VSL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var VerifiedAccessEndpointIdList = [
      1,
      n032,
      _VAEIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var VerifiedAccessEndpointList = [
      1,
      n032,
      _VAEL,
      0,
      [
        () => exports2.VerifiedAccessEndpoint$,
        { [_xN]: _it }
      ]
    ];
    var VerifiedAccessEndpointPortRangeList = [
      1,
      n032,
      _VAEPRL,
      0,
      [
        () => exports2.VerifiedAccessEndpointPortRange$,
        { [_xN]: _it }
      ]
    ];
    var VerifiedAccessEndpointSubnetIdList = [
      1,
      n032,
      _VAESIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var VerifiedAccessEndpointTargetList = [
      1,
      n032,
      _VAETL,
      0,
      [
        () => exports2.VerifiedAccessEndpointTarget$,
        { [_xN]: _it }
      ]
    ];
    var VerifiedAccessGroupIdList = [
      1,
      n032,
      _VAGIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var VerifiedAccessGroupList = [
      1,
      n032,
      _VAGL,
      0,
      [
        () => exports2.VerifiedAccessGroup$,
        { [_xN]: _it }
      ]
    ];
    var VerifiedAccessInstanceIdList = [
      1,
      n032,
      _VAIIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var VerifiedAccessInstanceList = [
      1,
      n032,
      _VAIL,
      0,
      [
        () => exports2.VerifiedAccessInstance$,
        { [_xN]: _it }
      ]
    ];
    var VerifiedAccessInstanceLoggingConfigurationList = [
      1,
      n032,
      _VAILCL,
      0,
      [
        () => exports2.VerifiedAccessInstanceLoggingConfiguration$,
        { [_xN]: _it }
      ]
    ];
    var VerifiedAccessInstanceOpenVpnClientConfigurationList = [
      1,
      n032,
      _VAIOVCCL,
      0,
      [
        () => exports2.VerifiedAccessInstanceOpenVpnClientConfiguration$,
        { [_xN]: _it }
      ]
    ];
    var VerifiedAccessInstanceOpenVpnClientConfigurationRouteList = [
      1,
      n032,
      _VAIOVCCRL,
      0,
      [
        () => exports2.VerifiedAccessInstanceOpenVpnClientConfigurationRoute$,
        { [_xN]: _it }
      ]
    ];
    var VerifiedAccessTrustProviderCondensedList = [
      1,
      n032,
      _VATPCL,
      0,
      [
        () => exports2.VerifiedAccessTrustProviderCondensed$,
        { [_xN]: _it }
      ]
    ];
    var VerifiedAccessTrustProviderIdList = [
      1,
      n032,
      _VATPIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var VerifiedAccessTrustProviderList = [
      1,
      n032,
      _VATPL,
      0,
      [
        () => exports2.VerifiedAccessTrustProvider$,
        { [_xN]: _it }
      ]
    ];
    var VersionStringList = [
      1,
      n032,
      _VSLe,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var VgwTelemetryList = [
      1,
      n032,
      _VTL,
      0,
      [
        () => exports2.VgwTelemetry$,
        { [_xN]: _it }
      ]
    ];
    var VirtualizationTypeList = [
      1,
      n032,
      _VTLi,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var VirtualizationTypeSet = [
      1,
      n032,
      _VTS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var VolumeAttachmentList = [
      1,
      n032,
      _VALo,
      0,
      [
        () => exports2.VolumeAttachment$,
        { [_xN]: _it }
      ]
    ];
    var VolumeIdStringList = [
      1,
      n032,
      _VISL,
      0,
      [
        0,
        { [_xN]: _VIo }
      ]
    ];
    var VolumeList = [
      1,
      n032,
      _VLo,
      0,
      [
        () => exports2.Volume$,
        { [_xN]: _it }
      ]
    ];
    var VolumeModificationList = [
      1,
      n032,
      _VML,
      0,
      [
        () => exports2.VolumeModification$,
        { [_xN]: _it }
      ]
    ];
    var VolumeRecycleBinInfoList = [
      1,
      n032,
      _VRBIL,
      0,
      [
        () => exports2.VolumeRecycleBinInfo$,
        { [_xN]: _it }
      ]
    ];
    var VolumeStatusActionsList = [
      1,
      n032,
      _VSAL,
      0,
      [
        () => exports2.VolumeStatusAction$,
        { [_xN]: _it }
      ]
    ];
    var VolumeStatusAttachmentStatusList = [
      1,
      n032,
      _VSASL,
      0,
      [
        () => exports2.VolumeStatusAttachmentStatus$,
        { [_xN]: _it }
      ]
    ];
    var VolumeStatusDetailsList = [
      1,
      n032,
      _VSDL,
      0,
      [
        () => exports2.VolumeStatusDetails$,
        { [_xN]: _it }
      ]
    ];
    var VolumeStatusEventsList = [
      1,
      n032,
      _VSEL,
      0,
      [
        () => exports2.VolumeStatusEvent$,
        { [_xN]: _it }
      ]
    ];
    var VolumeStatusList = [
      1,
      n032,
      _VSLo,
      0,
      [
        () => exports2.VolumeStatusItem$,
        { [_xN]: _it }
      ]
    ];
    var VpcAttachmentList = [
      1,
      n032,
      _VALp,
      0,
      [
        () => exports2.VpcAttachment$,
        { [_xN]: _it }
      ]
    ];
    var VpcBlockPublicAccessExclusionIdList = [
      1,
      n032,
      _VBPAEIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var VpcBlockPublicAccessExclusionList = [
      1,
      n032,
      _VBPAEL,
      0,
      [
        () => exports2.VpcBlockPublicAccessExclusion$,
        { [_xN]: _it }
      ]
    ];
    var VpcCidrBlockAssociationSet = [
      1,
      n032,
      _VCBAS,
      0,
      [
        () => exports2.VpcCidrBlockAssociation$,
        { [_xN]: _it }
      ]
    ];
    var VpcClassicLinkIdList = [
      1,
      n032,
      _VCLIL,
      0,
      [
        0,
        { [_xN]: _VI }
      ]
    ];
    var VpcClassicLinkList = [
      1,
      n032,
      _VCLL,
      0,
      [
        () => exports2.VpcClassicLink$,
        { [_xN]: _it }
      ]
    ];
    var VpcEncryptionControlIdList = [
      1,
      n032,
      _VECIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var VpcEncryptionControlList = [
      1,
      n032,
      _VECL,
      0,
      [
        () => exports2.VpcEncryptionControl$,
        { [_xN]: _it }
      ]
    ];
    var VpcEncryptionNonCompliantResourceList = [
      1,
      n032,
      _VENCRL,
      0,
      [
        () => exports2.VpcEncryptionNonCompliantResource$,
        { [_xN]: _it }
      ]
    ];
    var VpcEndpointAssociationSet = [
      1,
      n032,
      _VEAS,
      0,
      [
        () => exports2.VpcEndpointAssociation$,
        { [_xN]: _it }
      ]
    ];
    var VpcEndpointConnectionSet = [
      1,
      n032,
      _VECS,
      0,
      [
        () => exports2.VpcEndpointConnection$,
        { [_xN]: _it }
      ]
    ];
    var VpcEndpointIdList = [
      1,
      n032,
      _VEIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var VpcEndpointRouteTableIdList = [
      1,
      n032,
      _VERTIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var VpcEndpointSecurityGroupIdList = [
      1,
      n032,
      _VESGIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var VpcEndpointServiceIdList = [
      1,
      n032,
      _VESIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var VpcEndpointSet = [
      1,
      n032,
      _VESpcn,
      0,
      [
        () => exports2.VpcEndpoint$,
        { [_xN]: _it }
      ]
    ];
    var VpcEndpointSubnetIdList = [
      1,
      n032,
      _VESILp,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var VpcIdStringList = [
      1,
      n032,
      _VISLp,
      0,
      [
        0,
        { [_xN]: _VI }
      ]
    ];
    var VpcIpv6CidrBlockAssociationSet = [
      1,
      n032,
      _VICBAS,
      0,
      [
        () => exports2.VpcIpv6CidrBlockAssociation$,
        { [_xN]: _it }
      ]
    ];
    var VpcList = [
      1,
      n032,
      _VLp,
      0,
      [
        () => exports2.Vpc$,
        { [_xN]: _it }
      ]
    ];
    var VpcPeeringConnectionIdList = [
      1,
      n032,
      _VPCIL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var VpcPeeringConnectionList = [
      1,
      n032,
      _VPCL,
      0,
      [
        () => exports2.VpcPeeringConnection$,
        { [_xN]: _it }
      ]
    ];
    var VpnConcentratorIdStringList = [
      1,
      n032,
      _VCISL,
      0,
      [
        0,
        { [_xN]: _VCI }
      ]
    ];
    var VpnConcentratorList = [
      1,
      n032,
      _VCLp,
      0,
      [
        () => exports2.VpnConcentrator$,
        { [_xN]: _it }
      ]
    ];
    var VpnConnectionDeviceTypeList = [
      1,
      n032,
      _VCDTL,
      0,
      [
        () => exports2.VpnConnectionDeviceType$,
        { [_xN]: _it }
      ]
    ];
    var VpnConnectionIdStringList = [
      1,
      n032,
      _VCISLp,
      0,
      [
        0,
        { [_xN]: _VCIp }
      ]
    ];
    var VpnConnectionList = [
      1,
      n032,
      _VCLpn,
      0,
      [
        () => exports2.VpnConnection$,
        { [_xN]: _it }
      ]
    ];
    var VpnGatewayIdStringList = [
      1,
      n032,
      _VGISL,
      0,
      [
        0,
        { [_xN]: _VGI }
      ]
    ];
    var VpnGatewayList = [
      1,
      n032,
      _VGL,
      0,
      [
        () => exports2.VpnGateway$,
        { [_xN]: _it }
      ]
    ];
    var VpnStaticRouteList = [
      1,
      n032,
      _VSRL,
      0,
      [
        () => exports2.VpnStaticRoute$,
        { [_xN]: _it }
      ]
    ];
    var VpnTunnelOptionsSpecificationsList = [
      1,
      n032,
      _VTOSL,
      0,
      [
        () => exports2.VpnTunnelOptionsSpecification$,
        0
      ]
    ];
    var WorkloadsList = [
      1,
      n032,
      _WL,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var ZoneIdStringList = [
      1,
      n032,
      _ZISL,
      0,
      [
        0,
        { [_xN]: _ZI }
      ]
    ];
    var ZoneNameStringList = [
      1,
      n032,
      _ZNSL,
      0,
      [
        0,
        { [_xN]: _ZN }
      ]
    ];
    exports2.AcceptAddressTransfer$ = [
      9,
      n032,
      _AAT,
      0,
      () => exports2.AcceptAddressTransferRequest$,
      () => exports2.AcceptAddressTransferResult$
    ];
    exports2.AcceptCapacityReservationBillingOwnership$ = [
      9,
      n032,
      _ACRBO,
      0,
      () => exports2.AcceptCapacityReservationBillingOwnershipRequest$,
      () => exports2.AcceptCapacityReservationBillingOwnershipResult$
    ];
    exports2.AcceptReservedInstancesExchangeQuote$ = [
      9,
      n032,
      _ARIEQ,
      0,
      () => exports2.AcceptReservedInstancesExchangeQuoteRequest$,
      () => exports2.AcceptReservedInstancesExchangeQuoteResult$
    ];
    exports2.AcceptTransitGatewayClientVpnAttachment$ = [
      9,
      n032,
      _ATGCVA,
      0,
      () => exports2.AcceptTransitGatewayClientVpnAttachmentRequest$,
      () => exports2.AcceptTransitGatewayClientVpnAttachmentResult$
    ];
    exports2.AcceptTransitGatewayMulticastDomainAssociations$ = [
      9,
      n032,
      _ATGMDA,
      0,
      () => exports2.AcceptTransitGatewayMulticastDomainAssociationsRequest$,
      () => exports2.AcceptTransitGatewayMulticastDomainAssociationsResult$
    ];
    exports2.AcceptTransitGatewayPeeringAttachment$ = [
      9,
      n032,
      _ATGPA,
      0,
      () => exports2.AcceptTransitGatewayPeeringAttachmentRequest$,
      () => exports2.AcceptTransitGatewayPeeringAttachmentResult$
    ];
    exports2.AcceptTransitGatewayVpcAttachment$ = [
      9,
      n032,
      _ATGVA,
      0,
      () => exports2.AcceptTransitGatewayVpcAttachmentRequest$,
      () => exports2.AcceptTransitGatewayVpcAttachmentResult$
    ];
    exports2.AcceptVpcEndpointConnections$ = [
      9,
      n032,
      _AVEC,
      0,
      () => exports2.AcceptVpcEndpointConnectionsRequest$,
      () => exports2.AcceptVpcEndpointConnectionsResult$
    ];
    exports2.AcceptVpcPeeringConnection$ = [
      9,
      n032,
      _AVPC,
      0,
      () => exports2.AcceptVpcPeeringConnectionRequest$,
      () => exports2.AcceptVpcPeeringConnectionResult$
    ];
    exports2.AdvertiseByoipCidr$ = [
      9,
      n032,
      _ABC,
      0,
      () => exports2.AdvertiseByoipCidrRequest$,
      () => exports2.AdvertiseByoipCidrResult$
    ];
    exports2.AllocateAddress$ = [
      9,
      n032,
      _AAl,
      0,
      () => exports2.AllocateAddressRequest$,
      () => exports2.AllocateAddressResult$
    ];
    exports2.AllocateHosts$ = [
      9,
      n032,
      _AH,
      0,
      () => exports2.AllocateHostsRequest$,
      () => exports2.AllocateHostsResult$
    ];
    exports2.AllocateIpamPoolCidr$ = [
      9,
      n032,
      _AIPC,
      0,
      () => exports2.AllocateIpamPoolCidrRequest$,
      () => exports2.AllocateIpamPoolCidrResult$
    ];
    exports2.ApplySecurityGroupsToClientVpnTargetNetwork$ = [
      9,
      n032,
      _ASGTCVTN,
      0,
      () => exports2.ApplySecurityGroupsToClientVpnTargetNetworkRequest$,
      () => exports2.ApplySecurityGroupsToClientVpnTargetNetworkResult$
    ];
    exports2.AssignIpv6Addresses$ = [
      9,
      n032,
      _AIAs,
      0,
      () => exports2.AssignIpv6AddressesRequest$,
      () => exports2.AssignIpv6AddressesResult$
    ];
    exports2.AssignPrivateIpAddresses$ = [
      9,
      n032,
      _APIAssi,
      0,
      () => exports2.AssignPrivateIpAddressesRequest$,
      () => exports2.AssignPrivateIpAddressesResult$
    ];
    exports2.AssignPrivateNatGatewayAddress$ = [
      9,
      n032,
      _APNGA,
      0,
      () => exports2.AssignPrivateNatGatewayAddressRequest$,
      () => exports2.AssignPrivateNatGatewayAddressResult$
    ];
    exports2.AssociateAddress$ = [
      9,
      n032,
      _AAss,
      0,
      () => exports2.AssociateAddressRequest$,
      () => exports2.AssociateAddressResult$
    ];
    exports2.AssociateCapacityReservationBillingOwner$ = [
      9,
      n032,
      _ACRBOs,
      0,
      () => exports2.AssociateCapacityReservationBillingOwnerRequest$,
      () => exports2.AssociateCapacityReservationBillingOwnerResult$
    ];
    exports2.AssociateClientVpnTargetNetwork$ = [
      9,
      n032,
      _ACVTN,
      0,
      () => exports2.AssociateClientVpnTargetNetworkRequest$,
      () => exports2.AssociateClientVpnTargetNetworkResult$
    ];
    exports2.AssociateDhcpOptions$ = [
      9,
      n032,
      _ADO,
      0,
      () => exports2.AssociateDhcpOptionsRequest$,
      () => __Unit
    ];
    exports2.AssociateEnclaveCertificateIamRole$ = [
      9,
      n032,
      _AECIR,
      0,
      () => exports2.AssociateEnclaveCertificateIamRoleRequest$,
      () => exports2.AssociateEnclaveCertificateIamRoleResult$
    ];
    exports2.AssociateIamInstanceProfile$ = [
      9,
      n032,
      _AIIP,
      0,
      () => exports2.AssociateIamInstanceProfileRequest$,
      () => exports2.AssociateIamInstanceProfileResult$
    ];
    exports2.AssociateInstanceEventWindow$ = [
      9,
      n032,
      _AIEW,
      0,
      () => exports2.AssociateInstanceEventWindowRequest$,
      () => exports2.AssociateInstanceEventWindowResult$
    ];
    exports2.AssociateIpamByoasn$ = [
      9,
      n032,
      _AIB,
      0,
      () => exports2.AssociateIpamByoasnRequest$,
      () => exports2.AssociateIpamByoasnResult$
    ];
    exports2.AssociateIpamResourceDiscovery$ = [
      9,
      n032,
      _AIRD,
      0,
      () => exports2.AssociateIpamResourceDiscoveryRequest$,
      () => exports2.AssociateIpamResourceDiscoveryResult$
    ];
    exports2.AssociateNatGatewayAddress$ = [
      9,
      n032,
      _ANGA,
      0,
      () => exports2.AssociateNatGatewayAddressRequest$,
      () => exports2.AssociateNatGatewayAddressResult$
    ];
    exports2.AssociateRouteServer$ = [
      9,
      n032,
      _ARSs,
      0,
      () => exports2.AssociateRouteServerRequest$,
      () => exports2.AssociateRouteServerResult$
    ];
    exports2.AssociateRouteTable$ = [
      9,
      n032,
      _ARTs,
      0,
      () => exports2.AssociateRouteTableRequest$,
      () => exports2.AssociateRouteTableResult$
    ];
    exports2.AssociateSecurityGroupVpc$ = [
      9,
      n032,
      _ASGV,
      0,
      () => exports2.AssociateSecurityGroupVpcRequest$,
      () => exports2.AssociateSecurityGroupVpcResult$
    ];
    exports2.AssociateSubnetCidrBlock$ = [
      9,
      n032,
      _ASCB,
      0,
      () => exports2.AssociateSubnetCidrBlockRequest$,
      () => exports2.AssociateSubnetCidrBlockResult$
    ];
    exports2.AssociateTransitGatewayMulticastDomain$ = [
      9,
      n032,
      _ATGMD,
      0,
      () => exports2.AssociateTransitGatewayMulticastDomainRequest$,
      () => exports2.AssociateTransitGatewayMulticastDomainResult$
    ];
    exports2.AssociateTransitGatewayPolicyTable$ = [
      9,
      n032,
      _ATGPT,
      0,
      () => exports2.AssociateTransitGatewayPolicyTableRequest$,
      () => exports2.AssociateTransitGatewayPolicyTableResult$
    ];
    exports2.AssociateTransitGatewayRouteTable$ = [
      9,
      n032,
      _ATGRT,
      0,
      () => exports2.AssociateTransitGatewayRouteTableRequest$,
      () => exports2.AssociateTransitGatewayRouteTableResult$
    ];
    exports2.AssociateTrunkInterface$ = [
      9,
      n032,
      _ATIs,
      0,
      () => exports2.AssociateTrunkInterfaceRequest$,
      () => exports2.AssociateTrunkInterfaceResult$
    ];
    exports2.AssociateVpcCidrBlock$ = [
      9,
      n032,
      _AVCB,
      0,
      () => exports2.AssociateVpcCidrBlockRequest$,
      () => exports2.AssociateVpcCidrBlockResult$
    ];
    exports2.AttachClassicLinkVpc$ = [
      9,
      n032,
      _ACLV,
      0,
      () => exports2.AttachClassicLinkVpcRequest$,
      () => exports2.AttachClassicLinkVpcResult$
    ];
    exports2.AttachInternetGateway$ = [
      9,
      n032,
      _AIG,
      0,
      () => exports2.AttachInternetGatewayRequest$,
      () => __Unit
    ];
    exports2.AttachNetworkInterface$ = [
      9,
      n032,
      _ANI,
      0,
      () => exports2.AttachNetworkInterfaceRequest$,
      () => exports2.AttachNetworkInterfaceResult$
    ];
    exports2.AttachVerifiedAccessTrustProvider$ = [
      9,
      n032,
      _AVATP,
      0,
      () => exports2.AttachVerifiedAccessTrustProviderRequest$,
      () => exports2.AttachVerifiedAccessTrustProviderResult$
    ];
    exports2.AttachVolume$ = [
      9,
      n032,
      _AVtt,
      0,
      () => exports2.AttachVolumeRequest$,
      () => exports2.VolumeAttachment$
    ];
    exports2.AttachVpnGateway$ = [
      9,
      n032,
      _AVG,
      0,
      () => exports2.AttachVpnGatewayRequest$,
      () => exports2.AttachVpnGatewayResult$
    ];
    exports2.AuthorizeClientVpnIngress$ = [
      9,
      n032,
      _ACVI,
      0,
      () => exports2.AuthorizeClientVpnIngressRequest$,
      () => exports2.AuthorizeClientVpnIngressResult$
    ];
    exports2.AuthorizeSecurityGroupEgress$ = [
      9,
      n032,
      _ASGE,
      0,
      () => exports2.AuthorizeSecurityGroupEgressRequest$,
      () => exports2.AuthorizeSecurityGroupEgressResult$
    ];
    exports2.AuthorizeSecurityGroupIngress$ = [
      9,
      n032,
      _ASGIu,
      0,
      () => exports2.AuthorizeSecurityGroupIngressRequest$,
      () => exports2.AuthorizeSecurityGroupIngressResult$
    ];
    exports2.BundleInstance$ = [
      9,
      n032,
      _BIun,
      0,
      () => exports2.BundleInstanceRequest$,
      () => exports2.BundleInstanceResult$
    ];
    exports2.CancelBundleTask$ = [
      9,
      n032,
      _CBT,
      0,
      () => exports2.CancelBundleTaskRequest$,
      () => exports2.CancelBundleTaskResult$
    ];
    exports2.CancelCapacityReservation$ = [
      9,
      n032,
      _CCRa,
      0,
      () => exports2.CancelCapacityReservationRequest$,
      () => exports2.CancelCapacityReservationResult$
    ];
    exports2.CancelCapacityReservationFleets$ = [
      9,
      n032,
      _CCRF,
      0,
      () => exports2.CancelCapacityReservationFleetsRequest$,
      () => exports2.CancelCapacityReservationFleetsResult$
    ];
    exports2.CancelConversionTask$ = [
      9,
      n032,
      _CCT,
      0,
      () => exports2.CancelConversionRequest$,
      () => __Unit
    ];
    exports2.CancelDeclarativePoliciesReport$ = [
      9,
      n032,
      _CDPR,
      0,
      () => exports2.CancelDeclarativePoliciesReportRequest$,
      () => exports2.CancelDeclarativePoliciesReportResult$
    ];
    exports2.CancelExportTask$ = [
      9,
      n032,
      _CETa,
      0,
      () => exports2.CancelExportTaskRequest$,
      () => __Unit
    ];
    exports2.CancelImageLaunchPermission$ = [
      9,
      n032,
      _CILP,
      0,
      () => exports2.CancelImageLaunchPermissionRequest$,
      () => exports2.CancelImageLaunchPermissionResult$
    ];
    exports2.CancelImportTask$ = [
      9,
      n032,
      _CITa,
      0,
      () => exports2.CancelImportTaskRequest$,
      () => exports2.CancelImportTaskResult$
    ];
    exports2.CancelReservedInstancesListing$ = [
      9,
      n032,
      _CRIL,
      0,
      () => exports2.CancelReservedInstancesListingRequest$,
      () => exports2.CancelReservedInstancesListingResult$
    ];
    exports2.CancelSpotFleetRequests$ = [
      9,
      n032,
      _CSFR,
      0,
      () => exports2.CancelSpotFleetRequestsRequest$,
      () => exports2.CancelSpotFleetRequestsResponse$
    ];
    exports2.CancelSpotInstanceRequests$ = [
      9,
      n032,
      _CSIRan,
      0,
      () => exports2.CancelSpotInstanceRequestsRequest$,
      () => exports2.CancelSpotInstanceRequestsResult$
    ];
    exports2.ConfirmProductInstance$ = [
      9,
      n032,
      _CPIo,
      0,
      () => exports2.ConfirmProductInstanceRequest$,
      () => exports2.ConfirmProductInstanceResult$
    ];
    exports2.CopyFpgaImage$ = [
      9,
      n032,
      _CFIo,
      0,
      () => exports2.CopyFpgaImageRequest$,
      () => exports2.CopyFpgaImageResult$
    ];
    exports2.CopyImage$ = [
      9,
      n032,
      _CIopy,
      0,
      () => exports2.CopyImageRequest$,
      () => exports2.CopyImageResult$
    ];
    exports2.CopySnapshot$ = [
      9,
      n032,
      _CSop,
      0,
      () => exports2.CopySnapshotRequest$,
      () => exports2.CopySnapshotResult$
    ];
    exports2.CopyVolumes$ = [
      9,
      n032,
      _CVo,
      0,
      () => exports2.CopyVolumesRequest$,
      () => exports2.CopyVolumesResult$
    ];
    exports2.CreateCapacityManagerDataExport$ = [
      9,
      n032,
      _CCMDE,
      0,
      () => exports2.CreateCapacityManagerDataExportRequest$,
      () => exports2.CreateCapacityManagerDataExportResult$
    ];
    exports2.CreateCapacityReservation$ = [
      9,
      n032,
      _CCRr,
      0,
      () => exports2.CreateCapacityReservationRequest$,
      () => exports2.CreateCapacityReservationResult$
    ];
    exports2.CreateCapacityReservationBySplitting$ = [
      9,
      n032,
      _CCRBS,
      0,
      () => exports2.CreateCapacityReservationBySplittingRequest$,
      () => exports2.CreateCapacityReservationBySplittingResult$
    ];
    exports2.CreateCapacityReservationFleet$ = [
      9,
      n032,
      _CCRFr,
      0,
      () => exports2.CreateCapacityReservationFleetRequest$,
      () => exports2.CreateCapacityReservationFleetResult$
    ];
    exports2.CreateCarrierGateway$ = [
      9,
      n032,
      _CCG,
      0,
      () => exports2.CreateCarrierGatewayRequest$,
      () => exports2.CreateCarrierGatewayResult$
    ];
    exports2.CreateClientVpnEndpoint$ = [
      9,
      n032,
      _CCVE,
      0,
      () => exports2.CreateClientVpnEndpointRequest$,
      () => exports2.CreateClientVpnEndpointResult$
    ];
    exports2.CreateClientVpnRoute$ = [
      9,
      n032,
      _CCVR,
      0,
      () => exports2.CreateClientVpnRouteRequest$,
      () => exports2.CreateClientVpnRouteResult$
    ];
    exports2.CreateCoipCidr$ = [
      9,
      n032,
      _CCC,
      0,
      () => exports2.CreateCoipCidrRequest$,
      () => exports2.CreateCoipCidrResult$
    ];
    exports2.CreateCoipPool$ = [
      9,
      n032,
      _CCP,
      0,
      () => exports2.CreateCoipPoolRequest$,
      () => exports2.CreateCoipPoolResult$
    ];
    exports2.CreateCustomerGateway$ = [
      9,
      n032,
      _CCGr,
      0,
      () => exports2.CreateCustomerGatewayRequest$,
      () => exports2.CreateCustomerGatewayResult$
    ];
    exports2.CreateDefaultSubnet$ = [
      9,
      n032,
      _CDSr,
      0,
      () => exports2.CreateDefaultSubnetRequest$,
      () => exports2.CreateDefaultSubnetResult$
    ];
    exports2.CreateDefaultVpc$ = [
      9,
      n032,
      _CDV,
      0,
      () => exports2.CreateDefaultVpcRequest$,
      () => exports2.CreateDefaultVpcResult$
    ];
    exports2.CreateDelegateMacVolumeOwnershipTask$ = [
      9,
      n032,
      _CDMVOT,
      0,
      () => exports2.CreateDelegateMacVolumeOwnershipTaskRequest$,
      () => exports2.CreateDelegateMacVolumeOwnershipTaskResult$
    ];
    exports2.CreateDhcpOptions$ = [
      9,
      n032,
      _CDO,
      0,
      () => exports2.CreateDhcpOptionsRequest$,
      () => exports2.CreateDhcpOptionsResult$
    ];
    exports2.CreateEgressOnlyInternetGateway$ = [
      9,
      n032,
      _CEOIG,
      0,
      () => exports2.CreateEgressOnlyInternetGatewayRequest$,
      () => exports2.CreateEgressOnlyInternetGatewayResult$
    ];
    exports2.CreateFleet$ = [
      9,
      n032,
      _CFr,
      0,
      () => exports2.CreateFleetRequest$,
      () => exports2.CreateFleetResult$
    ];
    exports2.CreateFlowLogs$ = [
      9,
      n032,
      _CFL,
      0,
      () => exports2.CreateFlowLogsRequest$,
      () => exports2.CreateFlowLogsResult$
    ];
    exports2.CreateFpgaImage$ = [
      9,
      n032,
      _CFIr,
      0,
      () => exports2.CreateFpgaImageRequest$,
      () => exports2.CreateFpgaImageResult$
    ];
    exports2.CreateImage$ = [
      9,
      n032,
      _CIr,
      0,
      () => exports2.CreateImageRequest$,
      () => exports2.CreateImageResult$
    ];
    exports2.CreateImageUsageReport$ = [
      9,
      n032,
      _CIUR,
      0,
      () => exports2.CreateImageUsageReportRequest$,
      () => exports2.CreateImageUsageReportResult$
    ];
    exports2.CreateInstanceConnectEndpoint$ = [
      9,
      n032,
      _CICE,
      0,
      () => exports2.CreateInstanceConnectEndpointRequest$,
      () => exports2.CreateInstanceConnectEndpointResult$
    ];
    exports2.CreateInstanceEventWindow$ = [
      9,
      n032,
      _CIEW,
      0,
      () => exports2.CreateInstanceEventWindowRequest$,
      () => exports2.CreateInstanceEventWindowResult$
    ];
    exports2.CreateInstanceExportTask$ = [
      9,
      n032,
      _CIET,
      0,
      () => exports2.CreateInstanceExportTaskRequest$,
      () => exports2.CreateInstanceExportTaskResult$
    ];
    exports2.CreateInternetGateway$ = [
      9,
      n032,
      _CIG,
      0,
      () => exports2.CreateInternetGatewayRequest$,
      () => exports2.CreateInternetGatewayResult$
    ];
    exports2.CreateInterruptibleCapacityReservationAllocation$ = [
      9,
      n032,
      _CICRA,
      0,
      () => exports2.CreateInterruptibleCapacityReservationAllocationRequest$,
      () => exports2.CreateInterruptibleCapacityReservationAllocationResult$
    ];
    exports2.CreateIpam$ = [
      9,
      n032,
      _CIre,
      0,
      () => exports2.CreateIpamRequest$,
      () => exports2.CreateIpamResult$
    ];
    exports2.CreateIpamExternalResourceVerificationToken$ = [
      9,
      n032,
      _CIERVT,
      0,
      () => exports2.CreateIpamExternalResourceVerificationTokenRequest$,
      () => exports2.CreateIpamExternalResourceVerificationTokenResult$
    ];
    exports2.CreateIpamPolicy$ = [
      9,
      n032,
      _CIP,
      0,
      () => exports2.CreateIpamPolicyRequest$,
      () => exports2.CreateIpamPolicyResult$
    ];
    exports2.CreateIpamPool$ = [
      9,
      n032,
      _CIPr,
      0,
      () => exports2.CreateIpamPoolRequest$,
      () => exports2.CreateIpamPoolResult$
    ];
    exports2.CreateIpamPrefixListResolver$ = [
      9,
      n032,
      _CIPLR,
      0,
      () => exports2.CreateIpamPrefixListResolverRequest$,
      () => exports2.CreateIpamPrefixListResolverResult$
    ];
    exports2.CreateIpamPrefixListResolverTarget$ = [
      9,
      n032,
      _CIPLRT,
      0,
      () => exports2.CreateIpamPrefixListResolverTargetRequest$,
      () => exports2.CreateIpamPrefixListResolverTargetResult$
    ];
    exports2.CreateIpamResourceDiscovery$ = [
      9,
      n032,
      _CIRD,
      0,
      () => exports2.CreateIpamResourceDiscoveryRequest$,
      () => exports2.CreateIpamResourceDiscoveryResult$
    ];
    exports2.CreateIpamScope$ = [
      9,
      n032,
      _CIS,
      0,
      () => exports2.CreateIpamScopeRequest$,
      () => exports2.CreateIpamScopeResult$
    ];
    exports2.CreateKeyPair$ = [
      9,
      n032,
      _CKP,
      0,
      () => exports2.CreateKeyPairRequest$,
      () => exports2.KeyPair$
    ];
    exports2.CreateLaunchTemplate$ = [
      9,
      n032,
      _CLT,
      0,
      () => exports2.CreateLaunchTemplateRequest$,
      () => exports2.CreateLaunchTemplateResult$
    ];
    exports2.CreateLaunchTemplateVersion$ = [
      9,
      n032,
      _CLTV,
      0,
      () => exports2.CreateLaunchTemplateVersionRequest$,
      () => exports2.CreateLaunchTemplateVersionResult$
    ];
    exports2.CreateLocalGatewayRoute$ = [
      9,
      n032,
      _CLGR,
      0,
      () => exports2.CreateLocalGatewayRouteRequest$,
      () => exports2.CreateLocalGatewayRouteResult$
    ];
    exports2.CreateLocalGatewayRouteTable$ = [
      9,
      n032,
      _CLGRT,
      0,
      () => exports2.CreateLocalGatewayRouteTableRequest$,
      () => exports2.CreateLocalGatewayRouteTableResult$
    ];
    exports2.CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociation$ = [
      9,
      n032,
      _CLGRTVIGA,
      0,
      () => exports2.CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest$,
      () => exports2.CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationResult$
    ];
    exports2.CreateLocalGatewayRouteTableVpcAssociation$ = [
      9,
      n032,
      _CLGRTVA,
      0,
      () => exports2.CreateLocalGatewayRouteTableVpcAssociationRequest$,
      () => exports2.CreateLocalGatewayRouteTableVpcAssociationResult$
    ];
    exports2.CreateLocalGatewayVirtualInterface$ = [
      9,
      n032,
      _CLGVI,
      0,
      () => exports2.CreateLocalGatewayVirtualInterfaceRequest$,
      () => exports2.CreateLocalGatewayVirtualInterfaceResult$
    ];
    exports2.CreateLocalGatewayVirtualInterfaceGroup$ = [
      9,
      n032,
      _CLGVIG,
      0,
      () => exports2.CreateLocalGatewayVirtualInterfaceGroupRequest$,
      () => exports2.CreateLocalGatewayVirtualInterfaceGroupResult$
    ];
    exports2.CreateMacSystemIntegrityProtectionModificationTask$ = [
      9,
      n032,
      _CMSIPMT,
      0,
      () => exports2.CreateMacSystemIntegrityProtectionModificationTaskRequest$,
      () => exports2.CreateMacSystemIntegrityProtectionModificationTaskResult$
    ];
    exports2.CreateManagedPrefixList$ = [
      9,
      n032,
      _CMPL,
      0,
      () => exports2.CreateManagedPrefixListRequest$,
      () => exports2.CreateManagedPrefixListResult$
    ];
    exports2.CreateNatGateway$ = [
      9,
      n032,
      _CNG,
      0,
      () => exports2.CreateNatGatewayRequest$,
      () => exports2.CreateNatGatewayResult$
    ];
    exports2.CreateNetworkAcl$ = [
      9,
      n032,
      _CNAr,
      0,
      () => exports2.CreateNetworkAclRequest$,
      () => exports2.CreateNetworkAclResult$
    ];
    exports2.CreateNetworkAclEntry$ = [
      9,
      n032,
      _CNAE,
      0,
      () => exports2.CreateNetworkAclEntryRequest$,
      () => __Unit
    ];
    exports2.CreateNetworkInsightsAccessScope$ = [
      9,
      n032,
      _CNIAS,
      0,
      () => exports2.CreateNetworkInsightsAccessScopeRequest$,
      () => exports2.CreateNetworkInsightsAccessScopeResult$
    ];
    exports2.CreateNetworkInsightsPath$ = [
      9,
      n032,
      _CNIP,
      0,
      () => exports2.CreateNetworkInsightsPathRequest$,
      () => exports2.CreateNetworkInsightsPathResult$
    ];
    exports2.CreateNetworkInterface$ = [
      9,
      n032,
      _CNIr,
      0,
      () => exports2.CreateNetworkInterfaceRequest$,
      () => exports2.CreateNetworkInterfaceResult$
    ];
    exports2.CreateNetworkInterfacePermission$ = [
      9,
      n032,
      _CNIPr,
      0,
      () => exports2.CreateNetworkInterfacePermissionRequest$,
      () => exports2.CreateNetworkInterfacePermissionResult$
    ];
    exports2.CreatePlacementGroup$ = [
      9,
      n032,
      _CPG,
      0,
      () => exports2.CreatePlacementGroupRequest$,
      () => exports2.CreatePlacementGroupResult$
    ];
    exports2.CreatePublicIpv4Pool$ = [
      9,
      n032,
      _CPIP,
      0,
      () => exports2.CreatePublicIpv4PoolRequest$,
      () => exports2.CreatePublicIpv4PoolResult$
    ];
    exports2.CreateReplaceRootVolumeTask$ = [
      9,
      n032,
      _CRRVT,
      0,
      () => exports2.CreateReplaceRootVolumeTaskRequest$,
      () => exports2.CreateReplaceRootVolumeTaskResult$
    ];
    exports2.CreateReservedInstancesListing$ = [
      9,
      n032,
      _CRILr,
      0,
      () => exports2.CreateReservedInstancesListingRequest$,
      () => exports2.CreateReservedInstancesListingResult$
    ];
    exports2.CreateRestoreImageTask$ = [
      9,
      n032,
      _CRIT,
      0,
      () => exports2.CreateRestoreImageTaskRequest$,
      () => exports2.CreateRestoreImageTaskResult$
    ];
    exports2.CreateRoute$ = [
      9,
      n032,
      _CRr,
      0,
      () => exports2.CreateRouteRequest$,
      () => exports2.CreateRouteResult$
    ];
    exports2.CreateRouteServer$ = [
      9,
      n032,
      _CRSr,
      0,
      () => exports2.CreateRouteServerRequest$,
      () => exports2.CreateRouteServerResult$
    ];
    exports2.CreateRouteServerEndpoint$ = [
      9,
      n032,
      _CRSE,
      0,
      () => exports2.CreateRouteServerEndpointRequest$,
      () => exports2.CreateRouteServerEndpointResult$
    ];
    exports2.CreateRouteServerPeer$ = [
      9,
      n032,
      _CRSP,
      0,
      () => exports2.CreateRouteServerPeerRequest$,
      () => exports2.CreateRouteServerPeerResult$
    ];
    exports2.CreateRouteTable$ = [
      9,
      n032,
      _CRTr,
      0,
      () => exports2.CreateRouteTableRequest$,
      () => exports2.CreateRouteTableResult$
    ];
    exports2.CreateSecondaryNetwork$ = [
      9,
      n032,
      _CSN,
      0,
      () => exports2.CreateSecondaryNetworkRequest$,
      () => exports2.CreateSecondaryNetworkResult$
    ];
    exports2.CreateSecondarySubnet$ = [
      9,
      n032,
      _CSS,
      0,
      () => exports2.CreateSecondarySubnetRequest$,
      () => exports2.CreateSecondarySubnetResult$
    ];
    exports2.CreateSecurityGroup$ = [
      9,
      n032,
      _CSG,
      0,
      () => exports2.CreateSecurityGroupRequest$,
      () => exports2.CreateSecurityGroupResult$
    ];
    exports2.CreateSnapshot$ = [
      9,
      n032,
      _CSre,
      0,
      () => exports2.CreateSnapshotRequest$,
      () => exports2.Snapshot$
    ];
    exports2.CreateSnapshots$ = [
      9,
      n032,
      _CSrea,
      0,
      () => exports2.CreateSnapshotsRequest$,
      () => exports2.CreateSnapshotsResult$
    ];
    exports2.CreateSpotDatafeedSubscription$ = [
      9,
      n032,
      _CSDS,
      0,
      () => exports2.CreateSpotDatafeedSubscriptionRequest$,
      () => exports2.CreateSpotDatafeedSubscriptionResult$
    ];
    exports2.CreateStoreImageTask$ = [
      9,
      n032,
      _CSIT,
      0,
      () => exports2.CreateStoreImageTaskRequest$,
      () => exports2.CreateStoreImageTaskResult$
    ];
    exports2.CreateSubnet$ = [
      9,
      n032,
      _CSreat,
      0,
      () => exports2.CreateSubnetRequest$,
      () => exports2.CreateSubnetResult$
    ];
    exports2.CreateSubnetCidrReservation$ = [
      9,
      n032,
      _CSCR,
      0,
      () => exports2.CreateSubnetCidrReservationRequest$,
      () => exports2.CreateSubnetCidrReservationResult$
    ];
    exports2.CreateTags$ = [
      9,
      n032,
      _CTreat,
      0,
      () => exports2.CreateTagsRequest$,
      () => __Unit
    ];
    exports2.CreateTrafficMirrorFilter$ = [
      9,
      n032,
      _CTMF,
      0,
      () => exports2.CreateTrafficMirrorFilterRequest$,
      () => exports2.CreateTrafficMirrorFilterResult$
    ];
    exports2.CreateTrafficMirrorFilterRule$ = [
      9,
      n032,
      _CTMFRre,
      0,
      () => exports2.CreateTrafficMirrorFilterRuleRequest$,
      () => exports2.CreateTrafficMirrorFilterRuleResult$
    ];
    exports2.CreateTrafficMirrorSession$ = [
      9,
      n032,
      _CTMS,
      0,
      () => exports2.CreateTrafficMirrorSessionRequest$,
      () => exports2.CreateTrafficMirrorSessionResult$
    ];
    exports2.CreateTrafficMirrorTarget$ = [
      9,
      n032,
      _CTMT,
      0,
      () => exports2.CreateTrafficMirrorTargetRequest$,
      () => exports2.CreateTrafficMirrorTargetResult$
    ];
    exports2.CreateTransitGateway$ = [
      9,
      n032,
      _CTG,
      0,
      () => exports2.CreateTransitGatewayRequest$,
      () => exports2.CreateTransitGatewayResult$
    ];
    exports2.CreateTransitGatewayConnect$ = [
      9,
      n032,
      _CTGC,
      0,
      () => exports2.CreateTransitGatewayConnectRequest$,
      () => exports2.CreateTransitGatewayConnectResult$
    ];
    exports2.CreateTransitGatewayConnectPeer$ = [
      9,
      n032,
      _CTGCP,
      0,
      () => exports2.CreateTransitGatewayConnectPeerRequest$,
      () => exports2.CreateTransitGatewayConnectPeerResult$
    ];
    exports2.CreateTransitGatewayMeteringPolicy$ = [
      9,
      n032,
      _CTGMP,
      0,
      () => exports2.CreateTransitGatewayMeteringPolicyRequest$,
      () => exports2.CreateTransitGatewayMeteringPolicyResult$
    ];
    exports2.CreateTransitGatewayMeteringPolicyEntry$ = [
      9,
      n032,
      _CTGMPE,
      0,
      () => exports2.CreateTransitGatewayMeteringPolicyEntryRequest$,
      () => exports2.CreateTransitGatewayMeteringPolicyEntryResult$
    ];
    exports2.CreateTransitGatewayMulticastDomain$ = [
      9,
      n032,
      _CTGMD,
      0,
      () => exports2.CreateTransitGatewayMulticastDomainRequest$,
      () => exports2.CreateTransitGatewayMulticastDomainResult$
    ];
    exports2.CreateTransitGatewayPeeringAttachment$ = [
      9,
      n032,
      _CTGPA,
      0,
      () => exports2.CreateTransitGatewayPeeringAttachmentRequest$,
      () => exports2.CreateTransitGatewayPeeringAttachmentResult$
    ];
    exports2.CreateTransitGatewayPolicyTable$ = [
      9,
      n032,
      _CTGPT,
      0,
      () => exports2.CreateTransitGatewayPolicyTableRequest$,
      () => exports2.CreateTransitGatewayPolicyTableResult$
    ];
    exports2.CreateTransitGatewayPrefixListReference$ = [
      9,
      n032,
      _CTGPLR,
      0,
      () => exports2.CreateTransitGatewayPrefixListReferenceRequest$,
      () => exports2.CreateTransitGatewayPrefixListReferenceResult$
    ];
    exports2.CreateTransitGatewayRoute$ = [
      9,
      n032,
      _CTGRre,
      0,
      () => exports2.CreateTransitGatewayRouteRequest$,
      () => exports2.CreateTransitGatewayRouteResult$
    ];
    exports2.CreateTransitGatewayRouteTable$ = [
      9,
      n032,
      _CTGRT,
      0,
      () => exports2.CreateTransitGatewayRouteTableRequest$,
      () => exports2.CreateTransitGatewayRouteTableResult$
    ];
    exports2.CreateTransitGatewayRouteTableAnnouncement$ = [
      9,
      n032,
      _CTGRTA,
      0,
      () => exports2.CreateTransitGatewayRouteTableAnnouncementRequest$,
      () => exports2.CreateTransitGatewayRouteTableAnnouncementResult$
    ];
    exports2.CreateTransitGatewayVpcAttachment$ = [
      9,
      n032,
      _CTGVA,
      0,
      () => exports2.CreateTransitGatewayVpcAttachmentRequest$,
      () => exports2.CreateTransitGatewayVpcAttachmentResult$
    ];
    exports2.CreateVerifiedAccessEndpoint$ = [
      9,
      n032,
      _CVAE,
      0,
      () => exports2.CreateVerifiedAccessEndpointRequest$,
      () => exports2.CreateVerifiedAccessEndpointResult$
    ];
    exports2.CreateVerifiedAccessGroup$ = [
      9,
      n032,
      _CVAG,
      0,
      () => exports2.CreateVerifiedAccessGroupRequest$,
      () => exports2.CreateVerifiedAccessGroupResult$
    ];
    exports2.CreateVerifiedAccessInstance$ = [
      9,
      n032,
      _CVAI,
      0,
      () => exports2.CreateVerifiedAccessInstanceRequest$,
      () => exports2.CreateVerifiedAccessInstanceResult$
    ];
    exports2.CreateVerifiedAccessTrustProvider$ = [
      9,
      n032,
      _CVATP,
      0,
      () => exports2.CreateVerifiedAccessTrustProviderRequest$,
      () => exports2.CreateVerifiedAccessTrustProviderResult$
    ];
    exports2.CreateVolume$ = [
      9,
      n032,
      _CVr,
      0,
      () => exports2.CreateVolumeRequest$,
      () => exports2.Volume$
    ];
    exports2.CreateVpc$ = [
      9,
      n032,
      _CVre,
      0,
      () => exports2.CreateVpcRequest$,
      () => exports2.CreateVpcResult$
    ];
    exports2.CreateVpcBlockPublicAccessExclusion$ = [
      9,
      n032,
      _CVBPAE,
      0,
      () => exports2.CreateVpcBlockPublicAccessExclusionRequest$,
      () => exports2.CreateVpcBlockPublicAccessExclusionResult$
    ];
    exports2.CreateVpcEncryptionControl$ = [
      9,
      n032,
      _CVEC,
      0,
      () => exports2.CreateVpcEncryptionControlRequest$,
      () => exports2.CreateVpcEncryptionControlResult$
    ];
    exports2.CreateVpcEndpoint$ = [
      9,
      n032,
      _CVEr,
      0,
      () => exports2.CreateVpcEndpointRequest$,
      () => exports2.CreateVpcEndpointResult$
    ];
    exports2.CreateVpcEndpointConnectionNotification$ = [
      9,
      n032,
      _CVECN,
      0,
      () => exports2.CreateVpcEndpointConnectionNotificationRequest$,
      () => exports2.CreateVpcEndpointConnectionNotificationResult$
    ];
    exports2.CreateVpcEndpointServiceConfiguration$ = [
      9,
      n032,
      _CVESC,
      0,
      () => exports2.CreateVpcEndpointServiceConfigurationRequest$,
      () => exports2.CreateVpcEndpointServiceConfigurationResult$
    ];
    exports2.CreateVpcPeeringConnection$ = [
      9,
      n032,
      _CVPC,
      0,
      () => exports2.CreateVpcPeeringConnectionRequest$,
      () => exports2.CreateVpcPeeringConnectionResult$
    ];
    exports2.CreateVpnConcentrator$ = [
      9,
      n032,
      _CVCr,
      0,
      () => exports2.CreateVpnConcentratorRequest$,
      () => exports2.CreateVpnConcentratorResult$
    ];
    exports2.CreateVpnConnection$ = [
      9,
      n032,
      _CVCre,
      0,
      () => exports2.CreateVpnConnectionRequest$,
      () => exports2.CreateVpnConnectionResult$
    ];
    exports2.CreateVpnConnectionRoute$ = [
      9,
      n032,
      _CVCRreat,
      0,
      () => exports2.CreateVpnConnectionRouteRequest$,
      () => __Unit
    ];
    exports2.CreateVpnGateway$ = [
      9,
      n032,
      _CVG,
      0,
      () => exports2.CreateVpnGatewayRequest$,
      () => exports2.CreateVpnGatewayResult$
    ];
    exports2.DeleteCapacityManagerDataExport$ = [
      9,
      n032,
      _DCMDE,
      0,
      () => exports2.DeleteCapacityManagerDataExportRequest$,
      () => exports2.DeleteCapacityManagerDataExportResult$
    ];
    exports2.DeleteCarrierGateway$ = [
      9,
      n032,
      _DCG,
      0,
      () => exports2.DeleteCarrierGatewayRequest$,
      () => exports2.DeleteCarrierGatewayResult$
    ];
    exports2.DeleteClientVpnEndpoint$ = [
      9,
      n032,
      _DCVE,
      0,
      () => exports2.DeleteClientVpnEndpointRequest$,
      () => exports2.DeleteClientVpnEndpointResult$
    ];
    exports2.DeleteClientVpnRoute$ = [
      9,
      n032,
      _DCVR,
      0,
      () => exports2.DeleteClientVpnRouteRequest$,
      () => exports2.DeleteClientVpnRouteResult$
    ];
    exports2.DeleteCoipCidr$ = [
      9,
      n032,
      _DCC,
      0,
      () => exports2.DeleteCoipCidrRequest$,
      () => exports2.DeleteCoipCidrResult$
    ];
    exports2.DeleteCoipPool$ = [
      9,
      n032,
      _DCP,
      0,
      () => exports2.DeleteCoipPoolRequest$,
      () => exports2.DeleteCoipPoolResult$
    ];
    exports2.DeleteCustomerGateway$ = [
      9,
      n032,
      _DCGe,
      0,
      () => exports2.DeleteCustomerGatewayRequest$,
      () => __Unit
    ];
    exports2.DeleteDhcpOptions$ = [
      9,
      n032,
      _DDO,
      0,
      () => exports2.DeleteDhcpOptionsRequest$,
      () => __Unit
    ];
    exports2.DeleteEgressOnlyInternetGateway$ = [
      9,
      n032,
      _DEOIG,
      0,
      () => exports2.DeleteEgressOnlyInternetGatewayRequest$,
      () => exports2.DeleteEgressOnlyInternetGatewayResult$
    ];
    exports2.DeleteFleets$ = [
      9,
      n032,
      _DF,
      0,
      () => exports2.DeleteFleetsRequest$,
      () => exports2.DeleteFleetsResult$
    ];
    exports2.DeleteFlowLogs$ = [
      9,
      n032,
      _DFL,
      0,
      () => exports2.DeleteFlowLogsRequest$,
      () => exports2.DeleteFlowLogsResult$
    ];
    exports2.DeleteFpgaImage$ = [
      9,
      n032,
      _DFIe,
      0,
      () => exports2.DeleteFpgaImageRequest$,
      () => exports2.DeleteFpgaImageResult$
    ];
    exports2.DeleteImageUsageReport$ = [
      9,
      n032,
      _DIUR,
      0,
      () => exports2.DeleteImageUsageReportRequest$,
      () => exports2.DeleteImageUsageReportResult$
    ];
    exports2.DeleteInstanceConnectEndpoint$ = [
      9,
      n032,
      _DICE,
      0,
      () => exports2.DeleteInstanceConnectEndpointRequest$,
      () => exports2.DeleteInstanceConnectEndpointResult$
    ];
    exports2.DeleteInstanceEventWindow$ = [
      9,
      n032,
      _DIEW,
      0,
      () => exports2.DeleteInstanceEventWindowRequest$,
      () => exports2.DeleteInstanceEventWindowResult$
    ];
    exports2.DeleteInternetGateway$ = [
      9,
      n032,
      _DIG,
      0,
      () => exports2.DeleteInternetGatewayRequest$,
      () => __Unit
    ];
    exports2.DeleteIpam$ = [
      9,
      n032,
      _DIel,
      0,
      () => exports2.DeleteIpamRequest$,
      () => exports2.DeleteIpamResult$
    ];
    exports2.DeleteIpamExternalResourceVerificationToken$ = [
      9,
      n032,
      _DIERVT,
      0,
      () => exports2.DeleteIpamExternalResourceVerificationTokenRequest$,
      () => exports2.DeleteIpamExternalResourceVerificationTokenResult$
    ];
    exports2.DeleteIpamPolicy$ = [
      9,
      n032,
      _DIP,
      0,
      () => exports2.DeleteIpamPolicyRequest$,
      () => exports2.DeleteIpamPolicyResult$
    ];
    exports2.DeleteIpamPool$ = [
      9,
      n032,
      _DIPe,
      0,
      () => exports2.DeleteIpamPoolRequest$,
      () => exports2.DeleteIpamPoolResult$
    ];
    exports2.DeleteIpamPrefixListResolver$ = [
      9,
      n032,
      _DIPLR,
      0,
      () => exports2.DeleteIpamPrefixListResolverRequest$,
      () => exports2.DeleteIpamPrefixListResolverResult$
    ];
    exports2.DeleteIpamPrefixListResolverTarget$ = [
      9,
      n032,
      _DIPLRT,
      0,
      () => exports2.DeleteIpamPrefixListResolverTargetRequest$,
      () => exports2.DeleteIpamPrefixListResolverTargetResult$
    ];
    exports2.DeleteIpamResourceDiscovery$ = [
      9,
      n032,
      _DIRD,
      0,
      () => exports2.DeleteIpamResourceDiscoveryRequest$,
      () => exports2.DeleteIpamResourceDiscoveryResult$
    ];
    exports2.DeleteIpamScope$ = [
      9,
      n032,
      _DISe,
      0,
      () => exports2.DeleteIpamScopeRequest$,
      () => exports2.DeleteIpamScopeResult$
    ];
    exports2.DeleteKeyPair$ = [
      9,
      n032,
      _DKP,
      0,
      () => exports2.DeleteKeyPairRequest$,
      () => exports2.DeleteKeyPairResult$
    ];
    exports2.DeleteLaunchTemplate$ = [
      9,
      n032,
      _DLT,
      0,
      () => exports2.DeleteLaunchTemplateRequest$,
      () => exports2.DeleteLaunchTemplateResult$
    ];
    exports2.DeleteLaunchTemplateVersions$ = [
      9,
      n032,
      _DLTV,
      0,
      () => exports2.DeleteLaunchTemplateVersionsRequest$,
      () => exports2.DeleteLaunchTemplateVersionsResult$
    ];
    exports2.DeleteLocalGatewayRoute$ = [
      9,
      n032,
      _DLGRel,
      0,
      () => exports2.DeleteLocalGatewayRouteRequest$,
      () => exports2.DeleteLocalGatewayRouteResult$
    ];
    exports2.DeleteLocalGatewayRouteTable$ = [
      9,
      n032,
      _DLGRT,
      0,
      () => exports2.DeleteLocalGatewayRouteTableRequest$,
      () => exports2.DeleteLocalGatewayRouteTableResult$
    ];
    exports2.DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociation$ = [
      9,
      n032,
      _DLGRTVIGA,
      0,
      () => exports2.DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest$,
      () => exports2.DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociationResult$
    ];
    exports2.DeleteLocalGatewayRouteTableVpcAssociation$ = [
      9,
      n032,
      _DLGRTVA,
      0,
      () => exports2.DeleteLocalGatewayRouteTableVpcAssociationRequest$,
      () => exports2.DeleteLocalGatewayRouteTableVpcAssociationResult$
    ];
    exports2.DeleteLocalGatewayVirtualInterface$ = [
      9,
      n032,
      _DLGVI,
      0,
      () => exports2.DeleteLocalGatewayVirtualInterfaceRequest$,
      () => exports2.DeleteLocalGatewayVirtualInterfaceResult$
    ];
    exports2.DeleteLocalGatewayVirtualInterfaceGroup$ = [
      9,
      n032,
      _DLGVIG,
      0,
      () => exports2.DeleteLocalGatewayVirtualInterfaceGroupRequest$,
      () => exports2.DeleteLocalGatewayVirtualInterfaceGroupResult$
    ];
    exports2.DeleteManagedPrefixList$ = [
      9,
      n032,
      _DMPL,
      0,
      () => exports2.DeleteManagedPrefixListRequest$,
      () => exports2.DeleteManagedPrefixListResult$
    ];
    exports2.DeleteNatGateway$ = [
      9,
      n032,
      _DNG,
      0,
      () => exports2.DeleteNatGatewayRequest$,
      () => exports2.DeleteNatGatewayResult$
    ];
    exports2.DeleteNetworkAcl$ = [
      9,
      n032,
      _DNA,
      0,
      () => exports2.DeleteNetworkAclRequest$,
      () => __Unit
    ];
    exports2.DeleteNetworkAclEntry$ = [
      9,
      n032,
      _DNAE,
      0,
      () => exports2.DeleteNetworkAclEntryRequest$,
      () => __Unit
    ];
    exports2.DeleteNetworkInsightsAccessScope$ = [
      9,
      n032,
      _DNIAS,
      0,
      () => exports2.DeleteNetworkInsightsAccessScopeRequest$,
      () => exports2.DeleteNetworkInsightsAccessScopeResult$
    ];
    exports2.DeleteNetworkInsightsAccessScopeAnalysis$ = [
      9,
      n032,
      _DNIASA,
      0,
      () => exports2.DeleteNetworkInsightsAccessScopeAnalysisRequest$,
      () => exports2.DeleteNetworkInsightsAccessScopeAnalysisResult$
    ];
    exports2.DeleteNetworkInsightsAnalysis$ = [
      9,
      n032,
      _DNIA,
      0,
      () => exports2.DeleteNetworkInsightsAnalysisRequest$,
      () => exports2.DeleteNetworkInsightsAnalysisResult$
    ];
    exports2.DeleteNetworkInsightsPath$ = [
      9,
      n032,
      _DNIP,
      0,
      () => exports2.DeleteNetworkInsightsPathRequest$,
      () => exports2.DeleteNetworkInsightsPathResult$
    ];
    exports2.DeleteNetworkInterface$ = [
      9,
      n032,
      _DNI,
      0,
      () => exports2.DeleteNetworkInterfaceRequest$,
      () => __Unit
    ];
    exports2.DeleteNetworkInterfacePermission$ = [
      9,
      n032,
      _DNIPe,
      0,
      () => exports2.DeleteNetworkInterfacePermissionRequest$,
      () => exports2.DeleteNetworkInterfacePermissionResult$
    ];
    exports2.DeletePlacementGroup$ = [
      9,
      n032,
      _DPG,
      0,
      () => exports2.DeletePlacementGroupRequest$,
      () => __Unit
    ];
    exports2.DeletePublicIpv4Pool$ = [
      9,
      n032,
      _DPIP,
      0,
      () => exports2.DeletePublicIpv4PoolRequest$,
      () => exports2.DeletePublicIpv4PoolResult$
    ];
    exports2.DeleteQueuedReservedInstances$ = [
      9,
      n032,
      _DQRI,
      0,
      () => exports2.DeleteQueuedReservedInstancesRequest$,
      () => exports2.DeleteQueuedReservedInstancesResult$
    ];
    exports2.DeleteRoute$ = [
      9,
      n032,
      _DRel,
      0,
      () => exports2.DeleteRouteRequest$,
      () => __Unit
    ];
    exports2.DeleteRouteServer$ = [
      9,
      n032,
      _DRSe,
      0,
      () => exports2.DeleteRouteServerRequest$,
      () => exports2.DeleteRouteServerResult$
    ];
    exports2.DeleteRouteServerEndpoint$ = [
      9,
      n032,
      _DRSE,
      0,
      () => exports2.DeleteRouteServerEndpointRequest$,
      () => exports2.DeleteRouteServerEndpointResult$
    ];
    exports2.DeleteRouteServerPeer$ = [
      9,
      n032,
      _DRSP,
      0,
      () => exports2.DeleteRouteServerPeerRequest$,
      () => exports2.DeleteRouteServerPeerResult$
    ];
    exports2.DeleteRouteTable$ = [
      9,
      n032,
      _DRT,
      0,
      () => exports2.DeleteRouteTableRequest$,
      () => __Unit
    ];
    exports2.DeleteSecondaryNetwork$ = [
      9,
      n032,
      _DSN,
      0,
      () => exports2.DeleteSecondaryNetworkRequest$,
      () => exports2.DeleteSecondaryNetworkResult$
    ];
    exports2.DeleteSecondarySubnet$ = [
      9,
      n032,
      _DSS,
      0,
      () => exports2.DeleteSecondarySubnetRequest$,
      () => exports2.DeleteSecondarySubnetResult$
    ];
    exports2.DeleteSecurityGroup$ = [
      9,
      n032,
      _DSG,
      0,
      () => exports2.DeleteSecurityGroupRequest$,
      () => exports2.DeleteSecurityGroupResult$
    ];
    exports2.DeleteSnapshot$ = [
      9,
      n032,
      _DSele,
      0,
      () => exports2.DeleteSnapshotRequest$,
      () => __Unit
    ];
    exports2.DeleteSpotDatafeedSubscription$ = [
      9,
      n032,
      _DSDS,
      0,
      () => exports2.DeleteSpotDatafeedSubscriptionRequest$,
      () => __Unit
    ];
    exports2.DeleteSubnet$ = [
      9,
      n032,
      _DSelet,
      0,
      () => exports2.DeleteSubnetRequest$,
      () => __Unit
    ];
    exports2.DeleteSubnetCidrReservation$ = [
      9,
      n032,
      _DSCRe,
      0,
      () => exports2.DeleteSubnetCidrReservationRequest$,
      () => exports2.DeleteSubnetCidrReservationResult$
    ];
    exports2.DeleteTags$ = [
      9,
      n032,
      _DTelet,
      0,
      () => exports2.DeleteTagsRequest$,
      () => __Unit
    ];
    exports2.DeleteTrafficMirrorFilter$ = [
      9,
      n032,
      _DTMF,
      0,
      () => exports2.DeleteTrafficMirrorFilterRequest$,
      () => exports2.DeleteTrafficMirrorFilterResult$
    ];
    exports2.DeleteTrafficMirrorFilterRule$ = [
      9,
      n032,
      _DTMFRel,
      0,
      () => exports2.DeleteTrafficMirrorFilterRuleRequest$,
      () => exports2.DeleteTrafficMirrorFilterRuleResult$
    ];
    exports2.DeleteTrafficMirrorSession$ = [
      9,
      n032,
      _DTMS,
      0,
      () => exports2.DeleteTrafficMirrorSessionRequest$,
      () => exports2.DeleteTrafficMirrorSessionResult$
    ];
    exports2.DeleteTrafficMirrorTarget$ = [
      9,
      n032,
      _DTMT,
      0,
      () => exports2.DeleteTrafficMirrorTargetRequest$,
      () => exports2.DeleteTrafficMirrorTargetResult$
    ];
    exports2.DeleteTransitGateway$ = [
      9,
      n032,
      _DTG,
      0,
      () => exports2.DeleteTransitGatewayRequest$,
      () => exports2.DeleteTransitGatewayResult$
    ];
    exports2.DeleteTransitGatewayClientVpnAttachment$ = [
      9,
      n032,
      _DTGCVA,
      0,
      () => exports2.DeleteTransitGatewayClientVpnAttachmentRequest$,
      () => exports2.DeleteTransitGatewayClientVpnAttachmentResult$
    ];
    exports2.DeleteTransitGatewayConnect$ = [
      9,
      n032,
      _DTGC,
      0,
      () => exports2.DeleteTransitGatewayConnectRequest$,
      () => exports2.DeleteTransitGatewayConnectResult$
    ];
    exports2.DeleteTransitGatewayConnectPeer$ = [
      9,
      n032,
      _DTGCP,
      0,
      () => exports2.DeleteTransitGatewayConnectPeerRequest$,
      () => exports2.DeleteTransitGatewayConnectPeerResult$
    ];
    exports2.DeleteTransitGatewayMeteringPolicy$ = [
      9,
      n032,
      _DTGMP,
      0,
      () => exports2.DeleteTransitGatewayMeteringPolicyRequest$,
      () => exports2.DeleteTransitGatewayMeteringPolicyResult$
    ];
    exports2.DeleteTransitGatewayMeteringPolicyEntry$ = [
      9,
      n032,
      _DTGMPE,
      0,
      () => exports2.DeleteTransitGatewayMeteringPolicyEntryRequest$,
      () => exports2.DeleteTransitGatewayMeteringPolicyEntryResult$
    ];
    exports2.DeleteTransitGatewayMulticastDomain$ = [
      9,
      n032,
      _DTGMD,
      0,
      () => exports2.DeleteTransitGatewayMulticastDomainRequest$,
      () => exports2.DeleteTransitGatewayMulticastDomainResult$
    ];
    exports2.DeleteTransitGatewayPeeringAttachment$ = [
      9,
      n032,
      _DTGPA,
      0,
      () => exports2.DeleteTransitGatewayPeeringAttachmentRequest$,
      () => exports2.DeleteTransitGatewayPeeringAttachmentResult$
    ];
    exports2.DeleteTransitGatewayPolicyTable$ = [
      9,
      n032,
      _DTGPT,
      0,
      () => exports2.DeleteTransitGatewayPolicyTableRequest$,
      () => exports2.DeleteTransitGatewayPolicyTableResult$
    ];
    exports2.DeleteTransitGatewayPrefixListReference$ = [
      9,
      n032,
      _DTGPLR,
      0,
      () => exports2.DeleteTransitGatewayPrefixListReferenceRequest$,
      () => exports2.DeleteTransitGatewayPrefixListReferenceResult$
    ];
    exports2.DeleteTransitGatewayRoute$ = [
      9,
      n032,
      _DTGRel,
      0,
      () => exports2.DeleteTransitGatewayRouteRequest$,
      () => exports2.DeleteTransitGatewayRouteResult$
    ];
    exports2.DeleteTransitGatewayRouteTable$ = [
      9,
      n032,
      _DTGRT,
      0,
      () => exports2.DeleteTransitGatewayRouteTableRequest$,
      () => exports2.DeleteTransitGatewayRouteTableResult$
    ];
    exports2.DeleteTransitGatewayRouteTableAnnouncement$ = [
      9,
      n032,
      _DTGRTA,
      0,
      () => exports2.DeleteTransitGatewayRouteTableAnnouncementRequest$,
      () => exports2.DeleteTransitGatewayRouteTableAnnouncementResult$
    ];
    exports2.DeleteTransitGatewayVpcAttachment$ = [
      9,
      n032,
      _DTGVA,
      0,
      () => exports2.DeleteTransitGatewayVpcAttachmentRequest$,
      () => exports2.DeleteTransitGatewayVpcAttachmentResult$
    ];
    exports2.DeleteVerifiedAccessEndpoint$ = [
      9,
      n032,
      _DVAE,
      0,
      () => exports2.DeleteVerifiedAccessEndpointRequest$,
      () => exports2.DeleteVerifiedAccessEndpointResult$
    ];
    exports2.DeleteVerifiedAccessGroup$ = [
      9,
      n032,
      _DVAG,
      0,
      () => exports2.DeleteVerifiedAccessGroupRequest$,
      () => exports2.DeleteVerifiedAccessGroupResult$
    ];
    exports2.DeleteVerifiedAccessInstance$ = [
      9,
      n032,
      _DVAI,
      0,
      () => exports2.DeleteVerifiedAccessInstanceRequest$,
      () => exports2.DeleteVerifiedAccessInstanceResult$
    ];
    exports2.DeleteVerifiedAccessTrustProvider$ = [
      9,
      n032,
      _DVATP,
      0,
      () => exports2.DeleteVerifiedAccessTrustProviderRequest$,
      () => exports2.DeleteVerifiedAccessTrustProviderResult$
    ];
    exports2.DeleteVolume$ = [
      9,
      n032,
      _DVel,
      0,
      () => exports2.DeleteVolumeRequest$,
      () => __Unit
    ];
    exports2.DeleteVpc$ = [
      9,
      n032,
      _DVele,
      0,
      () => exports2.DeleteVpcRequest$,
      () => __Unit
    ];
    exports2.DeleteVpcBlockPublicAccessExclusion$ = [
      9,
      n032,
      _DVBPAE,
      0,
      () => exports2.DeleteVpcBlockPublicAccessExclusionRequest$,
      () => exports2.DeleteVpcBlockPublicAccessExclusionResult$
    ];
    exports2.DeleteVpcEncryptionControl$ = [
      9,
      n032,
      _DVEC,
      0,
      () => exports2.DeleteVpcEncryptionControlRequest$,
      () => exports2.DeleteVpcEncryptionControlResult$
    ];
    exports2.DeleteVpcEndpointConnectionNotifications$ = [
      9,
      n032,
      _DVECN,
      0,
      () => exports2.DeleteVpcEndpointConnectionNotificationsRequest$,
      () => exports2.DeleteVpcEndpointConnectionNotificationsResult$
    ];
    exports2.DeleteVpcEndpoints$ = [
      9,
      n032,
      _DVE,
      0,
      () => exports2.DeleteVpcEndpointsRequest$,
      () => exports2.DeleteVpcEndpointsResult$
    ];
    exports2.DeleteVpcEndpointServiceConfigurations$ = [
      9,
      n032,
      _DVESC,
      0,
      () => exports2.DeleteVpcEndpointServiceConfigurationsRequest$,
      () => exports2.DeleteVpcEndpointServiceConfigurationsResult$
    ];
    exports2.DeleteVpcPeeringConnection$ = [
      9,
      n032,
      _DVPC,
      0,
      () => exports2.DeleteVpcPeeringConnectionRequest$,
      () => exports2.DeleteVpcPeeringConnectionResult$
    ];
    exports2.DeleteVpnConcentrator$ = [
      9,
      n032,
      _DVCe,
      0,
      () => exports2.DeleteVpnConcentratorRequest$,
      () => exports2.DeleteVpnConcentratorResult$
    ];
    exports2.DeleteVpnConnection$ = [
      9,
      n032,
      _DVCel,
      0,
      () => exports2.DeleteVpnConnectionRequest$,
      () => __Unit
    ];
    exports2.DeleteVpnConnectionRoute$ = [
      9,
      n032,
      _DVCRele,
      0,
      () => exports2.DeleteVpnConnectionRouteRequest$,
      () => __Unit
    ];
    exports2.DeleteVpnGateway$ = [
      9,
      n032,
      _DVG,
      0,
      () => exports2.DeleteVpnGatewayRequest$,
      () => __Unit
    ];
    exports2.DeprovisionByoipCidr$ = [
      9,
      n032,
      _DBC,
      0,
      () => exports2.DeprovisionByoipCidrRequest$,
      () => exports2.DeprovisionByoipCidrResult$
    ];
    exports2.DeprovisionIpamByoasn$ = [
      9,
      n032,
      _DIB,
      0,
      () => exports2.DeprovisionIpamByoasnRequest$,
      () => exports2.DeprovisionIpamByoasnResult$
    ];
    exports2.DeprovisionIpamPoolCidr$ = [
      9,
      n032,
      _DIPC,
      0,
      () => exports2.DeprovisionIpamPoolCidrRequest$,
      () => exports2.DeprovisionIpamPoolCidrResult$
    ];
    exports2.DeprovisionPublicIpv4PoolCidr$ = [
      9,
      n032,
      _DPIPC,
      0,
      () => exports2.DeprovisionPublicIpv4PoolCidrRequest$,
      () => exports2.DeprovisionPublicIpv4PoolCidrResult$
    ];
    exports2.DeregisterImage$ = [
      9,
      n032,
      _DIer,
      0,
      () => exports2.DeregisterImageRequest$,
      () => exports2.DeregisterImageResult$
    ];
    exports2.DeregisterInstanceEventNotificationAttributes$ = [
      9,
      n032,
      _DIENA,
      0,
      () => exports2.DeregisterInstanceEventNotificationAttributesRequest$,
      () => exports2.DeregisterInstanceEventNotificationAttributesResult$
    ];
    exports2.DeregisterTransitGatewayMulticastGroupMembers$ = [
      9,
      n032,
      _DTGMGM,
      0,
      () => exports2.DeregisterTransitGatewayMulticastGroupMembersRequest$,
      () => exports2.DeregisterTransitGatewayMulticastGroupMembersResult$
    ];
    exports2.DeregisterTransitGatewayMulticastGroupSources$ = [
      9,
      n032,
      _DTGMGS,
      0,
      () => exports2.DeregisterTransitGatewayMulticastGroupSourcesRequest$,
      () => exports2.DeregisterTransitGatewayMulticastGroupSourcesResult$
    ];
    exports2.DescribeAccountAttributes$ = [
      9,
      n032,
      _DAA,
      0,
      () => exports2.DescribeAccountAttributesRequest$,
      () => exports2.DescribeAccountAttributesResult$
    ];
    exports2.DescribeAddresses$ = [
      9,
      n032,
      _DAesc,
      0,
      () => exports2.DescribeAddressesRequest$,
      () => exports2.DescribeAddressesResult$
    ];
    exports2.DescribeAddressesAttribute$ = [
      9,
      n032,
      _DAAe,
      0,
      () => exports2.DescribeAddressesAttributeRequest$,
      () => exports2.DescribeAddressesAttributeResult$
    ];
    exports2.DescribeAddressTransfers$ = [
      9,
      n032,
      _DATe,
      0,
      () => exports2.DescribeAddressTransfersRequest$,
      () => exports2.DescribeAddressTransfersResult$
    ];
    exports2.DescribeAggregateIdFormat$ = [
      9,
      n032,
      _DAIF,
      0,
      () => exports2.DescribeAggregateIdFormatRequest$,
      () => exports2.DescribeAggregateIdFormatResult$
    ];
    exports2.DescribeAvailabilityZones$ = [
      9,
      n032,
      _DAZe,
      0,
      () => exports2.DescribeAvailabilityZonesRequest$,
      () => exports2.DescribeAvailabilityZonesResult$
    ];
    exports2.DescribeAwsNetworkPerformanceMetricSubscriptions$ = [
      9,
      n032,
      _DANPMS,
      0,
      () => exports2.DescribeAwsNetworkPerformanceMetricSubscriptionsRequest$,
      () => exports2.DescribeAwsNetworkPerformanceMetricSubscriptionsResult$
    ];
    exports2.DescribeBundleTasks$ = [
      9,
      n032,
      _DBT,
      0,
      () => exports2.DescribeBundleTasksRequest$,
      () => exports2.DescribeBundleTasksResult$
    ];
    exports2.DescribeByoipCidrs$ = [
      9,
      n032,
      _DBCe,
      0,
      () => exports2.DescribeByoipCidrsRequest$,
      () => exports2.DescribeByoipCidrsResult$
    ];
    exports2.DescribeCapacityBlockExtensionHistory$ = [
      9,
      n032,
      _DCBEH,
      0,
      () => exports2.DescribeCapacityBlockExtensionHistoryRequest$,
      () => exports2.DescribeCapacityBlockExtensionHistoryResult$
    ];
    exports2.DescribeCapacityBlockExtensionOfferings$ = [
      9,
      n032,
      _DCBEO,
      0,
      () => exports2.DescribeCapacityBlockExtensionOfferingsRequest$,
      () => exports2.DescribeCapacityBlockExtensionOfferingsResult$
    ];
    exports2.DescribeCapacityBlockOfferings$ = [
      9,
      n032,
      _DCBO,
      0,
      () => exports2.DescribeCapacityBlockOfferingsRequest$,
      () => exports2.DescribeCapacityBlockOfferingsResult$
    ];
    exports2.DescribeCapacityBlocks$ = [
      9,
      n032,
      _DCBe,
      0,
      () => exports2.DescribeCapacityBlocksRequest$,
      () => exports2.DescribeCapacityBlocksResult$
    ];
    exports2.DescribeCapacityBlockStatus$ = [
      9,
      n032,
      _DCBS,
      0,
      () => exports2.DescribeCapacityBlockStatusRequest$,
      () => exports2.DescribeCapacityBlockStatusResult$
    ];
    exports2.DescribeCapacityManagerDataExports$ = [
      9,
      n032,
      _DCMDEe,
      0,
      () => exports2.DescribeCapacityManagerDataExportsRequest$,
      () => exports2.DescribeCapacityManagerDataExportsResult$
    ];
    exports2.DescribeCapacityReservationBillingRequests$ = [
      9,
      n032,
      _DCRBR,
      0,
      () => exports2.DescribeCapacityReservationBillingRequestsRequest$,
      () => exports2.DescribeCapacityReservationBillingRequestsResult$
    ];
    exports2.DescribeCapacityReservationFleets$ = [
      9,
      n032,
      _DCRF,
      0,
      () => exports2.DescribeCapacityReservationFleetsRequest$,
      () => exports2.DescribeCapacityReservationFleetsResult$
    ];
    exports2.DescribeCapacityReservations$ = [
      9,
      n032,
      _DCRe,
      0,
      () => exports2.DescribeCapacityReservationsRequest$,
      () => exports2.DescribeCapacityReservationsResult$
    ];
    exports2.DescribeCapacityReservationTopology$ = [
      9,
      n032,
      _DCRT,
      0,
      () => exports2.DescribeCapacityReservationTopologyRequest$,
      () => exports2.DescribeCapacityReservationTopologyResult$
    ];
    exports2.DescribeCarrierGateways$ = [
      9,
      n032,
      _DCGes,
      0,
      () => exports2.DescribeCarrierGatewaysRequest$,
      () => exports2.DescribeCarrierGatewaysResult$
    ];
    exports2.DescribeClassicLinkInstances$ = [
      9,
      n032,
      _DCLI,
      0,
      () => exports2.DescribeClassicLinkInstancesRequest$,
      () => exports2.DescribeClassicLinkInstancesResult$
    ];
    exports2.DescribeClientVpnAuthorizationRules$ = [
      9,
      n032,
      _DCVAR,
      0,
      () => exports2.DescribeClientVpnAuthorizationRulesRequest$,
      () => exports2.DescribeClientVpnAuthorizationRulesResult$
    ];
    exports2.DescribeClientVpnConnections$ = [
      9,
      n032,
      _DCVC,
      0,
      () => exports2.DescribeClientVpnConnectionsRequest$,
      () => exports2.DescribeClientVpnConnectionsResult$
    ];
    exports2.DescribeClientVpnEndpoints$ = [
      9,
      n032,
      _DCVEe,
      0,
      () => exports2.DescribeClientVpnEndpointsRequest$,
      () => exports2.DescribeClientVpnEndpointsResult$
    ];
    exports2.DescribeClientVpnRoutes$ = [
      9,
      n032,
      _DCVRe,
      0,
      () => exports2.DescribeClientVpnRoutesRequest$,
      () => exports2.DescribeClientVpnRoutesResult$
    ];
    exports2.DescribeClientVpnTargetNetworks$ = [
      9,
      n032,
      _DCVTN,
      0,
      () => exports2.DescribeClientVpnTargetNetworksRequest$,
      () => exports2.DescribeClientVpnTargetNetworksResult$
    ];
    exports2.DescribeCoipPools$ = [
      9,
      n032,
      _DCPe,
      0,
      () => exports2.DescribeCoipPoolsRequest$,
      () => exports2.DescribeCoipPoolsResult$
    ];
    exports2.DescribeConversionTasks$ = [
      9,
      n032,
      _DCT,
      0,
      () => exports2.DescribeConversionTasksRequest$,
      () => exports2.DescribeConversionTasksResult$
    ];
    exports2.DescribeCustomerGateways$ = [
      9,
      n032,
      _DCGesc,
      0,
      () => exports2.DescribeCustomerGatewaysRequest$,
      () => exports2.DescribeCustomerGatewaysResult$
    ];
    exports2.DescribeDeclarativePoliciesReports$ = [
      9,
      n032,
      _DDPR,
      0,
      () => exports2.DescribeDeclarativePoliciesReportsRequest$,
      () => exports2.DescribeDeclarativePoliciesReportsResult$
    ];
    exports2.DescribeDhcpOptions$ = [
      9,
      n032,
      _DDOe,
      0,
      () => exports2.DescribeDhcpOptionsRequest$,
      () => exports2.DescribeDhcpOptionsResult$
    ];
    exports2.DescribeEgressOnlyInternetGateways$ = [
      9,
      n032,
      _DEOIGe,
      0,
      () => exports2.DescribeEgressOnlyInternetGatewaysRequest$,
      () => exports2.DescribeEgressOnlyInternetGatewaysResult$
    ];
    exports2.DescribeElasticGpus$ = [
      9,
      n032,
      _DEG,
      0,
      () => exports2.DescribeElasticGpusRequest$,
      () => exports2.DescribeElasticGpusResult$
    ];
    exports2.DescribeExportImageTasks$ = [
      9,
      n032,
      _DEIT,
      0,
      () => exports2.DescribeExportImageTasksRequest$,
      () => exports2.DescribeExportImageTasksResult$
    ];
    exports2.DescribeExportTasks$ = [
      9,
      n032,
      _DET,
      0,
      () => exports2.DescribeExportTasksRequest$,
      () => exports2.DescribeExportTasksResult$
    ];
    exports2.DescribeFastLaunchImages$ = [
      9,
      n032,
      _DFLI,
      0,
      () => exports2.DescribeFastLaunchImagesRequest$,
      () => exports2.DescribeFastLaunchImagesResult$
    ];
    exports2.DescribeFastSnapshotRestores$ = [
      9,
      n032,
      _DFSR,
      0,
      () => exports2.DescribeFastSnapshotRestoresRequest$,
      () => exports2.DescribeFastSnapshotRestoresResult$
    ];
    exports2.DescribeFleetHistory$ = [
      9,
      n032,
      _DFH,
      0,
      () => exports2.DescribeFleetHistoryRequest$,
      () => exports2.DescribeFleetHistoryResult$
    ];
    exports2.DescribeFleetInstances$ = [
      9,
      n032,
      _DFIes,
      0,
      () => exports2.DescribeFleetInstancesRequest$,
      () => exports2.DescribeFleetInstancesResult$
    ];
    exports2.DescribeFleets$ = [
      9,
      n032,
      _DFe,
      0,
      () => exports2.DescribeFleetsRequest$,
      () => exports2.DescribeFleetsResult$
    ];
    exports2.DescribeFlowLogs$ = [
      9,
      n032,
      _DFLe,
      0,
      () => exports2.DescribeFlowLogsRequest$,
      () => exports2.DescribeFlowLogsResult$
    ];
    exports2.DescribeFpgaImageAttribute$ = [
      9,
      n032,
      _DFIA,
      0,
      () => exports2.DescribeFpgaImageAttributeRequest$,
      () => exports2.DescribeFpgaImageAttributeResult$
    ];
    exports2.DescribeFpgaImages$ = [
      9,
      n032,
      _DFIesc,
      0,
      () => exports2.DescribeFpgaImagesRequest$,
      () => exports2.DescribeFpgaImagesResult$
    ];
    exports2.DescribeHostReservationOfferings$ = [
      9,
      n032,
      _DHRO,
      0,
      () => exports2.DescribeHostReservationOfferingsRequest$,
      () => exports2.DescribeHostReservationOfferingsResult$
    ];
    exports2.DescribeHostReservations$ = [
      9,
      n032,
      _DHRes,
      0,
      () => exports2.DescribeHostReservationsRequest$,
      () => exports2.DescribeHostReservationsResult$
    ];
    exports2.DescribeHosts$ = [
      9,
      n032,
      _DH,
      0,
      () => exports2.DescribeHostsRequest$,
      () => exports2.DescribeHostsResult$
    ];
    exports2.DescribeIamInstanceProfileAssociations$ = [
      9,
      n032,
      _DIIPA,
      0,
      () => exports2.DescribeIamInstanceProfileAssociationsRequest$,
      () => exports2.DescribeIamInstanceProfileAssociationsResult$
    ];
    exports2.DescribeIdentityIdFormat$ = [
      9,
      n032,
      _DIIF,
      0,
      () => exports2.DescribeIdentityIdFormatRequest$,
      () => exports2.DescribeIdentityIdFormatResult$
    ];
    exports2.DescribeIdFormat$ = [
      9,
      n032,
      _DIFe,
      0,
      () => exports2.DescribeIdFormatRequest$,
      () => exports2.DescribeIdFormatResult$
    ];
    exports2.DescribeImageAttribute$ = [
      9,
      n032,
      _DIA,
      0,
      () => exports2.DescribeImageAttributeRequest$,
      () => exports2.ImageAttribute$
    ];
    exports2.DescribeImageReferences$ = [
      9,
      n032,
      _DIRescribem,
      0,
      () => exports2.DescribeImageReferencesRequest$,
      () => exports2.DescribeImageReferencesResult$
    ];
    exports2.DescribeImages$ = [
      9,
      n032,
      _DIes,
      0,
      () => exports2.DescribeImagesRequest$,
      () => exports2.DescribeImagesResult$
    ];
    exports2.DescribeImageUsageReportEntries$ = [
      9,
      n032,
      _DIURE,
      0,
      () => exports2.DescribeImageUsageReportEntriesRequest$,
      () => exports2.DescribeImageUsageReportEntriesResult$
    ];
    exports2.DescribeImageUsageReports$ = [
      9,
      n032,
      _DIURe,
      0,
      () => exports2.DescribeImageUsageReportsRequest$,
      () => exports2.DescribeImageUsageReportsResult$
    ];
    exports2.DescribeImportImageTasks$ = [
      9,
      n032,
      _DIIT,
      0,
      () => exports2.DescribeImportImageTasksRequest$,
      () => exports2.DescribeImportImageTasksResult$
    ];
    exports2.DescribeImportSnapshotTasks$ = [
      9,
      n032,
      _DIST,
      0,
      () => exports2.DescribeImportSnapshotTasksRequest$,
      () => exports2.DescribeImportSnapshotTasksResult$
    ];
    exports2.DescribeInstanceAttribute$ = [
      9,
      n032,
      _DIAe,
      0,
      () => exports2.DescribeInstanceAttributeRequest$,
      () => exports2.InstanceAttribute$
    ];
    exports2.DescribeInstanceConnectEndpoints$ = [
      9,
      n032,
      _DICEe,
      0,
      () => exports2.DescribeInstanceConnectEndpointsRequest$,
      () => exports2.DescribeInstanceConnectEndpointsResult$
    ];
    exports2.DescribeInstanceCreditSpecifications$ = [
      9,
      n032,
      _DICS,
      0,
      () => exports2.DescribeInstanceCreditSpecificationsRequest$,
      () => exports2.DescribeInstanceCreditSpecificationsResult$
    ];
    exports2.DescribeInstanceEventNotificationAttributes$ = [
      9,
      n032,
      _DIENAe,
      0,
      () => exports2.DescribeInstanceEventNotificationAttributesRequest$,
      () => exports2.DescribeInstanceEventNotificationAttributesResult$
    ];
    exports2.DescribeInstanceEventWindows$ = [
      9,
      n032,
      _DIEWe,
      0,
      () => exports2.DescribeInstanceEventWindowsRequest$,
      () => exports2.DescribeInstanceEventWindowsResult$
    ];
    exports2.DescribeInstanceImageMetadata$ = [
      9,
      n032,
      _DIIM,
      0,
      () => exports2.DescribeInstanceImageMetadataRequest$,
      () => exports2.DescribeInstanceImageMetadataResult$
    ];
    exports2.DescribeInstances$ = [
      9,
      n032,
      _DIesc,
      0,
      () => exports2.DescribeInstancesRequest$,
      () => exports2.DescribeInstancesResult$
    ];
    exports2.DescribeInstanceSqlHaHistoryStates$ = [
      9,
      n032,
      _DISHHS,
      0,
      () => exports2.DescribeInstanceSqlHaHistoryStatesRequest$,
      () => exports2.DescribeInstanceSqlHaHistoryStatesResult$
    ];
    exports2.DescribeInstanceSqlHaStates$ = [
      9,
      n032,
      _DISHS,
      0,
      () => exports2.DescribeInstanceSqlHaStatesRequest$,
      () => exports2.DescribeInstanceSqlHaStatesResult$
    ];
    exports2.DescribeInstanceStatus$ = [
      9,
      n032,
      _DISes,
      0,
      () => exports2.DescribeInstanceStatusRequest$,
      () => exports2.DescribeInstanceStatusResult$
    ];
    exports2.DescribeInstanceTopology$ = [
      9,
      n032,
      _DIT,
      0,
      () => exports2.DescribeInstanceTopologyRequest$,
      () => exports2.DescribeInstanceTopologyResult$
    ];
    exports2.DescribeInstanceTypeOfferings$ = [
      9,
      n032,
      _DITO,
      0,
      () => exports2.DescribeInstanceTypeOfferingsRequest$,
      () => exports2.DescribeInstanceTypeOfferingsResult$
    ];
    exports2.DescribeInstanceTypes$ = [
      9,
      n032,
      _DITe,
      0,
      () => exports2.DescribeInstanceTypesRequest$,
      () => exports2.DescribeInstanceTypesResult$
    ];
    exports2.DescribeInternetGateways$ = [
      9,
      n032,
      _DIGe,
      0,
      () => exports2.DescribeInternetGatewaysRequest$,
      () => exports2.DescribeInternetGatewaysResult$
    ];
    exports2.DescribeIpamByoasn$ = [
      9,
      n032,
      _DIBe,
      0,
      () => exports2.DescribeIpamByoasnRequest$,
      () => exports2.DescribeIpamByoasnResult$
    ];
    exports2.DescribeIpamExternalResourceVerificationTokens$ = [
      9,
      n032,
      _DIERVTe,
      0,
      () => exports2.DescribeIpamExternalResourceVerificationTokensRequest$,
      () => exports2.DescribeIpamExternalResourceVerificationTokensResult$
    ];
    exports2.DescribeIpamPolicies$ = [
      9,
      n032,
      _DIPes,
      0,
      () => exports2.DescribeIpamPoliciesRequest$,
      () => exports2.DescribeIpamPoliciesResult$
    ];
    exports2.DescribeIpamPools$ = [
      9,
      n032,
      _DIPesc,
      0,
      () => exports2.DescribeIpamPoolsRequest$,
      () => exports2.DescribeIpamPoolsResult$
    ];
    exports2.DescribeIpamPrefixListResolvers$ = [
      9,
      n032,
      _DIPLRe,
      0,
      () => exports2.DescribeIpamPrefixListResolversRequest$,
      () => exports2.DescribeIpamPrefixListResolversResult$
    ];
    exports2.DescribeIpamPrefixListResolverTargets$ = [
      9,
      n032,
      _DIPLRTe,
      0,
      () => exports2.DescribeIpamPrefixListResolverTargetsRequest$,
      () => exports2.DescribeIpamPrefixListResolverTargetsResult$
    ];
    exports2.DescribeIpamResourceDiscoveries$ = [
      9,
      n032,
      _DIRDe,
      0,
      () => exports2.DescribeIpamResourceDiscoveriesRequest$,
      () => exports2.DescribeIpamResourceDiscoveriesResult$
    ];
    exports2.DescribeIpamResourceDiscoveryAssociations$ = [
      9,
      n032,
      _DIRDA,
      0,
      () => exports2.DescribeIpamResourceDiscoveryAssociationsRequest$,
      () => exports2.DescribeIpamResourceDiscoveryAssociationsResult$
    ];
    exports2.DescribeIpams$ = [
      9,
      n032,
      _DIescr,
      0,
      () => exports2.DescribeIpamsRequest$,
      () => exports2.DescribeIpamsResult$
    ];
    exports2.DescribeIpamScopes$ = [
      9,
      n032,
      _DISesc,
      0,
      () => exports2.DescribeIpamScopesRequest$,
      () => exports2.DescribeIpamScopesResult$
    ];
    exports2.DescribeIpv6Pools$ = [
      9,
      n032,
      _DIPescr,
      0,
      () => exports2.DescribeIpv6PoolsRequest$,
      () => exports2.DescribeIpv6PoolsResult$
    ];
    exports2.DescribeKeyPairs$ = [
      9,
      n032,
      _DKPe,
      0,
      () => exports2.DescribeKeyPairsRequest$,
      () => exports2.DescribeKeyPairsResult$
    ];
    exports2.DescribeLaunchTemplates$ = [
      9,
      n032,
      _DLTe,
      0,
      () => exports2.DescribeLaunchTemplatesRequest$,
      () => exports2.DescribeLaunchTemplatesResult$
    ];
    exports2.DescribeLaunchTemplateVersions$ = [
      9,
      n032,
      _DLTVe,
      0,
      () => exports2.DescribeLaunchTemplateVersionsRequest$,
      () => exports2.DescribeLaunchTemplateVersionsResult$
    ];
    exports2.DescribeLocalGatewayRouteTables$ = [
      9,
      n032,
      _DLGRTe,
      0,
      () => exports2.DescribeLocalGatewayRouteTablesRequest$,
      () => exports2.DescribeLocalGatewayRouteTablesResult$
    ];
    exports2.DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociations$ = [
      9,
      n032,
      _DLGRTVIGAe,
      0,
      () => exports2.DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociationsRequest$,
      () => exports2.DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociationsResult$
    ];
    exports2.DescribeLocalGatewayRouteTableVpcAssociations$ = [
      9,
      n032,
      _DLGRTVAe,
      0,
      () => exports2.DescribeLocalGatewayRouteTableVpcAssociationsRequest$,
      () => exports2.DescribeLocalGatewayRouteTableVpcAssociationsResult$
    ];
    exports2.DescribeLocalGateways$ = [
      9,
      n032,
      _DLG,
      0,
      () => exports2.DescribeLocalGatewaysRequest$,
      () => exports2.DescribeLocalGatewaysResult$
    ];
    exports2.DescribeLocalGatewayVirtualInterfaceGroups$ = [
      9,
      n032,
      _DLGVIGe,
      0,
      () => exports2.DescribeLocalGatewayVirtualInterfaceGroupsRequest$,
      () => exports2.DescribeLocalGatewayVirtualInterfaceGroupsResult$
    ];
    exports2.DescribeLocalGatewayVirtualInterfaces$ = [
      9,
      n032,
      _DLGVIe,
      0,
      () => exports2.DescribeLocalGatewayVirtualInterfacesRequest$,
      () => exports2.DescribeLocalGatewayVirtualInterfacesResult$
    ];
    exports2.DescribeLockedSnapshots$ = [
      9,
      n032,
      _DLSe,
      0,
      () => exports2.DescribeLockedSnapshotsRequest$,
      () => exports2.DescribeLockedSnapshotsResult$
    ];
    exports2.DescribeMacHosts$ = [
      9,
      n032,
      _DMH,
      0,
      () => exports2.DescribeMacHostsRequest$,
      () => exports2.DescribeMacHostsResult$
    ];
    exports2.DescribeMacModificationTasks$ = [
      9,
      n032,
      _DMMT,
      0,
      () => exports2.DescribeMacModificationTasksRequest$,
      () => exports2.DescribeMacModificationTasksResult$
    ];
    exports2.DescribeManagedPrefixLists$ = [
      9,
      n032,
      _DMPLe,
      0,
      () => exports2.DescribeManagedPrefixListsRequest$,
      () => exports2.DescribeManagedPrefixListsResult$
    ];
    exports2.DescribeMovingAddresses$ = [
      9,
      n032,
      _DMA,
      0,
      () => exports2.DescribeMovingAddressesRequest$,
      () => exports2.DescribeMovingAddressesResult$
    ];
    exports2.DescribeNatGateways$ = [
      9,
      n032,
      _DNGe,
      0,
      () => exports2.DescribeNatGatewaysRequest$,
      () => exports2.DescribeNatGatewaysResult$
    ];
    exports2.DescribeNetworkAcls$ = [
      9,
      n032,
      _DNAe,
      0,
      () => exports2.DescribeNetworkAclsRequest$,
      () => exports2.DescribeNetworkAclsResult$
    ];
    exports2.DescribeNetworkInsightsAccessScopeAnalyses$ = [
      9,
      n032,
      _DNIASAe,
      0,
      () => exports2.DescribeNetworkInsightsAccessScopeAnalysesRequest$,
      () => exports2.DescribeNetworkInsightsAccessScopeAnalysesResult$
    ];
    exports2.DescribeNetworkInsightsAccessScopes$ = [
      9,
      n032,
      _DNIASe,
      0,
      () => exports2.DescribeNetworkInsightsAccessScopesRequest$,
      () => exports2.DescribeNetworkInsightsAccessScopesResult$
    ];
    exports2.DescribeNetworkInsightsAnalyses$ = [
      9,
      n032,
      _DNIAe,
      0,
      () => exports2.DescribeNetworkInsightsAnalysesRequest$,
      () => exports2.DescribeNetworkInsightsAnalysesResult$
    ];
    exports2.DescribeNetworkInsightsPaths$ = [
      9,
      n032,
      _DNIPes,
      0,
      () => exports2.DescribeNetworkInsightsPathsRequest$,
      () => exports2.DescribeNetworkInsightsPathsResult$
    ];
    exports2.DescribeNetworkInterfaceAttribute$ = [
      9,
      n032,
      _DNIAes,
      0,
      () => exports2.DescribeNetworkInterfaceAttributeRequest$,
      () => exports2.DescribeNetworkInterfaceAttributeResult$
    ];
    exports2.DescribeNetworkInterfacePermissions$ = [
      9,
      n032,
      _DNIPesc,
      0,
      () => exports2.DescribeNetworkInterfacePermissionsRequest$,
      () => exports2.DescribeNetworkInterfacePermissionsResult$
    ];
    exports2.DescribeNetworkInterfaces$ = [
      9,
      n032,
      _DNIe,
      0,
      () => exports2.DescribeNetworkInterfacesRequest$,
      () => exports2.DescribeNetworkInterfacesResult$
    ];
    exports2.DescribeOutpostLags$ = [
      9,
      n032,
      _DOLe,
      0,
      () => exports2.DescribeOutpostLagsRequest$,
      () => exports2.DescribeOutpostLagsResult$
    ];
    exports2.DescribePlacementGroups$ = [
      9,
      n032,
      _DPGe,
      0,
      () => exports2.DescribePlacementGroupsRequest$,
      () => exports2.DescribePlacementGroupsResult$
    ];
    exports2.DescribePrefixLists$ = [
      9,
      n032,
      _DPLes,
      0,
      () => exports2.DescribePrefixListsRequest$,
      () => exports2.DescribePrefixListsResult$
    ];
    exports2.DescribePrincipalIdFormat$ = [
      9,
      n032,
      _DPIF,
      0,
      () => exports2.DescribePrincipalIdFormatRequest$,
      () => exports2.DescribePrincipalIdFormatResult$
    ];
    exports2.DescribePublicIpv4Pools$ = [
      9,
      n032,
      _DPIPe,
      0,
      () => exports2.DescribePublicIpv4PoolsRequest$,
      () => exports2.DescribePublicIpv4PoolsResult$
    ];
    exports2.DescribeRegions$ = [
      9,
      n032,
      _DRes,
      0,
      () => exports2.DescribeRegionsRequest$,
      () => exports2.DescribeRegionsResult$
    ];
    exports2.DescribeReplaceRootVolumeTasks$ = [
      9,
      n032,
      _DRRVT,
      0,
      () => exports2.DescribeReplaceRootVolumeTasksRequest$,
      () => exports2.DescribeReplaceRootVolumeTasksResult$
    ];
    exports2.DescribeReservedInstances$ = [
      9,
      n032,
      _DRI,
      0,
      () => exports2.DescribeReservedInstancesRequest$,
      () => exports2.DescribeReservedInstancesResult$
    ];
    exports2.DescribeReservedInstancesListings$ = [
      9,
      n032,
      _DRIL,
      0,
      () => exports2.DescribeReservedInstancesListingsRequest$,
      () => exports2.DescribeReservedInstancesListingsResult$
    ];
    exports2.DescribeReservedInstancesModifications$ = [
      9,
      n032,
      _DRIM,
      0,
      () => exports2.DescribeReservedInstancesModificationsRequest$,
      () => exports2.DescribeReservedInstancesModificationsResult$
    ];
    exports2.DescribeReservedInstancesOfferings$ = [
      9,
      n032,
      _DRIO,
      0,
      () => exports2.DescribeReservedInstancesOfferingsRequest$,
      () => exports2.DescribeReservedInstancesOfferingsResult$
    ];
    exports2.DescribeRouteServerEndpoints$ = [
      9,
      n032,
      _DRSEe,
      0,
      () => exports2.DescribeRouteServerEndpointsRequest$,
      () => exports2.DescribeRouteServerEndpointsResult$
    ];
    exports2.DescribeRouteServerPeers$ = [
      9,
      n032,
      _DRSPe,
      0,
      () => exports2.DescribeRouteServerPeersRequest$,
      () => exports2.DescribeRouteServerPeersResult$
    ];
    exports2.DescribeRouteServers$ = [
      9,
      n032,
      _DRSes,
      0,
      () => exports2.DescribeRouteServersRequest$,
      () => exports2.DescribeRouteServersResult$
    ];
    exports2.DescribeRouteTables$ = [
      9,
      n032,
      _DRTe,
      0,
      () => exports2.DescribeRouteTablesRequest$,
      () => exports2.DescribeRouteTablesResult$
    ];
    exports2.DescribeScheduledInstanceAvailability$ = [
      9,
      n032,
      _DSIA,
      0,
      () => exports2.DescribeScheduledInstanceAvailabilityRequest$,
      () => exports2.DescribeScheduledInstanceAvailabilityResult$
    ];
    exports2.DescribeScheduledInstances$ = [
      9,
      n032,
      _DSI,
      0,
      () => exports2.DescribeScheduledInstancesRequest$,
      () => exports2.DescribeScheduledInstancesResult$
    ];
    exports2.DescribeSecondaryInterfaces$ = [
      9,
      n032,
      _DSIe,
      0,
      () => exports2.DescribeSecondaryInterfacesRequest$,
      () => exports2.DescribeSecondaryInterfacesResult$
    ];
    exports2.DescribeSecondaryNetworks$ = [
      9,
      n032,
      _DSNe,
      0,
      () => exports2.DescribeSecondaryNetworksRequest$,
      () => exports2.DescribeSecondaryNetworksResult$
    ];
    exports2.DescribeSecondarySubnets$ = [
      9,
      n032,
      _DSSe,
      0,
      () => exports2.DescribeSecondarySubnetsRequest$,
      () => exports2.DescribeSecondarySubnetsResult$
    ];
    exports2.DescribeSecurityGroupReferences$ = [
      9,
      n032,
      _DSGRescr,
      0,
      () => exports2.DescribeSecurityGroupReferencesRequest$,
      () => exports2.DescribeSecurityGroupReferencesResult$
    ];
    exports2.DescribeSecurityGroupRules$ = [
      9,
      n032,
      _DSGRescri,
      0,
      () => exports2.DescribeSecurityGroupRulesRequest$,
      () => exports2.DescribeSecurityGroupRulesResult$
    ];
    exports2.DescribeSecurityGroups$ = [
      9,
      n032,
      _DSGe,
      0,
      () => exports2.DescribeSecurityGroupsRequest$,
      () => exports2.DescribeSecurityGroupsResult$
    ];
    exports2.DescribeSecurityGroupVpcAssociations$ = [
      9,
      n032,
      _DSGVA,
      0,
      () => exports2.DescribeSecurityGroupVpcAssociationsRequest$,
      () => exports2.DescribeSecurityGroupVpcAssociationsResult$
    ];
    exports2.DescribeServiceLinkVirtualInterfaces$ = [
      9,
      n032,
      _DSLVI,
      0,
      () => exports2.DescribeServiceLinkVirtualInterfacesRequest$,
      () => exports2.DescribeServiceLinkVirtualInterfacesResult$
    ];
    exports2.DescribeSnapshotAttribute$ = [
      9,
      n032,
      _DSAe,
      0,
      () => exports2.DescribeSnapshotAttributeRequest$,
      () => exports2.DescribeSnapshotAttributeResult$
    ];
    exports2.DescribeSnapshots$ = [
      9,
      n032,
      _DSes,
      0,
      () => exports2.DescribeSnapshotsRequest$,
      () => exports2.DescribeSnapshotsResult$
    ];
    exports2.DescribeSnapshotTierStatus$ = [
      9,
      n032,
      _DSTS,
      0,
      () => exports2.DescribeSnapshotTierStatusRequest$,
      () => exports2.DescribeSnapshotTierStatusResult$
    ];
    exports2.DescribeSpotDatafeedSubscription$ = [
      9,
      n032,
      _DSDSe,
      0,
      () => exports2.DescribeSpotDatafeedSubscriptionRequest$,
      () => exports2.DescribeSpotDatafeedSubscriptionResult$
    ];
    exports2.DescribeSpotFleetInstances$ = [
      9,
      n032,
      _DSFI,
      0,
      () => exports2.DescribeSpotFleetInstancesRequest$,
      () => exports2.DescribeSpotFleetInstancesResponse$
    ];
    exports2.DescribeSpotFleetRequestHistory$ = [
      9,
      n032,
      _DSFRH,
      0,
      () => exports2.DescribeSpotFleetRequestHistoryRequest$,
      () => exports2.DescribeSpotFleetRequestHistoryResponse$
    ];
    exports2.DescribeSpotFleetRequests$ = [
      9,
      n032,
      _DSFR,
      0,
      () => exports2.DescribeSpotFleetRequestsRequest$,
      () => exports2.DescribeSpotFleetRequestsResponse$
    ];
    exports2.DescribeSpotInstanceRequests$ = [
      9,
      n032,
      _DSIRescr,
      0,
      () => exports2.DescribeSpotInstanceRequestsRequest$,
      () => exports2.DescribeSpotInstanceRequestsResult$
    ];
    exports2.DescribeSpotPriceHistory$ = [
      9,
      n032,
      _DSPH,
      0,
      () => exports2.DescribeSpotPriceHistoryRequest$,
      () => exports2.DescribeSpotPriceHistoryResult$
    ];
    exports2.DescribeStaleSecurityGroups$ = [
      9,
      n032,
      _DSSG,
      0,
      () => exports2.DescribeStaleSecurityGroupsRequest$,
      () => exports2.DescribeStaleSecurityGroupsResult$
    ];
    exports2.DescribeStoreImageTasks$ = [
      9,
      n032,
      _DSIT,
      0,
      () => exports2.DescribeStoreImageTasksRequest$,
      () => exports2.DescribeStoreImageTasksResult$
    ];
    exports2.DescribeSubnets$ = [
      9,
      n032,
      _DSesc,
      0,
      () => exports2.DescribeSubnetsRequest$,
      () => exports2.DescribeSubnetsResult$
    ];
    exports2.DescribeTags$ = [
      9,
      n032,
      _DTes,
      0,
      () => exports2.DescribeTagsRequest$,
      () => exports2.DescribeTagsResult$
    ];
    exports2.DescribeTrafficMirrorFilterRules$ = [
      9,
      n032,
      _DTMFRescr,
      0,
      () => exports2.DescribeTrafficMirrorFilterRulesRequest$,
      () => exports2.DescribeTrafficMirrorFilterRulesResult$
    ];
    exports2.DescribeTrafficMirrorFilters$ = [
      9,
      n032,
      _DTMFe,
      0,
      () => exports2.DescribeTrafficMirrorFiltersRequest$,
      () => exports2.DescribeTrafficMirrorFiltersResult$
    ];
    exports2.DescribeTrafficMirrorSessions$ = [
      9,
      n032,
      _DTMSe,
      0,
      () => exports2.DescribeTrafficMirrorSessionsRequest$,
      () => exports2.DescribeTrafficMirrorSessionsResult$
    ];
    exports2.DescribeTrafficMirrorTargets$ = [
      9,
      n032,
      _DTMTe,
      0,
      () => exports2.DescribeTrafficMirrorTargetsRequest$,
      () => exports2.DescribeTrafficMirrorTargetsResult$
    ];
    exports2.DescribeTransitGatewayAttachments$ = [
      9,
      n032,
      _DTGA,
      0,
      () => exports2.DescribeTransitGatewayAttachmentsRequest$,
      () => exports2.DescribeTransitGatewayAttachmentsResult$
    ];
    exports2.DescribeTransitGatewayConnectPeers$ = [
      9,
      n032,
      _DTGCPe,
      0,
      () => exports2.DescribeTransitGatewayConnectPeersRequest$,
      () => exports2.DescribeTransitGatewayConnectPeersResult$
    ];
    exports2.DescribeTransitGatewayConnects$ = [
      9,
      n032,
      _DTGCe,
      0,
      () => exports2.DescribeTransitGatewayConnectsRequest$,
      () => exports2.DescribeTransitGatewayConnectsResult$
    ];
    exports2.DescribeTransitGatewayMeteringPolicies$ = [
      9,
      n032,
      _DTGMPe,
      0,
      () => exports2.DescribeTransitGatewayMeteringPoliciesRequest$,
      () => exports2.DescribeTransitGatewayMeteringPoliciesResult$
    ];
    exports2.DescribeTransitGatewayMulticastDomains$ = [
      9,
      n032,
      _DTGMDe,
      0,
      () => exports2.DescribeTransitGatewayMulticastDomainsRequest$,
      () => exports2.DescribeTransitGatewayMulticastDomainsResult$
    ];
    exports2.DescribeTransitGatewayPeeringAttachments$ = [
      9,
      n032,
      _DTGPAe,
      0,
      () => exports2.DescribeTransitGatewayPeeringAttachmentsRequest$,
      () => exports2.DescribeTransitGatewayPeeringAttachmentsResult$
    ];
    exports2.DescribeTransitGatewayPolicyTables$ = [
      9,
      n032,
      _DTGPTe,
      0,
      () => exports2.DescribeTransitGatewayPolicyTablesRequest$,
      () => exports2.DescribeTransitGatewayPolicyTablesResult$
    ];
    exports2.DescribeTransitGatewayRouteTableAnnouncements$ = [
      9,
      n032,
      _DTGRTAe,
      0,
      () => exports2.DescribeTransitGatewayRouteTableAnnouncementsRequest$,
      () => exports2.DescribeTransitGatewayRouteTableAnnouncementsResult$
    ];
    exports2.DescribeTransitGatewayRouteTables$ = [
      9,
      n032,
      _DTGRTe,
      0,
      () => exports2.DescribeTransitGatewayRouteTablesRequest$,
      () => exports2.DescribeTransitGatewayRouteTablesResult$
    ];
    exports2.DescribeTransitGateways$ = [
      9,
      n032,
      _DTGe,
      0,
      () => exports2.DescribeTransitGatewaysRequest$,
      () => exports2.DescribeTransitGatewaysResult$
    ];
    exports2.DescribeTransitGatewayVpcAttachments$ = [
      9,
      n032,
      _DTGVAe,
      0,
      () => exports2.DescribeTransitGatewayVpcAttachmentsRequest$,
      () => exports2.DescribeTransitGatewayVpcAttachmentsResult$
    ];
    exports2.DescribeTrunkInterfaceAssociations$ = [
      9,
      n032,
      _DTIA,
      0,
      () => exports2.DescribeTrunkInterfaceAssociationsRequest$,
      () => exports2.DescribeTrunkInterfaceAssociationsResult$
    ];
    exports2.DescribeVerifiedAccessEndpoints$ = [
      9,
      n032,
      _DVAEe,
      0,
      () => exports2.DescribeVerifiedAccessEndpointsRequest$,
      () => exports2.DescribeVerifiedAccessEndpointsResult$
    ];
    exports2.DescribeVerifiedAccessGroups$ = [
      9,
      n032,
      _DVAGe,
      0,
      () => exports2.DescribeVerifiedAccessGroupsRequest$,
      () => exports2.DescribeVerifiedAccessGroupsResult$
    ];
    exports2.DescribeVerifiedAccessInstanceLoggingConfigurations$ = [
      9,
      n032,
      _DVAILC,
      0,
      () => exports2.DescribeVerifiedAccessInstanceLoggingConfigurationsRequest$,
      () => exports2.DescribeVerifiedAccessInstanceLoggingConfigurationsResult$
    ];
    exports2.DescribeVerifiedAccessInstances$ = [
      9,
      n032,
      _DVAIe,
      0,
      () => exports2.DescribeVerifiedAccessInstancesRequest$,
      () => exports2.DescribeVerifiedAccessInstancesResult$
    ];
    exports2.DescribeVerifiedAccessTrustProviders$ = [
      9,
      n032,
      _DVATPe,
      0,
      () => exports2.DescribeVerifiedAccessTrustProvidersRequest$,
      () => exports2.DescribeVerifiedAccessTrustProvidersResult$
    ];
    exports2.DescribeVolumeAttribute$ = [
      9,
      n032,
      _DVA,
      0,
      () => exports2.DescribeVolumeAttributeRequest$,
      () => exports2.DescribeVolumeAttributeResult$
    ];
    exports2.DescribeVolumes$ = [
      9,
      n032,
      _DVes,
      0,
      () => exports2.DescribeVolumesRequest$,
      () => exports2.DescribeVolumesResult$
    ];
    exports2.DescribeVolumesModifications$ = [
      9,
      n032,
      _DVM,
      0,
      () => exports2.DescribeVolumesModificationsRequest$,
      () => exports2.DescribeVolumesModificationsResult$
    ];
    exports2.DescribeVolumeStatus$ = [
      9,
      n032,
      _DVS,
      0,
      () => exports2.DescribeVolumeStatusRequest$,
      () => exports2.DescribeVolumeStatusResult$
    ];
    exports2.DescribeVpcAttribute$ = [
      9,
      n032,
      _DVAe,
      0,
      () => exports2.DescribeVpcAttributeRequest$,
      () => exports2.DescribeVpcAttributeResult$
    ];
    exports2.DescribeVpcBlockPublicAccessExclusions$ = [
      9,
      n032,
      _DVBPAEe,
      0,
      () => exports2.DescribeVpcBlockPublicAccessExclusionsRequest$,
      () => exports2.DescribeVpcBlockPublicAccessExclusionsResult$
    ];
    exports2.DescribeVpcBlockPublicAccessOptions$ = [
      9,
      n032,
      _DVBPAO,
      0,
      () => exports2.DescribeVpcBlockPublicAccessOptionsRequest$,
      () => exports2.DescribeVpcBlockPublicAccessOptionsResult$
    ];
    exports2.DescribeVpcClassicLink$ = [
      9,
      n032,
      _DVCL,
      0,
      () => exports2.DescribeVpcClassicLinkRequest$,
      () => exports2.DescribeVpcClassicLinkResult$
    ];
    exports2.DescribeVpcClassicLinkDnsSupport$ = [
      9,
      n032,
      _DVCLDS,
      0,
      () => exports2.DescribeVpcClassicLinkDnsSupportRequest$,
      () => exports2.DescribeVpcClassicLinkDnsSupportResult$
    ];
    exports2.DescribeVpcEncryptionControls$ = [
      9,
      n032,
      _DVECe,
      0,
      () => exports2.DescribeVpcEncryptionControlsRequest$,
      () => exports2.DescribeVpcEncryptionControlsResult$
    ];
    exports2.DescribeVpcEndpointAssociations$ = [
      9,
      n032,
      _DVEA,
      0,
      () => exports2.DescribeVpcEndpointAssociationsRequest$,
      () => exports2.DescribeVpcEndpointAssociationsResult$
    ];
    exports2.DescribeVpcEndpointConnectionNotifications$ = [
      9,
      n032,
      _DVECNe,
      0,
      () => exports2.DescribeVpcEndpointConnectionNotificationsRequest$,
      () => exports2.DescribeVpcEndpointConnectionNotificationsResult$
    ];
    exports2.DescribeVpcEndpointConnections$ = [
      9,
      n032,
      _DVECes,
      0,
      () => exports2.DescribeVpcEndpointConnectionsRequest$,
      () => exports2.DescribeVpcEndpointConnectionsResult$
    ];
    exports2.DescribeVpcEndpoints$ = [
      9,
      n032,
      _DVEe,
      0,
      () => exports2.DescribeVpcEndpointsRequest$,
      () => exports2.DescribeVpcEndpointsResult$
    ];
    exports2.DescribeVpcEndpointServiceConfigurations$ = [
      9,
      n032,
      _DVESCe,
      0,
      () => exports2.DescribeVpcEndpointServiceConfigurationsRequest$,
      () => exports2.DescribeVpcEndpointServiceConfigurationsResult$
    ];
    exports2.DescribeVpcEndpointServicePermissions$ = [
      9,
      n032,
      _DVESP,
      0,
      () => exports2.DescribeVpcEndpointServicePermissionsRequest$,
      () => exports2.DescribeVpcEndpointServicePermissionsResult$
    ];
    exports2.DescribeVpcEndpointServices$ = [
      9,
      n032,
      _DVES,
      0,
      () => exports2.DescribeVpcEndpointServicesRequest$,
      () => exports2.DescribeVpcEndpointServicesResult$
    ];
    exports2.DescribeVpcPeeringConnections$ = [
      9,
      n032,
      _DVPCe,
      0,
      () => exports2.DescribeVpcPeeringConnectionsRequest$,
      () => exports2.DescribeVpcPeeringConnectionsResult$
    ];
    exports2.DescribeVpcs$ = [
      9,
      n032,
      _DVesc,
      0,
      () => exports2.DescribeVpcsRequest$,
      () => exports2.DescribeVpcsResult$
    ];
    exports2.DescribeVpnConcentrators$ = [
      9,
      n032,
      _DVCes,
      0,
      () => exports2.DescribeVpnConcentratorsRequest$,
      () => exports2.DescribeVpnConcentratorsResult$
    ];
    exports2.DescribeVpnConnections$ = [
      9,
      n032,
      _DVCesc,
      0,
      () => exports2.DescribeVpnConnectionsRequest$,
      () => exports2.DescribeVpnConnectionsResult$
    ];
    exports2.DescribeVpnGateways$ = [
      9,
      n032,
      _DVGe,
      0,
      () => exports2.DescribeVpnGatewaysRequest$,
      () => exports2.DescribeVpnGatewaysResult$
    ];
    exports2.DetachClassicLinkVpc$ = [
      9,
      n032,
      _DCLV,
      0,
      () => exports2.DetachClassicLinkVpcRequest$,
      () => exports2.DetachClassicLinkVpcResult$
    ];
    exports2.DetachInternetGateway$ = [
      9,
      n032,
      _DIGet,
      0,
      () => exports2.DetachInternetGatewayRequest$,
      () => __Unit
    ];
    exports2.DetachNetworkInterface$ = [
      9,
      n032,
      _DNIet,
      0,
      () => exports2.DetachNetworkInterfaceRequest$,
      () => __Unit
    ];
    exports2.DetachVerifiedAccessTrustProvider$ = [
      9,
      n032,
      _DVATPet,
      0,
      () => exports2.DetachVerifiedAccessTrustProviderRequest$,
      () => exports2.DetachVerifiedAccessTrustProviderResult$
    ];
    exports2.DetachVolume$ = [
      9,
      n032,
      _DVet,
      0,
      () => exports2.DetachVolumeRequest$,
      () => exports2.VolumeAttachment$
    ];
    exports2.DetachVpnGateway$ = [
      9,
      n032,
      _DVGet,
      0,
      () => exports2.DetachVpnGatewayRequest$,
      () => __Unit
    ];
    exports2.DisableAddressTransfer$ = [
      9,
      n032,
      _DATi,
      0,
      () => exports2.DisableAddressTransferRequest$,
      () => exports2.DisableAddressTransferResult$
    ];
    exports2.DisableAllowedImagesSettings$ = [
      9,
      n032,
      _DAIS,
      0,
      () => exports2.DisableAllowedImagesSettingsRequest$,
      () => exports2.DisableAllowedImagesSettingsResult$
    ];
    exports2.DisableAwsNetworkPerformanceMetricSubscription$ = [
      9,
      n032,
      _DANPMSi,
      0,
      () => exports2.DisableAwsNetworkPerformanceMetricSubscriptionRequest$,
      () => exports2.DisableAwsNetworkPerformanceMetricSubscriptionResult$
    ];
    exports2.DisableCapacityManager$ = [
      9,
      n032,
      _DCM,
      0,
      () => exports2.DisableCapacityManagerRequest$,
      () => exports2.DisableCapacityManagerResult$
    ];
    exports2.DisableEbsEncryptionByDefault$ = [
      9,
      n032,
      _DEEBD,
      0,
      () => exports2.DisableEbsEncryptionByDefaultRequest$,
      () => exports2.DisableEbsEncryptionByDefaultResult$
    ];
    exports2.DisableFastLaunch$ = [
      9,
      n032,
      _DFLi,
      0,
      () => exports2.DisableFastLaunchRequest$,
      () => exports2.DisableFastLaunchResult$
    ];
    exports2.DisableFastSnapshotRestores$ = [
      9,
      n032,
      _DFSRi,
      0,
      () => exports2.DisableFastSnapshotRestoresRequest$,
      () => exports2.DisableFastSnapshotRestoresResult$
    ];
    exports2.DisableImage$ = [
      9,
      n032,
      _DIisa,
      0,
      () => exports2.DisableImageRequest$,
      () => exports2.DisableImageResult$
    ];
    exports2.DisableImageBlockPublicAccess$ = [
      9,
      n032,
      _DIBPA,
      0,
      () => exports2.DisableImageBlockPublicAccessRequest$,
      () => exports2.DisableImageBlockPublicAccessResult$
    ];
    exports2.DisableImageDeprecation$ = [
      9,
      n032,
      _DIDis,
      0,
      () => exports2.DisableImageDeprecationRequest$,
      () => exports2.DisableImageDeprecationResult$
    ];
    exports2.DisableImageDeregistrationProtection$ = [
      9,
      n032,
      _DIDP,
      0,
      () => exports2.DisableImageDeregistrationProtectionRequest$,
      () => exports2.DisableImageDeregistrationProtectionResult$
    ];
    exports2.DisableInstanceSqlHaStandbyDetections$ = [
      9,
      n032,
      _DISHSD,
      0,
      () => exports2.DisableInstanceSqlHaStandbyDetectionsRequest$,
      () => exports2.DisableInstanceSqlHaStandbyDetectionsResult$
    ];
    exports2.DisableIpamOrganizationAdminAccount$ = [
      9,
      n032,
      _DIOAA,
      0,
      () => exports2.DisableIpamOrganizationAdminAccountRequest$,
      () => exports2.DisableIpamOrganizationAdminAccountResult$
    ];
    exports2.DisableIpamPolicy$ = [
      9,
      n032,
      _DIPi,
      0,
      () => exports2.DisableIpamPolicyRequest$,
      () => exports2.DisableIpamPolicyResult$
    ];
    exports2.DisableRouteServerPropagation$ = [
      9,
      n032,
      _DRSPi,
      0,
      () => exports2.DisableRouteServerPropagationRequest$,
      () => exports2.DisableRouteServerPropagationResult$
    ];
    exports2.DisableSerialConsoleAccess$ = [
      9,
      n032,
      _DSCA,
      0,
      () => exports2.DisableSerialConsoleAccessRequest$,
      () => exports2.DisableSerialConsoleAccessResult$
    ];
    exports2.DisableSnapshotBlockPublicAccess$ = [
      9,
      n032,
      _DSBPA,
      0,
      () => exports2.DisableSnapshotBlockPublicAccessRequest$,
      () => exports2.DisableSnapshotBlockPublicAccessResult$
    ];
    exports2.DisableTransitGatewayRouteTablePropagation$ = [
      9,
      n032,
      _DTGRTP,
      0,
      () => exports2.DisableTransitGatewayRouteTablePropagationRequest$,
      () => exports2.DisableTransitGatewayRouteTablePropagationResult$
    ];
    exports2.DisableVgwRoutePropagation$ = [
      9,
      n032,
      _DVRP,
      0,
      () => exports2.DisableVgwRoutePropagationRequest$,
      () => __Unit
    ];
    exports2.DisableVpcClassicLink$ = [
      9,
      n032,
      _DVCLi,
      0,
      () => exports2.DisableVpcClassicLinkRequest$,
      () => exports2.DisableVpcClassicLinkResult$
    ];
    exports2.DisableVpcClassicLinkDnsSupport$ = [
      9,
      n032,
      _DVCLDSi,
      0,
      () => exports2.DisableVpcClassicLinkDnsSupportRequest$,
      () => exports2.DisableVpcClassicLinkDnsSupportResult$
    ];
    exports2.DisassociateAddress$ = [
      9,
      n032,
      _DAi,
      0,
      () => exports2.DisassociateAddressRequest$,
      () => __Unit
    ];
    exports2.DisassociateCapacityReservationBillingOwner$ = [
      9,
      n032,
      _DCRBO,
      0,
      () => exports2.DisassociateCapacityReservationBillingOwnerRequest$,
      () => exports2.DisassociateCapacityReservationBillingOwnerResult$
    ];
    exports2.DisassociateClientVpnTargetNetwork$ = [
      9,
      n032,
      _DCVTNi,
      0,
      () => exports2.DisassociateClientVpnTargetNetworkRequest$,
      () => exports2.DisassociateClientVpnTargetNetworkResult$
    ];
    exports2.DisassociateEnclaveCertificateIamRole$ = [
      9,
      n032,
      _DECIR,
      0,
      () => exports2.DisassociateEnclaveCertificateIamRoleRequest$,
      () => exports2.DisassociateEnclaveCertificateIamRoleResult$
    ];
    exports2.DisassociateIamInstanceProfile$ = [
      9,
      n032,
      _DIIP,
      0,
      () => exports2.DisassociateIamInstanceProfileRequest$,
      () => exports2.DisassociateIamInstanceProfileResult$
    ];
    exports2.DisassociateInstanceEventWindow$ = [
      9,
      n032,
      _DIEWi,
      0,
      () => exports2.DisassociateInstanceEventWindowRequest$,
      () => exports2.DisassociateInstanceEventWindowResult$
    ];
    exports2.DisassociateIpamByoasn$ = [
      9,
      n032,
      _DIBi,
      0,
      () => exports2.DisassociateIpamByoasnRequest$,
      () => exports2.DisassociateIpamByoasnResult$
    ];
    exports2.DisassociateIpamResourceDiscovery$ = [
      9,
      n032,
      _DIRDi,
      0,
      () => exports2.DisassociateIpamResourceDiscoveryRequest$,
      () => exports2.DisassociateIpamResourceDiscoveryResult$
    ];
    exports2.DisassociateNatGatewayAddress$ = [
      9,
      n032,
      _DNGA,
      0,
      () => exports2.DisassociateNatGatewayAddressRequest$,
      () => exports2.DisassociateNatGatewayAddressResult$
    ];
    exports2.DisassociateRouteServer$ = [
      9,
      n032,
      _DRSi,
      0,
      () => exports2.DisassociateRouteServerRequest$,
      () => exports2.DisassociateRouteServerResult$
    ];
    exports2.DisassociateRouteTable$ = [
      9,
      n032,
      _DRTi,
      0,
      () => exports2.DisassociateRouteTableRequest$,
      () => __Unit
    ];
    exports2.DisassociateSecurityGroupVpc$ = [
      9,
      n032,
      _DSGV,
      0,
      () => exports2.DisassociateSecurityGroupVpcRequest$,
      () => exports2.DisassociateSecurityGroupVpcResult$
    ];
    exports2.DisassociateSubnetCidrBlock$ = [
      9,
      n032,
      _DSCB,
      0,
      () => exports2.DisassociateSubnetCidrBlockRequest$,
      () => exports2.DisassociateSubnetCidrBlockResult$
    ];
    exports2.DisassociateTransitGatewayMulticastDomain$ = [
      9,
      n032,
      _DTGMDi,
      0,
      () => exports2.DisassociateTransitGatewayMulticastDomainRequest$,
      () => exports2.DisassociateTransitGatewayMulticastDomainResult$
    ];
    exports2.DisassociateTransitGatewayPolicyTable$ = [
      9,
      n032,
      _DTGPTi,
      0,
      () => exports2.DisassociateTransitGatewayPolicyTableRequest$,
      () => exports2.DisassociateTransitGatewayPolicyTableResult$
    ];
    exports2.DisassociateTransitGatewayRouteTable$ = [
      9,
      n032,
      _DTGRTi,
      0,
      () => exports2.DisassociateTransitGatewayRouteTableRequest$,
      () => exports2.DisassociateTransitGatewayRouteTableResult$
    ];
    exports2.DisassociateTrunkInterface$ = [
      9,
      n032,
      _DTI,
      0,
      () => exports2.DisassociateTrunkInterfaceRequest$,
      () => exports2.DisassociateTrunkInterfaceResult$
    ];
    exports2.DisassociateVpcCidrBlock$ = [
      9,
      n032,
      _DVCB,
      0,
      () => exports2.DisassociateVpcCidrBlockRequest$,
      () => exports2.DisassociateVpcCidrBlockResult$
    ];
    exports2.EnableAddressTransfer$ = [
      9,
      n032,
      _EAT,
      0,
      () => exports2.EnableAddressTransferRequest$,
      () => exports2.EnableAddressTransferResult$
    ];
    exports2.EnableAllowedImagesSettings$ = [
      9,
      n032,
      _EAIS,
      0,
      () => exports2.EnableAllowedImagesSettingsRequest$,
      () => exports2.EnableAllowedImagesSettingsResult$
    ];
    exports2.EnableAwsNetworkPerformanceMetricSubscription$ = [
      9,
      n032,
      _EANPMS,
      0,
      () => exports2.EnableAwsNetworkPerformanceMetricSubscriptionRequest$,
      () => exports2.EnableAwsNetworkPerformanceMetricSubscriptionResult$
    ];
    exports2.EnableCapacityManager$ = [
      9,
      n032,
      _ECM,
      0,
      () => exports2.EnableCapacityManagerRequest$,
      () => exports2.EnableCapacityManagerResult$
    ];
    exports2.EnableEbsEncryptionByDefault$ = [
      9,
      n032,
      _EEEBD,
      0,
      () => exports2.EnableEbsEncryptionByDefaultRequest$,
      () => exports2.EnableEbsEncryptionByDefaultResult$
    ];
    exports2.EnableFastLaunch$ = [
      9,
      n032,
      _EFL,
      0,
      () => exports2.EnableFastLaunchRequest$,
      () => exports2.EnableFastLaunchResult$
    ];
    exports2.EnableFastSnapshotRestores$ = [
      9,
      n032,
      _EFSR,
      0,
      () => exports2.EnableFastSnapshotRestoresRequest$,
      () => exports2.EnableFastSnapshotRestoresResult$
    ];
    exports2.EnableImage$ = [
      9,
      n032,
      _EIna,
      0,
      () => exports2.EnableImageRequest$,
      () => exports2.EnableImageResult$
    ];
    exports2.EnableImageBlockPublicAccess$ = [
      9,
      n032,
      _EIBPA,
      0,
      () => exports2.EnableImageBlockPublicAccessRequest$,
      () => exports2.EnableImageBlockPublicAccessResult$
    ];
    exports2.EnableImageDeprecation$ = [
      9,
      n032,
      _EID,
      0,
      () => exports2.EnableImageDeprecationRequest$,
      () => exports2.EnableImageDeprecationResult$
    ];
    exports2.EnableImageDeregistrationProtection$ = [
      9,
      n032,
      _EIDP,
      0,
      () => exports2.EnableImageDeregistrationProtectionRequest$,
      () => exports2.EnableImageDeregistrationProtectionResult$
    ];
    exports2.EnableInstanceSqlHaStandbyDetections$ = [
      9,
      n032,
      _EISHSD,
      0,
      () => exports2.EnableInstanceSqlHaStandbyDetectionsRequest$,
      () => exports2.EnableInstanceSqlHaStandbyDetectionsResult$
    ];
    exports2.EnableIpamOrganizationAdminAccount$ = [
      9,
      n032,
      _EIOAA,
      0,
      () => exports2.EnableIpamOrganizationAdminAccountRequest$,
      () => exports2.EnableIpamOrganizationAdminAccountResult$
    ];
    exports2.EnableIpamPolicy$ = [
      9,
      n032,
      _EIP,
      0,
      () => exports2.EnableIpamPolicyRequest$,
      () => exports2.EnableIpamPolicyResult$
    ];
    exports2.EnableReachabilityAnalyzerOrganizationSharing$ = [
      9,
      n032,
      _ERAOS,
      0,
      () => exports2.EnableReachabilityAnalyzerOrganizationSharingRequest$,
      () => exports2.EnableReachabilityAnalyzerOrganizationSharingResult$
    ];
    exports2.EnableRouteServerPropagation$ = [
      9,
      n032,
      _ERSP,
      0,
      () => exports2.EnableRouteServerPropagationRequest$,
      () => exports2.EnableRouteServerPropagationResult$
    ];
    exports2.EnableSerialConsoleAccess$ = [
      9,
      n032,
      _ESCA,
      0,
      () => exports2.EnableSerialConsoleAccessRequest$,
      () => exports2.EnableSerialConsoleAccessResult$
    ];
    exports2.EnableSnapshotBlockPublicAccess$ = [
      9,
      n032,
      _ESBPA,
      0,
      () => exports2.EnableSnapshotBlockPublicAccessRequest$,
      () => exports2.EnableSnapshotBlockPublicAccessResult$
    ];
    exports2.EnableTransitGatewayRouteTablePropagation$ = [
      9,
      n032,
      _ETGRTP,
      0,
      () => exports2.EnableTransitGatewayRouteTablePropagationRequest$,
      () => exports2.EnableTransitGatewayRouteTablePropagationResult$
    ];
    exports2.EnableVgwRoutePropagation$ = [
      9,
      n032,
      _EVRP,
      0,
      () => exports2.EnableVgwRoutePropagationRequest$,
      () => __Unit
    ];
    exports2.EnableVolumeIO$ = [
      9,
      n032,
      _EVIO,
      0,
      () => exports2.EnableVolumeIORequest$,
      () => __Unit
    ];
    exports2.EnableVpcClassicLink$ = [
      9,
      n032,
      _EVCL,
      0,
      () => exports2.EnableVpcClassicLinkRequest$,
      () => exports2.EnableVpcClassicLinkResult$
    ];
    exports2.EnableVpcClassicLinkDnsSupport$ = [
      9,
      n032,
      _EVCLDS,
      0,
      () => exports2.EnableVpcClassicLinkDnsSupportRequest$,
      () => exports2.EnableVpcClassicLinkDnsSupportResult$
    ];
    exports2.ExportClientVpnClientCertificateRevocationList$ = [
      9,
      n032,
      _ECVCCRL,
      0,
      () => exports2.ExportClientVpnClientCertificateRevocationListRequest$,
      () => exports2.ExportClientVpnClientCertificateRevocationListResult$
    ];
    exports2.ExportClientVpnClientConfiguration$ = [
      9,
      n032,
      _ECVCC,
      0,
      () => exports2.ExportClientVpnClientConfigurationRequest$,
      () => exports2.ExportClientVpnClientConfigurationResult$
    ];
    exports2.ExportImage$ = [
      9,
      n032,
      _EIxp,
      0,
      () => exports2.ExportImageRequest$,
      () => exports2.ExportImageResult$
    ];
    exports2.ExportTransitGatewayRoutes$ = [
      9,
      n032,
      _ETGR,
      0,
      () => exports2.ExportTransitGatewayRoutesRequest$,
      () => exports2.ExportTransitGatewayRoutesResult$
    ];
    exports2.ExportVerifiedAccessInstanceClientConfiguration$ = [
      9,
      n032,
      _EVAICC,
      0,
      () => exports2.ExportVerifiedAccessInstanceClientConfigurationRequest$,
      () => exports2.ExportVerifiedAccessInstanceClientConfigurationResult$
    ];
    exports2.GetActiveVpnTunnelStatus$ = [
      9,
      n032,
      _GAVTS,
      0,
      () => exports2.GetActiveVpnTunnelStatusRequest$,
      () => exports2.GetActiveVpnTunnelStatusResult$
    ];
    exports2.GetAllowedImagesSettings$ = [
      9,
      n032,
      _GAIS,
      0,
      () => exports2.GetAllowedImagesSettingsRequest$,
      () => exports2.GetAllowedImagesSettingsResult$
    ];
    exports2.GetAssociatedEnclaveCertificateIamRoles$ = [
      9,
      n032,
      _GAECIR,
      0,
      () => exports2.GetAssociatedEnclaveCertificateIamRolesRequest$,
      () => exports2.GetAssociatedEnclaveCertificateIamRolesResult$
    ];
    exports2.GetAssociatedIpv6PoolCidrs$ = [
      9,
      n032,
      _GAIPC,
      0,
      () => exports2.GetAssociatedIpv6PoolCidrsRequest$,
      () => exports2.GetAssociatedIpv6PoolCidrsResult$
    ];
    exports2.GetAwsNetworkPerformanceData$ = [
      9,
      n032,
      _GANPD,
      0,
      () => exports2.GetAwsNetworkPerformanceDataRequest$,
      () => exports2.GetAwsNetworkPerformanceDataResult$
    ];
    exports2.GetCapacityManagerAttributes$ = [
      9,
      n032,
      _GCMA,
      0,
      () => exports2.GetCapacityManagerAttributesRequest$,
      () => exports2.GetCapacityManagerAttributesResult$
    ];
    exports2.GetCapacityManagerMetricData$ = [
      9,
      n032,
      _GCMMD,
      0,
      () => exports2.GetCapacityManagerMetricDataRequest$,
      () => exports2.GetCapacityManagerMetricDataResult$
    ];
    exports2.GetCapacityManagerMetricDimensions$ = [
      9,
      n032,
      _GCMMDe,
      0,
      () => exports2.GetCapacityManagerMetricDimensionsRequest$,
      () => exports2.GetCapacityManagerMetricDimensionsResult$
    ];
    exports2.GetCapacityManagerMonitoredTagKeys$ = [
      9,
      n032,
      _GCMMTK,
      0,
      () => exports2.GetCapacityManagerMonitoredTagKeysRequest$,
      () => exports2.GetCapacityManagerMonitoredTagKeysResult$
    ];
    exports2.GetCapacityReservationUsage$ = [
      9,
      n032,
      _GCRU,
      0,
      () => exports2.GetCapacityReservationUsageRequest$,
      () => exports2.GetCapacityReservationUsageResult$
    ];
    exports2.GetCoipPoolUsage$ = [
      9,
      n032,
      _GCPU,
      0,
      () => exports2.GetCoipPoolUsageRequest$,
      () => exports2.GetCoipPoolUsageResult$
    ];
    exports2.GetConsoleOutput$ = [
      9,
      n032,
      _GCO,
      0,
      () => exports2.GetConsoleOutputRequest$,
      () => exports2.GetConsoleOutputResult$
    ];
    exports2.GetConsoleScreenshot$ = [
      9,
      n032,
      _GCS,
      0,
      () => exports2.GetConsoleScreenshotRequest$,
      () => exports2.GetConsoleScreenshotResult$
    ];
    exports2.GetDeclarativePoliciesReportSummary$ = [
      9,
      n032,
      _GDPRS,
      0,
      () => exports2.GetDeclarativePoliciesReportSummaryRequest$,
      () => exports2.GetDeclarativePoliciesReportSummaryResult$
    ];
    exports2.GetDefaultCreditSpecification$ = [
      9,
      n032,
      _GDCS,
      0,
      () => exports2.GetDefaultCreditSpecificationRequest$,
      () => exports2.GetDefaultCreditSpecificationResult$
    ];
    exports2.GetEbsDefaultKmsKeyId$ = [
      9,
      n032,
      _GEDKKI,
      0,
      () => exports2.GetEbsDefaultKmsKeyIdRequest$,
      () => exports2.GetEbsDefaultKmsKeyIdResult$
    ];
    exports2.GetEbsEncryptionByDefault$ = [
      9,
      n032,
      _GEEBD,
      0,
      () => exports2.GetEbsEncryptionByDefaultRequest$,
      () => exports2.GetEbsEncryptionByDefaultResult$
    ];
    exports2.GetEnabledIpamPolicy$ = [
      9,
      n032,
      _GEIP,
      0,
      () => exports2.GetEnabledIpamPolicyRequest$,
      () => exports2.GetEnabledIpamPolicyResult$
    ];
    exports2.GetFlowLogsIntegrationTemplate$ = [
      9,
      n032,
      _GFLIT,
      0,
      () => exports2.GetFlowLogsIntegrationTemplateRequest$,
      () => exports2.GetFlowLogsIntegrationTemplateResult$
    ];
    exports2.GetGroupsForCapacityReservation$ = [
      9,
      n032,
      _GGFCR,
      0,
      () => exports2.GetGroupsForCapacityReservationRequest$,
      () => exports2.GetGroupsForCapacityReservationResult$
    ];
    exports2.GetHostReservationPurchasePreview$ = [
      9,
      n032,
      _GHRPP,
      0,
      () => exports2.GetHostReservationPurchasePreviewRequest$,
      () => exports2.GetHostReservationPurchasePreviewResult$
    ];
    exports2.GetImageAncestry$ = [
      9,
      n032,
      _GIAe,
      0,
      () => exports2.GetImageAncestryRequest$,
      () => exports2.GetImageAncestryResult$
    ];
    exports2.GetImageBlockPublicAccessState$ = [
      9,
      n032,
      _GIBPAS,
      0,
      () => exports2.GetImageBlockPublicAccessStateRequest$,
      () => exports2.GetImageBlockPublicAccessStateResult$
    ];
    exports2.GetInstanceMetadataDefaults$ = [
      9,
      n032,
      _GIMD,
      0,
      () => exports2.GetInstanceMetadataDefaultsRequest$,
      () => exports2.GetInstanceMetadataDefaultsResult$
    ];
    exports2.GetInstanceTpmEkPub$ = [
      9,
      n032,
      _GITEP,
      0,
      () => exports2.GetInstanceTpmEkPubRequest$,
      () => exports2.GetInstanceTpmEkPubResult$
    ];
    exports2.GetInstanceTypesFromInstanceRequirements$ = [
      9,
      n032,
      _GITFIR,
      0,
      () => exports2.GetInstanceTypesFromInstanceRequirementsRequest$,
      () => exports2.GetInstanceTypesFromInstanceRequirementsResult$
    ];
    exports2.GetInstanceUefiData$ = [
      9,
      n032,
      _GIUD,
      0,
      () => exports2.GetInstanceUefiDataRequest$,
      () => exports2.GetInstanceUefiDataResult$
    ];
    exports2.GetIpamAddressHistory$ = [
      9,
      n032,
      _GIAH,
      0,
      () => exports2.GetIpamAddressHistoryRequest$,
      () => exports2.GetIpamAddressHistoryResult$
    ];
    exports2.GetIpamDiscoveredAccounts$ = [
      9,
      n032,
      _GIDA,
      0,
      () => exports2.GetIpamDiscoveredAccountsRequest$,
      () => exports2.GetIpamDiscoveredAccountsResult$
    ];
    exports2.GetIpamDiscoveredPublicAddresses$ = [
      9,
      n032,
      _GIDPA,
      0,
      () => exports2.GetIpamDiscoveredPublicAddressesRequest$,
      () => exports2.GetIpamDiscoveredPublicAddressesResult$
    ];
    exports2.GetIpamDiscoveredResourceCidrs$ = [
      9,
      n032,
      _GIDRC,
      0,
      () => exports2.GetIpamDiscoveredResourceCidrsRequest$,
      () => exports2.GetIpamDiscoveredResourceCidrsResult$
    ];
    exports2.GetIpamPolicyAllocationRules$ = [
      9,
      n032,
      _GIPARet,
      0,
      () => exports2.GetIpamPolicyAllocationRulesRequest$,
      () => exports2.GetIpamPolicyAllocationRulesResult$
    ];
    exports2.GetIpamPolicyOrganizationTargets$ = [
      9,
      n032,
      _GIPOT,
      0,
      () => exports2.GetIpamPolicyOrganizationTargetsRequest$,
      () => exports2.GetIpamPolicyOrganizationTargetsResult$
    ];
    exports2.GetIpamPoolAllocations$ = [
      9,
      n032,
      _GIPA,
      0,
      () => exports2.GetIpamPoolAllocationsRequest$,
      () => exports2.GetIpamPoolAllocationsResult$
    ];
    exports2.GetIpamPoolCidrs$ = [
      9,
      n032,
      _GIPC,
      0,
      () => exports2.GetIpamPoolCidrsRequest$,
      () => exports2.GetIpamPoolCidrsResult$
    ];
    exports2.GetIpamPrefixListResolverRules$ = [
      9,
      n032,
      _GIPLRR,
      0,
      () => exports2.GetIpamPrefixListResolverRulesRequest$,
      () => exports2.GetIpamPrefixListResolverRulesResult$
    ];
    exports2.GetIpamPrefixListResolverVersionEntries$ = [
      9,
      n032,
      _GIPLRVE,
      0,
      () => exports2.GetIpamPrefixListResolverVersionEntriesRequest$,
      () => exports2.GetIpamPrefixListResolverVersionEntriesResult$
    ];
    exports2.GetIpamPrefixListResolverVersions$ = [
      9,
      n032,
      _GIPLRV,
      0,
      () => exports2.GetIpamPrefixListResolverVersionsRequest$,
      () => exports2.GetIpamPrefixListResolverVersionsResult$
    ];
    exports2.GetIpamResourceCidrs$ = [
      9,
      n032,
      _GIRC,
      0,
      () => exports2.GetIpamResourceCidrsRequest$,
      () => exports2.GetIpamResourceCidrsResult$
    ];
    exports2.GetLaunchTemplateData$ = [
      9,
      n032,
      _GLTD,
      0,
      () => exports2.GetLaunchTemplateDataRequest$,
      () => exports2.GetLaunchTemplateDataResult$
    ];
    exports2.GetManagedPrefixListAssociations$ = [
      9,
      n032,
      _GMPLA,
      0,
      () => exports2.GetManagedPrefixListAssociationsRequest$,
      () => exports2.GetManagedPrefixListAssociationsResult$
    ];
    exports2.GetManagedPrefixListEntries$ = [
      9,
      n032,
      _GMPLE,
      0,
      () => exports2.GetManagedPrefixListEntriesRequest$,
      () => exports2.GetManagedPrefixListEntriesResult$
    ];
    exports2.GetManagedResourceVisibility$ = [
      9,
      n032,
      _GMRV,
      0,
      () => exports2.GetManagedResourceVisibilityRequest$,
      () => exports2.GetManagedResourceVisibilityResult$
    ];
    exports2.GetNetworkInsightsAccessScopeAnalysisFindings$ = [
      9,
      n032,
      _GNIASAF,
      0,
      () => exports2.GetNetworkInsightsAccessScopeAnalysisFindingsRequest$,
      () => exports2.GetNetworkInsightsAccessScopeAnalysisFindingsResult$
    ];
    exports2.GetNetworkInsightsAccessScopeContent$ = [
      9,
      n032,
      _GNIASC,
      0,
      () => exports2.GetNetworkInsightsAccessScopeContentRequest$,
      () => exports2.GetNetworkInsightsAccessScopeContentResult$
    ];
    exports2.GetPasswordData$ = [
      9,
      n032,
      _GPD,
      0,
      () => exports2.GetPasswordDataRequest$,
      () => exports2.GetPasswordDataResult$
    ];
    exports2.GetReservedInstancesExchangeQuote$ = [
      9,
      n032,
      _GRIEQ,
      0,
      () => exports2.GetReservedInstancesExchangeQuoteRequest$,
      () => exports2.GetReservedInstancesExchangeQuoteResult$
    ];
    exports2.GetRouteServerAssociations$ = [
      9,
      n032,
      _GRSA,
      0,
      () => exports2.GetRouteServerAssociationsRequest$,
      () => exports2.GetRouteServerAssociationsResult$
    ];
    exports2.GetRouteServerPropagations$ = [
      9,
      n032,
      _GRSP,
      0,
      () => exports2.GetRouteServerPropagationsRequest$,
      () => exports2.GetRouteServerPropagationsResult$
    ];
    exports2.GetRouteServerRoutingDatabase$ = [
      9,
      n032,
      _GRSRD,
      0,
      () => exports2.GetRouteServerRoutingDatabaseRequest$,
      () => exports2.GetRouteServerRoutingDatabaseResult$
    ];
    exports2.GetSecurityGroupsForVpc$ = [
      9,
      n032,
      _GSGFV,
      0,
      () => exports2.GetSecurityGroupsForVpcRequest$,
      () => exports2.GetSecurityGroupsForVpcResult$
    ];
    exports2.GetSerialConsoleAccessStatus$ = [
      9,
      n032,
      _GSCAS,
      0,
      () => exports2.GetSerialConsoleAccessStatusRequest$,
      () => exports2.GetSerialConsoleAccessStatusResult$
    ];
    exports2.GetSnapshotBlockPublicAccessState$ = [
      9,
      n032,
      _GSBPAS,
      0,
      () => exports2.GetSnapshotBlockPublicAccessStateRequest$,
      () => exports2.GetSnapshotBlockPublicAccessStateResult$
    ];
    exports2.GetSpotPlacementScores$ = [
      9,
      n032,
      _GSPS,
      0,
      () => exports2.GetSpotPlacementScoresRequest$,
      () => exports2.GetSpotPlacementScoresResult$
    ];
    exports2.GetSubnetCidrReservations$ = [
      9,
      n032,
      _GSCR,
      0,
      () => exports2.GetSubnetCidrReservationsRequest$,
      () => exports2.GetSubnetCidrReservationsResult$
    ];
    exports2.GetTransitGatewayAttachmentPropagations$ = [
      9,
      n032,
      _GTGAP,
      0,
      () => exports2.GetTransitGatewayAttachmentPropagationsRequest$,
      () => exports2.GetTransitGatewayAttachmentPropagationsResult$
    ];
    exports2.GetTransitGatewayMeteringPolicyEntries$ = [
      9,
      n032,
      _GTGMPE,
      0,
      () => exports2.GetTransitGatewayMeteringPolicyEntriesRequest$,
      () => exports2.GetTransitGatewayMeteringPolicyEntriesResult$
    ];
    exports2.GetTransitGatewayMulticastDomainAssociations$ = [
      9,
      n032,
      _GTGMDA,
      0,
      () => exports2.GetTransitGatewayMulticastDomainAssociationsRequest$,
      () => exports2.GetTransitGatewayMulticastDomainAssociationsResult$
    ];
    exports2.GetTransitGatewayPolicyTableAssociations$ = [
      9,
      n032,
      _GTGPTA,
      0,
      () => exports2.GetTransitGatewayPolicyTableAssociationsRequest$,
      () => exports2.GetTransitGatewayPolicyTableAssociationsResult$
    ];
    exports2.GetTransitGatewayPolicyTableEntries$ = [
      9,
      n032,
      _GTGPTE,
      0,
      () => exports2.GetTransitGatewayPolicyTableEntriesRequest$,
      () => exports2.GetTransitGatewayPolicyTableEntriesResult$
    ];
    exports2.GetTransitGatewayPrefixListReferences$ = [
      9,
      n032,
      _GTGPLR,
      0,
      () => exports2.GetTransitGatewayPrefixListReferencesRequest$,
      () => exports2.GetTransitGatewayPrefixListReferencesResult$
    ];
    exports2.GetTransitGatewayRouteTableAssociations$ = [
      9,
      n032,
      _GTGRTA,
      0,
      () => exports2.GetTransitGatewayRouteTableAssociationsRequest$,
      () => exports2.GetTransitGatewayRouteTableAssociationsResult$
    ];
    exports2.GetTransitGatewayRouteTablePropagations$ = [
      9,
      n032,
      _GTGRTP,
      0,
      () => exports2.GetTransitGatewayRouteTablePropagationsRequest$,
      () => exports2.GetTransitGatewayRouteTablePropagationsResult$
    ];
    exports2.GetVerifiedAccessEndpointPolicy$ = [
      9,
      n032,
      _GVAEP,
      0,
      () => exports2.GetVerifiedAccessEndpointPolicyRequest$,
      () => exports2.GetVerifiedAccessEndpointPolicyResult$
    ];
    exports2.GetVerifiedAccessEndpointTargets$ = [
      9,
      n032,
      _GVAET,
      0,
      () => exports2.GetVerifiedAccessEndpointTargetsRequest$,
      () => exports2.GetVerifiedAccessEndpointTargetsResult$
    ];
    exports2.GetVerifiedAccessGroupPolicy$ = [
      9,
      n032,
      _GVAGP,
      0,
      () => exports2.GetVerifiedAccessGroupPolicyRequest$,
      () => exports2.GetVerifiedAccessGroupPolicyResult$
    ];
    exports2.GetVpcResourcesBlockingEncryptionEnforcement$ = [
      9,
      n032,
      _GVRBEE,
      0,
      () => exports2.GetVpcResourcesBlockingEncryptionEnforcementRequest$,
      () => exports2.GetVpcResourcesBlockingEncryptionEnforcementResult$
    ];
    exports2.GetVpnConnectionDeviceSampleConfiguration$ = [
      9,
      n032,
      _GVCDSC,
      0,
      () => exports2.GetVpnConnectionDeviceSampleConfigurationRequest$,
      () => exports2.GetVpnConnectionDeviceSampleConfigurationResult$
    ];
    exports2.GetVpnConnectionDeviceTypes$ = [
      9,
      n032,
      _GVCDT,
      0,
      () => exports2.GetVpnConnectionDeviceTypesRequest$,
      () => exports2.GetVpnConnectionDeviceTypesResult$
    ];
    exports2.GetVpnTunnelReplacementStatus$ = [
      9,
      n032,
      _GVTRS,
      0,
      () => exports2.GetVpnTunnelReplacementStatusRequest$,
      () => exports2.GetVpnTunnelReplacementStatusResult$
    ];
    exports2.ImportClientVpnClientCertificateRevocationList$ = [
      9,
      n032,
      _ICVCCRL,
      0,
      () => exports2.ImportClientVpnClientCertificateRevocationListRequest$,
      () => exports2.ImportClientVpnClientCertificateRevocationListResult$
    ];
    exports2.ImportImage$ = [
      9,
      n032,
      _IImpo,
      0,
      () => exports2.ImportImageRequest$,
      () => exports2.ImportImageResult$
    ];
    exports2.ImportInstance$ = [
      9,
      n032,
      _IImp,
      0,
      () => exports2.ImportInstanceRequest$,
      () => exports2.ImportInstanceResult$
    ];
    exports2.ImportKeyPair$ = [
      9,
      n032,
      _IKP,
      0,
      () => exports2.ImportKeyPairRequest$,
      () => exports2.ImportKeyPairResult$
    ];
    exports2.ImportSnapshot$ = [
      9,
      n032,
      _ISmp,
      0,
      () => exports2.ImportSnapshotRequest$,
      () => exports2.ImportSnapshotResult$
    ];
    exports2.ImportVolume$ = [
      9,
      n032,
      _IVm,
      0,
      () => exports2.ImportVolumeRequest$,
      () => exports2.ImportVolumeResult$
    ];
    exports2.ListImagesInRecycleBin$ = [
      9,
      n032,
      _LIIRB,
      0,
      () => exports2.ListImagesInRecycleBinRequest$,
      () => exports2.ListImagesInRecycleBinResult$
    ];
    exports2.ListSnapshotsInRecycleBin$ = [
      9,
      n032,
      _LSIRB,
      0,
      () => exports2.ListSnapshotsInRecycleBinRequest$,
      () => exports2.ListSnapshotsInRecycleBinResult$
    ];
    exports2.ListVolumesInRecycleBin$ = [
      9,
      n032,
      _LVIRB,
      0,
      () => exports2.ListVolumesInRecycleBinRequest$,
      () => exports2.ListVolumesInRecycleBinResult$
    ];
    exports2.LockSnapshot$ = [
      9,
      n032,
      _LSock,
      0,
      () => exports2.LockSnapshotRequest$,
      () => exports2.LockSnapshotResult$
    ];
    exports2.ModifyAddressAttribute$ = [
      9,
      n032,
      _MAA,
      0,
      () => exports2.ModifyAddressAttributeRequest$,
      () => exports2.ModifyAddressAttributeResult$
    ];
    exports2.ModifyAvailabilityZoneGroup$ = [
      9,
      n032,
      _MAZG,
      0,
      () => exports2.ModifyAvailabilityZoneGroupRequest$,
      () => exports2.ModifyAvailabilityZoneGroupResult$
    ];
    exports2.ModifyCapacityReservation$ = [
      9,
      n032,
      _MCR,
      0,
      () => exports2.ModifyCapacityReservationRequest$,
      () => exports2.ModifyCapacityReservationResult$
    ];
    exports2.ModifyCapacityReservationFleet$ = [
      9,
      n032,
      _MCRF,
      0,
      () => exports2.ModifyCapacityReservationFleetRequest$,
      () => exports2.ModifyCapacityReservationFleetResult$
    ];
    exports2.ModifyClientVpnEndpoint$ = [
      9,
      n032,
      _MCVE,
      0,
      () => exports2.ModifyClientVpnEndpointRequest$,
      () => exports2.ModifyClientVpnEndpointResult$
    ];
    exports2.ModifyDefaultCreditSpecification$ = [
      9,
      n032,
      _MDCS,
      0,
      () => exports2.ModifyDefaultCreditSpecificationRequest$,
      () => exports2.ModifyDefaultCreditSpecificationResult$
    ];
    exports2.ModifyEbsDefaultKmsKeyId$ = [
      9,
      n032,
      _MEDKKI,
      0,
      () => exports2.ModifyEbsDefaultKmsKeyIdRequest$,
      () => exports2.ModifyEbsDefaultKmsKeyIdResult$
    ];
    exports2.ModifyFleet$ = [
      9,
      n032,
      _MF,
      0,
      () => exports2.ModifyFleetRequest$,
      () => exports2.ModifyFleetResult$
    ];
    exports2.ModifyFpgaImageAttribute$ = [
      9,
      n032,
      _MFIA,
      0,
      () => exports2.ModifyFpgaImageAttributeRequest$,
      () => exports2.ModifyFpgaImageAttributeResult$
    ];
    exports2.ModifyHosts$ = [
      9,
      n032,
      _MHo,
      0,
      () => exports2.ModifyHostsRequest$,
      () => exports2.ModifyHostsResult$
    ];
    exports2.ModifyIdentityIdFormat$ = [
      9,
      n032,
      _MIIF,
      0,
      () => exports2.ModifyIdentityIdFormatRequest$,
      () => __Unit
    ];
    exports2.ModifyIdFormat$ = [
      9,
      n032,
      _MIF,
      0,
      () => exports2.ModifyIdFormatRequest$,
      () => __Unit
    ];
    exports2.ModifyImageAttribute$ = [
      9,
      n032,
      _MIA,
      0,
      () => exports2.ModifyImageAttributeRequest$,
      () => __Unit
    ];
    exports2.ModifyInstanceAttribute$ = [
      9,
      n032,
      _MIAo,
      0,
      () => exports2.ModifyInstanceAttributeRequest$,
      () => __Unit
    ];
    exports2.ModifyInstanceCapacityReservationAttributes$ = [
      9,
      n032,
      _MICRA,
      0,
      () => exports2.ModifyInstanceCapacityReservationAttributesRequest$,
      () => exports2.ModifyInstanceCapacityReservationAttributesResult$
    ];
    exports2.ModifyInstanceConnectEndpoint$ = [
      9,
      n032,
      _MICE,
      0,
      () => exports2.ModifyInstanceConnectEndpointRequest$,
      () => exports2.ModifyInstanceConnectEndpointResult$
    ];
    exports2.ModifyInstanceCpuOptions$ = [
      9,
      n032,
      _MICO,
      0,
      () => exports2.ModifyInstanceCpuOptionsRequest$,
      () => exports2.ModifyInstanceCpuOptionsResult$
    ];
    exports2.ModifyInstanceCreditSpecification$ = [
      9,
      n032,
      _MICS,
      0,
      () => exports2.ModifyInstanceCreditSpecificationRequest$,
      () => exports2.ModifyInstanceCreditSpecificationResult$
    ];
    exports2.ModifyInstanceEventStartTime$ = [
      9,
      n032,
      _MIEST,
      0,
      () => exports2.ModifyInstanceEventStartTimeRequest$,
      () => exports2.ModifyInstanceEventStartTimeResult$
    ];
    exports2.ModifyInstanceEventWindow$ = [
      9,
      n032,
      _MIEW,
      0,
      () => exports2.ModifyInstanceEventWindowRequest$,
      () => exports2.ModifyInstanceEventWindowResult$
    ];
    exports2.ModifyInstanceMaintenanceOptions$ = [
      9,
      n032,
      _MIMO,
      0,
      () => exports2.ModifyInstanceMaintenanceOptionsRequest$,
      () => exports2.ModifyInstanceMaintenanceOptionsResult$
    ];
    exports2.ModifyInstanceMetadataDefaults$ = [
      9,
      n032,
      _MIMD,
      0,
      () => exports2.ModifyInstanceMetadataDefaultsRequest$,
      () => exports2.ModifyInstanceMetadataDefaultsResult$
    ];
    exports2.ModifyInstanceMetadataOptions$ = [
      9,
      n032,
      _MIMOo,
      0,
      () => exports2.ModifyInstanceMetadataOptionsRequest$,
      () => exports2.ModifyInstanceMetadataOptionsResult$
    ];
    exports2.ModifyInstanceNetworkPerformanceOptions$ = [
      9,
      n032,
      _MINPO,
      0,
      () => exports2.ModifyInstanceNetworkPerformanceRequest$,
      () => exports2.ModifyInstanceNetworkPerformanceResult$
    ];
    exports2.ModifyInstancePlacement$ = [
      9,
      n032,
      _MIP,
      0,
      () => exports2.ModifyInstancePlacementRequest$,
      () => exports2.ModifyInstancePlacementResult$
    ];
    exports2.ModifyIpam$ = [
      9,
      n032,
      _MIo,
      0,
      () => exports2.ModifyIpamRequest$,
      () => exports2.ModifyIpamResult$
    ];
    exports2.ModifyIpamPolicyAllocationRules$ = [
      9,
      n032,
      _MIPAR,
      0,
      () => exports2.ModifyIpamPolicyAllocationRulesRequest$,
      () => exports2.ModifyIpamPolicyAllocationRulesResult$
    ];
    exports2.ModifyIpamPool$ = [
      9,
      n032,
      _MIPo,
      0,
      () => exports2.ModifyIpamPoolRequest$,
      () => exports2.ModifyIpamPoolResult$
    ];
    exports2.ModifyIpamPrefixListResolver$ = [
      9,
      n032,
      _MIPLR,
      0,
      () => exports2.ModifyIpamPrefixListResolverRequest$,
      () => exports2.ModifyIpamPrefixListResolverResult$
    ];
    exports2.ModifyIpamPrefixListResolverTarget$ = [
      9,
      n032,
      _MIPLRT,
      0,
      () => exports2.ModifyIpamPrefixListResolverTargetRequest$,
      () => exports2.ModifyIpamPrefixListResolverTargetResult$
    ];
    exports2.ModifyIpamResourceCidr$ = [
      9,
      n032,
      _MIRC,
      0,
      () => exports2.ModifyIpamResourceCidrRequest$,
      () => exports2.ModifyIpamResourceCidrResult$
    ];
    exports2.ModifyIpamResourceDiscovery$ = [
      9,
      n032,
      _MIRD,
      0,
      () => exports2.ModifyIpamResourceDiscoveryRequest$,
      () => exports2.ModifyIpamResourceDiscoveryResult$
    ];
    exports2.ModifyIpamScope$ = [
      9,
      n032,
      _MIS,
      0,
      () => exports2.ModifyIpamScopeRequest$,
      () => exports2.ModifyIpamScopeResult$
    ];
    exports2.ModifyLaunchTemplate$ = [
      9,
      n032,
      _MLT,
      0,
      () => exports2.ModifyLaunchTemplateRequest$,
      () => exports2.ModifyLaunchTemplateResult$
    ];
    exports2.ModifyLocalGatewayRoute$ = [
      9,
      n032,
      _MLGR,
      0,
      () => exports2.ModifyLocalGatewayRouteRequest$,
      () => exports2.ModifyLocalGatewayRouteResult$
    ];
    exports2.ModifyManagedPrefixList$ = [
      9,
      n032,
      _MMPL,
      0,
      () => exports2.ModifyManagedPrefixListRequest$,
      () => exports2.ModifyManagedPrefixListResult$
    ];
    exports2.ModifyManagedResourceVisibility$ = [
      9,
      n032,
      _MMRV,
      0,
      () => exports2.ModifyManagedResourceVisibilityRequest$,
      () => exports2.ModifyManagedResourceVisibilityResult$
    ];
    exports2.ModifyNetworkInterfaceAttribute$ = [
      9,
      n032,
      _MNIA,
      0,
      () => exports2.ModifyNetworkInterfaceAttributeRequest$,
      () => __Unit
    ];
    exports2.ModifyPrivateDnsNameOptions$ = [
      9,
      n032,
      _MPDNO,
      0,
      () => exports2.ModifyPrivateDnsNameOptionsRequest$,
      () => exports2.ModifyPrivateDnsNameOptionsResult$
    ];
    exports2.ModifyPublicIpDnsNameOptions$ = [
      9,
      n032,
      _MPIDNO,
      0,
      () => exports2.ModifyPublicIpDnsNameOptionsRequest$,
      () => exports2.ModifyPublicIpDnsNameOptionsResult$
    ];
    exports2.ModifyReservedInstances$ = [
      9,
      n032,
      _MRI,
      0,
      () => exports2.ModifyReservedInstancesRequest$,
      () => exports2.ModifyReservedInstancesResult$
    ];
    exports2.ModifyRouteServer$ = [
      9,
      n032,
      _MRS,
      0,
      () => exports2.ModifyRouteServerRequest$,
      () => exports2.ModifyRouteServerResult$
    ];
    exports2.ModifySecurityGroupRules$ = [
      9,
      n032,
      _MSGR,
      0,
      () => exports2.ModifySecurityGroupRulesRequest$,
      () => exports2.ModifySecurityGroupRulesResult$
    ];
    exports2.ModifySnapshotAttribute$ = [
      9,
      n032,
      _MSA,
      0,
      () => exports2.ModifySnapshotAttributeRequest$,
      () => __Unit
    ];
    exports2.ModifySnapshotTier$ = [
      9,
      n032,
      _MST,
      0,
      () => exports2.ModifySnapshotTierRequest$,
      () => exports2.ModifySnapshotTierResult$
    ];
    exports2.ModifySpotFleetRequest$ = [
      9,
      n032,
      _MSFR,
      0,
      () => exports2.ModifySpotFleetRequestRequest$,
      () => exports2.ModifySpotFleetRequestResponse$
    ];
    exports2.ModifySubnetAttribute$ = [
      9,
      n032,
      _MSAo,
      0,
      () => exports2.ModifySubnetAttributeRequest$,
      () => __Unit
    ];
    exports2.ModifyTrafficMirrorFilterNetworkServices$ = [
      9,
      n032,
      _MTMFNS,
      0,
      () => exports2.ModifyTrafficMirrorFilterNetworkServicesRequest$,
      () => exports2.ModifyTrafficMirrorFilterNetworkServicesResult$
    ];
    exports2.ModifyTrafficMirrorFilterRule$ = [
      9,
      n032,
      _MTMFR,
      0,
      () => exports2.ModifyTrafficMirrorFilterRuleRequest$,
      () => exports2.ModifyTrafficMirrorFilterRuleResult$
    ];
    exports2.ModifyTrafficMirrorSession$ = [
      9,
      n032,
      _MTMS,
      0,
      () => exports2.ModifyTrafficMirrorSessionRequest$,
      () => exports2.ModifyTrafficMirrorSessionResult$
    ];
    exports2.ModifyTransitGateway$ = [
      9,
      n032,
      _MTG,
      0,
      () => exports2.ModifyTransitGatewayRequest$,
      () => exports2.ModifyTransitGatewayResult$
    ];
    exports2.ModifyTransitGatewayMeteringPolicy$ = [
      9,
      n032,
      _MTGMP,
      0,
      () => exports2.ModifyTransitGatewayMeteringPolicyRequest$,
      () => exports2.ModifyTransitGatewayMeteringPolicyResult$
    ];
    exports2.ModifyTransitGatewayPrefixListReference$ = [
      9,
      n032,
      _MTGPLR,
      0,
      () => exports2.ModifyTransitGatewayPrefixListReferenceRequest$,
      () => exports2.ModifyTransitGatewayPrefixListReferenceResult$
    ];
    exports2.ModifyTransitGatewayVpcAttachment$ = [
      9,
      n032,
      _MTGVA,
      0,
      () => exports2.ModifyTransitGatewayVpcAttachmentRequest$,
      () => exports2.ModifyTransitGatewayVpcAttachmentResult$
    ];
    exports2.ModifyVerifiedAccessEndpoint$ = [
      9,
      n032,
      _MVAE,
      0,
      () => exports2.ModifyVerifiedAccessEndpointRequest$,
      () => exports2.ModifyVerifiedAccessEndpointResult$
    ];
    exports2.ModifyVerifiedAccessEndpointPolicy$ = [
      9,
      n032,
      _MVAEP,
      0,
      () => exports2.ModifyVerifiedAccessEndpointPolicyRequest$,
      () => exports2.ModifyVerifiedAccessEndpointPolicyResult$
    ];
    exports2.ModifyVerifiedAccessGroup$ = [
      9,
      n032,
      _MVAG,
      0,
      () => exports2.ModifyVerifiedAccessGroupRequest$,
      () => exports2.ModifyVerifiedAccessGroupResult$
    ];
    exports2.ModifyVerifiedAccessGroupPolicy$ = [
      9,
      n032,
      _MVAGP,
      0,
      () => exports2.ModifyVerifiedAccessGroupPolicyRequest$,
      () => exports2.ModifyVerifiedAccessGroupPolicyResult$
    ];
    exports2.ModifyVerifiedAccessInstance$ = [
      9,
      n032,
      _MVAI,
      0,
      () => exports2.ModifyVerifiedAccessInstanceRequest$,
      () => exports2.ModifyVerifiedAccessInstanceResult$
    ];
    exports2.ModifyVerifiedAccessInstanceLoggingConfiguration$ = [
      9,
      n032,
      _MVAILC,
      0,
      () => exports2.ModifyVerifiedAccessInstanceLoggingConfigurationRequest$,
      () => exports2.ModifyVerifiedAccessInstanceLoggingConfigurationResult$
    ];
    exports2.ModifyVerifiedAccessTrustProvider$ = [
      9,
      n032,
      _MVATP,
      0,
      () => exports2.ModifyVerifiedAccessTrustProviderRequest$,
      () => exports2.ModifyVerifiedAccessTrustProviderResult$
    ];
    exports2.ModifyVolume$ = [
      9,
      n032,
      _MVo,
      0,
      () => exports2.ModifyVolumeRequest$,
      () => exports2.ModifyVolumeResult$
    ];
    exports2.ModifyVolumeAttribute$ = [
      9,
      n032,
      _MVA,
      0,
      () => exports2.ModifyVolumeAttributeRequest$,
      () => __Unit
    ];
    exports2.ModifyVpcAttribute$ = [
      9,
      n032,
      _MVAo,
      0,
      () => exports2.ModifyVpcAttributeRequest$,
      () => __Unit
    ];
    exports2.ModifyVpcBlockPublicAccessExclusion$ = [
      9,
      n032,
      _MVBPAE,
      0,
      () => exports2.ModifyVpcBlockPublicAccessExclusionRequest$,
      () => exports2.ModifyVpcBlockPublicAccessExclusionResult$
    ];
    exports2.ModifyVpcBlockPublicAccessOptions$ = [
      9,
      n032,
      _MVBPAO,
      0,
      () => exports2.ModifyVpcBlockPublicAccessOptionsRequest$,
      () => exports2.ModifyVpcBlockPublicAccessOptionsResult$
    ];
    exports2.ModifyVpcEncryptionControl$ = [
      9,
      n032,
      _MVEC,
      0,
      () => exports2.ModifyVpcEncryptionControlRequest$,
      () => exports2.ModifyVpcEncryptionControlResult$
    ];
    exports2.ModifyVpcEndpoint$ = [
      9,
      n032,
      _MVEo,
      0,
      () => exports2.ModifyVpcEndpointRequest$,
      () => exports2.ModifyVpcEndpointResult$
    ];
    exports2.ModifyVpcEndpointConnectionNotification$ = [
      9,
      n032,
      _MVECN,
      0,
      () => exports2.ModifyVpcEndpointConnectionNotificationRequest$,
      () => exports2.ModifyVpcEndpointConnectionNotificationResult$
    ];
    exports2.ModifyVpcEndpointServiceConfiguration$ = [
      9,
      n032,
      _MVESC,
      0,
      () => exports2.ModifyVpcEndpointServiceConfigurationRequest$,
      () => exports2.ModifyVpcEndpointServiceConfigurationResult$
    ];
    exports2.ModifyVpcEndpointServicePayerResponsibility$ = [
      9,
      n032,
      _MVESPRod,
      0,
      () => exports2.ModifyVpcEndpointServicePayerResponsibilityRequest$,
      () => exports2.ModifyVpcEndpointServicePayerResponsibilityResult$
    ];
    exports2.ModifyVpcEndpointServicePermissions$ = [
      9,
      n032,
      _MVESP,
      0,
      () => exports2.ModifyVpcEndpointServicePermissionsRequest$,
      () => exports2.ModifyVpcEndpointServicePermissionsResult$
    ];
    exports2.ModifyVpcPeeringConnectionOptions$ = [
      9,
      n032,
      _MVPCO,
      0,
      () => exports2.ModifyVpcPeeringConnectionOptionsRequest$,
      () => exports2.ModifyVpcPeeringConnectionOptionsResult$
    ];
    exports2.ModifyVpcTenancy$ = [
      9,
      n032,
      _MVT,
      0,
      () => exports2.ModifyVpcTenancyRequest$,
      () => exports2.ModifyVpcTenancyResult$
    ];
    exports2.ModifyVpnConnection$ = [
      9,
      n032,
      _MVC,
      0,
      () => exports2.ModifyVpnConnectionRequest$,
      () => exports2.ModifyVpnConnectionResult$
    ];
    exports2.ModifyVpnConnectionOptions$ = [
      9,
      n032,
      _MVCO,
      0,
      () => exports2.ModifyVpnConnectionOptionsRequest$,
      () => exports2.ModifyVpnConnectionOptionsResult$
    ];
    exports2.ModifyVpnTunnelCertificate$ = [
      9,
      n032,
      _MVTC,
      0,
      () => exports2.ModifyVpnTunnelCertificateRequest$,
      () => exports2.ModifyVpnTunnelCertificateResult$
    ];
    exports2.ModifyVpnTunnelOptions$ = [
      9,
      n032,
      _MVTO,
      0,
      () => exports2.ModifyVpnTunnelOptionsRequest$,
      () => exports2.ModifyVpnTunnelOptionsResult$
    ];
    exports2.MonitorInstances$ = [
      9,
      n032,
      _MIon,
      0,
      () => exports2.MonitorInstancesRequest$,
      () => exports2.MonitorInstancesResult$
    ];
    exports2.MoveAddressToVpc$ = [
      9,
      n032,
      _MATV,
      0,
      () => exports2.MoveAddressToVpcRequest$,
      () => exports2.MoveAddressToVpcResult$
    ];
    exports2.MoveByoipCidrToIpam$ = [
      9,
      n032,
      _MBCTI,
      0,
      () => exports2.MoveByoipCidrToIpamRequest$,
      () => exports2.MoveByoipCidrToIpamResult$
    ];
    exports2.MoveCapacityReservationInstances$ = [
      9,
      n032,
      _MCRI,
      0,
      () => exports2.MoveCapacityReservationInstancesRequest$,
      () => exports2.MoveCapacityReservationInstancesResult$
    ];
    exports2.ProvisionByoipCidr$ = [
      9,
      n032,
      _PBC,
      0,
      () => exports2.ProvisionByoipCidrRequest$,
      () => exports2.ProvisionByoipCidrResult$
    ];
    exports2.ProvisionIpamByoasn$ = [
      9,
      n032,
      _PIB,
      0,
      () => exports2.ProvisionIpamByoasnRequest$,
      () => exports2.ProvisionIpamByoasnResult$
    ];
    exports2.ProvisionIpamPoolCidr$ = [
      9,
      n032,
      _PIPC,
      0,
      () => exports2.ProvisionIpamPoolCidrRequest$,
      () => exports2.ProvisionIpamPoolCidrResult$
    ];
    exports2.ProvisionPublicIpv4PoolCidr$ = [
      9,
      n032,
      _PPIPC,
      0,
      () => exports2.ProvisionPublicIpv4PoolCidrRequest$,
      () => exports2.ProvisionPublicIpv4PoolCidrResult$
    ];
    exports2.PurchaseCapacityBlock$ = [
      9,
      n032,
      _PCBu,
      0,
      () => exports2.PurchaseCapacityBlockRequest$,
      () => exports2.PurchaseCapacityBlockResult$
    ];
    exports2.PurchaseCapacityBlockExtension$ = [
      9,
      n032,
      _PCBE,
      0,
      () => exports2.PurchaseCapacityBlockExtensionRequest$,
      () => exports2.PurchaseCapacityBlockExtensionResult$
    ];
    exports2.PurchaseHostReservation$ = [
      9,
      n032,
      _PHR,
      0,
      () => exports2.PurchaseHostReservationRequest$,
      () => exports2.PurchaseHostReservationResult$
    ];
    exports2.PurchaseReservedInstancesOffering$ = [
      9,
      n032,
      _PRIO,
      0,
      () => exports2.PurchaseReservedInstancesOfferingRequest$,
      () => exports2.PurchaseReservedInstancesOfferingResult$
    ];
    exports2.PurchaseScheduledInstances$ = [
      9,
      n032,
      _PSI,
      0,
      () => exports2.PurchaseScheduledInstancesRequest$,
      () => exports2.PurchaseScheduledInstancesResult$
    ];
    exports2.RebootInstances$ = [
      9,
      n032,
      _RIeb,
      0,
      () => exports2.RebootInstancesRequest$,
      () => __Unit
    ];
    exports2.RegisterImage$ = [
      9,
      n032,
      _RIegi,
      0,
      () => exports2.RegisterImageRequest$,
      () => exports2.RegisterImageResult$
    ];
    exports2.RegisterInstanceEventNotificationAttributes$ = [
      9,
      n032,
      _RIENA,
      0,
      () => exports2.RegisterInstanceEventNotificationAttributesRequest$,
      () => exports2.RegisterInstanceEventNotificationAttributesResult$
    ];
    exports2.RegisterTransitGatewayMulticastGroupMembers$ = [
      9,
      n032,
      _RTGMGM,
      0,
      () => exports2.RegisterTransitGatewayMulticastGroupMembersRequest$,
      () => exports2.RegisterTransitGatewayMulticastGroupMembersResult$
    ];
    exports2.RegisterTransitGatewayMulticastGroupSources$ = [
      9,
      n032,
      _RTGMGS,
      0,
      () => exports2.RegisterTransitGatewayMulticastGroupSourcesRequest$,
      () => exports2.RegisterTransitGatewayMulticastGroupSourcesResult$
    ];
    exports2.RejectCapacityReservationBillingOwnership$ = [
      9,
      n032,
      _RCRBO,
      0,
      () => exports2.RejectCapacityReservationBillingOwnershipRequest$,
      () => exports2.RejectCapacityReservationBillingOwnershipResult$
    ];
    exports2.RejectTransitGatewayClientVpnAttachment$ = [
      9,
      n032,
      _RTGCVA,
      0,
      () => exports2.RejectTransitGatewayClientVpnAttachmentRequest$,
      () => exports2.RejectTransitGatewayClientVpnAttachmentResult$
    ];
    exports2.RejectTransitGatewayMulticastDomainAssociations$ = [
      9,
      n032,
      _RTGMDA,
      0,
      () => exports2.RejectTransitGatewayMulticastDomainAssociationsRequest$,
      () => exports2.RejectTransitGatewayMulticastDomainAssociationsResult$
    ];
    exports2.RejectTransitGatewayPeeringAttachment$ = [
      9,
      n032,
      _RTGPA,
      0,
      () => exports2.RejectTransitGatewayPeeringAttachmentRequest$,
      () => exports2.RejectTransitGatewayPeeringAttachmentResult$
    ];
    exports2.RejectTransitGatewayVpcAttachment$ = [
      9,
      n032,
      _RTGVA,
      0,
      () => exports2.RejectTransitGatewayVpcAttachmentRequest$,
      () => exports2.RejectTransitGatewayVpcAttachmentResult$
    ];
    exports2.RejectVpcEndpointConnections$ = [
      9,
      n032,
      _RVEC,
      0,
      () => exports2.RejectVpcEndpointConnectionsRequest$,
      () => exports2.RejectVpcEndpointConnectionsResult$
    ];
    exports2.RejectVpcPeeringConnection$ = [
      9,
      n032,
      _RVPC,
      0,
      () => exports2.RejectVpcPeeringConnectionRequest$,
      () => exports2.RejectVpcPeeringConnectionResult$
    ];
    exports2.ReleaseAddress$ = [
      9,
      n032,
      _RAel,
      0,
      () => exports2.ReleaseAddressRequest$,
      () => __Unit
    ];
    exports2.ReleaseHosts$ = [
      9,
      n032,
      _RH,
      0,
      () => exports2.ReleaseHostsRequest$,
      () => exports2.ReleaseHostsResult$
    ];
    exports2.ReleaseIpamPoolAllocation$ = [
      9,
      n032,
      _RIPA,
      0,
      () => exports2.ReleaseIpamPoolAllocationRequest$,
      () => exports2.ReleaseIpamPoolAllocationResult$
    ];
    exports2.ReplaceIamInstanceProfileAssociation$ = [
      9,
      n032,
      _RIIPA,
      0,
      () => exports2.ReplaceIamInstanceProfileAssociationRequest$,
      () => exports2.ReplaceIamInstanceProfileAssociationResult$
    ];
    exports2.ReplaceImageCriteriaInAllowedImagesSettings$ = [
      9,
      n032,
      _RICIAIS,
      0,
      () => exports2.ReplaceImageCriteriaInAllowedImagesSettingsRequest$,
      () => exports2.ReplaceImageCriteriaInAllowedImagesSettingsResult$
    ];
    exports2.ReplaceNetworkAclAssociation$ = [
      9,
      n032,
      _RNAA,
      0,
      () => exports2.ReplaceNetworkAclAssociationRequest$,
      () => exports2.ReplaceNetworkAclAssociationResult$
    ];
    exports2.ReplaceNetworkAclEntry$ = [
      9,
      n032,
      _RNAE,
      0,
      () => exports2.ReplaceNetworkAclEntryRequest$,
      () => __Unit
    ];
    exports2.ReplaceRoute$ = [
      9,
      n032,
      _RRe,
      0,
      () => exports2.ReplaceRouteRequest$,
      () => __Unit
    ];
    exports2.ReplaceRouteTableAssociation$ = [
      9,
      n032,
      _RRTA,
      0,
      () => exports2.ReplaceRouteTableAssociationRequest$,
      () => exports2.ReplaceRouteTableAssociationResult$
    ];
    exports2.ReplaceTransitGatewayRoute$ = [
      9,
      n032,
      _RTGR,
      0,
      () => exports2.ReplaceTransitGatewayRouteRequest$,
      () => exports2.ReplaceTransitGatewayRouteResult$
    ];
    exports2.ReplaceVpnTunnel$ = [
      9,
      n032,
      _RVT,
      0,
      () => exports2.ReplaceVpnTunnelRequest$,
      () => exports2.ReplaceVpnTunnelResult$
    ];
    exports2.ReportInstanceStatus$ = [
      9,
      n032,
      _RISe,
      0,
      () => exports2.ReportInstanceStatusRequest$,
      () => __Unit
    ];
    exports2.RequestSpotFleet$ = [
      9,
      n032,
      _RSF,
      0,
      () => exports2.RequestSpotFleetRequest$,
      () => exports2.RequestSpotFleetResponse$
    ];
    exports2.RequestSpotInstances$ = [
      9,
      n032,
      _RSIeq,
      0,
      () => exports2.RequestSpotInstancesRequest$,
      () => exports2.RequestSpotInstancesResult$
    ];
    exports2.ResetAddressAttribute$ = [
      9,
      n032,
      _RAA,
      0,
      () => exports2.ResetAddressAttributeRequest$,
      () => exports2.ResetAddressAttributeResult$
    ];
    exports2.ResetEbsDefaultKmsKeyId$ = [
      9,
      n032,
      _REDKKI,
      0,
      () => exports2.ResetEbsDefaultKmsKeyIdRequest$,
      () => exports2.ResetEbsDefaultKmsKeyIdResult$
    ];
    exports2.ResetFpgaImageAttribute$ = [
      9,
      n032,
      _RFIA,
      0,
      () => exports2.ResetFpgaImageAttributeRequest$,
      () => exports2.ResetFpgaImageAttributeResult$
    ];
    exports2.ResetImageAttribute$ = [
      9,
      n032,
      _RIA,
      0,
      () => exports2.ResetImageAttributeRequest$,
      () => __Unit
    ];
    exports2.ResetInstanceAttribute$ = [
      9,
      n032,
      _RIAe,
      0,
      () => exports2.ResetInstanceAttributeRequest$,
      () => __Unit
    ];
    exports2.ResetNetworkInterfaceAttribute$ = [
      9,
      n032,
      _RNIA,
      0,
      () => exports2.ResetNetworkInterfaceAttributeRequest$,
      () => __Unit
    ];
    exports2.ResetSnapshotAttribute$ = [
      9,
      n032,
      _RSAe,
      0,
      () => exports2.ResetSnapshotAttributeRequest$,
      () => __Unit
    ];
    exports2.RestoreAddressToClassic$ = [
      9,
      n032,
      _RATC,
      0,
      () => exports2.RestoreAddressToClassicRequest$,
      () => exports2.RestoreAddressToClassicResult$
    ];
    exports2.RestoreImageFromRecycleBin$ = [
      9,
      n032,
      _RIFRB,
      0,
      () => exports2.RestoreImageFromRecycleBinRequest$,
      () => exports2.RestoreImageFromRecycleBinResult$
    ];
    exports2.RestoreManagedPrefixListVersion$ = [
      9,
      n032,
      _RMPLV,
      0,
      () => exports2.RestoreManagedPrefixListVersionRequest$,
      () => exports2.RestoreManagedPrefixListVersionResult$
    ];
    exports2.RestoreSnapshotFromRecycleBin$ = [
      9,
      n032,
      _RSFRB,
      0,
      () => exports2.RestoreSnapshotFromRecycleBinRequest$,
      () => exports2.RestoreSnapshotFromRecycleBinResult$
    ];
    exports2.RestoreSnapshotTier$ = [
      9,
      n032,
      _RSTes,
      0,
      () => exports2.RestoreSnapshotTierRequest$,
      () => exports2.RestoreSnapshotTierResult$
    ];
    exports2.RestoreVolumeFromRecycleBin$ = [
      9,
      n032,
      _RVFRB,
      0,
      () => exports2.RestoreVolumeFromRecycleBinRequest$,
      () => exports2.RestoreVolumeFromRecycleBinResult$
    ];
    exports2.RevokeClientVpnIngress$ = [
      9,
      n032,
      _RCVI,
      0,
      () => exports2.RevokeClientVpnIngressRequest$,
      () => exports2.RevokeClientVpnIngressResult$
    ];
    exports2.RevokeSecurityGroupEgress$ = [
      9,
      n032,
      _RSGE,
      0,
      () => exports2.RevokeSecurityGroupEgressRequest$,
      () => exports2.RevokeSecurityGroupEgressResult$
    ];
    exports2.RevokeSecurityGroupIngress$ = [
      9,
      n032,
      _RSGIev,
      0,
      () => exports2.RevokeSecurityGroupIngressRequest$,
      () => exports2.RevokeSecurityGroupIngressResult$
    ];
    exports2.RunInstances$ = [
      9,
      n032,
      _RIu,
      0,
      () => exports2.RunInstancesRequest$,
      () => exports2.Reservation$
    ];
    exports2.RunScheduledInstances$ = [
      9,
      n032,
      _RSIu,
      0,
      () => exports2.RunScheduledInstancesRequest$,
      () => exports2.RunScheduledInstancesResult$
    ];
    exports2.SearchLocalGatewayRoutes$ = [
      9,
      n032,
      _SLGR,
      0,
      () => exports2.SearchLocalGatewayRoutesRequest$,
      () => exports2.SearchLocalGatewayRoutesResult$
    ];
    exports2.SearchTransitGatewayMulticastGroups$ = [
      9,
      n032,
      _STGMG,
      0,
      () => exports2.SearchTransitGatewayMulticastGroupsRequest$,
      () => exports2.SearchTransitGatewayMulticastGroupsResult$
    ];
    exports2.SearchTransitGatewayRoutes$ = [
      9,
      n032,
      _STGR,
      0,
      () => exports2.SearchTransitGatewayRoutesRequest$,
      () => exports2.SearchTransitGatewayRoutesResult$
    ];
    exports2.SendDiagnosticInterrupt$ = [
      9,
      n032,
      _SDI,
      0,
      () => exports2.SendDiagnosticInterruptRequest$,
      () => __Unit
    ];
    exports2.StartDeclarativePoliciesReport$ = [
      9,
      n032,
      _SDPR,
      0,
      () => exports2.StartDeclarativePoliciesReportRequest$,
      () => exports2.StartDeclarativePoliciesReportResult$
    ];
    exports2.StartInstances$ = [
      9,
      n032,
      _SIta,
      0,
      () => exports2.StartInstancesRequest$,
      () => exports2.StartInstancesResult$
    ];
    exports2.StartNetworkInsightsAccessScopeAnalysis$ = [
      9,
      n032,
      _SNIASA,
      0,
      () => exports2.StartNetworkInsightsAccessScopeAnalysisRequest$,
      () => exports2.StartNetworkInsightsAccessScopeAnalysisResult$
    ];
    exports2.StartNetworkInsightsAnalysis$ = [
      9,
      n032,
      _SNIA,
      0,
      () => exports2.StartNetworkInsightsAnalysisRequest$,
      () => exports2.StartNetworkInsightsAnalysisResult$
    ];
    exports2.StartVpcEndpointServicePrivateDnsVerification$ = [
      9,
      n032,
      _SVESPDV,
      0,
      () => exports2.StartVpcEndpointServicePrivateDnsVerificationRequest$,
      () => exports2.StartVpcEndpointServicePrivateDnsVerificationResult$
    ];
    exports2.StopInstances$ = [
      9,
      n032,
      _SItop,
      0,
      () => exports2.StopInstancesRequest$,
      () => exports2.StopInstancesResult$
    ];
    exports2.TerminateClientVpnConnections$ = [
      9,
      n032,
      _TCVC,
      0,
      () => exports2.TerminateClientVpnConnectionsRequest$,
      () => exports2.TerminateClientVpnConnectionsResult$
    ];
    exports2.TerminateInstances$ = [
      9,
      n032,
      _TI,
      0,
      () => exports2.TerminateInstancesRequest$,
      () => exports2.TerminateInstancesResult$
    ];
    exports2.UnassignIpv6Addresses$ = [
      9,
      n032,
      _UIAn,
      0,
      () => exports2.UnassignIpv6AddressesRequest$,
      () => exports2.UnassignIpv6AddressesResult$
    ];
    exports2.UnassignPrivateIpAddresses$ = [
      9,
      n032,
      _UPIA,
      0,
      () => exports2.UnassignPrivateIpAddressesRequest$,
      () => __Unit
    ];
    exports2.UnassignPrivateNatGatewayAddress$ = [
      9,
      n032,
      _UPNGA,
      0,
      () => exports2.UnassignPrivateNatGatewayAddressRequest$,
      () => exports2.UnassignPrivateNatGatewayAddressResult$
    ];
    exports2.UnlockSnapshot$ = [
      9,
      n032,
      _USn,
      0,
      () => exports2.UnlockSnapshotRequest$,
      () => exports2.UnlockSnapshotResult$
    ];
    exports2.UnmonitorInstances$ = [
      9,
      n032,
      _UInm,
      0,
      () => exports2.UnmonitorInstancesRequest$,
      () => exports2.UnmonitorInstancesResult$
    ];
    exports2.UpdateCapacityManagerMonitoredTagKeys$ = [
      9,
      n032,
      _UCMMTK,
      0,
      () => exports2.UpdateCapacityManagerMonitoredTagKeysRequest$,
      () => exports2.UpdateCapacityManagerMonitoredTagKeysResult$
    ];
    exports2.UpdateCapacityManagerOrganizationsAccess$ = [
      9,
      n032,
      _UCMOA,
      0,
      () => exports2.UpdateCapacityManagerOrganizationsAccessRequest$,
      () => exports2.UpdateCapacityManagerOrganizationsAccessResult$
    ];
    exports2.UpdateInterruptibleCapacityReservationAllocation$ = [
      9,
      n032,
      _UICRA,
      0,
      () => exports2.UpdateInterruptibleCapacityReservationAllocationRequest$,
      () => exports2.UpdateInterruptibleCapacityReservationAllocationResult$
    ];
    exports2.UpdateSecurityGroupRuleDescriptionsEgress$ = [
      9,
      n032,
      _USGRDE,
      0,
      () => exports2.UpdateSecurityGroupRuleDescriptionsEgressRequest$,
      () => exports2.UpdateSecurityGroupRuleDescriptionsEgressResult$
    ];
    exports2.UpdateSecurityGroupRuleDescriptionsIngress$ = [
      9,
      n032,
      _USGRDI,
      0,
      () => exports2.UpdateSecurityGroupRuleDescriptionsIngressRequest$,
      () => exports2.UpdateSecurityGroupRuleDescriptionsIngressResult$
    ];
    exports2.WithdrawByoipCidr$ = [
      9,
      n032,
      _WBC,
      0,
      () => exports2.WithdrawByoipCidrRequest$,
      () => exports2.WithdrawByoipCidrResult$
    ];
  }
});

// ../../node_modules/@aws-sdk/client-ec2/dist-cjs/runtimeConfig.shared.js
var require_runtimeConfig_shared12 = __commonJS({
  "../../node_modules/@aws-sdk/client-ec2/dist-cjs/runtimeConfig.shared.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var protocols_1 = (init_protocols8(), __toCommonJS(protocols_exports5));
    var smithy_client_1 = require_dist_cjs34();
    var url_parser_1 = require_dist_cjs18();
    var util_base64_1 = require_dist_cjs10();
    var util_utf8_1 = require_dist_cjs9();
    var httpAuthSchemeProvider_1 = require_httpAuthSchemeProvider11();
    var endpointResolver_1 = require_endpointResolver11();
    var schemas_0_1 = require_schemas_011();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2016-11-15",
        base64Decoder: config2?.base64Decoder ?? util_base64_1.fromBase64,
        base64Encoder: config2?.base64Encoder ?? util_base64_1.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? endpointResolver_1.defaultEndpointResolver,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? httpAuthSchemeProvider_1.defaultEC2HttpAuthSchemeProvider,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new httpAuthSchemes_1.AwsSdkSigV4Signer()
          }
        ],
        logger: config2?.logger ?? new smithy_client_1.NoOpLogger(),
        protocol: config2?.protocol ?? protocols_1.AwsEc2QueryProtocol,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.ec2",
          errorTypeRegistries: schemas_0_1.errorTypeRegistries,
          xmlNamespace: "http://ec2.amazonaws.com/doc/2016-11-15",
          version: "2016-11-15",
          serviceTarget: "AmazonEC2"
        },
        serviceId: config2?.serviceId ?? "EC2",
        urlParser: config2?.urlParser ?? url_parser_1.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? util_utf8_1.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? util_utf8_1.toUtf8
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-ec2/dist-cjs/runtimeConfig.js
var require_runtimeConfig12 = __commonJS({
  "../../node_modules/@aws-sdk/client-ec2/dist-cjs/runtimeConfig.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var package_json_1 = tslib_1.__importDefault(require_package11());
    var client_1 = (init_client8(), __toCommonJS(client_exports7));
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var credential_provider_node_1 = require_dist_cjs122();
    var util_user_agent_node_1 = require_dist_cjs113();
    var config_resolver_1 = require_dist_cjs25();
    var hash_node_1 = require_dist_cjs44();
    var middleware_retry_1 = require_dist_cjs106();
    var node_config_provider_1 = require_dist_cjs29();
    var node_http_handler_1 = require_dist_cjs13();
    var smithy_client_1 = require_dist_cjs34();
    var util_body_length_node_1 = require_dist_cjs45();
    var util_defaults_mode_node_1 = require_dist_cjs46();
    var util_retry_1 = require_dist_cjs22();
    var runtimeConfig_shared_1 = require_runtimeConfig_shared12();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      (0, smithy_client_1.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, util_defaults_mode_node_1.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(smithy_client_1.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = (0, runtimeConfig_shared_1.getRuntimeConfig)(config2);
      (0, client_1.emitWarningIfUnsupportedVersion)(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, node_config_provider_1.loadConfig)(httpAuthSchemes_1.NODE_AUTH_SCHEME_PREFERENCE_OPTIONS, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? util_body_length_node_1.calculateBodyLength,
        credentialDefaultProvider: config2?.credentialDefaultProvider ?? credential_provider_node_1.defaultProvider,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, util_user_agent_node_1.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_json_1.default.version }),
        maxAttempts: config2?.maxAttempts ?? (0, node_config_provider_1.loadConfig)(middleware_retry_1.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_REGION_CONFIG_OPTIONS, { ...config_resolver_1.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: node_http_handler_1.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, node_config_provider_1.loadConfig)({
          ...middleware_retry_1.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || util_retry_1.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? hash_node_1.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? node_http_handler_1.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, node_config_provider_1.loadConfig)(util_user_agent_node_1.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/util-format-url/dist-cjs/index.js
var require_dist_cjs161 = __commonJS({
  "../../node_modules/@aws-sdk/util-format-url/dist-cjs/index.js"(exports2) {
    "use strict";
    var querystringBuilder = require_dist_cjs12();
    function formatUrl(request4) {
      const { port, query } = request4;
      let { protocol, path: path47, hostname } = request4;
      if (protocol && protocol.slice(-1) !== ":") {
        protocol += ":";
      }
      if (port) {
        hostname += `:${port}`;
      }
      if (path47 && path47.charAt(0) !== "/") {
        path47 = `/${path47}`;
      }
      let queryString = query ? querystringBuilder.buildQueryString(query) : "";
      if (queryString && queryString[0] !== "?") {
        queryString = `?${queryString}`;
      }
      let auth = "";
      if (request4.username != null || request4.password != null) {
        const username = request4.username ?? "";
        const password = request4.password ?? "";
        auth = `${username}:${password}@`;
      }
      let fragment = "";
      if (request4.fragment) {
        fragment = `#${request4.fragment}`;
      }
      return `${protocol}//${auth}${hostname}${path47}${queryString}${fragment}`;
    }
    __name(formatUrl, "formatUrl");
    exports2.formatUrl = formatUrl;
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-ec2/dist-cjs/index.js
var require_dist_cjs162 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-sdk-ec2/dist-cjs/index.js"(exports2) {
    "use strict";
    var utilFormatUrl = require_dist_cjs161();
    var middlewareEndpoint = require_dist_cjs31();
    var protocolHttp = require_dist_cjs2();
    var signatureV4 = require_dist_cjs36();
    var smithyClient = require_dist_cjs34();
    var version = "2016-11-15";
    function copySnapshotPresignedUrlMiddleware(options) {
      return (next, context) => async (args) => {
        const { input } = args;
        if (!input.PresignedUrl) {
          const destinationRegion = await options.region();
          const endpoint = await middlewareEndpoint.getEndpointFromInstructions(input, {
            getEndpointParameterInstructions() {
              return {
                UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
                Endpoint: { type: "builtInParams", name: "endpoint" },
                Region: { type: "builtInParams", name: "region" },
                UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
              };
            }
          }, {
            ...options,
            region: input.SourceRegion
          });
          const resolvedEndpoint = typeof options.endpoint === "function" ? await options.endpoint() : middlewareEndpoint.toEndpointV1(endpoint);
          const requestToSign = new protocolHttp.HttpRequest({
            ...resolvedEndpoint,
            protocol: "https",
            headers: {
              host: resolvedEndpoint.hostname
            },
            query: {
              ...Object.entries(input).reduce((acc, [k32, v]) => {
                acc[k32] = String(v ?? "");
                return acc;
              }, {}),
              Action: "CopySnapshot",
              Version: version,
              DestinationRegion: destinationRegion
            }
          });
          const signer = new signatureV4.SignatureV4({
            credentials: options.credentials,
            region: input.SourceRegion,
            service: "ec2",
            sha256: options.sha256,
            uriEscapePath: options.signingEscapePath
          });
          const presignedRequest = await signer.presign(requestToSign, {
            expiresIn: 3600
          });
          args = {
            ...args,
            input: {
              ...args.input,
              DestinationRegion: destinationRegion,
              PresignedUrl: utilFormatUrl.formatUrl(presignedRequest)
            }
          };
          if (protocolHttp.HttpRequest.isInstance(args.request)) {
            const { request: request4 } = args;
            if (!(request4.body ?? "").includes("DestinationRegion=")) {
              request4.body += `&DestinationRegion=${destinationRegion}`;
            }
            if (!(request4.body ?? "").includes("PresignedUrl=")) {
              request4.body += `&PresignedUrl=${smithyClient.extendedEncodeURIComponent(args.input.PresignedUrl)}`;
            }
          }
        }
        return next(args);
      };
    }
    __name(copySnapshotPresignedUrlMiddleware, "copySnapshotPresignedUrlMiddleware");
    var copySnapshotPresignedUrlMiddlewareOptions = {
      step: "serialize",
      tags: ["CROSS_REGION_PRESIGNED_URL"],
      name: "crossRegionPresignedUrlMiddleware",
      override: true,
      relation: "after",
      toMiddleware: "endpointV2Middleware"
    };
    var getCopySnapshotPresignedUrlPlugin = /* @__PURE__ */ __name((config2) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(copySnapshotPresignedUrlMiddleware(config2), copySnapshotPresignedUrlMiddlewareOptions);
      }, "applyToStack")
    }), "getCopySnapshotPresignedUrlPlugin");
    exports2.copySnapshotPresignedUrlMiddleware = copySnapshotPresignedUrlMiddleware;
    exports2.copySnapshotPresignedUrlMiddlewareOptions = copySnapshotPresignedUrlMiddlewareOptions;
    exports2.getCopySnapshotPresignedUrlPlugin = getCopySnapshotPresignedUrlPlugin;
  }
});

// ../../node_modules/@aws-sdk/client-ec2/dist-cjs/index.js
var require_dist_cjs163 = __commonJS({
  "../../node_modules/@aws-sdk/client-ec2/dist-cjs/index.js"(exports2) {
    "use strict";
    var middlewareHostHeader = require_dist_cjs3();
    var middlewareLogger = require_dist_cjs4();
    var middlewareRecursionDetection = require_dist_cjs5();
    var middlewareUserAgent = require_dist_cjs104();
    var configResolver = require_dist_cjs25();
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var schema = (init_schema4(), __toCommonJS(schema_exports));
    var middlewareContentLength = require_dist_cjs26();
    var middlewareEndpoint = require_dist_cjs31();
    var middlewareRetry = require_dist_cjs106();
    var smithyClient = require_dist_cjs34();
    var httpAuthSchemeProvider = require_httpAuthSchemeProvider11();
    var runtimeConfig = require_runtimeConfig12();
    var regionConfigResolver = require_dist_cjs48();
    var protocolHttp = require_dist_cjs2();
    var schemas_0 = require_schemas_011();
    var middlewareSdkEc2 = require_dist_cjs162();
    var utilWaiter = require_dist_cjs156();
    var EC2ServiceException = require_EC2ServiceException();
    var resolveClientEndpointParameters32 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "ec2"
      });
    }, "resolveClientEndpointParameters");
    var commonParams32 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
    var getHttpAuthExtensionConfiguration32 = /* @__PURE__ */ __name((runtimeConfig2) => {
      const _httpAuthSchemes = runtimeConfig2.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig2.httpAuthSchemeProvider;
      let _credentials = runtimeConfig2.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider2) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider2;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    var resolveHttpAuthRuntimeConfig32 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
    var resolveRuntimeExtensions32 = /* @__PURE__ */ __name((runtimeConfig2, extensions) => {
      const extensionConfiguration = Object.assign(regionConfigResolver.getAwsRegionExtensionConfiguration(runtimeConfig2), smithyClient.getDefaultExtensionConfiguration(runtimeConfig2), protocolHttp.getHttpHandlerExtensionConfiguration(runtimeConfig2), getHttpAuthExtensionConfiguration32(runtimeConfig2));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig2, regionConfigResolver.resolveAwsRegionExtensionConfiguration(extensionConfiguration), smithyClient.resolveDefaultRuntimeConfig(extensionConfiguration), protocolHttp.resolveHttpHandlerRuntimeConfig(extensionConfiguration), resolveHttpAuthRuntimeConfig32(extensionConfiguration));
    }, "resolveRuntimeExtensions");
    var EC2Client2 = class extends smithyClient.Client {
      static {
        __name(this, "EC2Client");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = runtimeConfig.getRuntimeConfig(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters32(_config_0);
        const _config_2 = middlewareUserAgent.resolveUserAgentConfig(_config_1);
        const _config_3 = middlewareRetry.resolveRetryConfig(_config_2);
        const _config_4 = configResolver.resolveRegionConfig(_config_3);
        const _config_5 = middlewareHostHeader.resolveHostHeaderConfig(_config_4);
        const _config_6 = middlewareEndpoint.resolveEndpointConfig(_config_5);
        const _config_7 = httpAuthSchemeProvider.resolveHttpAuthSchemeConfig(_config_6);
        const _config_8 = resolveRuntimeExtensions32(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(schema.getSchemaSerdePlugin(this.config));
        this.middlewareStack.use(middlewareUserAgent.getUserAgentPlugin(this.config));
        this.middlewareStack.use(middlewareRetry.getRetryPlugin(this.config));
        this.middlewareStack.use(middlewareContentLength.getContentLengthPlugin(this.config));
        this.middlewareStack.use(middlewareHostHeader.getHostHeaderPlugin(this.config));
        this.middlewareStack.use(middlewareLogger.getLoggerPlugin(this.config));
        this.middlewareStack.use(middlewareRecursionDetection.getRecursionDetectionPlugin(this.config));
        this.middlewareStack.use(core.getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: httpAuthSchemeProvider.defaultEC2HttpAuthSchemeParametersProvider,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new core.DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(core.getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
    var AcceptAddressTransferCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AcceptAddressTransfer", {}).n("EC2Client", "AcceptAddressTransferCommand").sc(schemas_0.AcceptAddressTransfer$).build() {
      static {
        __name(this, "AcceptAddressTransferCommand");
      }
    };
    var AcceptCapacityReservationBillingOwnershipCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AcceptCapacityReservationBillingOwnership", {}).n("EC2Client", "AcceptCapacityReservationBillingOwnershipCommand").sc(schemas_0.AcceptCapacityReservationBillingOwnership$).build() {
      static {
        __name(this, "AcceptCapacityReservationBillingOwnershipCommand");
      }
    };
    var AcceptReservedInstancesExchangeQuoteCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AcceptReservedInstancesExchangeQuote", {}).n("EC2Client", "AcceptReservedInstancesExchangeQuoteCommand").sc(schemas_0.AcceptReservedInstancesExchangeQuote$).build() {
      static {
        __name(this, "AcceptReservedInstancesExchangeQuoteCommand");
      }
    };
    var AcceptTransitGatewayClientVpnAttachmentCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AcceptTransitGatewayClientVpnAttachment", {}).n("EC2Client", "AcceptTransitGatewayClientVpnAttachmentCommand").sc(schemas_0.AcceptTransitGatewayClientVpnAttachment$).build() {
      static {
        __name(this, "AcceptTransitGatewayClientVpnAttachmentCommand");
      }
    };
    var AcceptTransitGatewayMulticastDomainAssociationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AcceptTransitGatewayMulticastDomainAssociations", {}).n("EC2Client", "AcceptTransitGatewayMulticastDomainAssociationsCommand").sc(schemas_0.AcceptTransitGatewayMulticastDomainAssociations$).build() {
      static {
        __name(this, "AcceptTransitGatewayMulticastDomainAssociationsCommand");
      }
    };
    var AcceptTransitGatewayPeeringAttachmentCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AcceptTransitGatewayPeeringAttachment", {}).n("EC2Client", "AcceptTransitGatewayPeeringAttachmentCommand").sc(schemas_0.AcceptTransitGatewayPeeringAttachment$).build() {
      static {
        __name(this, "AcceptTransitGatewayPeeringAttachmentCommand");
      }
    };
    var AcceptTransitGatewayVpcAttachmentCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AcceptTransitGatewayVpcAttachment", {}).n("EC2Client", "AcceptTransitGatewayVpcAttachmentCommand").sc(schemas_0.AcceptTransitGatewayVpcAttachment$).build() {
      static {
        __name(this, "AcceptTransitGatewayVpcAttachmentCommand");
      }
    };
    var AcceptVpcEndpointConnectionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AcceptVpcEndpointConnections", {}).n("EC2Client", "AcceptVpcEndpointConnectionsCommand").sc(schemas_0.AcceptVpcEndpointConnections$).build() {
      static {
        __name(this, "AcceptVpcEndpointConnectionsCommand");
      }
    };
    var AcceptVpcPeeringConnectionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AcceptVpcPeeringConnection", {}).n("EC2Client", "AcceptVpcPeeringConnectionCommand").sc(schemas_0.AcceptVpcPeeringConnection$).build() {
      static {
        __name(this, "AcceptVpcPeeringConnectionCommand");
      }
    };
    var AdvertiseByoipCidrCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AdvertiseByoipCidr", {}).n("EC2Client", "AdvertiseByoipCidrCommand").sc(schemas_0.AdvertiseByoipCidr$).build() {
      static {
        __name(this, "AdvertiseByoipCidrCommand");
      }
    };
    var AllocateAddressCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AllocateAddress", {}).n("EC2Client", "AllocateAddressCommand").sc(schemas_0.AllocateAddress$).build() {
      static {
        __name(this, "AllocateAddressCommand");
      }
    };
    var AllocateHostsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AllocateHosts", {}).n("EC2Client", "AllocateHostsCommand").sc(schemas_0.AllocateHosts$).build() {
      static {
        __name(this, "AllocateHostsCommand");
      }
    };
    var AllocateIpamPoolCidrCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AllocateIpamPoolCidr", {}).n("EC2Client", "AllocateIpamPoolCidrCommand").sc(schemas_0.AllocateIpamPoolCidr$).build() {
      static {
        __name(this, "AllocateIpamPoolCidrCommand");
      }
    };
    var ApplySecurityGroupsToClientVpnTargetNetworkCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ApplySecurityGroupsToClientVpnTargetNetwork", {}).n("EC2Client", "ApplySecurityGroupsToClientVpnTargetNetworkCommand").sc(schemas_0.ApplySecurityGroupsToClientVpnTargetNetwork$).build() {
      static {
        __name(this, "ApplySecurityGroupsToClientVpnTargetNetworkCommand");
      }
    };
    var AssignIpv6AddressesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AssignIpv6Addresses", {}).n("EC2Client", "AssignIpv6AddressesCommand").sc(schemas_0.AssignIpv6Addresses$).build() {
      static {
        __name(this, "AssignIpv6AddressesCommand");
      }
    };
    var AssignPrivateIpAddressesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AssignPrivateIpAddresses", {}).n("EC2Client", "AssignPrivateIpAddressesCommand").sc(schemas_0.AssignPrivateIpAddresses$).build() {
      static {
        __name(this, "AssignPrivateIpAddressesCommand");
      }
    };
    var AssignPrivateNatGatewayAddressCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AssignPrivateNatGatewayAddress", {}).n("EC2Client", "AssignPrivateNatGatewayAddressCommand").sc(schemas_0.AssignPrivateNatGatewayAddress$).build() {
      static {
        __name(this, "AssignPrivateNatGatewayAddressCommand");
      }
    };
    var AssociateAddressCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AssociateAddress", {}).n("EC2Client", "AssociateAddressCommand").sc(schemas_0.AssociateAddress$).build() {
      static {
        __name(this, "AssociateAddressCommand");
      }
    };
    var AssociateCapacityReservationBillingOwnerCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AssociateCapacityReservationBillingOwner", {}).n("EC2Client", "AssociateCapacityReservationBillingOwnerCommand").sc(schemas_0.AssociateCapacityReservationBillingOwner$).build() {
      static {
        __name(this, "AssociateCapacityReservationBillingOwnerCommand");
      }
    };
    var AssociateClientVpnTargetNetworkCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AssociateClientVpnTargetNetwork", {}).n("EC2Client", "AssociateClientVpnTargetNetworkCommand").sc(schemas_0.AssociateClientVpnTargetNetwork$).build() {
      static {
        __name(this, "AssociateClientVpnTargetNetworkCommand");
      }
    };
    var AssociateDhcpOptionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AssociateDhcpOptions", {}).n("EC2Client", "AssociateDhcpOptionsCommand").sc(schemas_0.AssociateDhcpOptions$).build() {
      static {
        __name(this, "AssociateDhcpOptionsCommand");
      }
    };
    var AssociateEnclaveCertificateIamRoleCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AssociateEnclaveCertificateIamRole", {}).n("EC2Client", "AssociateEnclaveCertificateIamRoleCommand").sc(schemas_0.AssociateEnclaveCertificateIamRole$).build() {
      static {
        __name(this, "AssociateEnclaveCertificateIamRoleCommand");
      }
    };
    var AssociateIamInstanceProfileCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AssociateIamInstanceProfile", {}).n("EC2Client", "AssociateIamInstanceProfileCommand").sc(schemas_0.AssociateIamInstanceProfile$).build() {
      static {
        __name(this, "AssociateIamInstanceProfileCommand");
      }
    };
    var AssociateInstanceEventWindowCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AssociateInstanceEventWindow", {}).n("EC2Client", "AssociateInstanceEventWindowCommand").sc(schemas_0.AssociateInstanceEventWindow$).build() {
      static {
        __name(this, "AssociateInstanceEventWindowCommand");
      }
    };
    var AssociateIpamByoasnCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AssociateIpamByoasn", {}).n("EC2Client", "AssociateIpamByoasnCommand").sc(schemas_0.AssociateIpamByoasn$).build() {
      static {
        __name(this, "AssociateIpamByoasnCommand");
      }
    };
    var AssociateIpamResourceDiscoveryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AssociateIpamResourceDiscovery", {}).n("EC2Client", "AssociateIpamResourceDiscoveryCommand").sc(schemas_0.AssociateIpamResourceDiscovery$).build() {
      static {
        __name(this, "AssociateIpamResourceDiscoveryCommand");
      }
    };
    var AssociateNatGatewayAddressCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AssociateNatGatewayAddress", {}).n("EC2Client", "AssociateNatGatewayAddressCommand").sc(schemas_0.AssociateNatGatewayAddress$).build() {
      static {
        __name(this, "AssociateNatGatewayAddressCommand");
      }
    };
    var AssociateRouteServerCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AssociateRouteServer", {}).n("EC2Client", "AssociateRouteServerCommand").sc(schemas_0.AssociateRouteServer$).build() {
      static {
        __name(this, "AssociateRouteServerCommand");
      }
    };
    var AssociateRouteTableCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AssociateRouteTable", {}).n("EC2Client", "AssociateRouteTableCommand").sc(schemas_0.AssociateRouteTable$).build() {
      static {
        __name(this, "AssociateRouteTableCommand");
      }
    };
    var AssociateSecurityGroupVpcCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AssociateSecurityGroupVpc", {}).n("EC2Client", "AssociateSecurityGroupVpcCommand").sc(schemas_0.AssociateSecurityGroupVpc$).build() {
      static {
        __name(this, "AssociateSecurityGroupVpcCommand");
      }
    };
    var AssociateSubnetCidrBlockCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AssociateSubnetCidrBlock", {}).n("EC2Client", "AssociateSubnetCidrBlockCommand").sc(schemas_0.AssociateSubnetCidrBlock$).build() {
      static {
        __name(this, "AssociateSubnetCidrBlockCommand");
      }
    };
    var AssociateTransitGatewayMulticastDomainCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AssociateTransitGatewayMulticastDomain", {}).n("EC2Client", "AssociateTransitGatewayMulticastDomainCommand").sc(schemas_0.AssociateTransitGatewayMulticastDomain$).build() {
      static {
        __name(this, "AssociateTransitGatewayMulticastDomainCommand");
      }
    };
    var AssociateTransitGatewayPolicyTableCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AssociateTransitGatewayPolicyTable", {}).n("EC2Client", "AssociateTransitGatewayPolicyTableCommand").sc(schemas_0.AssociateTransitGatewayPolicyTable$).build() {
      static {
        __name(this, "AssociateTransitGatewayPolicyTableCommand");
      }
    };
    var AssociateTransitGatewayRouteTableCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AssociateTransitGatewayRouteTable", {}).n("EC2Client", "AssociateTransitGatewayRouteTableCommand").sc(schemas_0.AssociateTransitGatewayRouteTable$).build() {
      static {
        __name(this, "AssociateTransitGatewayRouteTableCommand");
      }
    };
    var AssociateTrunkInterfaceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AssociateTrunkInterface", {}).n("EC2Client", "AssociateTrunkInterfaceCommand").sc(schemas_0.AssociateTrunkInterface$).build() {
      static {
        __name(this, "AssociateTrunkInterfaceCommand");
      }
    };
    var AssociateVpcCidrBlockCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AssociateVpcCidrBlock", {}).n("EC2Client", "AssociateVpcCidrBlockCommand").sc(schemas_0.AssociateVpcCidrBlock$).build() {
      static {
        __name(this, "AssociateVpcCidrBlockCommand");
      }
    };
    var AttachClassicLinkVpcCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AttachClassicLinkVpc", {}).n("EC2Client", "AttachClassicLinkVpcCommand").sc(schemas_0.AttachClassicLinkVpc$).build() {
      static {
        __name(this, "AttachClassicLinkVpcCommand");
      }
    };
    var AttachInternetGatewayCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AttachInternetGateway", {}).n("EC2Client", "AttachInternetGatewayCommand").sc(schemas_0.AttachInternetGateway$).build() {
      static {
        __name(this, "AttachInternetGatewayCommand");
      }
    };
    var AttachNetworkInterfaceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AttachNetworkInterface", {}).n("EC2Client", "AttachNetworkInterfaceCommand").sc(schemas_0.AttachNetworkInterface$).build() {
      static {
        __name(this, "AttachNetworkInterfaceCommand");
      }
    };
    var AttachVerifiedAccessTrustProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AttachVerifiedAccessTrustProvider", {}).n("EC2Client", "AttachVerifiedAccessTrustProviderCommand").sc(schemas_0.AttachVerifiedAccessTrustProvider$).build() {
      static {
        __name(this, "AttachVerifiedAccessTrustProviderCommand");
      }
    };
    var AttachVolumeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AttachVolume", {}).n("EC2Client", "AttachVolumeCommand").sc(schemas_0.AttachVolume$).build() {
      static {
        __name(this, "AttachVolumeCommand");
      }
    };
    var AttachVpnGatewayCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AttachVpnGateway", {}).n("EC2Client", "AttachVpnGatewayCommand").sc(schemas_0.AttachVpnGateway$).build() {
      static {
        __name(this, "AttachVpnGatewayCommand");
      }
    };
    var AuthorizeClientVpnIngressCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AuthorizeClientVpnIngress", {}).n("EC2Client", "AuthorizeClientVpnIngressCommand").sc(schemas_0.AuthorizeClientVpnIngress$).build() {
      static {
        __name(this, "AuthorizeClientVpnIngressCommand");
      }
    };
    var AuthorizeSecurityGroupEgressCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AuthorizeSecurityGroupEgress", {}).n("EC2Client", "AuthorizeSecurityGroupEgressCommand").sc(schemas_0.AuthorizeSecurityGroupEgress$).build() {
      static {
        __name(this, "AuthorizeSecurityGroupEgressCommand");
      }
    };
    var AuthorizeSecurityGroupIngressCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "AuthorizeSecurityGroupIngress", {}).n("EC2Client", "AuthorizeSecurityGroupIngressCommand").sc(schemas_0.AuthorizeSecurityGroupIngress$).build() {
      static {
        __name(this, "AuthorizeSecurityGroupIngressCommand");
      }
    };
    var BundleInstanceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "BundleInstance", {}).n("EC2Client", "BundleInstanceCommand").sc(schemas_0.BundleInstance$).build() {
      static {
        __name(this, "BundleInstanceCommand");
      }
    };
    var CancelBundleTaskCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CancelBundleTask", {}).n("EC2Client", "CancelBundleTaskCommand").sc(schemas_0.CancelBundleTask$).build() {
      static {
        __name(this, "CancelBundleTaskCommand");
      }
    };
    var CancelCapacityReservationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CancelCapacityReservation", {}).n("EC2Client", "CancelCapacityReservationCommand").sc(schemas_0.CancelCapacityReservation$).build() {
      static {
        __name(this, "CancelCapacityReservationCommand");
      }
    };
    var CancelCapacityReservationFleetsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CancelCapacityReservationFleets", {}).n("EC2Client", "CancelCapacityReservationFleetsCommand").sc(schemas_0.CancelCapacityReservationFleets$).build() {
      static {
        __name(this, "CancelCapacityReservationFleetsCommand");
      }
    };
    var CancelConversionTaskCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CancelConversionTask", {}).n("EC2Client", "CancelConversionTaskCommand").sc(schemas_0.CancelConversionTask$).build() {
      static {
        __name(this, "CancelConversionTaskCommand");
      }
    };
    var CancelDeclarativePoliciesReportCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CancelDeclarativePoliciesReport", {}).n("EC2Client", "CancelDeclarativePoliciesReportCommand").sc(schemas_0.CancelDeclarativePoliciesReport$).build() {
      static {
        __name(this, "CancelDeclarativePoliciesReportCommand");
      }
    };
    var CancelExportTaskCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CancelExportTask", {}).n("EC2Client", "CancelExportTaskCommand").sc(schemas_0.CancelExportTask$).build() {
      static {
        __name(this, "CancelExportTaskCommand");
      }
    };
    var CancelImageLaunchPermissionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CancelImageLaunchPermission", {}).n("EC2Client", "CancelImageLaunchPermissionCommand").sc(schemas_0.CancelImageLaunchPermission$).build() {
      static {
        __name(this, "CancelImageLaunchPermissionCommand");
      }
    };
    var CancelImportTaskCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CancelImportTask", {}).n("EC2Client", "CancelImportTaskCommand").sc(schemas_0.CancelImportTask$).build() {
      static {
        __name(this, "CancelImportTaskCommand");
      }
    };
    var CancelReservedInstancesListingCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CancelReservedInstancesListing", {}).n("EC2Client", "CancelReservedInstancesListingCommand").sc(schemas_0.CancelReservedInstancesListing$).build() {
      static {
        __name(this, "CancelReservedInstancesListingCommand");
      }
    };
    var CancelSpotFleetRequestsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CancelSpotFleetRequests", {}).n("EC2Client", "CancelSpotFleetRequestsCommand").sc(schemas_0.CancelSpotFleetRequests$).build() {
      static {
        __name(this, "CancelSpotFleetRequestsCommand");
      }
    };
    var CancelSpotInstanceRequestsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CancelSpotInstanceRequests", {}).n("EC2Client", "CancelSpotInstanceRequestsCommand").sc(schemas_0.CancelSpotInstanceRequests$).build() {
      static {
        __name(this, "CancelSpotInstanceRequestsCommand");
      }
    };
    var ConfirmProductInstanceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ConfirmProductInstance", {}).n("EC2Client", "ConfirmProductInstanceCommand").sc(schemas_0.ConfirmProductInstance$).build() {
      static {
        __name(this, "ConfirmProductInstanceCommand");
      }
    };
    var CopyFpgaImageCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CopyFpgaImage", {}).n("EC2Client", "CopyFpgaImageCommand").sc(schemas_0.CopyFpgaImage$).build() {
      static {
        __name(this, "CopyFpgaImageCommand");
      }
    };
    var CopyImageCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CopyImage", {}).n("EC2Client", "CopyImageCommand").sc(schemas_0.CopyImage$).build() {
      static {
        __name(this, "CopyImageCommand");
      }
    };
    var CopySnapshotCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkEc2.getCopySnapshotPresignedUrlPlugin(config2)
      ];
    }).s("AmazonEC2", "CopySnapshot", {}).n("EC2Client", "CopySnapshotCommand").sc(schemas_0.CopySnapshot$).build() {
      static {
        __name(this, "CopySnapshotCommand");
      }
    };
    var CopyVolumesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CopyVolumes", {}).n("EC2Client", "CopyVolumesCommand").sc(schemas_0.CopyVolumes$).build() {
      static {
        __name(this, "CopyVolumesCommand");
      }
    };
    var CreateCapacityManagerDataExportCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateCapacityManagerDataExport", {}).n("EC2Client", "CreateCapacityManagerDataExportCommand").sc(schemas_0.CreateCapacityManagerDataExport$).build() {
      static {
        __name(this, "CreateCapacityManagerDataExportCommand");
      }
    };
    var CreateCapacityReservationBySplittingCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateCapacityReservationBySplitting", {}).n("EC2Client", "CreateCapacityReservationBySplittingCommand").sc(schemas_0.CreateCapacityReservationBySplitting$).build() {
      static {
        __name(this, "CreateCapacityReservationBySplittingCommand");
      }
    };
    var CreateCapacityReservationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateCapacityReservation", {}).n("EC2Client", "CreateCapacityReservationCommand").sc(schemas_0.CreateCapacityReservation$).build() {
      static {
        __name(this, "CreateCapacityReservationCommand");
      }
    };
    var CreateCapacityReservationFleetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateCapacityReservationFleet", {}).n("EC2Client", "CreateCapacityReservationFleetCommand").sc(schemas_0.CreateCapacityReservationFleet$).build() {
      static {
        __name(this, "CreateCapacityReservationFleetCommand");
      }
    };
    var CreateCarrierGatewayCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateCarrierGateway", {}).n("EC2Client", "CreateCarrierGatewayCommand").sc(schemas_0.CreateCarrierGateway$).build() {
      static {
        __name(this, "CreateCarrierGatewayCommand");
      }
    };
    var CreateClientVpnEndpointCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateClientVpnEndpoint", {}).n("EC2Client", "CreateClientVpnEndpointCommand").sc(schemas_0.CreateClientVpnEndpoint$).build() {
      static {
        __name(this, "CreateClientVpnEndpointCommand");
      }
    };
    var CreateClientVpnRouteCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateClientVpnRoute", {}).n("EC2Client", "CreateClientVpnRouteCommand").sc(schemas_0.CreateClientVpnRoute$).build() {
      static {
        __name(this, "CreateClientVpnRouteCommand");
      }
    };
    var CreateCoipCidrCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateCoipCidr", {}).n("EC2Client", "CreateCoipCidrCommand").sc(schemas_0.CreateCoipCidr$).build() {
      static {
        __name(this, "CreateCoipCidrCommand");
      }
    };
    var CreateCoipPoolCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateCoipPool", {}).n("EC2Client", "CreateCoipPoolCommand").sc(schemas_0.CreateCoipPool$).build() {
      static {
        __name(this, "CreateCoipPoolCommand");
      }
    };
    var CreateCustomerGatewayCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateCustomerGateway", {}).n("EC2Client", "CreateCustomerGatewayCommand").sc(schemas_0.CreateCustomerGateway$).build() {
      static {
        __name(this, "CreateCustomerGatewayCommand");
      }
    };
    var CreateDefaultSubnetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateDefaultSubnet", {}).n("EC2Client", "CreateDefaultSubnetCommand").sc(schemas_0.CreateDefaultSubnet$).build() {
      static {
        __name(this, "CreateDefaultSubnetCommand");
      }
    };
    var CreateDefaultVpcCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateDefaultVpc", {}).n("EC2Client", "CreateDefaultVpcCommand").sc(schemas_0.CreateDefaultVpc$).build() {
      static {
        __name(this, "CreateDefaultVpcCommand");
      }
    };
    var CreateDelegateMacVolumeOwnershipTaskCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateDelegateMacVolumeOwnershipTask", {}).n("EC2Client", "CreateDelegateMacVolumeOwnershipTaskCommand").sc(schemas_0.CreateDelegateMacVolumeOwnershipTask$).build() {
      static {
        __name(this, "CreateDelegateMacVolumeOwnershipTaskCommand");
      }
    };
    var CreateDhcpOptionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateDhcpOptions", {}).n("EC2Client", "CreateDhcpOptionsCommand").sc(schemas_0.CreateDhcpOptions$).build() {
      static {
        __name(this, "CreateDhcpOptionsCommand");
      }
    };
    var CreateEgressOnlyInternetGatewayCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateEgressOnlyInternetGateway", {}).n("EC2Client", "CreateEgressOnlyInternetGatewayCommand").sc(schemas_0.CreateEgressOnlyInternetGateway$).build() {
      static {
        __name(this, "CreateEgressOnlyInternetGatewayCommand");
      }
    };
    var CreateFleetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateFleet", {}).n("EC2Client", "CreateFleetCommand").sc(schemas_0.CreateFleet$).build() {
      static {
        __name(this, "CreateFleetCommand");
      }
    };
    var CreateFlowLogsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateFlowLogs", {}).n("EC2Client", "CreateFlowLogsCommand").sc(schemas_0.CreateFlowLogs$).build() {
      static {
        __name(this, "CreateFlowLogsCommand");
      }
    };
    var CreateFpgaImageCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateFpgaImage", {}).n("EC2Client", "CreateFpgaImageCommand").sc(schemas_0.CreateFpgaImage$).build() {
      static {
        __name(this, "CreateFpgaImageCommand");
      }
    };
    var CreateImageCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateImage", {}).n("EC2Client", "CreateImageCommand").sc(schemas_0.CreateImage$).build() {
      static {
        __name(this, "CreateImageCommand");
      }
    };
    var CreateImageUsageReportCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateImageUsageReport", {}).n("EC2Client", "CreateImageUsageReportCommand").sc(schemas_0.CreateImageUsageReport$).build() {
      static {
        __name(this, "CreateImageUsageReportCommand");
      }
    };
    var CreateInstanceConnectEndpointCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateInstanceConnectEndpoint", {}).n("EC2Client", "CreateInstanceConnectEndpointCommand").sc(schemas_0.CreateInstanceConnectEndpoint$).build() {
      static {
        __name(this, "CreateInstanceConnectEndpointCommand");
      }
    };
    var CreateInstanceEventWindowCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateInstanceEventWindow", {}).n("EC2Client", "CreateInstanceEventWindowCommand").sc(schemas_0.CreateInstanceEventWindow$).build() {
      static {
        __name(this, "CreateInstanceEventWindowCommand");
      }
    };
    var CreateInstanceExportTaskCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateInstanceExportTask", {}).n("EC2Client", "CreateInstanceExportTaskCommand").sc(schemas_0.CreateInstanceExportTask$).build() {
      static {
        __name(this, "CreateInstanceExportTaskCommand");
      }
    };
    var CreateInternetGatewayCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateInternetGateway", {}).n("EC2Client", "CreateInternetGatewayCommand").sc(schemas_0.CreateInternetGateway$).build() {
      static {
        __name(this, "CreateInternetGatewayCommand");
      }
    };
    var CreateInterruptibleCapacityReservationAllocationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateInterruptibleCapacityReservationAllocation", {}).n("EC2Client", "CreateInterruptibleCapacityReservationAllocationCommand").sc(schemas_0.CreateInterruptibleCapacityReservationAllocation$).build() {
      static {
        __name(this, "CreateInterruptibleCapacityReservationAllocationCommand");
      }
    };
    var CreateIpamCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateIpam", {}).n("EC2Client", "CreateIpamCommand").sc(schemas_0.CreateIpam$).build() {
      static {
        __name(this, "CreateIpamCommand");
      }
    };
    var CreateIpamExternalResourceVerificationTokenCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateIpamExternalResourceVerificationToken", {}).n("EC2Client", "CreateIpamExternalResourceVerificationTokenCommand").sc(schemas_0.CreateIpamExternalResourceVerificationToken$).build() {
      static {
        __name(this, "CreateIpamExternalResourceVerificationTokenCommand");
      }
    };
    var CreateIpamPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateIpamPolicy", {}).n("EC2Client", "CreateIpamPolicyCommand").sc(schemas_0.CreateIpamPolicy$).build() {
      static {
        __name(this, "CreateIpamPolicyCommand");
      }
    };
    var CreateIpamPoolCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateIpamPool", {}).n("EC2Client", "CreateIpamPoolCommand").sc(schemas_0.CreateIpamPool$).build() {
      static {
        __name(this, "CreateIpamPoolCommand");
      }
    };
    var CreateIpamPrefixListResolverCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateIpamPrefixListResolver", {}).n("EC2Client", "CreateIpamPrefixListResolverCommand").sc(schemas_0.CreateIpamPrefixListResolver$).build() {
      static {
        __name(this, "CreateIpamPrefixListResolverCommand");
      }
    };
    var CreateIpamPrefixListResolverTargetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateIpamPrefixListResolverTarget", {}).n("EC2Client", "CreateIpamPrefixListResolverTargetCommand").sc(schemas_0.CreateIpamPrefixListResolverTarget$).build() {
      static {
        __name(this, "CreateIpamPrefixListResolverTargetCommand");
      }
    };
    var CreateIpamResourceDiscoveryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateIpamResourceDiscovery", {}).n("EC2Client", "CreateIpamResourceDiscoveryCommand").sc(schemas_0.CreateIpamResourceDiscovery$).build() {
      static {
        __name(this, "CreateIpamResourceDiscoveryCommand");
      }
    };
    var CreateIpamScopeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateIpamScope", {}).n("EC2Client", "CreateIpamScopeCommand").sc(schemas_0.CreateIpamScope$).build() {
      static {
        __name(this, "CreateIpamScopeCommand");
      }
    };
    var CreateKeyPairCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateKeyPair", {}).n("EC2Client", "CreateKeyPairCommand").sc(schemas_0.CreateKeyPair$).build() {
      static {
        __name(this, "CreateKeyPairCommand");
      }
    };
    var CreateLaunchTemplateCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateLaunchTemplate", {}).n("EC2Client", "CreateLaunchTemplateCommand").sc(schemas_0.CreateLaunchTemplate$).build() {
      static {
        __name(this, "CreateLaunchTemplateCommand");
      }
    };
    var CreateLaunchTemplateVersionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateLaunchTemplateVersion", {}).n("EC2Client", "CreateLaunchTemplateVersionCommand").sc(schemas_0.CreateLaunchTemplateVersion$).build() {
      static {
        __name(this, "CreateLaunchTemplateVersionCommand");
      }
    };
    var CreateLocalGatewayRouteCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateLocalGatewayRoute", {}).n("EC2Client", "CreateLocalGatewayRouteCommand").sc(schemas_0.CreateLocalGatewayRoute$).build() {
      static {
        __name(this, "CreateLocalGatewayRouteCommand");
      }
    };
    var CreateLocalGatewayRouteTableCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateLocalGatewayRouteTable", {}).n("EC2Client", "CreateLocalGatewayRouteTableCommand").sc(schemas_0.CreateLocalGatewayRouteTable$).build() {
      static {
        __name(this, "CreateLocalGatewayRouteTableCommand");
      }
    };
    var CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociation", {}).n("EC2Client", "CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationCommand").sc(schemas_0.CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociation$).build() {
      static {
        __name(this, "CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationCommand");
      }
    };
    var CreateLocalGatewayRouteTableVpcAssociationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateLocalGatewayRouteTableVpcAssociation", {}).n("EC2Client", "CreateLocalGatewayRouteTableVpcAssociationCommand").sc(schemas_0.CreateLocalGatewayRouteTableVpcAssociation$).build() {
      static {
        __name(this, "CreateLocalGatewayRouteTableVpcAssociationCommand");
      }
    };
    var CreateLocalGatewayVirtualInterfaceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateLocalGatewayVirtualInterface", {}).n("EC2Client", "CreateLocalGatewayVirtualInterfaceCommand").sc(schemas_0.CreateLocalGatewayVirtualInterface$).build() {
      static {
        __name(this, "CreateLocalGatewayVirtualInterfaceCommand");
      }
    };
    var CreateLocalGatewayVirtualInterfaceGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateLocalGatewayVirtualInterfaceGroup", {}).n("EC2Client", "CreateLocalGatewayVirtualInterfaceGroupCommand").sc(schemas_0.CreateLocalGatewayVirtualInterfaceGroup$).build() {
      static {
        __name(this, "CreateLocalGatewayVirtualInterfaceGroupCommand");
      }
    };
    var CreateMacSystemIntegrityProtectionModificationTaskCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateMacSystemIntegrityProtectionModificationTask", {}).n("EC2Client", "CreateMacSystemIntegrityProtectionModificationTaskCommand").sc(schemas_0.CreateMacSystemIntegrityProtectionModificationTask$).build() {
      static {
        __name(this, "CreateMacSystemIntegrityProtectionModificationTaskCommand");
      }
    };
    var CreateManagedPrefixListCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateManagedPrefixList", {}).n("EC2Client", "CreateManagedPrefixListCommand").sc(schemas_0.CreateManagedPrefixList$).build() {
      static {
        __name(this, "CreateManagedPrefixListCommand");
      }
    };
    var CreateNatGatewayCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateNatGateway", {}).n("EC2Client", "CreateNatGatewayCommand").sc(schemas_0.CreateNatGateway$).build() {
      static {
        __name(this, "CreateNatGatewayCommand");
      }
    };
    var CreateNetworkAclCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateNetworkAcl", {}).n("EC2Client", "CreateNetworkAclCommand").sc(schemas_0.CreateNetworkAcl$).build() {
      static {
        __name(this, "CreateNetworkAclCommand");
      }
    };
    var CreateNetworkAclEntryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateNetworkAclEntry", {}).n("EC2Client", "CreateNetworkAclEntryCommand").sc(schemas_0.CreateNetworkAclEntry$).build() {
      static {
        __name(this, "CreateNetworkAclEntryCommand");
      }
    };
    var CreateNetworkInsightsAccessScopeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateNetworkInsightsAccessScope", {}).n("EC2Client", "CreateNetworkInsightsAccessScopeCommand").sc(schemas_0.CreateNetworkInsightsAccessScope$).build() {
      static {
        __name(this, "CreateNetworkInsightsAccessScopeCommand");
      }
    };
    var CreateNetworkInsightsPathCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateNetworkInsightsPath", {}).n("EC2Client", "CreateNetworkInsightsPathCommand").sc(schemas_0.CreateNetworkInsightsPath$).build() {
      static {
        __name(this, "CreateNetworkInsightsPathCommand");
      }
    };
    var CreateNetworkInterfaceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateNetworkInterface", {}).n("EC2Client", "CreateNetworkInterfaceCommand").sc(schemas_0.CreateNetworkInterface$).build() {
      static {
        __name(this, "CreateNetworkInterfaceCommand");
      }
    };
    var CreateNetworkInterfacePermissionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateNetworkInterfacePermission", {}).n("EC2Client", "CreateNetworkInterfacePermissionCommand").sc(schemas_0.CreateNetworkInterfacePermission$).build() {
      static {
        __name(this, "CreateNetworkInterfacePermissionCommand");
      }
    };
    var CreatePlacementGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreatePlacementGroup", {}).n("EC2Client", "CreatePlacementGroupCommand").sc(schemas_0.CreatePlacementGroup$).build() {
      static {
        __name(this, "CreatePlacementGroupCommand");
      }
    };
    var CreatePublicIpv4PoolCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreatePublicIpv4Pool", {}).n("EC2Client", "CreatePublicIpv4PoolCommand").sc(schemas_0.CreatePublicIpv4Pool$).build() {
      static {
        __name(this, "CreatePublicIpv4PoolCommand");
      }
    };
    var CreateReplaceRootVolumeTaskCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateReplaceRootVolumeTask", {}).n("EC2Client", "CreateReplaceRootVolumeTaskCommand").sc(schemas_0.CreateReplaceRootVolumeTask$).build() {
      static {
        __name(this, "CreateReplaceRootVolumeTaskCommand");
      }
    };
    var CreateReservedInstancesListingCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateReservedInstancesListing", {}).n("EC2Client", "CreateReservedInstancesListingCommand").sc(schemas_0.CreateReservedInstancesListing$).build() {
      static {
        __name(this, "CreateReservedInstancesListingCommand");
      }
    };
    var CreateRestoreImageTaskCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateRestoreImageTask", {}).n("EC2Client", "CreateRestoreImageTaskCommand").sc(schemas_0.CreateRestoreImageTask$).build() {
      static {
        __name(this, "CreateRestoreImageTaskCommand");
      }
    };
    var CreateRouteCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateRoute", {}).n("EC2Client", "CreateRouteCommand").sc(schemas_0.CreateRoute$).build() {
      static {
        __name(this, "CreateRouteCommand");
      }
    };
    var CreateRouteServerCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateRouteServer", {}).n("EC2Client", "CreateRouteServerCommand").sc(schemas_0.CreateRouteServer$).build() {
      static {
        __name(this, "CreateRouteServerCommand");
      }
    };
    var CreateRouteServerEndpointCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateRouteServerEndpoint", {}).n("EC2Client", "CreateRouteServerEndpointCommand").sc(schemas_0.CreateRouteServerEndpoint$).build() {
      static {
        __name(this, "CreateRouteServerEndpointCommand");
      }
    };
    var CreateRouteServerPeerCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateRouteServerPeer", {}).n("EC2Client", "CreateRouteServerPeerCommand").sc(schemas_0.CreateRouteServerPeer$).build() {
      static {
        __name(this, "CreateRouteServerPeerCommand");
      }
    };
    var CreateRouteTableCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateRouteTable", {}).n("EC2Client", "CreateRouteTableCommand").sc(schemas_0.CreateRouteTable$).build() {
      static {
        __name(this, "CreateRouteTableCommand");
      }
    };
    var CreateSecondaryNetworkCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateSecondaryNetwork", {}).n("EC2Client", "CreateSecondaryNetworkCommand").sc(schemas_0.CreateSecondaryNetwork$).build() {
      static {
        __name(this, "CreateSecondaryNetworkCommand");
      }
    };
    var CreateSecondarySubnetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateSecondarySubnet", {}).n("EC2Client", "CreateSecondarySubnetCommand").sc(schemas_0.CreateSecondarySubnet$).build() {
      static {
        __name(this, "CreateSecondarySubnetCommand");
      }
    };
    var CreateSecurityGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateSecurityGroup", {}).n("EC2Client", "CreateSecurityGroupCommand").sc(schemas_0.CreateSecurityGroup$).build() {
      static {
        __name(this, "CreateSecurityGroupCommand");
      }
    };
    var CreateSnapshotCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateSnapshot", {}).n("EC2Client", "CreateSnapshotCommand").sc(schemas_0.CreateSnapshot$).build() {
      static {
        __name(this, "CreateSnapshotCommand");
      }
    };
    var CreateSnapshotsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateSnapshots", {}).n("EC2Client", "CreateSnapshotsCommand").sc(schemas_0.CreateSnapshots$).build() {
      static {
        __name(this, "CreateSnapshotsCommand");
      }
    };
    var CreateSpotDatafeedSubscriptionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateSpotDatafeedSubscription", {}).n("EC2Client", "CreateSpotDatafeedSubscriptionCommand").sc(schemas_0.CreateSpotDatafeedSubscription$).build() {
      static {
        __name(this, "CreateSpotDatafeedSubscriptionCommand");
      }
    };
    var CreateStoreImageTaskCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateStoreImageTask", {}).n("EC2Client", "CreateStoreImageTaskCommand").sc(schemas_0.CreateStoreImageTask$).build() {
      static {
        __name(this, "CreateStoreImageTaskCommand");
      }
    };
    var CreateSubnetCidrReservationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateSubnetCidrReservation", {}).n("EC2Client", "CreateSubnetCidrReservationCommand").sc(schemas_0.CreateSubnetCidrReservation$).build() {
      static {
        __name(this, "CreateSubnetCidrReservationCommand");
      }
    };
    var CreateSubnetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateSubnet", {}).n("EC2Client", "CreateSubnetCommand").sc(schemas_0.CreateSubnet$).build() {
      static {
        __name(this, "CreateSubnetCommand");
      }
    };
    var CreateTagsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateTags", {}).n("EC2Client", "CreateTagsCommand").sc(schemas_0.CreateTags$).build() {
      static {
        __name(this, "CreateTagsCommand");
      }
    };
    var CreateTrafficMirrorFilterCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateTrafficMirrorFilter", {}).n("EC2Client", "CreateTrafficMirrorFilterCommand").sc(schemas_0.CreateTrafficMirrorFilter$).build() {
      static {
        __name(this, "CreateTrafficMirrorFilterCommand");
      }
    };
    var CreateTrafficMirrorFilterRuleCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateTrafficMirrorFilterRule", {}).n("EC2Client", "CreateTrafficMirrorFilterRuleCommand").sc(schemas_0.CreateTrafficMirrorFilterRule$).build() {
      static {
        __name(this, "CreateTrafficMirrorFilterRuleCommand");
      }
    };
    var CreateTrafficMirrorSessionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateTrafficMirrorSession", {}).n("EC2Client", "CreateTrafficMirrorSessionCommand").sc(schemas_0.CreateTrafficMirrorSession$).build() {
      static {
        __name(this, "CreateTrafficMirrorSessionCommand");
      }
    };
    var CreateTrafficMirrorTargetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateTrafficMirrorTarget", {}).n("EC2Client", "CreateTrafficMirrorTargetCommand").sc(schemas_0.CreateTrafficMirrorTarget$).build() {
      static {
        __name(this, "CreateTrafficMirrorTargetCommand");
      }
    };
    var CreateTransitGatewayCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateTransitGateway", {}).n("EC2Client", "CreateTransitGatewayCommand").sc(schemas_0.CreateTransitGateway$).build() {
      static {
        __name(this, "CreateTransitGatewayCommand");
      }
    };
    var CreateTransitGatewayConnectCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateTransitGatewayConnect", {}).n("EC2Client", "CreateTransitGatewayConnectCommand").sc(schemas_0.CreateTransitGatewayConnect$).build() {
      static {
        __name(this, "CreateTransitGatewayConnectCommand");
      }
    };
    var CreateTransitGatewayConnectPeerCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateTransitGatewayConnectPeer", {}).n("EC2Client", "CreateTransitGatewayConnectPeerCommand").sc(schemas_0.CreateTransitGatewayConnectPeer$).build() {
      static {
        __name(this, "CreateTransitGatewayConnectPeerCommand");
      }
    };
    var CreateTransitGatewayMeteringPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateTransitGatewayMeteringPolicy", {}).n("EC2Client", "CreateTransitGatewayMeteringPolicyCommand").sc(schemas_0.CreateTransitGatewayMeteringPolicy$).build() {
      static {
        __name(this, "CreateTransitGatewayMeteringPolicyCommand");
      }
    };
    var CreateTransitGatewayMeteringPolicyEntryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateTransitGatewayMeteringPolicyEntry", {}).n("EC2Client", "CreateTransitGatewayMeteringPolicyEntryCommand").sc(schemas_0.CreateTransitGatewayMeteringPolicyEntry$).build() {
      static {
        __name(this, "CreateTransitGatewayMeteringPolicyEntryCommand");
      }
    };
    var CreateTransitGatewayMulticastDomainCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateTransitGatewayMulticastDomain", {}).n("EC2Client", "CreateTransitGatewayMulticastDomainCommand").sc(schemas_0.CreateTransitGatewayMulticastDomain$).build() {
      static {
        __name(this, "CreateTransitGatewayMulticastDomainCommand");
      }
    };
    var CreateTransitGatewayPeeringAttachmentCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateTransitGatewayPeeringAttachment", {}).n("EC2Client", "CreateTransitGatewayPeeringAttachmentCommand").sc(schemas_0.CreateTransitGatewayPeeringAttachment$).build() {
      static {
        __name(this, "CreateTransitGatewayPeeringAttachmentCommand");
      }
    };
    var CreateTransitGatewayPolicyTableCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateTransitGatewayPolicyTable", {}).n("EC2Client", "CreateTransitGatewayPolicyTableCommand").sc(schemas_0.CreateTransitGatewayPolicyTable$).build() {
      static {
        __name(this, "CreateTransitGatewayPolicyTableCommand");
      }
    };
    var CreateTransitGatewayPrefixListReferenceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateTransitGatewayPrefixListReference", {}).n("EC2Client", "CreateTransitGatewayPrefixListReferenceCommand").sc(schemas_0.CreateTransitGatewayPrefixListReference$).build() {
      static {
        __name(this, "CreateTransitGatewayPrefixListReferenceCommand");
      }
    };
    var CreateTransitGatewayRouteCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateTransitGatewayRoute", {}).n("EC2Client", "CreateTransitGatewayRouteCommand").sc(schemas_0.CreateTransitGatewayRoute$).build() {
      static {
        __name(this, "CreateTransitGatewayRouteCommand");
      }
    };
    var CreateTransitGatewayRouteTableAnnouncementCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateTransitGatewayRouteTableAnnouncement", {}).n("EC2Client", "CreateTransitGatewayRouteTableAnnouncementCommand").sc(schemas_0.CreateTransitGatewayRouteTableAnnouncement$).build() {
      static {
        __name(this, "CreateTransitGatewayRouteTableAnnouncementCommand");
      }
    };
    var CreateTransitGatewayRouteTableCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateTransitGatewayRouteTable", {}).n("EC2Client", "CreateTransitGatewayRouteTableCommand").sc(schemas_0.CreateTransitGatewayRouteTable$).build() {
      static {
        __name(this, "CreateTransitGatewayRouteTableCommand");
      }
    };
    var CreateTransitGatewayVpcAttachmentCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateTransitGatewayVpcAttachment", {}).n("EC2Client", "CreateTransitGatewayVpcAttachmentCommand").sc(schemas_0.CreateTransitGatewayVpcAttachment$).build() {
      static {
        __name(this, "CreateTransitGatewayVpcAttachmentCommand");
      }
    };
    var CreateVerifiedAccessEndpointCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateVerifiedAccessEndpoint", {}).n("EC2Client", "CreateVerifiedAccessEndpointCommand").sc(schemas_0.CreateVerifiedAccessEndpoint$).build() {
      static {
        __name(this, "CreateVerifiedAccessEndpointCommand");
      }
    };
    var CreateVerifiedAccessGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateVerifiedAccessGroup", {}).n("EC2Client", "CreateVerifiedAccessGroupCommand").sc(schemas_0.CreateVerifiedAccessGroup$).build() {
      static {
        __name(this, "CreateVerifiedAccessGroupCommand");
      }
    };
    var CreateVerifiedAccessInstanceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateVerifiedAccessInstance", {}).n("EC2Client", "CreateVerifiedAccessInstanceCommand").sc(schemas_0.CreateVerifiedAccessInstance$).build() {
      static {
        __name(this, "CreateVerifiedAccessInstanceCommand");
      }
    };
    var CreateVerifiedAccessTrustProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateVerifiedAccessTrustProvider", {}).n("EC2Client", "CreateVerifiedAccessTrustProviderCommand").sc(schemas_0.CreateVerifiedAccessTrustProvider$).build() {
      static {
        __name(this, "CreateVerifiedAccessTrustProviderCommand");
      }
    };
    var CreateVolumeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateVolume", {}).n("EC2Client", "CreateVolumeCommand").sc(schemas_0.CreateVolume$).build() {
      static {
        __name(this, "CreateVolumeCommand");
      }
    };
    var CreateVpcBlockPublicAccessExclusionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateVpcBlockPublicAccessExclusion", {}).n("EC2Client", "CreateVpcBlockPublicAccessExclusionCommand").sc(schemas_0.CreateVpcBlockPublicAccessExclusion$).build() {
      static {
        __name(this, "CreateVpcBlockPublicAccessExclusionCommand");
      }
    };
    var CreateVpcCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateVpc", {}).n("EC2Client", "CreateVpcCommand").sc(schemas_0.CreateVpc$).build() {
      static {
        __name(this, "CreateVpcCommand");
      }
    };
    var CreateVpcEncryptionControlCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateVpcEncryptionControl", {}).n("EC2Client", "CreateVpcEncryptionControlCommand").sc(schemas_0.CreateVpcEncryptionControl$).build() {
      static {
        __name(this, "CreateVpcEncryptionControlCommand");
      }
    };
    var CreateVpcEndpointCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateVpcEndpoint", {}).n("EC2Client", "CreateVpcEndpointCommand").sc(schemas_0.CreateVpcEndpoint$).build() {
      static {
        __name(this, "CreateVpcEndpointCommand");
      }
    };
    var CreateVpcEndpointConnectionNotificationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateVpcEndpointConnectionNotification", {}).n("EC2Client", "CreateVpcEndpointConnectionNotificationCommand").sc(schemas_0.CreateVpcEndpointConnectionNotification$).build() {
      static {
        __name(this, "CreateVpcEndpointConnectionNotificationCommand");
      }
    };
    var CreateVpcEndpointServiceConfigurationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateVpcEndpointServiceConfiguration", {}).n("EC2Client", "CreateVpcEndpointServiceConfigurationCommand").sc(schemas_0.CreateVpcEndpointServiceConfiguration$).build() {
      static {
        __name(this, "CreateVpcEndpointServiceConfigurationCommand");
      }
    };
    var CreateVpcPeeringConnectionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateVpcPeeringConnection", {}).n("EC2Client", "CreateVpcPeeringConnectionCommand").sc(schemas_0.CreateVpcPeeringConnection$).build() {
      static {
        __name(this, "CreateVpcPeeringConnectionCommand");
      }
    };
    var CreateVpnConcentratorCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateVpnConcentrator", {}).n("EC2Client", "CreateVpnConcentratorCommand").sc(schemas_0.CreateVpnConcentrator$).build() {
      static {
        __name(this, "CreateVpnConcentratorCommand");
      }
    };
    var CreateVpnConnectionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateVpnConnection", {}).n("EC2Client", "CreateVpnConnectionCommand").sc(schemas_0.CreateVpnConnection$).build() {
      static {
        __name(this, "CreateVpnConnectionCommand");
      }
    };
    var CreateVpnConnectionRouteCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateVpnConnectionRoute", {}).n("EC2Client", "CreateVpnConnectionRouteCommand").sc(schemas_0.CreateVpnConnectionRoute$).build() {
      static {
        __name(this, "CreateVpnConnectionRouteCommand");
      }
    };
    var CreateVpnGatewayCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "CreateVpnGateway", {}).n("EC2Client", "CreateVpnGatewayCommand").sc(schemas_0.CreateVpnGateway$).build() {
      static {
        __name(this, "CreateVpnGatewayCommand");
      }
    };
    var DeleteCapacityManagerDataExportCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteCapacityManagerDataExport", {}).n("EC2Client", "DeleteCapacityManagerDataExportCommand").sc(schemas_0.DeleteCapacityManagerDataExport$).build() {
      static {
        __name(this, "DeleteCapacityManagerDataExportCommand");
      }
    };
    var DeleteCarrierGatewayCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteCarrierGateway", {}).n("EC2Client", "DeleteCarrierGatewayCommand").sc(schemas_0.DeleteCarrierGateway$).build() {
      static {
        __name(this, "DeleteCarrierGatewayCommand");
      }
    };
    var DeleteClientVpnEndpointCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteClientVpnEndpoint", {}).n("EC2Client", "DeleteClientVpnEndpointCommand").sc(schemas_0.DeleteClientVpnEndpoint$).build() {
      static {
        __name(this, "DeleteClientVpnEndpointCommand");
      }
    };
    var DeleteClientVpnRouteCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteClientVpnRoute", {}).n("EC2Client", "DeleteClientVpnRouteCommand").sc(schemas_0.DeleteClientVpnRoute$).build() {
      static {
        __name(this, "DeleteClientVpnRouteCommand");
      }
    };
    var DeleteCoipCidrCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteCoipCidr", {}).n("EC2Client", "DeleteCoipCidrCommand").sc(schemas_0.DeleteCoipCidr$).build() {
      static {
        __name(this, "DeleteCoipCidrCommand");
      }
    };
    var DeleteCoipPoolCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteCoipPool", {}).n("EC2Client", "DeleteCoipPoolCommand").sc(schemas_0.DeleteCoipPool$).build() {
      static {
        __name(this, "DeleteCoipPoolCommand");
      }
    };
    var DeleteCustomerGatewayCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteCustomerGateway", {}).n("EC2Client", "DeleteCustomerGatewayCommand").sc(schemas_0.DeleteCustomerGateway$).build() {
      static {
        __name(this, "DeleteCustomerGatewayCommand");
      }
    };
    var DeleteDhcpOptionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteDhcpOptions", {}).n("EC2Client", "DeleteDhcpOptionsCommand").sc(schemas_0.DeleteDhcpOptions$).build() {
      static {
        __name(this, "DeleteDhcpOptionsCommand");
      }
    };
    var DeleteEgressOnlyInternetGatewayCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteEgressOnlyInternetGateway", {}).n("EC2Client", "DeleteEgressOnlyInternetGatewayCommand").sc(schemas_0.DeleteEgressOnlyInternetGateway$).build() {
      static {
        __name(this, "DeleteEgressOnlyInternetGatewayCommand");
      }
    };
    var DeleteFleetsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteFleets", {}).n("EC2Client", "DeleteFleetsCommand").sc(schemas_0.DeleteFleets$).build() {
      static {
        __name(this, "DeleteFleetsCommand");
      }
    };
    var DeleteFlowLogsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteFlowLogs", {}).n("EC2Client", "DeleteFlowLogsCommand").sc(schemas_0.DeleteFlowLogs$).build() {
      static {
        __name(this, "DeleteFlowLogsCommand");
      }
    };
    var DeleteFpgaImageCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteFpgaImage", {}).n("EC2Client", "DeleteFpgaImageCommand").sc(schemas_0.DeleteFpgaImage$).build() {
      static {
        __name(this, "DeleteFpgaImageCommand");
      }
    };
    var DeleteImageUsageReportCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteImageUsageReport", {}).n("EC2Client", "DeleteImageUsageReportCommand").sc(schemas_0.DeleteImageUsageReport$).build() {
      static {
        __name(this, "DeleteImageUsageReportCommand");
      }
    };
    var DeleteInstanceConnectEndpointCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteInstanceConnectEndpoint", {}).n("EC2Client", "DeleteInstanceConnectEndpointCommand").sc(schemas_0.DeleteInstanceConnectEndpoint$).build() {
      static {
        __name(this, "DeleteInstanceConnectEndpointCommand");
      }
    };
    var DeleteInstanceEventWindowCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteInstanceEventWindow", {}).n("EC2Client", "DeleteInstanceEventWindowCommand").sc(schemas_0.DeleteInstanceEventWindow$).build() {
      static {
        __name(this, "DeleteInstanceEventWindowCommand");
      }
    };
    var DeleteInternetGatewayCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteInternetGateway", {}).n("EC2Client", "DeleteInternetGatewayCommand").sc(schemas_0.DeleteInternetGateway$).build() {
      static {
        __name(this, "DeleteInternetGatewayCommand");
      }
    };
    var DeleteIpamCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteIpam", {}).n("EC2Client", "DeleteIpamCommand").sc(schemas_0.DeleteIpam$).build() {
      static {
        __name(this, "DeleteIpamCommand");
      }
    };
    var DeleteIpamExternalResourceVerificationTokenCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteIpamExternalResourceVerificationToken", {}).n("EC2Client", "DeleteIpamExternalResourceVerificationTokenCommand").sc(schemas_0.DeleteIpamExternalResourceVerificationToken$).build() {
      static {
        __name(this, "DeleteIpamExternalResourceVerificationTokenCommand");
      }
    };
    var DeleteIpamPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteIpamPolicy", {}).n("EC2Client", "DeleteIpamPolicyCommand").sc(schemas_0.DeleteIpamPolicy$).build() {
      static {
        __name(this, "DeleteIpamPolicyCommand");
      }
    };
    var DeleteIpamPoolCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteIpamPool", {}).n("EC2Client", "DeleteIpamPoolCommand").sc(schemas_0.DeleteIpamPool$).build() {
      static {
        __name(this, "DeleteIpamPoolCommand");
      }
    };
    var DeleteIpamPrefixListResolverCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteIpamPrefixListResolver", {}).n("EC2Client", "DeleteIpamPrefixListResolverCommand").sc(schemas_0.DeleteIpamPrefixListResolver$).build() {
      static {
        __name(this, "DeleteIpamPrefixListResolverCommand");
      }
    };
    var DeleteIpamPrefixListResolverTargetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteIpamPrefixListResolverTarget", {}).n("EC2Client", "DeleteIpamPrefixListResolverTargetCommand").sc(schemas_0.DeleteIpamPrefixListResolverTarget$).build() {
      static {
        __name(this, "DeleteIpamPrefixListResolverTargetCommand");
      }
    };
    var DeleteIpamResourceDiscoveryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteIpamResourceDiscovery", {}).n("EC2Client", "DeleteIpamResourceDiscoveryCommand").sc(schemas_0.DeleteIpamResourceDiscovery$).build() {
      static {
        __name(this, "DeleteIpamResourceDiscoveryCommand");
      }
    };
    var DeleteIpamScopeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteIpamScope", {}).n("EC2Client", "DeleteIpamScopeCommand").sc(schemas_0.DeleteIpamScope$).build() {
      static {
        __name(this, "DeleteIpamScopeCommand");
      }
    };
    var DeleteKeyPairCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteKeyPair", {}).n("EC2Client", "DeleteKeyPairCommand").sc(schemas_0.DeleteKeyPair$).build() {
      static {
        __name(this, "DeleteKeyPairCommand");
      }
    };
    var DeleteLaunchTemplateCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteLaunchTemplate", {}).n("EC2Client", "DeleteLaunchTemplateCommand").sc(schemas_0.DeleteLaunchTemplate$).build() {
      static {
        __name(this, "DeleteLaunchTemplateCommand");
      }
    };
    var DeleteLaunchTemplateVersionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteLaunchTemplateVersions", {}).n("EC2Client", "DeleteLaunchTemplateVersionsCommand").sc(schemas_0.DeleteLaunchTemplateVersions$).build() {
      static {
        __name(this, "DeleteLaunchTemplateVersionsCommand");
      }
    };
    var DeleteLocalGatewayRouteCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteLocalGatewayRoute", {}).n("EC2Client", "DeleteLocalGatewayRouteCommand").sc(schemas_0.DeleteLocalGatewayRoute$).build() {
      static {
        __name(this, "DeleteLocalGatewayRouteCommand");
      }
    };
    var DeleteLocalGatewayRouteTableCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteLocalGatewayRouteTable", {}).n("EC2Client", "DeleteLocalGatewayRouteTableCommand").sc(schemas_0.DeleteLocalGatewayRouteTable$).build() {
      static {
        __name(this, "DeleteLocalGatewayRouteTableCommand");
      }
    };
    var DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociation", {}).n("EC2Client", "DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociationCommand").sc(schemas_0.DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociation$).build() {
      static {
        __name(this, "DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociationCommand");
      }
    };
    var DeleteLocalGatewayRouteTableVpcAssociationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteLocalGatewayRouteTableVpcAssociation", {}).n("EC2Client", "DeleteLocalGatewayRouteTableVpcAssociationCommand").sc(schemas_0.DeleteLocalGatewayRouteTableVpcAssociation$).build() {
      static {
        __name(this, "DeleteLocalGatewayRouteTableVpcAssociationCommand");
      }
    };
    var DeleteLocalGatewayVirtualInterfaceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteLocalGatewayVirtualInterface", {}).n("EC2Client", "DeleteLocalGatewayVirtualInterfaceCommand").sc(schemas_0.DeleteLocalGatewayVirtualInterface$).build() {
      static {
        __name(this, "DeleteLocalGatewayVirtualInterfaceCommand");
      }
    };
    var DeleteLocalGatewayVirtualInterfaceGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteLocalGatewayVirtualInterfaceGroup", {}).n("EC2Client", "DeleteLocalGatewayVirtualInterfaceGroupCommand").sc(schemas_0.DeleteLocalGatewayVirtualInterfaceGroup$).build() {
      static {
        __name(this, "DeleteLocalGatewayVirtualInterfaceGroupCommand");
      }
    };
    var DeleteManagedPrefixListCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteManagedPrefixList", {}).n("EC2Client", "DeleteManagedPrefixListCommand").sc(schemas_0.DeleteManagedPrefixList$).build() {
      static {
        __name(this, "DeleteManagedPrefixListCommand");
      }
    };
    var DeleteNatGatewayCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteNatGateway", {}).n("EC2Client", "DeleteNatGatewayCommand").sc(schemas_0.DeleteNatGateway$).build() {
      static {
        __name(this, "DeleteNatGatewayCommand");
      }
    };
    var DeleteNetworkAclCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteNetworkAcl", {}).n("EC2Client", "DeleteNetworkAclCommand").sc(schemas_0.DeleteNetworkAcl$).build() {
      static {
        __name(this, "DeleteNetworkAclCommand");
      }
    };
    var DeleteNetworkAclEntryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteNetworkAclEntry", {}).n("EC2Client", "DeleteNetworkAclEntryCommand").sc(schemas_0.DeleteNetworkAclEntry$).build() {
      static {
        __name(this, "DeleteNetworkAclEntryCommand");
      }
    };
    var DeleteNetworkInsightsAccessScopeAnalysisCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteNetworkInsightsAccessScopeAnalysis", {}).n("EC2Client", "DeleteNetworkInsightsAccessScopeAnalysisCommand").sc(schemas_0.DeleteNetworkInsightsAccessScopeAnalysis$).build() {
      static {
        __name(this, "DeleteNetworkInsightsAccessScopeAnalysisCommand");
      }
    };
    var DeleteNetworkInsightsAccessScopeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteNetworkInsightsAccessScope", {}).n("EC2Client", "DeleteNetworkInsightsAccessScopeCommand").sc(schemas_0.DeleteNetworkInsightsAccessScope$).build() {
      static {
        __name(this, "DeleteNetworkInsightsAccessScopeCommand");
      }
    };
    var DeleteNetworkInsightsAnalysisCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteNetworkInsightsAnalysis", {}).n("EC2Client", "DeleteNetworkInsightsAnalysisCommand").sc(schemas_0.DeleteNetworkInsightsAnalysis$).build() {
      static {
        __name(this, "DeleteNetworkInsightsAnalysisCommand");
      }
    };
    var DeleteNetworkInsightsPathCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteNetworkInsightsPath", {}).n("EC2Client", "DeleteNetworkInsightsPathCommand").sc(schemas_0.DeleteNetworkInsightsPath$).build() {
      static {
        __name(this, "DeleteNetworkInsightsPathCommand");
      }
    };
    var DeleteNetworkInterfaceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteNetworkInterface", {}).n("EC2Client", "DeleteNetworkInterfaceCommand").sc(schemas_0.DeleteNetworkInterface$).build() {
      static {
        __name(this, "DeleteNetworkInterfaceCommand");
      }
    };
    var DeleteNetworkInterfacePermissionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteNetworkInterfacePermission", {}).n("EC2Client", "DeleteNetworkInterfacePermissionCommand").sc(schemas_0.DeleteNetworkInterfacePermission$).build() {
      static {
        __name(this, "DeleteNetworkInterfacePermissionCommand");
      }
    };
    var DeletePlacementGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeletePlacementGroup", {}).n("EC2Client", "DeletePlacementGroupCommand").sc(schemas_0.DeletePlacementGroup$).build() {
      static {
        __name(this, "DeletePlacementGroupCommand");
      }
    };
    var DeletePublicIpv4PoolCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeletePublicIpv4Pool", {}).n("EC2Client", "DeletePublicIpv4PoolCommand").sc(schemas_0.DeletePublicIpv4Pool$).build() {
      static {
        __name(this, "DeletePublicIpv4PoolCommand");
      }
    };
    var DeleteQueuedReservedInstancesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteQueuedReservedInstances", {}).n("EC2Client", "DeleteQueuedReservedInstancesCommand").sc(schemas_0.DeleteQueuedReservedInstances$).build() {
      static {
        __name(this, "DeleteQueuedReservedInstancesCommand");
      }
    };
    var DeleteRouteCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteRoute", {}).n("EC2Client", "DeleteRouteCommand").sc(schemas_0.DeleteRoute$).build() {
      static {
        __name(this, "DeleteRouteCommand");
      }
    };
    var DeleteRouteServerCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteRouteServer", {}).n("EC2Client", "DeleteRouteServerCommand").sc(schemas_0.DeleteRouteServer$).build() {
      static {
        __name(this, "DeleteRouteServerCommand");
      }
    };
    var DeleteRouteServerEndpointCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteRouteServerEndpoint", {}).n("EC2Client", "DeleteRouteServerEndpointCommand").sc(schemas_0.DeleteRouteServerEndpoint$).build() {
      static {
        __name(this, "DeleteRouteServerEndpointCommand");
      }
    };
    var DeleteRouteServerPeerCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteRouteServerPeer", {}).n("EC2Client", "DeleteRouteServerPeerCommand").sc(schemas_0.DeleteRouteServerPeer$).build() {
      static {
        __name(this, "DeleteRouteServerPeerCommand");
      }
    };
    var DeleteRouteTableCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteRouteTable", {}).n("EC2Client", "DeleteRouteTableCommand").sc(schemas_0.DeleteRouteTable$).build() {
      static {
        __name(this, "DeleteRouteTableCommand");
      }
    };
    var DeleteSecondaryNetworkCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteSecondaryNetwork", {}).n("EC2Client", "DeleteSecondaryNetworkCommand").sc(schemas_0.DeleteSecondaryNetwork$).build() {
      static {
        __name(this, "DeleteSecondaryNetworkCommand");
      }
    };
    var DeleteSecondarySubnetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteSecondarySubnet", {}).n("EC2Client", "DeleteSecondarySubnetCommand").sc(schemas_0.DeleteSecondarySubnet$).build() {
      static {
        __name(this, "DeleteSecondarySubnetCommand");
      }
    };
    var DeleteSecurityGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteSecurityGroup", {}).n("EC2Client", "DeleteSecurityGroupCommand").sc(schemas_0.DeleteSecurityGroup$).build() {
      static {
        __name(this, "DeleteSecurityGroupCommand");
      }
    };
    var DeleteSnapshotCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteSnapshot", {}).n("EC2Client", "DeleteSnapshotCommand").sc(schemas_0.DeleteSnapshot$).build() {
      static {
        __name(this, "DeleteSnapshotCommand");
      }
    };
    var DeleteSpotDatafeedSubscriptionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteSpotDatafeedSubscription", {}).n("EC2Client", "DeleteSpotDatafeedSubscriptionCommand").sc(schemas_0.DeleteSpotDatafeedSubscription$).build() {
      static {
        __name(this, "DeleteSpotDatafeedSubscriptionCommand");
      }
    };
    var DeleteSubnetCidrReservationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteSubnetCidrReservation", {}).n("EC2Client", "DeleteSubnetCidrReservationCommand").sc(schemas_0.DeleteSubnetCidrReservation$).build() {
      static {
        __name(this, "DeleteSubnetCidrReservationCommand");
      }
    };
    var DeleteSubnetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteSubnet", {}).n("EC2Client", "DeleteSubnetCommand").sc(schemas_0.DeleteSubnet$).build() {
      static {
        __name(this, "DeleteSubnetCommand");
      }
    };
    var DeleteTagsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteTags", {}).n("EC2Client", "DeleteTagsCommand").sc(schemas_0.DeleteTags$).build() {
      static {
        __name(this, "DeleteTagsCommand");
      }
    };
    var DeleteTrafficMirrorFilterCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteTrafficMirrorFilter", {}).n("EC2Client", "DeleteTrafficMirrorFilterCommand").sc(schemas_0.DeleteTrafficMirrorFilter$).build() {
      static {
        __name(this, "DeleteTrafficMirrorFilterCommand");
      }
    };
    var DeleteTrafficMirrorFilterRuleCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteTrafficMirrorFilterRule", {}).n("EC2Client", "DeleteTrafficMirrorFilterRuleCommand").sc(schemas_0.DeleteTrafficMirrorFilterRule$).build() {
      static {
        __name(this, "DeleteTrafficMirrorFilterRuleCommand");
      }
    };
    var DeleteTrafficMirrorSessionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteTrafficMirrorSession", {}).n("EC2Client", "DeleteTrafficMirrorSessionCommand").sc(schemas_0.DeleteTrafficMirrorSession$).build() {
      static {
        __name(this, "DeleteTrafficMirrorSessionCommand");
      }
    };
    var DeleteTrafficMirrorTargetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteTrafficMirrorTarget", {}).n("EC2Client", "DeleteTrafficMirrorTargetCommand").sc(schemas_0.DeleteTrafficMirrorTarget$).build() {
      static {
        __name(this, "DeleteTrafficMirrorTargetCommand");
      }
    };
    var DeleteTransitGatewayClientVpnAttachmentCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteTransitGatewayClientVpnAttachment", {}).n("EC2Client", "DeleteTransitGatewayClientVpnAttachmentCommand").sc(schemas_0.DeleteTransitGatewayClientVpnAttachment$).build() {
      static {
        __name(this, "DeleteTransitGatewayClientVpnAttachmentCommand");
      }
    };
    var DeleteTransitGatewayCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteTransitGateway", {}).n("EC2Client", "DeleteTransitGatewayCommand").sc(schemas_0.DeleteTransitGateway$).build() {
      static {
        __name(this, "DeleteTransitGatewayCommand");
      }
    };
    var DeleteTransitGatewayConnectCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteTransitGatewayConnect", {}).n("EC2Client", "DeleteTransitGatewayConnectCommand").sc(schemas_0.DeleteTransitGatewayConnect$).build() {
      static {
        __name(this, "DeleteTransitGatewayConnectCommand");
      }
    };
    var DeleteTransitGatewayConnectPeerCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteTransitGatewayConnectPeer", {}).n("EC2Client", "DeleteTransitGatewayConnectPeerCommand").sc(schemas_0.DeleteTransitGatewayConnectPeer$).build() {
      static {
        __name(this, "DeleteTransitGatewayConnectPeerCommand");
      }
    };
    var DeleteTransitGatewayMeteringPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteTransitGatewayMeteringPolicy", {}).n("EC2Client", "DeleteTransitGatewayMeteringPolicyCommand").sc(schemas_0.DeleteTransitGatewayMeteringPolicy$).build() {
      static {
        __name(this, "DeleteTransitGatewayMeteringPolicyCommand");
      }
    };
    var DeleteTransitGatewayMeteringPolicyEntryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteTransitGatewayMeteringPolicyEntry", {}).n("EC2Client", "DeleteTransitGatewayMeteringPolicyEntryCommand").sc(schemas_0.DeleteTransitGatewayMeteringPolicyEntry$).build() {
      static {
        __name(this, "DeleteTransitGatewayMeteringPolicyEntryCommand");
      }
    };
    var DeleteTransitGatewayMulticastDomainCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteTransitGatewayMulticastDomain", {}).n("EC2Client", "DeleteTransitGatewayMulticastDomainCommand").sc(schemas_0.DeleteTransitGatewayMulticastDomain$).build() {
      static {
        __name(this, "DeleteTransitGatewayMulticastDomainCommand");
      }
    };
    var DeleteTransitGatewayPeeringAttachmentCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteTransitGatewayPeeringAttachment", {}).n("EC2Client", "DeleteTransitGatewayPeeringAttachmentCommand").sc(schemas_0.DeleteTransitGatewayPeeringAttachment$).build() {
      static {
        __name(this, "DeleteTransitGatewayPeeringAttachmentCommand");
      }
    };
    var DeleteTransitGatewayPolicyTableCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteTransitGatewayPolicyTable", {}).n("EC2Client", "DeleteTransitGatewayPolicyTableCommand").sc(schemas_0.DeleteTransitGatewayPolicyTable$).build() {
      static {
        __name(this, "DeleteTransitGatewayPolicyTableCommand");
      }
    };
    var DeleteTransitGatewayPrefixListReferenceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteTransitGatewayPrefixListReference", {}).n("EC2Client", "DeleteTransitGatewayPrefixListReferenceCommand").sc(schemas_0.DeleteTransitGatewayPrefixListReference$).build() {
      static {
        __name(this, "DeleteTransitGatewayPrefixListReferenceCommand");
      }
    };
    var DeleteTransitGatewayRouteCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteTransitGatewayRoute", {}).n("EC2Client", "DeleteTransitGatewayRouteCommand").sc(schemas_0.DeleteTransitGatewayRoute$).build() {
      static {
        __name(this, "DeleteTransitGatewayRouteCommand");
      }
    };
    var DeleteTransitGatewayRouteTableAnnouncementCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteTransitGatewayRouteTableAnnouncement", {}).n("EC2Client", "DeleteTransitGatewayRouteTableAnnouncementCommand").sc(schemas_0.DeleteTransitGatewayRouteTableAnnouncement$).build() {
      static {
        __name(this, "DeleteTransitGatewayRouteTableAnnouncementCommand");
      }
    };
    var DeleteTransitGatewayRouteTableCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteTransitGatewayRouteTable", {}).n("EC2Client", "DeleteTransitGatewayRouteTableCommand").sc(schemas_0.DeleteTransitGatewayRouteTable$).build() {
      static {
        __name(this, "DeleteTransitGatewayRouteTableCommand");
      }
    };
    var DeleteTransitGatewayVpcAttachmentCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteTransitGatewayVpcAttachment", {}).n("EC2Client", "DeleteTransitGatewayVpcAttachmentCommand").sc(schemas_0.DeleteTransitGatewayVpcAttachment$).build() {
      static {
        __name(this, "DeleteTransitGatewayVpcAttachmentCommand");
      }
    };
    var DeleteVerifiedAccessEndpointCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteVerifiedAccessEndpoint", {}).n("EC2Client", "DeleteVerifiedAccessEndpointCommand").sc(schemas_0.DeleteVerifiedAccessEndpoint$).build() {
      static {
        __name(this, "DeleteVerifiedAccessEndpointCommand");
      }
    };
    var DeleteVerifiedAccessGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteVerifiedAccessGroup", {}).n("EC2Client", "DeleteVerifiedAccessGroupCommand").sc(schemas_0.DeleteVerifiedAccessGroup$).build() {
      static {
        __name(this, "DeleteVerifiedAccessGroupCommand");
      }
    };
    var DeleteVerifiedAccessInstanceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteVerifiedAccessInstance", {}).n("EC2Client", "DeleteVerifiedAccessInstanceCommand").sc(schemas_0.DeleteVerifiedAccessInstance$).build() {
      static {
        __name(this, "DeleteVerifiedAccessInstanceCommand");
      }
    };
    var DeleteVerifiedAccessTrustProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteVerifiedAccessTrustProvider", {}).n("EC2Client", "DeleteVerifiedAccessTrustProviderCommand").sc(schemas_0.DeleteVerifiedAccessTrustProvider$).build() {
      static {
        __name(this, "DeleteVerifiedAccessTrustProviderCommand");
      }
    };
    var DeleteVolumeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteVolume", {}).n("EC2Client", "DeleteVolumeCommand").sc(schemas_0.DeleteVolume$).build() {
      static {
        __name(this, "DeleteVolumeCommand");
      }
    };
    var DeleteVpcBlockPublicAccessExclusionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteVpcBlockPublicAccessExclusion", {}).n("EC2Client", "DeleteVpcBlockPublicAccessExclusionCommand").sc(schemas_0.DeleteVpcBlockPublicAccessExclusion$).build() {
      static {
        __name(this, "DeleteVpcBlockPublicAccessExclusionCommand");
      }
    };
    var DeleteVpcCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteVpc", {}).n("EC2Client", "DeleteVpcCommand").sc(schemas_0.DeleteVpc$).build() {
      static {
        __name(this, "DeleteVpcCommand");
      }
    };
    var DeleteVpcEncryptionControlCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteVpcEncryptionControl", {}).n("EC2Client", "DeleteVpcEncryptionControlCommand").sc(schemas_0.DeleteVpcEncryptionControl$).build() {
      static {
        __name(this, "DeleteVpcEncryptionControlCommand");
      }
    };
    var DeleteVpcEndpointConnectionNotificationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteVpcEndpointConnectionNotifications", {}).n("EC2Client", "DeleteVpcEndpointConnectionNotificationsCommand").sc(schemas_0.DeleteVpcEndpointConnectionNotifications$).build() {
      static {
        __name(this, "DeleteVpcEndpointConnectionNotificationsCommand");
      }
    };
    var DeleteVpcEndpointsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteVpcEndpoints", {}).n("EC2Client", "DeleteVpcEndpointsCommand").sc(schemas_0.DeleteVpcEndpoints$).build() {
      static {
        __name(this, "DeleteVpcEndpointsCommand");
      }
    };
    var DeleteVpcEndpointServiceConfigurationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteVpcEndpointServiceConfigurations", {}).n("EC2Client", "DeleteVpcEndpointServiceConfigurationsCommand").sc(schemas_0.DeleteVpcEndpointServiceConfigurations$).build() {
      static {
        __name(this, "DeleteVpcEndpointServiceConfigurationsCommand");
      }
    };
    var DeleteVpcPeeringConnectionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteVpcPeeringConnection", {}).n("EC2Client", "DeleteVpcPeeringConnectionCommand").sc(schemas_0.DeleteVpcPeeringConnection$).build() {
      static {
        __name(this, "DeleteVpcPeeringConnectionCommand");
      }
    };
    var DeleteVpnConcentratorCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteVpnConcentrator", {}).n("EC2Client", "DeleteVpnConcentratorCommand").sc(schemas_0.DeleteVpnConcentrator$).build() {
      static {
        __name(this, "DeleteVpnConcentratorCommand");
      }
    };
    var DeleteVpnConnectionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteVpnConnection", {}).n("EC2Client", "DeleteVpnConnectionCommand").sc(schemas_0.DeleteVpnConnection$).build() {
      static {
        __name(this, "DeleteVpnConnectionCommand");
      }
    };
    var DeleteVpnConnectionRouteCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteVpnConnectionRoute", {}).n("EC2Client", "DeleteVpnConnectionRouteCommand").sc(schemas_0.DeleteVpnConnectionRoute$).build() {
      static {
        __name(this, "DeleteVpnConnectionRouteCommand");
      }
    };
    var DeleteVpnGatewayCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeleteVpnGateway", {}).n("EC2Client", "DeleteVpnGatewayCommand").sc(schemas_0.DeleteVpnGateway$).build() {
      static {
        __name(this, "DeleteVpnGatewayCommand");
      }
    };
    var DeprovisionByoipCidrCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeprovisionByoipCidr", {}).n("EC2Client", "DeprovisionByoipCidrCommand").sc(schemas_0.DeprovisionByoipCidr$).build() {
      static {
        __name(this, "DeprovisionByoipCidrCommand");
      }
    };
    var DeprovisionIpamByoasnCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeprovisionIpamByoasn", {}).n("EC2Client", "DeprovisionIpamByoasnCommand").sc(schemas_0.DeprovisionIpamByoasn$).build() {
      static {
        __name(this, "DeprovisionIpamByoasnCommand");
      }
    };
    var DeprovisionIpamPoolCidrCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeprovisionIpamPoolCidr", {}).n("EC2Client", "DeprovisionIpamPoolCidrCommand").sc(schemas_0.DeprovisionIpamPoolCidr$).build() {
      static {
        __name(this, "DeprovisionIpamPoolCidrCommand");
      }
    };
    var DeprovisionPublicIpv4PoolCidrCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeprovisionPublicIpv4PoolCidr", {}).n("EC2Client", "DeprovisionPublicIpv4PoolCidrCommand").sc(schemas_0.DeprovisionPublicIpv4PoolCidr$).build() {
      static {
        __name(this, "DeprovisionPublicIpv4PoolCidrCommand");
      }
    };
    var DeregisterImageCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeregisterImage", {}).n("EC2Client", "DeregisterImageCommand").sc(schemas_0.DeregisterImage$).build() {
      static {
        __name(this, "DeregisterImageCommand");
      }
    };
    var DeregisterInstanceEventNotificationAttributesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeregisterInstanceEventNotificationAttributes", {}).n("EC2Client", "DeregisterInstanceEventNotificationAttributesCommand").sc(schemas_0.DeregisterInstanceEventNotificationAttributes$).build() {
      static {
        __name(this, "DeregisterInstanceEventNotificationAttributesCommand");
      }
    };
    var DeregisterTransitGatewayMulticastGroupMembersCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeregisterTransitGatewayMulticastGroupMembers", {}).n("EC2Client", "DeregisterTransitGatewayMulticastGroupMembersCommand").sc(schemas_0.DeregisterTransitGatewayMulticastGroupMembers$).build() {
      static {
        __name(this, "DeregisterTransitGatewayMulticastGroupMembersCommand");
      }
    };
    var DeregisterTransitGatewayMulticastGroupSourcesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DeregisterTransitGatewayMulticastGroupSources", {}).n("EC2Client", "DeregisterTransitGatewayMulticastGroupSourcesCommand").sc(schemas_0.DeregisterTransitGatewayMulticastGroupSources$).build() {
      static {
        __name(this, "DeregisterTransitGatewayMulticastGroupSourcesCommand");
      }
    };
    var DescribeAccountAttributesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeAccountAttributes", {}).n("EC2Client", "DescribeAccountAttributesCommand").sc(schemas_0.DescribeAccountAttributes$).build() {
      static {
        __name(this, "DescribeAccountAttributesCommand");
      }
    };
    var DescribeAddressesAttributeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeAddressesAttribute", {}).n("EC2Client", "DescribeAddressesAttributeCommand").sc(schemas_0.DescribeAddressesAttribute$).build() {
      static {
        __name(this, "DescribeAddressesAttributeCommand");
      }
    };
    var DescribeAddressesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeAddresses", {}).n("EC2Client", "DescribeAddressesCommand").sc(schemas_0.DescribeAddresses$).build() {
      static {
        __name(this, "DescribeAddressesCommand");
      }
    };
    var DescribeAddressTransfersCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeAddressTransfers", {}).n("EC2Client", "DescribeAddressTransfersCommand").sc(schemas_0.DescribeAddressTransfers$).build() {
      static {
        __name(this, "DescribeAddressTransfersCommand");
      }
    };
    var DescribeAggregateIdFormatCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeAggregateIdFormat", {}).n("EC2Client", "DescribeAggregateIdFormatCommand").sc(schemas_0.DescribeAggregateIdFormat$).build() {
      static {
        __name(this, "DescribeAggregateIdFormatCommand");
      }
    };
    var DescribeAvailabilityZonesCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeAvailabilityZones", {}).n("EC2Client", "DescribeAvailabilityZonesCommand").sc(schemas_0.DescribeAvailabilityZones$).build() {
      static {
        __name(this, "DescribeAvailabilityZonesCommand");
      }
    };
    var DescribeAwsNetworkPerformanceMetricSubscriptionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeAwsNetworkPerformanceMetricSubscriptions", {}).n("EC2Client", "DescribeAwsNetworkPerformanceMetricSubscriptionsCommand").sc(schemas_0.DescribeAwsNetworkPerformanceMetricSubscriptions$).build() {
      static {
        __name(this, "DescribeAwsNetworkPerformanceMetricSubscriptionsCommand");
      }
    };
    var DescribeBundleTasksCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeBundleTasks", {}).n("EC2Client", "DescribeBundleTasksCommand").sc(schemas_0.DescribeBundleTasks$).build() {
      static {
        __name(this, "DescribeBundleTasksCommand");
      }
    };
    var DescribeByoipCidrsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeByoipCidrs", {}).n("EC2Client", "DescribeByoipCidrsCommand").sc(schemas_0.DescribeByoipCidrs$).build() {
      static {
        __name(this, "DescribeByoipCidrsCommand");
      }
    };
    var DescribeCapacityBlockExtensionHistoryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeCapacityBlockExtensionHistory", {}).n("EC2Client", "DescribeCapacityBlockExtensionHistoryCommand").sc(schemas_0.DescribeCapacityBlockExtensionHistory$).build() {
      static {
        __name(this, "DescribeCapacityBlockExtensionHistoryCommand");
      }
    };
    var DescribeCapacityBlockExtensionOfferingsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeCapacityBlockExtensionOfferings", {}).n("EC2Client", "DescribeCapacityBlockExtensionOfferingsCommand").sc(schemas_0.DescribeCapacityBlockExtensionOfferings$).build() {
      static {
        __name(this, "DescribeCapacityBlockExtensionOfferingsCommand");
      }
    };
    var DescribeCapacityBlockOfferingsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeCapacityBlockOfferings", {}).n("EC2Client", "DescribeCapacityBlockOfferingsCommand").sc(schemas_0.DescribeCapacityBlockOfferings$).build() {
      static {
        __name(this, "DescribeCapacityBlockOfferingsCommand");
      }
    };
    var DescribeCapacityBlocksCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeCapacityBlocks", {}).n("EC2Client", "DescribeCapacityBlocksCommand").sc(schemas_0.DescribeCapacityBlocks$).build() {
      static {
        __name(this, "DescribeCapacityBlocksCommand");
      }
    };
    var DescribeCapacityBlockStatusCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeCapacityBlockStatus", {}).n("EC2Client", "DescribeCapacityBlockStatusCommand").sc(schemas_0.DescribeCapacityBlockStatus$).build() {
      static {
        __name(this, "DescribeCapacityBlockStatusCommand");
      }
    };
    var DescribeCapacityManagerDataExportsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeCapacityManagerDataExports", {}).n("EC2Client", "DescribeCapacityManagerDataExportsCommand").sc(schemas_0.DescribeCapacityManagerDataExports$).build() {
      static {
        __name(this, "DescribeCapacityManagerDataExportsCommand");
      }
    };
    var DescribeCapacityReservationBillingRequestsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeCapacityReservationBillingRequests", {}).n("EC2Client", "DescribeCapacityReservationBillingRequestsCommand").sc(schemas_0.DescribeCapacityReservationBillingRequests$).build() {
      static {
        __name(this, "DescribeCapacityReservationBillingRequestsCommand");
      }
    };
    var DescribeCapacityReservationFleetsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeCapacityReservationFleets", {}).n("EC2Client", "DescribeCapacityReservationFleetsCommand").sc(schemas_0.DescribeCapacityReservationFleets$).build() {
      static {
        __name(this, "DescribeCapacityReservationFleetsCommand");
      }
    };
    var DescribeCapacityReservationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeCapacityReservations", {}).n("EC2Client", "DescribeCapacityReservationsCommand").sc(schemas_0.DescribeCapacityReservations$).build() {
      static {
        __name(this, "DescribeCapacityReservationsCommand");
      }
    };
    var DescribeCapacityReservationTopologyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeCapacityReservationTopology", {}).n("EC2Client", "DescribeCapacityReservationTopologyCommand").sc(schemas_0.DescribeCapacityReservationTopology$).build() {
      static {
        __name(this, "DescribeCapacityReservationTopologyCommand");
      }
    };
    var DescribeCarrierGatewaysCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeCarrierGateways", {}).n("EC2Client", "DescribeCarrierGatewaysCommand").sc(schemas_0.DescribeCarrierGateways$).build() {
      static {
        __name(this, "DescribeCarrierGatewaysCommand");
      }
    };
    var DescribeClassicLinkInstancesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeClassicLinkInstances", {}).n("EC2Client", "DescribeClassicLinkInstancesCommand").sc(schemas_0.DescribeClassicLinkInstances$).build() {
      static {
        __name(this, "DescribeClassicLinkInstancesCommand");
      }
    };
    var DescribeClientVpnAuthorizationRulesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeClientVpnAuthorizationRules", {}).n("EC2Client", "DescribeClientVpnAuthorizationRulesCommand").sc(schemas_0.DescribeClientVpnAuthorizationRules$).build() {
      static {
        __name(this, "DescribeClientVpnAuthorizationRulesCommand");
      }
    };
    var DescribeClientVpnConnectionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeClientVpnConnections", {}).n("EC2Client", "DescribeClientVpnConnectionsCommand").sc(schemas_0.DescribeClientVpnConnections$).build() {
      static {
        __name(this, "DescribeClientVpnConnectionsCommand");
      }
    };
    var DescribeClientVpnEndpointsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeClientVpnEndpoints", {}).n("EC2Client", "DescribeClientVpnEndpointsCommand").sc(schemas_0.DescribeClientVpnEndpoints$).build() {
      static {
        __name(this, "DescribeClientVpnEndpointsCommand");
      }
    };
    var DescribeClientVpnRoutesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeClientVpnRoutes", {}).n("EC2Client", "DescribeClientVpnRoutesCommand").sc(schemas_0.DescribeClientVpnRoutes$).build() {
      static {
        __name(this, "DescribeClientVpnRoutesCommand");
      }
    };
    var DescribeClientVpnTargetNetworksCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeClientVpnTargetNetworks", {}).n("EC2Client", "DescribeClientVpnTargetNetworksCommand").sc(schemas_0.DescribeClientVpnTargetNetworks$).build() {
      static {
        __name(this, "DescribeClientVpnTargetNetworksCommand");
      }
    };
    var DescribeCoipPoolsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeCoipPools", {}).n("EC2Client", "DescribeCoipPoolsCommand").sc(schemas_0.DescribeCoipPools$).build() {
      static {
        __name(this, "DescribeCoipPoolsCommand");
      }
    };
    var DescribeConversionTasksCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeConversionTasks", {}).n("EC2Client", "DescribeConversionTasksCommand").sc(schemas_0.DescribeConversionTasks$).build() {
      static {
        __name(this, "DescribeConversionTasksCommand");
      }
    };
    var DescribeCustomerGatewaysCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeCustomerGateways", {}).n("EC2Client", "DescribeCustomerGatewaysCommand").sc(schemas_0.DescribeCustomerGateways$).build() {
      static {
        __name(this, "DescribeCustomerGatewaysCommand");
      }
    };
    var DescribeDeclarativePoliciesReportsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeDeclarativePoliciesReports", {}).n("EC2Client", "DescribeDeclarativePoliciesReportsCommand").sc(schemas_0.DescribeDeclarativePoliciesReports$).build() {
      static {
        __name(this, "DescribeDeclarativePoliciesReportsCommand");
      }
    };
    var DescribeDhcpOptionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeDhcpOptions", {}).n("EC2Client", "DescribeDhcpOptionsCommand").sc(schemas_0.DescribeDhcpOptions$).build() {
      static {
        __name(this, "DescribeDhcpOptionsCommand");
      }
    };
    var DescribeEgressOnlyInternetGatewaysCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeEgressOnlyInternetGateways", {}).n("EC2Client", "DescribeEgressOnlyInternetGatewaysCommand").sc(schemas_0.DescribeEgressOnlyInternetGateways$).build() {
      static {
        __name(this, "DescribeEgressOnlyInternetGatewaysCommand");
      }
    };
    var DescribeElasticGpusCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeElasticGpus", {}).n("EC2Client", "DescribeElasticGpusCommand").sc(schemas_0.DescribeElasticGpus$).build() {
      static {
        __name(this, "DescribeElasticGpusCommand");
      }
    };
    var DescribeExportImageTasksCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeExportImageTasks", {}).n("EC2Client", "DescribeExportImageTasksCommand").sc(schemas_0.DescribeExportImageTasks$).build() {
      static {
        __name(this, "DescribeExportImageTasksCommand");
      }
    };
    var DescribeExportTasksCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeExportTasks", {}).n("EC2Client", "DescribeExportTasksCommand").sc(schemas_0.DescribeExportTasks$).build() {
      static {
        __name(this, "DescribeExportTasksCommand");
      }
    };
    var DescribeFastLaunchImagesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeFastLaunchImages", {}).n("EC2Client", "DescribeFastLaunchImagesCommand").sc(schemas_0.DescribeFastLaunchImages$).build() {
      static {
        __name(this, "DescribeFastLaunchImagesCommand");
      }
    };
    var DescribeFastSnapshotRestoresCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeFastSnapshotRestores", {}).n("EC2Client", "DescribeFastSnapshotRestoresCommand").sc(schemas_0.DescribeFastSnapshotRestores$).build() {
      static {
        __name(this, "DescribeFastSnapshotRestoresCommand");
      }
    };
    var DescribeFleetHistoryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeFleetHistory", {}).n("EC2Client", "DescribeFleetHistoryCommand").sc(schemas_0.DescribeFleetHistory$).build() {
      static {
        __name(this, "DescribeFleetHistoryCommand");
      }
    };
    var DescribeFleetInstancesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeFleetInstances", {}).n("EC2Client", "DescribeFleetInstancesCommand").sc(schemas_0.DescribeFleetInstances$).build() {
      static {
        __name(this, "DescribeFleetInstancesCommand");
      }
    };
    var DescribeFleetsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeFleets", {}).n("EC2Client", "DescribeFleetsCommand").sc(schemas_0.DescribeFleets$).build() {
      static {
        __name(this, "DescribeFleetsCommand");
      }
    };
    var DescribeFlowLogsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeFlowLogs", {}).n("EC2Client", "DescribeFlowLogsCommand").sc(schemas_0.DescribeFlowLogs$).build() {
      static {
        __name(this, "DescribeFlowLogsCommand");
      }
    };
    var DescribeFpgaImageAttributeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeFpgaImageAttribute", {}).n("EC2Client", "DescribeFpgaImageAttributeCommand").sc(schemas_0.DescribeFpgaImageAttribute$).build() {
      static {
        __name(this, "DescribeFpgaImageAttributeCommand");
      }
    };
    var DescribeFpgaImagesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeFpgaImages", {}).n("EC2Client", "DescribeFpgaImagesCommand").sc(schemas_0.DescribeFpgaImages$).build() {
      static {
        __name(this, "DescribeFpgaImagesCommand");
      }
    };
    var DescribeHostReservationOfferingsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeHostReservationOfferings", {}).n("EC2Client", "DescribeHostReservationOfferingsCommand").sc(schemas_0.DescribeHostReservationOfferings$).build() {
      static {
        __name(this, "DescribeHostReservationOfferingsCommand");
      }
    };
    var DescribeHostReservationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeHostReservations", {}).n("EC2Client", "DescribeHostReservationsCommand").sc(schemas_0.DescribeHostReservations$).build() {
      static {
        __name(this, "DescribeHostReservationsCommand");
      }
    };
    var DescribeHostsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeHosts", {}).n("EC2Client", "DescribeHostsCommand").sc(schemas_0.DescribeHosts$).build() {
      static {
        __name(this, "DescribeHostsCommand");
      }
    };
    var DescribeIamInstanceProfileAssociationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeIamInstanceProfileAssociations", {}).n("EC2Client", "DescribeIamInstanceProfileAssociationsCommand").sc(schemas_0.DescribeIamInstanceProfileAssociations$).build() {
      static {
        __name(this, "DescribeIamInstanceProfileAssociationsCommand");
      }
    };
    var DescribeIdentityIdFormatCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeIdentityIdFormat", {}).n("EC2Client", "DescribeIdentityIdFormatCommand").sc(schemas_0.DescribeIdentityIdFormat$).build() {
      static {
        __name(this, "DescribeIdentityIdFormatCommand");
      }
    };
    var DescribeIdFormatCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeIdFormat", {}).n("EC2Client", "DescribeIdFormatCommand").sc(schemas_0.DescribeIdFormat$).build() {
      static {
        __name(this, "DescribeIdFormatCommand");
      }
    };
    var DescribeImageAttributeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeImageAttribute", {}).n("EC2Client", "DescribeImageAttributeCommand").sc(schemas_0.DescribeImageAttribute$).build() {
      static {
        __name(this, "DescribeImageAttributeCommand");
      }
    };
    var DescribeImageReferencesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeImageReferences", {}).n("EC2Client", "DescribeImageReferencesCommand").sc(schemas_0.DescribeImageReferences$).build() {
      static {
        __name(this, "DescribeImageReferencesCommand");
      }
    };
    var DescribeImagesCommand3 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeImages", {}).n("EC2Client", "DescribeImagesCommand").sc(schemas_0.DescribeImages$).build() {
      static {
        __name(this, "DescribeImagesCommand");
      }
    };
    var DescribeImageUsageReportEntriesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeImageUsageReportEntries", {}).n("EC2Client", "DescribeImageUsageReportEntriesCommand").sc(schemas_0.DescribeImageUsageReportEntries$).build() {
      static {
        __name(this, "DescribeImageUsageReportEntriesCommand");
      }
    };
    var DescribeImageUsageReportsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeImageUsageReports", {}).n("EC2Client", "DescribeImageUsageReportsCommand").sc(schemas_0.DescribeImageUsageReports$).build() {
      static {
        __name(this, "DescribeImageUsageReportsCommand");
      }
    };
    var DescribeImportImageTasksCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeImportImageTasks", {}).n("EC2Client", "DescribeImportImageTasksCommand").sc(schemas_0.DescribeImportImageTasks$).build() {
      static {
        __name(this, "DescribeImportImageTasksCommand");
      }
    };
    var DescribeImportSnapshotTasksCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeImportSnapshotTasks", {}).n("EC2Client", "DescribeImportSnapshotTasksCommand").sc(schemas_0.DescribeImportSnapshotTasks$).build() {
      static {
        __name(this, "DescribeImportSnapshotTasksCommand");
      }
    };
    var DescribeInstanceAttributeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeInstanceAttribute", {}).n("EC2Client", "DescribeInstanceAttributeCommand").sc(schemas_0.DescribeInstanceAttribute$).build() {
      static {
        __name(this, "DescribeInstanceAttributeCommand");
      }
    };
    var DescribeInstanceConnectEndpointsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeInstanceConnectEndpoints", {}).n("EC2Client", "DescribeInstanceConnectEndpointsCommand").sc(schemas_0.DescribeInstanceConnectEndpoints$).build() {
      static {
        __name(this, "DescribeInstanceConnectEndpointsCommand");
      }
    };
    var DescribeInstanceCreditSpecificationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeInstanceCreditSpecifications", {}).n("EC2Client", "DescribeInstanceCreditSpecificationsCommand").sc(schemas_0.DescribeInstanceCreditSpecifications$).build() {
      static {
        __name(this, "DescribeInstanceCreditSpecificationsCommand");
      }
    };
    var DescribeInstanceEventNotificationAttributesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeInstanceEventNotificationAttributes", {}).n("EC2Client", "DescribeInstanceEventNotificationAttributesCommand").sc(schemas_0.DescribeInstanceEventNotificationAttributes$).build() {
      static {
        __name(this, "DescribeInstanceEventNotificationAttributesCommand");
      }
    };
    var DescribeInstanceEventWindowsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeInstanceEventWindows", {}).n("EC2Client", "DescribeInstanceEventWindowsCommand").sc(schemas_0.DescribeInstanceEventWindows$).build() {
      static {
        __name(this, "DescribeInstanceEventWindowsCommand");
      }
    };
    var DescribeInstanceImageMetadataCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeInstanceImageMetadata", {}).n("EC2Client", "DescribeInstanceImageMetadataCommand").sc(schemas_0.DescribeInstanceImageMetadata$).build() {
      static {
        __name(this, "DescribeInstanceImageMetadataCommand");
      }
    };
    var DescribeInstancesCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeInstances", {}).n("EC2Client", "DescribeInstancesCommand").sc(schemas_0.DescribeInstances$).build() {
      static {
        __name(this, "DescribeInstancesCommand");
      }
    };
    var DescribeInstanceSqlHaHistoryStatesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeInstanceSqlHaHistoryStates", {}).n("EC2Client", "DescribeInstanceSqlHaHistoryStatesCommand").sc(schemas_0.DescribeInstanceSqlHaHistoryStates$).build() {
      static {
        __name(this, "DescribeInstanceSqlHaHistoryStatesCommand");
      }
    };
    var DescribeInstanceSqlHaStatesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeInstanceSqlHaStates", {}).n("EC2Client", "DescribeInstanceSqlHaStatesCommand").sc(schemas_0.DescribeInstanceSqlHaStates$).build() {
      static {
        __name(this, "DescribeInstanceSqlHaStatesCommand");
      }
    };
    var DescribeInstanceStatusCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeInstanceStatus", {}).n("EC2Client", "DescribeInstanceStatusCommand").sc(schemas_0.DescribeInstanceStatus$).build() {
      static {
        __name(this, "DescribeInstanceStatusCommand");
      }
    };
    var DescribeInstanceTopologyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeInstanceTopology", {}).n("EC2Client", "DescribeInstanceTopologyCommand").sc(schemas_0.DescribeInstanceTopology$).build() {
      static {
        __name(this, "DescribeInstanceTopologyCommand");
      }
    };
    var DescribeInstanceTypeOfferingsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeInstanceTypeOfferings", {}).n("EC2Client", "DescribeInstanceTypeOfferingsCommand").sc(schemas_0.DescribeInstanceTypeOfferings$).build() {
      static {
        __name(this, "DescribeInstanceTypeOfferingsCommand");
      }
    };
    var DescribeInstanceTypesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeInstanceTypes", {}).n("EC2Client", "DescribeInstanceTypesCommand").sc(schemas_0.DescribeInstanceTypes$).build() {
      static {
        __name(this, "DescribeInstanceTypesCommand");
      }
    };
    var DescribeInternetGatewaysCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeInternetGateways", {}).n("EC2Client", "DescribeInternetGatewaysCommand").sc(schemas_0.DescribeInternetGateways$).build() {
      static {
        __name(this, "DescribeInternetGatewaysCommand");
      }
    };
    var DescribeIpamByoasnCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeIpamByoasn", {}).n("EC2Client", "DescribeIpamByoasnCommand").sc(schemas_0.DescribeIpamByoasn$).build() {
      static {
        __name(this, "DescribeIpamByoasnCommand");
      }
    };
    var DescribeIpamExternalResourceVerificationTokensCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeIpamExternalResourceVerificationTokens", {}).n("EC2Client", "DescribeIpamExternalResourceVerificationTokensCommand").sc(schemas_0.DescribeIpamExternalResourceVerificationTokens$).build() {
      static {
        __name(this, "DescribeIpamExternalResourceVerificationTokensCommand");
      }
    };
    var DescribeIpamPoliciesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeIpamPolicies", {}).n("EC2Client", "DescribeIpamPoliciesCommand").sc(schemas_0.DescribeIpamPolicies$).build() {
      static {
        __name(this, "DescribeIpamPoliciesCommand");
      }
    };
    var DescribeIpamPoolsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeIpamPools", {}).n("EC2Client", "DescribeIpamPoolsCommand").sc(schemas_0.DescribeIpamPools$).build() {
      static {
        __name(this, "DescribeIpamPoolsCommand");
      }
    };
    var DescribeIpamPrefixListResolversCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeIpamPrefixListResolvers", {}).n("EC2Client", "DescribeIpamPrefixListResolversCommand").sc(schemas_0.DescribeIpamPrefixListResolvers$).build() {
      static {
        __name(this, "DescribeIpamPrefixListResolversCommand");
      }
    };
    var DescribeIpamPrefixListResolverTargetsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeIpamPrefixListResolverTargets", {}).n("EC2Client", "DescribeIpamPrefixListResolverTargetsCommand").sc(schemas_0.DescribeIpamPrefixListResolverTargets$).build() {
      static {
        __name(this, "DescribeIpamPrefixListResolverTargetsCommand");
      }
    };
    var DescribeIpamResourceDiscoveriesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeIpamResourceDiscoveries", {}).n("EC2Client", "DescribeIpamResourceDiscoveriesCommand").sc(schemas_0.DescribeIpamResourceDiscoveries$).build() {
      static {
        __name(this, "DescribeIpamResourceDiscoveriesCommand");
      }
    };
    var DescribeIpamResourceDiscoveryAssociationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeIpamResourceDiscoveryAssociations", {}).n("EC2Client", "DescribeIpamResourceDiscoveryAssociationsCommand").sc(schemas_0.DescribeIpamResourceDiscoveryAssociations$).build() {
      static {
        __name(this, "DescribeIpamResourceDiscoveryAssociationsCommand");
      }
    };
    var DescribeIpamsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeIpams", {}).n("EC2Client", "DescribeIpamsCommand").sc(schemas_0.DescribeIpams$).build() {
      static {
        __name(this, "DescribeIpamsCommand");
      }
    };
    var DescribeIpamScopesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeIpamScopes", {}).n("EC2Client", "DescribeIpamScopesCommand").sc(schemas_0.DescribeIpamScopes$).build() {
      static {
        __name(this, "DescribeIpamScopesCommand");
      }
    };
    var DescribeIpv6PoolsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeIpv6Pools", {}).n("EC2Client", "DescribeIpv6PoolsCommand").sc(schemas_0.DescribeIpv6Pools$).build() {
      static {
        __name(this, "DescribeIpv6PoolsCommand");
      }
    };
    var DescribeKeyPairsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeKeyPairs", {}).n("EC2Client", "DescribeKeyPairsCommand").sc(schemas_0.DescribeKeyPairs$).build() {
      static {
        __name(this, "DescribeKeyPairsCommand");
      }
    };
    var DescribeLaunchTemplatesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeLaunchTemplates", {}).n("EC2Client", "DescribeLaunchTemplatesCommand").sc(schemas_0.DescribeLaunchTemplates$).build() {
      static {
        __name(this, "DescribeLaunchTemplatesCommand");
      }
    };
    var DescribeLaunchTemplateVersionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeLaunchTemplateVersions", {}).n("EC2Client", "DescribeLaunchTemplateVersionsCommand").sc(schemas_0.DescribeLaunchTemplateVersions$).build() {
      static {
        __name(this, "DescribeLaunchTemplateVersionsCommand");
      }
    };
    var DescribeLocalGatewayRouteTablesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeLocalGatewayRouteTables", {}).n("EC2Client", "DescribeLocalGatewayRouteTablesCommand").sc(schemas_0.DescribeLocalGatewayRouteTables$).build() {
      static {
        __name(this, "DescribeLocalGatewayRouteTablesCommand");
      }
    };
    var DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociations", {}).n("EC2Client", "DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociationsCommand").sc(schemas_0.DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociations$).build() {
      static {
        __name(this, "DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociationsCommand");
      }
    };
    var DescribeLocalGatewayRouteTableVpcAssociationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeLocalGatewayRouteTableVpcAssociations", {}).n("EC2Client", "DescribeLocalGatewayRouteTableVpcAssociationsCommand").sc(schemas_0.DescribeLocalGatewayRouteTableVpcAssociations$).build() {
      static {
        __name(this, "DescribeLocalGatewayRouteTableVpcAssociationsCommand");
      }
    };
    var DescribeLocalGatewaysCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeLocalGateways", {}).n("EC2Client", "DescribeLocalGatewaysCommand").sc(schemas_0.DescribeLocalGateways$).build() {
      static {
        __name(this, "DescribeLocalGatewaysCommand");
      }
    };
    var DescribeLocalGatewayVirtualInterfaceGroupsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeLocalGatewayVirtualInterfaceGroups", {}).n("EC2Client", "DescribeLocalGatewayVirtualInterfaceGroupsCommand").sc(schemas_0.DescribeLocalGatewayVirtualInterfaceGroups$).build() {
      static {
        __name(this, "DescribeLocalGatewayVirtualInterfaceGroupsCommand");
      }
    };
    var DescribeLocalGatewayVirtualInterfacesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeLocalGatewayVirtualInterfaces", {}).n("EC2Client", "DescribeLocalGatewayVirtualInterfacesCommand").sc(schemas_0.DescribeLocalGatewayVirtualInterfaces$).build() {
      static {
        __name(this, "DescribeLocalGatewayVirtualInterfacesCommand");
      }
    };
    var DescribeLockedSnapshotsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeLockedSnapshots", {}).n("EC2Client", "DescribeLockedSnapshotsCommand").sc(schemas_0.DescribeLockedSnapshots$).build() {
      static {
        __name(this, "DescribeLockedSnapshotsCommand");
      }
    };
    var DescribeMacHostsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeMacHosts", {}).n("EC2Client", "DescribeMacHostsCommand").sc(schemas_0.DescribeMacHosts$).build() {
      static {
        __name(this, "DescribeMacHostsCommand");
      }
    };
    var DescribeMacModificationTasksCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeMacModificationTasks", {}).n("EC2Client", "DescribeMacModificationTasksCommand").sc(schemas_0.DescribeMacModificationTasks$).build() {
      static {
        __name(this, "DescribeMacModificationTasksCommand");
      }
    };
    var DescribeManagedPrefixListsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeManagedPrefixLists", {}).n("EC2Client", "DescribeManagedPrefixListsCommand").sc(schemas_0.DescribeManagedPrefixLists$).build() {
      static {
        __name(this, "DescribeManagedPrefixListsCommand");
      }
    };
    var DescribeMovingAddressesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeMovingAddresses", {}).n("EC2Client", "DescribeMovingAddressesCommand").sc(schemas_0.DescribeMovingAddresses$).build() {
      static {
        __name(this, "DescribeMovingAddressesCommand");
      }
    };
    var DescribeNatGatewaysCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeNatGateways", {}).n("EC2Client", "DescribeNatGatewaysCommand").sc(schemas_0.DescribeNatGateways$).build() {
      static {
        __name(this, "DescribeNatGatewaysCommand");
      }
    };
    var DescribeNetworkAclsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeNetworkAcls", {}).n("EC2Client", "DescribeNetworkAclsCommand").sc(schemas_0.DescribeNetworkAcls$).build() {
      static {
        __name(this, "DescribeNetworkAclsCommand");
      }
    };
    var DescribeNetworkInsightsAccessScopeAnalysesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeNetworkInsightsAccessScopeAnalyses", {}).n("EC2Client", "DescribeNetworkInsightsAccessScopeAnalysesCommand").sc(schemas_0.DescribeNetworkInsightsAccessScopeAnalyses$).build() {
      static {
        __name(this, "DescribeNetworkInsightsAccessScopeAnalysesCommand");
      }
    };
    var DescribeNetworkInsightsAccessScopesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeNetworkInsightsAccessScopes", {}).n("EC2Client", "DescribeNetworkInsightsAccessScopesCommand").sc(schemas_0.DescribeNetworkInsightsAccessScopes$).build() {
      static {
        __name(this, "DescribeNetworkInsightsAccessScopesCommand");
      }
    };
    var DescribeNetworkInsightsAnalysesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeNetworkInsightsAnalyses", {}).n("EC2Client", "DescribeNetworkInsightsAnalysesCommand").sc(schemas_0.DescribeNetworkInsightsAnalyses$).build() {
      static {
        __name(this, "DescribeNetworkInsightsAnalysesCommand");
      }
    };
    var DescribeNetworkInsightsPathsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeNetworkInsightsPaths", {}).n("EC2Client", "DescribeNetworkInsightsPathsCommand").sc(schemas_0.DescribeNetworkInsightsPaths$).build() {
      static {
        __name(this, "DescribeNetworkInsightsPathsCommand");
      }
    };
    var DescribeNetworkInterfaceAttributeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeNetworkInterfaceAttribute", {}).n("EC2Client", "DescribeNetworkInterfaceAttributeCommand").sc(schemas_0.DescribeNetworkInterfaceAttribute$).build() {
      static {
        __name(this, "DescribeNetworkInterfaceAttributeCommand");
      }
    };
    var DescribeNetworkInterfacePermissionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeNetworkInterfacePermissions", {}).n("EC2Client", "DescribeNetworkInterfacePermissionsCommand").sc(schemas_0.DescribeNetworkInterfacePermissions$).build() {
      static {
        __name(this, "DescribeNetworkInterfacePermissionsCommand");
      }
    };
    var DescribeNetworkInterfacesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeNetworkInterfaces", {}).n("EC2Client", "DescribeNetworkInterfacesCommand").sc(schemas_0.DescribeNetworkInterfaces$).build() {
      static {
        __name(this, "DescribeNetworkInterfacesCommand");
      }
    };
    var DescribeOutpostLagsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeOutpostLags", {}).n("EC2Client", "DescribeOutpostLagsCommand").sc(schemas_0.DescribeOutpostLags$).build() {
      static {
        __name(this, "DescribeOutpostLagsCommand");
      }
    };
    var DescribePlacementGroupsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribePlacementGroups", {}).n("EC2Client", "DescribePlacementGroupsCommand").sc(schemas_0.DescribePlacementGroups$).build() {
      static {
        __name(this, "DescribePlacementGroupsCommand");
      }
    };
    var DescribePrefixListsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribePrefixLists", {}).n("EC2Client", "DescribePrefixListsCommand").sc(schemas_0.DescribePrefixLists$).build() {
      static {
        __name(this, "DescribePrefixListsCommand");
      }
    };
    var DescribePrincipalIdFormatCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribePrincipalIdFormat", {}).n("EC2Client", "DescribePrincipalIdFormatCommand").sc(schemas_0.DescribePrincipalIdFormat$).build() {
      static {
        __name(this, "DescribePrincipalIdFormatCommand");
      }
    };
    var DescribePublicIpv4PoolsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribePublicIpv4Pools", {}).n("EC2Client", "DescribePublicIpv4PoolsCommand").sc(schemas_0.DescribePublicIpv4Pools$).build() {
      static {
        __name(this, "DescribePublicIpv4PoolsCommand");
      }
    };
    var DescribeRegionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeRegions", {}).n("EC2Client", "DescribeRegionsCommand").sc(schemas_0.DescribeRegions$).build() {
      static {
        __name(this, "DescribeRegionsCommand");
      }
    };
    var DescribeReplaceRootVolumeTasksCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeReplaceRootVolumeTasks", {}).n("EC2Client", "DescribeReplaceRootVolumeTasksCommand").sc(schemas_0.DescribeReplaceRootVolumeTasks$).build() {
      static {
        __name(this, "DescribeReplaceRootVolumeTasksCommand");
      }
    };
    var DescribeReservedInstancesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeReservedInstances", {}).n("EC2Client", "DescribeReservedInstancesCommand").sc(schemas_0.DescribeReservedInstances$).build() {
      static {
        __name(this, "DescribeReservedInstancesCommand");
      }
    };
    var DescribeReservedInstancesListingsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeReservedInstancesListings", {}).n("EC2Client", "DescribeReservedInstancesListingsCommand").sc(schemas_0.DescribeReservedInstancesListings$).build() {
      static {
        __name(this, "DescribeReservedInstancesListingsCommand");
      }
    };
    var DescribeReservedInstancesModificationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeReservedInstancesModifications", {}).n("EC2Client", "DescribeReservedInstancesModificationsCommand").sc(schemas_0.DescribeReservedInstancesModifications$).build() {
      static {
        __name(this, "DescribeReservedInstancesModificationsCommand");
      }
    };
    var DescribeReservedInstancesOfferingsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeReservedInstancesOfferings", {}).n("EC2Client", "DescribeReservedInstancesOfferingsCommand").sc(schemas_0.DescribeReservedInstancesOfferings$).build() {
      static {
        __name(this, "DescribeReservedInstancesOfferingsCommand");
      }
    };
    var DescribeRouteServerEndpointsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeRouteServerEndpoints", {}).n("EC2Client", "DescribeRouteServerEndpointsCommand").sc(schemas_0.DescribeRouteServerEndpoints$).build() {
      static {
        __name(this, "DescribeRouteServerEndpointsCommand");
      }
    };
    var DescribeRouteServerPeersCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeRouteServerPeers", {}).n("EC2Client", "DescribeRouteServerPeersCommand").sc(schemas_0.DescribeRouteServerPeers$).build() {
      static {
        __name(this, "DescribeRouteServerPeersCommand");
      }
    };
    var DescribeRouteServersCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeRouteServers", {}).n("EC2Client", "DescribeRouteServersCommand").sc(schemas_0.DescribeRouteServers$).build() {
      static {
        __name(this, "DescribeRouteServersCommand");
      }
    };
    var DescribeRouteTablesCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeRouteTables", {}).n("EC2Client", "DescribeRouteTablesCommand").sc(schemas_0.DescribeRouteTables$).build() {
      static {
        __name(this, "DescribeRouteTablesCommand");
      }
    };
    var DescribeScheduledInstanceAvailabilityCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeScheduledInstanceAvailability", {}).n("EC2Client", "DescribeScheduledInstanceAvailabilityCommand").sc(schemas_0.DescribeScheduledInstanceAvailability$).build() {
      static {
        __name(this, "DescribeScheduledInstanceAvailabilityCommand");
      }
    };
    var DescribeScheduledInstancesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeScheduledInstances", {}).n("EC2Client", "DescribeScheduledInstancesCommand").sc(schemas_0.DescribeScheduledInstances$).build() {
      static {
        __name(this, "DescribeScheduledInstancesCommand");
      }
    };
    var DescribeSecondaryInterfacesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeSecondaryInterfaces", {}).n("EC2Client", "DescribeSecondaryInterfacesCommand").sc(schemas_0.DescribeSecondaryInterfaces$).build() {
      static {
        __name(this, "DescribeSecondaryInterfacesCommand");
      }
    };
    var DescribeSecondaryNetworksCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeSecondaryNetworks", {}).n("EC2Client", "DescribeSecondaryNetworksCommand").sc(schemas_0.DescribeSecondaryNetworks$).build() {
      static {
        __name(this, "DescribeSecondaryNetworksCommand");
      }
    };
    var DescribeSecondarySubnetsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeSecondarySubnets", {}).n("EC2Client", "DescribeSecondarySubnetsCommand").sc(schemas_0.DescribeSecondarySubnets$).build() {
      static {
        __name(this, "DescribeSecondarySubnetsCommand");
      }
    };
    var DescribeSecurityGroupReferencesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeSecurityGroupReferences", {}).n("EC2Client", "DescribeSecurityGroupReferencesCommand").sc(schemas_0.DescribeSecurityGroupReferences$).build() {
      static {
        __name(this, "DescribeSecurityGroupReferencesCommand");
      }
    };
    var DescribeSecurityGroupRulesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeSecurityGroupRules", {}).n("EC2Client", "DescribeSecurityGroupRulesCommand").sc(schemas_0.DescribeSecurityGroupRules$).build() {
      static {
        __name(this, "DescribeSecurityGroupRulesCommand");
      }
    };
    var DescribeSecurityGroupsCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeSecurityGroups", {}).n("EC2Client", "DescribeSecurityGroupsCommand").sc(schemas_0.DescribeSecurityGroups$).build() {
      static {
        __name(this, "DescribeSecurityGroupsCommand");
      }
    };
    var DescribeSecurityGroupVpcAssociationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeSecurityGroupVpcAssociations", {}).n("EC2Client", "DescribeSecurityGroupVpcAssociationsCommand").sc(schemas_0.DescribeSecurityGroupVpcAssociations$).build() {
      static {
        __name(this, "DescribeSecurityGroupVpcAssociationsCommand");
      }
    };
    var DescribeServiceLinkVirtualInterfacesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeServiceLinkVirtualInterfaces", {}).n("EC2Client", "DescribeServiceLinkVirtualInterfacesCommand").sc(schemas_0.DescribeServiceLinkVirtualInterfaces$).build() {
      static {
        __name(this, "DescribeServiceLinkVirtualInterfacesCommand");
      }
    };
    var DescribeSnapshotAttributeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeSnapshotAttribute", {}).n("EC2Client", "DescribeSnapshotAttributeCommand").sc(schemas_0.DescribeSnapshotAttribute$).build() {
      static {
        __name(this, "DescribeSnapshotAttributeCommand");
      }
    };
    var DescribeSnapshotsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeSnapshots", {}).n("EC2Client", "DescribeSnapshotsCommand").sc(schemas_0.DescribeSnapshots$).build() {
      static {
        __name(this, "DescribeSnapshotsCommand");
      }
    };
    var DescribeSnapshotTierStatusCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeSnapshotTierStatus", {}).n("EC2Client", "DescribeSnapshotTierStatusCommand").sc(schemas_0.DescribeSnapshotTierStatus$).build() {
      static {
        __name(this, "DescribeSnapshotTierStatusCommand");
      }
    };
    var DescribeSpotDatafeedSubscriptionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeSpotDatafeedSubscription", {}).n("EC2Client", "DescribeSpotDatafeedSubscriptionCommand").sc(schemas_0.DescribeSpotDatafeedSubscription$).build() {
      static {
        __name(this, "DescribeSpotDatafeedSubscriptionCommand");
      }
    };
    var DescribeSpotFleetInstancesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeSpotFleetInstances", {}).n("EC2Client", "DescribeSpotFleetInstancesCommand").sc(schemas_0.DescribeSpotFleetInstances$).build() {
      static {
        __name(this, "DescribeSpotFleetInstancesCommand");
      }
    };
    var DescribeSpotFleetRequestHistoryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeSpotFleetRequestHistory", {}).n("EC2Client", "DescribeSpotFleetRequestHistoryCommand").sc(schemas_0.DescribeSpotFleetRequestHistory$).build() {
      static {
        __name(this, "DescribeSpotFleetRequestHistoryCommand");
      }
    };
    var DescribeSpotFleetRequestsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeSpotFleetRequests", {}).n("EC2Client", "DescribeSpotFleetRequestsCommand").sc(schemas_0.DescribeSpotFleetRequests$).build() {
      static {
        __name(this, "DescribeSpotFleetRequestsCommand");
      }
    };
    var DescribeSpotInstanceRequestsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeSpotInstanceRequests", {}).n("EC2Client", "DescribeSpotInstanceRequestsCommand").sc(schemas_0.DescribeSpotInstanceRequests$).build() {
      static {
        __name(this, "DescribeSpotInstanceRequestsCommand");
      }
    };
    var DescribeSpotPriceHistoryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeSpotPriceHistory", {}).n("EC2Client", "DescribeSpotPriceHistoryCommand").sc(schemas_0.DescribeSpotPriceHistory$).build() {
      static {
        __name(this, "DescribeSpotPriceHistoryCommand");
      }
    };
    var DescribeStaleSecurityGroupsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeStaleSecurityGroups", {}).n("EC2Client", "DescribeStaleSecurityGroupsCommand").sc(schemas_0.DescribeStaleSecurityGroups$).build() {
      static {
        __name(this, "DescribeStaleSecurityGroupsCommand");
      }
    };
    var DescribeStoreImageTasksCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeStoreImageTasks", {}).n("EC2Client", "DescribeStoreImageTasksCommand").sc(schemas_0.DescribeStoreImageTasks$).build() {
      static {
        __name(this, "DescribeStoreImageTasksCommand");
      }
    };
    var DescribeSubnetsCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeSubnets", {}).n("EC2Client", "DescribeSubnetsCommand").sc(schemas_0.DescribeSubnets$).build() {
      static {
        __name(this, "DescribeSubnetsCommand");
      }
    };
    var DescribeTagsCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeTags", {}).n("EC2Client", "DescribeTagsCommand").sc(schemas_0.DescribeTags$).build() {
      static {
        __name(this, "DescribeTagsCommand");
      }
    };
    var DescribeTrafficMirrorFilterRulesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeTrafficMirrorFilterRules", {}).n("EC2Client", "DescribeTrafficMirrorFilterRulesCommand").sc(schemas_0.DescribeTrafficMirrorFilterRules$).build() {
      static {
        __name(this, "DescribeTrafficMirrorFilterRulesCommand");
      }
    };
    var DescribeTrafficMirrorFiltersCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeTrafficMirrorFilters", {}).n("EC2Client", "DescribeTrafficMirrorFiltersCommand").sc(schemas_0.DescribeTrafficMirrorFilters$).build() {
      static {
        __name(this, "DescribeTrafficMirrorFiltersCommand");
      }
    };
    var DescribeTrafficMirrorSessionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeTrafficMirrorSessions", {}).n("EC2Client", "DescribeTrafficMirrorSessionsCommand").sc(schemas_0.DescribeTrafficMirrorSessions$).build() {
      static {
        __name(this, "DescribeTrafficMirrorSessionsCommand");
      }
    };
    var DescribeTrafficMirrorTargetsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeTrafficMirrorTargets", {}).n("EC2Client", "DescribeTrafficMirrorTargetsCommand").sc(schemas_0.DescribeTrafficMirrorTargets$).build() {
      static {
        __name(this, "DescribeTrafficMirrorTargetsCommand");
      }
    };
    var DescribeTransitGatewayAttachmentsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeTransitGatewayAttachments", {}).n("EC2Client", "DescribeTransitGatewayAttachmentsCommand").sc(schemas_0.DescribeTransitGatewayAttachments$).build() {
      static {
        __name(this, "DescribeTransitGatewayAttachmentsCommand");
      }
    };
    var DescribeTransitGatewayConnectPeersCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeTransitGatewayConnectPeers", {}).n("EC2Client", "DescribeTransitGatewayConnectPeersCommand").sc(schemas_0.DescribeTransitGatewayConnectPeers$).build() {
      static {
        __name(this, "DescribeTransitGatewayConnectPeersCommand");
      }
    };
    var DescribeTransitGatewayConnectsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeTransitGatewayConnects", {}).n("EC2Client", "DescribeTransitGatewayConnectsCommand").sc(schemas_0.DescribeTransitGatewayConnects$).build() {
      static {
        __name(this, "DescribeTransitGatewayConnectsCommand");
      }
    };
    var DescribeTransitGatewayMeteringPoliciesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeTransitGatewayMeteringPolicies", {}).n("EC2Client", "DescribeTransitGatewayMeteringPoliciesCommand").sc(schemas_0.DescribeTransitGatewayMeteringPolicies$).build() {
      static {
        __name(this, "DescribeTransitGatewayMeteringPoliciesCommand");
      }
    };
    var DescribeTransitGatewayMulticastDomainsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeTransitGatewayMulticastDomains", {}).n("EC2Client", "DescribeTransitGatewayMulticastDomainsCommand").sc(schemas_0.DescribeTransitGatewayMulticastDomains$).build() {
      static {
        __name(this, "DescribeTransitGatewayMulticastDomainsCommand");
      }
    };
    var DescribeTransitGatewayPeeringAttachmentsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeTransitGatewayPeeringAttachments", {}).n("EC2Client", "DescribeTransitGatewayPeeringAttachmentsCommand").sc(schemas_0.DescribeTransitGatewayPeeringAttachments$).build() {
      static {
        __name(this, "DescribeTransitGatewayPeeringAttachmentsCommand");
      }
    };
    var DescribeTransitGatewayPolicyTablesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeTransitGatewayPolicyTables", {}).n("EC2Client", "DescribeTransitGatewayPolicyTablesCommand").sc(schemas_0.DescribeTransitGatewayPolicyTables$).build() {
      static {
        __name(this, "DescribeTransitGatewayPolicyTablesCommand");
      }
    };
    var DescribeTransitGatewayRouteTableAnnouncementsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeTransitGatewayRouteTableAnnouncements", {}).n("EC2Client", "DescribeTransitGatewayRouteTableAnnouncementsCommand").sc(schemas_0.DescribeTransitGatewayRouteTableAnnouncements$).build() {
      static {
        __name(this, "DescribeTransitGatewayRouteTableAnnouncementsCommand");
      }
    };
    var DescribeTransitGatewayRouteTablesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeTransitGatewayRouteTables", {}).n("EC2Client", "DescribeTransitGatewayRouteTablesCommand").sc(schemas_0.DescribeTransitGatewayRouteTables$).build() {
      static {
        __name(this, "DescribeTransitGatewayRouteTablesCommand");
      }
    };
    var DescribeTransitGatewaysCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeTransitGateways", {}).n("EC2Client", "DescribeTransitGatewaysCommand").sc(schemas_0.DescribeTransitGateways$).build() {
      static {
        __name(this, "DescribeTransitGatewaysCommand");
      }
    };
    var DescribeTransitGatewayVpcAttachmentsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeTransitGatewayVpcAttachments", {}).n("EC2Client", "DescribeTransitGatewayVpcAttachmentsCommand").sc(schemas_0.DescribeTransitGatewayVpcAttachments$).build() {
      static {
        __name(this, "DescribeTransitGatewayVpcAttachmentsCommand");
      }
    };
    var DescribeTrunkInterfaceAssociationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeTrunkInterfaceAssociations", {}).n("EC2Client", "DescribeTrunkInterfaceAssociationsCommand").sc(schemas_0.DescribeTrunkInterfaceAssociations$).build() {
      static {
        __name(this, "DescribeTrunkInterfaceAssociationsCommand");
      }
    };
    var DescribeVerifiedAccessEndpointsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeVerifiedAccessEndpoints", {}).n("EC2Client", "DescribeVerifiedAccessEndpointsCommand").sc(schemas_0.DescribeVerifiedAccessEndpoints$).build() {
      static {
        __name(this, "DescribeVerifiedAccessEndpointsCommand");
      }
    };
    var DescribeVerifiedAccessGroupsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeVerifiedAccessGroups", {}).n("EC2Client", "DescribeVerifiedAccessGroupsCommand").sc(schemas_0.DescribeVerifiedAccessGroups$).build() {
      static {
        __name(this, "DescribeVerifiedAccessGroupsCommand");
      }
    };
    var DescribeVerifiedAccessInstanceLoggingConfigurationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeVerifiedAccessInstanceLoggingConfigurations", {}).n("EC2Client", "DescribeVerifiedAccessInstanceLoggingConfigurationsCommand").sc(schemas_0.DescribeVerifiedAccessInstanceLoggingConfigurations$).build() {
      static {
        __name(this, "DescribeVerifiedAccessInstanceLoggingConfigurationsCommand");
      }
    };
    var DescribeVerifiedAccessInstancesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeVerifiedAccessInstances", {}).n("EC2Client", "DescribeVerifiedAccessInstancesCommand").sc(schemas_0.DescribeVerifiedAccessInstances$).build() {
      static {
        __name(this, "DescribeVerifiedAccessInstancesCommand");
      }
    };
    var DescribeVerifiedAccessTrustProvidersCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeVerifiedAccessTrustProviders", {}).n("EC2Client", "DescribeVerifiedAccessTrustProvidersCommand").sc(schemas_0.DescribeVerifiedAccessTrustProviders$).build() {
      static {
        __name(this, "DescribeVerifiedAccessTrustProvidersCommand");
      }
    };
    var DescribeVolumeAttributeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeVolumeAttribute", {}).n("EC2Client", "DescribeVolumeAttributeCommand").sc(schemas_0.DescribeVolumeAttribute$).build() {
      static {
        __name(this, "DescribeVolumeAttributeCommand");
      }
    };
    var DescribeVolumesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeVolumes", {}).n("EC2Client", "DescribeVolumesCommand").sc(schemas_0.DescribeVolumes$).build() {
      static {
        __name(this, "DescribeVolumesCommand");
      }
    };
    var DescribeVolumesModificationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeVolumesModifications", {}).n("EC2Client", "DescribeVolumesModificationsCommand").sc(schemas_0.DescribeVolumesModifications$).build() {
      static {
        __name(this, "DescribeVolumesModificationsCommand");
      }
    };
    var DescribeVolumeStatusCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeVolumeStatus", {}).n("EC2Client", "DescribeVolumeStatusCommand").sc(schemas_0.DescribeVolumeStatus$).build() {
      static {
        __name(this, "DescribeVolumeStatusCommand");
      }
    };
    var DescribeVpcAttributeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeVpcAttribute", {}).n("EC2Client", "DescribeVpcAttributeCommand").sc(schemas_0.DescribeVpcAttribute$).build() {
      static {
        __name(this, "DescribeVpcAttributeCommand");
      }
    };
    var DescribeVpcBlockPublicAccessExclusionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeVpcBlockPublicAccessExclusions", {}).n("EC2Client", "DescribeVpcBlockPublicAccessExclusionsCommand").sc(schemas_0.DescribeVpcBlockPublicAccessExclusions$).build() {
      static {
        __name(this, "DescribeVpcBlockPublicAccessExclusionsCommand");
      }
    };
    var DescribeVpcBlockPublicAccessOptionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeVpcBlockPublicAccessOptions", {}).n("EC2Client", "DescribeVpcBlockPublicAccessOptionsCommand").sc(schemas_0.DescribeVpcBlockPublicAccessOptions$).build() {
      static {
        __name(this, "DescribeVpcBlockPublicAccessOptionsCommand");
      }
    };
    var DescribeVpcClassicLinkCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeVpcClassicLink", {}).n("EC2Client", "DescribeVpcClassicLinkCommand").sc(schemas_0.DescribeVpcClassicLink$).build() {
      static {
        __name(this, "DescribeVpcClassicLinkCommand");
      }
    };
    var DescribeVpcClassicLinkDnsSupportCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeVpcClassicLinkDnsSupport", {}).n("EC2Client", "DescribeVpcClassicLinkDnsSupportCommand").sc(schemas_0.DescribeVpcClassicLinkDnsSupport$).build() {
      static {
        __name(this, "DescribeVpcClassicLinkDnsSupportCommand");
      }
    };
    var DescribeVpcEncryptionControlsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeVpcEncryptionControls", {}).n("EC2Client", "DescribeVpcEncryptionControlsCommand").sc(schemas_0.DescribeVpcEncryptionControls$).build() {
      static {
        __name(this, "DescribeVpcEncryptionControlsCommand");
      }
    };
    var DescribeVpcEndpointAssociationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeVpcEndpointAssociations", {}).n("EC2Client", "DescribeVpcEndpointAssociationsCommand").sc(schemas_0.DescribeVpcEndpointAssociations$).build() {
      static {
        __name(this, "DescribeVpcEndpointAssociationsCommand");
      }
    };
    var DescribeVpcEndpointConnectionNotificationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeVpcEndpointConnectionNotifications", {}).n("EC2Client", "DescribeVpcEndpointConnectionNotificationsCommand").sc(schemas_0.DescribeVpcEndpointConnectionNotifications$).build() {
      static {
        __name(this, "DescribeVpcEndpointConnectionNotificationsCommand");
      }
    };
    var DescribeVpcEndpointConnectionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeVpcEndpointConnections", {}).n("EC2Client", "DescribeVpcEndpointConnectionsCommand").sc(schemas_0.DescribeVpcEndpointConnections$).build() {
      static {
        __name(this, "DescribeVpcEndpointConnectionsCommand");
      }
    };
    var DescribeVpcEndpointsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeVpcEndpoints", {}).n("EC2Client", "DescribeVpcEndpointsCommand").sc(schemas_0.DescribeVpcEndpoints$).build() {
      static {
        __name(this, "DescribeVpcEndpointsCommand");
      }
    };
    var DescribeVpcEndpointServiceConfigurationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeVpcEndpointServiceConfigurations", {}).n("EC2Client", "DescribeVpcEndpointServiceConfigurationsCommand").sc(schemas_0.DescribeVpcEndpointServiceConfigurations$).build() {
      static {
        __name(this, "DescribeVpcEndpointServiceConfigurationsCommand");
      }
    };
    var DescribeVpcEndpointServicePermissionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeVpcEndpointServicePermissions", {}).n("EC2Client", "DescribeVpcEndpointServicePermissionsCommand").sc(schemas_0.DescribeVpcEndpointServicePermissions$).build() {
      static {
        __name(this, "DescribeVpcEndpointServicePermissionsCommand");
      }
    };
    var DescribeVpcEndpointServicesCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeVpcEndpointServices", {}).n("EC2Client", "DescribeVpcEndpointServicesCommand").sc(schemas_0.DescribeVpcEndpointServices$).build() {
      static {
        __name(this, "DescribeVpcEndpointServicesCommand");
      }
    };
    var DescribeVpcPeeringConnectionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeVpcPeeringConnections", {}).n("EC2Client", "DescribeVpcPeeringConnectionsCommand").sc(schemas_0.DescribeVpcPeeringConnections$).build() {
      static {
        __name(this, "DescribeVpcPeeringConnectionsCommand");
      }
    };
    var DescribeVpcsCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeVpcs", {}).n("EC2Client", "DescribeVpcsCommand").sc(schemas_0.DescribeVpcs$).build() {
      static {
        __name(this, "DescribeVpcsCommand");
      }
    };
    var DescribeVpnConcentratorsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeVpnConcentrators", {}).n("EC2Client", "DescribeVpnConcentratorsCommand").sc(schemas_0.DescribeVpnConcentrators$).build() {
      static {
        __name(this, "DescribeVpnConcentratorsCommand");
      }
    };
    var DescribeVpnConnectionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeVpnConnections", {}).n("EC2Client", "DescribeVpnConnectionsCommand").sc(schemas_0.DescribeVpnConnections$).build() {
      static {
        __name(this, "DescribeVpnConnectionsCommand");
      }
    };
    var DescribeVpnGatewaysCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DescribeVpnGateways", {}).n("EC2Client", "DescribeVpnGatewaysCommand").sc(schemas_0.DescribeVpnGateways$).build() {
      static {
        __name(this, "DescribeVpnGatewaysCommand");
      }
    };
    var DetachClassicLinkVpcCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DetachClassicLinkVpc", {}).n("EC2Client", "DetachClassicLinkVpcCommand").sc(schemas_0.DetachClassicLinkVpc$).build() {
      static {
        __name(this, "DetachClassicLinkVpcCommand");
      }
    };
    var DetachInternetGatewayCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DetachInternetGateway", {}).n("EC2Client", "DetachInternetGatewayCommand").sc(schemas_0.DetachInternetGateway$).build() {
      static {
        __name(this, "DetachInternetGatewayCommand");
      }
    };
    var DetachNetworkInterfaceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DetachNetworkInterface", {}).n("EC2Client", "DetachNetworkInterfaceCommand").sc(schemas_0.DetachNetworkInterface$).build() {
      static {
        __name(this, "DetachNetworkInterfaceCommand");
      }
    };
    var DetachVerifiedAccessTrustProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DetachVerifiedAccessTrustProvider", {}).n("EC2Client", "DetachVerifiedAccessTrustProviderCommand").sc(schemas_0.DetachVerifiedAccessTrustProvider$).build() {
      static {
        __name(this, "DetachVerifiedAccessTrustProviderCommand");
      }
    };
    var DetachVolumeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DetachVolume", {}).n("EC2Client", "DetachVolumeCommand").sc(schemas_0.DetachVolume$).build() {
      static {
        __name(this, "DetachVolumeCommand");
      }
    };
    var DetachVpnGatewayCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DetachVpnGateway", {}).n("EC2Client", "DetachVpnGatewayCommand").sc(schemas_0.DetachVpnGateway$).build() {
      static {
        __name(this, "DetachVpnGatewayCommand");
      }
    };
    var DisableAddressTransferCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisableAddressTransfer", {}).n("EC2Client", "DisableAddressTransferCommand").sc(schemas_0.DisableAddressTransfer$).build() {
      static {
        __name(this, "DisableAddressTransferCommand");
      }
    };
    var DisableAllowedImagesSettingsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisableAllowedImagesSettings", {}).n("EC2Client", "DisableAllowedImagesSettingsCommand").sc(schemas_0.DisableAllowedImagesSettings$).build() {
      static {
        __name(this, "DisableAllowedImagesSettingsCommand");
      }
    };
    var DisableAwsNetworkPerformanceMetricSubscriptionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisableAwsNetworkPerformanceMetricSubscription", {}).n("EC2Client", "DisableAwsNetworkPerformanceMetricSubscriptionCommand").sc(schemas_0.DisableAwsNetworkPerformanceMetricSubscription$).build() {
      static {
        __name(this, "DisableAwsNetworkPerformanceMetricSubscriptionCommand");
      }
    };
    var DisableCapacityManagerCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisableCapacityManager", {}).n("EC2Client", "DisableCapacityManagerCommand").sc(schemas_0.DisableCapacityManager$).build() {
      static {
        __name(this, "DisableCapacityManagerCommand");
      }
    };
    var DisableEbsEncryptionByDefaultCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisableEbsEncryptionByDefault", {}).n("EC2Client", "DisableEbsEncryptionByDefaultCommand").sc(schemas_0.DisableEbsEncryptionByDefault$).build() {
      static {
        __name(this, "DisableEbsEncryptionByDefaultCommand");
      }
    };
    var DisableFastLaunchCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisableFastLaunch", {}).n("EC2Client", "DisableFastLaunchCommand").sc(schemas_0.DisableFastLaunch$).build() {
      static {
        __name(this, "DisableFastLaunchCommand");
      }
    };
    var DisableFastSnapshotRestoresCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisableFastSnapshotRestores", {}).n("EC2Client", "DisableFastSnapshotRestoresCommand").sc(schemas_0.DisableFastSnapshotRestores$).build() {
      static {
        __name(this, "DisableFastSnapshotRestoresCommand");
      }
    };
    var DisableImageBlockPublicAccessCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisableImageBlockPublicAccess", {}).n("EC2Client", "DisableImageBlockPublicAccessCommand").sc(schemas_0.DisableImageBlockPublicAccess$).build() {
      static {
        __name(this, "DisableImageBlockPublicAccessCommand");
      }
    };
    var DisableImageCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisableImage", {}).n("EC2Client", "DisableImageCommand").sc(schemas_0.DisableImage$).build() {
      static {
        __name(this, "DisableImageCommand");
      }
    };
    var DisableImageDeprecationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisableImageDeprecation", {}).n("EC2Client", "DisableImageDeprecationCommand").sc(schemas_0.DisableImageDeprecation$).build() {
      static {
        __name(this, "DisableImageDeprecationCommand");
      }
    };
    var DisableImageDeregistrationProtectionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisableImageDeregistrationProtection", {}).n("EC2Client", "DisableImageDeregistrationProtectionCommand").sc(schemas_0.DisableImageDeregistrationProtection$).build() {
      static {
        __name(this, "DisableImageDeregistrationProtectionCommand");
      }
    };
    var DisableInstanceSqlHaStandbyDetectionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisableInstanceSqlHaStandbyDetections", {}).n("EC2Client", "DisableInstanceSqlHaStandbyDetectionsCommand").sc(schemas_0.DisableInstanceSqlHaStandbyDetections$).build() {
      static {
        __name(this, "DisableInstanceSqlHaStandbyDetectionsCommand");
      }
    };
    var DisableIpamOrganizationAdminAccountCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisableIpamOrganizationAdminAccount", {}).n("EC2Client", "DisableIpamOrganizationAdminAccountCommand").sc(schemas_0.DisableIpamOrganizationAdminAccount$).build() {
      static {
        __name(this, "DisableIpamOrganizationAdminAccountCommand");
      }
    };
    var DisableIpamPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisableIpamPolicy", {}).n("EC2Client", "DisableIpamPolicyCommand").sc(schemas_0.DisableIpamPolicy$).build() {
      static {
        __name(this, "DisableIpamPolicyCommand");
      }
    };
    var DisableRouteServerPropagationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisableRouteServerPropagation", {}).n("EC2Client", "DisableRouteServerPropagationCommand").sc(schemas_0.DisableRouteServerPropagation$).build() {
      static {
        __name(this, "DisableRouteServerPropagationCommand");
      }
    };
    var DisableSerialConsoleAccessCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisableSerialConsoleAccess", {}).n("EC2Client", "DisableSerialConsoleAccessCommand").sc(schemas_0.DisableSerialConsoleAccess$).build() {
      static {
        __name(this, "DisableSerialConsoleAccessCommand");
      }
    };
    var DisableSnapshotBlockPublicAccessCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisableSnapshotBlockPublicAccess", {}).n("EC2Client", "DisableSnapshotBlockPublicAccessCommand").sc(schemas_0.DisableSnapshotBlockPublicAccess$).build() {
      static {
        __name(this, "DisableSnapshotBlockPublicAccessCommand");
      }
    };
    var DisableTransitGatewayRouteTablePropagationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisableTransitGatewayRouteTablePropagation", {}).n("EC2Client", "DisableTransitGatewayRouteTablePropagationCommand").sc(schemas_0.DisableTransitGatewayRouteTablePropagation$).build() {
      static {
        __name(this, "DisableTransitGatewayRouteTablePropagationCommand");
      }
    };
    var DisableVgwRoutePropagationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisableVgwRoutePropagation", {}).n("EC2Client", "DisableVgwRoutePropagationCommand").sc(schemas_0.DisableVgwRoutePropagation$).build() {
      static {
        __name(this, "DisableVgwRoutePropagationCommand");
      }
    };
    var DisableVpcClassicLinkCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisableVpcClassicLink", {}).n("EC2Client", "DisableVpcClassicLinkCommand").sc(schemas_0.DisableVpcClassicLink$).build() {
      static {
        __name(this, "DisableVpcClassicLinkCommand");
      }
    };
    var DisableVpcClassicLinkDnsSupportCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisableVpcClassicLinkDnsSupport", {}).n("EC2Client", "DisableVpcClassicLinkDnsSupportCommand").sc(schemas_0.DisableVpcClassicLinkDnsSupport$).build() {
      static {
        __name(this, "DisableVpcClassicLinkDnsSupportCommand");
      }
    };
    var DisassociateAddressCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisassociateAddress", {}).n("EC2Client", "DisassociateAddressCommand").sc(schemas_0.DisassociateAddress$).build() {
      static {
        __name(this, "DisassociateAddressCommand");
      }
    };
    var DisassociateCapacityReservationBillingOwnerCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisassociateCapacityReservationBillingOwner", {}).n("EC2Client", "DisassociateCapacityReservationBillingOwnerCommand").sc(schemas_0.DisassociateCapacityReservationBillingOwner$).build() {
      static {
        __name(this, "DisassociateCapacityReservationBillingOwnerCommand");
      }
    };
    var DisassociateClientVpnTargetNetworkCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisassociateClientVpnTargetNetwork", {}).n("EC2Client", "DisassociateClientVpnTargetNetworkCommand").sc(schemas_0.DisassociateClientVpnTargetNetwork$).build() {
      static {
        __name(this, "DisassociateClientVpnTargetNetworkCommand");
      }
    };
    var DisassociateEnclaveCertificateIamRoleCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisassociateEnclaveCertificateIamRole", {}).n("EC2Client", "DisassociateEnclaveCertificateIamRoleCommand").sc(schemas_0.DisassociateEnclaveCertificateIamRole$).build() {
      static {
        __name(this, "DisassociateEnclaveCertificateIamRoleCommand");
      }
    };
    var DisassociateIamInstanceProfileCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisassociateIamInstanceProfile", {}).n("EC2Client", "DisassociateIamInstanceProfileCommand").sc(schemas_0.DisassociateIamInstanceProfile$).build() {
      static {
        __name(this, "DisassociateIamInstanceProfileCommand");
      }
    };
    var DisassociateInstanceEventWindowCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisassociateInstanceEventWindow", {}).n("EC2Client", "DisassociateInstanceEventWindowCommand").sc(schemas_0.DisassociateInstanceEventWindow$).build() {
      static {
        __name(this, "DisassociateInstanceEventWindowCommand");
      }
    };
    var DisassociateIpamByoasnCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisassociateIpamByoasn", {}).n("EC2Client", "DisassociateIpamByoasnCommand").sc(schemas_0.DisassociateIpamByoasn$).build() {
      static {
        __name(this, "DisassociateIpamByoasnCommand");
      }
    };
    var DisassociateIpamResourceDiscoveryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisassociateIpamResourceDiscovery", {}).n("EC2Client", "DisassociateIpamResourceDiscoveryCommand").sc(schemas_0.DisassociateIpamResourceDiscovery$).build() {
      static {
        __name(this, "DisassociateIpamResourceDiscoveryCommand");
      }
    };
    var DisassociateNatGatewayAddressCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisassociateNatGatewayAddress", {}).n("EC2Client", "DisassociateNatGatewayAddressCommand").sc(schemas_0.DisassociateNatGatewayAddress$).build() {
      static {
        __name(this, "DisassociateNatGatewayAddressCommand");
      }
    };
    var DisassociateRouteServerCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisassociateRouteServer", {}).n("EC2Client", "DisassociateRouteServerCommand").sc(schemas_0.DisassociateRouteServer$).build() {
      static {
        __name(this, "DisassociateRouteServerCommand");
      }
    };
    var DisassociateRouteTableCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisassociateRouteTable", {}).n("EC2Client", "DisassociateRouteTableCommand").sc(schemas_0.DisassociateRouteTable$).build() {
      static {
        __name(this, "DisassociateRouteTableCommand");
      }
    };
    var DisassociateSecurityGroupVpcCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisassociateSecurityGroupVpc", {}).n("EC2Client", "DisassociateSecurityGroupVpcCommand").sc(schemas_0.DisassociateSecurityGroupVpc$).build() {
      static {
        __name(this, "DisassociateSecurityGroupVpcCommand");
      }
    };
    var DisassociateSubnetCidrBlockCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisassociateSubnetCidrBlock", {}).n("EC2Client", "DisassociateSubnetCidrBlockCommand").sc(schemas_0.DisassociateSubnetCidrBlock$).build() {
      static {
        __name(this, "DisassociateSubnetCidrBlockCommand");
      }
    };
    var DisassociateTransitGatewayMulticastDomainCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisassociateTransitGatewayMulticastDomain", {}).n("EC2Client", "DisassociateTransitGatewayMulticastDomainCommand").sc(schemas_0.DisassociateTransitGatewayMulticastDomain$).build() {
      static {
        __name(this, "DisassociateTransitGatewayMulticastDomainCommand");
      }
    };
    var DisassociateTransitGatewayPolicyTableCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisassociateTransitGatewayPolicyTable", {}).n("EC2Client", "DisassociateTransitGatewayPolicyTableCommand").sc(schemas_0.DisassociateTransitGatewayPolicyTable$).build() {
      static {
        __name(this, "DisassociateTransitGatewayPolicyTableCommand");
      }
    };
    var DisassociateTransitGatewayRouteTableCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisassociateTransitGatewayRouteTable", {}).n("EC2Client", "DisassociateTransitGatewayRouteTableCommand").sc(schemas_0.DisassociateTransitGatewayRouteTable$).build() {
      static {
        __name(this, "DisassociateTransitGatewayRouteTableCommand");
      }
    };
    var DisassociateTrunkInterfaceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisassociateTrunkInterface", {}).n("EC2Client", "DisassociateTrunkInterfaceCommand").sc(schemas_0.DisassociateTrunkInterface$).build() {
      static {
        __name(this, "DisassociateTrunkInterfaceCommand");
      }
    };
    var DisassociateVpcCidrBlockCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "DisassociateVpcCidrBlock", {}).n("EC2Client", "DisassociateVpcCidrBlockCommand").sc(schemas_0.DisassociateVpcCidrBlock$).build() {
      static {
        __name(this, "DisassociateVpcCidrBlockCommand");
      }
    };
    var EnableAddressTransferCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "EnableAddressTransfer", {}).n("EC2Client", "EnableAddressTransferCommand").sc(schemas_0.EnableAddressTransfer$).build() {
      static {
        __name(this, "EnableAddressTransferCommand");
      }
    };
    var EnableAllowedImagesSettingsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "EnableAllowedImagesSettings", {}).n("EC2Client", "EnableAllowedImagesSettingsCommand").sc(schemas_0.EnableAllowedImagesSettings$).build() {
      static {
        __name(this, "EnableAllowedImagesSettingsCommand");
      }
    };
    var EnableAwsNetworkPerformanceMetricSubscriptionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "EnableAwsNetworkPerformanceMetricSubscription", {}).n("EC2Client", "EnableAwsNetworkPerformanceMetricSubscriptionCommand").sc(schemas_0.EnableAwsNetworkPerformanceMetricSubscription$).build() {
      static {
        __name(this, "EnableAwsNetworkPerformanceMetricSubscriptionCommand");
      }
    };
    var EnableCapacityManagerCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "EnableCapacityManager", {}).n("EC2Client", "EnableCapacityManagerCommand").sc(schemas_0.EnableCapacityManager$).build() {
      static {
        __name(this, "EnableCapacityManagerCommand");
      }
    };
    var EnableEbsEncryptionByDefaultCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "EnableEbsEncryptionByDefault", {}).n("EC2Client", "EnableEbsEncryptionByDefaultCommand").sc(schemas_0.EnableEbsEncryptionByDefault$).build() {
      static {
        __name(this, "EnableEbsEncryptionByDefaultCommand");
      }
    };
    var EnableFastLaunchCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "EnableFastLaunch", {}).n("EC2Client", "EnableFastLaunchCommand").sc(schemas_0.EnableFastLaunch$).build() {
      static {
        __name(this, "EnableFastLaunchCommand");
      }
    };
    var EnableFastSnapshotRestoresCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "EnableFastSnapshotRestores", {}).n("EC2Client", "EnableFastSnapshotRestoresCommand").sc(schemas_0.EnableFastSnapshotRestores$).build() {
      static {
        __name(this, "EnableFastSnapshotRestoresCommand");
      }
    };
    var EnableImageBlockPublicAccessCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "EnableImageBlockPublicAccess", {}).n("EC2Client", "EnableImageBlockPublicAccessCommand").sc(schemas_0.EnableImageBlockPublicAccess$).build() {
      static {
        __name(this, "EnableImageBlockPublicAccessCommand");
      }
    };
    var EnableImageCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "EnableImage", {}).n("EC2Client", "EnableImageCommand").sc(schemas_0.EnableImage$).build() {
      static {
        __name(this, "EnableImageCommand");
      }
    };
    var EnableImageDeprecationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "EnableImageDeprecation", {}).n("EC2Client", "EnableImageDeprecationCommand").sc(schemas_0.EnableImageDeprecation$).build() {
      static {
        __name(this, "EnableImageDeprecationCommand");
      }
    };
    var EnableImageDeregistrationProtectionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "EnableImageDeregistrationProtection", {}).n("EC2Client", "EnableImageDeregistrationProtectionCommand").sc(schemas_0.EnableImageDeregistrationProtection$).build() {
      static {
        __name(this, "EnableImageDeregistrationProtectionCommand");
      }
    };
    var EnableInstanceSqlHaStandbyDetectionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "EnableInstanceSqlHaStandbyDetections", {}).n("EC2Client", "EnableInstanceSqlHaStandbyDetectionsCommand").sc(schemas_0.EnableInstanceSqlHaStandbyDetections$).build() {
      static {
        __name(this, "EnableInstanceSqlHaStandbyDetectionsCommand");
      }
    };
    var EnableIpamOrganizationAdminAccountCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "EnableIpamOrganizationAdminAccount", {}).n("EC2Client", "EnableIpamOrganizationAdminAccountCommand").sc(schemas_0.EnableIpamOrganizationAdminAccount$).build() {
      static {
        __name(this, "EnableIpamOrganizationAdminAccountCommand");
      }
    };
    var EnableIpamPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "EnableIpamPolicy", {}).n("EC2Client", "EnableIpamPolicyCommand").sc(schemas_0.EnableIpamPolicy$).build() {
      static {
        __name(this, "EnableIpamPolicyCommand");
      }
    };
    var EnableReachabilityAnalyzerOrganizationSharingCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "EnableReachabilityAnalyzerOrganizationSharing", {}).n("EC2Client", "EnableReachabilityAnalyzerOrganizationSharingCommand").sc(schemas_0.EnableReachabilityAnalyzerOrganizationSharing$).build() {
      static {
        __name(this, "EnableReachabilityAnalyzerOrganizationSharingCommand");
      }
    };
    var EnableRouteServerPropagationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "EnableRouteServerPropagation", {}).n("EC2Client", "EnableRouteServerPropagationCommand").sc(schemas_0.EnableRouteServerPropagation$).build() {
      static {
        __name(this, "EnableRouteServerPropagationCommand");
      }
    };
    var EnableSerialConsoleAccessCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "EnableSerialConsoleAccess", {}).n("EC2Client", "EnableSerialConsoleAccessCommand").sc(schemas_0.EnableSerialConsoleAccess$).build() {
      static {
        __name(this, "EnableSerialConsoleAccessCommand");
      }
    };
    var EnableSnapshotBlockPublicAccessCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "EnableSnapshotBlockPublicAccess", {}).n("EC2Client", "EnableSnapshotBlockPublicAccessCommand").sc(schemas_0.EnableSnapshotBlockPublicAccess$).build() {
      static {
        __name(this, "EnableSnapshotBlockPublicAccessCommand");
      }
    };
    var EnableTransitGatewayRouteTablePropagationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "EnableTransitGatewayRouteTablePropagation", {}).n("EC2Client", "EnableTransitGatewayRouteTablePropagationCommand").sc(schemas_0.EnableTransitGatewayRouteTablePropagation$).build() {
      static {
        __name(this, "EnableTransitGatewayRouteTablePropagationCommand");
      }
    };
    var EnableVgwRoutePropagationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "EnableVgwRoutePropagation", {}).n("EC2Client", "EnableVgwRoutePropagationCommand").sc(schemas_0.EnableVgwRoutePropagation$).build() {
      static {
        __name(this, "EnableVgwRoutePropagationCommand");
      }
    };
    var EnableVolumeIOCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "EnableVolumeIO", {}).n("EC2Client", "EnableVolumeIOCommand").sc(schemas_0.EnableVolumeIO$).build() {
      static {
        __name(this, "EnableVolumeIOCommand");
      }
    };
    var EnableVpcClassicLinkCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "EnableVpcClassicLink", {}).n("EC2Client", "EnableVpcClassicLinkCommand").sc(schemas_0.EnableVpcClassicLink$).build() {
      static {
        __name(this, "EnableVpcClassicLinkCommand");
      }
    };
    var EnableVpcClassicLinkDnsSupportCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "EnableVpcClassicLinkDnsSupport", {}).n("EC2Client", "EnableVpcClassicLinkDnsSupportCommand").sc(schemas_0.EnableVpcClassicLinkDnsSupport$).build() {
      static {
        __name(this, "EnableVpcClassicLinkDnsSupportCommand");
      }
    };
    var ExportClientVpnClientCertificateRevocationListCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ExportClientVpnClientCertificateRevocationList", {}).n("EC2Client", "ExportClientVpnClientCertificateRevocationListCommand").sc(schemas_0.ExportClientVpnClientCertificateRevocationList$).build() {
      static {
        __name(this, "ExportClientVpnClientCertificateRevocationListCommand");
      }
    };
    var ExportClientVpnClientConfigurationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ExportClientVpnClientConfiguration", {}).n("EC2Client", "ExportClientVpnClientConfigurationCommand").sc(schemas_0.ExportClientVpnClientConfiguration$).build() {
      static {
        __name(this, "ExportClientVpnClientConfigurationCommand");
      }
    };
    var ExportImageCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ExportImage", {}).n("EC2Client", "ExportImageCommand").sc(schemas_0.ExportImage$).build() {
      static {
        __name(this, "ExportImageCommand");
      }
    };
    var ExportTransitGatewayRoutesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ExportTransitGatewayRoutes", {}).n("EC2Client", "ExportTransitGatewayRoutesCommand").sc(schemas_0.ExportTransitGatewayRoutes$).build() {
      static {
        __name(this, "ExportTransitGatewayRoutesCommand");
      }
    };
    var ExportVerifiedAccessInstanceClientConfigurationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ExportVerifiedAccessInstanceClientConfiguration", {}).n("EC2Client", "ExportVerifiedAccessInstanceClientConfigurationCommand").sc(schemas_0.ExportVerifiedAccessInstanceClientConfiguration$).build() {
      static {
        __name(this, "ExportVerifiedAccessInstanceClientConfigurationCommand");
      }
    };
    var GetActiveVpnTunnelStatusCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetActiveVpnTunnelStatus", {}).n("EC2Client", "GetActiveVpnTunnelStatusCommand").sc(schemas_0.GetActiveVpnTunnelStatus$).build() {
      static {
        __name(this, "GetActiveVpnTunnelStatusCommand");
      }
    };
    var GetAllowedImagesSettingsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetAllowedImagesSettings", {}).n("EC2Client", "GetAllowedImagesSettingsCommand").sc(schemas_0.GetAllowedImagesSettings$).build() {
      static {
        __name(this, "GetAllowedImagesSettingsCommand");
      }
    };
    var GetAssociatedEnclaveCertificateIamRolesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetAssociatedEnclaveCertificateIamRoles", {}).n("EC2Client", "GetAssociatedEnclaveCertificateIamRolesCommand").sc(schemas_0.GetAssociatedEnclaveCertificateIamRoles$).build() {
      static {
        __name(this, "GetAssociatedEnclaveCertificateIamRolesCommand");
      }
    };
    var GetAssociatedIpv6PoolCidrsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetAssociatedIpv6PoolCidrs", {}).n("EC2Client", "GetAssociatedIpv6PoolCidrsCommand").sc(schemas_0.GetAssociatedIpv6PoolCidrs$).build() {
      static {
        __name(this, "GetAssociatedIpv6PoolCidrsCommand");
      }
    };
    var GetAwsNetworkPerformanceDataCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetAwsNetworkPerformanceData", {}).n("EC2Client", "GetAwsNetworkPerformanceDataCommand").sc(schemas_0.GetAwsNetworkPerformanceData$).build() {
      static {
        __name(this, "GetAwsNetworkPerformanceDataCommand");
      }
    };
    var GetCapacityManagerAttributesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetCapacityManagerAttributes", {}).n("EC2Client", "GetCapacityManagerAttributesCommand").sc(schemas_0.GetCapacityManagerAttributes$).build() {
      static {
        __name(this, "GetCapacityManagerAttributesCommand");
      }
    };
    var GetCapacityManagerMetricDataCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetCapacityManagerMetricData", {}).n("EC2Client", "GetCapacityManagerMetricDataCommand").sc(schemas_0.GetCapacityManagerMetricData$).build() {
      static {
        __name(this, "GetCapacityManagerMetricDataCommand");
      }
    };
    var GetCapacityManagerMetricDimensionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetCapacityManagerMetricDimensions", {}).n("EC2Client", "GetCapacityManagerMetricDimensionsCommand").sc(schemas_0.GetCapacityManagerMetricDimensions$).build() {
      static {
        __name(this, "GetCapacityManagerMetricDimensionsCommand");
      }
    };
    var GetCapacityManagerMonitoredTagKeysCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetCapacityManagerMonitoredTagKeys", {}).n("EC2Client", "GetCapacityManagerMonitoredTagKeysCommand").sc(schemas_0.GetCapacityManagerMonitoredTagKeys$).build() {
      static {
        __name(this, "GetCapacityManagerMonitoredTagKeysCommand");
      }
    };
    var GetCapacityReservationUsageCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetCapacityReservationUsage", {}).n("EC2Client", "GetCapacityReservationUsageCommand").sc(schemas_0.GetCapacityReservationUsage$).build() {
      static {
        __name(this, "GetCapacityReservationUsageCommand");
      }
    };
    var GetCoipPoolUsageCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetCoipPoolUsage", {}).n("EC2Client", "GetCoipPoolUsageCommand").sc(schemas_0.GetCoipPoolUsage$).build() {
      static {
        __name(this, "GetCoipPoolUsageCommand");
      }
    };
    var GetConsoleOutputCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetConsoleOutput", {}).n("EC2Client", "GetConsoleOutputCommand").sc(schemas_0.GetConsoleOutput$).build() {
      static {
        __name(this, "GetConsoleOutputCommand");
      }
    };
    var GetConsoleScreenshotCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetConsoleScreenshot", {}).n("EC2Client", "GetConsoleScreenshotCommand").sc(schemas_0.GetConsoleScreenshot$).build() {
      static {
        __name(this, "GetConsoleScreenshotCommand");
      }
    };
    var GetDeclarativePoliciesReportSummaryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetDeclarativePoliciesReportSummary", {}).n("EC2Client", "GetDeclarativePoliciesReportSummaryCommand").sc(schemas_0.GetDeclarativePoliciesReportSummary$).build() {
      static {
        __name(this, "GetDeclarativePoliciesReportSummaryCommand");
      }
    };
    var GetDefaultCreditSpecificationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetDefaultCreditSpecification", {}).n("EC2Client", "GetDefaultCreditSpecificationCommand").sc(schemas_0.GetDefaultCreditSpecification$).build() {
      static {
        __name(this, "GetDefaultCreditSpecificationCommand");
      }
    };
    var GetEbsDefaultKmsKeyIdCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetEbsDefaultKmsKeyId", {}).n("EC2Client", "GetEbsDefaultKmsKeyIdCommand").sc(schemas_0.GetEbsDefaultKmsKeyId$).build() {
      static {
        __name(this, "GetEbsDefaultKmsKeyIdCommand");
      }
    };
    var GetEbsEncryptionByDefaultCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetEbsEncryptionByDefault", {}).n("EC2Client", "GetEbsEncryptionByDefaultCommand").sc(schemas_0.GetEbsEncryptionByDefault$).build() {
      static {
        __name(this, "GetEbsEncryptionByDefaultCommand");
      }
    };
    var GetEnabledIpamPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetEnabledIpamPolicy", {}).n("EC2Client", "GetEnabledIpamPolicyCommand").sc(schemas_0.GetEnabledIpamPolicy$).build() {
      static {
        __name(this, "GetEnabledIpamPolicyCommand");
      }
    };
    var GetFlowLogsIntegrationTemplateCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetFlowLogsIntegrationTemplate", {}).n("EC2Client", "GetFlowLogsIntegrationTemplateCommand").sc(schemas_0.GetFlowLogsIntegrationTemplate$).build() {
      static {
        __name(this, "GetFlowLogsIntegrationTemplateCommand");
      }
    };
    var GetGroupsForCapacityReservationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetGroupsForCapacityReservation", {}).n("EC2Client", "GetGroupsForCapacityReservationCommand").sc(schemas_0.GetGroupsForCapacityReservation$).build() {
      static {
        __name(this, "GetGroupsForCapacityReservationCommand");
      }
    };
    var GetHostReservationPurchasePreviewCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetHostReservationPurchasePreview", {}).n("EC2Client", "GetHostReservationPurchasePreviewCommand").sc(schemas_0.GetHostReservationPurchasePreview$).build() {
      static {
        __name(this, "GetHostReservationPurchasePreviewCommand");
      }
    };
    var GetImageAncestryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetImageAncestry", {}).n("EC2Client", "GetImageAncestryCommand").sc(schemas_0.GetImageAncestry$).build() {
      static {
        __name(this, "GetImageAncestryCommand");
      }
    };
    var GetImageBlockPublicAccessStateCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetImageBlockPublicAccessState", {}).n("EC2Client", "GetImageBlockPublicAccessStateCommand").sc(schemas_0.GetImageBlockPublicAccessState$).build() {
      static {
        __name(this, "GetImageBlockPublicAccessStateCommand");
      }
    };
    var GetInstanceMetadataDefaultsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetInstanceMetadataDefaults", {}).n("EC2Client", "GetInstanceMetadataDefaultsCommand").sc(schemas_0.GetInstanceMetadataDefaults$).build() {
      static {
        __name(this, "GetInstanceMetadataDefaultsCommand");
      }
    };
    var GetInstanceTpmEkPubCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetInstanceTpmEkPub", {}).n("EC2Client", "GetInstanceTpmEkPubCommand").sc(schemas_0.GetInstanceTpmEkPub$).build() {
      static {
        __name(this, "GetInstanceTpmEkPubCommand");
      }
    };
    var GetInstanceTypesFromInstanceRequirementsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetInstanceTypesFromInstanceRequirements", {}).n("EC2Client", "GetInstanceTypesFromInstanceRequirementsCommand").sc(schemas_0.GetInstanceTypesFromInstanceRequirements$).build() {
      static {
        __name(this, "GetInstanceTypesFromInstanceRequirementsCommand");
      }
    };
    var GetInstanceUefiDataCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetInstanceUefiData", {}).n("EC2Client", "GetInstanceUefiDataCommand").sc(schemas_0.GetInstanceUefiData$).build() {
      static {
        __name(this, "GetInstanceUefiDataCommand");
      }
    };
    var GetIpamAddressHistoryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetIpamAddressHistory", {}).n("EC2Client", "GetIpamAddressHistoryCommand").sc(schemas_0.GetIpamAddressHistory$).build() {
      static {
        __name(this, "GetIpamAddressHistoryCommand");
      }
    };
    var GetIpamDiscoveredAccountsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetIpamDiscoveredAccounts", {}).n("EC2Client", "GetIpamDiscoveredAccountsCommand").sc(schemas_0.GetIpamDiscoveredAccounts$).build() {
      static {
        __name(this, "GetIpamDiscoveredAccountsCommand");
      }
    };
    var GetIpamDiscoveredPublicAddressesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetIpamDiscoveredPublicAddresses", {}).n("EC2Client", "GetIpamDiscoveredPublicAddressesCommand").sc(schemas_0.GetIpamDiscoveredPublicAddresses$).build() {
      static {
        __name(this, "GetIpamDiscoveredPublicAddressesCommand");
      }
    };
    var GetIpamDiscoveredResourceCidrsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetIpamDiscoveredResourceCidrs", {}).n("EC2Client", "GetIpamDiscoveredResourceCidrsCommand").sc(schemas_0.GetIpamDiscoveredResourceCidrs$).build() {
      static {
        __name(this, "GetIpamDiscoveredResourceCidrsCommand");
      }
    };
    var GetIpamPolicyAllocationRulesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetIpamPolicyAllocationRules", {}).n("EC2Client", "GetIpamPolicyAllocationRulesCommand").sc(schemas_0.GetIpamPolicyAllocationRules$).build() {
      static {
        __name(this, "GetIpamPolicyAllocationRulesCommand");
      }
    };
    var GetIpamPolicyOrganizationTargetsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetIpamPolicyOrganizationTargets", {}).n("EC2Client", "GetIpamPolicyOrganizationTargetsCommand").sc(schemas_0.GetIpamPolicyOrganizationTargets$).build() {
      static {
        __name(this, "GetIpamPolicyOrganizationTargetsCommand");
      }
    };
    var GetIpamPoolAllocationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetIpamPoolAllocations", {}).n("EC2Client", "GetIpamPoolAllocationsCommand").sc(schemas_0.GetIpamPoolAllocations$).build() {
      static {
        __name(this, "GetIpamPoolAllocationsCommand");
      }
    };
    var GetIpamPoolCidrsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetIpamPoolCidrs", {}).n("EC2Client", "GetIpamPoolCidrsCommand").sc(schemas_0.GetIpamPoolCidrs$).build() {
      static {
        __name(this, "GetIpamPoolCidrsCommand");
      }
    };
    var GetIpamPrefixListResolverRulesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetIpamPrefixListResolverRules", {}).n("EC2Client", "GetIpamPrefixListResolverRulesCommand").sc(schemas_0.GetIpamPrefixListResolverRules$).build() {
      static {
        __name(this, "GetIpamPrefixListResolverRulesCommand");
      }
    };
    var GetIpamPrefixListResolverVersionEntriesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetIpamPrefixListResolverVersionEntries", {}).n("EC2Client", "GetIpamPrefixListResolverVersionEntriesCommand").sc(schemas_0.GetIpamPrefixListResolverVersionEntries$).build() {
      static {
        __name(this, "GetIpamPrefixListResolverVersionEntriesCommand");
      }
    };
    var GetIpamPrefixListResolverVersionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetIpamPrefixListResolverVersions", {}).n("EC2Client", "GetIpamPrefixListResolverVersionsCommand").sc(schemas_0.GetIpamPrefixListResolverVersions$).build() {
      static {
        __name(this, "GetIpamPrefixListResolverVersionsCommand");
      }
    };
    var GetIpamResourceCidrsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetIpamResourceCidrs", {}).n("EC2Client", "GetIpamResourceCidrsCommand").sc(schemas_0.GetIpamResourceCidrs$).build() {
      static {
        __name(this, "GetIpamResourceCidrsCommand");
      }
    };
    var GetLaunchTemplateDataCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetLaunchTemplateData", {}).n("EC2Client", "GetLaunchTemplateDataCommand").sc(schemas_0.GetLaunchTemplateData$).build() {
      static {
        __name(this, "GetLaunchTemplateDataCommand");
      }
    };
    var GetManagedPrefixListAssociationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetManagedPrefixListAssociations", {}).n("EC2Client", "GetManagedPrefixListAssociationsCommand").sc(schemas_0.GetManagedPrefixListAssociations$).build() {
      static {
        __name(this, "GetManagedPrefixListAssociationsCommand");
      }
    };
    var GetManagedPrefixListEntriesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetManagedPrefixListEntries", {}).n("EC2Client", "GetManagedPrefixListEntriesCommand").sc(schemas_0.GetManagedPrefixListEntries$).build() {
      static {
        __name(this, "GetManagedPrefixListEntriesCommand");
      }
    };
    var GetManagedResourceVisibilityCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetManagedResourceVisibility", {}).n("EC2Client", "GetManagedResourceVisibilityCommand").sc(schemas_0.GetManagedResourceVisibility$).build() {
      static {
        __name(this, "GetManagedResourceVisibilityCommand");
      }
    };
    var GetNetworkInsightsAccessScopeAnalysisFindingsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetNetworkInsightsAccessScopeAnalysisFindings", {}).n("EC2Client", "GetNetworkInsightsAccessScopeAnalysisFindingsCommand").sc(schemas_0.GetNetworkInsightsAccessScopeAnalysisFindings$).build() {
      static {
        __name(this, "GetNetworkInsightsAccessScopeAnalysisFindingsCommand");
      }
    };
    var GetNetworkInsightsAccessScopeContentCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetNetworkInsightsAccessScopeContent", {}).n("EC2Client", "GetNetworkInsightsAccessScopeContentCommand").sc(schemas_0.GetNetworkInsightsAccessScopeContent$).build() {
      static {
        __name(this, "GetNetworkInsightsAccessScopeContentCommand");
      }
    };
    var GetPasswordDataCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetPasswordData", {}).n("EC2Client", "GetPasswordDataCommand").sc(schemas_0.GetPasswordData$).build() {
      static {
        __name(this, "GetPasswordDataCommand");
      }
    };
    var GetReservedInstancesExchangeQuoteCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetReservedInstancesExchangeQuote", {}).n("EC2Client", "GetReservedInstancesExchangeQuoteCommand").sc(schemas_0.GetReservedInstancesExchangeQuote$).build() {
      static {
        __name(this, "GetReservedInstancesExchangeQuoteCommand");
      }
    };
    var GetRouteServerAssociationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetRouteServerAssociations", {}).n("EC2Client", "GetRouteServerAssociationsCommand").sc(schemas_0.GetRouteServerAssociations$).build() {
      static {
        __name(this, "GetRouteServerAssociationsCommand");
      }
    };
    var GetRouteServerPropagationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetRouteServerPropagations", {}).n("EC2Client", "GetRouteServerPropagationsCommand").sc(schemas_0.GetRouteServerPropagations$).build() {
      static {
        __name(this, "GetRouteServerPropagationsCommand");
      }
    };
    var GetRouteServerRoutingDatabaseCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetRouteServerRoutingDatabase", {}).n("EC2Client", "GetRouteServerRoutingDatabaseCommand").sc(schemas_0.GetRouteServerRoutingDatabase$).build() {
      static {
        __name(this, "GetRouteServerRoutingDatabaseCommand");
      }
    };
    var GetSecurityGroupsForVpcCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetSecurityGroupsForVpc", {}).n("EC2Client", "GetSecurityGroupsForVpcCommand").sc(schemas_0.GetSecurityGroupsForVpc$).build() {
      static {
        __name(this, "GetSecurityGroupsForVpcCommand");
      }
    };
    var GetSerialConsoleAccessStatusCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetSerialConsoleAccessStatus", {}).n("EC2Client", "GetSerialConsoleAccessStatusCommand").sc(schemas_0.GetSerialConsoleAccessStatus$).build() {
      static {
        __name(this, "GetSerialConsoleAccessStatusCommand");
      }
    };
    var GetSnapshotBlockPublicAccessStateCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetSnapshotBlockPublicAccessState", {}).n("EC2Client", "GetSnapshotBlockPublicAccessStateCommand").sc(schemas_0.GetSnapshotBlockPublicAccessState$).build() {
      static {
        __name(this, "GetSnapshotBlockPublicAccessStateCommand");
      }
    };
    var GetSpotPlacementScoresCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetSpotPlacementScores", {}).n("EC2Client", "GetSpotPlacementScoresCommand").sc(schemas_0.GetSpotPlacementScores$).build() {
      static {
        __name(this, "GetSpotPlacementScoresCommand");
      }
    };
    var GetSubnetCidrReservationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetSubnetCidrReservations", {}).n("EC2Client", "GetSubnetCidrReservationsCommand").sc(schemas_0.GetSubnetCidrReservations$).build() {
      static {
        __name(this, "GetSubnetCidrReservationsCommand");
      }
    };
    var GetTransitGatewayAttachmentPropagationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetTransitGatewayAttachmentPropagations", {}).n("EC2Client", "GetTransitGatewayAttachmentPropagationsCommand").sc(schemas_0.GetTransitGatewayAttachmentPropagations$).build() {
      static {
        __name(this, "GetTransitGatewayAttachmentPropagationsCommand");
      }
    };
    var GetTransitGatewayMeteringPolicyEntriesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetTransitGatewayMeteringPolicyEntries", {}).n("EC2Client", "GetTransitGatewayMeteringPolicyEntriesCommand").sc(schemas_0.GetTransitGatewayMeteringPolicyEntries$).build() {
      static {
        __name(this, "GetTransitGatewayMeteringPolicyEntriesCommand");
      }
    };
    var GetTransitGatewayMulticastDomainAssociationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetTransitGatewayMulticastDomainAssociations", {}).n("EC2Client", "GetTransitGatewayMulticastDomainAssociationsCommand").sc(schemas_0.GetTransitGatewayMulticastDomainAssociations$).build() {
      static {
        __name(this, "GetTransitGatewayMulticastDomainAssociationsCommand");
      }
    };
    var GetTransitGatewayPolicyTableAssociationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetTransitGatewayPolicyTableAssociations", {}).n("EC2Client", "GetTransitGatewayPolicyTableAssociationsCommand").sc(schemas_0.GetTransitGatewayPolicyTableAssociations$).build() {
      static {
        __name(this, "GetTransitGatewayPolicyTableAssociationsCommand");
      }
    };
    var GetTransitGatewayPolicyTableEntriesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetTransitGatewayPolicyTableEntries", {}).n("EC2Client", "GetTransitGatewayPolicyTableEntriesCommand").sc(schemas_0.GetTransitGatewayPolicyTableEntries$).build() {
      static {
        __name(this, "GetTransitGatewayPolicyTableEntriesCommand");
      }
    };
    var GetTransitGatewayPrefixListReferencesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetTransitGatewayPrefixListReferences", {}).n("EC2Client", "GetTransitGatewayPrefixListReferencesCommand").sc(schemas_0.GetTransitGatewayPrefixListReferences$).build() {
      static {
        __name(this, "GetTransitGatewayPrefixListReferencesCommand");
      }
    };
    var GetTransitGatewayRouteTableAssociationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetTransitGatewayRouteTableAssociations", {}).n("EC2Client", "GetTransitGatewayRouteTableAssociationsCommand").sc(schemas_0.GetTransitGatewayRouteTableAssociations$).build() {
      static {
        __name(this, "GetTransitGatewayRouteTableAssociationsCommand");
      }
    };
    var GetTransitGatewayRouteTablePropagationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetTransitGatewayRouteTablePropagations", {}).n("EC2Client", "GetTransitGatewayRouteTablePropagationsCommand").sc(schemas_0.GetTransitGatewayRouteTablePropagations$).build() {
      static {
        __name(this, "GetTransitGatewayRouteTablePropagationsCommand");
      }
    };
    var GetVerifiedAccessEndpointPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetVerifiedAccessEndpointPolicy", {}).n("EC2Client", "GetVerifiedAccessEndpointPolicyCommand").sc(schemas_0.GetVerifiedAccessEndpointPolicy$).build() {
      static {
        __name(this, "GetVerifiedAccessEndpointPolicyCommand");
      }
    };
    var GetVerifiedAccessEndpointTargetsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetVerifiedAccessEndpointTargets", {}).n("EC2Client", "GetVerifiedAccessEndpointTargetsCommand").sc(schemas_0.GetVerifiedAccessEndpointTargets$).build() {
      static {
        __name(this, "GetVerifiedAccessEndpointTargetsCommand");
      }
    };
    var GetVerifiedAccessGroupPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetVerifiedAccessGroupPolicy", {}).n("EC2Client", "GetVerifiedAccessGroupPolicyCommand").sc(schemas_0.GetVerifiedAccessGroupPolicy$).build() {
      static {
        __name(this, "GetVerifiedAccessGroupPolicyCommand");
      }
    };
    var GetVpcResourcesBlockingEncryptionEnforcementCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetVpcResourcesBlockingEncryptionEnforcement", {}).n("EC2Client", "GetVpcResourcesBlockingEncryptionEnforcementCommand").sc(schemas_0.GetVpcResourcesBlockingEncryptionEnforcement$).build() {
      static {
        __name(this, "GetVpcResourcesBlockingEncryptionEnforcementCommand");
      }
    };
    var GetVpnConnectionDeviceSampleConfigurationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetVpnConnectionDeviceSampleConfiguration", {}).n("EC2Client", "GetVpnConnectionDeviceSampleConfigurationCommand").sc(schemas_0.GetVpnConnectionDeviceSampleConfiguration$).build() {
      static {
        __name(this, "GetVpnConnectionDeviceSampleConfigurationCommand");
      }
    };
    var GetVpnConnectionDeviceTypesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetVpnConnectionDeviceTypes", {}).n("EC2Client", "GetVpnConnectionDeviceTypesCommand").sc(schemas_0.GetVpnConnectionDeviceTypes$).build() {
      static {
        __name(this, "GetVpnConnectionDeviceTypesCommand");
      }
    };
    var GetVpnTunnelReplacementStatusCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "GetVpnTunnelReplacementStatus", {}).n("EC2Client", "GetVpnTunnelReplacementStatusCommand").sc(schemas_0.GetVpnTunnelReplacementStatus$).build() {
      static {
        __name(this, "GetVpnTunnelReplacementStatusCommand");
      }
    };
    var ImportClientVpnClientCertificateRevocationListCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ImportClientVpnClientCertificateRevocationList", {}).n("EC2Client", "ImportClientVpnClientCertificateRevocationListCommand").sc(schemas_0.ImportClientVpnClientCertificateRevocationList$).build() {
      static {
        __name(this, "ImportClientVpnClientCertificateRevocationListCommand");
      }
    };
    var ImportImageCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ImportImage", {}).n("EC2Client", "ImportImageCommand").sc(schemas_0.ImportImage$).build() {
      static {
        __name(this, "ImportImageCommand");
      }
    };
    var ImportInstanceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ImportInstance", {}).n("EC2Client", "ImportInstanceCommand").sc(schemas_0.ImportInstance$).build() {
      static {
        __name(this, "ImportInstanceCommand");
      }
    };
    var ImportKeyPairCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ImportKeyPair", {}).n("EC2Client", "ImportKeyPairCommand").sc(schemas_0.ImportKeyPair$).build() {
      static {
        __name(this, "ImportKeyPairCommand");
      }
    };
    var ImportSnapshotCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ImportSnapshot", {}).n("EC2Client", "ImportSnapshotCommand").sc(schemas_0.ImportSnapshot$).build() {
      static {
        __name(this, "ImportSnapshotCommand");
      }
    };
    var ImportVolumeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ImportVolume", {}).n("EC2Client", "ImportVolumeCommand").sc(schemas_0.ImportVolume$).build() {
      static {
        __name(this, "ImportVolumeCommand");
      }
    };
    var ListImagesInRecycleBinCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ListImagesInRecycleBin", {}).n("EC2Client", "ListImagesInRecycleBinCommand").sc(schemas_0.ListImagesInRecycleBin$).build() {
      static {
        __name(this, "ListImagesInRecycleBinCommand");
      }
    };
    var ListSnapshotsInRecycleBinCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ListSnapshotsInRecycleBin", {}).n("EC2Client", "ListSnapshotsInRecycleBinCommand").sc(schemas_0.ListSnapshotsInRecycleBin$).build() {
      static {
        __name(this, "ListSnapshotsInRecycleBinCommand");
      }
    };
    var ListVolumesInRecycleBinCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ListVolumesInRecycleBin", {}).n("EC2Client", "ListVolumesInRecycleBinCommand").sc(schemas_0.ListVolumesInRecycleBin$).build() {
      static {
        __name(this, "ListVolumesInRecycleBinCommand");
      }
    };
    var LockSnapshotCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "LockSnapshot", {}).n("EC2Client", "LockSnapshotCommand").sc(schemas_0.LockSnapshot$).build() {
      static {
        __name(this, "LockSnapshotCommand");
      }
    };
    var ModifyAddressAttributeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyAddressAttribute", {}).n("EC2Client", "ModifyAddressAttributeCommand").sc(schemas_0.ModifyAddressAttribute$).build() {
      static {
        __name(this, "ModifyAddressAttributeCommand");
      }
    };
    var ModifyAvailabilityZoneGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyAvailabilityZoneGroup", {}).n("EC2Client", "ModifyAvailabilityZoneGroupCommand").sc(schemas_0.ModifyAvailabilityZoneGroup$).build() {
      static {
        __name(this, "ModifyAvailabilityZoneGroupCommand");
      }
    };
    var ModifyCapacityReservationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyCapacityReservation", {}).n("EC2Client", "ModifyCapacityReservationCommand").sc(schemas_0.ModifyCapacityReservation$).build() {
      static {
        __name(this, "ModifyCapacityReservationCommand");
      }
    };
    var ModifyCapacityReservationFleetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyCapacityReservationFleet", {}).n("EC2Client", "ModifyCapacityReservationFleetCommand").sc(schemas_0.ModifyCapacityReservationFleet$).build() {
      static {
        __name(this, "ModifyCapacityReservationFleetCommand");
      }
    };
    var ModifyClientVpnEndpointCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyClientVpnEndpoint", {}).n("EC2Client", "ModifyClientVpnEndpointCommand").sc(schemas_0.ModifyClientVpnEndpoint$).build() {
      static {
        __name(this, "ModifyClientVpnEndpointCommand");
      }
    };
    var ModifyDefaultCreditSpecificationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyDefaultCreditSpecification", {}).n("EC2Client", "ModifyDefaultCreditSpecificationCommand").sc(schemas_0.ModifyDefaultCreditSpecification$).build() {
      static {
        __name(this, "ModifyDefaultCreditSpecificationCommand");
      }
    };
    var ModifyEbsDefaultKmsKeyIdCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyEbsDefaultKmsKeyId", {}).n("EC2Client", "ModifyEbsDefaultKmsKeyIdCommand").sc(schemas_0.ModifyEbsDefaultKmsKeyId$).build() {
      static {
        __name(this, "ModifyEbsDefaultKmsKeyIdCommand");
      }
    };
    var ModifyFleetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyFleet", {}).n("EC2Client", "ModifyFleetCommand").sc(schemas_0.ModifyFleet$).build() {
      static {
        __name(this, "ModifyFleetCommand");
      }
    };
    var ModifyFpgaImageAttributeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyFpgaImageAttribute", {}).n("EC2Client", "ModifyFpgaImageAttributeCommand").sc(schemas_0.ModifyFpgaImageAttribute$).build() {
      static {
        __name(this, "ModifyFpgaImageAttributeCommand");
      }
    };
    var ModifyHostsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyHosts", {}).n("EC2Client", "ModifyHostsCommand").sc(schemas_0.ModifyHosts$).build() {
      static {
        __name(this, "ModifyHostsCommand");
      }
    };
    var ModifyIdentityIdFormatCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyIdentityIdFormat", {}).n("EC2Client", "ModifyIdentityIdFormatCommand").sc(schemas_0.ModifyIdentityIdFormat$).build() {
      static {
        __name(this, "ModifyIdentityIdFormatCommand");
      }
    };
    var ModifyIdFormatCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyIdFormat", {}).n("EC2Client", "ModifyIdFormatCommand").sc(schemas_0.ModifyIdFormat$).build() {
      static {
        __name(this, "ModifyIdFormatCommand");
      }
    };
    var ModifyImageAttributeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyImageAttribute", {}).n("EC2Client", "ModifyImageAttributeCommand").sc(schemas_0.ModifyImageAttribute$).build() {
      static {
        __name(this, "ModifyImageAttributeCommand");
      }
    };
    var ModifyInstanceAttributeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyInstanceAttribute", {}).n("EC2Client", "ModifyInstanceAttributeCommand").sc(schemas_0.ModifyInstanceAttribute$).build() {
      static {
        __name(this, "ModifyInstanceAttributeCommand");
      }
    };
    var ModifyInstanceCapacityReservationAttributesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyInstanceCapacityReservationAttributes", {}).n("EC2Client", "ModifyInstanceCapacityReservationAttributesCommand").sc(schemas_0.ModifyInstanceCapacityReservationAttributes$).build() {
      static {
        __name(this, "ModifyInstanceCapacityReservationAttributesCommand");
      }
    };
    var ModifyInstanceConnectEndpointCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyInstanceConnectEndpoint", {}).n("EC2Client", "ModifyInstanceConnectEndpointCommand").sc(schemas_0.ModifyInstanceConnectEndpoint$).build() {
      static {
        __name(this, "ModifyInstanceConnectEndpointCommand");
      }
    };
    var ModifyInstanceCpuOptionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyInstanceCpuOptions", {}).n("EC2Client", "ModifyInstanceCpuOptionsCommand").sc(schemas_0.ModifyInstanceCpuOptions$).build() {
      static {
        __name(this, "ModifyInstanceCpuOptionsCommand");
      }
    };
    var ModifyInstanceCreditSpecificationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyInstanceCreditSpecification", {}).n("EC2Client", "ModifyInstanceCreditSpecificationCommand").sc(schemas_0.ModifyInstanceCreditSpecification$).build() {
      static {
        __name(this, "ModifyInstanceCreditSpecificationCommand");
      }
    };
    var ModifyInstanceEventStartTimeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyInstanceEventStartTime", {}).n("EC2Client", "ModifyInstanceEventStartTimeCommand").sc(schemas_0.ModifyInstanceEventStartTime$).build() {
      static {
        __name(this, "ModifyInstanceEventStartTimeCommand");
      }
    };
    var ModifyInstanceEventWindowCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyInstanceEventWindow", {}).n("EC2Client", "ModifyInstanceEventWindowCommand").sc(schemas_0.ModifyInstanceEventWindow$).build() {
      static {
        __name(this, "ModifyInstanceEventWindowCommand");
      }
    };
    var ModifyInstanceMaintenanceOptionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyInstanceMaintenanceOptions", {}).n("EC2Client", "ModifyInstanceMaintenanceOptionsCommand").sc(schemas_0.ModifyInstanceMaintenanceOptions$).build() {
      static {
        __name(this, "ModifyInstanceMaintenanceOptionsCommand");
      }
    };
    var ModifyInstanceMetadataDefaultsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyInstanceMetadataDefaults", {}).n("EC2Client", "ModifyInstanceMetadataDefaultsCommand").sc(schemas_0.ModifyInstanceMetadataDefaults$).build() {
      static {
        __name(this, "ModifyInstanceMetadataDefaultsCommand");
      }
    };
    var ModifyInstanceMetadataOptionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyInstanceMetadataOptions", {}).n("EC2Client", "ModifyInstanceMetadataOptionsCommand").sc(schemas_0.ModifyInstanceMetadataOptions$).build() {
      static {
        __name(this, "ModifyInstanceMetadataOptionsCommand");
      }
    };
    var ModifyInstanceNetworkPerformanceOptionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyInstanceNetworkPerformanceOptions", {}).n("EC2Client", "ModifyInstanceNetworkPerformanceOptionsCommand").sc(schemas_0.ModifyInstanceNetworkPerformanceOptions$).build() {
      static {
        __name(this, "ModifyInstanceNetworkPerformanceOptionsCommand");
      }
    };
    var ModifyInstancePlacementCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyInstancePlacement", {}).n("EC2Client", "ModifyInstancePlacementCommand").sc(schemas_0.ModifyInstancePlacement$).build() {
      static {
        __name(this, "ModifyInstancePlacementCommand");
      }
    };
    var ModifyIpamCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyIpam", {}).n("EC2Client", "ModifyIpamCommand").sc(schemas_0.ModifyIpam$).build() {
      static {
        __name(this, "ModifyIpamCommand");
      }
    };
    var ModifyIpamPolicyAllocationRulesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyIpamPolicyAllocationRules", {}).n("EC2Client", "ModifyIpamPolicyAllocationRulesCommand").sc(schemas_0.ModifyIpamPolicyAllocationRules$).build() {
      static {
        __name(this, "ModifyIpamPolicyAllocationRulesCommand");
      }
    };
    var ModifyIpamPoolCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyIpamPool", {}).n("EC2Client", "ModifyIpamPoolCommand").sc(schemas_0.ModifyIpamPool$).build() {
      static {
        __name(this, "ModifyIpamPoolCommand");
      }
    };
    var ModifyIpamPrefixListResolverCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyIpamPrefixListResolver", {}).n("EC2Client", "ModifyIpamPrefixListResolverCommand").sc(schemas_0.ModifyIpamPrefixListResolver$).build() {
      static {
        __name(this, "ModifyIpamPrefixListResolverCommand");
      }
    };
    var ModifyIpamPrefixListResolverTargetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyIpamPrefixListResolverTarget", {}).n("EC2Client", "ModifyIpamPrefixListResolverTargetCommand").sc(schemas_0.ModifyIpamPrefixListResolverTarget$).build() {
      static {
        __name(this, "ModifyIpamPrefixListResolverTargetCommand");
      }
    };
    var ModifyIpamResourceCidrCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyIpamResourceCidr", {}).n("EC2Client", "ModifyIpamResourceCidrCommand").sc(schemas_0.ModifyIpamResourceCidr$).build() {
      static {
        __name(this, "ModifyIpamResourceCidrCommand");
      }
    };
    var ModifyIpamResourceDiscoveryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyIpamResourceDiscovery", {}).n("EC2Client", "ModifyIpamResourceDiscoveryCommand").sc(schemas_0.ModifyIpamResourceDiscovery$).build() {
      static {
        __name(this, "ModifyIpamResourceDiscoveryCommand");
      }
    };
    var ModifyIpamScopeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyIpamScope", {}).n("EC2Client", "ModifyIpamScopeCommand").sc(schemas_0.ModifyIpamScope$).build() {
      static {
        __name(this, "ModifyIpamScopeCommand");
      }
    };
    var ModifyLaunchTemplateCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyLaunchTemplate", {}).n("EC2Client", "ModifyLaunchTemplateCommand").sc(schemas_0.ModifyLaunchTemplate$).build() {
      static {
        __name(this, "ModifyLaunchTemplateCommand");
      }
    };
    var ModifyLocalGatewayRouteCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyLocalGatewayRoute", {}).n("EC2Client", "ModifyLocalGatewayRouteCommand").sc(schemas_0.ModifyLocalGatewayRoute$).build() {
      static {
        __name(this, "ModifyLocalGatewayRouteCommand");
      }
    };
    var ModifyManagedPrefixListCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyManagedPrefixList", {}).n("EC2Client", "ModifyManagedPrefixListCommand").sc(schemas_0.ModifyManagedPrefixList$).build() {
      static {
        __name(this, "ModifyManagedPrefixListCommand");
      }
    };
    var ModifyManagedResourceVisibilityCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyManagedResourceVisibility", {}).n("EC2Client", "ModifyManagedResourceVisibilityCommand").sc(schemas_0.ModifyManagedResourceVisibility$).build() {
      static {
        __name(this, "ModifyManagedResourceVisibilityCommand");
      }
    };
    var ModifyNetworkInterfaceAttributeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyNetworkInterfaceAttribute", {}).n("EC2Client", "ModifyNetworkInterfaceAttributeCommand").sc(schemas_0.ModifyNetworkInterfaceAttribute$).build() {
      static {
        __name(this, "ModifyNetworkInterfaceAttributeCommand");
      }
    };
    var ModifyPrivateDnsNameOptionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyPrivateDnsNameOptions", {}).n("EC2Client", "ModifyPrivateDnsNameOptionsCommand").sc(schemas_0.ModifyPrivateDnsNameOptions$).build() {
      static {
        __name(this, "ModifyPrivateDnsNameOptionsCommand");
      }
    };
    var ModifyPublicIpDnsNameOptionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyPublicIpDnsNameOptions", {}).n("EC2Client", "ModifyPublicIpDnsNameOptionsCommand").sc(schemas_0.ModifyPublicIpDnsNameOptions$).build() {
      static {
        __name(this, "ModifyPublicIpDnsNameOptionsCommand");
      }
    };
    var ModifyReservedInstancesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyReservedInstances", {}).n("EC2Client", "ModifyReservedInstancesCommand").sc(schemas_0.ModifyReservedInstances$).build() {
      static {
        __name(this, "ModifyReservedInstancesCommand");
      }
    };
    var ModifyRouteServerCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyRouteServer", {}).n("EC2Client", "ModifyRouteServerCommand").sc(schemas_0.ModifyRouteServer$).build() {
      static {
        __name(this, "ModifyRouteServerCommand");
      }
    };
    var ModifySecurityGroupRulesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifySecurityGroupRules", {}).n("EC2Client", "ModifySecurityGroupRulesCommand").sc(schemas_0.ModifySecurityGroupRules$).build() {
      static {
        __name(this, "ModifySecurityGroupRulesCommand");
      }
    };
    var ModifySnapshotAttributeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifySnapshotAttribute", {}).n("EC2Client", "ModifySnapshotAttributeCommand").sc(schemas_0.ModifySnapshotAttribute$).build() {
      static {
        __name(this, "ModifySnapshotAttributeCommand");
      }
    };
    var ModifySnapshotTierCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifySnapshotTier", {}).n("EC2Client", "ModifySnapshotTierCommand").sc(schemas_0.ModifySnapshotTier$).build() {
      static {
        __name(this, "ModifySnapshotTierCommand");
      }
    };
    var ModifySpotFleetRequestCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifySpotFleetRequest", {}).n("EC2Client", "ModifySpotFleetRequestCommand").sc(schemas_0.ModifySpotFleetRequest$).build() {
      static {
        __name(this, "ModifySpotFleetRequestCommand");
      }
    };
    var ModifySubnetAttributeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifySubnetAttribute", {}).n("EC2Client", "ModifySubnetAttributeCommand").sc(schemas_0.ModifySubnetAttribute$).build() {
      static {
        __name(this, "ModifySubnetAttributeCommand");
      }
    };
    var ModifyTrafficMirrorFilterNetworkServicesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyTrafficMirrorFilterNetworkServices", {}).n("EC2Client", "ModifyTrafficMirrorFilterNetworkServicesCommand").sc(schemas_0.ModifyTrafficMirrorFilterNetworkServices$).build() {
      static {
        __name(this, "ModifyTrafficMirrorFilterNetworkServicesCommand");
      }
    };
    var ModifyTrafficMirrorFilterRuleCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyTrafficMirrorFilterRule", {}).n("EC2Client", "ModifyTrafficMirrorFilterRuleCommand").sc(schemas_0.ModifyTrafficMirrorFilterRule$).build() {
      static {
        __name(this, "ModifyTrafficMirrorFilterRuleCommand");
      }
    };
    var ModifyTrafficMirrorSessionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyTrafficMirrorSession", {}).n("EC2Client", "ModifyTrafficMirrorSessionCommand").sc(schemas_0.ModifyTrafficMirrorSession$).build() {
      static {
        __name(this, "ModifyTrafficMirrorSessionCommand");
      }
    };
    var ModifyTransitGatewayCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyTransitGateway", {}).n("EC2Client", "ModifyTransitGatewayCommand").sc(schemas_0.ModifyTransitGateway$).build() {
      static {
        __name(this, "ModifyTransitGatewayCommand");
      }
    };
    var ModifyTransitGatewayMeteringPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyTransitGatewayMeteringPolicy", {}).n("EC2Client", "ModifyTransitGatewayMeteringPolicyCommand").sc(schemas_0.ModifyTransitGatewayMeteringPolicy$).build() {
      static {
        __name(this, "ModifyTransitGatewayMeteringPolicyCommand");
      }
    };
    var ModifyTransitGatewayPrefixListReferenceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyTransitGatewayPrefixListReference", {}).n("EC2Client", "ModifyTransitGatewayPrefixListReferenceCommand").sc(schemas_0.ModifyTransitGatewayPrefixListReference$).build() {
      static {
        __name(this, "ModifyTransitGatewayPrefixListReferenceCommand");
      }
    };
    var ModifyTransitGatewayVpcAttachmentCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyTransitGatewayVpcAttachment", {}).n("EC2Client", "ModifyTransitGatewayVpcAttachmentCommand").sc(schemas_0.ModifyTransitGatewayVpcAttachment$).build() {
      static {
        __name(this, "ModifyTransitGatewayVpcAttachmentCommand");
      }
    };
    var ModifyVerifiedAccessEndpointCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyVerifiedAccessEndpoint", {}).n("EC2Client", "ModifyVerifiedAccessEndpointCommand").sc(schemas_0.ModifyVerifiedAccessEndpoint$).build() {
      static {
        __name(this, "ModifyVerifiedAccessEndpointCommand");
      }
    };
    var ModifyVerifiedAccessEndpointPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyVerifiedAccessEndpointPolicy", {}).n("EC2Client", "ModifyVerifiedAccessEndpointPolicyCommand").sc(schemas_0.ModifyVerifiedAccessEndpointPolicy$).build() {
      static {
        __name(this, "ModifyVerifiedAccessEndpointPolicyCommand");
      }
    };
    var ModifyVerifiedAccessGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyVerifiedAccessGroup", {}).n("EC2Client", "ModifyVerifiedAccessGroupCommand").sc(schemas_0.ModifyVerifiedAccessGroup$).build() {
      static {
        __name(this, "ModifyVerifiedAccessGroupCommand");
      }
    };
    var ModifyVerifiedAccessGroupPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyVerifiedAccessGroupPolicy", {}).n("EC2Client", "ModifyVerifiedAccessGroupPolicyCommand").sc(schemas_0.ModifyVerifiedAccessGroupPolicy$).build() {
      static {
        __name(this, "ModifyVerifiedAccessGroupPolicyCommand");
      }
    };
    var ModifyVerifiedAccessInstanceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyVerifiedAccessInstance", {}).n("EC2Client", "ModifyVerifiedAccessInstanceCommand").sc(schemas_0.ModifyVerifiedAccessInstance$).build() {
      static {
        __name(this, "ModifyVerifiedAccessInstanceCommand");
      }
    };
    var ModifyVerifiedAccessInstanceLoggingConfigurationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyVerifiedAccessInstanceLoggingConfiguration", {}).n("EC2Client", "ModifyVerifiedAccessInstanceLoggingConfigurationCommand").sc(schemas_0.ModifyVerifiedAccessInstanceLoggingConfiguration$).build() {
      static {
        __name(this, "ModifyVerifiedAccessInstanceLoggingConfigurationCommand");
      }
    };
    var ModifyVerifiedAccessTrustProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyVerifiedAccessTrustProvider", {}).n("EC2Client", "ModifyVerifiedAccessTrustProviderCommand").sc(schemas_0.ModifyVerifiedAccessTrustProvider$).build() {
      static {
        __name(this, "ModifyVerifiedAccessTrustProviderCommand");
      }
    };
    var ModifyVolumeAttributeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyVolumeAttribute", {}).n("EC2Client", "ModifyVolumeAttributeCommand").sc(schemas_0.ModifyVolumeAttribute$).build() {
      static {
        __name(this, "ModifyVolumeAttributeCommand");
      }
    };
    var ModifyVolumeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyVolume", {}).n("EC2Client", "ModifyVolumeCommand").sc(schemas_0.ModifyVolume$).build() {
      static {
        __name(this, "ModifyVolumeCommand");
      }
    };
    var ModifyVpcAttributeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyVpcAttribute", {}).n("EC2Client", "ModifyVpcAttributeCommand").sc(schemas_0.ModifyVpcAttribute$).build() {
      static {
        __name(this, "ModifyVpcAttributeCommand");
      }
    };
    var ModifyVpcBlockPublicAccessExclusionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyVpcBlockPublicAccessExclusion", {}).n("EC2Client", "ModifyVpcBlockPublicAccessExclusionCommand").sc(schemas_0.ModifyVpcBlockPublicAccessExclusion$).build() {
      static {
        __name(this, "ModifyVpcBlockPublicAccessExclusionCommand");
      }
    };
    var ModifyVpcBlockPublicAccessOptionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyVpcBlockPublicAccessOptions", {}).n("EC2Client", "ModifyVpcBlockPublicAccessOptionsCommand").sc(schemas_0.ModifyVpcBlockPublicAccessOptions$).build() {
      static {
        __name(this, "ModifyVpcBlockPublicAccessOptionsCommand");
      }
    };
    var ModifyVpcEncryptionControlCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyVpcEncryptionControl", {}).n("EC2Client", "ModifyVpcEncryptionControlCommand").sc(schemas_0.ModifyVpcEncryptionControl$).build() {
      static {
        __name(this, "ModifyVpcEncryptionControlCommand");
      }
    };
    var ModifyVpcEndpointCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyVpcEndpoint", {}).n("EC2Client", "ModifyVpcEndpointCommand").sc(schemas_0.ModifyVpcEndpoint$).build() {
      static {
        __name(this, "ModifyVpcEndpointCommand");
      }
    };
    var ModifyVpcEndpointConnectionNotificationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyVpcEndpointConnectionNotification", {}).n("EC2Client", "ModifyVpcEndpointConnectionNotificationCommand").sc(schemas_0.ModifyVpcEndpointConnectionNotification$).build() {
      static {
        __name(this, "ModifyVpcEndpointConnectionNotificationCommand");
      }
    };
    var ModifyVpcEndpointServiceConfigurationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyVpcEndpointServiceConfiguration", {}).n("EC2Client", "ModifyVpcEndpointServiceConfigurationCommand").sc(schemas_0.ModifyVpcEndpointServiceConfiguration$).build() {
      static {
        __name(this, "ModifyVpcEndpointServiceConfigurationCommand");
      }
    };
    var ModifyVpcEndpointServicePayerResponsibilityCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyVpcEndpointServicePayerResponsibility", {}).n("EC2Client", "ModifyVpcEndpointServicePayerResponsibilityCommand").sc(schemas_0.ModifyVpcEndpointServicePayerResponsibility$).build() {
      static {
        __name(this, "ModifyVpcEndpointServicePayerResponsibilityCommand");
      }
    };
    var ModifyVpcEndpointServicePermissionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyVpcEndpointServicePermissions", {}).n("EC2Client", "ModifyVpcEndpointServicePermissionsCommand").sc(schemas_0.ModifyVpcEndpointServicePermissions$).build() {
      static {
        __name(this, "ModifyVpcEndpointServicePermissionsCommand");
      }
    };
    var ModifyVpcPeeringConnectionOptionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyVpcPeeringConnectionOptions", {}).n("EC2Client", "ModifyVpcPeeringConnectionOptionsCommand").sc(schemas_0.ModifyVpcPeeringConnectionOptions$).build() {
      static {
        __name(this, "ModifyVpcPeeringConnectionOptionsCommand");
      }
    };
    var ModifyVpcTenancyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyVpcTenancy", {}).n("EC2Client", "ModifyVpcTenancyCommand").sc(schemas_0.ModifyVpcTenancy$).build() {
      static {
        __name(this, "ModifyVpcTenancyCommand");
      }
    };
    var ModifyVpnConnectionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyVpnConnection", {}).n("EC2Client", "ModifyVpnConnectionCommand").sc(schemas_0.ModifyVpnConnection$).build() {
      static {
        __name(this, "ModifyVpnConnectionCommand");
      }
    };
    var ModifyVpnConnectionOptionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyVpnConnectionOptions", {}).n("EC2Client", "ModifyVpnConnectionOptionsCommand").sc(schemas_0.ModifyVpnConnectionOptions$).build() {
      static {
        __name(this, "ModifyVpnConnectionOptionsCommand");
      }
    };
    var ModifyVpnTunnelCertificateCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyVpnTunnelCertificate", {}).n("EC2Client", "ModifyVpnTunnelCertificateCommand").sc(schemas_0.ModifyVpnTunnelCertificate$).build() {
      static {
        __name(this, "ModifyVpnTunnelCertificateCommand");
      }
    };
    var ModifyVpnTunnelOptionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ModifyVpnTunnelOptions", {}).n("EC2Client", "ModifyVpnTunnelOptionsCommand").sc(schemas_0.ModifyVpnTunnelOptions$).build() {
      static {
        __name(this, "ModifyVpnTunnelOptionsCommand");
      }
    };
    var MonitorInstancesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "MonitorInstances", {}).n("EC2Client", "MonitorInstancesCommand").sc(schemas_0.MonitorInstances$).build() {
      static {
        __name(this, "MonitorInstancesCommand");
      }
    };
    var MoveAddressToVpcCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "MoveAddressToVpc", {}).n("EC2Client", "MoveAddressToVpcCommand").sc(schemas_0.MoveAddressToVpc$).build() {
      static {
        __name(this, "MoveAddressToVpcCommand");
      }
    };
    var MoveByoipCidrToIpamCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "MoveByoipCidrToIpam", {}).n("EC2Client", "MoveByoipCidrToIpamCommand").sc(schemas_0.MoveByoipCidrToIpam$).build() {
      static {
        __name(this, "MoveByoipCidrToIpamCommand");
      }
    };
    var MoveCapacityReservationInstancesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "MoveCapacityReservationInstances", {}).n("EC2Client", "MoveCapacityReservationInstancesCommand").sc(schemas_0.MoveCapacityReservationInstances$).build() {
      static {
        __name(this, "MoveCapacityReservationInstancesCommand");
      }
    };
    var ProvisionByoipCidrCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ProvisionByoipCidr", {}).n("EC2Client", "ProvisionByoipCidrCommand").sc(schemas_0.ProvisionByoipCidr$).build() {
      static {
        __name(this, "ProvisionByoipCidrCommand");
      }
    };
    var ProvisionIpamByoasnCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ProvisionIpamByoasn", {}).n("EC2Client", "ProvisionIpamByoasnCommand").sc(schemas_0.ProvisionIpamByoasn$).build() {
      static {
        __name(this, "ProvisionIpamByoasnCommand");
      }
    };
    var ProvisionIpamPoolCidrCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ProvisionIpamPoolCidr", {}).n("EC2Client", "ProvisionIpamPoolCidrCommand").sc(schemas_0.ProvisionIpamPoolCidr$).build() {
      static {
        __name(this, "ProvisionIpamPoolCidrCommand");
      }
    };
    var ProvisionPublicIpv4PoolCidrCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ProvisionPublicIpv4PoolCidr", {}).n("EC2Client", "ProvisionPublicIpv4PoolCidrCommand").sc(schemas_0.ProvisionPublicIpv4PoolCidr$).build() {
      static {
        __name(this, "ProvisionPublicIpv4PoolCidrCommand");
      }
    };
    var PurchaseCapacityBlockCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "PurchaseCapacityBlock", {}).n("EC2Client", "PurchaseCapacityBlockCommand").sc(schemas_0.PurchaseCapacityBlock$).build() {
      static {
        __name(this, "PurchaseCapacityBlockCommand");
      }
    };
    var PurchaseCapacityBlockExtensionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "PurchaseCapacityBlockExtension", {}).n("EC2Client", "PurchaseCapacityBlockExtensionCommand").sc(schemas_0.PurchaseCapacityBlockExtension$).build() {
      static {
        __name(this, "PurchaseCapacityBlockExtensionCommand");
      }
    };
    var PurchaseHostReservationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "PurchaseHostReservation", {}).n("EC2Client", "PurchaseHostReservationCommand").sc(schemas_0.PurchaseHostReservation$).build() {
      static {
        __name(this, "PurchaseHostReservationCommand");
      }
    };
    var PurchaseReservedInstancesOfferingCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "PurchaseReservedInstancesOffering", {}).n("EC2Client", "PurchaseReservedInstancesOfferingCommand").sc(schemas_0.PurchaseReservedInstancesOffering$).build() {
      static {
        __name(this, "PurchaseReservedInstancesOfferingCommand");
      }
    };
    var PurchaseScheduledInstancesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "PurchaseScheduledInstances", {}).n("EC2Client", "PurchaseScheduledInstancesCommand").sc(schemas_0.PurchaseScheduledInstances$).build() {
      static {
        __name(this, "PurchaseScheduledInstancesCommand");
      }
    };
    var RebootInstancesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "RebootInstances", {}).n("EC2Client", "RebootInstancesCommand").sc(schemas_0.RebootInstances$).build() {
      static {
        __name(this, "RebootInstancesCommand");
      }
    };
    var RegisterImageCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "RegisterImage", {}).n("EC2Client", "RegisterImageCommand").sc(schemas_0.RegisterImage$).build() {
      static {
        __name(this, "RegisterImageCommand");
      }
    };
    var RegisterInstanceEventNotificationAttributesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "RegisterInstanceEventNotificationAttributes", {}).n("EC2Client", "RegisterInstanceEventNotificationAttributesCommand").sc(schemas_0.RegisterInstanceEventNotificationAttributes$).build() {
      static {
        __name(this, "RegisterInstanceEventNotificationAttributesCommand");
      }
    };
    var RegisterTransitGatewayMulticastGroupMembersCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "RegisterTransitGatewayMulticastGroupMembers", {}).n("EC2Client", "RegisterTransitGatewayMulticastGroupMembersCommand").sc(schemas_0.RegisterTransitGatewayMulticastGroupMembers$).build() {
      static {
        __name(this, "RegisterTransitGatewayMulticastGroupMembersCommand");
      }
    };
    var RegisterTransitGatewayMulticastGroupSourcesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "RegisterTransitGatewayMulticastGroupSources", {}).n("EC2Client", "RegisterTransitGatewayMulticastGroupSourcesCommand").sc(schemas_0.RegisterTransitGatewayMulticastGroupSources$).build() {
      static {
        __name(this, "RegisterTransitGatewayMulticastGroupSourcesCommand");
      }
    };
    var RejectCapacityReservationBillingOwnershipCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "RejectCapacityReservationBillingOwnership", {}).n("EC2Client", "RejectCapacityReservationBillingOwnershipCommand").sc(schemas_0.RejectCapacityReservationBillingOwnership$).build() {
      static {
        __name(this, "RejectCapacityReservationBillingOwnershipCommand");
      }
    };
    var RejectTransitGatewayClientVpnAttachmentCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "RejectTransitGatewayClientVpnAttachment", {}).n("EC2Client", "RejectTransitGatewayClientVpnAttachmentCommand").sc(schemas_0.RejectTransitGatewayClientVpnAttachment$).build() {
      static {
        __name(this, "RejectTransitGatewayClientVpnAttachmentCommand");
      }
    };
    var RejectTransitGatewayMulticastDomainAssociationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "RejectTransitGatewayMulticastDomainAssociations", {}).n("EC2Client", "RejectTransitGatewayMulticastDomainAssociationsCommand").sc(schemas_0.RejectTransitGatewayMulticastDomainAssociations$).build() {
      static {
        __name(this, "RejectTransitGatewayMulticastDomainAssociationsCommand");
      }
    };
    var RejectTransitGatewayPeeringAttachmentCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "RejectTransitGatewayPeeringAttachment", {}).n("EC2Client", "RejectTransitGatewayPeeringAttachmentCommand").sc(schemas_0.RejectTransitGatewayPeeringAttachment$).build() {
      static {
        __name(this, "RejectTransitGatewayPeeringAttachmentCommand");
      }
    };
    var RejectTransitGatewayVpcAttachmentCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "RejectTransitGatewayVpcAttachment", {}).n("EC2Client", "RejectTransitGatewayVpcAttachmentCommand").sc(schemas_0.RejectTransitGatewayVpcAttachment$).build() {
      static {
        __name(this, "RejectTransitGatewayVpcAttachmentCommand");
      }
    };
    var RejectVpcEndpointConnectionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "RejectVpcEndpointConnections", {}).n("EC2Client", "RejectVpcEndpointConnectionsCommand").sc(schemas_0.RejectVpcEndpointConnections$).build() {
      static {
        __name(this, "RejectVpcEndpointConnectionsCommand");
      }
    };
    var RejectVpcPeeringConnectionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "RejectVpcPeeringConnection", {}).n("EC2Client", "RejectVpcPeeringConnectionCommand").sc(schemas_0.RejectVpcPeeringConnection$).build() {
      static {
        __name(this, "RejectVpcPeeringConnectionCommand");
      }
    };
    var ReleaseAddressCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ReleaseAddress", {}).n("EC2Client", "ReleaseAddressCommand").sc(schemas_0.ReleaseAddress$).build() {
      static {
        __name(this, "ReleaseAddressCommand");
      }
    };
    var ReleaseHostsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ReleaseHosts", {}).n("EC2Client", "ReleaseHostsCommand").sc(schemas_0.ReleaseHosts$).build() {
      static {
        __name(this, "ReleaseHostsCommand");
      }
    };
    var ReleaseIpamPoolAllocationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ReleaseIpamPoolAllocation", {}).n("EC2Client", "ReleaseIpamPoolAllocationCommand").sc(schemas_0.ReleaseIpamPoolAllocation$).build() {
      static {
        __name(this, "ReleaseIpamPoolAllocationCommand");
      }
    };
    var ReplaceIamInstanceProfileAssociationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ReplaceIamInstanceProfileAssociation", {}).n("EC2Client", "ReplaceIamInstanceProfileAssociationCommand").sc(schemas_0.ReplaceIamInstanceProfileAssociation$).build() {
      static {
        __name(this, "ReplaceIamInstanceProfileAssociationCommand");
      }
    };
    var ReplaceImageCriteriaInAllowedImagesSettingsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ReplaceImageCriteriaInAllowedImagesSettings", {}).n("EC2Client", "ReplaceImageCriteriaInAllowedImagesSettingsCommand").sc(schemas_0.ReplaceImageCriteriaInAllowedImagesSettings$).build() {
      static {
        __name(this, "ReplaceImageCriteriaInAllowedImagesSettingsCommand");
      }
    };
    var ReplaceNetworkAclAssociationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ReplaceNetworkAclAssociation", {}).n("EC2Client", "ReplaceNetworkAclAssociationCommand").sc(schemas_0.ReplaceNetworkAclAssociation$).build() {
      static {
        __name(this, "ReplaceNetworkAclAssociationCommand");
      }
    };
    var ReplaceNetworkAclEntryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ReplaceNetworkAclEntry", {}).n("EC2Client", "ReplaceNetworkAclEntryCommand").sc(schemas_0.ReplaceNetworkAclEntry$).build() {
      static {
        __name(this, "ReplaceNetworkAclEntryCommand");
      }
    };
    var ReplaceRouteCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ReplaceRoute", {}).n("EC2Client", "ReplaceRouteCommand").sc(schemas_0.ReplaceRoute$).build() {
      static {
        __name(this, "ReplaceRouteCommand");
      }
    };
    var ReplaceRouteTableAssociationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ReplaceRouteTableAssociation", {}).n("EC2Client", "ReplaceRouteTableAssociationCommand").sc(schemas_0.ReplaceRouteTableAssociation$).build() {
      static {
        __name(this, "ReplaceRouteTableAssociationCommand");
      }
    };
    var ReplaceTransitGatewayRouteCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ReplaceTransitGatewayRoute", {}).n("EC2Client", "ReplaceTransitGatewayRouteCommand").sc(schemas_0.ReplaceTransitGatewayRoute$).build() {
      static {
        __name(this, "ReplaceTransitGatewayRouteCommand");
      }
    };
    var ReplaceVpnTunnelCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ReplaceVpnTunnel", {}).n("EC2Client", "ReplaceVpnTunnelCommand").sc(schemas_0.ReplaceVpnTunnel$).build() {
      static {
        __name(this, "ReplaceVpnTunnelCommand");
      }
    };
    var ReportInstanceStatusCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ReportInstanceStatus", {}).n("EC2Client", "ReportInstanceStatusCommand").sc(schemas_0.ReportInstanceStatus$).build() {
      static {
        __name(this, "ReportInstanceStatusCommand");
      }
    };
    var RequestSpotFleetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "RequestSpotFleet", {}).n("EC2Client", "RequestSpotFleetCommand").sc(schemas_0.RequestSpotFleet$).build() {
      static {
        __name(this, "RequestSpotFleetCommand");
      }
    };
    var RequestSpotInstancesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "RequestSpotInstances", {}).n("EC2Client", "RequestSpotInstancesCommand").sc(schemas_0.RequestSpotInstances$).build() {
      static {
        __name(this, "RequestSpotInstancesCommand");
      }
    };
    var ResetAddressAttributeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ResetAddressAttribute", {}).n("EC2Client", "ResetAddressAttributeCommand").sc(schemas_0.ResetAddressAttribute$).build() {
      static {
        __name(this, "ResetAddressAttributeCommand");
      }
    };
    var ResetEbsDefaultKmsKeyIdCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ResetEbsDefaultKmsKeyId", {}).n("EC2Client", "ResetEbsDefaultKmsKeyIdCommand").sc(schemas_0.ResetEbsDefaultKmsKeyId$).build() {
      static {
        __name(this, "ResetEbsDefaultKmsKeyIdCommand");
      }
    };
    var ResetFpgaImageAttributeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ResetFpgaImageAttribute", {}).n("EC2Client", "ResetFpgaImageAttributeCommand").sc(schemas_0.ResetFpgaImageAttribute$).build() {
      static {
        __name(this, "ResetFpgaImageAttributeCommand");
      }
    };
    var ResetImageAttributeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ResetImageAttribute", {}).n("EC2Client", "ResetImageAttributeCommand").sc(schemas_0.ResetImageAttribute$).build() {
      static {
        __name(this, "ResetImageAttributeCommand");
      }
    };
    var ResetInstanceAttributeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ResetInstanceAttribute", {}).n("EC2Client", "ResetInstanceAttributeCommand").sc(schemas_0.ResetInstanceAttribute$).build() {
      static {
        __name(this, "ResetInstanceAttributeCommand");
      }
    };
    var ResetNetworkInterfaceAttributeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ResetNetworkInterfaceAttribute", {}).n("EC2Client", "ResetNetworkInterfaceAttributeCommand").sc(schemas_0.ResetNetworkInterfaceAttribute$).build() {
      static {
        __name(this, "ResetNetworkInterfaceAttributeCommand");
      }
    };
    var ResetSnapshotAttributeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "ResetSnapshotAttribute", {}).n("EC2Client", "ResetSnapshotAttributeCommand").sc(schemas_0.ResetSnapshotAttribute$).build() {
      static {
        __name(this, "ResetSnapshotAttributeCommand");
      }
    };
    var RestoreAddressToClassicCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "RestoreAddressToClassic", {}).n("EC2Client", "RestoreAddressToClassicCommand").sc(schemas_0.RestoreAddressToClassic$).build() {
      static {
        __name(this, "RestoreAddressToClassicCommand");
      }
    };
    var RestoreImageFromRecycleBinCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "RestoreImageFromRecycleBin", {}).n("EC2Client", "RestoreImageFromRecycleBinCommand").sc(schemas_0.RestoreImageFromRecycleBin$).build() {
      static {
        __name(this, "RestoreImageFromRecycleBinCommand");
      }
    };
    var RestoreManagedPrefixListVersionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "RestoreManagedPrefixListVersion", {}).n("EC2Client", "RestoreManagedPrefixListVersionCommand").sc(schemas_0.RestoreManagedPrefixListVersion$).build() {
      static {
        __name(this, "RestoreManagedPrefixListVersionCommand");
      }
    };
    var RestoreSnapshotFromRecycleBinCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "RestoreSnapshotFromRecycleBin", {}).n("EC2Client", "RestoreSnapshotFromRecycleBinCommand").sc(schemas_0.RestoreSnapshotFromRecycleBin$).build() {
      static {
        __name(this, "RestoreSnapshotFromRecycleBinCommand");
      }
    };
    var RestoreSnapshotTierCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "RestoreSnapshotTier", {}).n("EC2Client", "RestoreSnapshotTierCommand").sc(schemas_0.RestoreSnapshotTier$).build() {
      static {
        __name(this, "RestoreSnapshotTierCommand");
      }
    };
    var RestoreVolumeFromRecycleBinCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "RestoreVolumeFromRecycleBin", {}).n("EC2Client", "RestoreVolumeFromRecycleBinCommand").sc(schemas_0.RestoreVolumeFromRecycleBin$).build() {
      static {
        __name(this, "RestoreVolumeFromRecycleBinCommand");
      }
    };
    var RevokeClientVpnIngressCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "RevokeClientVpnIngress", {}).n("EC2Client", "RevokeClientVpnIngressCommand").sc(schemas_0.RevokeClientVpnIngress$).build() {
      static {
        __name(this, "RevokeClientVpnIngressCommand");
      }
    };
    var RevokeSecurityGroupEgressCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "RevokeSecurityGroupEgress", {}).n("EC2Client", "RevokeSecurityGroupEgressCommand").sc(schemas_0.RevokeSecurityGroupEgress$).build() {
      static {
        __name(this, "RevokeSecurityGroupEgressCommand");
      }
    };
    var RevokeSecurityGroupIngressCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "RevokeSecurityGroupIngress", {}).n("EC2Client", "RevokeSecurityGroupIngressCommand").sc(schemas_0.RevokeSecurityGroupIngress$).build() {
      static {
        __name(this, "RevokeSecurityGroupIngressCommand");
      }
    };
    var RunInstancesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "RunInstances", {}).n("EC2Client", "RunInstancesCommand").sc(schemas_0.RunInstances$).build() {
      static {
        __name(this, "RunInstancesCommand");
      }
    };
    var RunScheduledInstancesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "RunScheduledInstances", {}).n("EC2Client", "RunScheduledInstancesCommand").sc(schemas_0.RunScheduledInstances$).build() {
      static {
        __name(this, "RunScheduledInstancesCommand");
      }
    };
    var SearchLocalGatewayRoutesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "SearchLocalGatewayRoutes", {}).n("EC2Client", "SearchLocalGatewayRoutesCommand").sc(schemas_0.SearchLocalGatewayRoutes$).build() {
      static {
        __name(this, "SearchLocalGatewayRoutesCommand");
      }
    };
    var SearchTransitGatewayMulticastGroupsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "SearchTransitGatewayMulticastGroups", {}).n("EC2Client", "SearchTransitGatewayMulticastGroupsCommand").sc(schemas_0.SearchTransitGatewayMulticastGroups$).build() {
      static {
        __name(this, "SearchTransitGatewayMulticastGroupsCommand");
      }
    };
    var SearchTransitGatewayRoutesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "SearchTransitGatewayRoutes", {}).n("EC2Client", "SearchTransitGatewayRoutesCommand").sc(schemas_0.SearchTransitGatewayRoutes$).build() {
      static {
        __name(this, "SearchTransitGatewayRoutesCommand");
      }
    };
    var SendDiagnosticInterruptCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "SendDiagnosticInterrupt", {}).n("EC2Client", "SendDiagnosticInterruptCommand").sc(schemas_0.SendDiagnosticInterrupt$).build() {
      static {
        __name(this, "SendDiagnosticInterruptCommand");
      }
    };
    var StartDeclarativePoliciesReportCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "StartDeclarativePoliciesReport", {}).n("EC2Client", "StartDeclarativePoliciesReportCommand").sc(schemas_0.StartDeclarativePoliciesReport$).build() {
      static {
        __name(this, "StartDeclarativePoliciesReportCommand");
      }
    };
    var StartInstancesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "StartInstances", {}).n("EC2Client", "StartInstancesCommand").sc(schemas_0.StartInstances$).build() {
      static {
        __name(this, "StartInstancesCommand");
      }
    };
    var StartNetworkInsightsAccessScopeAnalysisCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "StartNetworkInsightsAccessScopeAnalysis", {}).n("EC2Client", "StartNetworkInsightsAccessScopeAnalysisCommand").sc(schemas_0.StartNetworkInsightsAccessScopeAnalysis$).build() {
      static {
        __name(this, "StartNetworkInsightsAccessScopeAnalysisCommand");
      }
    };
    var StartNetworkInsightsAnalysisCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "StartNetworkInsightsAnalysis", {}).n("EC2Client", "StartNetworkInsightsAnalysisCommand").sc(schemas_0.StartNetworkInsightsAnalysis$).build() {
      static {
        __name(this, "StartNetworkInsightsAnalysisCommand");
      }
    };
    var StartVpcEndpointServicePrivateDnsVerificationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "StartVpcEndpointServicePrivateDnsVerification", {}).n("EC2Client", "StartVpcEndpointServicePrivateDnsVerificationCommand").sc(schemas_0.StartVpcEndpointServicePrivateDnsVerification$).build() {
      static {
        __name(this, "StartVpcEndpointServicePrivateDnsVerificationCommand");
      }
    };
    var StopInstancesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "StopInstances", {}).n("EC2Client", "StopInstancesCommand").sc(schemas_0.StopInstances$).build() {
      static {
        __name(this, "StopInstancesCommand");
      }
    };
    var TerminateClientVpnConnectionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "TerminateClientVpnConnections", {}).n("EC2Client", "TerminateClientVpnConnectionsCommand").sc(schemas_0.TerminateClientVpnConnections$).build() {
      static {
        __name(this, "TerminateClientVpnConnectionsCommand");
      }
    };
    var TerminateInstancesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "TerminateInstances", {}).n("EC2Client", "TerminateInstancesCommand").sc(schemas_0.TerminateInstances$).build() {
      static {
        __name(this, "TerminateInstancesCommand");
      }
    };
    var UnassignIpv6AddressesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "UnassignIpv6Addresses", {}).n("EC2Client", "UnassignIpv6AddressesCommand").sc(schemas_0.UnassignIpv6Addresses$).build() {
      static {
        __name(this, "UnassignIpv6AddressesCommand");
      }
    };
    var UnassignPrivateIpAddressesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "UnassignPrivateIpAddresses", {}).n("EC2Client", "UnassignPrivateIpAddressesCommand").sc(schemas_0.UnassignPrivateIpAddresses$).build() {
      static {
        __name(this, "UnassignPrivateIpAddressesCommand");
      }
    };
    var UnassignPrivateNatGatewayAddressCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "UnassignPrivateNatGatewayAddress", {}).n("EC2Client", "UnassignPrivateNatGatewayAddressCommand").sc(schemas_0.UnassignPrivateNatGatewayAddress$).build() {
      static {
        __name(this, "UnassignPrivateNatGatewayAddressCommand");
      }
    };
    var UnlockSnapshotCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "UnlockSnapshot", {}).n("EC2Client", "UnlockSnapshotCommand").sc(schemas_0.UnlockSnapshot$).build() {
      static {
        __name(this, "UnlockSnapshotCommand");
      }
    };
    var UnmonitorInstancesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "UnmonitorInstances", {}).n("EC2Client", "UnmonitorInstancesCommand").sc(schemas_0.UnmonitorInstances$).build() {
      static {
        __name(this, "UnmonitorInstancesCommand");
      }
    };
    var UpdateCapacityManagerMonitoredTagKeysCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "UpdateCapacityManagerMonitoredTagKeys", {}).n("EC2Client", "UpdateCapacityManagerMonitoredTagKeysCommand").sc(schemas_0.UpdateCapacityManagerMonitoredTagKeys$).build() {
      static {
        __name(this, "UpdateCapacityManagerMonitoredTagKeysCommand");
      }
    };
    var UpdateCapacityManagerOrganizationsAccessCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "UpdateCapacityManagerOrganizationsAccess", {}).n("EC2Client", "UpdateCapacityManagerOrganizationsAccessCommand").sc(schemas_0.UpdateCapacityManagerOrganizationsAccess$).build() {
      static {
        __name(this, "UpdateCapacityManagerOrganizationsAccessCommand");
      }
    };
    var UpdateInterruptibleCapacityReservationAllocationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "UpdateInterruptibleCapacityReservationAllocation", {}).n("EC2Client", "UpdateInterruptibleCapacityReservationAllocationCommand").sc(schemas_0.UpdateInterruptibleCapacityReservationAllocation$).build() {
      static {
        __name(this, "UpdateInterruptibleCapacityReservationAllocationCommand");
      }
    };
    var UpdateSecurityGroupRuleDescriptionsEgressCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "UpdateSecurityGroupRuleDescriptionsEgress", {}).n("EC2Client", "UpdateSecurityGroupRuleDescriptionsEgressCommand").sc(schemas_0.UpdateSecurityGroupRuleDescriptionsEgress$).build() {
      static {
        __name(this, "UpdateSecurityGroupRuleDescriptionsEgressCommand");
      }
    };
    var UpdateSecurityGroupRuleDescriptionsIngressCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "UpdateSecurityGroupRuleDescriptionsIngress", {}).n("EC2Client", "UpdateSecurityGroupRuleDescriptionsIngressCommand").sc(schemas_0.UpdateSecurityGroupRuleDescriptionsIngress$).build() {
      static {
        __name(this, "UpdateSecurityGroupRuleDescriptionsIngressCommand");
      }
    };
    var WithdrawByoipCidrCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2", "WithdrawByoipCidr", {}).n("EC2Client", "WithdrawByoipCidrCommand").sc(schemas_0.WithdrawByoipCidr$).build() {
      static {
        __name(this, "WithdrawByoipCidrCommand");
      }
    };
    var paginateDescribeAddressesAttribute = core.createPaginator(EC2Client2, DescribeAddressesAttributeCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeAddressTransfers = core.createPaginator(EC2Client2, DescribeAddressTransfersCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeAwsNetworkPerformanceMetricSubscriptions = core.createPaginator(EC2Client2, DescribeAwsNetworkPerformanceMetricSubscriptionsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeByoipCidrs = core.createPaginator(EC2Client2, DescribeByoipCidrsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeCapacityBlockExtensionHistory = core.createPaginator(EC2Client2, DescribeCapacityBlockExtensionHistoryCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeCapacityBlockExtensionOfferings = core.createPaginator(EC2Client2, DescribeCapacityBlockExtensionOfferingsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeCapacityBlockOfferings = core.createPaginator(EC2Client2, DescribeCapacityBlockOfferingsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeCapacityBlocks = core.createPaginator(EC2Client2, DescribeCapacityBlocksCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeCapacityBlockStatus = core.createPaginator(EC2Client2, DescribeCapacityBlockStatusCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeCapacityManagerDataExports = core.createPaginator(EC2Client2, DescribeCapacityManagerDataExportsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeCapacityReservationBillingRequests = core.createPaginator(EC2Client2, DescribeCapacityReservationBillingRequestsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeCapacityReservationFleets = core.createPaginator(EC2Client2, DescribeCapacityReservationFleetsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeCapacityReservations = core.createPaginator(EC2Client2, DescribeCapacityReservationsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeCarrierGateways = core.createPaginator(EC2Client2, DescribeCarrierGatewaysCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeClassicLinkInstances = core.createPaginator(EC2Client2, DescribeClassicLinkInstancesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeClientVpnAuthorizationRules = core.createPaginator(EC2Client2, DescribeClientVpnAuthorizationRulesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeClientVpnConnections = core.createPaginator(EC2Client2, DescribeClientVpnConnectionsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeClientVpnEndpoints = core.createPaginator(EC2Client2, DescribeClientVpnEndpointsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeClientVpnRoutes = core.createPaginator(EC2Client2, DescribeClientVpnRoutesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeClientVpnTargetNetworks = core.createPaginator(EC2Client2, DescribeClientVpnTargetNetworksCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeCoipPools = core.createPaginator(EC2Client2, DescribeCoipPoolsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeDhcpOptions = core.createPaginator(EC2Client2, DescribeDhcpOptionsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeEgressOnlyInternetGateways = core.createPaginator(EC2Client2, DescribeEgressOnlyInternetGatewaysCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeExportImageTasks = core.createPaginator(EC2Client2, DescribeExportImageTasksCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeFastLaunchImages = core.createPaginator(EC2Client2, DescribeFastLaunchImagesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeFastSnapshotRestores = core.createPaginator(EC2Client2, DescribeFastSnapshotRestoresCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeFleets = core.createPaginator(EC2Client2, DescribeFleetsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeFlowLogs = core.createPaginator(EC2Client2, DescribeFlowLogsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeFpgaImages = core.createPaginator(EC2Client2, DescribeFpgaImagesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeHostReservationOfferings = core.createPaginator(EC2Client2, DescribeHostReservationOfferingsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeHostReservations = core.createPaginator(EC2Client2, DescribeHostReservationsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeHosts = core.createPaginator(EC2Client2, DescribeHostsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeIamInstanceProfileAssociations = core.createPaginator(EC2Client2, DescribeIamInstanceProfileAssociationsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeImageReferences = core.createPaginator(EC2Client2, DescribeImageReferencesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeImages = core.createPaginator(EC2Client2, DescribeImagesCommand3, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeImageUsageReportEntries = core.createPaginator(EC2Client2, DescribeImageUsageReportEntriesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeImageUsageReports = core.createPaginator(EC2Client2, DescribeImageUsageReportsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeImportImageTasks = core.createPaginator(EC2Client2, DescribeImportImageTasksCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeImportSnapshotTasks = core.createPaginator(EC2Client2, DescribeImportSnapshotTasksCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeInstanceConnectEndpoints = core.createPaginator(EC2Client2, DescribeInstanceConnectEndpointsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeInstanceCreditSpecifications = core.createPaginator(EC2Client2, DescribeInstanceCreditSpecificationsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeInstanceEventWindows = core.createPaginator(EC2Client2, DescribeInstanceEventWindowsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeInstanceImageMetadata = core.createPaginator(EC2Client2, DescribeInstanceImageMetadataCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeInstances = core.createPaginator(EC2Client2, DescribeInstancesCommand2, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeInstanceStatus = core.createPaginator(EC2Client2, DescribeInstanceStatusCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeInstanceTopology = core.createPaginator(EC2Client2, DescribeInstanceTopologyCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeInstanceTypeOfferings = core.createPaginator(EC2Client2, DescribeInstanceTypeOfferingsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeInstanceTypes = core.createPaginator(EC2Client2, DescribeInstanceTypesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeInternetGateways = core.createPaginator(EC2Client2, DescribeInternetGatewaysCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeIpamPools = core.createPaginator(EC2Client2, DescribeIpamPoolsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeIpamPrefixListResolvers = core.createPaginator(EC2Client2, DescribeIpamPrefixListResolversCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeIpamPrefixListResolverTargets = core.createPaginator(EC2Client2, DescribeIpamPrefixListResolverTargetsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeIpamResourceDiscoveries = core.createPaginator(EC2Client2, DescribeIpamResourceDiscoveriesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeIpamResourceDiscoveryAssociations = core.createPaginator(EC2Client2, DescribeIpamResourceDiscoveryAssociationsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeIpamScopes = core.createPaginator(EC2Client2, DescribeIpamScopesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeIpams = core.createPaginator(EC2Client2, DescribeIpamsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeIpv6Pools = core.createPaginator(EC2Client2, DescribeIpv6PoolsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeLaunchTemplates = core.createPaginator(EC2Client2, DescribeLaunchTemplatesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeLaunchTemplateVersions = core.createPaginator(EC2Client2, DescribeLaunchTemplateVersionsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeLocalGatewayRouteTables = core.createPaginator(EC2Client2, DescribeLocalGatewayRouteTablesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociations = core.createPaginator(EC2Client2, DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociationsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeLocalGatewayRouteTableVpcAssociations = core.createPaginator(EC2Client2, DescribeLocalGatewayRouteTableVpcAssociationsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeLocalGateways = core.createPaginator(EC2Client2, DescribeLocalGatewaysCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeLocalGatewayVirtualInterfaceGroups = core.createPaginator(EC2Client2, DescribeLocalGatewayVirtualInterfaceGroupsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeLocalGatewayVirtualInterfaces = core.createPaginator(EC2Client2, DescribeLocalGatewayVirtualInterfacesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeMacHosts = core.createPaginator(EC2Client2, DescribeMacHostsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeMacModificationTasks = core.createPaginator(EC2Client2, DescribeMacModificationTasksCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeManagedPrefixLists = core.createPaginator(EC2Client2, DescribeManagedPrefixListsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeMovingAddresses = core.createPaginator(EC2Client2, DescribeMovingAddressesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeNatGateways = core.createPaginator(EC2Client2, DescribeNatGatewaysCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeNetworkAcls = core.createPaginator(EC2Client2, DescribeNetworkAclsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeNetworkInsightsAccessScopeAnalyses = core.createPaginator(EC2Client2, DescribeNetworkInsightsAccessScopeAnalysesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeNetworkInsightsAccessScopes = core.createPaginator(EC2Client2, DescribeNetworkInsightsAccessScopesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeNetworkInsightsAnalyses = core.createPaginator(EC2Client2, DescribeNetworkInsightsAnalysesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeNetworkInsightsPaths = core.createPaginator(EC2Client2, DescribeNetworkInsightsPathsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeNetworkInterfacePermissions = core.createPaginator(EC2Client2, DescribeNetworkInterfacePermissionsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeNetworkInterfaces = core.createPaginator(EC2Client2, DescribeNetworkInterfacesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribePrefixLists = core.createPaginator(EC2Client2, DescribePrefixListsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribePrincipalIdFormat = core.createPaginator(EC2Client2, DescribePrincipalIdFormatCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribePublicIpv4Pools = core.createPaginator(EC2Client2, DescribePublicIpv4PoolsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeReplaceRootVolumeTasks = core.createPaginator(EC2Client2, DescribeReplaceRootVolumeTasksCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeReservedInstancesModifications = core.createPaginator(EC2Client2, DescribeReservedInstancesModificationsCommand, "NextToken", "NextToken", "");
    var paginateDescribeReservedInstancesOfferings = core.createPaginator(EC2Client2, DescribeReservedInstancesOfferingsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeRouteServerEndpoints = core.createPaginator(EC2Client2, DescribeRouteServerEndpointsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeRouteServerPeers = core.createPaginator(EC2Client2, DescribeRouteServerPeersCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeRouteServers = core.createPaginator(EC2Client2, DescribeRouteServersCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeRouteTables = core.createPaginator(EC2Client2, DescribeRouteTablesCommand2, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeScheduledInstanceAvailability = core.createPaginator(EC2Client2, DescribeScheduledInstanceAvailabilityCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeScheduledInstances = core.createPaginator(EC2Client2, DescribeScheduledInstancesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeSecondaryInterfaces = core.createPaginator(EC2Client2, DescribeSecondaryInterfacesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeSecondaryNetworks = core.createPaginator(EC2Client2, DescribeSecondaryNetworksCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeSecondarySubnets = core.createPaginator(EC2Client2, DescribeSecondarySubnetsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeSecurityGroupRules = core.createPaginator(EC2Client2, DescribeSecurityGroupRulesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeSecurityGroups = core.createPaginator(EC2Client2, DescribeSecurityGroupsCommand2, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeSecurityGroupVpcAssociations = core.createPaginator(EC2Client2, DescribeSecurityGroupVpcAssociationsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeSnapshots = core.createPaginator(EC2Client2, DescribeSnapshotsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeSnapshotTierStatus = core.createPaginator(EC2Client2, DescribeSnapshotTierStatusCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeSpotFleetRequests = core.createPaginator(EC2Client2, DescribeSpotFleetRequestsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeSpotInstanceRequests = core.createPaginator(EC2Client2, DescribeSpotInstanceRequestsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeSpotPriceHistory = core.createPaginator(EC2Client2, DescribeSpotPriceHistoryCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeStaleSecurityGroups = core.createPaginator(EC2Client2, DescribeStaleSecurityGroupsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeStoreImageTasks = core.createPaginator(EC2Client2, DescribeStoreImageTasksCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeSubnets = core.createPaginator(EC2Client2, DescribeSubnetsCommand2, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeTags = core.createPaginator(EC2Client2, DescribeTagsCommand2, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeTrafficMirrorFilters = core.createPaginator(EC2Client2, DescribeTrafficMirrorFiltersCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeTrafficMirrorSessions = core.createPaginator(EC2Client2, DescribeTrafficMirrorSessionsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeTrafficMirrorTargets = core.createPaginator(EC2Client2, DescribeTrafficMirrorTargetsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeTransitGatewayAttachments = core.createPaginator(EC2Client2, DescribeTransitGatewayAttachmentsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeTransitGatewayConnectPeers = core.createPaginator(EC2Client2, DescribeTransitGatewayConnectPeersCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeTransitGatewayConnects = core.createPaginator(EC2Client2, DescribeTransitGatewayConnectsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeTransitGatewayMulticastDomains = core.createPaginator(EC2Client2, DescribeTransitGatewayMulticastDomainsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeTransitGatewayPeeringAttachments = core.createPaginator(EC2Client2, DescribeTransitGatewayPeeringAttachmentsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeTransitGatewayPolicyTables = core.createPaginator(EC2Client2, DescribeTransitGatewayPolicyTablesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeTransitGatewayRouteTableAnnouncements = core.createPaginator(EC2Client2, DescribeTransitGatewayRouteTableAnnouncementsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeTransitGatewayRouteTables = core.createPaginator(EC2Client2, DescribeTransitGatewayRouteTablesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeTransitGateways = core.createPaginator(EC2Client2, DescribeTransitGatewaysCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeTransitGatewayVpcAttachments = core.createPaginator(EC2Client2, DescribeTransitGatewayVpcAttachmentsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeTrunkInterfaceAssociations = core.createPaginator(EC2Client2, DescribeTrunkInterfaceAssociationsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeVerifiedAccessEndpoints = core.createPaginator(EC2Client2, DescribeVerifiedAccessEndpointsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeVerifiedAccessGroups = core.createPaginator(EC2Client2, DescribeVerifiedAccessGroupsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeVerifiedAccessInstanceLoggingConfigurations = core.createPaginator(EC2Client2, DescribeVerifiedAccessInstanceLoggingConfigurationsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeVerifiedAccessInstances = core.createPaginator(EC2Client2, DescribeVerifiedAccessInstancesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeVerifiedAccessTrustProviders = core.createPaginator(EC2Client2, DescribeVerifiedAccessTrustProvidersCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeVolumesModifications = core.createPaginator(EC2Client2, DescribeVolumesModificationsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeVolumes = core.createPaginator(EC2Client2, DescribeVolumesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeVolumeStatus = core.createPaginator(EC2Client2, DescribeVolumeStatusCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeVpcClassicLinkDnsSupport = core.createPaginator(EC2Client2, DescribeVpcClassicLinkDnsSupportCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeVpcEndpointConnectionNotifications = core.createPaginator(EC2Client2, DescribeVpcEndpointConnectionNotificationsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeVpcEndpointConnections = core.createPaginator(EC2Client2, DescribeVpcEndpointConnectionsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeVpcEndpointServiceConfigurations = core.createPaginator(EC2Client2, DescribeVpcEndpointServiceConfigurationsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeVpcEndpointServicePermissions = core.createPaginator(EC2Client2, DescribeVpcEndpointServicePermissionsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeVpcEndpoints = core.createPaginator(EC2Client2, DescribeVpcEndpointsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeVpcPeeringConnections = core.createPaginator(EC2Client2, DescribeVpcPeeringConnectionsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeVpcs = core.createPaginator(EC2Client2, DescribeVpcsCommand2, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeVpnConcentrators = core.createPaginator(EC2Client2, DescribeVpnConcentratorsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetAssociatedIpv6PoolCidrs = core.createPaginator(EC2Client2, GetAssociatedIpv6PoolCidrsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetAwsNetworkPerformanceData = core.createPaginator(EC2Client2, GetAwsNetworkPerformanceDataCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetCapacityManagerMetricData = core.createPaginator(EC2Client2, GetCapacityManagerMetricDataCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetCapacityManagerMetricDimensions = core.createPaginator(EC2Client2, GetCapacityManagerMetricDimensionsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetCapacityManagerMonitoredTagKeys = core.createPaginator(EC2Client2, GetCapacityManagerMonitoredTagKeysCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetGroupsForCapacityReservation = core.createPaginator(EC2Client2, GetGroupsForCapacityReservationCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetInstanceTypesFromInstanceRequirements = core.createPaginator(EC2Client2, GetInstanceTypesFromInstanceRequirementsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetIpamAddressHistory = core.createPaginator(EC2Client2, GetIpamAddressHistoryCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetIpamDiscoveredAccounts = core.createPaginator(EC2Client2, GetIpamDiscoveredAccountsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetIpamDiscoveredResourceCidrs = core.createPaginator(EC2Client2, GetIpamDiscoveredResourceCidrsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetIpamPoolAllocations = core.createPaginator(EC2Client2, GetIpamPoolAllocationsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetIpamPoolCidrs = core.createPaginator(EC2Client2, GetIpamPoolCidrsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetIpamPrefixListResolverRules = core.createPaginator(EC2Client2, GetIpamPrefixListResolverRulesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetIpamPrefixListResolverVersionEntries = core.createPaginator(EC2Client2, GetIpamPrefixListResolverVersionEntriesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetIpamPrefixListResolverVersions = core.createPaginator(EC2Client2, GetIpamPrefixListResolverVersionsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetIpamResourceCidrs = core.createPaginator(EC2Client2, GetIpamResourceCidrsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetManagedPrefixListAssociations = core.createPaginator(EC2Client2, GetManagedPrefixListAssociationsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetManagedPrefixListEntries = core.createPaginator(EC2Client2, GetManagedPrefixListEntriesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetNetworkInsightsAccessScopeAnalysisFindings = core.createPaginator(EC2Client2, GetNetworkInsightsAccessScopeAnalysisFindingsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetSecurityGroupsForVpc = core.createPaginator(EC2Client2, GetSecurityGroupsForVpcCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetSpotPlacementScores = core.createPaginator(EC2Client2, GetSpotPlacementScoresCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetTransitGatewayAttachmentPropagations = core.createPaginator(EC2Client2, GetTransitGatewayAttachmentPropagationsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetTransitGatewayMulticastDomainAssociations = core.createPaginator(EC2Client2, GetTransitGatewayMulticastDomainAssociationsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetTransitGatewayPolicyTableAssociations = core.createPaginator(EC2Client2, GetTransitGatewayPolicyTableAssociationsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetTransitGatewayPrefixListReferences = core.createPaginator(EC2Client2, GetTransitGatewayPrefixListReferencesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetTransitGatewayRouteTableAssociations = core.createPaginator(EC2Client2, GetTransitGatewayRouteTableAssociationsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetTransitGatewayRouteTablePropagations = core.createPaginator(EC2Client2, GetTransitGatewayRouteTablePropagationsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetVpnConnectionDeviceTypes = core.createPaginator(EC2Client2, GetVpnConnectionDeviceTypesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListImagesInRecycleBin = core.createPaginator(EC2Client2, ListImagesInRecycleBinCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListSnapshotsInRecycleBin = core.createPaginator(EC2Client2, ListSnapshotsInRecycleBinCommand, "NextToken", "NextToken", "MaxResults");
    var paginateSearchLocalGatewayRoutes = core.createPaginator(EC2Client2, SearchLocalGatewayRoutesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateSearchTransitGatewayMulticastGroups = core.createPaginator(EC2Client2, SearchTransitGatewayMulticastGroupsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateSearchTransitGatewayRoutes = core.createPaginator(EC2Client2, SearchTransitGatewayRoutesCommand, "NextToken", "NextToken", "MaxResults");
    var checkState$G = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeBundleTasksCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.BundleTasks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "complete";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.BundleTasks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "failed") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$G");
    var waitForBundleTaskComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$G);
    }, "waitForBundleTaskComplete");
    var waitUntilBundleTaskComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$G);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilBundleTaskComplete");
    var checkState$F = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeConversionTasksCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.ConversionTasks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "cancelled";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$F");
    var waitForConversionTaskCancelled = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$F);
    }, "waitForConversionTaskCancelled");
    var waitUntilConversionTaskCancelled = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$F);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilConversionTaskCancelled");
    var checkState$E = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeConversionTasksCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.ConversionTasks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "completed";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.ConversionTasks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "cancelled") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.ConversionTasks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "cancelling") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$E");
    var waitForConversionTaskCompleted = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$E);
    }, "waitForConversionTaskCompleted");
    var waitUntilConversionTaskCompleted = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$E);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilConversionTaskCompleted");
    var checkState$D = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeConversionTasksCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.ConversionTasks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "deleted";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$D");
    var waitForConversionTaskDeleted = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$D);
    }, "waitForConversionTaskDeleted");
    var waitUntilConversionTaskDeleted = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$D);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilConversionTaskDeleted");
    var checkState$C = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeCustomerGatewaysCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.CustomerGateways);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "available";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.CustomerGateways);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "deleted") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.CustomerGateways);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "deleting") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$C");
    var waitForCustomerGatewayAvailable = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$C);
    }, "waitForCustomerGatewayAvailable");
    var waitUntilCustomerGatewayAvailable = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$C);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilCustomerGatewayAvailable");
    var checkState$B = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeExportTasksCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.ExportTasks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "cancelled";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$B");
    var waitForExportTaskCancelled = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$B);
    }, "waitForExportTaskCancelled");
    var waitUntilExportTaskCancelled = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$B);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilExportTaskCancelled");
    var checkState$A = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeExportTasksCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.ExportTasks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "completed";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$A");
    var waitForExportTaskCompleted = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$A);
    }, "waitForExportTaskCompleted");
    var waitUntilExportTaskCompleted = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$A);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilExportTaskCompleted");
    var checkState$z = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeImagesCommand3(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Images);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "available";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Images);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "failed") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$z");
    var waitForImageAvailable = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$z);
    }, "waitForImageAvailable");
    var waitUntilImageAvailable = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$z);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilImageAvailable");
    var checkState$y = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeImagesCommand3(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Images);
            return flat_1.length > 0;
          }, "returnComparator");
          if (returnComparator() == true) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "InvalidAMIID.NotFound") {
          return { state: utilWaiter.WaiterState.RETRY, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$y");
    var waitForImageExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$y);
    }, "waitForImageExists");
    var waitUntilImageExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$y);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilImageExists");
    var checkState$x = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeImageUsageReportsCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.ImageUsageReports);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "available";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.ImageUsageReports);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "failed") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$x");
    var waitForImageUsageReportAvailable = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$x);
    }, "waitForImageUsageReportAvailable");
    var waitUntilImageUsageReportAvailable = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$x);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilImageUsageReportAvailable");
    var checkState$w = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeInstancesCommand2(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Reservations);
            return flat_1.length > 0;
          }, "returnComparator");
          if (returnComparator() == true) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "InvalidInstanceID.NotFound") {
          return { state: utilWaiter.WaiterState.RETRY, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$w");
    var waitForInstanceExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$w);
    }, "waitForInstanceExists");
    var waitUntilInstanceExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$w);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilInstanceExists");
    var checkState$v = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeInstancesCommand2(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Reservations);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.Instances;
            });
            let flat_4 = [].concat(...projection_3);
            let projection_6 = flat_4.map((element_5) => {
              return element_5.State.Name;
            });
            return projection_6;
          }, "returnComparator");
          let allStringEq_8 = returnComparator().length > 0;
          for (let element_7 of returnComparator()) {
            allStringEq_8 = allStringEq_8 && element_7 == "running";
          }
          if (allStringEq_8) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Reservations);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.Instances;
            });
            let flat_4 = [].concat(...projection_3);
            let projection_6 = flat_4.map((element_5) => {
              return element_5.State.Name;
            });
            return projection_6;
          }, "returnComparator");
          for (let anyStringEq_7 of returnComparator()) {
            if (anyStringEq_7 == "shutting-down") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Reservations);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.Instances;
            });
            let flat_4 = [].concat(...projection_3);
            let projection_6 = flat_4.map((element_5) => {
              return element_5.State.Name;
            });
            return projection_6;
          }, "returnComparator");
          for (let anyStringEq_7 of returnComparator()) {
            if (anyStringEq_7 == "terminated") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Reservations);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.Instances;
            });
            let flat_4 = [].concat(...projection_3);
            let projection_6 = flat_4.map((element_5) => {
              return element_5.State.Name;
            });
            return projection_6;
          }, "returnComparator");
          for (let anyStringEq_7 of returnComparator()) {
            if (anyStringEq_7 == "stopping") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "InvalidInstanceID.NotFound") {
          return { state: utilWaiter.WaiterState.RETRY, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$v");
    var waitForInstanceRunning = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$v);
    }, "waitForInstanceRunning");
    var waitUntilInstanceRunning = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$v);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilInstanceRunning");
    var checkState$u = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeInstanceStatusCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.InstanceStatuses);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.InstanceStatus.Status;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "ok";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "InvalidInstanceID.NotFound") {
          return { state: utilWaiter.WaiterState.RETRY, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$u");
    var waitForInstanceStatusOk = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$u);
    }, "waitForInstanceStatusOk");
    var waitUntilInstanceStatusOk = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$u);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilInstanceStatusOk");
    var checkState$t = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeInstancesCommand2(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Reservations);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.Instances;
            });
            let flat_4 = [].concat(...projection_3);
            let projection_6 = flat_4.map((element_5) => {
              return element_5.State.Name;
            });
            return projection_6;
          }, "returnComparator");
          let allStringEq_8 = returnComparator().length > 0;
          for (let element_7 of returnComparator()) {
            allStringEq_8 = allStringEq_8 && element_7 == "stopped";
          }
          if (allStringEq_8) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Reservations);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.Instances;
            });
            let flat_4 = [].concat(...projection_3);
            let projection_6 = flat_4.map((element_5) => {
              return element_5.State.Name;
            });
            return projection_6;
          }, "returnComparator");
          for (let anyStringEq_7 of returnComparator()) {
            if (anyStringEq_7 == "pending") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Reservations);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.Instances;
            });
            let flat_4 = [].concat(...projection_3);
            let projection_6 = flat_4.map((element_5) => {
              return element_5.State.Name;
            });
            return projection_6;
          }, "returnComparator");
          for (let anyStringEq_7 of returnComparator()) {
            if (anyStringEq_7 == "terminated") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$t");
    var waitForInstanceStopped = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$t);
    }, "waitForInstanceStopped");
    var waitUntilInstanceStopped = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$t);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilInstanceStopped");
    var checkState$s = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeInstancesCommand2(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Reservations);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.Instances;
            });
            let flat_4 = [].concat(...projection_3);
            let projection_6 = flat_4.map((element_5) => {
              return element_5.State.Name;
            });
            return projection_6;
          }, "returnComparator");
          let allStringEq_8 = returnComparator().length > 0;
          for (let element_7 of returnComparator()) {
            allStringEq_8 = allStringEq_8 && element_7 == "terminated";
          }
          if (allStringEq_8) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Reservations);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.Instances;
            });
            let flat_4 = [].concat(...projection_3);
            let projection_6 = flat_4.map((element_5) => {
              return element_5.State.Name;
            });
            return projection_6;
          }, "returnComparator");
          for (let anyStringEq_7 of returnComparator()) {
            if (anyStringEq_7 == "pending") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Reservations);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.Instances;
            });
            let flat_4 = [].concat(...projection_3);
            let projection_6 = flat_4.map((element_5) => {
              return element_5.State.Name;
            });
            return projection_6;
          }, "returnComparator");
          for (let anyStringEq_7 of returnComparator()) {
            if (anyStringEq_7 == "stopping") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$s");
    var waitForInstanceTerminated = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$s);
    }, "waitForInstanceTerminated");
    var waitUntilInstanceTerminated = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$s);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilInstanceTerminated");
    var checkState$r = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeInternetGatewaysCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.InternetGateways);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.InternetGatewayId;
            });
            return projection_3.length > 0;
          }, "returnComparator");
          if (returnComparator() == true) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "InvalidInternetGateway.NotFound") {
          return { state: utilWaiter.WaiterState.RETRY, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$r");
    var waitForInternetGatewayExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$r);
    }, "waitForInternetGatewayExists");
    var waitUntilInternetGatewayExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$r);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilInternetGatewayExists");
    var checkState$q = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeKeyPairsCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.KeyPairs);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.KeyName;
            });
            return projection_3.length > 0;
          }, "returnComparator");
          if (returnComparator() == true) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "InvalidKeyPair.NotFound") {
          return { state: utilWaiter.WaiterState.RETRY, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$q");
    var waitForKeyPairExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$q);
    }, "waitForKeyPairExists");
    var waitUntilKeyPairExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$q);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilKeyPairExists");
    var checkState$p = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeNatGatewaysCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.NatGateways);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "available";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.NatGateways);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "failed") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.NatGateways);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "deleting") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.NatGateways);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "deleted") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "NatGatewayNotFound") {
          return { state: utilWaiter.WaiterState.RETRY, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$p");
    var waitForNatGatewayAvailable = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$p);
    }, "waitForNatGatewayAvailable");
    var waitUntilNatGatewayAvailable = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$p);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilNatGatewayAvailable");
    var checkState$o = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeNatGatewaysCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.NatGateways);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "deleted";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "NatGatewayNotFound") {
          return { state: utilWaiter.WaiterState.SUCCESS, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$o");
    var waitForNatGatewayDeleted = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$o);
    }, "waitForNatGatewayDeleted");
    var waitUntilNatGatewayDeleted = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$o);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilNatGatewayDeleted");
    var checkState$n = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeNetworkInterfacesCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.NetworkInterfaces);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.Status;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "available";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "InvalidNetworkInterfaceID.NotFound") {
          return { state: utilWaiter.WaiterState.FAILURE, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$n");
    var waitForNetworkInterfaceAvailable = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 20, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$n);
    }, "waitForNetworkInterfaceAvailable");
    var waitUntilNetworkInterfaceAvailable = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 20, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$n);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilNetworkInterfaceAvailable");
    var checkState$m = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new GetPasswordDataCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.PasswordData.length > 0;
          }, "returnComparator");
          if (returnComparator() == true) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$m");
    var waitForPasswordDataAvailable = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$m);
    }, "waitForPasswordDataAvailable");
    var waitUntilPasswordDataAvailable = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$m);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilPasswordDataAvailable");
    var checkState$l = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeSecondaryNetworksCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.SecondaryNetworks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "create-complete";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.SecondaryNetworks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "create-failed") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "InvalidSecondaryNetworkId.NotFound") {
          return { state: utilWaiter.WaiterState.RETRY, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$l");
    var waitForSecondaryNetworkCreateComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 10, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$l);
    }, "waitForSecondaryNetworkCreateComplete");
    var waitUntilSecondaryNetworkCreateComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 10, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$l);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilSecondaryNetworkCreateComplete");
    var checkState$k = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeSecondaryNetworksCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.SecondaryNetworks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "delete-complete";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.SecondaryNetworks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "delete-failed") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$k");
    var waitForSecondaryNetworkDeleteComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 10, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$k);
    }, "waitForSecondaryNetworkDeleteComplete");
    var waitUntilSecondaryNetworkDeleteComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 10, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$k);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilSecondaryNetworkDeleteComplete");
    var checkState$j = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeSecondarySubnetsCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.SecondarySubnets);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "create-complete";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.SecondarySubnets);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "delete-failed") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "InvalidSecondarySubnetId.NotFound") {
          return { state: utilWaiter.WaiterState.RETRY, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$j");
    var waitForSecondarySubnetCreateComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 10, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$j);
    }, "waitForSecondarySubnetCreateComplete");
    var waitUntilSecondarySubnetCreateComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 10, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$j);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilSecondarySubnetCreateComplete");
    var checkState$i = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeSecondarySubnetsCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.SecondarySubnets);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "delete-complete";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.SecondarySubnets);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "delete-failed") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$i");
    var waitForSecondarySubnetDeleteComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 10, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$i);
    }, "waitForSecondarySubnetDeleteComplete");
    var waitUntilSecondarySubnetDeleteComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 10, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$i);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilSecondarySubnetDeleteComplete");
    var checkState$h = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeSecurityGroupsCommand2(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.SecurityGroups);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.GroupId;
            });
            return projection_3.length > 0;
          }, "returnComparator");
          if (returnComparator() == true) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "InvalidGroup.NotFound") {
          return { state: utilWaiter.WaiterState.RETRY, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$h");
    var waitForSecurityGroupExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$h);
    }, "waitForSecurityGroupExists");
    var waitUntilSecurityGroupExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$h);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilSecurityGroupExists");
    var checkState$g = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeSecurityGroupVpcAssociationsCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.SecurityGroupVpcAssociations);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "associated";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.SecurityGroupVpcAssociations);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "associating") {
              return { state: utilWaiter.WaiterState.RETRY, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.SecurityGroupVpcAssociations);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "association-failed") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$g");
    var waitForSecurityGroupVpcAssociationAssociated = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 10, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$g);
    }, "waitForSecurityGroupVpcAssociationAssociated");
    var waitUntilSecurityGroupVpcAssociationAssociated = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 10, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$g);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilSecurityGroupVpcAssociationAssociated");
    var checkState$f = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeSecurityGroupVpcAssociationsCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.SecurityGroupVpcAssociations);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "disassociated";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.SecurityGroupVpcAssociations);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "disassociating") {
              return { state: utilWaiter.WaiterState.RETRY, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.SecurityGroupVpcAssociations);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "disassociation-failed") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.SecurityGroupVpcAssociations);
            return flat_1.length == 0;
          }, "returnComparator");
          if (returnComparator() == true) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$f");
    var waitForSecurityGroupVpcAssociationDisassociated = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 10, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$f);
    }, "waitForSecurityGroupVpcAssociationDisassociated");
    var waitUntilSecurityGroupVpcAssociationDisassociated = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 10, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$f);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilSecurityGroupVpcAssociationDisassociated");
    var checkState$e = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeSnapshotsCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Snapshots);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "completed";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Snapshots);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "error") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$e");
    var waitForSnapshotCompleted = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$e);
    }, "waitForSnapshotCompleted");
    var waitUntilSnapshotCompleted = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$e);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilSnapshotCompleted");
    var checkState$d = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeImportSnapshotTasksCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.ImportSnapshotTasks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.SnapshotTaskDetail.Status;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "completed";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.ImportSnapshotTasks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.SnapshotTaskDetail.Status;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "error") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$d");
    var waitForSnapshotImported = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$d);
    }, "waitForSnapshotImported");
    var waitUntilSnapshotImported = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$d);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilSnapshotImported");
    var checkState$c = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeSpotInstanceRequestsCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.SpotInstanceRequests);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.Status.Code;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "fulfilled";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.SpotInstanceRequests);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.Status.Code;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "request-canceled-and-instance-running";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.SpotInstanceRequests);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.Status.Code;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "schedule-expired") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.SpotInstanceRequests);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.Status.Code;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "canceled-before-fulfillment") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.SpotInstanceRequests);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.Status.Code;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "bad-parameters") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.SpotInstanceRequests);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.Status.Code;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "system-error") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "InvalidSpotInstanceRequestID.NotFound") {
          return { state: utilWaiter.WaiterState.RETRY, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$c");
    var waitForSpotInstanceRequestFulfilled = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$c);
    }, "waitForSpotInstanceRequestFulfilled");
    var waitUntilSpotInstanceRequestFulfilled = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$c);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilSpotInstanceRequestFulfilled");
    var checkState$b = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeStoreImageTasksCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.StoreImageTaskResults);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StoreTaskState;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "Completed";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.StoreImageTaskResults);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StoreTaskState;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "Failed") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.StoreImageTaskResults);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.StoreTaskState;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "InProgress") {
              return { state: utilWaiter.WaiterState.RETRY, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$b");
    var waitForStoreImageTaskComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$b);
    }, "waitForStoreImageTaskComplete");
    var waitUntilStoreImageTaskComplete = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$b);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilStoreImageTaskComplete");
    var checkState$a = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeSubnetsCommand2(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Subnets);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "available";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$a");
    var waitForSubnetAvailable = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$a);
    }, "waitForSubnetAvailable");
    var waitUntilSubnetAvailable = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$a);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilSubnetAvailable");
    var checkState$9 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeInstanceStatusCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.InstanceStatuses);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.SystemStatus.Status;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "ok";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$9");
    var waitForSystemStatusOk = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$9);
    }, "waitForSystemStatusOk");
    var waitUntilSystemStatusOk = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$9);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilSystemStatusOk");
    var checkState$8 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeVolumesCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Volumes);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "available";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Volumes);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "deleted") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$8");
    var waitForVolumeAvailable = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$8);
    }, "waitForVolumeAvailable");
    var waitUntilVolumeAvailable = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$8);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilVolumeAvailable");
    var checkState$7 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeVolumesCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Volumes);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "deleted";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "InvalidVolume.NotFound") {
          return { state: utilWaiter.WaiterState.SUCCESS, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$7");
    var waitForVolumeDeleted = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$7);
    }, "waitForVolumeDeleted");
    var waitUntilVolumeDeleted = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$7);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilVolumeDeleted");
    var checkState$6 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeVolumesCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Volumes);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "in-use";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Volumes);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "deleted") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$6");
    var waitForVolumeInUse = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$6);
    }, "waitForVolumeInUse");
    var waitUntilVolumeInUse = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$6);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilVolumeInUse");
    var checkState$5 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeVpcsCommand2(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.Vpcs);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "available";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$5");
    var waitForVpcAvailable = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$5);
    }, "waitForVpcAvailable");
    var waitUntilVpcAvailable = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$5);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilVpcAvailable");
    var checkState$4 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeVpcsCommand2(input));
        reason = result2;
        return { state: utilWaiter.WaiterState.SUCCESS, reason };
      } catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "InvalidVpcID.NotFound") {
          return { state: utilWaiter.WaiterState.RETRY, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$4");
    var waitForVpcExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 1, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$4);
    }, "waitForVpcExists");
    var waitUntilVpcExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 1, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$4);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilVpcExists");
    var checkState$3 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeVpcPeeringConnectionsCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.VpcPeeringConnections);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.Status.Code;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "deleted";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "InvalidVpcPeeringConnectionID.NotFound") {
          return { state: utilWaiter.WaiterState.SUCCESS, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$3");
    var waitForVpcPeeringConnectionDeleted = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$3);
    }, "waitForVpcPeeringConnectionDeleted");
    var waitUntilVpcPeeringConnectionDeleted = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$3);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilVpcPeeringConnectionDeleted");
    var checkState$2 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeVpcPeeringConnectionsCommand(input));
        reason = result2;
        return { state: utilWaiter.WaiterState.SUCCESS, reason };
      } catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "InvalidVpcPeeringConnectionID.NotFound") {
          return { state: utilWaiter.WaiterState.RETRY, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$2");
    var waitForVpcPeeringConnectionExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$2);
    }, "waitForVpcPeeringConnectionExists");
    var waitUntilVpcPeeringConnectionExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$2);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilVpcPeeringConnectionExists");
    var checkState$1 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeVpnConnectionsCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.VpnConnections);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "available";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.VpnConnections);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "deleting") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.VpnConnections);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "deleted") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$1");
    var waitForVpnConnectionAvailable = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$1);
    }, "waitForVpnConnectionAvailable");
    var waitUntilVpnConnectionAvailable = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$1);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilVpnConnectionAvailable");
    var checkState = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeVpnConnectionsCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.VpnConnections);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "deleted";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.VpnConnections);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "pending") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState");
    var waitForVpnConnectionDeleted = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState);
    }, "waitForVpnConnectionDeleted");
    var waitUntilVpnConnectionDeleted = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilVpnConnectionDeleted");
    var commands32 = {
      AcceptAddressTransferCommand,
      AcceptCapacityReservationBillingOwnershipCommand,
      AcceptReservedInstancesExchangeQuoteCommand,
      AcceptTransitGatewayClientVpnAttachmentCommand,
      AcceptTransitGatewayMulticastDomainAssociationsCommand,
      AcceptTransitGatewayPeeringAttachmentCommand,
      AcceptTransitGatewayVpcAttachmentCommand,
      AcceptVpcEndpointConnectionsCommand,
      AcceptVpcPeeringConnectionCommand,
      AdvertiseByoipCidrCommand,
      AllocateAddressCommand,
      AllocateHostsCommand,
      AllocateIpamPoolCidrCommand,
      ApplySecurityGroupsToClientVpnTargetNetworkCommand,
      AssignIpv6AddressesCommand,
      AssignPrivateIpAddressesCommand,
      AssignPrivateNatGatewayAddressCommand,
      AssociateAddressCommand,
      AssociateCapacityReservationBillingOwnerCommand,
      AssociateClientVpnTargetNetworkCommand,
      AssociateDhcpOptionsCommand,
      AssociateEnclaveCertificateIamRoleCommand,
      AssociateIamInstanceProfileCommand,
      AssociateInstanceEventWindowCommand,
      AssociateIpamByoasnCommand,
      AssociateIpamResourceDiscoveryCommand,
      AssociateNatGatewayAddressCommand,
      AssociateRouteServerCommand,
      AssociateRouteTableCommand,
      AssociateSecurityGroupVpcCommand,
      AssociateSubnetCidrBlockCommand,
      AssociateTransitGatewayMulticastDomainCommand,
      AssociateTransitGatewayPolicyTableCommand,
      AssociateTransitGatewayRouteTableCommand,
      AssociateTrunkInterfaceCommand,
      AssociateVpcCidrBlockCommand,
      AttachClassicLinkVpcCommand,
      AttachInternetGatewayCommand,
      AttachNetworkInterfaceCommand,
      AttachVerifiedAccessTrustProviderCommand,
      AttachVolumeCommand,
      AttachVpnGatewayCommand,
      AuthorizeClientVpnIngressCommand,
      AuthorizeSecurityGroupEgressCommand,
      AuthorizeSecurityGroupIngressCommand,
      BundleInstanceCommand,
      CancelBundleTaskCommand,
      CancelCapacityReservationCommand,
      CancelCapacityReservationFleetsCommand,
      CancelConversionTaskCommand,
      CancelDeclarativePoliciesReportCommand,
      CancelExportTaskCommand,
      CancelImageLaunchPermissionCommand,
      CancelImportTaskCommand,
      CancelReservedInstancesListingCommand,
      CancelSpotFleetRequestsCommand,
      CancelSpotInstanceRequestsCommand,
      ConfirmProductInstanceCommand,
      CopyFpgaImageCommand,
      CopyImageCommand,
      CopySnapshotCommand,
      CopyVolumesCommand,
      CreateCapacityManagerDataExportCommand,
      CreateCapacityReservationCommand,
      CreateCapacityReservationBySplittingCommand,
      CreateCapacityReservationFleetCommand,
      CreateCarrierGatewayCommand,
      CreateClientVpnEndpointCommand,
      CreateClientVpnRouteCommand,
      CreateCoipCidrCommand,
      CreateCoipPoolCommand,
      CreateCustomerGatewayCommand,
      CreateDefaultSubnetCommand,
      CreateDefaultVpcCommand,
      CreateDelegateMacVolumeOwnershipTaskCommand,
      CreateDhcpOptionsCommand,
      CreateEgressOnlyInternetGatewayCommand,
      CreateFleetCommand,
      CreateFlowLogsCommand,
      CreateFpgaImageCommand,
      CreateImageCommand,
      CreateImageUsageReportCommand,
      CreateInstanceConnectEndpointCommand,
      CreateInstanceEventWindowCommand,
      CreateInstanceExportTaskCommand,
      CreateInternetGatewayCommand,
      CreateInterruptibleCapacityReservationAllocationCommand,
      CreateIpamCommand,
      CreateIpamExternalResourceVerificationTokenCommand,
      CreateIpamPolicyCommand,
      CreateIpamPoolCommand,
      CreateIpamPrefixListResolverCommand,
      CreateIpamPrefixListResolverTargetCommand,
      CreateIpamResourceDiscoveryCommand,
      CreateIpamScopeCommand,
      CreateKeyPairCommand,
      CreateLaunchTemplateCommand,
      CreateLaunchTemplateVersionCommand,
      CreateLocalGatewayRouteCommand,
      CreateLocalGatewayRouteTableCommand,
      CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationCommand,
      CreateLocalGatewayRouteTableVpcAssociationCommand,
      CreateLocalGatewayVirtualInterfaceCommand,
      CreateLocalGatewayVirtualInterfaceGroupCommand,
      CreateMacSystemIntegrityProtectionModificationTaskCommand,
      CreateManagedPrefixListCommand,
      CreateNatGatewayCommand,
      CreateNetworkAclCommand,
      CreateNetworkAclEntryCommand,
      CreateNetworkInsightsAccessScopeCommand,
      CreateNetworkInsightsPathCommand,
      CreateNetworkInterfaceCommand,
      CreateNetworkInterfacePermissionCommand,
      CreatePlacementGroupCommand,
      CreatePublicIpv4PoolCommand,
      CreateReplaceRootVolumeTaskCommand,
      CreateReservedInstancesListingCommand,
      CreateRestoreImageTaskCommand,
      CreateRouteCommand,
      CreateRouteServerCommand,
      CreateRouteServerEndpointCommand,
      CreateRouteServerPeerCommand,
      CreateRouteTableCommand,
      CreateSecondaryNetworkCommand,
      CreateSecondarySubnetCommand,
      CreateSecurityGroupCommand,
      CreateSnapshotCommand,
      CreateSnapshotsCommand,
      CreateSpotDatafeedSubscriptionCommand,
      CreateStoreImageTaskCommand,
      CreateSubnetCommand,
      CreateSubnetCidrReservationCommand,
      CreateTagsCommand,
      CreateTrafficMirrorFilterCommand,
      CreateTrafficMirrorFilterRuleCommand,
      CreateTrafficMirrorSessionCommand,
      CreateTrafficMirrorTargetCommand,
      CreateTransitGatewayCommand,
      CreateTransitGatewayConnectCommand,
      CreateTransitGatewayConnectPeerCommand,
      CreateTransitGatewayMeteringPolicyCommand,
      CreateTransitGatewayMeteringPolicyEntryCommand,
      CreateTransitGatewayMulticastDomainCommand,
      CreateTransitGatewayPeeringAttachmentCommand,
      CreateTransitGatewayPolicyTableCommand,
      CreateTransitGatewayPrefixListReferenceCommand,
      CreateTransitGatewayRouteCommand,
      CreateTransitGatewayRouteTableCommand,
      CreateTransitGatewayRouteTableAnnouncementCommand,
      CreateTransitGatewayVpcAttachmentCommand,
      CreateVerifiedAccessEndpointCommand,
      CreateVerifiedAccessGroupCommand,
      CreateVerifiedAccessInstanceCommand,
      CreateVerifiedAccessTrustProviderCommand,
      CreateVolumeCommand,
      CreateVpcCommand,
      CreateVpcBlockPublicAccessExclusionCommand,
      CreateVpcEncryptionControlCommand,
      CreateVpcEndpointCommand,
      CreateVpcEndpointConnectionNotificationCommand,
      CreateVpcEndpointServiceConfigurationCommand,
      CreateVpcPeeringConnectionCommand,
      CreateVpnConcentratorCommand,
      CreateVpnConnectionCommand,
      CreateVpnConnectionRouteCommand,
      CreateVpnGatewayCommand,
      DeleteCapacityManagerDataExportCommand,
      DeleteCarrierGatewayCommand,
      DeleteClientVpnEndpointCommand,
      DeleteClientVpnRouteCommand,
      DeleteCoipCidrCommand,
      DeleteCoipPoolCommand,
      DeleteCustomerGatewayCommand,
      DeleteDhcpOptionsCommand,
      DeleteEgressOnlyInternetGatewayCommand,
      DeleteFleetsCommand,
      DeleteFlowLogsCommand,
      DeleteFpgaImageCommand,
      DeleteImageUsageReportCommand,
      DeleteInstanceConnectEndpointCommand,
      DeleteInstanceEventWindowCommand,
      DeleteInternetGatewayCommand,
      DeleteIpamCommand,
      DeleteIpamExternalResourceVerificationTokenCommand,
      DeleteIpamPolicyCommand,
      DeleteIpamPoolCommand,
      DeleteIpamPrefixListResolverCommand,
      DeleteIpamPrefixListResolverTargetCommand,
      DeleteIpamResourceDiscoveryCommand,
      DeleteIpamScopeCommand,
      DeleteKeyPairCommand,
      DeleteLaunchTemplateCommand,
      DeleteLaunchTemplateVersionsCommand,
      DeleteLocalGatewayRouteCommand,
      DeleteLocalGatewayRouteTableCommand,
      DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociationCommand,
      DeleteLocalGatewayRouteTableVpcAssociationCommand,
      DeleteLocalGatewayVirtualInterfaceCommand,
      DeleteLocalGatewayVirtualInterfaceGroupCommand,
      DeleteManagedPrefixListCommand,
      DeleteNatGatewayCommand,
      DeleteNetworkAclCommand,
      DeleteNetworkAclEntryCommand,
      DeleteNetworkInsightsAccessScopeCommand,
      DeleteNetworkInsightsAccessScopeAnalysisCommand,
      DeleteNetworkInsightsAnalysisCommand,
      DeleteNetworkInsightsPathCommand,
      DeleteNetworkInterfaceCommand,
      DeleteNetworkInterfacePermissionCommand,
      DeletePlacementGroupCommand,
      DeletePublicIpv4PoolCommand,
      DeleteQueuedReservedInstancesCommand,
      DeleteRouteCommand,
      DeleteRouteServerCommand,
      DeleteRouteServerEndpointCommand,
      DeleteRouteServerPeerCommand,
      DeleteRouteTableCommand,
      DeleteSecondaryNetworkCommand,
      DeleteSecondarySubnetCommand,
      DeleteSecurityGroupCommand,
      DeleteSnapshotCommand,
      DeleteSpotDatafeedSubscriptionCommand,
      DeleteSubnetCommand,
      DeleteSubnetCidrReservationCommand,
      DeleteTagsCommand,
      DeleteTrafficMirrorFilterCommand,
      DeleteTrafficMirrorFilterRuleCommand,
      DeleteTrafficMirrorSessionCommand,
      DeleteTrafficMirrorTargetCommand,
      DeleteTransitGatewayCommand,
      DeleteTransitGatewayClientVpnAttachmentCommand,
      DeleteTransitGatewayConnectCommand,
      DeleteTransitGatewayConnectPeerCommand,
      DeleteTransitGatewayMeteringPolicyCommand,
      DeleteTransitGatewayMeteringPolicyEntryCommand,
      DeleteTransitGatewayMulticastDomainCommand,
      DeleteTransitGatewayPeeringAttachmentCommand,
      DeleteTransitGatewayPolicyTableCommand,
      DeleteTransitGatewayPrefixListReferenceCommand,
      DeleteTransitGatewayRouteCommand,
      DeleteTransitGatewayRouteTableCommand,
      DeleteTransitGatewayRouteTableAnnouncementCommand,
      DeleteTransitGatewayVpcAttachmentCommand,
      DeleteVerifiedAccessEndpointCommand,
      DeleteVerifiedAccessGroupCommand,
      DeleteVerifiedAccessInstanceCommand,
      DeleteVerifiedAccessTrustProviderCommand,
      DeleteVolumeCommand,
      DeleteVpcCommand,
      DeleteVpcBlockPublicAccessExclusionCommand,
      DeleteVpcEncryptionControlCommand,
      DeleteVpcEndpointConnectionNotificationsCommand,
      DeleteVpcEndpointsCommand,
      DeleteVpcEndpointServiceConfigurationsCommand,
      DeleteVpcPeeringConnectionCommand,
      DeleteVpnConcentratorCommand,
      DeleteVpnConnectionCommand,
      DeleteVpnConnectionRouteCommand,
      DeleteVpnGatewayCommand,
      DeprovisionByoipCidrCommand,
      DeprovisionIpamByoasnCommand,
      DeprovisionIpamPoolCidrCommand,
      DeprovisionPublicIpv4PoolCidrCommand,
      DeregisterImageCommand,
      DeregisterInstanceEventNotificationAttributesCommand,
      DeregisterTransitGatewayMulticastGroupMembersCommand,
      DeregisterTransitGatewayMulticastGroupSourcesCommand,
      DescribeAccountAttributesCommand,
      DescribeAddressesCommand,
      DescribeAddressesAttributeCommand,
      DescribeAddressTransfersCommand,
      DescribeAggregateIdFormatCommand,
      DescribeAvailabilityZonesCommand: DescribeAvailabilityZonesCommand2,
      DescribeAwsNetworkPerformanceMetricSubscriptionsCommand,
      DescribeBundleTasksCommand,
      DescribeByoipCidrsCommand,
      DescribeCapacityBlockExtensionHistoryCommand,
      DescribeCapacityBlockExtensionOfferingsCommand,
      DescribeCapacityBlockOfferingsCommand,
      DescribeCapacityBlocksCommand,
      DescribeCapacityBlockStatusCommand,
      DescribeCapacityManagerDataExportsCommand,
      DescribeCapacityReservationBillingRequestsCommand,
      DescribeCapacityReservationFleetsCommand,
      DescribeCapacityReservationsCommand,
      DescribeCapacityReservationTopologyCommand,
      DescribeCarrierGatewaysCommand,
      DescribeClassicLinkInstancesCommand,
      DescribeClientVpnAuthorizationRulesCommand,
      DescribeClientVpnConnectionsCommand,
      DescribeClientVpnEndpointsCommand,
      DescribeClientVpnRoutesCommand,
      DescribeClientVpnTargetNetworksCommand,
      DescribeCoipPoolsCommand,
      DescribeConversionTasksCommand,
      DescribeCustomerGatewaysCommand,
      DescribeDeclarativePoliciesReportsCommand,
      DescribeDhcpOptionsCommand,
      DescribeEgressOnlyInternetGatewaysCommand,
      DescribeElasticGpusCommand,
      DescribeExportImageTasksCommand,
      DescribeExportTasksCommand,
      DescribeFastLaunchImagesCommand,
      DescribeFastSnapshotRestoresCommand,
      DescribeFleetHistoryCommand,
      DescribeFleetInstancesCommand,
      DescribeFleetsCommand,
      DescribeFlowLogsCommand,
      DescribeFpgaImageAttributeCommand,
      DescribeFpgaImagesCommand,
      DescribeHostReservationOfferingsCommand,
      DescribeHostReservationsCommand,
      DescribeHostsCommand,
      DescribeIamInstanceProfileAssociationsCommand,
      DescribeIdentityIdFormatCommand,
      DescribeIdFormatCommand,
      DescribeImageAttributeCommand,
      DescribeImageReferencesCommand,
      DescribeImagesCommand: DescribeImagesCommand3,
      DescribeImageUsageReportEntriesCommand,
      DescribeImageUsageReportsCommand,
      DescribeImportImageTasksCommand,
      DescribeImportSnapshotTasksCommand,
      DescribeInstanceAttributeCommand,
      DescribeInstanceConnectEndpointsCommand,
      DescribeInstanceCreditSpecificationsCommand,
      DescribeInstanceEventNotificationAttributesCommand,
      DescribeInstanceEventWindowsCommand,
      DescribeInstanceImageMetadataCommand,
      DescribeInstancesCommand: DescribeInstancesCommand2,
      DescribeInstanceSqlHaHistoryStatesCommand,
      DescribeInstanceSqlHaStatesCommand,
      DescribeInstanceStatusCommand,
      DescribeInstanceTopologyCommand,
      DescribeInstanceTypeOfferingsCommand,
      DescribeInstanceTypesCommand,
      DescribeInternetGatewaysCommand,
      DescribeIpamByoasnCommand,
      DescribeIpamExternalResourceVerificationTokensCommand,
      DescribeIpamPoliciesCommand,
      DescribeIpamPoolsCommand,
      DescribeIpamPrefixListResolversCommand,
      DescribeIpamPrefixListResolverTargetsCommand,
      DescribeIpamResourceDiscoveriesCommand,
      DescribeIpamResourceDiscoveryAssociationsCommand,
      DescribeIpamsCommand,
      DescribeIpamScopesCommand,
      DescribeIpv6PoolsCommand,
      DescribeKeyPairsCommand,
      DescribeLaunchTemplatesCommand,
      DescribeLaunchTemplateVersionsCommand,
      DescribeLocalGatewayRouteTablesCommand,
      DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociationsCommand,
      DescribeLocalGatewayRouteTableVpcAssociationsCommand,
      DescribeLocalGatewaysCommand,
      DescribeLocalGatewayVirtualInterfaceGroupsCommand,
      DescribeLocalGatewayVirtualInterfacesCommand,
      DescribeLockedSnapshotsCommand,
      DescribeMacHostsCommand,
      DescribeMacModificationTasksCommand,
      DescribeManagedPrefixListsCommand,
      DescribeMovingAddressesCommand,
      DescribeNatGatewaysCommand,
      DescribeNetworkAclsCommand,
      DescribeNetworkInsightsAccessScopeAnalysesCommand,
      DescribeNetworkInsightsAccessScopesCommand,
      DescribeNetworkInsightsAnalysesCommand,
      DescribeNetworkInsightsPathsCommand,
      DescribeNetworkInterfaceAttributeCommand,
      DescribeNetworkInterfacePermissionsCommand,
      DescribeNetworkInterfacesCommand,
      DescribeOutpostLagsCommand,
      DescribePlacementGroupsCommand,
      DescribePrefixListsCommand,
      DescribePrincipalIdFormatCommand,
      DescribePublicIpv4PoolsCommand,
      DescribeRegionsCommand,
      DescribeReplaceRootVolumeTasksCommand,
      DescribeReservedInstancesCommand,
      DescribeReservedInstancesListingsCommand,
      DescribeReservedInstancesModificationsCommand,
      DescribeReservedInstancesOfferingsCommand,
      DescribeRouteServerEndpointsCommand,
      DescribeRouteServerPeersCommand,
      DescribeRouteServersCommand,
      DescribeRouteTablesCommand: DescribeRouteTablesCommand2,
      DescribeScheduledInstanceAvailabilityCommand,
      DescribeScheduledInstancesCommand,
      DescribeSecondaryInterfacesCommand,
      DescribeSecondaryNetworksCommand,
      DescribeSecondarySubnetsCommand,
      DescribeSecurityGroupReferencesCommand,
      DescribeSecurityGroupRulesCommand,
      DescribeSecurityGroupsCommand: DescribeSecurityGroupsCommand2,
      DescribeSecurityGroupVpcAssociationsCommand,
      DescribeServiceLinkVirtualInterfacesCommand,
      DescribeSnapshotAttributeCommand,
      DescribeSnapshotsCommand,
      DescribeSnapshotTierStatusCommand,
      DescribeSpotDatafeedSubscriptionCommand,
      DescribeSpotFleetInstancesCommand,
      DescribeSpotFleetRequestHistoryCommand,
      DescribeSpotFleetRequestsCommand,
      DescribeSpotInstanceRequestsCommand,
      DescribeSpotPriceHistoryCommand,
      DescribeStaleSecurityGroupsCommand,
      DescribeStoreImageTasksCommand,
      DescribeSubnetsCommand: DescribeSubnetsCommand2,
      DescribeTagsCommand: DescribeTagsCommand2,
      DescribeTrafficMirrorFilterRulesCommand,
      DescribeTrafficMirrorFiltersCommand,
      DescribeTrafficMirrorSessionsCommand,
      DescribeTrafficMirrorTargetsCommand,
      DescribeTransitGatewayAttachmentsCommand,
      DescribeTransitGatewayConnectPeersCommand,
      DescribeTransitGatewayConnectsCommand,
      DescribeTransitGatewayMeteringPoliciesCommand,
      DescribeTransitGatewayMulticastDomainsCommand,
      DescribeTransitGatewayPeeringAttachmentsCommand,
      DescribeTransitGatewayPolicyTablesCommand,
      DescribeTransitGatewayRouteTableAnnouncementsCommand,
      DescribeTransitGatewayRouteTablesCommand,
      DescribeTransitGatewaysCommand,
      DescribeTransitGatewayVpcAttachmentsCommand,
      DescribeTrunkInterfaceAssociationsCommand,
      DescribeVerifiedAccessEndpointsCommand,
      DescribeVerifiedAccessGroupsCommand,
      DescribeVerifiedAccessInstanceLoggingConfigurationsCommand,
      DescribeVerifiedAccessInstancesCommand,
      DescribeVerifiedAccessTrustProvidersCommand,
      DescribeVolumeAttributeCommand,
      DescribeVolumesCommand,
      DescribeVolumesModificationsCommand,
      DescribeVolumeStatusCommand,
      DescribeVpcAttributeCommand,
      DescribeVpcBlockPublicAccessExclusionsCommand,
      DescribeVpcBlockPublicAccessOptionsCommand,
      DescribeVpcClassicLinkCommand,
      DescribeVpcClassicLinkDnsSupportCommand,
      DescribeVpcEncryptionControlsCommand,
      DescribeVpcEndpointAssociationsCommand,
      DescribeVpcEndpointConnectionNotificationsCommand,
      DescribeVpcEndpointConnectionsCommand,
      DescribeVpcEndpointsCommand,
      DescribeVpcEndpointServiceConfigurationsCommand,
      DescribeVpcEndpointServicePermissionsCommand,
      DescribeVpcEndpointServicesCommand: DescribeVpcEndpointServicesCommand2,
      DescribeVpcPeeringConnectionsCommand,
      DescribeVpcsCommand: DescribeVpcsCommand2,
      DescribeVpnConcentratorsCommand,
      DescribeVpnConnectionsCommand,
      DescribeVpnGatewaysCommand: DescribeVpnGatewaysCommand2,
      DetachClassicLinkVpcCommand,
      DetachInternetGatewayCommand,
      DetachNetworkInterfaceCommand,
      DetachVerifiedAccessTrustProviderCommand,
      DetachVolumeCommand,
      DetachVpnGatewayCommand,
      DisableAddressTransferCommand,
      DisableAllowedImagesSettingsCommand,
      DisableAwsNetworkPerformanceMetricSubscriptionCommand,
      DisableCapacityManagerCommand,
      DisableEbsEncryptionByDefaultCommand,
      DisableFastLaunchCommand,
      DisableFastSnapshotRestoresCommand,
      DisableImageCommand,
      DisableImageBlockPublicAccessCommand,
      DisableImageDeprecationCommand,
      DisableImageDeregistrationProtectionCommand,
      DisableInstanceSqlHaStandbyDetectionsCommand,
      DisableIpamOrganizationAdminAccountCommand,
      DisableIpamPolicyCommand,
      DisableRouteServerPropagationCommand,
      DisableSerialConsoleAccessCommand,
      DisableSnapshotBlockPublicAccessCommand,
      DisableTransitGatewayRouteTablePropagationCommand,
      DisableVgwRoutePropagationCommand,
      DisableVpcClassicLinkCommand,
      DisableVpcClassicLinkDnsSupportCommand,
      DisassociateAddressCommand,
      DisassociateCapacityReservationBillingOwnerCommand,
      DisassociateClientVpnTargetNetworkCommand,
      DisassociateEnclaveCertificateIamRoleCommand,
      DisassociateIamInstanceProfileCommand,
      DisassociateInstanceEventWindowCommand,
      DisassociateIpamByoasnCommand,
      DisassociateIpamResourceDiscoveryCommand,
      DisassociateNatGatewayAddressCommand,
      DisassociateRouteServerCommand,
      DisassociateRouteTableCommand,
      DisassociateSecurityGroupVpcCommand,
      DisassociateSubnetCidrBlockCommand,
      DisassociateTransitGatewayMulticastDomainCommand,
      DisassociateTransitGatewayPolicyTableCommand,
      DisassociateTransitGatewayRouteTableCommand,
      DisassociateTrunkInterfaceCommand,
      DisassociateVpcCidrBlockCommand,
      EnableAddressTransferCommand,
      EnableAllowedImagesSettingsCommand,
      EnableAwsNetworkPerformanceMetricSubscriptionCommand,
      EnableCapacityManagerCommand,
      EnableEbsEncryptionByDefaultCommand,
      EnableFastLaunchCommand,
      EnableFastSnapshotRestoresCommand,
      EnableImageCommand,
      EnableImageBlockPublicAccessCommand,
      EnableImageDeprecationCommand,
      EnableImageDeregistrationProtectionCommand,
      EnableInstanceSqlHaStandbyDetectionsCommand,
      EnableIpamOrganizationAdminAccountCommand,
      EnableIpamPolicyCommand,
      EnableReachabilityAnalyzerOrganizationSharingCommand,
      EnableRouteServerPropagationCommand,
      EnableSerialConsoleAccessCommand,
      EnableSnapshotBlockPublicAccessCommand,
      EnableTransitGatewayRouteTablePropagationCommand,
      EnableVgwRoutePropagationCommand,
      EnableVolumeIOCommand,
      EnableVpcClassicLinkCommand,
      EnableVpcClassicLinkDnsSupportCommand,
      ExportClientVpnClientCertificateRevocationListCommand,
      ExportClientVpnClientConfigurationCommand,
      ExportImageCommand,
      ExportTransitGatewayRoutesCommand,
      ExportVerifiedAccessInstanceClientConfigurationCommand,
      GetActiveVpnTunnelStatusCommand,
      GetAllowedImagesSettingsCommand,
      GetAssociatedEnclaveCertificateIamRolesCommand,
      GetAssociatedIpv6PoolCidrsCommand,
      GetAwsNetworkPerformanceDataCommand,
      GetCapacityManagerAttributesCommand,
      GetCapacityManagerMetricDataCommand,
      GetCapacityManagerMetricDimensionsCommand,
      GetCapacityManagerMonitoredTagKeysCommand,
      GetCapacityReservationUsageCommand,
      GetCoipPoolUsageCommand,
      GetConsoleOutputCommand,
      GetConsoleScreenshotCommand,
      GetDeclarativePoliciesReportSummaryCommand,
      GetDefaultCreditSpecificationCommand,
      GetEbsDefaultKmsKeyIdCommand,
      GetEbsEncryptionByDefaultCommand,
      GetEnabledIpamPolicyCommand,
      GetFlowLogsIntegrationTemplateCommand,
      GetGroupsForCapacityReservationCommand,
      GetHostReservationPurchasePreviewCommand,
      GetImageAncestryCommand,
      GetImageBlockPublicAccessStateCommand,
      GetInstanceMetadataDefaultsCommand,
      GetInstanceTpmEkPubCommand,
      GetInstanceTypesFromInstanceRequirementsCommand,
      GetInstanceUefiDataCommand,
      GetIpamAddressHistoryCommand,
      GetIpamDiscoveredAccountsCommand,
      GetIpamDiscoveredPublicAddressesCommand,
      GetIpamDiscoveredResourceCidrsCommand,
      GetIpamPolicyAllocationRulesCommand,
      GetIpamPolicyOrganizationTargetsCommand,
      GetIpamPoolAllocationsCommand,
      GetIpamPoolCidrsCommand,
      GetIpamPrefixListResolverRulesCommand,
      GetIpamPrefixListResolverVersionEntriesCommand,
      GetIpamPrefixListResolverVersionsCommand,
      GetIpamResourceCidrsCommand,
      GetLaunchTemplateDataCommand,
      GetManagedPrefixListAssociationsCommand,
      GetManagedPrefixListEntriesCommand,
      GetManagedResourceVisibilityCommand,
      GetNetworkInsightsAccessScopeAnalysisFindingsCommand,
      GetNetworkInsightsAccessScopeContentCommand,
      GetPasswordDataCommand,
      GetReservedInstancesExchangeQuoteCommand,
      GetRouteServerAssociationsCommand,
      GetRouteServerPropagationsCommand,
      GetRouteServerRoutingDatabaseCommand,
      GetSecurityGroupsForVpcCommand,
      GetSerialConsoleAccessStatusCommand,
      GetSnapshotBlockPublicAccessStateCommand,
      GetSpotPlacementScoresCommand,
      GetSubnetCidrReservationsCommand,
      GetTransitGatewayAttachmentPropagationsCommand,
      GetTransitGatewayMeteringPolicyEntriesCommand,
      GetTransitGatewayMulticastDomainAssociationsCommand,
      GetTransitGatewayPolicyTableAssociationsCommand,
      GetTransitGatewayPolicyTableEntriesCommand,
      GetTransitGatewayPrefixListReferencesCommand,
      GetTransitGatewayRouteTableAssociationsCommand,
      GetTransitGatewayRouteTablePropagationsCommand,
      GetVerifiedAccessEndpointPolicyCommand,
      GetVerifiedAccessEndpointTargetsCommand,
      GetVerifiedAccessGroupPolicyCommand,
      GetVpcResourcesBlockingEncryptionEnforcementCommand,
      GetVpnConnectionDeviceSampleConfigurationCommand,
      GetVpnConnectionDeviceTypesCommand,
      GetVpnTunnelReplacementStatusCommand,
      ImportClientVpnClientCertificateRevocationListCommand,
      ImportImageCommand,
      ImportInstanceCommand,
      ImportKeyPairCommand,
      ImportSnapshotCommand,
      ImportVolumeCommand,
      ListImagesInRecycleBinCommand,
      ListSnapshotsInRecycleBinCommand,
      ListVolumesInRecycleBinCommand,
      LockSnapshotCommand,
      ModifyAddressAttributeCommand,
      ModifyAvailabilityZoneGroupCommand,
      ModifyCapacityReservationCommand,
      ModifyCapacityReservationFleetCommand,
      ModifyClientVpnEndpointCommand,
      ModifyDefaultCreditSpecificationCommand,
      ModifyEbsDefaultKmsKeyIdCommand,
      ModifyFleetCommand,
      ModifyFpgaImageAttributeCommand,
      ModifyHostsCommand,
      ModifyIdentityIdFormatCommand,
      ModifyIdFormatCommand,
      ModifyImageAttributeCommand,
      ModifyInstanceAttributeCommand,
      ModifyInstanceCapacityReservationAttributesCommand,
      ModifyInstanceConnectEndpointCommand,
      ModifyInstanceCpuOptionsCommand,
      ModifyInstanceCreditSpecificationCommand,
      ModifyInstanceEventStartTimeCommand,
      ModifyInstanceEventWindowCommand,
      ModifyInstanceMaintenanceOptionsCommand,
      ModifyInstanceMetadataDefaultsCommand,
      ModifyInstanceMetadataOptionsCommand,
      ModifyInstanceNetworkPerformanceOptionsCommand,
      ModifyInstancePlacementCommand,
      ModifyIpamCommand,
      ModifyIpamPolicyAllocationRulesCommand,
      ModifyIpamPoolCommand,
      ModifyIpamPrefixListResolverCommand,
      ModifyIpamPrefixListResolverTargetCommand,
      ModifyIpamResourceCidrCommand,
      ModifyIpamResourceDiscoveryCommand,
      ModifyIpamScopeCommand,
      ModifyLaunchTemplateCommand,
      ModifyLocalGatewayRouteCommand,
      ModifyManagedPrefixListCommand,
      ModifyManagedResourceVisibilityCommand,
      ModifyNetworkInterfaceAttributeCommand,
      ModifyPrivateDnsNameOptionsCommand,
      ModifyPublicIpDnsNameOptionsCommand,
      ModifyReservedInstancesCommand,
      ModifyRouteServerCommand,
      ModifySecurityGroupRulesCommand,
      ModifySnapshotAttributeCommand,
      ModifySnapshotTierCommand,
      ModifySpotFleetRequestCommand,
      ModifySubnetAttributeCommand,
      ModifyTrafficMirrorFilterNetworkServicesCommand,
      ModifyTrafficMirrorFilterRuleCommand,
      ModifyTrafficMirrorSessionCommand,
      ModifyTransitGatewayCommand,
      ModifyTransitGatewayMeteringPolicyCommand,
      ModifyTransitGatewayPrefixListReferenceCommand,
      ModifyTransitGatewayVpcAttachmentCommand,
      ModifyVerifiedAccessEndpointCommand,
      ModifyVerifiedAccessEndpointPolicyCommand,
      ModifyVerifiedAccessGroupCommand,
      ModifyVerifiedAccessGroupPolicyCommand,
      ModifyVerifiedAccessInstanceCommand,
      ModifyVerifiedAccessInstanceLoggingConfigurationCommand,
      ModifyVerifiedAccessTrustProviderCommand,
      ModifyVolumeCommand,
      ModifyVolumeAttributeCommand,
      ModifyVpcAttributeCommand,
      ModifyVpcBlockPublicAccessExclusionCommand,
      ModifyVpcBlockPublicAccessOptionsCommand,
      ModifyVpcEncryptionControlCommand,
      ModifyVpcEndpointCommand,
      ModifyVpcEndpointConnectionNotificationCommand,
      ModifyVpcEndpointServiceConfigurationCommand,
      ModifyVpcEndpointServicePayerResponsibilityCommand,
      ModifyVpcEndpointServicePermissionsCommand,
      ModifyVpcPeeringConnectionOptionsCommand,
      ModifyVpcTenancyCommand,
      ModifyVpnConnectionCommand,
      ModifyVpnConnectionOptionsCommand,
      ModifyVpnTunnelCertificateCommand,
      ModifyVpnTunnelOptionsCommand,
      MonitorInstancesCommand,
      MoveAddressToVpcCommand,
      MoveByoipCidrToIpamCommand,
      MoveCapacityReservationInstancesCommand,
      ProvisionByoipCidrCommand,
      ProvisionIpamByoasnCommand,
      ProvisionIpamPoolCidrCommand,
      ProvisionPublicIpv4PoolCidrCommand,
      PurchaseCapacityBlockCommand,
      PurchaseCapacityBlockExtensionCommand,
      PurchaseHostReservationCommand,
      PurchaseReservedInstancesOfferingCommand,
      PurchaseScheduledInstancesCommand,
      RebootInstancesCommand,
      RegisterImageCommand,
      RegisterInstanceEventNotificationAttributesCommand,
      RegisterTransitGatewayMulticastGroupMembersCommand,
      RegisterTransitGatewayMulticastGroupSourcesCommand,
      RejectCapacityReservationBillingOwnershipCommand,
      RejectTransitGatewayClientVpnAttachmentCommand,
      RejectTransitGatewayMulticastDomainAssociationsCommand,
      RejectTransitGatewayPeeringAttachmentCommand,
      RejectTransitGatewayVpcAttachmentCommand,
      RejectVpcEndpointConnectionsCommand,
      RejectVpcPeeringConnectionCommand,
      ReleaseAddressCommand,
      ReleaseHostsCommand,
      ReleaseIpamPoolAllocationCommand,
      ReplaceIamInstanceProfileAssociationCommand,
      ReplaceImageCriteriaInAllowedImagesSettingsCommand,
      ReplaceNetworkAclAssociationCommand,
      ReplaceNetworkAclEntryCommand,
      ReplaceRouteCommand,
      ReplaceRouteTableAssociationCommand,
      ReplaceTransitGatewayRouteCommand,
      ReplaceVpnTunnelCommand,
      ReportInstanceStatusCommand,
      RequestSpotFleetCommand,
      RequestSpotInstancesCommand,
      ResetAddressAttributeCommand,
      ResetEbsDefaultKmsKeyIdCommand,
      ResetFpgaImageAttributeCommand,
      ResetImageAttributeCommand,
      ResetInstanceAttributeCommand,
      ResetNetworkInterfaceAttributeCommand,
      ResetSnapshotAttributeCommand,
      RestoreAddressToClassicCommand,
      RestoreImageFromRecycleBinCommand,
      RestoreManagedPrefixListVersionCommand,
      RestoreSnapshotFromRecycleBinCommand,
      RestoreSnapshotTierCommand,
      RestoreVolumeFromRecycleBinCommand,
      RevokeClientVpnIngressCommand,
      RevokeSecurityGroupEgressCommand,
      RevokeSecurityGroupIngressCommand,
      RunInstancesCommand,
      RunScheduledInstancesCommand,
      SearchLocalGatewayRoutesCommand,
      SearchTransitGatewayMulticastGroupsCommand,
      SearchTransitGatewayRoutesCommand,
      SendDiagnosticInterruptCommand,
      StartDeclarativePoliciesReportCommand,
      StartInstancesCommand,
      StartNetworkInsightsAccessScopeAnalysisCommand,
      StartNetworkInsightsAnalysisCommand,
      StartVpcEndpointServicePrivateDnsVerificationCommand,
      StopInstancesCommand,
      TerminateClientVpnConnectionsCommand,
      TerminateInstancesCommand,
      UnassignIpv6AddressesCommand,
      UnassignPrivateIpAddressesCommand,
      UnassignPrivateNatGatewayAddressCommand,
      UnlockSnapshotCommand,
      UnmonitorInstancesCommand,
      UpdateCapacityManagerMonitoredTagKeysCommand,
      UpdateCapacityManagerOrganizationsAccessCommand,
      UpdateInterruptibleCapacityReservationAllocationCommand,
      UpdateSecurityGroupRuleDescriptionsEgressCommand,
      UpdateSecurityGroupRuleDescriptionsIngressCommand,
      WithdrawByoipCidrCommand
    };
    var paginators = {
      paginateDescribeAddressesAttribute,
      paginateDescribeAddressTransfers,
      paginateDescribeAwsNetworkPerformanceMetricSubscriptions,
      paginateDescribeByoipCidrs,
      paginateDescribeCapacityBlockExtensionHistory,
      paginateDescribeCapacityBlockExtensionOfferings,
      paginateDescribeCapacityBlockOfferings,
      paginateDescribeCapacityBlocks,
      paginateDescribeCapacityBlockStatus,
      paginateDescribeCapacityManagerDataExports,
      paginateDescribeCapacityReservationBillingRequests,
      paginateDescribeCapacityReservationFleets,
      paginateDescribeCapacityReservations,
      paginateDescribeCarrierGateways,
      paginateDescribeClassicLinkInstances,
      paginateDescribeClientVpnAuthorizationRules,
      paginateDescribeClientVpnConnections,
      paginateDescribeClientVpnEndpoints,
      paginateDescribeClientVpnRoutes,
      paginateDescribeClientVpnTargetNetworks,
      paginateDescribeCoipPools,
      paginateDescribeDhcpOptions,
      paginateDescribeEgressOnlyInternetGateways,
      paginateDescribeExportImageTasks,
      paginateDescribeFastLaunchImages,
      paginateDescribeFastSnapshotRestores,
      paginateDescribeFleets,
      paginateDescribeFlowLogs,
      paginateDescribeFpgaImages,
      paginateDescribeHostReservationOfferings,
      paginateDescribeHostReservations,
      paginateDescribeHosts,
      paginateDescribeIamInstanceProfileAssociations,
      paginateDescribeImageReferences,
      paginateDescribeImages,
      paginateDescribeImageUsageReportEntries,
      paginateDescribeImageUsageReports,
      paginateDescribeImportImageTasks,
      paginateDescribeImportSnapshotTasks,
      paginateDescribeInstanceConnectEndpoints,
      paginateDescribeInstanceCreditSpecifications,
      paginateDescribeInstanceEventWindows,
      paginateDescribeInstanceImageMetadata,
      paginateDescribeInstances,
      paginateDescribeInstanceStatus,
      paginateDescribeInstanceTopology,
      paginateDescribeInstanceTypeOfferings,
      paginateDescribeInstanceTypes,
      paginateDescribeInternetGateways,
      paginateDescribeIpamPools,
      paginateDescribeIpamPrefixListResolvers,
      paginateDescribeIpamPrefixListResolverTargets,
      paginateDescribeIpamResourceDiscoveries,
      paginateDescribeIpamResourceDiscoveryAssociations,
      paginateDescribeIpams,
      paginateDescribeIpamScopes,
      paginateDescribeIpv6Pools,
      paginateDescribeLaunchTemplates,
      paginateDescribeLaunchTemplateVersions,
      paginateDescribeLocalGatewayRouteTables,
      paginateDescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociations,
      paginateDescribeLocalGatewayRouteTableVpcAssociations,
      paginateDescribeLocalGateways,
      paginateDescribeLocalGatewayVirtualInterfaceGroups,
      paginateDescribeLocalGatewayVirtualInterfaces,
      paginateDescribeMacHosts,
      paginateDescribeMacModificationTasks,
      paginateDescribeManagedPrefixLists,
      paginateDescribeMovingAddresses,
      paginateDescribeNatGateways,
      paginateDescribeNetworkAcls,
      paginateDescribeNetworkInsightsAccessScopeAnalyses,
      paginateDescribeNetworkInsightsAccessScopes,
      paginateDescribeNetworkInsightsAnalyses,
      paginateDescribeNetworkInsightsPaths,
      paginateDescribeNetworkInterfacePermissions,
      paginateDescribeNetworkInterfaces,
      paginateDescribePrefixLists,
      paginateDescribePrincipalIdFormat,
      paginateDescribePublicIpv4Pools,
      paginateDescribeReplaceRootVolumeTasks,
      paginateDescribeReservedInstancesModifications,
      paginateDescribeReservedInstancesOfferings,
      paginateDescribeRouteServerEndpoints,
      paginateDescribeRouteServerPeers,
      paginateDescribeRouteServers,
      paginateDescribeRouteTables,
      paginateDescribeScheduledInstanceAvailability,
      paginateDescribeScheduledInstances,
      paginateDescribeSecondaryInterfaces,
      paginateDescribeSecondaryNetworks,
      paginateDescribeSecondarySubnets,
      paginateDescribeSecurityGroupRules,
      paginateDescribeSecurityGroups,
      paginateDescribeSecurityGroupVpcAssociations,
      paginateDescribeSnapshots,
      paginateDescribeSnapshotTierStatus,
      paginateDescribeSpotFleetRequests,
      paginateDescribeSpotInstanceRequests,
      paginateDescribeSpotPriceHistory,
      paginateDescribeStaleSecurityGroups,
      paginateDescribeStoreImageTasks,
      paginateDescribeSubnets,
      paginateDescribeTags,
      paginateDescribeTrafficMirrorFilters,
      paginateDescribeTrafficMirrorSessions,
      paginateDescribeTrafficMirrorTargets,
      paginateDescribeTransitGatewayAttachments,
      paginateDescribeTransitGatewayConnectPeers,
      paginateDescribeTransitGatewayConnects,
      paginateDescribeTransitGatewayMulticastDomains,
      paginateDescribeTransitGatewayPeeringAttachments,
      paginateDescribeTransitGatewayPolicyTables,
      paginateDescribeTransitGatewayRouteTableAnnouncements,
      paginateDescribeTransitGatewayRouteTables,
      paginateDescribeTransitGateways,
      paginateDescribeTransitGatewayVpcAttachments,
      paginateDescribeTrunkInterfaceAssociations,
      paginateDescribeVerifiedAccessEndpoints,
      paginateDescribeVerifiedAccessGroups,
      paginateDescribeVerifiedAccessInstanceLoggingConfigurations,
      paginateDescribeVerifiedAccessInstances,
      paginateDescribeVerifiedAccessTrustProviders,
      paginateDescribeVolumes,
      paginateDescribeVolumesModifications,
      paginateDescribeVolumeStatus,
      paginateDescribeVpcClassicLinkDnsSupport,
      paginateDescribeVpcEndpointConnectionNotifications,
      paginateDescribeVpcEndpointConnections,
      paginateDescribeVpcEndpoints,
      paginateDescribeVpcEndpointServiceConfigurations,
      paginateDescribeVpcEndpointServicePermissions,
      paginateDescribeVpcPeeringConnections,
      paginateDescribeVpcs,
      paginateDescribeVpnConcentrators,
      paginateGetAssociatedIpv6PoolCidrs,
      paginateGetAwsNetworkPerformanceData,
      paginateGetCapacityManagerMetricData,
      paginateGetCapacityManagerMetricDimensions,
      paginateGetCapacityManagerMonitoredTagKeys,
      paginateGetGroupsForCapacityReservation,
      paginateGetInstanceTypesFromInstanceRequirements,
      paginateGetIpamAddressHistory,
      paginateGetIpamDiscoveredAccounts,
      paginateGetIpamDiscoveredResourceCidrs,
      paginateGetIpamPoolAllocations,
      paginateGetIpamPoolCidrs,
      paginateGetIpamPrefixListResolverRules,
      paginateGetIpamPrefixListResolverVersionEntries,
      paginateGetIpamPrefixListResolverVersions,
      paginateGetIpamResourceCidrs,
      paginateGetManagedPrefixListAssociations,
      paginateGetManagedPrefixListEntries,
      paginateGetNetworkInsightsAccessScopeAnalysisFindings,
      paginateGetSecurityGroupsForVpc,
      paginateGetSpotPlacementScores,
      paginateGetTransitGatewayAttachmentPropagations,
      paginateGetTransitGatewayMulticastDomainAssociations,
      paginateGetTransitGatewayPolicyTableAssociations,
      paginateGetTransitGatewayPrefixListReferences,
      paginateGetTransitGatewayRouteTableAssociations,
      paginateGetTransitGatewayRouteTablePropagations,
      paginateGetVpnConnectionDeviceTypes,
      paginateListImagesInRecycleBin,
      paginateListSnapshotsInRecycleBin,
      paginateSearchLocalGatewayRoutes,
      paginateSearchTransitGatewayMulticastGroups,
      paginateSearchTransitGatewayRoutes
    };
    var waiters = {
      waitUntilBundleTaskComplete,
      waitUntilConversionTaskCancelled,
      waitUntilConversionTaskCompleted,
      waitUntilConversionTaskDeleted,
      waitUntilCustomerGatewayAvailable,
      waitUntilExportTaskCancelled,
      waitUntilExportTaskCompleted,
      waitUntilImageAvailable,
      waitUntilImageExists,
      waitUntilImageUsageReportAvailable,
      waitUntilSnapshotImported,
      waitUntilInstanceExists,
      waitUntilInstanceRunning,
      waitUntilInstanceStopped,
      waitUntilInstanceTerminated,
      waitUntilInstanceStatusOk,
      waitUntilSystemStatusOk,
      waitUntilInternetGatewayExists,
      waitUntilKeyPairExists,
      waitUntilNatGatewayAvailable,
      waitUntilNatGatewayDeleted,
      waitUntilNetworkInterfaceAvailable,
      waitUntilSecondaryNetworkCreateComplete,
      waitUntilSecondaryNetworkDeleteComplete,
      waitUntilSecondarySubnetCreateComplete,
      waitUntilSecondarySubnetDeleteComplete,
      waitUntilSecurityGroupExists,
      waitUntilSecurityGroupVpcAssociationAssociated,
      waitUntilSecurityGroupVpcAssociationDisassociated,
      waitUntilSnapshotCompleted,
      waitUntilSpotInstanceRequestFulfilled,
      waitUntilStoreImageTaskComplete,
      waitUntilSubnetAvailable,
      waitUntilVolumeAvailable,
      waitUntilVolumeDeleted,
      waitUntilVolumeInUse,
      waitUntilVpcPeeringConnectionDeleted,
      waitUntilVpcPeeringConnectionExists,
      waitUntilVpcAvailable,
      waitUntilVpcExists,
      waitUntilVpnConnectionAvailable,
      waitUntilVpnConnectionDeleted,
      waitUntilPasswordDataAvailable
    };
    var EC2 = class extends EC2Client2 {
      static {
        __name(this, "EC2");
      }
    };
    smithyClient.createAggregatedClient(commands32, EC2, { paginators, waiters });
    var AcceleratorManufacturer = {
      AMAZON_WEB_SERVICES: "amazon-web-services",
      AMD: "amd",
      HABANA: "habana",
      NVIDIA: "nvidia",
      XILINX: "xilinx"
    };
    var AcceleratorName = {
      A100: "a100",
      A10G: "a10g",
      GAUDI_HL_205: "gaudi-hl-205",
      H100: "h100",
      INFERENTIA: "inferentia",
      INFERENTIA2: "inferentia2",
      K520: "k520",
      K80: "k80",
      L4: "l4",
      L40S: "l40s",
      M60: "m60",
      RADEON_PRO_V520: "radeon-pro-v520",
      T4: "t4",
      T4G: "t4g",
      TRAINIUM: "trainium",
      TRAINIUM2: "trainium2",
      U30: "u30",
      V100: "v100",
      VU9P: "vu9p"
    };
    var AcceleratorType = {
      FPGA: "fpga",
      GPU: "gpu",
      INFERENCE: "inference",
      MEDIA: "media"
    };
    var ResourceType = {
      capacity_block: "capacity-block",
      capacity_manager_data_export: "capacity-manager-data-export",
      capacity_reservation: "capacity-reservation",
      capacity_reservation_fleet: "capacity-reservation-fleet",
      carrier_gateway: "carrier-gateway",
      client_vpn_endpoint: "client-vpn-endpoint",
      coip_pool: "coip-pool",
      customer_gateway: "customer-gateway",
      declarative_policies_report: "declarative-policies-report",
      dedicated_host: "dedicated-host",
      dhcp_options: "dhcp-options",
      egress_only_internet_gateway: "egress-only-internet-gateway",
      elastic_gpu: "elastic-gpu",
      elastic_ip: "elastic-ip",
      export_image_task: "export-image-task",
      export_instance_task: "export-instance-task",
      fleet: "fleet",
      fpga_image: "fpga-image",
      host_reservation: "host-reservation",
      image: "image",
      image_usage_report: "image-usage-report",
      import_image_task: "import-image-task",
      import_snapshot_task: "import-snapshot-task",
      instance: "instance",
      instance_connect_endpoint: "instance-connect-endpoint",
      instance_event_window: "instance-event-window",
      internet_gateway: "internet-gateway",
      ipam: "ipam",
      ipam_external_resource_verification_token: "ipam-external-resource-verification-token",
      ipam_policy: "ipam-policy",
      ipam_pool: "ipam-pool",
      ipam_prefix_list_resolver: "ipam-prefix-list-resolver",
      ipam_prefix_list_resolver_target: "ipam-prefix-list-resolver-target",
      ipam_resource_discovery: "ipam-resource-discovery",
      ipam_resource_discovery_association: "ipam-resource-discovery-association",
      ipam_scope: "ipam-scope",
      ipv4pool_ec2: "ipv4pool-ec2",
      ipv6pool_ec2: "ipv6pool-ec2",
      key_pair: "key-pair",
      launch_template: "launch-template",
      local_gateway: "local-gateway",
      local_gateway_route_table: "local-gateway-route-table",
      local_gateway_route_table_virtual_interface_group_association: "local-gateway-route-table-virtual-interface-group-association",
      local_gateway_route_table_vpc_association: "local-gateway-route-table-vpc-association",
      local_gateway_virtual_interface: "local-gateway-virtual-interface",
      local_gateway_virtual_interface_group: "local-gateway-virtual-interface-group",
      mac_modification_task: "mac-modification-task",
      natgateway: "natgateway",
      network_acl: "network-acl",
      network_insights_access_scope: "network-insights-access-scope",
      network_insights_access_scope_analysis: "network-insights-access-scope-analysis",
      network_insights_analysis: "network-insights-analysis",
      network_insights_path: "network-insights-path",
      network_interface: "network-interface",
      outpost_lag: "outpost-lag",
      placement_group: "placement-group",
      prefix_list: "prefix-list",
      replace_root_volume_task: "replace-root-volume-task",
      reserved_instances: "reserved-instances",
      route_server: "route-server",
      route_server_endpoint: "route-server-endpoint",
      route_server_peer: "route-server-peer",
      route_table: "route-table",
      secondary_interface: "secondary-interface",
      secondary_network: "secondary-network",
      secondary_subnet: "secondary-subnet",
      security_group: "security-group",
      security_group_rule: "security-group-rule",
      service_link_virtual_interface: "service-link-virtual-interface",
      snapshot: "snapshot",
      spot_fleet_request: "spot-fleet-request",
      spot_instances_request: "spot-instances-request",
      subnet: "subnet",
      subnet_cidr_reservation: "subnet-cidr-reservation",
      traffic_mirror_filter: "traffic-mirror-filter",
      traffic_mirror_filter_rule: "traffic-mirror-filter-rule",
      traffic_mirror_session: "traffic-mirror-session",
      traffic_mirror_target: "traffic-mirror-target",
      transit_gateway: "transit-gateway",
      transit_gateway_attachment: "transit-gateway-attachment",
      transit_gateway_connect_peer: "transit-gateway-connect-peer",
      transit_gateway_metering_policy: "transit-gateway-metering-policy",
      transit_gateway_multicast_domain: "transit-gateway-multicast-domain",
      transit_gateway_policy_table: "transit-gateway-policy-table",
      transit_gateway_route_table: "transit-gateway-route-table",
      transit_gateway_route_table_announcement: "transit-gateway-route-table-announcement",
      verified_access_endpoint: "verified-access-endpoint",
      verified_access_endpoint_target: "verified-access-endpoint-target",
      verified_access_group: "verified-access-group",
      verified_access_instance: "verified-access-instance",
      verified_access_policy: "verified-access-policy",
      verified_access_trust_provider: "verified-access-trust-provider",
      volume: "volume",
      vpc: "vpc",
      vpc_block_public_access_exclusion: "vpc-block-public-access-exclusion",
      vpc_encryption_control: "vpc-encryption-control",
      vpc_endpoint: "vpc-endpoint",
      vpc_endpoint_connection: "vpc-endpoint-connection",
      vpc_endpoint_connection_device_type: "vpc-endpoint-connection-device-type",
      vpc_endpoint_service: "vpc-endpoint-service",
      vpc_endpoint_service_permission: "vpc-endpoint-service-permission",
      vpc_flow_log: "vpc-flow-log",
      vpc_peering_connection: "vpc-peering-connection",
      vpn_concentrator: "vpn-concentrator",
      vpn_connection: "vpn-connection",
      vpn_connection_device_type: "vpn-connection-device-type",
      vpn_gateway: "vpn-gateway"
    };
    var AddressTransferStatus = {
      accepted: "accepted",
      disabled: "disabled",
      pending: "pending"
    };
    var TransitGatewayAttachmentStatusType = {
      available: "available",
      deleted: "deleted",
      deleting: "deleting",
      pending: "pending",
      pending_acceptance: "pending-acceptance",
      rejected: "rejected"
    };
    var TransitGatewayAttachmentResourceType = {
      client_vpn: "client-vpn",
      connect: "connect",
      direct_connect_gateway: "direct-connect-gateway",
      network_function: "network-function",
      peering: "peering",
      tgw_peering: "tgw-peering",
      vpc: "vpc",
      vpn: "vpn",
      vpn_concentrator: "vpn-concentrator"
    };
    var TransitGatewayMulitcastDomainAssociationState = {
      associated: "associated",
      associating: "associating",
      disassociated: "disassociated",
      disassociating: "disassociating",
      failed: "failed",
      pendingAcceptance: "pendingAcceptance",
      rejected: "rejected"
    };
    var DynamicRoutingValue = {
      disable: "disable",
      enable: "enable"
    };
    var TransitGatewayAttachmentState = {
      available: "available",
      deleted: "deleted",
      deleting: "deleting",
      failed: "failed",
      failing: "failing",
      initiating: "initiating",
      initiatingRequest: "initiatingRequest",
      modifying: "modifying",
      pending: "pending",
      pendingAcceptance: "pendingAcceptance",
      rejected: "rejected",
      rejecting: "rejecting",
      rollingBack: "rollingBack"
    };
    var ApplianceModeSupportValue = {
      disable: "disable",
      enable: "enable"
    };
    var DnsSupportValue = {
      disable: "disable",
      enable: "enable"
    };
    var Ipv6SupportValue = {
      disable: "disable",
      enable: "enable"
    };
    var SecurityGroupReferencingSupportValue = {
      disable: "disable",
      enable: "enable"
    };
    var VpcPeeringConnectionStateReasonCode = {
      active: "active",
      deleted: "deleted",
      deleting: "deleting",
      expired: "expired",
      failed: "failed",
      initiating_request: "initiating-request",
      pending_acceptance: "pending-acceptance",
      provisioning: "provisioning",
      rejected: "rejected"
    };
    var Protocol = {
      tcp: "tcp",
      udp: "udp"
    };
    var AccountAttributeName = {
      default_vpc: "default-vpc",
      supported_platforms: "supported-platforms"
    };
    var InstanceHealthStatus = {
      HEALTHY_STATUS: "healthy",
      UNHEALTHY_STATUS: "unhealthy"
    };
    var VpnTunnelProvisioningStatus = {
      available: "available",
      failed: "failed",
      pending: "pending"
    };
    var ActivityStatus = {
      ERROR: "error",
      FULFILLED: "fulfilled",
      PENDING_FULFILLMENT: "pending_fulfillment",
      PENDING_TERMINATION: "pending_termination"
    };
    var PrincipalType = {
      Account: "Account",
      All: "All",
      OrganizationUnit: "OrganizationUnit",
      Role: "Role",
      Service: "Service",
      User: "User"
    };
    var DomainType = {
      standard: "standard",
      vpc: "vpc"
    };
    var ServiceManaged = {
      alb: "alb",
      nlb: "nlb",
      rds: "rds",
      rnat: "rnat"
    };
    var AddressAttributeName = {
      domain_name: "domain-name"
    };
    var AddressFamily = {
      ipv4: "ipv4",
      ipv6: "ipv6"
    };
    var AsnAssociationState = {
      associated: "associated",
      disassociated: "disassociated",
      failed_association: "failed-association",
      failed_disassociation: "failed-disassociation",
      pending_association: "pending-association",
      pending_disassociation: "pending-disassociation"
    };
    var ByoipCidrState = {
      advertised: "advertised",
      deprovisioned: "deprovisioned",
      failed_deprovision: "failed-deprovision",
      failed_provision: "failed-provision",
      pending_advertising: "pending-advertising",
      pending_deprovision: "pending-deprovision",
      pending_provision: "pending-provision",
      pending_withdrawal: "pending-withdrawal",
      provisioned: "provisioned",
      provisioned_not_publicly_advertisable: "provisioned-not-publicly-advertisable"
    };
    var Affinity = {
      default: "default",
      host: "host"
    };
    var AutoPlacement = {
      off: "off",
      on: "on"
    };
    var HostMaintenance = {
      off: "off",
      on: "on"
    };
    var HostRecovery = {
      off: "off",
      on: "on"
    };
    var IpamPoolAllocationResourceType = {
      anycast_ip_list: "anycast-ip-list",
      custom: "custom",
      ec2_public_ipv4_pool: "ec2-public-ipv4-pool",
      eip: "eip",
      ipam_pool: "ipam-pool",
      subnet: "subnet",
      vpc: "vpc"
    };
    var AllocationState = {
      available: "available",
      pending: "pending",
      permanent_failure: "permanent-failure",
      released: "released",
      released_permanent_failure: "released-permanent-failure",
      under_assessment: "under-assessment"
    };
    var AllocationStrategy = {
      CAPACITY_OPTIMIZED: "capacityOptimized",
      CAPACITY_OPTIMIZED_PRIORITIZED: "capacityOptimizedPrioritized",
      DIVERSIFIED: "diversified",
      LOWEST_PRICE: "lowestPrice",
      PRICE_CAPACITY_OPTIMIZED: "priceCapacityOptimized"
    };
    var AllocationType = {
      future: "future",
      used: "used"
    };
    var AllowedImagesSettingsDisabledState = {
      disabled: "disabled"
    };
    var AllowedImagesSettingsEnabledState = {
      audit_mode: "audit-mode",
      enabled: "enabled"
    };
    var AllowsMultipleInstanceTypes = {
      off: "off",
      on: "on"
    };
    var NatGatewayAddressStatus = {
      ASSIGNING: "assigning",
      ASSOCIATING: "associating",
      DISASSOCIATING: "disassociating",
      FAILED: "failed",
      SUCCEEDED: "succeeded",
      UNASSIGNING: "unassigning"
    };
    var AssociationStatusCode = {
      associated: "associated",
      associating: "associating",
      association_failed: "association-failed",
      disassociated: "disassociated",
      disassociating: "disassociating"
    };
    var IamInstanceProfileAssociationState = {
      ASSOCIATED: "associated",
      ASSOCIATING: "associating",
      DISASSOCIATED: "disassociated",
      DISASSOCIATING: "disassociating"
    };
    var InstanceEventWindowState = {
      active: "active",
      creating: "creating",
      deleted: "deleted",
      deleting: "deleting"
    };
    var WeekDay = {
      friday: "friday",
      monday: "monday",
      saturday: "saturday",
      sunday: "sunday",
      thursday: "thursday",
      tuesday: "tuesday",
      wednesday: "wednesday"
    };
    var IpamAssociatedResourceDiscoveryStatus = {
      ACTIVE: "active",
      NOT_FOUND: "not-found"
    };
    var IpamResourceDiscoveryAssociationState = {
      ASSOCIATE_COMPLETE: "associate-complete",
      ASSOCIATE_FAILED: "associate-failed",
      ASSOCIATE_IN_PROGRESS: "associate-in-progress",
      DISASSOCIATE_COMPLETE: "disassociate-complete",
      DISASSOCIATE_FAILED: "disassociate-failed",
      DISASSOCIATE_IN_PROGRESS: "disassociate-in-progress",
      ISOLATE_COMPLETE: "isolate-complete",
      ISOLATE_IN_PROGRESS: "isolate-in-progress",
      RESTORE_IN_PROGRESS: "restore-in-progress"
    };
    var RouteServerAssociationState = {
      ASSOCIATED: "associated",
      ASSOCIATING: "associating",
      DISASSOCIATING: "disassociating"
    };
    var RouteTableAssociationStateCode = {
      associated: "associated",
      associating: "associating",
      disassociated: "disassociated",
      disassociating: "disassociating",
      failed: "failed"
    };
    var SecurityGroupVpcAssociationState = {
      associated: "associated",
      associating: "associating",
      association_failed: "association-failed",
      disassociated: "disassociated",
      disassociating: "disassociating",
      disassociation_failed: "disassociation-failed"
    };
    var IpSource = {
      amazon: "amazon",
      byoip: "byoip",
      none: "none"
    };
    var Ipv6AddressAttribute = {
      private: "private",
      public: "public"
    };
    var SubnetCidrBlockStateCode = {
      associated: "associated",
      associating: "associating",
      disassociated: "disassociated",
      disassociating: "disassociating",
      failed: "failed",
      failing: "failing"
    };
    var TransitGatewayAssociationState = {
      associated: "associated",
      associating: "associating",
      disassociated: "disassociated",
      disassociating: "disassociating"
    };
    var InterfaceProtocolType = {
      GRE: "GRE",
      VLAN: "VLAN"
    };
    var VpcCidrBlockStateCode = {
      associated: "associated",
      associating: "associating",
      disassociated: "disassociated",
      disassociating: "disassociating",
      failed: "failed",
      failing: "failing"
    };
    var DeviceTrustProviderType = {
      crowdstrike: "crowdstrike",
      jamf: "jamf",
      jumpcloud: "jumpcloud"
    };
    var TrustProviderType = {
      device: "device",
      user: "user"
    };
    var UserTrustProviderType = {
      iam_identity_center: "iam-identity-center",
      oidc: "oidc"
    };
    var VolumeAttachmentState = {
      attached: "attached",
      attaching: "attaching",
      busy: "busy",
      detached: "detached",
      detaching: "detaching"
    };
    var AttachmentStatus = {
      attached: "attached",
      attaching: "attaching",
      detached: "detached",
      detaching: "detaching"
    };
    var ClientVpnAuthorizationRuleStatusCode = {
      active: "active",
      authorizing: "authorizing",
      failed: "failed",
      revoking: "revoking"
    };
    var BundleTaskState = {
      bundling: "bundling",
      cancelling: "cancelling",
      complete: "complete",
      failed: "failed",
      pending: "pending",
      storing: "storing",
      waiting_for_shutdown: "waiting-for-shutdown"
    };
    var CapacityReservationFleetState = {
      ACTIVE: "active",
      CANCELLED: "cancelled",
      CANCELLING: "cancelling",
      EXPIRED: "expired",
      EXPIRING: "expiring",
      FAILED: "failed",
      MODIFYING: "modifying",
      PARTIALLY_FULFILLED: "partially_fulfilled",
      SUBMITTED: "submitted"
    };
    var ListingState = {
      available: "available",
      cancelled: "cancelled",
      pending: "pending",
      sold: "sold"
    };
    var CurrencyCodeValues = {
      USD: "USD"
    };
    var ListingStatus = {
      active: "active",
      cancelled: "cancelled",
      closed: "closed",
      pending: "pending"
    };
    var BatchState = {
      ACTIVE: "active",
      CANCELLED: "cancelled",
      CANCELLED_RUNNING: "cancelled_running",
      CANCELLED_TERMINATING_INSTANCES: "cancelled_terminating",
      FAILED: "failed",
      MODIFYING: "modifying",
      SUBMITTED: "submitted"
    };
    var CancelBatchErrorCode = {
      FLEET_REQUEST_ID_DOES_NOT_EXIST: "fleetRequestIdDoesNotExist",
      FLEET_REQUEST_ID_MALFORMED: "fleetRequestIdMalformed",
      FLEET_REQUEST_NOT_IN_CANCELLABLE_STATE: "fleetRequestNotInCancellableState",
      UNEXPECTED_ERROR: "unexpectedError"
    };
    var CancelSpotInstanceRequestState = {
      active: "active",
      cancelled: "cancelled",
      closed: "closed",
      completed: "completed",
      open: "open"
    };
    var VolumeType = {
      gp2: "gp2",
      gp3: "gp3",
      io1: "io1",
      io2: "io2",
      sc1: "sc1",
      st1: "st1",
      standard: "standard"
    };
    var SSEType = {
      none: "none",
      sse_ebs: "sse-ebs",
      sse_kms: "sse-kms"
    };
    var VolumeState = {
      available: "available",
      creating: "creating",
      deleted: "deleted",
      deleting: "deleting",
      error: "error",
      in_use: "in-use"
    };
    var OutputFormat = {
      CSV: "csv",
      PARQUET: "parquet"
    };
    var Schedule = {
      HOURLY: "hourly"
    };
    var CapacityReservationDeliveryPreference = {
      FIXED: "fixed",
      INCREMENTAL: "incremental"
    };
    var EndDateType = {
      limited: "limited",
      unlimited: "unlimited"
    };
    var InstanceMatchCriteria = {
      open: "open",
      targeted: "targeted"
    };
    var CapacityReservationInstancePlatform = {
      LINUX_UNIX: "Linux/UNIX",
      LINUX_WITH_SQL_SERVER_ENTERPRISE: "Linux with SQL Server Enterprise",
      LINUX_WITH_SQL_SERVER_STANDARD: "Linux with SQL Server Standard",
      LINUX_WITH_SQL_SERVER_WEB: "Linux with SQL Server Web",
      RED_HAT_ENTERPRISE_LINUX: "Red Hat Enterprise Linux",
      RHEL_WITH_HA: "RHEL with HA",
      RHEL_WITH_HA_AND_SQL_SERVER_ENTERPRISE: "RHEL with HA and SQL Server Enterprise",
      RHEL_WITH_HA_AND_SQL_SERVER_STANDARD: "RHEL with HA and SQL Server Standard",
      RHEL_WITH_SQL_SERVER_ENTERPRISE: "RHEL with SQL Server Enterprise",
      RHEL_WITH_SQL_SERVER_STANDARD: "RHEL with SQL Server Standard",
      RHEL_WITH_SQL_SERVER_WEB: "RHEL with SQL Server Web",
      SUSE_LINUX: "SUSE Linux",
      UBUNTU_PRO_LINUX: "Ubuntu Pro",
      WINDOWS: "Windows",
      WINDOWS_WITH_SQL_SERVER: "Windows with SQL Server",
      WINDOWS_WITH_SQL_SERVER_ENTERPRISE: "Windows with SQL Server Enterprise",
      WINDOWS_WITH_SQL_SERVER_STANDARD: "Windows with SQL Server Standard",
      WINDOWS_WITH_SQL_SERVER_WEB: "Windows with SQL Server Web"
    };
    var CapacityReservationTenancy = {
      dedicated: "dedicated",
      default: "default"
    };
    var InterruptionType = {
      adhoc: "adhoc"
    };
    var InterruptibleCapacityReservationAllocationStatus = {
      active: "active",
      canceled: "canceled",
      canceling: "canceling",
      failed: "failed",
      pending: "pending",
      updating: "updating"
    };
    var CapacityReservationType = {
      CAPACITY_BLOCK: "capacity-block",
      DEFAULT: "default"
    };
    var CapacityReservationState = {
      active: "active",
      assessing: "assessing",
      cancelled: "cancelled",
      delayed: "delayed",
      expired: "expired",
      failed: "failed",
      payment_failed: "payment-failed",
      payment_pending: "payment-pending",
      pending: "pending",
      scheduled: "scheduled",
      unavailable: "unavailable",
      unsupported: "unsupported"
    };
    var FleetInstanceMatchCriteria = {
      open: "open"
    };
    var _InstanceType = {
      a1_2xlarge: "a1.2xlarge",
      a1_4xlarge: "a1.4xlarge",
      a1_large: "a1.large",
      a1_medium: "a1.medium",
      a1_metal: "a1.metal",
      a1_xlarge: "a1.xlarge",
      c1_medium: "c1.medium",
      c1_xlarge: "c1.xlarge",
      c3_2xlarge: "c3.2xlarge",
      c3_4xlarge: "c3.4xlarge",
      c3_8xlarge: "c3.8xlarge",
      c3_large: "c3.large",
      c3_xlarge: "c3.xlarge",
      c4_2xlarge: "c4.2xlarge",
      c4_4xlarge: "c4.4xlarge",
      c4_8xlarge: "c4.8xlarge",
      c4_large: "c4.large",
      c4_xlarge: "c4.xlarge",
      c5_12xlarge: "c5.12xlarge",
      c5_18xlarge: "c5.18xlarge",
      c5_24xlarge: "c5.24xlarge",
      c5_2xlarge: "c5.2xlarge",
      c5_4xlarge: "c5.4xlarge",
      c5_9xlarge: "c5.9xlarge",
      c5_large: "c5.large",
      c5_metal: "c5.metal",
      c5_xlarge: "c5.xlarge",
      c5a_12xlarge: "c5a.12xlarge",
      c5a_16xlarge: "c5a.16xlarge",
      c5a_24xlarge: "c5a.24xlarge",
      c5a_2xlarge: "c5a.2xlarge",
      c5a_4xlarge: "c5a.4xlarge",
      c5a_8xlarge: "c5a.8xlarge",
      c5a_large: "c5a.large",
      c5a_xlarge: "c5a.xlarge",
      c5ad_12xlarge: "c5ad.12xlarge",
      c5ad_16xlarge: "c5ad.16xlarge",
      c5ad_24xlarge: "c5ad.24xlarge",
      c5ad_2xlarge: "c5ad.2xlarge",
      c5ad_4xlarge: "c5ad.4xlarge",
      c5ad_8xlarge: "c5ad.8xlarge",
      c5ad_large: "c5ad.large",
      c5ad_xlarge: "c5ad.xlarge",
      c5d_12xlarge: "c5d.12xlarge",
      c5d_18xlarge: "c5d.18xlarge",
      c5d_24xlarge: "c5d.24xlarge",
      c5d_2xlarge: "c5d.2xlarge",
      c5d_4xlarge: "c5d.4xlarge",
      c5d_9xlarge: "c5d.9xlarge",
      c5d_large: "c5d.large",
      c5d_metal: "c5d.metal",
      c5d_xlarge: "c5d.xlarge",
      c5n_18xlarge: "c5n.18xlarge",
      c5n_2xlarge: "c5n.2xlarge",
      c5n_4xlarge: "c5n.4xlarge",
      c5n_9xlarge: "c5n.9xlarge",
      c5n_large: "c5n.large",
      c5n_metal: "c5n.metal",
      c5n_xlarge: "c5n.xlarge",
      c6a_12xlarge: "c6a.12xlarge",
      c6a_16xlarge: "c6a.16xlarge",
      c6a_24xlarge: "c6a.24xlarge",
      c6a_2xlarge: "c6a.2xlarge",
      c6a_32xlarge: "c6a.32xlarge",
      c6a_48xlarge: "c6a.48xlarge",
      c6a_4xlarge: "c6a.4xlarge",
      c6a_8xlarge: "c6a.8xlarge",
      c6a_large: "c6a.large",
      c6a_metal: "c6a.metal",
      c6a_xlarge: "c6a.xlarge",
      c6g_12xlarge: "c6g.12xlarge",
      c6g_16xlarge: "c6g.16xlarge",
      c6g_2xlarge: "c6g.2xlarge",
      c6g_4xlarge: "c6g.4xlarge",
      c6g_8xlarge: "c6g.8xlarge",
      c6g_large: "c6g.large",
      c6g_medium: "c6g.medium",
      c6g_metal: "c6g.metal",
      c6g_xlarge: "c6g.xlarge",
      c6gd_12xlarge: "c6gd.12xlarge",
      c6gd_16xlarge: "c6gd.16xlarge",
      c6gd_2xlarge: "c6gd.2xlarge",
      c6gd_4xlarge: "c6gd.4xlarge",
      c6gd_8xlarge: "c6gd.8xlarge",
      c6gd_large: "c6gd.large",
      c6gd_medium: "c6gd.medium",
      c6gd_metal: "c6gd.metal",
      c6gd_xlarge: "c6gd.xlarge",
      c6gn_12xlarge: "c6gn.12xlarge",
      c6gn_16xlarge: "c6gn.16xlarge",
      c6gn_2xlarge: "c6gn.2xlarge",
      c6gn_4xlarge: "c6gn.4xlarge",
      c6gn_8xlarge: "c6gn.8xlarge",
      c6gn_large: "c6gn.large",
      c6gn_medium: "c6gn.medium",
      c6gn_xlarge: "c6gn.xlarge",
      c6i_12xlarge: "c6i.12xlarge",
      c6i_16xlarge: "c6i.16xlarge",
      c6i_24xlarge: "c6i.24xlarge",
      c6i_2xlarge: "c6i.2xlarge",
      c6i_32xlarge: "c6i.32xlarge",
      c6i_4xlarge: "c6i.4xlarge",
      c6i_8xlarge: "c6i.8xlarge",
      c6i_large: "c6i.large",
      c6i_metal: "c6i.metal",
      c6i_xlarge: "c6i.xlarge",
      c6id_12xlarge: "c6id.12xlarge",
      c6id_16xlarge: "c6id.16xlarge",
      c6id_24xlarge: "c6id.24xlarge",
      c6id_2xlarge: "c6id.2xlarge",
      c6id_32xlarge: "c6id.32xlarge",
      c6id_4xlarge: "c6id.4xlarge",
      c6id_8xlarge: "c6id.8xlarge",
      c6id_large: "c6id.large",
      c6id_metal: "c6id.metal",
      c6id_xlarge: "c6id.xlarge",
      c6in_12xlarge: "c6in.12xlarge",
      c6in_16xlarge: "c6in.16xlarge",
      c6in_24xlarge: "c6in.24xlarge",
      c6in_2xlarge: "c6in.2xlarge",
      c6in_32xlarge: "c6in.32xlarge",
      c6in_4xlarge: "c6in.4xlarge",
      c6in_8xlarge: "c6in.8xlarge",
      c6in_large: "c6in.large",
      c6in_metal: "c6in.metal",
      c6in_xlarge: "c6in.xlarge",
      c7a_12xlarge: "c7a.12xlarge",
      c7a_16xlarge: "c7a.16xlarge",
      c7a_24xlarge: "c7a.24xlarge",
      c7a_2xlarge: "c7a.2xlarge",
      c7a_32xlarge: "c7a.32xlarge",
      c7a_48xlarge: "c7a.48xlarge",
      c7a_4xlarge: "c7a.4xlarge",
      c7a_8xlarge: "c7a.8xlarge",
      c7a_large: "c7a.large",
      c7a_medium: "c7a.medium",
      c7a_metal_48xl: "c7a.metal-48xl",
      c7a_xlarge: "c7a.xlarge",
      c7g_12xlarge: "c7g.12xlarge",
      c7g_16xlarge: "c7g.16xlarge",
      c7g_2xlarge: "c7g.2xlarge",
      c7g_4xlarge: "c7g.4xlarge",
      c7g_8xlarge: "c7g.8xlarge",
      c7g_large: "c7g.large",
      c7g_medium: "c7g.medium",
      c7g_metal: "c7g.metal",
      c7g_xlarge: "c7g.xlarge",
      c7gd_12xlarge: "c7gd.12xlarge",
      c7gd_16xlarge: "c7gd.16xlarge",
      c7gd_2xlarge: "c7gd.2xlarge",
      c7gd_4xlarge: "c7gd.4xlarge",
      c7gd_8xlarge: "c7gd.8xlarge",
      c7gd_large: "c7gd.large",
      c7gd_medium: "c7gd.medium",
      c7gd_metal: "c7gd.metal",
      c7gd_xlarge: "c7gd.xlarge",
      c7gn_12xlarge: "c7gn.12xlarge",
      c7gn_16xlarge: "c7gn.16xlarge",
      c7gn_2xlarge: "c7gn.2xlarge",
      c7gn_4xlarge: "c7gn.4xlarge",
      c7gn_8xlarge: "c7gn.8xlarge",
      c7gn_large: "c7gn.large",
      c7gn_medium: "c7gn.medium",
      c7gn_metal: "c7gn.metal",
      c7gn_xlarge: "c7gn.xlarge",
      c7i_12xlarge: "c7i.12xlarge",
      c7i_16xlarge: "c7i.16xlarge",
      c7i_24xlarge: "c7i.24xlarge",
      c7i_2xlarge: "c7i.2xlarge",
      c7i_48xlarge: "c7i.48xlarge",
      c7i_4xlarge: "c7i.4xlarge",
      c7i_8xlarge: "c7i.8xlarge",
      c7i_flex_12xlarge: "c7i-flex.12xlarge",
      c7i_flex_16xlarge: "c7i-flex.16xlarge",
      c7i_flex_2xlarge: "c7i-flex.2xlarge",
      c7i_flex_4xlarge: "c7i-flex.4xlarge",
      c7i_flex_8xlarge: "c7i-flex.8xlarge",
      c7i_flex_large: "c7i-flex.large",
      c7i_flex_xlarge: "c7i-flex.xlarge",
      c7i_large: "c7i.large",
      c7i_metal_24xl: "c7i.metal-24xl",
      c7i_metal_48xl: "c7i.metal-48xl",
      c7i_xlarge: "c7i.xlarge",
      c8a_12xlarge: "c8a.12xlarge",
      c8a_16xlarge: "c8a.16xlarge",
      c8a_24xlarge: "c8a.24xlarge",
      c8a_2xlarge: "c8a.2xlarge",
      c8a_48xlarge: "c8a.48xlarge",
      c8a_4xlarge: "c8a.4xlarge",
      c8a_8xlarge: "c8a.8xlarge",
      c8a_large: "c8a.large",
      c8a_medium: "c8a.medium",
      c8a_metal_24xl: "c8a.metal-24xl",
      c8a_metal_48xl: "c8a.metal-48xl",
      c8a_xlarge: "c8a.xlarge",
      c8g_12xlarge: "c8g.12xlarge",
      c8g_16xlarge: "c8g.16xlarge",
      c8g_24xlarge: "c8g.24xlarge",
      c8g_2xlarge: "c8g.2xlarge",
      c8g_48xlarge: "c8g.48xlarge",
      c8g_4xlarge: "c8g.4xlarge",
      c8g_8xlarge: "c8g.8xlarge",
      c8g_large: "c8g.large",
      c8g_medium: "c8g.medium",
      c8g_metal_24xl: "c8g.metal-24xl",
      c8g_metal_48xl: "c8g.metal-48xl",
      c8g_xlarge: "c8g.xlarge",
      c8gb_12xlarge: "c8gb.12xlarge",
      c8gb_16xlarge: "c8gb.16xlarge",
      c8gb_24xlarge: "c8gb.24xlarge",
      c8gb_2xlarge: "c8gb.2xlarge",
      c8gb_48xlarge: "c8gb.48xlarge",
      c8gb_4xlarge: "c8gb.4xlarge",
      c8gb_8xlarge: "c8gb.8xlarge",
      c8gb_large: "c8gb.large",
      c8gb_medium: "c8gb.medium",
      c8gb_metal_24xl: "c8gb.metal-24xl",
      c8gb_metal_48xl: "c8gb.metal-48xl",
      c8gb_xlarge: "c8gb.xlarge",
      c8gd_12xlarge: "c8gd.12xlarge",
      c8gd_16xlarge: "c8gd.16xlarge",
      c8gd_24xlarge: "c8gd.24xlarge",
      c8gd_2xlarge: "c8gd.2xlarge",
      c8gd_48xlarge: "c8gd.48xlarge",
      c8gd_4xlarge: "c8gd.4xlarge",
      c8gd_8xlarge: "c8gd.8xlarge",
      c8gd_large: "c8gd.large",
      c8gd_medium: "c8gd.medium",
      c8gd_metal_24xl: "c8gd.metal-24xl",
      c8gd_metal_48xl: "c8gd.metal-48xl",
      c8gd_xlarge: "c8gd.xlarge",
      c8gn_12xlarge: "c8gn.12xlarge",
      c8gn_16xlarge: "c8gn.16xlarge",
      c8gn_24xlarge: "c8gn.24xlarge",
      c8gn_2xlarge: "c8gn.2xlarge",
      c8gn_48xlarge: "c8gn.48xlarge",
      c8gn_4xlarge: "c8gn.4xlarge",
      c8gn_8xlarge: "c8gn.8xlarge",
      c8gn_large: "c8gn.large",
      c8gn_medium: "c8gn.medium",
      c8gn_metal_24xl: "c8gn.metal-24xl",
      c8gn_metal_48xl: "c8gn.metal-48xl",
      c8gn_xlarge: "c8gn.xlarge",
      c8i_12xlarge: "c8i.12xlarge",
      c8i_16xlarge: "c8i.16xlarge",
      c8i_24xlarge: "c8i.24xlarge",
      c8i_2xlarge: "c8i.2xlarge",
      c8i_32xlarge: "c8i.32xlarge",
      c8i_48xlarge: "c8i.48xlarge",
      c8i_4xlarge: "c8i.4xlarge",
      c8i_8xlarge: "c8i.8xlarge",
      c8i_96xlarge: "c8i.96xlarge",
      c8i_flex_12xlarge: "c8i-flex.12xlarge",
      c8i_flex_16xlarge: "c8i-flex.16xlarge",
      c8i_flex_2xlarge: "c8i-flex.2xlarge",
      c8i_flex_4xlarge: "c8i-flex.4xlarge",
      c8i_flex_8xlarge: "c8i-flex.8xlarge",
      c8i_flex_large: "c8i-flex.large",
      c8i_flex_xlarge: "c8i-flex.xlarge",
      c8i_large: "c8i.large",
      c8i_metal_48xl: "c8i.metal-48xl",
      c8i_metal_96xl: "c8i.metal-96xl",
      c8i_xlarge: "c8i.xlarge",
      c8id_12xlarge: "c8id.12xlarge",
      c8id_16xlarge: "c8id.16xlarge",
      c8id_24xlarge: "c8id.24xlarge",
      c8id_2xlarge: "c8id.2xlarge",
      c8id_32xlarge: "c8id.32xlarge",
      c8id_48xlarge: "c8id.48xlarge",
      c8id_4xlarge: "c8id.4xlarge",
      c8id_8xlarge: "c8id.8xlarge",
      c8id_96xlarge: "c8id.96xlarge",
      c8id_large: "c8id.large",
      c8id_metal_48xl: "c8id.metal-48xl",
      c8id_metal_96xl: "c8id.metal-96xl",
      c8id_xlarge: "c8id.xlarge",
      cc1_4xlarge: "cc1.4xlarge",
      cc2_8xlarge: "cc2.8xlarge",
      cg1_4xlarge: "cg1.4xlarge",
      cr1_8xlarge: "cr1.8xlarge",
      d2_2xlarge: "d2.2xlarge",
      d2_4xlarge: "d2.4xlarge",
      d2_8xlarge: "d2.8xlarge",
      d2_xlarge: "d2.xlarge",
      d3_2xlarge: "d3.2xlarge",
      d3_4xlarge: "d3.4xlarge",
      d3_8xlarge: "d3.8xlarge",
      d3_xlarge: "d3.xlarge",
      d3en_12xlarge: "d3en.12xlarge",
      d3en_2xlarge: "d3en.2xlarge",
      d3en_4xlarge: "d3en.4xlarge",
      d3en_6xlarge: "d3en.6xlarge",
      d3en_8xlarge: "d3en.8xlarge",
      d3en_xlarge: "d3en.xlarge",
      dl1_24xlarge: "dl1.24xlarge",
      dl2q_24xlarge: "dl2q.24xlarge",
      f1_16xlarge: "f1.16xlarge",
      f1_2xlarge: "f1.2xlarge",
      f1_4xlarge: "f1.4xlarge",
      f2_12xlarge: "f2.12xlarge",
      f2_48xlarge: "f2.48xlarge",
      f2_6xlarge: "f2.6xlarge",
      g2_2xlarge: "g2.2xlarge",
      g2_8xlarge: "g2.8xlarge",
      g3_16xlarge: "g3.16xlarge",
      g3_4xlarge: "g3.4xlarge",
      g3_8xlarge: "g3.8xlarge",
      g3s_xlarge: "g3s.xlarge",
      g4ad_16xlarge: "g4ad.16xlarge",
      g4ad_2xlarge: "g4ad.2xlarge",
      g4ad_4xlarge: "g4ad.4xlarge",
      g4ad_8xlarge: "g4ad.8xlarge",
      g4ad_xlarge: "g4ad.xlarge",
      g4dn_12xlarge: "g4dn.12xlarge",
      g4dn_16xlarge: "g4dn.16xlarge",
      g4dn_2xlarge: "g4dn.2xlarge",
      g4dn_4xlarge: "g4dn.4xlarge",
      g4dn_8xlarge: "g4dn.8xlarge",
      g4dn_metal: "g4dn.metal",
      g4dn_xlarge: "g4dn.xlarge",
      g5_12xlarge: "g5.12xlarge",
      g5_16xlarge: "g5.16xlarge",
      g5_24xlarge: "g5.24xlarge",
      g5_2xlarge: "g5.2xlarge",
      g5_48xlarge: "g5.48xlarge",
      g5_4xlarge: "g5.4xlarge",
      g5_8xlarge: "g5.8xlarge",
      g5_xlarge: "g5.xlarge",
      g5g_16xlarge: "g5g.16xlarge",
      g5g_2xlarge: "g5g.2xlarge",
      g5g_4xlarge: "g5g.4xlarge",
      g5g_8xlarge: "g5g.8xlarge",
      g5g_metal: "g5g.metal",
      g5g_xlarge: "g5g.xlarge",
      g6_12xlarge: "g6.12xlarge",
      g6_16xlarge: "g6.16xlarge",
      g6_24xlarge: "g6.24xlarge",
      g6_2xlarge: "g6.2xlarge",
      g6_48xlarge: "g6.48xlarge",
      g6_4xlarge: "g6.4xlarge",
      g6_8xlarge: "g6.8xlarge",
      g6_xlarge: "g6.xlarge",
      g6e_12xlarge: "g6e.12xlarge",
      g6e_16xlarge: "g6e.16xlarge",
      g6e_24xlarge: "g6e.24xlarge",
      g6e_2xlarge: "g6e.2xlarge",
      g6e_48xlarge: "g6e.48xlarge",
      g6e_4xlarge: "g6e.4xlarge",
      g6e_8xlarge: "g6e.8xlarge",
      g6e_xlarge: "g6e.xlarge",
      g6f_2xlarge: "g6f.2xlarge",
      g6f_4xlarge: "g6f.4xlarge",
      g6f_large: "g6f.large",
      g6f_xlarge: "g6f.xlarge",
      g7e_12xlarge: "g7e.12xlarge",
      g7e_24xlarge: "g7e.24xlarge",
      g7e_2xlarge: "g7e.2xlarge",
      g7e_48xlarge: "g7e.48xlarge",
      g7e_4xlarge: "g7e.4xlarge",
      g7e_8xlarge: "g7e.8xlarge",
      gr6_4xlarge: "gr6.4xlarge",
      gr6_8xlarge: "gr6.8xlarge",
      gr6f_4xlarge: "gr6f.4xlarge",
      h1_16xlarge: "h1.16xlarge",
      h1_2xlarge: "h1.2xlarge",
      h1_4xlarge: "h1.4xlarge",
      h1_8xlarge: "h1.8xlarge",
      hi1_4xlarge: "hi1.4xlarge",
      hpc6a_48xlarge: "hpc6a.48xlarge",
      hpc6id_32xlarge: "hpc6id.32xlarge",
      hpc7a_12xlarge: "hpc7a.12xlarge",
      hpc7a_24xlarge: "hpc7a.24xlarge",
      hpc7a_48xlarge: "hpc7a.48xlarge",
      hpc7a_96xlarge: "hpc7a.96xlarge",
      hpc7g_16xlarge: "hpc7g.16xlarge",
      hpc7g_4xlarge: "hpc7g.4xlarge",
      hpc7g_8xlarge: "hpc7g.8xlarge",
      hpc8a_96xlarge: "hpc8a.96xlarge",
      hs1_8xlarge: "hs1.8xlarge",
      i2_2xlarge: "i2.2xlarge",
      i2_4xlarge: "i2.4xlarge",
      i2_8xlarge: "i2.8xlarge",
      i2_xlarge: "i2.xlarge",
      i3_16xlarge: "i3.16xlarge",
      i3_2xlarge: "i3.2xlarge",
      i3_4xlarge: "i3.4xlarge",
      i3_8xlarge: "i3.8xlarge",
      i3_large: "i3.large",
      i3_metal: "i3.metal",
      i3_xlarge: "i3.xlarge",
      i3en_12xlarge: "i3en.12xlarge",
      i3en_24xlarge: "i3en.24xlarge",
      i3en_2xlarge: "i3en.2xlarge",
      i3en_3xlarge: "i3en.3xlarge",
      i3en_6xlarge: "i3en.6xlarge",
      i3en_large: "i3en.large",
      i3en_metal: "i3en.metal",
      i3en_xlarge: "i3en.xlarge",
      i4g_16xlarge: "i4g.16xlarge",
      i4g_2xlarge: "i4g.2xlarge",
      i4g_4xlarge: "i4g.4xlarge",
      i4g_8xlarge: "i4g.8xlarge",
      i4g_large: "i4g.large",
      i4g_xlarge: "i4g.xlarge",
      i4i_12xlarge: "i4i.12xlarge",
      i4i_16xlarge: "i4i.16xlarge",
      i4i_24xlarge: "i4i.24xlarge",
      i4i_2xlarge: "i4i.2xlarge",
      i4i_32xlarge: "i4i.32xlarge",
      i4i_4xlarge: "i4i.4xlarge",
      i4i_8xlarge: "i4i.8xlarge",
      i4i_large: "i4i.large",
      i4i_metal: "i4i.metal",
      i4i_xlarge: "i4i.xlarge",
      i7i_12xlarge: "i7i.12xlarge",
      i7i_16xlarge: "i7i.16xlarge",
      i7i_24xlarge: "i7i.24xlarge",
      i7i_2xlarge: "i7i.2xlarge",
      i7i_48xlarge: "i7i.48xlarge",
      i7i_4xlarge: "i7i.4xlarge",
      i7i_8xlarge: "i7i.8xlarge",
      i7i_large: "i7i.large",
      i7i_metal_24xl: "i7i.metal-24xl",
      i7i_metal_48xl: "i7i.metal-48xl",
      i7i_xlarge: "i7i.xlarge",
      i7ie_12xlarge: "i7ie.12xlarge",
      i7ie_18xlarge: "i7ie.18xlarge",
      i7ie_24xlarge: "i7ie.24xlarge",
      i7ie_2xlarge: "i7ie.2xlarge",
      i7ie_3xlarge: "i7ie.3xlarge",
      i7ie_48xlarge: "i7ie.48xlarge",
      i7ie_6xlarge: "i7ie.6xlarge",
      i7ie_large: "i7ie.large",
      i7ie_metal_24xl: "i7ie.metal-24xl",
      i7ie_metal_48xl: "i7ie.metal-48xl",
      i7ie_xlarge: "i7ie.xlarge",
      i8g_12xlarge: "i8g.12xlarge",
      i8g_16xlarge: "i8g.16xlarge",
      i8g_24xlarge: "i8g.24xlarge",
      i8g_2xlarge: "i8g.2xlarge",
      i8g_48xlarge: "i8g.48xlarge",
      i8g_4xlarge: "i8g.4xlarge",
      i8g_8xlarge: "i8g.8xlarge",
      i8g_large: "i8g.large",
      i8g_metal_24xl: "i8g.metal-24xl",
      i8g_xlarge: "i8g.xlarge",
      i8ge_12xlarge: "i8ge.12xlarge",
      i8ge_18xlarge: "i8ge.18xlarge",
      i8ge_24xlarge: "i8ge.24xlarge",
      i8ge_2xlarge: "i8ge.2xlarge",
      i8ge_3xlarge: "i8ge.3xlarge",
      i8ge_48xlarge: "i8ge.48xlarge",
      i8ge_6xlarge: "i8ge.6xlarge",
      i8ge_large: "i8ge.large",
      i8ge_metal_24xl: "i8ge.metal-24xl",
      i8ge_metal_48xl: "i8ge.metal-48xl",
      i8ge_xlarge: "i8ge.xlarge",
      im4gn_16xlarge: "im4gn.16xlarge",
      im4gn_2xlarge: "im4gn.2xlarge",
      im4gn_4xlarge: "im4gn.4xlarge",
      im4gn_8xlarge: "im4gn.8xlarge",
      im4gn_large: "im4gn.large",
      im4gn_xlarge: "im4gn.xlarge",
      inf1_24xlarge: "inf1.24xlarge",
      inf1_2xlarge: "inf1.2xlarge",
      inf1_6xlarge: "inf1.6xlarge",
      inf1_xlarge: "inf1.xlarge",
      inf2_24xlarge: "inf2.24xlarge",
      inf2_48xlarge: "inf2.48xlarge",
      inf2_8xlarge: "inf2.8xlarge",
      inf2_xlarge: "inf2.xlarge",
      is4gen_2xlarge: "is4gen.2xlarge",
      is4gen_4xlarge: "is4gen.4xlarge",
      is4gen_8xlarge: "is4gen.8xlarge",
      is4gen_large: "is4gen.large",
      is4gen_medium: "is4gen.medium",
      is4gen_xlarge: "is4gen.xlarge",
      m1_large: "m1.large",
      m1_medium: "m1.medium",
      m1_small: "m1.small",
      m1_xlarge: "m1.xlarge",
      m2_2xlarge: "m2.2xlarge",
      m2_4xlarge: "m2.4xlarge",
      m2_xlarge: "m2.xlarge",
      m3_2xlarge: "m3.2xlarge",
      m3_large: "m3.large",
      m3_medium: "m3.medium",
      m3_xlarge: "m3.xlarge",
      m4_10xlarge: "m4.10xlarge",
      m4_16xlarge: "m4.16xlarge",
      m4_2xlarge: "m4.2xlarge",
      m4_4xlarge: "m4.4xlarge",
      m4_large: "m4.large",
      m4_xlarge: "m4.xlarge",
      m5_12xlarge: "m5.12xlarge",
      m5_16xlarge: "m5.16xlarge",
      m5_24xlarge: "m5.24xlarge",
      m5_2xlarge: "m5.2xlarge",
      m5_4xlarge: "m5.4xlarge",
      m5_8xlarge: "m5.8xlarge",
      m5_large: "m5.large",
      m5_metal: "m5.metal",
      m5_xlarge: "m5.xlarge",
      m5a_12xlarge: "m5a.12xlarge",
      m5a_16xlarge: "m5a.16xlarge",
      m5a_24xlarge: "m5a.24xlarge",
      m5a_2xlarge: "m5a.2xlarge",
      m5a_4xlarge: "m5a.4xlarge",
      m5a_8xlarge: "m5a.8xlarge",
      m5a_large: "m5a.large",
      m5a_xlarge: "m5a.xlarge",
      m5ad_12xlarge: "m5ad.12xlarge",
      m5ad_16xlarge: "m5ad.16xlarge",
      m5ad_24xlarge: "m5ad.24xlarge",
      m5ad_2xlarge: "m5ad.2xlarge",
      m5ad_4xlarge: "m5ad.4xlarge",
      m5ad_8xlarge: "m5ad.8xlarge",
      m5ad_large: "m5ad.large",
      m5ad_xlarge: "m5ad.xlarge",
      m5d_12xlarge: "m5d.12xlarge",
      m5d_16xlarge: "m5d.16xlarge",
      m5d_24xlarge: "m5d.24xlarge",
      m5d_2xlarge: "m5d.2xlarge",
      m5d_4xlarge: "m5d.4xlarge",
      m5d_8xlarge: "m5d.8xlarge",
      m5d_large: "m5d.large",
      m5d_metal: "m5d.metal",
      m5d_xlarge: "m5d.xlarge",
      m5dn_12xlarge: "m5dn.12xlarge",
      m5dn_16xlarge: "m5dn.16xlarge",
      m5dn_24xlarge: "m5dn.24xlarge",
      m5dn_2xlarge: "m5dn.2xlarge",
      m5dn_4xlarge: "m5dn.4xlarge",
      m5dn_8xlarge: "m5dn.8xlarge",
      m5dn_large: "m5dn.large",
      m5dn_metal: "m5dn.metal",
      m5dn_xlarge: "m5dn.xlarge",
      m5n_12xlarge: "m5n.12xlarge",
      m5n_16xlarge: "m5n.16xlarge",
      m5n_24xlarge: "m5n.24xlarge",
      m5n_2xlarge: "m5n.2xlarge",
      m5n_4xlarge: "m5n.4xlarge",
      m5n_8xlarge: "m5n.8xlarge",
      m5n_large: "m5n.large",
      m5n_metal: "m5n.metal",
      m5n_xlarge: "m5n.xlarge",
      m5zn_12xlarge: "m5zn.12xlarge",
      m5zn_2xlarge: "m5zn.2xlarge",
      m5zn_3xlarge: "m5zn.3xlarge",
      m5zn_6xlarge: "m5zn.6xlarge",
      m5zn_large: "m5zn.large",
      m5zn_metal: "m5zn.metal",
      m5zn_xlarge: "m5zn.xlarge",
      m6a_12xlarge: "m6a.12xlarge",
      m6a_16xlarge: "m6a.16xlarge",
      m6a_24xlarge: "m6a.24xlarge",
      m6a_2xlarge: "m6a.2xlarge",
      m6a_32xlarge: "m6a.32xlarge",
      m6a_48xlarge: "m6a.48xlarge",
      m6a_4xlarge: "m6a.4xlarge",
      m6a_8xlarge: "m6a.8xlarge",
      m6a_large: "m6a.large",
      m6a_metal: "m6a.metal",
      m6a_xlarge: "m6a.xlarge",
      m6g_12xlarge: "m6g.12xlarge",
      m6g_16xlarge: "m6g.16xlarge",
      m6g_2xlarge: "m6g.2xlarge",
      m6g_4xlarge: "m6g.4xlarge",
      m6g_8xlarge: "m6g.8xlarge",
      m6g_large: "m6g.large",
      m6g_medium: "m6g.medium",
      m6g_metal: "m6g.metal",
      m6g_xlarge: "m6g.xlarge",
      m6gd_12xlarge: "m6gd.12xlarge",
      m6gd_16xlarge: "m6gd.16xlarge",
      m6gd_2xlarge: "m6gd.2xlarge",
      m6gd_4xlarge: "m6gd.4xlarge",
      m6gd_8xlarge: "m6gd.8xlarge",
      m6gd_large: "m6gd.large",
      m6gd_medium: "m6gd.medium",
      m6gd_metal: "m6gd.metal",
      m6gd_xlarge: "m6gd.xlarge",
      m6i_12xlarge: "m6i.12xlarge",
      m6i_16xlarge: "m6i.16xlarge",
      m6i_24xlarge: "m6i.24xlarge",
      m6i_2xlarge: "m6i.2xlarge",
      m6i_32xlarge: "m6i.32xlarge",
      m6i_4xlarge: "m6i.4xlarge",
      m6i_8xlarge: "m6i.8xlarge",
      m6i_large: "m6i.large",
      m6i_metal: "m6i.metal",
      m6i_xlarge: "m6i.xlarge",
      m6id_12xlarge: "m6id.12xlarge",
      m6id_16xlarge: "m6id.16xlarge",
      m6id_24xlarge: "m6id.24xlarge",
      m6id_2xlarge: "m6id.2xlarge",
      m6id_32xlarge: "m6id.32xlarge",
      m6id_4xlarge: "m6id.4xlarge",
      m6id_8xlarge: "m6id.8xlarge",
      m6id_large: "m6id.large",
      m6id_metal: "m6id.metal",
      m6id_xlarge: "m6id.xlarge",
      m6idn_12xlarge: "m6idn.12xlarge",
      m6idn_16xlarge: "m6idn.16xlarge",
      m6idn_24xlarge: "m6idn.24xlarge",
      m6idn_2xlarge: "m6idn.2xlarge",
      m6idn_32xlarge: "m6idn.32xlarge",
      m6idn_4xlarge: "m6idn.4xlarge",
      m6idn_8xlarge: "m6idn.8xlarge",
      m6idn_large: "m6idn.large",
      m6idn_metal: "m6idn.metal",
      m6idn_xlarge: "m6idn.xlarge",
      m6in_12xlarge: "m6in.12xlarge",
      m6in_16xlarge: "m6in.16xlarge",
      m6in_24xlarge: "m6in.24xlarge",
      m6in_2xlarge: "m6in.2xlarge",
      m6in_32xlarge: "m6in.32xlarge",
      m6in_4xlarge: "m6in.4xlarge",
      m6in_8xlarge: "m6in.8xlarge",
      m6in_large: "m6in.large",
      m6in_metal: "m6in.metal",
      m6in_xlarge: "m6in.xlarge",
      m7a_12xlarge: "m7a.12xlarge",
      m7a_16xlarge: "m7a.16xlarge",
      m7a_24xlarge: "m7a.24xlarge",
      m7a_2xlarge: "m7a.2xlarge",
      m7a_32xlarge: "m7a.32xlarge",
      m7a_48xlarge: "m7a.48xlarge",
      m7a_4xlarge: "m7a.4xlarge",
      m7a_8xlarge: "m7a.8xlarge",
      m7a_large: "m7a.large",
      m7a_medium: "m7a.medium",
      m7a_metal_48xl: "m7a.metal-48xl",
      m7a_xlarge: "m7a.xlarge",
      m7g_12xlarge: "m7g.12xlarge",
      m7g_16xlarge: "m7g.16xlarge",
      m7g_2xlarge: "m7g.2xlarge",
      m7g_4xlarge: "m7g.4xlarge",
      m7g_8xlarge: "m7g.8xlarge",
      m7g_large: "m7g.large",
      m7g_medium: "m7g.medium",
      m7g_metal: "m7g.metal",
      m7g_xlarge: "m7g.xlarge",
      m7gd_12xlarge: "m7gd.12xlarge",
      m7gd_16xlarge: "m7gd.16xlarge",
      m7gd_2xlarge: "m7gd.2xlarge",
      m7gd_4xlarge: "m7gd.4xlarge",
      m7gd_8xlarge: "m7gd.8xlarge",
      m7gd_large: "m7gd.large",
      m7gd_medium: "m7gd.medium",
      m7gd_metal: "m7gd.metal",
      m7gd_xlarge: "m7gd.xlarge",
      m7i_12xlarge: "m7i.12xlarge",
      m7i_16xlarge: "m7i.16xlarge",
      m7i_24xlarge: "m7i.24xlarge",
      m7i_2xlarge: "m7i.2xlarge",
      m7i_48xlarge: "m7i.48xlarge",
      m7i_4xlarge: "m7i.4xlarge",
      m7i_8xlarge: "m7i.8xlarge",
      m7i_flex_12xlarge: "m7i-flex.12xlarge",
      m7i_flex_16xlarge: "m7i-flex.16xlarge",
      m7i_flex_2xlarge: "m7i-flex.2xlarge",
      m7i_flex_4xlarge: "m7i-flex.4xlarge",
      m7i_flex_8xlarge: "m7i-flex.8xlarge",
      m7i_flex_large: "m7i-flex.large",
      m7i_flex_xlarge: "m7i-flex.xlarge",
      m7i_large: "m7i.large",
      m7i_metal_24xl: "m7i.metal-24xl",
      m7i_metal_48xl: "m7i.metal-48xl",
      m7i_xlarge: "m7i.xlarge",
      m8a_12xlarge: "m8a.12xlarge",
      m8a_16xlarge: "m8a.16xlarge",
      m8a_24xlarge: "m8a.24xlarge",
      m8a_2xlarge: "m8a.2xlarge",
      m8a_48xlarge: "m8a.48xlarge",
      m8a_4xlarge: "m8a.4xlarge",
      m8a_8xlarge: "m8a.8xlarge",
      m8a_large: "m8a.large",
      m8a_medium: "m8a.medium",
      m8a_metal_24xl: "m8a.metal-24xl",
      m8a_metal_48xl: "m8a.metal-48xl",
      m8a_xlarge: "m8a.xlarge",
      m8azn_12xlarge: "m8azn.12xlarge",
      m8azn_24xlarge: "m8azn.24xlarge",
      m8azn_3xlarge: "m8azn.3xlarge",
      m8azn_6xlarge: "m8azn.6xlarge",
      m8azn_large: "m8azn.large",
      m8azn_medium: "m8azn.medium",
      m8azn_metal_12xl: "m8azn.metal-12xl",
      m8azn_metal_24xl: "m8azn.metal-24xl",
      m8azn_xlarge: "m8azn.xlarge",
      m8g_12xlarge: "m8g.12xlarge",
      m8g_16xlarge: "m8g.16xlarge",
      m8g_24xlarge: "m8g.24xlarge",
      m8g_2xlarge: "m8g.2xlarge",
      m8g_48xlarge: "m8g.48xlarge",
      m8g_4xlarge: "m8g.4xlarge",
      m8g_8xlarge: "m8g.8xlarge",
      m8g_large: "m8g.large",
      m8g_medium: "m8g.medium",
      m8g_metal_24xl: "m8g.metal-24xl",
      m8g_metal_48xl: "m8g.metal-48xl",
      m8g_xlarge: "m8g.xlarge",
      m8gb_12xlarge: "m8gb.12xlarge",
      m8gb_16xlarge: "m8gb.16xlarge",
      m8gb_24xlarge: "m8gb.24xlarge",
      m8gb_2xlarge: "m8gb.2xlarge",
      m8gb_48xlarge: "m8gb.48xlarge",
      m8gb_4xlarge: "m8gb.4xlarge",
      m8gb_8xlarge: "m8gb.8xlarge",
      m8gb_large: "m8gb.large",
      m8gb_medium: "m8gb.medium",
      m8gb_metal_24xl: "m8gb.metal-24xl",
      m8gb_metal_48xl: "m8gb.metal-48xl",
      m8gb_xlarge: "m8gb.xlarge",
      m8gd_12xlarge: "m8gd.12xlarge",
      m8gd_16xlarge: "m8gd.16xlarge",
      m8gd_24xlarge: "m8gd.24xlarge",
      m8gd_2xlarge: "m8gd.2xlarge",
      m8gd_48xlarge: "m8gd.48xlarge",
      m8gd_4xlarge: "m8gd.4xlarge",
      m8gd_8xlarge: "m8gd.8xlarge",
      m8gd_large: "m8gd.large",
      m8gd_medium: "m8gd.medium",
      m8gd_metal_24xl: "m8gd.metal-24xl",
      m8gd_metal_48xl: "m8gd.metal-48xl",
      m8gd_xlarge: "m8gd.xlarge",
      m8gn_12xlarge: "m8gn.12xlarge",
      m8gn_16xlarge: "m8gn.16xlarge",
      m8gn_24xlarge: "m8gn.24xlarge",
      m8gn_2xlarge: "m8gn.2xlarge",
      m8gn_48xlarge: "m8gn.48xlarge",
      m8gn_4xlarge: "m8gn.4xlarge",
      m8gn_8xlarge: "m8gn.8xlarge",
      m8gn_large: "m8gn.large",
      m8gn_medium: "m8gn.medium",
      m8gn_metal_24xl: "m8gn.metal-24xl",
      m8gn_metal_48xl: "m8gn.metal-48xl",
      m8gn_xlarge: "m8gn.xlarge",
      m8i_12xlarge: "m8i.12xlarge",
      m8i_16xlarge: "m8i.16xlarge",
      m8i_24xlarge: "m8i.24xlarge",
      m8i_2xlarge: "m8i.2xlarge",
      m8i_32xlarge: "m8i.32xlarge",
      m8i_48xlarge: "m8i.48xlarge",
      m8i_4xlarge: "m8i.4xlarge",
      m8i_8xlarge: "m8i.8xlarge",
      m8i_96xlarge: "m8i.96xlarge",
      m8i_flex_12xlarge: "m8i-flex.12xlarge",
      m8i_flex_16xlarge: "m8i-flex.16xlarge",
      m8i_flex_2xlarge: "m8i-flex.2xlarge",
      m8i_flex_4xlarge: "m8i-flex.4xlarge",
      m8i_flex_8xlarge: "m8i-flex.8xlarge",
      m8i_flex_large: "m8i-flex.large",
      m8i_flex_xlarge: "m8i-flex.xlarge",
      m8i_large: "m8i.large",
      m8i_metal_48xl: "m8i.metal-48xl",
      m8i_metal_96xl: "m8i.metal-96xl",
      m8i_xlarge: "m8i.xlarge",
      m8id_12xlarge: "m8id.12xlarge",
      m8id_16xlarge: "m8id.16xlarge",
      m8id_24xlarge: "m8id.24xlarge",
      m8id_2xlarge: "m8id.2xlarge",
      m8id_32xlarge: "m8id.32xlarge",
      m8id_48xlarge: "m8id.48xlarge",
      m8id_4xlarge: "m8id.4xlarge",
      m8id_8xlarge: "m8id.8xlarge",
      m8id_96xlarge: "m8id.96xlarge",
      m8id_large: "m8id.large",
      m8id_metal_48xl: "m8id.metal-48xl",
      m8id_metal_96xl: "m8id.metal-96xl",
      m8id_xlarge: "m8id.xlarge",
      mac1_metal: "mac1.metal",
      mac2_m1ultra_metal: "mac2-m1ultra.metal",
      mac2_m2_metal: "mac2-m2.metal",
      mac2_m2pro_metal: "mac2-m2pro.metal",
      mac2_metal: "mac2.metal",
      mac_m4_metal: "mac-m4.metal",
      mac_m4max_metal: "mac-m4max.metal",
      mac_m4pro_metal: "mac-m4pro.metal",
      p2_16xlarge: "p2.16xlarge",
      p2_8xlarge: "p2.8xlarge",
      p2_xlarge: "p2.xlarge",
      p3_16xlarge: "p3.16xlarge",
      p3_2xlarge: "p3.2xlarge",
      p3_8xlarge: "p3.8xlarge",
      p3dn_24xlarge: "p3dn.24xlarge",
      p4d_24xlarge: "p4d.24xlarge",
      p4de_24xlarge: "p4de.24xlarge",
      p5_48xlarge: "p5.48xlarge",
      p5_4xlarge: "p5.4xlarge",
      p5e_48xlarge: "p5e.48xlarge",
      p5en_48xlarge: "p5en.48xlarge",
      p6_b200_48xlarge: "p6-b200.48xlarge",
      p6_b300_48xlarge: "p6-b300.48xlarge",
      p6e_gb200_36xlarge: "p6e-gb200.36xlarge",
      r3_2xlarge: "r3.2xlarge",
      r3_4xlarge: "r3.4xlarge",
      r3_8xlarge: "r3.8xlarge",
      r3_large: "r3.large",
      r3_xlarge: "r3.xlarge",
      r4_16xlarge: "r4.16xlarge",
      r4_2xlarge: "r4.2xlarge",
      r4_4xlarge: "r4.4xlarge",
      r4_8xlarge: "r4.8xlarge",
      r4_large: "r4.large",
      r4_xlarge: "r4.xlarge",
      r5_12xlarge: "r5.12xlarge",
      r5_16xlarge: "r5.16xlarge",
      r5_24xlarge: "r5.24xlarge",
      r5_2xlarge: "r5.2xlarge",
      r5_4xlarge: "r5.4xlarge",
      r5_8xlarge: "r5.8xlarge",
      r5_large: "r5.large",
      r5_metal: "r5.metal",
      r5_xlarge: "r5.xlarge",
      r5a_12xlarge: "r5a.12xlarge",
      r5a_16xlarge: "r5a.16xlarge",
      r5a_24xlarge: "r5a.24xlarge",
      r5a_2xlarge: "r5a.2xlarge",
      r5a_4xlarge: "r5a.4xlarge",
      r5a_8xlarge: "r5a.8xlarge",
      r5a_large: "r5a.large",
      r5a_xlarge: "r5a.xlarge",
      r5ad_12xlarge: "r5ad.12xlarge",
      r5ad_16xlarge: "r5ad.16xlarge",
      r5ad_24xlarge: "r5ad.24xlarge",
      r5ad_2xlarge: "r5ad.2xlarge",
      r5ad_4xlarge: "r5ad.4xlarge",
      r5ad_8xlarge: "r5ad.8xlarge",
      r5ad_large: "r5ad.large",
      r5ad_xlarge: "r5ad.xlarge",
      r5b_12xlarge: "r5b.12xlarge",
      r5b_16xlarge: "r5b.16xlarge",
      r5b_24xlarge: "r5b.24xlarge",
      r5b_2xlarge: "r5b.2xlarge",
      r5b_4xlarge: "r5b.4xlarge",
      r5b_8xlarge: "r5b.8xlarge",
      r5b_large: "r5b.large",
      r5b_metal: "r5b.metal",
      r5b_xlarge: "r5b.xlarge",
      r5d_12xlarge: "r5d.12xlarge",
      r5d_16xlarge: "r5d.16xlarge",
      r5d_24xlarge: "r5d.24xlarge",
      r5d_2xlarge: "r5d.2xlarge",
      r5d_4xlarge: "r5d.4xlarge",
      r5d_8xlarge: "r5d.8xlarge",
      r5d_large: "r5d.large",
      r5d_metal: "r5d.metal",
      r5d_xlarge: "r5d.xlarge",
      r5dn_12xlarge: "r5dn.12xlarge",
      r5dn_16xlarge: "r5dn.16xlarge",
      r5dn_24xlarge: "r5dn.24xlarge",
      r5dn_2xlarge: "r5dn.2xlarge",
      r5dn_4xlarge: "r5dn.4xlarge",
      r5dn_8xlarge: "r5dn.8xlarge",
      r5dn_large: "r5dn.large",
      r5dn_metal: "r5dn.metal",
      r5dn_xlarge: "r5dn.xlarge",
      r5n_12xlarge: "r5n.12xlarge",
      r5n_16xlarge: "r5n.16xlarge",
      r5n_24xlarge: "r5n.24xlarge",
      r5n_2xlarge: "r5n.2xlarge",
      r5n_4xlarge: "r5n.4xlarge",
      r5n_8xlarge: "r5n.8xlarge",
      r5n_large: "r5n.large",
      r5n_metal: "r5n.metal",
      r5n_xlarge: "r5n.xlarge",
      r6a_12xlarge: "r6a.12xlarge",
      r6a_16xlarge: "r6a.16xlarge",
      r6a_24xlarge: "r6a.24xlarge",
      r6a_2xlarge: "r6a.2xlarge",
      r6a_32xlarge: "r6a.32xlarge",
      r6a_48xlarge: "r6a.48xlarge",
      r6a_4xlarge: "r6a.4xlarge",
      r6a_8xlarge: "r6a.8xlarge",
      r6a_large: "r6a.large",
      r6a_metal: "r6a.metal",
      r6a_xlarge: "r6a.xlarge",
      r6g_12xlarge: "r6g.12xlarge",
      r6g_16xlarge: "r6g.16xlarge",
      r6g_2xlarge: "r6g.2xlarge",
      r6g_4xlarge: "r6g.4xlarge",
      r6g_8xlarge: "r6g.8xlarge",
      r6g_large: "r6g.large",
      r6g_medium: "r6g.medium",
      r6g_metal: "r6g.metal",
      r6g_xlarge: "r6g.xlarge",
      r6gd_12xlarge: "r6gd.12xlarge",
      r6gd_16xlarge: "r6gd.16xlarge",
      r6gd_2xlarge: "r6gd.2xlarge",
      r6gd_4xlarge: "r6gd.4xlarge",
      r6gd_8xlarge: "r6gd.8xlarge",
      r6gd_large: "r6gd.large",
      r6gd_medium: "r6gd.medium",
      r6gd_metal: "r6gd.metal",
      r6gd_xlarge: "r6gd.xlarge",
      r6i_12xlarge: "r6i.12xlarge",
      r6i_16xlarge: "r6i.16xlarge",
      r6i_24xlarge: "r6i.24xlarge",
      r6i_2xlarge: "r6i.2xlarge",
      r6i_32xlarge: "r6i.32xlarge",
      r6i_4xlarge: "r6i.4xlarge",
      r6i_8xlarge: "r6i.8xlarge",
      r6i_large: "r6i.large",
      r6i_metal: "r6i.metal",
      r6i_xlarge: "r6i.xlarge",
      r6id_12xlarge: "r6id.12xlarge",
      r6id_16xlarge: "r6id.16xlarge",
      r6id_24xlarge: "r6id.24xlarge",
      r6id_2xlarge: "r6id.2xlarge",
      r6id_32xlarge: "r6id.32xlarge",
      r6id_4xlarge: "r6id.4xlarge",
      r6id_8xlarge: "r6id.8xlarge",
      r6id_large: "r6id.large",
      r6id_metal: "r6id.metal",
      r6id_xlarge: "r6id.xlarge",
      r6idn_12xlarge: "r6idn.12xlarge",
      r6idn_16xlarge: "r6idn.16xlarge",
      r6idn_24xlarge: "r6idn.24xlarge",
      r6idn_2xlarge: "r6idn.2xlarge",
      r6idn_32xlarge: "r6idn.32xlarge",
      r6idn_4xlarge: "r6idn.4xlarge",
      r6idn_8xlarge: "r6idn.8xlarge",
      r6idn_large: "r6idn.large",
      r6idn_metal: "r6idn.metal",
      r6idn_xlarge: "r6idn.xlarge",
      r6in_12xlarge: "r6in.12xlarge",
      r6in_16xlarge: "r6in.16xlarge",
      r6in_24xlarge: "r6in.24xlarge",
      r6in_2xlarge: "r6in.2xlarge",
      r6in_32xlarge: "r6in.32xlarge",
      r6in_4xlarge: "r6in.4xlarge",
      r6in_8xlarge: "r6in.8xlarge",
      r6in_large: "r6in.large",
      r6in_metal: "r6in.metal",
      r6in_xlarge: "r6in.xlarge",
      r7a_12xlarge: "r7a.12xlarge",
      r7a_16xlarge: "r7a.16xlarge",
      r7a_24xlarge: "r7a.24xlarge",
      r7a_2xlarge: "r7a.2xlarge",
      r7a_32xlarge: "r7a.32xlarge",
      r7a_48xlarge: "r7a.48xlarge",
      r7a_4xlarge: "r7a.4xlarge",
      r7a_8xlarge: "r7a.8xlarge",
      r7a_large: "r7a.large",
      r7a_medium: "r7a.medium",
      r7a_metal_48xl: "r7a.metal-48xl",
      r7a_xlarge: "r7a.xlarge",
      r7g_12xlarge: "r7g.12xlarge",
      r7g_16xlarge: "r7g.16xlarge",
      r7g_2xlarge: "r7g.2xlarge",
      r7g_4xlarge: "r7g.4xlarge",
      r7g_8xlarge: "r7g.8xlarge",
      r7g_large: "r7g.large",
      r7g_medium: "r7g.medium",
      r7g_metal: "r7g.metal",
      r7g_xlarge: "r7g.xlarge",
      r7gd_12xlarge: "r7gd.12xlarge",
      r7gd_16xlarge: "r7gd.16xlarge",
      r7gd_2xlarge: "r7gd.2xlarge",
      r7gd_4xlarge: "r7gd.4xlarge",
      r7gd_8xlarge: "r7gd.8xlarge",
      r7gd_large: "r7gd.large",
      r7gd_medium: "r7gd.medium",
      r7gd_metal: "r7gd.metal",
      r7gd_xlarge: "r7gd.xlarge",
      r7i_12xlarge: "r7i.12xlarge",
      r7i_16xlarge: "r7i.16xlarge",
      r7i_24xlarge: "r7i.24xlarge",
      r7i_2xlarge: "r7i.2xlarge",
      r7i_48xlarge: "r7i.48xlarge",
      r7i_4xlarge: "r7i.4xlarge",
      r7i_8xlarge: "r7i.8xlarge",
      r7i_large: "r7i.large",
      r7i_metal_24xl: "r7i.metal-24xl",
      r7i_metal_48xl: "r7i.metal-48xl",
      r7i_xlarge: "r7i.xlarge",
      r7iz_12xlarge: "r7iz.12xlarge",
      r7iz_16xlarge: "r7iz.16xlarge",
      r7iz_2xlarge: "r7iz.2xlarge",
      r7iz_32xlarge: "r7iz.32xlarge",
      r7iz_4xlarge: "r7iz.4xlarge",
      r7iz_8xlarge: "r7iz.8xlarge",
      r7iz_large: "r7iz.large",
      r7iz_metal_16xl: "r7iz.metal-16xl",
      r7iz_metal_32xl: "r7iz.metal-32xl",
      r7iz_xlarge: "r7iz.xlarge",
      r8a_12xlarge: "r8a.12xlarge",
      r8a_16xlarge: "r8a.16xlarge",
      r8a_24xlarge: "r8a.24xlarge",
      r8a_2xlarge: "r8a.2xlarge",
      r8a_48xlarge: "r8a.48xlarge",
      r8a_4xlarge: "r8a.4xlarge",
      r8a_8xlarge: "r8a.8xlarge",
      r8a_large: "r8a.large",
      r8a_medium: "r8a.medium",
      r8a_metal_24xl: "r8a.metal-24xl",
      r8a_metal_48xl: "r8a.metal-48xl",
      r8a_xlarge: "r8a.xlarge",
      r8g_12xlarge: "r8g.12xlarge",
      r8g_16xlarge: "r8g.16xlarge",
      r8g_24xlarge: "r8g.24xlarge",
      r8g_2xlarge: "r8g.2xlarge",
      r8g_48xlarge: "r8g.48xlarge",
      r8g_4xlarge: "r8g.4xlarge",
      r8g_8xlarge: "r8g.8xlarge",
      r8g_large: "r8g.large",
      r8g_medium: "r8g.medium",
      r8g_metal_24xl: "r8g.metal-24xl",
      r8g_metal_48xl: "r8g.metal-48xl",
      r8g_xlarge: "r8g.xlarge",
      r8gb_12xlarge: "r8gb.12xlarge",
      r8gb_16xlarge: "r8gb.16xlarge",
      r8gb_24xlarge: "r8gb.24xlarge",
      r8gb_2xlarge: "r8gb.2xlarge",
      r8gb_4xlarge: "r8gb.4xlarge",
      r8gb_8xlarge: "r8gb.8xlarge",
      r8gb_large: "r8gb.large",
      r8gb_medium: "r8gb.medium",
      r8gb_metal_24xl: "r8gb.metal-24xl",
      r8gb_xlarge: "r8gb.xlarge",
      r8gd_12xlarge: "r8gd.12xlarge",
      r8gd_16xlarge: "r8gd.16xlarge",
      r8gd_24xlarge: "r8gd.24xlarge",
      r8gd_2xlarge: "r8gd.2xlarge",
      r8gd_48xlarge: "r8gd.48xlarge",
      r8gd_4xlarge: "r8gd.4xlarge",
      r8gd_8xlarge: "r8gd.8xlarge",
      r8gd_large: "r8gd.large",
      r8gd_medium: "r8gd.medium",
      r8gd_metal_24xl: "r8gd.metal-24xl",
      r8gd_metal_48xl: "r8gd.metal-48xl",
      r8gd_xlarge: "r8gd.xlarge",
      r8gn_12xlarge: "r8gn.12xlarge",
      r8gn_16xlarge: "r8gn.16xlarge",
      r8gn_24xlarge: "r8gn.24xlarge",
      r8gn_2xlarge: "r8gn.2xlarge",
      r8gn_48xlarge: "r8gn.48xlarge",
      r8gn_4xlarge: "r8gn.4xlarge",
      r8gn_8xlarge: "r8gn.8xlarge",
      r8gn_large: "r8gn.large",
      r8gn_medium: "r8gn.medium",
      r8gn_metal_24xl: "r8gn.metal-24xl",
      r8gn_metal_48xl: "r8gn.metal-48xl",
      r8gn_xlarge: "r8gn.xlarge",
      r8i_12xlarge: "r8i.12xlarge",
      r8i_16xlarge: "r8i.16xlarge",
      r8i_24xlarge: "r8i.24xlarge",
      r8i_2xlarge: "r8i.2xlarge",
      r8i_32xlarge: "r8i.32xlarge",
      r8i_48xlarge: "r8i.48xlarge",
      r8i_4xlarge: "r8i.4xlarge",
      r8i_8xlarge: "r8i.8xlarge",
      r8i_96xlarge: "r8i.96xlarge",
      r8i_flex_12xlarge: "r8i-flex.12xlarge",
      r8i_flex_16xlarge: "r8i-flex.16xlarge",
      r8i_flex_2xlarge: "r8i-flex.2xlarge",
      r8i_flex_4xlarge: "r8i-flex.4xlarge",
      r8i_flex_8xlarge: "r8i-flex.8xlarge",
      r8i_flex_large: "r8i-flex.large",
      r8i_flex_xlarge: "r8i-flex.xlarge",
      r8i_large: "r8i.large",
      r8i_metal_48xl: "r8i.metal-48xl",
      r8i_metal_96xl: "r8i.metal-96xl",
      r8i_xlarge: "r8i.xlarge",
      r8id_12xlarge: "r8id.12xlarge",
      r8id_16xlarge: "r8id.16xlarge",
      r8id_24xlarge: "r8id.24xlarge",
      r8id_2xlarge: "r8id.2xlarge",
      r8id_32xlarge: "r8id.32xlarge",
      r8id_48xlarge: "r8id.48xlarge",
      r8id_4xlarge: "r8id.4xlarge",
      r8id_8xlarge: "r8id.8xlarge",
      r8id_96xlarge: "r8id.96xlarge",
      r8id_large: "r8id.large",
      r8id_metal_48xl: "r8id.metal-48xl",
      r8id_metal_96xl: "r8id.metal-96xl",
      r8id_xlarge: "r8id.xlarge",
      t1_micro: "t1.micro",
      t2_2xlarge: "t2.2xlarge",
      t2_large: "t2.large",
      t2_medium: "t2.medium",
      t2_micro: "t2.micro",
      t2_nano: "t2.nano",
      t2_small: "t2.small",
      t2_xlarge: "t2.xlarge",
      t3_2xlarge: "t3.2xlarge",
      t3_large: "t3.large",
      t3_medium: "t3.medium",
      t3_micro: "t3.micro",
      t3_nano: "t3.nano",
      t3_small: "t3.small",
      t3_xlarge: "t3.xlarge",
      t3a_2xlarge: "t3a.2xlarge",
      t3a_large: "t3a.large",
      t3a_medium: "t3a.medium",
      t3a_micro: "t3a.micro",
      t3a_nano: "t3a.nano",
      t3a_small: "t3a.small",
      t3a_xlarge: "t3a.xlarge",
      t4g_2xlarge: "t4g.2xlarge",
      t4g_large: "t4g.large",
      t4g_medium: "t4g.medium",
      t4g_micro: "t4g.micro",
      t4g_nano: "t4g.nano",
      t4g_small: "t4g.small",
      t4g_xlarge: "t4g.xlarge",
      trn1_2xlarge: "trn1.2xlarge",
      trn1_32xlarge: "trn1.32xlarge",
      trn1n_32xlarge: "trn1n.32xlarge",
      trn2_3xlarge: "trn2.3xlarge",
      trn2_48xlarge: "trn2.48xlarge",
      u7i_12tb_224xlarge: "u7i-12tb.224xlarge",
      u7i_6tb_112xlarge: "u7i-6tb.112xlarge",
      u7i_8tb_112xlarge: "u7i-8tb.112xlarge",
      u7ib_12tb_224xlarge: "u7ib-12tb.224xlarge",
      u7in_16tb_224xlarge: "u7in-16tb.224xlarge",
      u7in_24tb_224xlarge: "u7in-24tb.224xlarge",
      u7in_32tb_224xlarge: "u7in-32tb.224xlarge",
      u7inh_32tb_480xlarge: "u7inh-32tb.480xlarge",
      u_12tb1_112xlarge: "u-12tb1.112xlarge",
      u_12tb1_metal: "u-12tb1.metal",
      u_18tb1_112xlarge: "u-18tb1.112xlarge",
      u_18tb1_metal: "u-18tb1.metal",
      u_24tb1_112xlarge: "u-24tb1.112xlarge",
      u_24tb1_metal: "u-24tb1.metal",
      u_3tb1_56xlarge: "u-3tb1.56xlarge",
      u_6tb1_112xlarge: "u-6tb1.112xlarge",
      u_6tb1_56xlarge: "u-6tb1.56xlarge",
      u_6tb1_metal: "u-6tb1.metal",
      u_9tb1_112xlarge: "u-9tb1.112xlarge",
      u_9tb1_metal: "u-9tb1.metal",
      vt1_24xlarge: "vt1.24xlarge",
      vt1_3xlarge: "vt1.3xlarge",
      vt1_6xlarge: "vt1.6xlarge",
      x1_16xlarge: "x1.16xlarge",
      x1_32xlarge: "x1.32xlarge",
      x1e_16xlarge: "x1e.16xlarge",
      x1e_2xlarge: "x1e.2xlarge",
      x1e_32xlarge: "x1e.32xlarge",
      x1e_4xlarge: "x1e.4xlarge",
      x1e_8xlarge: "x1e.8xlarge",
      x1e_xlarge: "x1e.xlarge",
      x2gd_12xlarge: "x2gd.12xlarge",
      x2gd_16xlarge: "x2gd.16xlarge",
      x2gd_2xlarge: "x2gd.2xlarge",
      x2gd_4xlarge: "x2gd.4xlarge",
      x2gd_8xlarge: "x2gd.8xlarge",
      x2gd_large: "x2gd.large",
      x2gd_medium: "x2gd.medium",
      x2gd_metal: "x2gd.metal",
      x2gd_xlarge: "x2gd.xlarge",
      x2idn_16xlarge: "x2idn.16xlarge",
      x2idn_24xlarge: "x2idn.24xlarge",
      x2idn_32xlarge: "x2idn.32xlarge",
      x2idn_metal: "x2idn.metal",
      x2iedn_16xlarge: "x2iedn.16xlarge",
      x2iedn_24xlarge: "x2iedn.24xlarge",
      x2iedn_2xlarge: "x2iedn.2xlarge",
      x2iedn_32xlarge: "x2iedn.32xlarge",
      x2iedn_4xlarge: "x2iedn.4xlarge",
      x2iedn_8xlarge: "x2iedn.8xlarge",
      x2iedn_metal: "x2iedn.metal",
      x2iedn_xlarge: "x2iedn.xlarge",
      x2iezn_12xlarge: "x2iezn.12xlarge",
      x2iezn_2xlarge: "x2iezn.2xlarge",
      x2iezn_4xlarge: "x2iezn.4xlarge",
      x2iezn_6xlarge: "x2iezn.6xlarge",
      x2iezn_8xlarge: "x2iezn.8xlarge",
      x2iezn_metal: "x2iezn.metal",
      x8aedz_12xlarge: "x8aedz.12xlarge",
      x8aedz_24xlarge: "x8aedz.24xlarge",
      x8aedz_3xlarge: "x8aedz.3xlarge",
      x8aedz_6xlarge: "x8aedz.6xlarge",
      x8aedz_large: "x8aedz.large",
      x8aedz_metal_12xl: "x8aedz.metal-12xl",
      x8aedz_metal_24xl: "x8aedz.metal-24xl",
      x8aedz_xlarge: "x8aedz.xlarge",
      x8g_12xlarge: "x8g.12xlarge",
      x8g_16xlarge: "x8g.16xlarge",
      x8g_24xlarge: "x8g.24xlarge",
      x8g_2xlarge: "x8g.2xlarge",
      x8g_48xlarge: "x8g.48xlarge",
      x8g_4xlarge: "x8g.4xlarge",
      x8g_8xlarge: "x8g.8xlarge",
      x8g_large: "x8g.large",
      x8g_medium: "x8g.medium",
      x8g_metal_24xl: "x8g.metal-24xl",
      x8g_metal_48xl: "x8g.metal-48xl",
      x8g_xlarge: "x8g.xlarge",
      x8i_12xlarge: "x8i.12xlarge",
      x8i_16xlarge: "x8i.16xlarge",
      x8i_24xlarge: "x8i.24xlarge",
      x8i_2xlarge: "x8i.2xlarge",
      x8i_32xlarge: "x8i.32xlarge",
      x8i_48xlarge: "x8i.48xlarge",
      x8i_4xlarge: "x8i.4xlarge",
      x8i_64xlarge: "x8i.64xlarge",
      x8i_8xlarge: "x8i.8xlarge",
      x8i_96xlarge: "x8i.96xlarge",
      x8i_large: "x8i.large",
      x8i_metal_48xl: "x8i.metal-48xl",
      x8i_metal_96xl: "x8i.metal-96xl",
      x8i_xlarge: "x8i.xlarge",
      z1d_12xlarge: "z1d.12xlarge",
      z1d_2xlarge: "z1d.2xlarge",
      z1d_3xlarge: "z1d.3xlarge",
      z1d_6xlarge: "z1d.6xlarge",
      z1d_large: "z1d.large",
      z1d_metal: "z1d.metal",
      z1d_xlarge: "z1d.xlarge"
    };
    var FleetCapacityReservationTenancy = {
      default: "default"
    };
    var CarrierGatewayState = {
      available: "available",
      deleted: "deleted",
      deleting: "deleting",
      pending: "pending"
    };
    var ClientVpnAuthenticationType = {
      certificate_authentication: "certificate-authentication",
      directory_service_authentication: "directory-service-authentication",
      federated_authentication: "federated-authentication"
    };
    var EndpointIpAddressType = {
      dual_stack: "dual-stack",
      ipv4: "ipv4",
      ipv6: "ipv6"
    };
    var SelfServicePortal = {
      disabled: "disabled",
      enabled: "enabled"
    };
    var TrafficIpAddressType = {
      dual_stack: "dual-stack",
      ipv4: "ipv4",
      ipv6: "ipv6"
    };
    var TransportProtocol = {
      tcp: "tcp",
      udp: "udp"
    };
    var ClientVpnEndpointStatusCode = {
      available: "available",
      deleted: "deleted",
      deleting: "deleting",
      pending: "pending",
      pending_associate: "pending-associate"
    };
    var ClientVpnRouteStatusCode = {
      active: "active",
      creating: "creating",
      deleting: "deleting",
      failed: "failed"
    };
    var GatewayType = {
      ipsec_1: "ipsec.1"
    };
    var BlockPublicAccessMode = {
      block_bidirectional: "block-bidirectional",
      block_ingress: "block-ingress",
      off: "off"
    };
    var HostnameType = {
      ip_name: "ip-name",
      resource_name: "resource-name"
    };
    var SubnetState = {
      available: "available",
      failed: "failed",
      failed_insufficient_capacity: "failed-insufficient-capacity",
      pending: "pending",
      unavailable: "unavailable"
    };
    var VpcEncryptionControlMode = {
      enforce: "enforce",
      monitor: "monitor"
    };
    var VpcEncryptionControlExclusionState = {
      disabled: "disabled",
      disabling: "disabling",
      enabled: "enabled",
      enabling: "enabling"
    };
    var VpcEncryptionControlState = {
      available: "available",
      creating: "creating",
      delete_failed: "delete-failed",
      deleted: "deleted",
      deleting: "deleting",
      enforce_failed: "enforce-failed",
      enforce_in_progress: "enforce-in-progress",
      monitor_failed: "monitor-failed",
      monitor_in_progress: "monitor-in-progress"
    };
    var Tenancy = {
      dedicated: "dedicated",
      default: "default",
      host: "host"
    };
    var VpcState = {
      available: "available",
      pending: "pending"
    };
    var MacSystemIntegrityProtectionSettingStatus = {
      disabled: "disabled",
      enabled: "enabled"
    };
    var MacModificationTaskState = {
      failed: "failed",
      inprogress: "in-progress",
      pending: "pending",
      successful: "successful"
    };
    var MacModificationTaskType = {
      SIPModification: "sip-modification",
      VolumeOwnershipDelegation: "volume-ownership-delegation"
    };
    var FleetExcessCapacityTerminationPolicy = {
      NO_TERMINATION: "no-termination",
      TERMINATION: "termination"
    };
    var BareMetal = {
      EXCLUDED: "excluded",
      INCLUDED: "included",
      REQUIRED: "required"
    };
    var BurstablePerformance = {
      EXCLUDED: "excluded",
      INCLUDED: "included",
      REQUIRED: "required"
    };
    var CpuManufacturer = {
      AMAZON_WEB_SERVICES: "amazon-web-services",
      AMD: "amd",
      APPLE: "apple",
      INTEL: "intel"
    };
    var InstanceGeneration = {
      CURRENT: "current",
      PREVIOUS: "previous"
    };
    var LocalStorage = {
      EXCLUDED: "excluded",
      INCLUDED: "included",
      REQUIRED: "required"
    };
    var LocalStorageType = {
      HDD: "hdd",
      SSD: "ssd"
    };
    var FleetOnDemandAllocationStrategy = {
      LOWEST_PRICE: "lowest-price",
      PRIORITIZED: "prioritized"
    };
    var FleetCapacityReservationUsageStrategy = {
      USE_CAPACITY_RESERVATIONS_FIRST: "use-capacity-reservations-first"
    };
    var FleetReservationType = {
      INTERRUPTIBLE_CAPACITY_RESERVATION: "interruptible-capacity-reservation"
    };
    var SpotAllocationStrategy = {
      CAPACITY_OPTIMIZED: "capacity-optimized",
      CAPACITY_OPTIMIZED_PRIORITIZED: "capacity-optimized-prioritized",
      DIVERSIFIED: "diversified",
      LOWEST_PRICE: "lowest-price",
      PRICE_CAPACITY_OPTIMIZED: "price-capacity-optimized"
    };
    var SpotInstanceInterruptionBehavior = {
      hibernate: "hibernate",
      stop: "stop",
      terminate: "terminate"
    };
    var FleetReplacementStrategy = {
      LAUNCH: "launch",
      LAUNCH_BEFORE_TERMINATE: "launch-before-terminate"
    };
    var DefaultTargetCapacityType = {
      CAPACITY_BLOCK: "capacity-block",
      ON_DEMAND: "on-demand",
      RESERVED_CAPACITY: "reserved-capacity",
      SPOT: "spot"
    };
    var TargetCapacityUnitType = {
      MEMORY_MIB: "memory-mib",
      UNITS: "units",
      VCPU: "vcpu"
    };
    var FleetType = {
      INSTANT: "instant",
      MAINTAIN: "maintain",
      REQUEST: "request"
    };
    var InstanceLifecycle = {
      INTERRUPTIBLE_CAPACITY_RESERVATION: "interruptible-capacity-reservation",
      ON_DEMAND: "on-demand",
      SPOT: "spot"
    };
    var PlatformValues = {
      Windows: "Windows"
    };
    var DestinationFileFormat = {
      parquet: "parquet",
      plain_text: "plain-text"
    };
    var LogDestinationType = {
      cloud_watch_logs: "cloud-watch-logs",
      kinesis_data_firehose: "kinesis-data-firehose",
      s3: "s3"
    };
    var FlowLogsResourceType = {
      NetworkInterface: "NetworkInterface",
      RegionalNatGateway: "RegionalNatGateway",
      Subnet: "Subnet",
      TransitGateway: "TransitGateway",
      TransitGatewayAttachment: "TransitGatewayAttachment",
      VPC: "VPC"
    };
    var TrafficType = {
      ACCEPT: "ACCEPT",
      ALL: "ALL",
      REJECT: "REJECT"
    };
    var SnapshotLocationEnum = {
      LOCAL: "local",
      REGIONAL: "regional"
    };
    var IpAddressType = {
      dualstack: "dualstack",
      ipv4: "ipv4",
      ipv6: "ipv6"
    };
    var Ec2InstanceConnectEndpointState = {
      create_complete: "create-complete",
      create_failed: "create-failed",
      create_in_progress: "create-in-progress",
      delete_complete: "delete-complete",
      delete_failed: "delete-failed",
      delete_in_progress: "delete-in-progress",
      update_complete: "update-complete",
      update_failed: "update-failed",
      update_in_progress: "update-in-progress"
    };
    var ContainerFormat = {
      ova: "ova"
    };
    var DiskImageFormat = {
      RAW: "RAW",
      VHD: "VHD",
      VMDK: "VMDK"
    };
    var ExportEnvironment = {
      citrix: "citrix",
      microsoft: "microsoft",
      vmware: "vmware"
    };
    var ExportTaskState = {
      active: "active",
      cancelled: "cancelled",
      cancelling: "cancelling",
      completed: "completed"
    };
    var IpamMeteredAccount = {
      ipam_owner: "ipam-owner",
      resource_owner: "resource-owner"
    };
    var IpamTier = {
      advanced: "advanced",
      free: "free"
    };
    var IpamState = {
      create_complete: "create-complete",
      create_failed: "create-failed",
      create_in_progress: "create-in-progress",
      delete_complete: "delete-complete",
      delete_failed: "delete-failed",
      delete_in_progress: "delete-in-progress",
      isolate_complete: "isolate-complete",
      isolate_in_progress: "isolate-in-progress",
      modify_complete: "modify-complete",
      modify_failed: "modify-failed",
      modify_in_progress: "modify-in-progress",
      restore_in_progress: "restore-in-progress"
    };
    var IpamExternalResourceVerificationTokenState = {
      CREATE_COMPLETE: "create-complete",
      CREATE_FAILED: "create-failed",
      CREATE_IN_PROGRESS: "create-in-progress",
      DELETE_COMPLETE: "delete-complete",
      DELETE_FAILED: "delete-failed",
      DELETE_IN_PROGRESS: "delete-in-progress"
    };
    var TokenState = {
      expired: "expired",
      valid: "valid"
    };
    var IpamPolicyState = {
      create_complete: "create-complete",
      create_failed: "create-failed",
      create_in_progress: "create-in-progress",
      delete_complete: "delete-complete",
      delete_failed: "delete-failed",
      delete_in_progress: "delete-in-progress",
      isolate_complete: "isolate-complete",
      isolate_in_progress: "isolate-in-progress",
      modify_complete: "modify-complete",
      modify_failed: "modify-failed",
      modify_in_progress: "modify-in-progress",
      restore_in_progress: "restore-in-progress"
    };
    var IpamPoolAwsService = {
      ec2: "ec2",
      global_services: "global-services"
    };
    var IpamPoolPublicIpSource = {
      amazon: "amazon",
      byoip: "byoip"
    };
    var IpamPoolSourceResourceType = {
      vpc: "vpc"
    };
    var IpamScopeType = {
      private: "private",
      public: "public"
    };
    var IpamPoolState = {
      create_complete: "create-complete",
      create_failed: "create-failed",
      create_in_progress: "create-in-progress",
      delete_complete: "delete-complete",
      delete_failed: "delete-failed",
      delete_in_progress: "delete-in-progress",
      isolate_complete: "isolate-complete",
      isolate_in_progress: "isolate-in-progress",
      modify_complete: "modify-complete",
      modify_failed: "modify-failed",
      modify_in_progress: "modify-in-progress",
      restore_in_progress: "restore-in-progress"
    };
    var IpamPrefixListResolverRuleConditionOperation = {
      equals: "equals",
      not_equals: "not-equals",
      subnet_of: "subnet-of"
    };
    var IpamResourceType = {
      anycast_ip_list: "anycast-ip-list",
      eip: "eip",
      eni: "eni",
      ipv6_pool: "ipv6-pool",
      public_ipv4_pool: "public-ipv4-pool",
      subnet: "subnet",
      vpc: "vpc"
    };
    var IpamPrefixListResolverRuleType = {
      ipam_pool_cidr: "ipam-pool-cidr",
      ipam_resource_cidr: "ipam-resource-cidr",
      static_cidr: "static-cidr"
    };
    var IpamPrefixListResolverVersionCreationStatus = {
      failure: "failure",
      pending: "pending",
      success: "success"
    };
    var IpamPrefixListResolverState = {
      create_complete: "create-complete",
      create_failed: "create-failed",
      create_in_progress: "create-in-progress",
      delete_complete: "delete-complete",
      delete_failed: "delete-failed",
      delete_in_progress: "delete-in-progress",
      isolate_complete: "isolate-complete",
      isolate_in_progress: "isolate-in-progress",
      modify_complete: "modify-complete",
      modify_failed: "modify-failed",
      modify_in_progress: "modify-in-progress",
      restore_in_progress: "restore-in-progress"
    };
    var IpamPrefixListResolverTargetState = {
      create_complete: "create-complete",
      create_failed: "create-failed",
      create_in_progress: "create-in-progress",
      delete_complete: "delete-complete",
      delete_failed: "delete-failed",
      delete_in_progress: "delete-in-progress",
      isolate_complete: "isolate-complete",
      isolate_in_progress: "isolate-in-progress",
      modify_complete: "modify-complete",
      modify_failed: "modify-failed",
      modify_in_progress: "modify-in-progress",
      restore_in_progress: "restore-in-progress",
      sync_complete: "sync-complete",
      sync_failed: "sync-failed",
      sync_in_progress: "sync-in-progress"
    };
    var IpamResourceDiscoveryState = {
      CREATE_COMPLETE: "create-complete",
      CREATE_FAILED: "create-failed",
      CREATE_IN_PROGRESS: "create-in-progress",
      DELETE_COMPLETE: "delete-complete",
      DELETE_FAILED: "delete-failed",
      DELETE_IN_PROGRESS: "delete-in-progress",
      ISOLATE_COMPLETE: "isolate-complete",
      ISOLATE_IN_PROGRESS: "isolate-in-progress",
      MODIFY_COMPLETE: "modify-complete",
      MODIFY_FAILED: "modify-failed",
      MODIFY_IN_PROGRESS: "modify-in-progress",
      RESTORE_IN_PROGRESS: "restore-in-progress"
    };
    var IpamScopeExternalAuthorityType = {
      infoblox: "infoblox"
    };
    var IpamScopeState = {
      create_complete: "create-complete",
      create_failed: "create-failed",
      create_in_progress: "create-in-progress",
      delete_complete: "delete-complete",
      delete_failed: "delete-failed",
      delete_in_progress: "delete-in-progress",
      isolate_complete: "isolate-complete",
      isolate_in_progress: "isolate-in-progress",
      modify_complete: "modify-complete",
      modify_failed: "modify-failed",
      modify_in_progress: "modify-in-progress",
      restore_in_progress: "restore-in-progress"
    };
    var KeyFormat = {
      pem: "pem",
      ppk: "ppk"
    };
    var KeyType = {
      ed25519: "ed25519",
      rsa: "rsa"
    };
    var CapacityReservationPreference = {
      capacity_reservations_only: "capacity-reservations-only",
      none: "none",
      open: "open"
    };
    var AmdSevSnpSpecification = {
      disabled: "disabled",
      enabled: "enabled"
    };
    var NestedVirtualizationSpecification = {
      disabled: "disabled",
      enabled: "enabled"
    };
    var ShutdownBehavior = {
      stop: "stop",
      terminate: "terminate"
    };
    var MarketType = {
      capacity_block: "capacity-block",
      interruptible_capacity_reservation: "interruptible-capacity-reservation",
      spot: "spot"
    };
    var InstanceInterruptionBehavior = {
      hibernate: "hibernate",
      stop: "stop",
      terminate: "terminate"
    };
    var SpotInstanceType = {
      one_time: "one-time",
      persistent: "persistent"
    };
    var LaunchTemplateAutoRecoveryState = {
      default: "default",
      disabled: "disabled"
    };
    var LaunchTemplateInstanceMetadataEndpointState = {
      disabled: "disabled",
      enabled: "enabled"
    };
    var LaunchTemplateInstanceMetadataProtocolIpv6 = {
      disabled: "disabled",
      enabled: "enabled"
    };
    var LaunchTemplateHttpTokensState = {
      optional: "optional",
      required: "required"
    };
    var LaunchTemplateInstanceMetadataTagsState = {
      disabled: "disabled",
      enabled: "enabled"
    };
    var InstanceBandwidthWeighting = {
      DEFAULT: "default",
      EBS_1: "ebs-1",
      VPC_1: "vpc-1"
    };
    var SecondaryInterfaceType = {
      SECONDARY: "secondary"
    };
    var LaunchTemplateInstanceMetadataOptionsState = {
      applied: "applied",
      pending: "pending"
    };
    var LocalGatewayRouteState = {
      active: "active",
      blackhole: "blackhole",
      deleted: "deleted",
      deleting: "deleting",
      pending: "pending"
    };
    var LocalGatewayRouteType = {
      propagated: "propagated",
      static: "static"
    };
    var LocalGatewayRouteTableMode = {
      coip: "coip",
      direct_vpc_routing: "direct-vpc-routing"
    };
    var LocalGatewayVirtualInterfaceConfigurationState = {
      available: "available",
      deleted: "deleted",
      deleting: "deleting",
      pending: "pending"
    };
    var LocalGatewayVirtualInterfaceGroupConfigurationState = {
      available: "available",
      deleted: "deleted",
      deleting: "deleting",
      incomplete: "incomplete",
      pending: "pending"
    };
    var PrefixListState = {
      create_complete: "create-complete",
      create_failed: "create-failed",
      create_in_progress: "create-in-progress",
      delete_complete: "delete-complete",
      delete_failed: "delete-failed",
      delete_in_progress: "delete-in-progress",
      modify_complete: "modify-complete",
      modify_failed: "modify-failed",
      modify_in_progress: "modify-in-progress",
      restore_complete: "restore-complete",
      restore_failed: "restore-failed",
      restore_in_progress: "restore-in-progress"
    };
    var AvailabilityMode = {
      REGIONAL: "regional",
      ZONAL: "zonal"
    };
    var ConnectivityType = {
      PRIVATE: "private",
      PUBLIC: "public"
    };
    var NatGatewayApplianceState = {
      ATTACHED: "attached",
      ATTACHING: "attaching",
      ATTACH_FAILED: "attach-failed",
      DETACHED: "detached",
      DETACHING: "detaching",
      DETACH_FAILED: "detach-failed"
    };
    var NatGatewayApplianceModifyState = {
      COMPLETED: "completed",
      FAILED: "failed",
      MODIFYING: "modifying"
    };
    var NatGatewayApplianceType = {
      NETWORK_FIREWALL_PROXY: "network-firewall-proxy"
    };
    var AutoProvisionZonesState = {
      DISABLED: "disabled",
      ENABLED: "enabled"
    };
    var AutoScalingIpsState = {
      DISABLED: "disabled",
      ENABLED: "enabled"
    };
    var NatGatewayState = {
      AVAILABLE: "available",
      DELETED: "deleted",
      DELETING: "deleting",
      FAILED: "failed",
      PENDING: "pending"
    };
    var RuleAction = {
      allow: "allow",
      deny: "deny"
    };
    var NetworkInterfaceCreationType = {
      branch: "branch",
      efa: "efa",
      efa_only: "efa-only",
      trunk: "trunk"
    };
    var NetworkInterfaceType = {
      api_gateway_managed: "api_gateway_managed",
      aws_codestar_connections_managed: "aws_codestar_connections_managed",
      branch: "branch",
      efa: "efa",
      efa_only: "efa-only",
      gateway_load_balancer: "gateway_load_balancer",
      gateway_load_balancer_endpoint: "gateway_load_balancer_endpoint",
      global_accelerator_managed: "global_accelerator_managed",
      interface: "interface",
      iot_rules_managed: "iot_rules_managed",
      lambda: "lambda",
      load_balancer: "load_balancer",
      natGateway: "natGateway",
      network_load_balancer: "network_load_balancer",
      quicksight: "quicksight",
      transit_gateway: "transit_gateway",
      trunk: "trunk",
      vpc_endpoint: "vpc_endpoint"
    };
    var NetworkInterfaceStatus = {
      associated: "associated",
      attaching: "attaching",
      available: "available",
      detaching: "detaching",
      in_use: "in-use"
    };
    var InterfacePermissionType = {
      EIP_ASSOCIATE: "EIP-ASSOCIATE",
      INSTANCE_ATTACH: "INSTANCE-ATTACH"
    };
    var NetworkInterfacePermissionStateCode = {
      granted: "granted",
      pending: "pending",
      revoked: "revoked",
      revoking: "revoking"
    };
    var SpreadLevel = {
      host: "host",
      rack: "rack"
    };
    var PlacementStrategy = {
      cluster: "cluster",
      partition: "partition",
      spread: "spread"
    };
    var PlacementGroupState = {
      available: "available",
      deleted: "deleted",
      deleting: "deleting",
      pending: "pending"
    };
    var ReplaceRootVolumeTaskState = {
      failed: "failed",
      failed_detached: "failed-detached",
      failing: "failing",
      in_progress: "in-progress",
      pending: "pending",
      succeeded: "succeeded"
    };
    var RouteServerPersistRoutesAction = {
      DISABLE: "disable",
      ENABLE: "enable",
      RESET: "reset"
    };
    var RouteServerPersistRoutesState = {
      DISABLED: "disabled",
      DISABLING: "disabling",
      ENABLED: "enabled",
      ENABLING: "enabling",
      MODIFYING: "modifying",
      RESETTING: "resetting"
    };
    var RouteServerState = {
      AVAILABLE: "available",
      DELETED: "deleted",
      DELETING: "deleting",
      MODIFYING: "modifying",
      PENDING: "pending"
    };
    var RouteServerEndpointState = {
      AVAILABLE: "available",
      DELETED: "deleted",
      DELETE_FAILED: "delete-failed",
      DELETING: "deleting",
      FAILED: "failed",
      FAILING: "failing",
      PENDING: "pending"
    };
    var RouteServerPeerLivenessMode = {
      BFD: "bfd",
      BGP_KEEPALIVE: "bgp-keepalive"
    };
    var RouteServerBfdState = {
      DOWN: "down",
      UP: "up"
    };
    var RouteServerBgpState = {
      DOWN: "down",
      UP: "up"
    };
    var RouteServerPeerState = {
      AVAILABLE: "available",
      DELETED: "deleted",
      DELETING: "deleting",
      FAILED: "failed",
      FAILING: "failing",
      PENDING: "pending"
    };
    var RouteOrigin = {
      Advertisement: "Advertisement",
      CreateRoute: "CreateRoute",
      CreateRouteTable: "CreateRouteTable",
      EnableVgwRoutePropagation: "EnableVgwRoutePropagation"
    };
    var RouteState = {
      active: "active",
      blackhole: "blackhole",
      filtered: "filtered"
    };
    var SecondaryNetworkType = {
      rdma: "rdma"
    };
    var SecondaryNetworkCidrBlockAssociationState = {
      associated: "associated",
      associating: "associating",
      association_failed: "association-failed",
      disassociated: "disassociated",
      disassociating: "disassociating",
      disassociation_failed: "disassociation-failed"
    };
    var SecondaryNetworkState = {
      create_complete: "create-complete",
      create_failed: "create-failed",
      create_in_progress: "create-in-progress",
      delete_complete: "delete-complete",
      delete_failed: "delete-failed",
      delete_in_progress: "delete-in-progress"
    };
    var SecondarySubnetCidrBlockAssociationState = {
      associated: "associated",
      associating: "associating",
      association_failed: "association-failed",
      disassociated: "disassociated",
      disassociating: "disassociating",
      disassociation_failed: "disassociation-failed"
    };
    var SecondarySubnetState = {
      create_complete: "create-complete",
      create_failed: "create-failed",
      create_in_progress: "create-in-progress",
      delete_complete: "delete-complete",
      delete_failed: "delete-failed",
      delete_in_progress: "delete-in-progress"
    };
    var SnapshotState = {
      completed: "completed",
      error: "error",
      pending: "pending",
      recoverable: "recoverable",
      recovering: "recovering"
    };
    var StorageTier = {
      archive: "archive",
      standard: "standard"
    };
    var TransferType = {
      standard: "standard",
      time_based: "time-based"
    };
    var CopyTagsFromSource = {
      volume: "volume"
    };
    var DatafeedSubscriptionState = {
      Active: "Active",
      Inactive: "Inactive"
    };
    var SubnetCidrReservationType = {
      explicit: "explicit",
      prefix: "prefix"
    };
    var TrafficMirrorRuleAction = {
      accept: "accept",
      reject: "reject"
    };
    var TrafficDirection = {
      egress: "egress",
      ingress: "ingress"
    };
    var TrafficMirrorNetworkService = {
      amazon_dns: "amazon-dns"
    };
    var TrafficMirrorTargetType = {
      gateway_load_balancer_endpoint: "gateway-load-balancer-endpoint",
      network_interface: "network-interface",
      network_load_balancer: "network-load-balancer"
    };
    var AutoAcceptSharedAttachmentsValue = {
      disable: "disable",
      enable: "enable"
    };
    var DefaultRouteTableAssociationValue = {
      disable: "disable",
      enable: "enable"
    };
    var DefaultRouteTablePropagationValue = {
      disable: "disable",
      enable: "enable"
    };
    var MulticastSupportValue = {
      disable: "disable",
      enable: "enable"
    };
    var VpnEcmpSupportValue = {
      disable: "disable",
      enable: "enable"
    };
    var EncryptionStateValue = {
      disabled: "disabled",
      disabling: "disabling",
      enabled: "enabled",
      enabling: "enabling"
    };
    var TransitGatewayState = {
      available: "available",
      deleted: "deleted",
      deleting: "deleting",
      modifying: "modifying",
      pending: "pending"
    };
    var ProtocolValue = {
      gre: "gre"
    };
    var BgpStatus = {
      down: "down",
      up: "up"
    };
    var TransitGatewayConnectPeerState = {
      available: "available",
      deleted: "deleted",
      deleting: "deleting",
      pending: "pending"
    };
    var TransitGatewayMeteringPolicyState = {
      available: "available",
      deleted: "deleted",
      deleting: "deleting",
      modifying: "modifying",
      pending: "pending"
    };
    var TransitGatewayMeteringPayerType = {
      destination_attachment_owner: "destination-attachment-owner",
      source_attachment_owner: "source-attachment-owner",
      transit_gateway_owner: "transit-gateway-owner"
    };
    var TransitGatewayMeteringPolicyEntryState = {
      available: "available",
      deleted: "deleted"
    };
    var AutoAcceptSharedAssociationsValue = {
      disable: "disable",
      enable: "enable"
    };
    var Igmpv2SupportValue = {
      disable: "disable",
      enable: "enable"
    };
    var StaticSourcesSupportValue = {
      disable: "disable",
      enable: "enable"
    };
    var TransitGatewayMulticastDomainState = {
      available: "available",
      deleted: "deleted",
      deleting: "deleting",
      pending: "pending"
    };
    var TransitGatewayPolicyTableState = {
      available: "available",
      deleted: "deleted",
      deleting: "deleting",
      pending: "pending"
    };
    var TransitGatewayPrefixListReferenceState = {
      available: "available",
      deleting: "deleting",
      modifying: "modifying",
      pending: "pending"
    };
    var TransitGatewayRouteState = {
      active: "active",
      blackhole: "blackhole",
      deleted: "deleted",
      deleting: "deleting",
      pending: "pending"
    };
    var TransitGatewayRouteType = {
      propagated: "propagated",
      static: "static"
    };
    var TransitGatewayRouteTableState = {
      available: "available",
      deleted: "deleted",
      deleting: "deleting",
      pending: "pending"
    };
    var TransitGatewayRouteTableAnnouncementDirection = {
      incoming: "incoming",
      outgoing: "outgoing"
    };
    var TransitGatewayRouteTableAnnouncementState = {
      available: "available",
      deleted: "deleted",
      deleting: "deleting",
      failed: "failed",
      failing: "failing",
      pending: "pending"
    };
    var VerifiedAccessEndpointAttachmentType = {
      vpc: "vpc"
    };
    var VerifiedAccessEndpointProtocol = {
      http: "http",
      https: "https",
      tcp: "tcp"
    };
    var VerifiedAccessEndpointType = {
      cidr: "cidr",
      load_balancer: "load-balancer",
      network_interface: "network-interface",
      rds: "rds"
    };
    var VerifiedAccessEndpointStatusCode = {
      active: "active",
      deleted: "deleted",
      deleting: "deleting",
      pending: "pending",
      updating: "updating"
    };
    var VpcEncryptionControlExclusionStateInput = {
      disable: "disable",
      enable: "enable"
    };
    var InternetGatewayExclusionMode = {
      allow_bidirectional: "allow-bidirectional",
      allow_egress: "allow-egress"
    };
    var VpcBlockPublicAccessExclusionState = {
      create_complete: "create-complete",
      create_failed: "create-failed",
      create_in_progress: "create-in-progress",
      delete_complete: "delete-complete",
      delete_in_progress: "delete-in-progress",
      disable_complete: "disable-complete",
      disable_in_progress: "disable-in-progress",
      update_complete: "update-complete",
      update_failed: "update-failed",
      update_in_progress: "update-in-progress"
    };
    var DnsRecordIpType = {
      dualstack: "dualstack",
      ipv4: "ipv4",
      ipv6: "ipv6",
      service_defined: "service-defined"
    };
    var VpcEndpointType = {
      Gateway: "Gateway",
      GatewayLoadBalancer: "GatewayLoadBalancer",
      Interface: "Interface",
      Resource: "Resource",
      ServiceNetwork: "ServiceNetwork"
    };
    var State = {
      Available: "Available",
      Deleted: "Deleted",
      Deleting: "Deleting",
      Expired: "Expired",
      Failed: "Failed",
      Partial: "Partial",
      Pending: "Pending",
      PendingAcceptance: "PendingAcceptance",
      Rejected: "Rejected"
    };
    var ConnectionNotificationState = {
      Disabled: "Disabled",
      Enabled: "Enabled"
    };
    var ConnectionNotificationType = {
      Topic: "Topic"
    };
    var PayerResponsibility = {
      ServiceOwner: "ServiceOwner"
    };
    var DnsNameState = {
      Failed: "failed",
      PendingVerification: "pendingVerification",
      Verified: "verified"
    };
    var ServiceState = {
      Available: "Available",
      Deleted: "Deleted",
      Deleting: "Deleting",
      Failed: "Failed",
      Pending: "Pending"
    };
    var ServiceType = {
      Gateway: "Gateway",
      GatewayLoadBalancer: "GatewayLoadBalancer",
      Interface: "Interface"
    };
    var ServiceConnectivityType = {
      ipv4: "ipv4",
      ipv6: "ipv6"
    };
    var VpnConcentratorType = {
      ipsec_1: "ipsec.1"
    };
    var VpnTunnelBandwidth = {
      large: "large",
      standard: "standard"
    };
    var TunnelInsideIpVersion = {
      ipv4: "ipv4",
      ipv6: "ipv6"
    };
    var GatewayAssociationState = {
      associated: "associated",
      associating: "associating",
      disassociating: "disassociating",
      not_associated: "not-associated"
    };
    var VpnStaticRouteSource = {
      Static: "Static"
    };
    var VpnState = {
      available: "available",
      deleted: "deleted",
      deleting: "deleting",
      pending: "pending"
    };
    var TelemetryStatus = {
      DOWN: "DOWN",
      UP: "UP"
    };
    var FleetStateCode = {
      ACTIVE: "active",
      DELETED: "deleted",
      DELETED_RUNNING: "deleted_running",
      DELETED_TERMINATING_INSTANCES: "deleted_terminating",
      FAILED: "failed",
      MODIFYING: "modifying",
      SUBMITTED: "submitted"
    };
    var DeleteFleetErrorCode = {
      FLEET_ID_DOES_NOT_EXIST: "fleetIdDoesNotExist",
      FLEET_ID_MALFORMED: "fleetIdMalformed",
      FLEET_NOT_IN_DELETABLE_STATE: "fleetNotInDeletableState",
      UNEXPECTED_ERROR: "unexpectedError"
    };
    var LaunchTemplateErrorCode = {
      LAUNCH_TEMPLATE_ID_DOES_NOT_EXIST: "launchTemplateIdDoesNotExist",
      LAUNCH_TEMPLATE_ID_MALFORMED: "launchTemplateIdMalformed",
      LAUNCH_TEMPLATE_NAME_DOES_NOT_EXIST: "launchTemplateNameDoesNotExist",
      LAUNCH_TEMPLATE_NAME_MALFORMED: "launchTemplateNameMalformed",
      LAUNCH_TEMPLATE_VERSION_DOES_NOT_EXIST: "launchTemplateVersionDoesNotExist",
      UNEXPECTED_ERROR: "unexpectedError"
    };
    var DeleteQueuedReservedInstancesErrorCode = {
      RESERVED_INSTANCES_ID_INVALID: "reserved-instances-id-invalid",
      RESERVED_INSTANCES_NOT_IN_QUEUED_STATE: "reserved-instances-not-in-queued-state",
      UNEXPECTED_ERROR: "unexpected-error"
    };
    var AsnState = {
      deprovisioned: "deprovisioned",
      failed_deprovision: "failed-deprovision",
      failed_provision: "failed-provision",
      pending_deprovision: "pending-deprovision",
      pending_provision: "pending-provision",
      provisioned: "provisioned"
    };
    var IpamPoolCidrFailureCode = {
      cidr_not_available: "cidr-not-available",
      limit_exceeded: "limit-exceeded"
    };
    var IpamPoolCidrState = {
      deprovisioned: "deprovisioned",
      failed_deprovision: "failed-deprovision",
      failed_import: "failed-import",
      failed_provision: "failed-provision",
      pending_deprovision: "pending-deprovision",
      pending_import: "pending-import",
      pending_provision: "pending-provision",
      provisioned: "provisioned"
    };
    var SnapshotReturnCodes = {
      ERROR_CODE_CLIENT_ERROR: "client-error",
      ERROR_CODE_INTERNAL_ERROR: "internal-error",
      ERROR_MISSING_PERMISSIONS: "missing-permissions",
      SUCCESS: "success",
      WARN_SKIPPED: "skipped"
    };
    var AvailabilityZoneOptInStatus = {
      not_opted_in: "not-opted-in",
      opt_in_not_required: "opt-in-not-required",
      opted_in: "opted-in"
    };
    var AvailabilityZoneState = {
      available: "available",
      constrained: "constrained",
      impaired: "impaired",
      information: "information",
      unavailable: "unavailable"
    };
    var MetricType = {
      aggregate_latency: "aggregate-latency"
    };
    var PeriodType = {
      fifteen_minutes: "fifteen-minutes",
      five_minutes: "five-minutes",
      one_day: "one-day",
      one_hour: "one-hour",
      one_week: "one-week",
      three_hours: "three-hours"
    };
    var StatisticType = {
      p50: "p50"
    };
    var CapacityBlockExtensionStatus = {
      PAYMENT_FAILED: "payment-failed",
      PAYMENT_PENDING: "payment-pending",
      PAYMENT_SUCCEEDED: "payment-succeeded"
    };
    var CapacityBlockResourceState = {
      active: "active",
      cancelled: "cancelled",
      expired: "expired",
      failed: "failed",
      payment_failed: "payment-failed",
      payment_pending: "payment-pending",
      scheduled: "scheduled",
      unavailable: "unavailable"
    };
    var CapacityBlockInterconnectStatus = {
      impaired: "impaired",
      insufficient_data: "insufficient-data",
      ok: "ok"
    };
    var CapacityManagerDataExportStatus = {
      DELIVERED: "delivered",
      FAILED: "failed",
      IN_PROGRESS: "in-progress",
      PENDING: "pending"
    };
    var CallerRole = {
      odcr_owner: "odcr-owner",
      unused_reservation_billing_owner: "unused-reservation-billing-owner"
    };
    var CapacityReservationBillingRequestStatus = {
      accepted: "accepted",
      cancelled: "cancelled",
      expired: "expired",
      pending: "pending",
      rejected: "rejected",
      revoked: "revoked"
    };
    var ClientVpnConnectionStatusCode = {
      active: "active",
      failed_to_terminate: "failed-to-terminate",
      terminated: "terminated",
      terminating: "terminating"
    };
    var AssociatedNetworkType = {
      vpc: "vpc"
    };
    var ClientVpnEndpointAttributeStatusCode = {
      applied: "applied",
      applying: "applying"
    };
    var VpnProtocol = {
      openvpn: "openvpn"
    };
    var ConversionTaskState = {
      active: "active",
      cancelled: "cancelled",
      cancelling: "cancelling",
      completed: "completed"
    };
    var ReportState = {
      cancelled: "cancelled",
      complete: "complete",
      error: "error",
      running: "running"
    };
    var ElasticGpuStatus = {
      Impaired: "IMPAIRED",
      Ok: "OK"
    };
    var ElasticGpuState = {
      Attached: "ATTACHED"
    };
    var FastLaunchResourceType = {
      SNAPSHOT: "snapshot"
    };
    var FastLaunchStateCode = {
      disabling: "disabling",
      disabling_failed: "disabling-failed",
      enabled: "enabled",
      enabled_failed: "enabled-failed",
      enabling: "enabling",
      enabling_failed: "enabling-failed"
    };
    var FastSnapshotRestoreStateCode = {
      disabled: "disabled",
      disabling: "disabling",
      enabled: "enabled",
      enabling: "enabling",
      optimizing: "optimizing"
    };
    var FleetEventType = {
      FLEET_CHANGE: "fleet-change",
      INSTANCE_CHANGE: "instance-change",
      SERVICE_ERROR: "service-error"
    };
    var FleetActivityStatus = {
      ERROR: "error",
      FULFILLED: "fulfilled",
      PENDING_FULFILLMENT: "pending_fulfillment",
      PENDING_TERMINATION: "pending_termination"
    };
    var FpgaImageAttributeName = {
      description: "description",
      loadPermission: "loadPermission",
      name: "name",
      productCodes: "productCodes"
    };
    var PermissionGroup = {
      all: "all"
    };
    var ProductCodeValues = {
      devpay: "devpay",
      marketplace: "marketplace"
    };
    var FpgaImageStateCode = {
      available: "available",
      failed: "failed",
      pending: "pending",
      unavailable: "unavailable"
    };
    var PaymentOption = {
      ALL_UPFRONT: "AllUpfront",
      NO_UPFRONT: "NoUpfront",
      PARTIAL_UPFRONT: "PartialUpfront"
    };
    var ReservationState = {
      ACTIVE: "active",
      CANCELLED: "cancelled",
      DELAYED: "delayed",
      EXPIRED: "expired",
      FAILED: "failed",
      PAYMENT_FAILED: "payment-failed",
      PAYMENT_PENDING: "payment-pending",
      PENDING: "pending",
      RETIRED: "retired",
      SCHEDULED: "scheduled",
      UNSUPPORTED: "unsupported"
    };
    var ImageAttributeName = {
      blockDeviceMapping: "blockDeviceMapping",
      bootMode: "bootMode",
      deregistrationProtection: "deregistrationProtection",
      description: "description",
      imdsSupport: "imdsSupport",
      kernel: "kernel",
      lastLaunchedTime: "lastLaunchedTime",
      launchPermission: "launchPermission",
      productCodes: "productCodes",
      ramdisk: "ramdisk",
      sriovNetSupport: "sriovNetSupport",
      tpmSupport: "tpmSupport",
      uefiData: "uefiData"
    };
    var ImageReferenceResourceType = {
      EC2_INSTANCE: "ec2:Instance",
      EC2_LAUNCH_TEMPLATE: "ec2:LaunchTemplate",
      IMAGE_BUILDER_CONTAINER_RECIPE: "imagebuilder:ContainerRecipe",
      IMAGE_BUILDER_IMAGE_RECIPE: "imagebuilder:ImageRecipe",
      SSM_PARAMETER: "ssm:Parameter"
    };
    var ImageReferenceOptionName = {
      STATE_NAME: "state-name",
      VERSION_DEPTH: "version-depth"
    };
    var ArchitectureValues = {
      arm64: "arm64",
      arm64_mac: "arm64_mac",
      i386: "i386",
      x86_64: "x86_64",
      x86_64_mac: "x86_64_mac"
    };
    var BootModeValues = {
      legacy_bios: "legacy-bios",
      uefi: "uefi",
      uefi_preferred: "uefi-preferred"
    };
    var HypervisorType = {
      ovm: "ovm",
      xen: "xen"
    };
    var ImageTypeValues = {
      kernel: "kernel",
      machine: "machine",
      ramdisk: "ramdisk"
    };
    var ImdsSupportValues = {
      v2_0: "v2.0"
    };
    var DeviceType = {
      ebs: "ebs",
      instance_store: "instance-store"
    };
    var ImageState = {
      available: "available",
      deregistered: "deregistered",
      disabled: "disabled",
      error: "error",
      failed: "failed",
      invalid: "invalid",
      pending: "pending",
      transient: "transient"
    };
    var TpmSupportValues = {
      v2_0: "v2.0"
    };
    var VirtualizationType = {
      hvm: "hvm",
      paravirtual: "paravirtual"
    };
    var InstanceAttributeName = {
      blockDeviceMapping: "blockDeviceMapping",
      disableApiStop: "disableApiStop",
      disableApiTermination: "disableApiTermination",
      ebsOptimized: "ebsOptimized",
      enaSupport: "enaSupport",
      enclaveOptions: "enclaveOptions",
      groupSet: "groupSet",
      instanceInitiatedShutdownBehavior: "instanceInitiatedShutdownBehavior",
      instanceType: "instanceType",
      kernel: "kernel",
      productCodes: "productCodes",
      ramdisk: "ramdisk",
      rootDeviceName: "rootDeviceName",
      sourceDestCheck: "sourceDestCheck",
      sriovNetSupport: "sriovNetSupport",
      userData: "userData"
    };
    var InstanceStateName = {
      pending: "pending",
      running: "running",
      shutting_down: "shutting-down",
      stopped: "stopped",
      stopping: "stopping",
      terminated: "terminated"
    };
    var InstanceBootModeValues = {
      legacy_bios: "legacy-bios",
      uefi: "uefi"
    };
    var InstanceLifecycleType = {
      capacity_block: "capacity-block",
      interruptible_capacity_reservation: "interruptible-capacity-reservation",
      scheduled: "scheduled",
      spot: "spot"
    };
    var InstanceAutoRecoveryState = {
      default: "default",
      disabled: "disabled"
    };
    var InstanceRebootMigrationState = {
      default: "default",
      disabled: "disabled"
    };
    var InstanceMetadataEndpointState = {
      disabled: "disabled",
      enabled: "enabled"
    };
    var InstanceMetadataProtocolState = {
      disabled: "disabled",
      enabled: "enabled"
    };
    var HttpTokensState = {
      optional: "optional",
      required: "required"
    };
    var InstanceMetadataTagsState = {
      disabled: "disabled",
      enabled: "enabled"
    };
    var InstanceMetadataOptionsState = {
      applied: "applied",
      pending: "pending"
    };
    var MonitoringState = {
      disabled: "disabled",
      disabling: "disabling",
      enabled: "enabled",
      pending: "pending"
    };
    var SecondaryInterfaceStatus = {
      available: "available",
      in_use: "in-use"
    };
    var HaStatus = {
      active: "active",
      invalid: "invalid",
      processing: "processing",
      standby: "standby"
    };
    var SqlServerLicenseUsage = {
      full: "full",
      waived: "waived"
    };
    var StatusName = {
      reachability: "reachability"
    };
    var StatusType = {
      failed: "failed",
      initializing: "initializing",
      insufficient_data: "insufficient-data",
      passed: "passed"
    };
    var SummaryStatus = {
      impaired: "impaired",
      initializing: "initializing",
      insufficient_data: "insufficient-data",
      not_applicable: "not-applicable",
      ok: "ok"
    };
    var EventCode = {
      instance_reboot: "instance-reboot",
      instance_retirement: "instance-retirement",
      instance_stop: "instance-stop",
      system_maintenance: "system-maintenance",
      system_reboot: "system-reboot"
    };
    var LocationType = {
      availability_zone: "availability-zone",
      availability_zone_id: "availability-zone-id",
      outpost: "outpost",
      region: "region"
    };
    var AttachmentLimitType = {
      DEDICATED: "dedicated",
      SHARED: "shared"
    };
    var EbsOptimizedSupport = {
      default: "default",
      supported: "supported",
      unsupported: "unsupported"
    };
    var EbsEncryptionSupport = {
      supported: "supported",
      unsupported: "unsupported"
    };
    var EbsNvmeSupport = {
      REQUIRED: "required",
      SUPPORTED: "supported",
      UNSUPPORTED: "unsupported"
    };
    var InstanceTypeHypervisor = {
      NITRO: "nitro",
      XEN: "xen"
    };
    var DiskType = {
      hdd: "hdd",
      ssd: "ssd"
    };
    var InstanceStorageEncryptionSupport = {
      required: "required",
      unsupported: "unsupported"
    };
    var EphemeralNvmeSupport = {
      REQUIRED: "required",
      SUPPORTED: "supported",
      UNSUPPORTED: "unsupported"
    };
    var BandwidthWeightingType = {
      DEFAULT: "default",
      EBS_1: "ebs-1",
      VPC_1: "vpc-1"
    };
    var EnaSupport = {
      required: "required",
      supported: "supported",
      unsupported: "unsupported"
    };
    var FlexibleEnaQueuesSupport = {
      SUPPORTED: "supported",
      UNSUPPORTED: "unsupported"
    };
    var NitroEnclavesSupport = {
      SUPPORTED: "supported",
      UNSUPPORTED: "unsupported"
    };
    var NitroTpmSupport = {
      SUPPORTED: "supported",
      UNSUPPORTED: "unsupported"
    };
    var PhcSupport = {
      SUPPORTED: "supported",
      UNSUPPORTED: "unsupported"
    };
    var PlacementGroupStrategy = {
      cluster: "cluster",
      partition: "partition",
      spread: "spread"
    };
    var ArchitectureType = {
      arm64: "arm64",
      arm64_mac: "arm64_mac",
      i386: "i386",
      x86_64: "x86_64",
      x86_64_mac: "x86_64_mac"
    };
    var SupportedAdditionalProcessorFeature = {
      AMD_SEV_SNP: "amd-sev-snp",
      NESTED_VIRTUALIZATION: "nested-virtualization"
    };
    var RebootMigrationSupport = {
      SUPPORTED: "supported",
      UNSUPPORTED: "unsupported"
    };
    var BootModeType = {
      legacy_bios: "legacy-bios",
      uefi: "uefi"
    };
    var RootDeviceType = {
      ebs: "ebs",
      instance_store: "instance-store"
    };
    var UsageClassType = {
      capacity_block: "capacity-block",
      on_demand: "on-demand",
      spot: "spot"
    };
    var LockState = {
      compliance: "compliance",
      compliance_cooloff: "compliance-cooloff",
      expired: "expired",
      governance: "governance"
    };
    var MoveStatus = {
      movingToVpc: "movingToVpc",
      restoringToClassic: "restoringToClassic"
    };
    var FindingsFound = {
      false: "false",
      true: "true",
      unknown: "unknown"
    };
    var AnalysisStatus = {
      failed: "failed",
      running: "running",
      succeeded: "succeeded"
    };
    var NetworkInterfaceAttribute = {
      associatePublicIpAddress: "associatePublicIpAddress",
      attachment: "attachment",
      description: "description",
      groupSet: "groupSet",
      sourceDestCheck: "sourceDestCheck"
    };
    var OfferingClassType = {
      CONVERTIBLE: "convertible",
      STANDARD: "standard"
    };
    var OfferingTypeValues = {
      All_Upfront: "All Upfront",
      Heavy_Utilization: "Heavy Utilization",
      Light_Utilization: "Light Utilization",
      Medium_Utilization: "Medium Utilization",
      No_Upfront: "No Upfront",
      Partial_Upfront: "Partial Upfront"
    };
    var RIProductDescription = {
      Linux_UNIX: "Linux/UNIX",
      Linux_UNIX_Amazon_VPC_: "Linux/UNIX (Amazon VPC)",
      Windows: "Windows",
      Windows_Amazon_VPC_: "Windows (Amazon VPC)"
    };
    var RecurringChargeFrequency = {
      Hourly: "Hourly"
    };
    var Scope = {
      AVAILABILITY_ZONE: "Availability Zone",
      REGIONAL: "Region"
    };
    var ReservedInstanceState = {
      active: "active",
      payment_failed: "payment-failed",
      payment_pending: "payment-pending",
      queued: "queued",
      queued_deleted: "queued-deleted",
      retired: "retired"
    };
    var ServiceLinkVirtualInterfaceConfigurationState = {
      available: "available",
      deleted: "deleted",
      deleting: "deleting",
      pending: "pending"
    };
    var SnapshotAttributeName = {
      createVolumePermission: "createVolumePermission",
      productCodes: "productCodes"
    };
    var TieringOperationStatus = {
      archival_completed: "archival-completed",
      archival_failed: "archival-failed",
      archival_in_progress: "archival-in-progress",
      permanent_restore_completed: "permanent-restore-completed",
      permanent_restore_failed: "permanent-restore-failed",
      permanent_restore_in_progress: "permanent-restore-in-progress",
      temporary_restore_completed: "temporary-restore-completed",
      temporary_restore_failed: "temporary-restore-failed",
      temporary_restore_in_progress: "temporary-restore-in-progress"
    };
    var EventType2 = {
      BATCH_CHANGE: "fleetRequestChange",
      ERROR: "error",
      INFORMATION: "information",
      INSTANCE_CHANGE: "instanceChange"
    };
    var ExcessCapacityTerminationPolicy = {
      DEFAULT: "default",
      NO_TERMINATION: "noTermination"
    };
    var OnDemandAllocationStrategy = {
      LOWEST_PRICE: "lowestPrice",
      PRIORITIZED: "prioritized"
    };
    var ReplacementStrategy = {
      LAUNCH: "launch",
      LAUNCH_BEFORE_TERMINATE: "launch-before-terminate"
    };
    var SpotInstanceState = {
      active: "active",
      cancelled: "cancelled",
      closed: "closed",
      disabled: "disabled",
      failed: "failed",
      open: "open"
    };
    var VerifiedAccessLogDeliveryStatusCode = {
      FAILED: "failed",
      SUCCESS: "success"
    };
    var VolumeAttributeName = {
      autoEnableIO: "autoEnableIO",
      productCodes: "productCodes"
    };
    var VolumeModificationState = {
      completed: "completed",
      failed: "failed",
      modifying: "modifying",
      optimizing: "optimizing"
    };
    var InitializationType = {
      default: "default",
      provisioned_rate: "provisioned-rate",
      volume_copy: "volume-copy"
    };
    var VolumeStatusName = {
      initialization_state: "initialization-state",
      io_enabled: "io-enabled",
      io_performance: "io-performance"
    };
    var VolumeStatusInfoStatus = {
      impaired: "impaired",
      insufficient_data: "insufficient-data",
      ok: "ok",
      warning: "warning"
    };
    var VpcAttributeName = {
      enableDnsHostnames: "enableDnsHostnames",
      enableDnsSupport: "enableDnsSupport",
      enableNetworkAddressUsageMetrics: "enableNetworkAddressUsageMetrics"
    };
    var VpcBlockPublicAccessExclusionsAllowed = {
      allowed: "allowed",
      not_allowed: "not-allowed"
    };
    var InternetGatewayBlockMode = {
      block_bidirectional: "block-bidirectional",
      block_ingress: "block-ingress",
      off: "off"
    };
    var ManagedBy = {
      account: "account",
      declarative_policy: "declarative-policy"
    };
    var VpcBlockPublicAccessState = {
      default_state: "default-state",
      update_complete: "update-complete",
      update_in_progress: "update-in-progress"
    };
    var CapacityManagerStatus = {
      DISABLED: "disabled",
      ENABLED: "enabled"
    };
    var ImageBlockPublicAccessDisabledState = {
      unblocked: "unblocked"
    };
    var RouteServerPropagationState = {
      AVAILABLE: "available",
      DELETING: "deleting",
      PENDING: "pending"
    };
    var SnapshotBlockPublicAccessState = {
      block_all_sharing: "block-all-sharing",
      block_new_sharing: "block-new-sharing",
      unblocked: "unblocked"
    };
    var TransitGatewayPropagationState = {
      disabled: "disabled",
      disabling: "disabling",
      enabled: "enabled",
      enabling: "enabling"
    };
    var ImageBlockPublicAccessEnabledState = {
      block_new_sharing: "block-new-sharing"
    };
    var ClientCertificateRevocationListStatusCode = {
      active: "active",
      pending: "pending"
    };
    var IngestionStatus = {
      INGESTION_COMPLETE: "ingestion-complete",
      INGESTION_FAILED: "ingestion-failed",
      INITIAL_INGESTION_IN_PROGRESS: "initial-ingestion-in-progress"
    };
    var Comparison = {
      EQUALS: "equals",
      IN: "in"
    };
    var FilterByDimension = {
      ACCOUNT_ID: "account-id",
      ACCOUNT_NAME: "account-name",
      AVAILABILITY_ZONE_ID: "availability-zone-id",
      INSTANCE_FAMILY: "instance-family",
      INSTANCE_PLATFORM: "instance-platform",
      INSTANCE_TYPE: "instance-type",
      RESERVATION_ARN: "reservation-arn",
      RESERVATION_CREATE_TIMESTAMP: "reservation-create-timestamp",
      RESERVATION_END_DATE_TYPE: "reservation-end-date-type",
      RESERVATION_END_TIMESTAMP: "reservation-end-timestamp",
      RESERVATION_ID: "reservation-id",
      RESERVATION_INSTANCE_MATCH_CRITERIA: "reservation-instance-match-criteria",
      RESERVATION_START_TIMESTAMP: "reservation-start-timestamp",
      RESERVATION_STATE: "reservation-state",
      RESERVATION_TYPE: "reservation-type",
      RESERVATION_UNUSED_FINANCIAL_OWNER: "reservation-unused-financial-owner",
      RESOURCE_REGION: "resource-region",
      TENANCY: "tenancy"
    };
    var GroupBy = {
      ACCOUNT_ID: "account-id",
      ACCOUNT_NAME: "account-name",
      AVAILABILITY_ZONE_ID: "availability-zone-id",
      INSTANCE_FAMILY: "instance-family",
      INSTANCE_PLATFORM: "instance-platform",
      INSTANCE_TYPE: "instance-type",
      RESERVATION_ARN: "reservation-arn",
      RESERVATION_CREATE_TIMESTAMP: "reservation-create-timestamp",
      RESERVATION_END_DATE_TYPE: "reservation-end-date-type",
      RESERVATION_END_TIMESTAMP: "reservation-end-timestamp",
      RESERVATION_ID: "reservation-id",
      RESERVATION_INSTANCE_MATCH_CRITERIA: "reservation-instance-match-criteria",
      RESERVATION_START_TIMESTAMP: "reservation-start-timestamp",
      RESERVATION_STATE: "reservation-state",
      RESERVATION_TYPE: "reservation-type",
      RESERVATION_UNUSED_FINANCIAL_OWNER: "reservation-unused-financial-owner",
      RESOURCE_REGION: "resource-region",
      TENANCY: "tenancy"
    };
    var Metric = {
      RESERVATION_AVG_COMMITTED_SIZE_INST: "reservation-avg-committed-size-inst",
      RESERVATION_AVG_COMMITTED_SIZE_VCPU: "reservation-avg-committed-size-vcpu",
      RESERVATION_AVG_FUTURE_SIZE_INST: "reservation-avg-future-size-inst",
      RESERVATION_AVG_FUTURE_SIZE_VCPU: "reservation-avg-future-size-vcpu",
      RESERVATION_AVG_UTILIZATION_INST: "reservation-avg-utilization-inst",
      RESERVATION_AVG_UTILIZATION_VCPU: "reservation-avg-utilization-vcpu",
      RESERVATION_MAX_COMMITTED_SIZE_INST: "reservation-max-committed-size-inst",
      RESERVATION_MAX_COMMITTED_SIZE_VCPU: "reservation-max-committed-size-vcpu",
      RESERVATION_MAX_FUTURE_SIZE_INST: "reservation-max-future-size-inst",
      RESERVATION_MAX_FUTURE_SIZE_VCPU: "reservation-max-future-size-vcpu",
      RESERVATION_MAX_SIZE_INST: "reservation-max-size-inst",
      RESERVATION_MAX_SIZE_VCPU: "reservation-max-size-vcpu",
      RESERVATION_MAX_UNUSED_SIZE_INST: "reservation-max-unused-size-inst",
      RESERVATION_MAX_UNUSED_SIZE_VCPU: "reservation-max-unused-size-vcpu",
      RESERVATION_MAX_UTILIZATION: "reservation-max-utilization",
      RESERVATION_MIN_COMMITTED_SIZE_INST: "reservation-min-committed-size-inst",
      RESERVATION_MIN_COMMITTED_SIZE_VCPU: "reservation-min-committed-size-vcpu",
      RESERVATION_MIN_FUTURE_SIZE_INST: "reservation-min-future-size-inst",
      RESERVATION_MIN_FUTURE_SIZE_VCPU: "reservation-min-future-size-vcpu",
      RESERVATION_MIN_SIZE_INST: "reservation-min-size-inst",
      RESERVATION_MIN_SIZE_VCPU: "reservation-min-size-vcpu",
      RESERVATION_MIN_UNUSED_SIZE_INST: "reservation-min-unused-size-inst",
      RESERVATION_MIN_UNUSED_SIZE_VCPU: "reservation-min-unused-size-vcpu",
      RESERVATION_MIN_UTILIZATION: "reservation-min-utilization",
      RESERVATION_TOTAL_CAPACITY_HRS_INST: "reservation-total-capacity-hrs-inst",
      RESERVATION_TOTAL_CAPACITY_HRS_VCPU: "reservation-total-capacity-hrs-vcpu",
      RESERVATION_TOTAL_COUNT: "reservation-total-count",
      RESERVATION_TOTAL_ESTIMATED_COST: "reservation-total-estimated-cost",
      RESERVATION_UNUSED_TOTAL_CAPACITY_HRS_INST: "reservation-unused-total-capacity-hrs-inst",
      RESERVATION_UNUSED_TOTAL_CAPACITY_HRS_VCPU: "reservation-unused-total-capacity-hrs-vcpu",
      RESERVATION_UNUSED_TOTAL_ESTIMATED_COST: "reservation-unused-total-estimated-cost",
      RESERVED_TOTAL_ESTIMATED_COST: "reserved-total-estimated-cost",
      RESERVED_TOTAL_USAGE_HRS_INST: "reserved-total-usage-hrs-inst",
      RESERVED_TOTAL_USAGE_HRS_VCPU: "reserved-total-usage-hrs-vcpu",
      SPOT_AVG_RUN_TIME_BEFORE_INTERRUPTION_INST: "spot-avg-run-time-before-interruption-inst",
      SPOT_INTERRUPTION_RATE_INST: "spot-interruption-rate-inst",
      SPOT_INTERRUPTION_RATE_VCPU: "spot-interruption-rate-vcpu",
      SPOT_MAX_RUN_TIME_BEFORE_INTERRUPTION_INST: "spot-max-run-time-before-interruption-inst",
      SPOT_MIN_RUN_TIME_BEFORE_INTERRUPTION_INST: "spot-min-run-time-before-interruption-inst",
      SPOT_TOTAL_COUNT_INST: "spot-total-count-inst",
      SPOT_TOTAL_COUNT_VCPU: "spot-total-count-vcpu",
      SPOT_TOTAL_ESTIMATED_COST: "spot-total-estimated-cost",
      SPOT_TOTAL_INTERRUPTIONS_INST: "spot-total-interruptions-inst",
      SPOT_TOTAL_INTERRUPTIONS_VCPU: "spot-total-interruptions-vcpu",
      SPOT_TOTAL_USAGE_HRS_INST: "spot-total-usage-hrs-inst",
      SPOT_TOTAL_USAGE_HRS_VCPU: "spot-total-usage-hrs-vcpu",
      UNRESERVED_TOTAL_ESTIMATED_COST: "unreserved-total-estimated-cost",
      UNRESERVED_TOTAL_USAGE_HRS_INST: "unreserved-total-usage-hrs-inst",
      UNRESERVED_TOTAL_USAGE_HRS_VCPU: "unreserved-total-usage-hrs-vcpu"
    };
    var ReservationEndDateType = {
      LIMITED: "limited",
      UNLIMITED: "unlimited"
    };
    var ReservationType = {
      CAPACITY_BLOCK: "capacity-block",
      ODCR: "odcr"
    };
    var CapacityTenancy = {
      DEDICATED: "dedicated",
      DEFAULT: "default"
    };
    var CapacityManagerMonitoredTagKeyStatus = {
      ACTIVATED: "activated",
      ACTIVATING: "activating",
      DEACTIVATING: "deactivating",
      SUSPENDED: "suspended"
    };
    var UnlimitedSupportedInstanceFamily = {
      t2: "t2",
      t3: "t3",
      t3a: "t3a",
      t4g: "t4g"
    };
    var IpamPolicyManagedBy = {
      account: "account",
      delegated_administrator_for_ipam: "delegated-administrator-for-ipam"
    };
    var PartitionLoadFrequency = {
      DAILY: "daily",
      MONTHLY: "monthly",
      NONE: "none",
      WEEKLY: "weekly"
    };
    var HttpTokensEnforcedState = {
      disabled: "disabled",
      enabled: "enabled"
    };
    var EkPubKeyFormat = {
      der: "der",
      tpmt: "tpmt"
    };
    var EkPubKeyType = {
      ECC_SEC_P384: "ecc-sec-p384",
      RSA_2048: "rsa-2048"
    };
    var IpamComplianceStatus = {
      compliant: "compliant",
      ignored: "ignored",
      noncompliant: "noncompliant",
      unmanaged: "unmanaged"
    };
    var IpamOverlapStatus = {
      ignored: "ignored",
      nonoverlapping: "nonoverlapping",
      overlapping: "overlapping"
    };
    var IpamAddressHistoryResourceType = {
      eip: "eip",
      instance: "instance",
      network_interface: "network-interface",
      subnet: "subnet",
      vpc: "vpc"
    };
    var IpamDiscoveryFailureCode = {
      assume_role_failure: "assume-role-failure",
      throttling_failure: "throttling-failure",
      unauthorized_failure: "unauthorized-failure"
    };
    var IpamPublicAddressType = {
      AMAZON_OWNED_CONTIG: "amazon-owned-contig",
      AMAZON_OWNED_EIP: "amazon-owned-eip",
      ANYCAST_IP_LIST_IP: "anycast-ip-list-ip",
      BYOIP: "byoip",
      EC2_PUBLIC_IP: "ec2-public-ip",
      SERVICE_MANAGED_BYOIP: "service-managed-byoip",
      SERVICE_MANAGED_IP: "service-managed-ip"
    };
    var IpamPublicAddressAssociationStatus = {
      ASSOCIATED: "associated",
      DISASSOCIATED: "disassociated"
    };
    var IpamPublicAddressAwsService = {
      AGA: "global-accelerator",
      CLOUDFRONT: "cloudfront",
      DMS: "database-migration-service",
      EC2_LB: "load-balancer",
      ECS: "elastic-container-service",
      NAT_GATEWAY: "nat-gateway",
      OTHER: "other",
      RDS: "relational-database-service",
      REDSHIFT: "redshift",
      S2S_VPN: "site-to-site-vpn"
    };
    var IpamResourceCidrIpSource = {
      amazon: "amazon",
      byoip: "byoip",
      none: "none"
    };
    var IpamNetworkInterfaceAttachmentStatus = {
      available: "available",
      in_use: "in-use"
    };
    var IpamPolicyResourceType = {
      alb: "alb",
      eip: "eip",
      rds: "rds",
      rnat: "rnat"
    };
    var IpamManagementState = {
      ignored: "ignored",
      managed: "managed",
      unmanaged: "unmanaged"
    };
    var ManagedResourceDefaultVisibility = {
      hidden: "hidden",
      visible: "visible"
    };
    var RouteServerRouteInstallationStatus = {
      INSTALLED: "installed",
      REJECTED: "rejected"
    };
    var RouteServerRouteStatus = {
      IN_FIB: "in-fib",
      IN_RIB: "in-rib"
    };
    var LockMode = {
      compliance: "compliance",
      governance: "governance"
    };
    var ModifyAvailabilityZoneOptInStatus = {
      not_opted_in: "not-opted-in",
      opted_in: "opted-in"
    };
    var OperationType = {
      add: "add",
      remove: "remove"
    };
    var UnsuccessfulInstanceCreditSpecificationErrorCode = {
      INCORRECT_INSTANCE_STATE: "IncorrectInstanceState",
      INSTANCE_CREDIT_SPECIFICATION_NOT_SUPPORTED: "InstanceCreditSpecification.NotSupported",
      INSTANCE_NOT_FOUND: "InvalidInstanceID.NotFound",
      INVALID_INSTANCE_ID: "InvalidInstanceID.Malformed"
    };
    var DefaultInstanceMetadataEndpointState = {
      disabled: "disabled",
      enabled: "enabled",
      no_preference: "no-preference"
    };
    var MetadataDefaultHttpTokensState = {
      no_preference: "no-preference",
      optional: "optional",
      required: "required"
    };
    var DefaultHttpTokensEnforcedState = {
      disabled: "disabled",
      enabled: "enabled",
      no_preference: "no-preference"
    };
    var DefaultInstanceMetadataTagsState = {
      disabled: "disabled",
      enabled: "enabled",
      no_preference: "no-preference"
    };
    var HostTenancy = {
      dedicated: "dedicated",
      default: "default",
      host: "host"
    };
    var PublicIpDnsOption = {
      public_dual_stack_dns_name: "public-dual-stack-dns-name",
      public_ipv4_dns_name: "public-ipv4-dns-name",
      public_ipv6_dns_name: "public-ipv6-dns-name"
    };
    var TargetStorageTier = {
      archive: "archive"
    };
    var TrafficMirrorFilterRuleField = {
      description: "description",
      destination_port_range: "destination-port-range",
      protocol: "protocol",
      source_port_range: "source-port-range"
    };
    var TrafficMirrorSessionField = {
      description: "description",
      packet_length: "packet-length",
      virtual_network_id: "virtual-network-id"
    };
    var EncryptionSupportOptionValue = {
      disable: "disable",
      enable: "enable"
    };
    var VpcTenancy = {
      default: "default"
    };
    var Status = {
      inClassic: "InClassic",
      inVpc: "InVpc",
      moveInProgress: "MoveInProgress"
    };
    var VerificationMethod = {
      dns_token: "dns-token",
      remarks_x509: "remarks-x509"
    };
    var ReportInstanceReasonCodes = {
      instance_stuck_in_state: "instance-stuck-in-state",
      not_accepting_credentials: "not-accepting-credentials",
      other: "other",
      password_not_available: "password-not-available",
      performance_ebs_volume: "performance-ebs-volume",
      performance_instance_store: "performance-instance-store",
      performance_network: "performance-network",
      performance_other: "performance-other",
      unresponsive: "unresponsive"
    };
    var ReportStatusType = {
      impaired: "impaired",
      ok: "ok"
    };
    var ResetFpgaImageAttributeName = {
      loadPermission: "loadPermission"
    };
    var ResetImageAttributeName = {
      launchPermission: "launchPermission"
    };
    var MembershipType = {
      igmp: "igmp",
      static: "static"
    };
    exports2.$Command = smithyClient.Command;
    exports2.__Client = smithyClient.Client;
    exports2.EC2ServiceException = EC2ServiceException.EC2ServiceException;
    exports2.AcceleratorManufacturer = AcceleratorManufacturer;
    exports2.AcceleratorName = AcceleratorName;
    exports2.AcceleratorType = AcceleratorType;
    exports2.AcceptAddressTransferCommand = AcceptAddressTransferCommand;
    exports2.AcceptCapacityReservationBillingOwnershipCommand = AcceptCapacityReservationBillingOwnershipCommand;
    exports2.AcceptReservedInstancesExchangeQuoteCommand = AcceptReservedInstancesExchangeQuoteCommand;
    exports2.AcceptTransitGatewayClientVpnAttachmentCommand = AcceptTransitGatewayClientVpnAttachmentCommand;
    exports2.AcceptTransitGatewayMulticastDomainAssociationsCommand = AcceptTransitGatewayMulticastDomainAssociationsCommand;
    exports2.AcceptTransitGatewayPeeringAttachmentCommand = AcceptTransitGatewayPeeringAttachmentCommand;
    exports2.AcceptTransitGatewayVpcAttachmentCommand = AcceptTransitGatewayVpcAttachmentCommand;
    exports2.AcceptVpcEndpointConnectionsCommand = AcceptVpcEndpointConnectionsCommand;
    exports2.AcceptVpcPeeringConnectionCommand = AcceptVpcPeeringConnectionCommand;
    exports2.AccountAttributeName = AccountAttributeName;
    exports2.ActivityStatus = ActivityStatus;
    exports2.AddressAttributeName = AddressAttributeName;
    exports2.AddressFamily = AddressFamily;
    exports2.AddressTransferStatus = AddressTransferStatus;
    exports2.AdvertiseByoipCidrCommand = AdvertiseByoipCidrCommand;
    exports2.Affinity = Affinity;
    exports2.AllocateAddressCommand = AllocateAddressCommand;
    exports2.AllocateHostsCommand = AllocateHostsCommand;
    exports2.AllocateIpamPoolCidrCommand = AllocateIpamPoolCidrCommand;
    exports2.AllocationState = AllocationState;
    exports2.AllocationStrategy = AllocationStrategy;
    exports2.AllocationType = AllocationType;
    exports2.AllowedImagesSettingsDisabledState = AllowedImagesSettingsDisabledState;
    exports2.AllowedImagesSettingsEnabledState = AllowedImagesSettingsEnabledState;
    exports2.AllowsMultipleInstanceTypes = AllowsMultipleInstanceTypes;
    exports2.AmdSevSnpSpecification = AmdSevSnpSpecification;
    exports2.AnalysisStatus = AnalysisStatus;
    exports2.ApplianceModeSupportValue = ApplianceModeSupportValue;
    exports2.ApplySecurityGroupsToClientVpnTargetNetworkCommand = ApplySecurityGroupsToClientVpnTargetNetworkCommand;
    exports2.ArchitectureType = ArchitectureType;
    exports2.ArchitectureValues = ArchitectureValues;
    exports2.AsnAssociationState = AsnAssociationState;
    exports2.AsnState = AsnState;
    exports2.AssignIpv6AddressesCommand = AssignIpv6AddressesCommand;
    exports2.AssignPrivateIpAddressesCommand = AssignPrivateIpAddressesCommand;
    exports2.AssignPrivateNatGatewayAddressCommand = AssignPrivateNatGatewayAddressCommand;
    exports2.AssociateAddressCommand = AssociateAddressCommand;
    exports2.AssociateCapacityReservationBillingOwnerCommand = AssociateCapacityReservationBillingOwnerCommand;
    exports2.AssociateClientVpnTargetNetworkCommand = AssociateClientVpnTargetNetworkCommand;
    exports2.AssociateDhcpOptionsCommand = AssociateDhcpOptionsCommand;
    exports2.AssociateEnclaveCertificateIamRoleCommand = AssociateEnclaveCertificateIamRoleCommand;
    exports2.AssociateIamInstanceProfileCommand = AssociateIamInstanceProfileCommand;
    exports2.AssociateInstanceEventWindowCommand = AssociateInstanceEventWindowCommand;
    exports2.AssociateIpamByoasnCommand = AssociateIpamByoasnCommand;
    exports2.AssociateIpamResourceDiscoveryCommand = AssociateIpamResourceDiscoveryCommand;
    exports2.AssociateNatGatewayAddressCommand = AssociateNatGatewayAddressCommand;
    exports2.AssociateRouteServerCommand = AssociateRouteServerCommand;
    exports2.AssociateRouteTableCommand = AssociateRouteTableCommand;
    exports2.AssociateSecurityGroupVpcCommand = AssociateSecurityGroupVpcCommand;
    exports2.AssociateSubnetCidrBlockCommand = AssociateSubnetCidrBlockCommand;
    exports2.AssociateTransitGatewayMulticastDomainCommand = AssociateTransitGatewayMulticastDomainCommand;
    exports2.AssociateTransitGatewayPolicyTableCommand = AssociateTransitGatewayPolicyTableCommand;
    exports2.AssociateTransitGatewayRouteTableCommand = AssociateTransitGatewayRouteTableCommand;
    exports2.AssociateTrunkInterfaceCommand = AssociateTrunkInterfaceCommand;
    exports2.AssociateVpcCidrBlockCommand = AssociateVpcCidrBlockCommand;
    exports2.AssociatedNetworkType = AssociatedNetworkType;
    exports2.AssociationStatusCode = AssociationStatusCode;
    exports2.AttachClassicLinkVpcCommand = AttachClassicLinkVpcCommand;
    exports2.AttachInternetGatewayCommand = AttachInternetGatewayCommand;
    exports2.AttachNetworkInterfaceCommand = AttachNetworkInterfaceCommand;
    exports2.AttachVerifiedAccessTrustProviderCommand = AttachVerifiedAccessTrustProviderCommand;
    exports2.AttachVolumeCommand = AttachVolumeCommand;
    exports2.AttachVpnGatewayCommand = AttachVpnGatewayCommand;
    exports2.AttachmentLimitType = AttachmentLimitType;
    exports2.AttachmentStatus = AttachmentStatus;
    exports2.AuthorizeClientVpnIngressCommand = AuthorizeClientVpnIngressCommand;
    exports2.AuthorizeSecurityGroupEgressCommand = AuthorizeSecurityGroupEgressCommand;
    exports2.AuthorizeSecurityGroupIngressCommand = AuthorizeSecurityGroupIngressCommand;
    exports2.AutoAcceptSharedAssociationsValue = AutoAcceptSharedAssociationsValue;
    exports2.AutoAcceptSharedAttachmentsValue = AutoAcceptSharedAttachmentsValue;
    exports2.AutoPlacement = AutoPlacement;
    exports2.AutoProvisionZonesState = AutoProvisionZonesState;
    exports2.AutoScalingIpsState = AutoScalingIpsState;
    exports2.AvailabilityMode = AvailabilityMode;
    exports2.AvailabilityZoneOptInStatus = AvailabilityZoneOptInStatus;
    exports2.AvailabilityZoneState = AvailabilityZoneState;
    exports2.BandwidthWeightingType = BandwidthWeightingType;
    exports2.BareMetal = BareMetal;
    exports2.BatchState = BatchState;
    exports2.BgpStatus = BgpStatus;
    exports2.BlockPublicAccessMode = BlockPublicAccessMode;
    exports2.BootModeType = BootModeType;
    exports2.BootModeValues = BootModeValues;
    exports2.BundleInstanceCommand = BundleInstanceCommand;
    exports2.BundleTaskState = BundleTaskState;
    exports2.BurstablePerformance = BurstablePerformance;
    exports2.ByoipCidrState = ByoipCidrState;
    exports2.CallerRole = CallerRole;
    exports2.CancelBatchErrorCode = CancelBatchErrorCode;
    exports2.CancelBundleTaskCommand = CancelBundleTaskCommand;
    exports2.CancelCapacityReservationCommand = CancelCapacityReservationCommand;
    exports2.CancelCapacityReservationFleetsCommand = CancelCapacityReservationFleetsCommand;
    exports2.CancelConversionTaskCommand = CancelConversionTaskCommand;
    exports2.CancelDeclarativePoliciesReportCommand = CancelDeclarativePoliciesReportCommand;
    exports2.CancelExportTaskCommand = CancelExportTaskCommand;
    exports2.CancelImageLaunchPermissionCommand = CancelImageLaunchPermissionCommand;
    exports2.CancelImportTaskCommand = CancelImportTaskCommand;
    exports2.CancelReservedInstancesListingCommand = CancelReservedInstancesListingCommand;
    exports2.CancelSpotFleetRequestsCommand = CancelSpotFleetRequestsCommand;
    exports2.CancelSpotInstanceRequestState = CancelSpotInstanceRequestState;
    exports2.CancelSpotInstanceRequestsCommand = CancelSpotInstanceRequestsCommand;
    exports2.CapacityBlockExtensionStatus = CapacityBlockExtensionStatus;
    exports2.CapacityBlockInterconnectStatus = CapacityBlockInterconnectStatus;
    exports2.CapacityBlockResourceState = CapacityBlockResourceState;
    exports2.CapacityManagerDataExportStatus = CapacityManagerDataExportStatus;
    exports2.CapacityManagerMonitoredTagKeyStatus = CapacityManagerMonitoredTagKeyStatus;
    exports2.CapacityManagerStatus = CapacityManagerStatus;
    exports2.CapacityReservationBillingRequestStatus = CapacityReservationBillingRequestStatus;
    exports2.CapacityReservationDeliveryPreference = CapacityReservationDeliveryPreference;
    exports2.CapacityReservationFleetState = CapacityReservationFleetState;
    exports2.CapacityReservationInstancePlatform = CapacityReservationInstancePlatform;
    exports2.CapacityReservationPreference = CapacityReservationPreference;
    exports2.CapacityReservationState = CapacityReservationState;
    exports2.CapacityReservationTenancy = CapacityReservationTenancy;
    exports2.CapacityReservationType = CapacityReservationType;
    exports2.CapacityTenancy = CapacityTenancy;
    exports2.CarrierGatewayState = CarrierGatewayState;
    exports2.ClientCertificateRevocationListStatusCode = ClientCertificateRevocationListStatusCode;
    exports2.ClientVpnAuthenticationType = ClientVpnAuthenticationType;
    exports2.ClientVpnAuthorizationRuleStatusCode = ClientVpnAuthorizationRuleStatusCode;
    exports2.ClientVpnConnectionStatusCode = ClientVpnConnectionStatusCode;
    exports2.ClientVpnEndpointAttributeStatusCode = ClientVpnEndpointAttributeStatusCode;
    exports2.ClientVpnEndpointStatusCode = ClientVpnEndpointStatusCode;
    exports2.ClientVpnRouteStatusCode = ClientVpnRouteStatusCode;
    exports2.Comparison = Comparison;
    exports2.ConfirmProductInstanceCommand = ConfirmProductInstanceCommand;
    exports2.ConnectionNotificationState = ConnectionNotificationState;
    exports2.ConnectionNotificationType = ConnectionNotificationType;
    exports2.ConnectivityType = ConnectivityType;
    exports2.ContainerFormat = ContainerFormat;
    exports2.ConversionTaskState = ConversionTaskState;
    exports2.CopyFpgaImageCommand = CopyFpgaImageCommand;
    exports2.CopyImageCommand = CopyImageCommand;
    exports2.CopySnapshotCommand = CopySnapshotCommand;
    exports2.CopyTagsFromSource = CopyTagsFromSource;
    exports2.CopyVolumesCommand = CopyVolumesCommand;
    exports2.CpuManufacturer = CpuManufacturer;
    exports2.CreateCapacityManagerDataExportCommand = CreateCapacityManagerDataExportCommand;
    exports2.CreateCapacityReservationBySplittingCommand = CreateCapacityReservationBySplittingCommand;
    exports2.CreateCapacityReservationCommand = CreateCapacityReservationCommand;
    exports2.CreateCapacityReservationFleetCommand = CreateCapacityReservationFleetCommand;
    exports2.CreateCarrierGatewayCommand = CreateCarrierGatewayCommand;
    exports2.CreateClientVpnEndpointCommand = CreateClientVpnEndpointCommand;
    exports2.CreateClientVpnRouteCommand = CreateClientVpnRouteCommand;
    exports2.CreateCoipCidrCommand = CreateCoipCidrCommand;
    exports2.CreateCoipPoolCommand = CreateCoipPoolCommand;
    exports2.CreateCustomerGatewayCommand = CreateCustomerGatewayCommand;
    exports2.CreateDefaultSubnetCommand = CreateDefaultSubnetCommand;
    exports2.CreateDefaultVpcCommand = CreateDefaultVpcCommand;
    exports2.CreateDelegateMacVolumeOwnershipTaskCommand = CreateDelegateMacVolumeOwnershipTaskCommand;
    exports2.CreateDhcpOptionsCommand = CreateDhcpOptionsCommand;
    exports2.CreateEgressOnlyInternetGatewayCommand = CreateEgressOnlyInternetGatewayCommand;
    exports2.CreateFleetCommand = CreateFleetCommand;
    exports2.CreateFlowLogsCommand = CreateFlowLogsCommand;
    exports2.CreateFpgaImageCommand = CreateFpgaImageCommand;
    exports2.CreateImageCommand = CreateImageCommand;
    exports2.CreateImageUsageReportCommand = CreateImageUsageReportCommand;
    exports2.CreateInstanceConnectEndpointCommand = CreateInstanceConnectEndpointCommand;
    exports2.CreateInstanceEventWindowCommand = CreateInstanceEventWindowCommand;
    exports2.CreateInstanceExportTaskCommand = CreateInstanceExportTaskCommand;
    exports2.CreateInternetGatewayCommand = CreateInternetGatewayCommand;
    exports2.CreateInterruptibleCapacityReservationAllocationCommand = CreateInterruptibleCapacityReservationAllocationCommand;
    exports2.CreateIpamCommand = CreateIpamCommand;
    exports2.CreateIpamExternalResourceVerificationTokenCommand = CreateIpamExternalResourceVerificationTokenCommand;
    exports2.CreateIpamPolicyCommand = CreateIpamPolicyCommand;
    exports2.CreateIpamPoolCommand = CreateIpamPoolCommand;
    exports2.CreateIpamPrefixListResolverCommand = CreateIpamPrefixListResolverCommand;
    exports2.CreateIpamPrefixListResolverTargetCommand = CreateIpamPrefixListResolverTargetCommand;
    exports2.CreateIpamResourceDiscoveryCommand = CreateIpamResourceDiscoveryCommand;
    exports2.CreateIpamScopeCommand = CreateIpamScopeCommand;
    exports2.CreateKeyPairCommand = CreateKeyPairCommand;
    exports2.CreateLaunchTemplateCommand = CreateLaunchTemplateCommand;
    exports2.CreateLaunchTemplateVersionCommand = CreateLaunchTemplateVersionCommand;
    exports2.CreateLocalGatewayRouteCommand = CreateLocalGatewayRouteCommand;
    exports2.CreateLocalGatewayRouteTableCommand = CreateLocalGatewayRouteTableCommand;
    exports2.CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationCommand = CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationCommand;
    exports2.CreateLocalGatewayRouteTableVpcAssociationCommand = CreateLocalGatewayRouteTableVpcAssociationCommand;
    exports2.CreateLocalGatewayVirtualInterfaceCommand = CreateLocalGatewayVirtualInterfaceCommand;
    exports2.CreateLocalGatewayVirtualInterfaceGroupCommand = CreateLocalGatewayVirtualInterfaceGroupCommand;
    exports2.CreateMacSystemIntegrityProtectionModificationTaskCommand = CreateMacSystemIntegrityProtectionModificationTaskCommand;
    exports2.CreateManagedPrefixListCommand = CreateManagedPrefixListCommand;
    exports2.CreateNatGatewayCommand = CreateNatGatewayCommand;
    exports2.CreateNetworkAclCommand = CreateNetworkAclCommand;
    exports2.CreateNetworkAclEntryCommand = CreateNetworkAclEntryCommand;
    exports2.CreateNetworkInsightsAccessScopeCommand = CreateNetworkInsightsAccessScopeCommand;
    exports2.CreateNetworkInsightsPathCommand = CreateNetworkInsightsPathCommand;
    exports2.CreateNetworkInterfaceCommand = CreateNetworkInterfaceCommand;
    exports2.CreateNetworkInterfacePermissionCommand = CreateNetworkInterfacePermissionCommand;
    exports2.CreatePlacementGroupCommand = CreatePlacementGroupCommand;
    exports2.CreatePublicIpv4PoolCommand = CreatePublicIpv4PoolCommand;
    exports2.CreateReplaceRootVolumeTaskCommand = CreateReplaceRootVolumeTaskCommand;
    exports2.CreateReservedInstancesListingCommand = CreateReservedInstancesListingCommand;
    exports2.CreateRestoreImageTaskCommand = CreateRestoreImageTaskCommand;
    exports2.CreateRouteCommand = CreateRouteCommand;
    exports2.CreateRouteServerCommand = CreateRouteServerCommand;
    exports2.CreateRouteServerEndpointCommand = CreateRouteServerEndpointCommand;
    exports2.CreateRouteServerPeerCommand = CreateRouteServerPeerCommand;
    exports2.CreateRouteTableCommand = CreateRouteTableCommand;
    exports2.CreateSecondaryNetworkCommand = CreateSecondaryNetworkCommand;
    exports2.CreateSecondarySubnetCommand = CreateSecondarySubnetCommand;
    exports2.CreateSecurityGroupCommand = CreateSecurityGroupCommand;
    exports2.CreateSnapshotCommand = CreateSnapshotCommand;
    exports2.CreateSnapshotsCommand = CreateSnapshotsCommand;
    exports2.CreateSpotDatafeedSubscriptionCommand = CreateSpotDatafeedSubscriptionCommand;
    exports2.CreateStoreImageTaskCommand = CreateStoreImageTaskCommand;
    exports2.CreateSubnetCidrReservationCommand = CreateSubnetCidrReservationCommand;
    exports2.CreateSubnetCommand = CreateSubnetCommand;
    exports2.CreateTagsCommand = CreateTagsCommand;
    exports2.CreateTrafficMirrorFilterCommand = CreateTrafficMirrorFilterCommand;
    exports2.CreateTrafficMirrorFilterRuleCommand = CreateTrafficMirrorFilterRuleCommand;
    exports2.CreateTrafficMirrorSessionCommand = CreateTrafficMirrorSessionCommand;
    exports2.CreateTrafficMirrorTargetCommand = CreateTrafficMirrorTargetCommand;
    exports2.CreateTransitGatewayCommand = CreateTransitGatewayCommand;
    exports2.CreateTransitGatewayConnectCommand = CreateTransitGatewayConnectCommand;
    exports2.CreateTransitGatewayConnectPeerCommand = CreateTransitGatewayConnectPeerCommand;
    exports2.CreateTransitGatewayMeteringPolicyCommand = CreateTransitGatewayMeteringPolicyCommand;
    exports2.CreateTransitGatewayMeteringPolicyEntryCommand = CreateTransitGatewayMeteringPolicyEntryCommand;
    exports2.CreateTransitGatewayMulticastDomainCommand = CreateTransitGatewayMulticastDomainCommand;
    exports2.CreateTransitGatewayPeeringAttachmentCommand = CreateTransitGatewayPeeringAttachmentCommand;
    exports2.CreateTransitGatewayPolicyTableCommand = CreateTransitGatewayPolicyTableCommand;
    exports2.CreateTransitGatewayPrefixListReferenceCommand = CreateTransitGatewayPrefixListReferenceCommand;
    exports2.CreateTransitGatewayRouteCommand = CreateTransitGatewayRouteCommand;
    exports2.CreateTransitGatewayRouteTableAnnouncementCommand = CreateTransitGatewayRouteTableAnnouncementCommand;
    exports2.CreateTransitGatewayRouteTableCommand = CreateTransitGatewayRouteTableCommand;
    exports2.CreateTransitGatewayVpcAttachmentCommand = CreateTransitGatewayVpcAttachmentCommand;
    exports2.CreateVerifiedAccessEndpointCommand = CreateVerifiedAccessEndpointCommand;
    exports2.CreateVerifiedAccessGroupCommand = CreateVerifiedAccessGroupCommand;
    exports2.CreateVerifiedAccessInstanceCommand = CreateVerifiedAccessInstanceCommand;
    exports2.CreateVerifiedAccessTrustProviderCommand = CreateVerifiedAccessTrustProviderCommand;
    exports2.CreateVolumeCommand = CreateVolumeCommand;
    exports2.CreateVpcBlockPublicAccessExclusionCommand = CreateVpcBlockPublicAccessExclusionCommand;
    exports2.CreateVpcCommand = CreateVpcCommand;
    exports2.CreateVpcEncryptionControlCommand = CreateVpcEncryptionControlCommand;
    exports2.CreateVpcEndpointCommand = CreateVpcEndpointCommand;
    exports2.CreateVpcEndpointConnectionNotificationCommand = CreateVpcEndpointConnectionNotificationCommand;
    exports2.CreateVpcEndpointServiceConfigurationCommand = CreateVpcEndpointServiceConfigurationCommand;
    exports2.CreateVpcPeeringConnectionCommand = CreateVpcPeeringConnectionCommand;
    exports2.CreateVpnConcentratorCommand = CreateVpnConcentratorCommand;
    exports2.CreateVpnConnectionCommand = CreateVpnConnectionCommand;
    exports2.CreateVpnConnectionRouteCommand = CreateVpnConnectionRouteCommand;
    exports2.CreateVpnGatewayCommand = CreateVpnGatewayCommand;
    exports2.CurrencyCodeValues = CurrencyCodeValues;
    exports2.DatafeedSubscriptionState = DatafeedSubscriptionState;
    exports2.DefaultHttpTokensEnforcedState = DefaultHttpTokensEnforcedState;
    exports2.DefaultInstanceMetadataEndpointState = DefaultInstanceMetadataEndpointState;
    exports2.DefaultInstanceMetadataTagsState = DefaultInstanceMetadataTagsState;
    exports2.DefaultRouteTableAssociationValue = DefaultRouteTableAssociationValue;
    exports2.DefaultRouteTablePropagationValue = DefaultRouteTablePropagationValue;
    exports2.DefaultTargetCapacityType = DefaultTargetCapacityType;
    exports2.DeleteCapacityManagerDataExportCommand = DeleteCapacityManagerDataExportCommand;
    exports2.DeleteCarrierGatewayCommand = DeleteCarrierGatewayCommand;
    exports2.DeleteClientVpnEndpointCommand = DeleteClientVpnEndpointCommand;
    exports2.DeleteClientVpnRouteCommand = DeleteClientVpnRouteCommand;
    exports2.DeleteCoipCidrCommand = DeleteCoipCidrCommand;
    exports2.DeleteCoipPoolCommand = DeleteCoipPoolCommand;
    exports2.DeleteCustomerGatewayCommand = DeleteCustomerGatewayCommand;
    exports2.DeleteDhcpOptionsCommand = DeleteDhcpOptionsCommand;
    exports2.DeleteEgressOnlyInternetGatewayCommand = DeleteEgressOnlyInternetGatewayCommand;
    exports2.DeleteFleetErrorCode = DeleteFleetErrorCode;
    exports2.DeleteFleetsCommand = DeleteFleetsCommand;
    exports2.DeleteFlowLogsCommand = DeleteFlowLogsCommand;
    exports2.DeleteFpgaImageCommand = DeleteFpgaImageCommand;
    exports2.DeleteImageUsageReportCommand = DeleteImageUsageReportCommand;
    exports2.DeleteInstanceConnectEndpointCommand = DeleteInstanceConnectEndpointCommand;
    exports2.DeleteInstanceEventWindowCommand = DeleteInstanceEventWindowCommand;
    exports2.DeleteInternetGatewayCommand = DeleteInternetGatewayCommand;
    exports2.DeleteIpamCommand = DeleteIpamCommand;
    exports2.DeleteIpamExternalResourceVerificationTokenCommand = DeleteIpamExternalResourceVerificationTokenCommand;
    exports2.DeleteIpamPolicyCommand = DeleteIpamPolicyCommand;
    exports2.DeleteIpamPoolCommand = DeleteIpamPoolCommand;
    exports2.DeleteIpamPrefixListResolverCommand = DeleteIpamPrefixListResolverCommand;
    exports2.DeleteIpamPrefixListResolverTargetCommand = DeleteIpamPrefixListResolverTargetCommand;
    exports2.DeleteIpamResourceDiscoveryCommand = DeleteIpamResourceDiscoveryCommand;
    exports2.DeleteIpamScopeCommand = DeleteIpamScopeCommand;
    exports2.DeleteKeyPairCommand = DeleteKeyPairCommand;
    exports2.DeleteLaunchTemplateCommand = DeleteLaunchTemplateCommand;
    exports2.DeleteLaunchTemplateVersionsCommand = DeleteLaunchTemplateVersionsCommand;
    exports2.DeleteLocalGatewayRouteCommand = DeleteLocalGatewayRouteCommand;
    exports2.DeleteLocalGatewayRouteTableCommand = DeleteLocalGatewayRouteTableCommand;
    exports2.DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociationCommand = DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociationCommand;
    exports2.DeleteLocalGatewayRouteTableVpcAssociationCommand = DeleteLocalGatewayRouteTableVpcAssociationCommand;
    exports2.DeleteLocalGatewayVirtualInterfaceCommand = DeleteLocalGatewayVirtualInterfaceCommand;
    exports2.DeleteLocalGatewayVirtualInterfaceGroupCommand = DeleteLocalGatewayVirtualInterfaceGroupCommand;
    exports2.DeleteManagedPrefixListCommand = DeleteManagedPrefixListCommand;
    exports2.DeleteNatGatewayCommand = DeleteNatGatewayCommand;
    exports2.DeleteNetworkAclCommand = DeleteNetworkAclCommand;
    exports2.DeleteNetworkAclEntryCommand = DeleteNetworkAclEntryCommand;
    exports2.DeleteNetworkInsightsAccessScopeAnalysisCommand = DeleteNetworkInsightsAccessScopeAnalysisCommand;
    exports2.DeleteNetworkInsightsAccessScopeCommand = DeleteNetworkInsightsAccessScopeCommand;
    exports2.DeleteNetworkInsightsAnalysisCommand = DeleteNetworkInsightsAnalysisCommand;
    exports2.DeleteNetworkInsightsPathCommand = DeleteNetworkInsightsPathCommand;
    exports2.DeleteNetworkInterfaceCommand = DeleteNetworkInterfaceCommand;
    exports2.DeleteNetworkInterfacePermissionCommand = DeleteNetworkInterfacePermissionCommand;
    exports2.DeletePlacementGroupCommand = DeletePlacementGroupCommand;
    exports2.DeletePublicIpv4PoolCommand = DeletePublicIpv4PoolCommand;
    exports2.DeleteQueuedReservedInstancesCommand = DeleteQueuedReservedInstancesCommand;
    exports2.DeleteQueuedReservedInstancesErrorCode = DeleteQueuedReservedInstancesErrorCode;
    exports2.DeleteRouteCommand = DeleteRouteCommand;
    exports2.DeleteRouteServerCommand = DeleteRouteServerCommand;
    exports2.DeleteRouteServerEndpointCommand = DeleteRouteServerEndpointCommand;
    exports2.DeleteRouteServerPeerCommand = DeleteRouteServerPeerCommand;
    exports2.DeleteRouteTableCommand = DeleteRouteTableCommand;
    exports2.DeleteSecondaryNetworkCommand = DeleteSecondaryNetworkCommand;
    exports2.DeleteSecondarySubnetCommand = DeleteSecondarySubnetCommand;
    exports2.DeleteSecurityGroupCommand = DeleteSecurityGroupCommand;
    exports2.DeleteSnapshotCommand = DeleteSnapshotCommand;
    exports2.DeleteSpotDatafeedSubscriptionCommand = DeleteSpotDatafeedSubscriptionCommand;
    exports2.DeleteSubnetCidrReservationCommand = DeleteSubnetCidrReservationCommand;
    exports2.DeleteSubnetCommand = DeleteSubnetCommand;
    exports2.DeleteTagsCommand = DeleteTagsCommand;
    exports2.DeleteTrafficMirrorFilterCommand = DeleteTrafficMirrorFilterCommand;
    exports2.DeleteTrafficMirrorFilterRuleCommand = DeleteTrafficMirrorFilterRuleCommand;
    exports2.DeleteTrafficMirrorSessionCommand = DeleteTrafficMirrorSessionCommand;
    exports2.DeleteTrafficMirrorTargetCommand = DeleteTrafficMirrorTargetCommand;
    exports2.DeleteTransitGatewayClientVpnAttachmentCommand = DeleteTransitGatewayClientVpnAttachmentCommand;
    exports2.DeleteTransitGatewayCommand = DeleteTransitGatewayCommand;
    exports2.DeleteTransitGatewayConnectCommand = DeleteTransitGatewayConnectCommand;
    exports2.DeleteTransitGatewayConnectPeerCommand = DeleteTransitGatewayConnectPeerCommand;
    exports2.DeleteTransitGatewayMeteringPolicyCommand = DeleteTransitGatewayMeteringPolicyCommand;
    exports2.DeleteTransitGatewayMeteringPolicyEntryCommand = DeleteTransitGatewayMeteringPolicyEntryCommand;
    exports2.DeleteTransitGatewayMulticastDomainCommand = DeleteTransitGatewayMulticastDomainCommand;
    exports2.DeleteTransitGatewayPeeringAttachmentCommand = DeleteTransitGatewayPeeringAttachmentCommand;
    exports2.DeleteTransitGatewayPolicyTableCommand = DeleteTransitGatewayPolicyTableCommand;
    exports2.DeleteTransitGatewayPrefixListReferenceCommand = DeleteTransitGatewayPrefixListReferenceCommand;
    exports2.DeleteTransitGatewayRouteCommand = DeleteTransitGatewayRouteCommand;
    exports2.DeleteTransitGatewayRouteTableAnnouncementCommand = DeleteTransitGatewayRouteTableAnnouncementCommand;
    exports2.DeleteTransitGatewayRouteTableCommand = DeleteTransitGatewayRouteTableCommand;
    exports2.DeleteTransitGatewayVpcAttachmentCommand = DeleteTransitGatewayVpcAttachmentCommand;
    exports2.DeleteVerifiedAccessEndpointCommand = DeleteVerifiedAccessEndpointCommand;
    exports2.DeleteVerifiedAccessGroupCommand = DeleteVerifiedAccessGroupCommand;
    exports2.DeleteVerifiedAccessInstanceCommand = DeleteVerifiedAccessInstanceCommand;
    exports2.DeleteVerifiedAccessTrustProviderCommand = DeleteVerifiedAccessTrustProviderCommand;
    exports2.DeleteVolumeCommand = DeleteVolumeCommand;
    exports2.DeleteVpcBlockPublicAccessExclusionCommand = DeleteVpcBlockPublicAccessExclusionCommand;
    exports2.DeleteVpcCommand = DeleteVpcCommand;
    exports2.DeleteVpcEncryptionControlCommand = DeleteVpcEncryptionControlCommand;
    exports2.DeleteVpcEndpointConnectionNotificationsCommand = DeleteVpcEndpointConnectionNotificationsCommand;
    exports2.DeleteVpcEndpointServiceConfigurationsCommand = DeleteVpcEndpointServiceConfigurationsCommand;
    exports2.DeleteVpcEndpointsCommand = DeleteVpcEndpointsCommand;
    exports2.DeleteVpcPeeringConnectionCommand = DeleteVpcPeeringConnectionCommand;
    exports2.DeleteVpnConcentratorCommand = DeleteVpnConcentratorCommand;
    exports2.DeleteVpnConnectionCommand = DeleteVpnConnectionCommand;
    exports2.DeleteVpnConnectionRouteCommand = DeleteVpnConnectionRouteCommand;
    exports2.DeleteVpnGatewayCommand = DeleteVpnGatewayCommand;
    exports2.DeprovisionByoipCidrCommand = DeprovisionByoipCidrCommand;
    exports2.DeprovisionIpamByoasnCommand = DeprovisionIpamByoasnCommand;
    exports2.DeprovisionIpamPoolCidrCommand = DeprovisionIpamPoolCidrCommand;
    exports2.DeprovisionPublicIpv4PoolCidrCommand = DeprovisionPublicIpv4PoolCidrCommand;
    exports2.DeregisterImageCommand = DeregisterImageCommand;
    exports2.DeregisterInstanceEventNotificationAttributesCommand = DeregisterInstanceEventNotificationAttributesCommand;
    exports2.DeregisterTransitGatewayMulticastGroupMembersCommand = DeregisterTransitGatewayMulticastGroupMembersCommand;
    exports2.DeregisterTransitGatewayMulticastGroupSourcesCommand = DeregisterTransitGatewayMulticastGroupSourcesCommand;
    exports2.DescribeAccountAttributesCommand = DescribeAccountAttributesCommand;
    exports2.DescribeAddressTransfersCommand = DescribeAddressTransfersCommand;
    exports2.DescribeAddressesAttributeCommand = DescribeAddressesAttributeCommand;
    exports2.DescribeAddressesCommand = DescribeAddressesCommand;
    exports2.DescribeAggregateIdFormatCommand = DescribeAggregateIdFormatCommand;
    exports2.DescribeAvailabilityZonesCommand = DescribeAvailabilityZonesCommand2;
    exports2.DescribeAwsNetworkPerformanceMetricSubscriptionsCommand = DescribeAwsNetworkPerformanceMetricSubscriptionsCommand;
    exports2.DescribeBundleTasksCommand = DescribeBundleTasksCommand;
    exports2.DescribeByoipCidrsCommand = DescribeByoipCidrsCommand;
    exports2.DescribeCapacityBlockExtensionHistoryCommand = DescribeCapacityBlockExtensionHistoryCommand;
    exports2.DescribeCapacityBlockExtensionOfferingsCommand = DescribeCapacityBlockExtensionOfferingsCommand;
    exports2.DescribeCapacityBlockOfferingsCommand = DescribeCapacityBlockOfferingsCommand;
    exports2.DescribeCapacityBlockStatusCommand = DescribeCapacityBlockStatusCommand;
    exports2.DescribeCapacityBlocksCommand = DescribeCapacityBlocksCommand;
    exports2.DescribeCapacityManagerDataExportsCommand = DescribeCapacityManagerDataExportsCommand;
    exports2.DescribeCapacityReservationBillingRequestsCommand = DescribeCapacityReservationBillingRequestsCommand;
    exports2.DescribeCapacityReservationFleetsCommand = DescribeCapacityReservationFleetsCommand;
    exports2.DescribeCapacityReservationTopologyCommand = DescribeCapacityReservationTopologyCommand;
    exports2.DescribeCapacityReservationsCommand = DescribeCapacityReservationsCommand;
    exports2.DescribeCarrierGatewaysCommand = DescribeCarrierGatewaysCommand;
    exports2.DescribeClassicLinkInstancesCommand = DescribeClassicLinkInstancesCommand;
    exports2.DescribeClientVpnAuthorizationRulesCommand = DescribeClientVpnAuthorizationRulesCommand;
    exports2.DescribeClientVpnConnectionsCommand = DescribeClientVpnConnectionsCommand;
    exports2.DescribeClientVpnEndpointsCommand = DescribeClientVpnEndpointsCommand;
    exports2.DescribeClientVpnRoutesCommand = DescribeClientVpnRoutesCommand;
    exports2.DescribeClientVpnTargetNetworksCommand = DescribeClientVpnTargetNetworksCommand;
    exports2.DescribeCoipPoolsCommand = DescribeCoipPoolsCommand;
    exports2.DescribeConversionTasksCommand = DescribeConversionTasksCommand;
    exports2.DescribeCustomerGatewaysCommand = DescribeCustomerGatewaysCommand;
    exports2.DescribeDeclarativePoliciesReportsCommand = DescribeDeclarativePoliciesReportsCommand;
    exports2.DescribeDhcpOptionsCommand = DescribeDhcpOptionsCommand;
    exports2.DescribeEgressOnlyInternetGatewaysCommand = DescribeEgressOnlyInternetGatewaysCommand;
    exports2.DescribeElasticGpusCommand = DescribeElasticGpusCommand;
    exports2.DescribeExportImageTasksCommand = DescribeExportImageTasksCommand;
    exports2.DescribeExportTasksCommand = DescribeExportTasksCommand;
    exports2.DescribeFastLaunchImagesCommand = DescribeFastLaunchImagesCommand;
    exports2.DescribeFastSnapshotRestoresCommand = DescribeFastSnapshotRestoresCommand;
    exports2.DescribeFleetHistoryCommand = DescribeFleetHistoryCommand;
    exports2.DescribeFleetInstancesCommand = DescribeFleetInstancesCommand;
    exports2.DescribeFleetsCommand = DescribeFleetsCommand;
    exports2.DescribeFlowLogsCommand = DescribeFlowLogsCommand;
    exports2.DescribeFpgaImageAttributeCommand = DescribeFpgaImageAttributeCommand;
    exports2.DescribeFpgaImagesCommand = DescribeFpgaImagesCommand;
    exports2.DescribeHostReservationOfferingsCommand = DescribeHostReservationOfferingsCommand;
    exports2.DescribeHostReservationsCommand = DescribeHostReservationsCommand;
    exports2.DescribeHostsCommand = DescribeHostsCommand;
    exports2.DescribeIamInstanceProfileAssociationsCommand = DescribeIamInstanceProfileAssociationsCommand;
    exports2.DescribeIdFormatCommand = DescribeIdFormatCommand;
    exports2.DescribeIdentityIdFormatCommand = DescribeIdentityIdFormatCommand;
    exports2.DescribeImageAttributeCommand = DescribeImageAttributeCommand;
    exports2.DescribeImageReferencesCommand = DescribeImageReferencesCommand;
    exports2.DescribeImageUsageReportEntriesCommand = DescribeImageUsageReportEntriesCommand;
    exports2.DescribeImageUsageReportsCommand = DescribeImageUsageReportsCommand;
    exports2.DescribeImagesCommand = DescribeImagesCommand3;
    exports2.DescribeImportImageTasksCommand = DescribeImportImageTasksCommand;
    exports2.DescribeImportSnapshotTasksCommand = DescribeImportSnapshotTasksCommand;
    exports2.DescribeInstanceAttributeCommand = DescribeInstanceAttributeCommand;
    exports2.DescribeInstanceConnectEndpointsCommand = DescribeInstanceConnectEndpointsCommand;
    exports2.DescribeInstanceCreditSpecificationsCommand = DescribeInstanceCreditSpecificationsCommand;
    exports2.DescribeInstanceEventNotificationAttributesCommand = DescribeInstanceEventNotificationAttributesCommand;
    exports2.DescribeInstanceEventWindowsCommand = DescribeInstanceEventWindowsCommand;
    exports2.DescribeInstanceImageMetadataCommand = DescribeInstanceImageMetadataCommand;
    exports2.DescribeInstanceSqlHaHistoryStatesCommand = DescribeInstanceSqlHaHistoryStatesCommand;
    exports2.DescribeInstanceSqlHaStatesCommand = DescribeInstanceSqlHaStatesCommand;
    exports2.DescribeInstanceStatusCommand = DescribeInstanceStatusCommand;
    exports2.DescribeInstanceTopologyCommand = DescribeInstanceTopologyCommand;
    exports2.DescribeInstanceTypeOfferingsCommand = DescribeInstanceTypeOfferingsCommand;
    exports2.DescribeInstanceTypesCommand = DescribeInstanceTypesCommand;
    exports2.DescribeInstancesCommand = DescribeInstancesCommand2;
    exports2.DescribeInternetGatewaysCommand = DescribeInternetGatewaysCommand;
    exports2.DescribeIpamByoasnCommand = DescribeIpamByoasnCommand;
    exports2.DescribeIpamExternalResourceVerificationTokensCommand = DescribeIpamExternalResourceVerificationTokensCommand;
    exports2.DescribeIpamPoliciesCommand = DescribeIpamPoliciesCommand;
    exports2.DescribeIpamPoolsCommand = DescribeIpamPoolsCommand;
    exports2.DescribeIpamPrefixListResolverTargetsCommand = DescribeIpamPrefixListResolverTargetsCommand;
    exports2.DescribeIpamPrefixListResolversCommand = DescribeIpamPrefixListResolversCommand;
    exports2.DescribeIpamResourceDiscoveriesCommand = DescribeIpamResourceDiscoveriesCommand;
    exports2.DescribeIpamResourceDiscoveryAssociationsCommand = DescribeIpamResourceDiscoveryAssociationsCommand;
    exports2.DescribeIpamScopesCommand = DescribeIpamScopesCommand;
    exports2.DescribeIpamsCommand = DescribeIpamsCommand;
    exports2.DescribeIpv6PoolsCommand = DescribeIpv6PoolsCommand;
    exports2.DescribeKeyPairsCommand = DescribeKeyPairsCommand;
    exports2.DescribeLaunchTemplateVersionsCommand = DescribeLaunchTemplateVersionsCommand;
    exports2.DescribeLaunchTemplatesCommand = DescribeLaunchTemplatesCommand;
    exports2.DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociationsCommand = DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociationsCommand;
    exports2.DescribeLocalGatewayRouteTableVpcAssociationsCommand = DescribeLocalGatewayRouteTableVpcAssociationsCommand;
    exports2.DescribeLocalGatewayRouteTablesCommand = DescribeLocalGatewayRouteTablesCommand;
    exports2.DescribeLocalGatewayVirtualInterfaceGroupsCommand = DescribeLocalGatewayVirtualInterfaceGroupsCommand;
    exports2.DescribeLocalGatewayVirtualInterfacesCommand = DescribeLocalGatewayVirtualInterfacesCommand;
    exports2.DescribeLocalGatewaysCommand = DescribeLocalGatewaysCommand;
    exports2.DescribeLockedSnapshotsCommand = DescribeLockedSnapshotsCommand;
    exports2.DescribeMacHostsCommand = DescribeMacHostsCommand;
    exports2.DescribeMacModificationTasksCommand = DescribeMacModificationTasksCommand;
    exports2.DescribeManagedPrefixListsCommand = DescribeManagedPrefixListsCommand;
    exports2.DescribeMovingAddressesCommand = DescribeMovingAddressesCommand;
    exports2.DescribeNatGatewaysCommand = DescribeNatGatewaysCommand;
    exports2.DescribeNetworkAclsCommand = DescribeNetworkAclsCommand;
    exports2.DescribeNetworkInsightsAccessScopeAnalysesCommand = DescribeNetworkInsightsAccessScopeAnalysesCommand;
    exports2.DescribeNetworkInsightsAccessScopesCommand = DescribeNetworkInsightsAccessScopesCommand;
    exports2.DescribeNetworkInsightsAnalysesCommand = DescribeNetworkInsightsAnalysesCommand;
    exports2.DescribeNetworkInsightsPathsCommand = DescribeNetworkInsightsPathsCommand;
    exports2.DescribeNetworkInterfaceAttributeCommand = DescribeNetworkInterfaceAttributeCommand;
    exports2.DescribeNetworkInterfacePermissionsCommand = DescribeNetworkInterfacePermissionsCommand;
    exports2.DescribeNetworkInterfacesCommand = DescribeNetworkInterfacesCommand;
    exports2.DescribeOutpostLagsCommand = DescribeOutpostLagsCommand;
    exports2.DescribePlacementGroupsCommand = DescribePlacementGroupsCommand;
    exports2.DescribePrefixListsCommand = DescribePrefixListsCommand;
    exports2.DescribePrincipalIdFormatCommand = DescribePrincipalIdFormatCommand;
    exports2.DescribePublicIpv4PoolsCommand = DescribePublicIpv4PoolsCommand;
    exports2.DescribeRegionsCommand = DescribeRegionsCommand;
    exports2.DescribeReplaceRootVolumeTasksCommand = DescribeReplaceRootVolumeTasksCommand;
    exports2.DescribeReservedInstancesCommand = DescribeReservedInstancesCommand;
    exports2.DescribeReservedInstancesListingsCommand = DescribeReservedInstancesListingsCommand;
    exports2.DescribeReservedInstancesModificationsCommand = DescribeReservedInstancesModificationsCommand;
    exports2.DescribeReservedInstancesOfferingsCommand = DescribeReservedInstancesOfferingsCommand;
    exports2.DescribeRouteServerEndpointsCommand = DescribeRouteServerEndpointsCommand;
    exports2.DescribeRouteServerPeersCommand = DescribeRouteServerPeersCommand;
    exports2.DescribeRouteServersCommand = DescribeRouteServersCommand;
    exports2.DescribeRouteTablesCommand = DescribeRouteTablesCommand2;
    exports2.DescribeScheduledInstanceAvailabilityCommand = DescribeScheduledInstanceAvailabilityCommand;
    exports2.DescribeScheduledInstancesCommand = DescribeScheduledInstancesCommand;
    exports2.DescribeSecondaryInterfacesCommand = DescribeSecondaryInterfacesCommand;
    exports2.DescribeSecondaryNetworksCommand = DescribeSecondaryNetworksCommand;
    exports2.DescribeSecondarySubnetsCommand = DescribeSecondarySubnetsCommand;
    exports2.DescribeSecurityGroupReferencesCommand = DescribeSecurityGroupReferencesCommand;
    exports2.DescribeSecurityGroupRulesCommand = DescribeSecurityGroupRulesCommand;
    exports2.DescribeSecurityGroupVpcAssociationsCommand = DescribeSecurityGroupVpcAssociationsCommand;
    exports2.DescribeSecurityGroupsCommand = DescribeSecurityGroupsCommand2;
    exports2.DescribeServiceLinkVirtualInterfacesCommand = DescribeServiceLinkVirtualInterfacesCommand;
    exports2.DescribeSnapshotAttributeCommand = DescribeSnapshotAttributeCommand;
    exports2.DescribeSnapshotTierStatusCommand = DescribeSnapshotTierStatusCommand;
    exports2.DescribeSnapshotsCommand = DescribeSnapshotsCommand;
    exports2.DescribeSpotDatafeedSubscriptionCommand = DescribeSpotDatafeedSubscriptionCommand;
    exports2.DescribeSpotFleetInstancesCommand = DescribeSpotFleetInstancesCommand;
    exports2.DescribeSpotFleetRequestHistoryCommand = DescribeSpotFleetRequestHistoryCommand;
    exports2.DescribeSpotFleetRequestsCommand = DescribeSpotFleetRequestsCommand;
    exports2.DescribeSpotInstanceRequestsCommand = DescribeSpotInstanceRequestsCommand;
    exports2.DescribeSpotPriceHistoryCommand = DescribeSpotPriceHistoryCommand;
    exports2.DescribeStaleSecurityGroupsCommand = DescribeStaleSecurityGroupsCommand;
    exports2.DescribeStoreImageTasksCommand = DescribeStoreImageTasksCommand;
    exports2.DescribeSubnetsCommand = DescribeSubnetsCommand2;
    exports2.DescribeTagsCommand = DescribeTagsCommand2;
    exports2.DescribeTrafficMirrorFilterRulesCommand = DescribeTrafficMirrorFilterRulesCommand;
    exports2.DescribeTrafficMirrorFiltersCommand = DescribeTrafficMirrorFiltersCommand;
    exports2.DescribeTrafficMirrorSessionsCommand = DescribeTrafficMirrorSessionsCommand;
    exports2.DescribeTrafficMirrorTargetsCommand = DescribeTrafficMirrorTargetsCommand;
    exports2.DescribeTransitGatewayAttachmentsCommand = DescribeTransitGatewayAttachmentsCommand;
    exports2.DescribeTransitGatewayConnectPeersCommand = DescribeTransitGatewayConnectPeersCommand;
    exports2.DescribeTransitGatewayConnectsCommand = DescribeTransitGatewayConnectsCommand;
    exports2.DescribeTransitGatewayMeteringPoliciesCommand = DescribeTransitGatewayMeteringPoliciesCommand;
    exports2.DescribeTransitGatewayMulticastDomainsCommand = DescribeTransitGatewayMulticastDomainsCommand;
    exports2.DescribeTransitGatewayPeeringAttachmentsCommand = DescribeTransitGatewayPeeringAttachmentsCommand;
    exports2.DescribeTransitGatewayPolicyTablesCommand = DescribeTransitGatewayPolicyTablesCommand;
    exports2.DescribeTransitGatewayRouteTableAnnouncementsCommand = DescribeTransitGatewayRouteTableAnnouncementsCommand;
    exports2.DescribeTransitGatewayRouteTablesCommand = DescribeTransitGatewayRouteTablesCommand;
    exports2.DescribeTransitGatewayVpcAttachmentsCommand = DescribeTransitGatewayVpcAttachmentsCommand;
    exports2.DescribeTransitGatewaysCommand = DescribeTransitGatewaysCommand;
    exports2.DescribeTrunkInterfaceAssociationsCommand = DescribeTrunkInterfaceAssociationsCommand;
    exports2.DescribeVerifiedAccessEndpointsCommand = DescribeVerifiedAccessEndpointsCommand;
    exports2.DescribeVerifiedAccessGroupsCommand = DescribeVerifiedAccessGroupsCommand;
    exports2.DescribeVerifiedAccessInstanceLoggingConfigurationsCommand = DescribeVerifiedAccessInstanceLoggingConfigurationsCommand;
    exports2.DescribeVerifiedAccessInstancesCommand = DescribeVerifiedAccessInstancesCommand;
    exports2.DescribeVerifiedAccessTrustProvidersCommand = DescribeVerifiedAccessTrustProvidersCommand;
    exports2.DescribeVolumeAttributeCommand = DescribeVolumeAttributeCommand;
    exports2.DescribeVolumeStatusCommand = DescribeVolumeStatusCommand;
    exports2.DescribeVolumesCommand = DescribeVolumesCommand;
    exports2.DescribeVolumesModificationsCommand = DescribeVolumesModificationsCommand;
    exports2.DescribeVpcAttributeCommand = DescribeVpcAttributeCommand;
    exports2.DescribeVpcBlockPublicAccessExclusionsCommand = DescribeVpcBlockPublicAccessExclusionsCommand;
    exports2.DescribeVpcBlockPublicAccessOptionsCommand = DescribeVpcBlockPublicAccessOptionsCommand;
    exports2.DescribeVpcClassicLinkCommand = DescribeVpcClassicLinkCommand;
    exports2.DescribeVpcClassicLinkDnsSupportCommand = DescribeVpcClassicLinkDnsSupportCommand;
    exports2.DescribeVpcEncryptionControlsCommand = DescribeVpcEncryptionControlsCommand;
    exports2.DescribeVpcEndpointAssociationsCommand = DescribeVpcEndpointAssociationsCommand;
    exports2.DescribeVpcEndpointConnectionNotificationsCommand = DescribeVpcEndpointConnectionNotificationsCommand;
    exports2.DescribeVpcEndpointConnectionsCommand = DescribeVpcEndpointConnectionsCommand;
    exports2.DescribeVpcEndpointServiceConfigurationsCommand = DescribeVpcEndpointServiceConfigurationsCommand;
    exports2.DescribeVpcEndpointServicePermissionsCommand = DescribeVpcEndpointServicePermissionsCommand;
    exports2.DescribeVpcEndpointServicesCommand = DescribeVpcEndpointServicesCommand2;
    exports2.DescribeVpcEndpointsCommand = DescribeVpcEndpointsCommand;
    exports2.DescribeVpcPeeringConnectionsCommand = DescribeVpcPeeringConnectionsCommand;
    exports2.DescribeVpcsCommand = DescribeVpcsCommand2;
    exports2.DescribeVpnConcentratorsCommand = DescribeVpnConcentratorsCommand;
    exports2.DescribeVpnConnectionsCommand = DescribeVpnConnectionsCommand;
    exports2.DescribeVpnGatewaysCommand = DescribeVpnGatewaysCommand2;
    exports2.DestinationFileFormat = DestinationFileFormat;
    exports2.DetachClassicLinkVpcCommand = DetachClassicLinkVpcCommand;
    exports2.DetachInternetGatewayCommand = DetachInternetGatewayCommand;
    exports2.DetachNetworkInterfaceCommand = DetachNetworkInterfaceCommand;
    exports2.DetachVerifiedAccessTrustProviderCommand = DetachVerifiedAccessTrustProviderCommand;
    exports2.DetachVolumeCommand = DetachVolumeCommand;
    exports2.DetachVpnGatewayCommand = DetachVpnGatewayCommand;
    exports2.DeviceTrustProviderType = DeviceTrustProviderType;
    exports2.DeviceType = DeviceType;
    exports2.DisableAddressTransferCommand = DisableAddressTransferCommand;
    exports2.DisableAllowedImagesSettingsCommand = DisableAllowedImagesSettingsCommand;
    exports2.DisableAwsNetworkPerformanceMetricSubscriptionCommand = DisableAwsNetworkPerformanceMetricSubscriptionCommand;
    exports2.DisableCapacityManagerCommand = DisableCapacityManagerCommand;
    exports2.DisableEbsEncryptionByDefaultCommand = DisableEbsEncryptionByDefaultCommand;
    exports2.DisableFastLaunchCommand = DisableFastLaunchCommand;
    exports2.DisableFastSnapshotRestoresCommand = DisableFastSnapshotRestoresCommand;
    exports2.DisableImageBlockPublicAccessCommand = DisableImageBlockPublicAccessCommand;
    exports2.DisableImageCommand = DisableImageCommand;
    exports2.DisableImageDeprecationCommand = DisableImageDeprecationCommand;
    exports2.DisableImageDeregistrationProtectionCommand = DisableImageDeregistrationProtectionCommand;
    exports2.DisableInstanceSqlHaStandbyDetectionsCommand = DisableInstanceSqlHaStandbyDetectionsCommand;
    exports2.DisableIpamOrganizationAdminAccountCommand = DisableIpamOrganizationAdminAccountCommand;
    exports2.DisableIpamPolicyCommand = DisableIpamPolicyCommand;
    exports2.DisableRouteServerPropagationCommand = DisableRouteServerPropagationCommand;
    exports2.DisableSerialConsoleAccessCommand = DisableSerialConsoleAccessCommand;
    exports2.DisableSnapshotBlockPublicAccessCommand = DisableSnapshotBlockPublicAccessCommand;
    exports2.DisableTransitGatewayRouteTablePropagationCommand = DisableTransitGatewayRouteTablePropagationCommand;
    exports2.DisableVgwRoutePropagationCommand = DisableVgwRoutePropagationCommand;
    exports2.DisableVpcClassicLinkCommand = DisableVpcClassicLinkCommand;
    exports2.DisableVpcClassicLinkDnsSupportCommand = DisableVpcClassicLinkDnsSupportCommand;
    exports2.DisassociateAddressCommand = DisassociateAddressCommand;
    exports2.DisassociateCapacityReservationBillingOwnerCommand = DisassociateCapacityReservationBillingOwnerCommand;
    exports2.DisassociateClientVpnTargetNetworkCommand = DisassociateClientVpnTargetNetworkCommand;
    exports2.DisassociateEnclaveCertificateIamRoleCommand = DisassociateEnclaveCertificateIamRoleCommand;
    exports2.DisassociateIamInstanceProfileCommand = DisassociateIamInstanceProfileCommand;
    exports2.DisassociateInstanceEventWindowCommand = DisassociateInstanceEventWindowCommand;
    exports2.DisassociateIpamByoasnCommand = DisassociateIpamByoasnCommand;
    exports2.DisassociateIpamResourceDiscoveryCommand = DisassociateIpamResourceDiscoveryCommand;
    exports2.DisassociateNatGatewayAddressCommand = DisassociateNatGatewayAddressCommand;
    exports2.DisassociateRouteServerCommand = DisassociateRouteServerCommand;
    exports2.DisassociateRouteTableCommand = DisassociateRouteTableCommand;
    exports2.DisassociateSecurityGroupVpcCommand = DisassociateSecurityGroupVpcCommand;
    exports2.DisassociateSubnetCidrBlockCommand = DisassociateSubnetCidrBlockCommand;
    exports2.DisassociateTransitGatewayMulticastDomainCommand = DisassociateTransitGatewayMulticastDomainCommand;
    exports2.DisassociateTransitGatewayPolicyTableCommand = DisassociateTransitGatewayPolicyTableCommand;
    exports2.DisassociateTransitGatewayRouteTableCommand = DisassociateTransitGatewayRouteTableCommand;
    exports2.DisassociateTrunkInterfaceCommand = DisassociateTrunkInterfaceCommand;
    exports2.DisassociateVpcCidrBlockCommand = DisassociateVpcCidrBlockCommand;
    exports2.DiskImageFormat = DiskImageFormat;
    exports2.DiskType = DiskType;
    exports2.DnsNameState = DnsNameState;
    exports2.DnsRecordIpType = DnsRecordIpType;
    exports2.DnsSupportValue = DnsSupportValue;
    exports2.DomainType = DomainType;
    exports2.DynamicRoutingValue = DynamicRoutingValue;
    exports2.EC2 = EC2;
    exports2.EC2Client = EC2Client2;
    exports2.EbsEncryptionSupport = EbsEncryptionSupport;
    exports2.EbsNvmeSupport = EbsNvmeSupport;
    exports2.EbsOptimizedSupport = EbsOptimizedSupport;
    exports2.Ec2InstanceConnectEndpointState = Ec2InstanceConnectEndpointState;
    exports2.EkPubKeyFormat = EkPubKeyFormat;
    exports2.EkPubKeyType = EkPubKeyType;
    exports2.ElasticGpuState = ElasticGpuState;
    exports2.ElasticGpuStatus = ElasticGpuStatus;
    exports2.EnaSupport = EnaSupport;
    exports2.EnableAddressTransferCommand = EnableAddressTransferCommand;
    exports2.EnableAllowedImagesSettingsCommand = EnableAllowedImagesSettingsCommand;
    exports2.EnableAwsNetworkPerformanceMetricSubscriptionCommand = EnableAwsNetworkPerformanceMetricSubscriptionCommand;
    exports2.EnableCapacityManagerCommand = EnableCapacityManagerCommand;
    exports2.EnableEbsEncryptionByDefaultCommand = EnableEbsEncryptionByDefaultCommand;
    exports2.EnableFastLaunchCommand = EnableFastLaunchCommand;
    exports2.EnableFastSnapshotRestoresCommand = EnableFastSnapshotRestoresCommand;
    exports2.EnableImageBlockPublicAccessCommand = EnableImageBlockPublicAccessCommand;
    exports2.EnableImageCommand = EnableImageCommand;
    exports2.EnableImageDeprecationCommand = EnableImageDeprecationCommand;
    exports2.EnableImageDeregistrationProtectionCommand = EnableImageDeregistrationProtectionCommand;
    exports2.EnableInstanceSqlHaStandbyDetectionsCommand = EnableInstanceSqlHaStandbyDetectionsCommand;
    exports2.EnableIpamOrganizationAdminAccountCommand = EnableIpamOrganizationAdminAccountCommand;
    exports2.EnableIpamPolicyCommand = EnableIpamPolicyCommand;
    exports2.EnableReachabilityAnalyzerOrganizationSharingCommand = EnableReachabilityAnalyzerOrganizationSharingCommand;
    exports2.EnableRouteServerPropagationCommand = EnableRouteServerPropagationCommand;
    exports2.EnableSerialConsoleAccessCommand = EnableSerialConsoleAccessCommand;
    exports2.EnableSnapshotBlockPublicAccessCommand = EnableSnapshotBlockPublicAccessCommand;
    exports2.EnableTransitGatewayRouteTablePropagationCommand = EnableTransitGatewayRouteTablePropagationCommand;
    exports2.EnableVgwRoutePropagationCommand = EnableVgwRoutePropagationCommand;
    exports2.EnableVolumeIOCommand = EnableVolumeIOCommand;
    exports2.EnableVpcClassicLinkCommand = EnableVpcClassicLinkCommand;
    exports2.EnableVpcClassicLinkDnsSupportCommand = EnableVpcClassicLinkDnsSupportCommand;
    exports2.EncryptionStateValue = EncryptionStateValue;
    exports2.EncryptionSupportOptionValue = EncryptionSupportOptionValue;
    exports2.EndDateType = EndDateType;
    exports2.EndpointIpAddressType = EndpointIpAddressType;
    exports2.EphemeralNvmeSupport = EphemeralNvmeSupport;
    exports2.EventCode = EventCode;
    exports2.EventType = EventType2;
    exports2.ExcessCapacityTerminationPolicy = ExcessCapacityTerminationPolicy;
    exports2.ExportClientVpnClientCertificateRevocationListCommand = ExportClientVpnClientCertificateRevocationListCommand;
    exports2.ExportClientVpnClientConfigurationCommand = ExportClientVpnClientConfigurationCommand;
    exports2.ExportEnvironment = ExportEnvironment;
    exports2.ExportImageCommand = ExportImageCommand;
    exports2.ExportTaskState = ExportTaskState;
    exports2.ExportTransitGatewayRoutesCommand = ExportTransitGatewayRoutesCommand;
    exports2.ExportVerifiedAccessInstanceClientConfigurationCommand = ExportVerifiedAccessInstanceClientConfigurationCommand;
    exports2.FastLaunchResourceType = FastLaunchResourceType;
    exports2.FastLaunchStateCode = FastLaunchStateCode;
    exports2.FastSnapshotRestoreStateCode = FastSnapshotRestoreStateCode;
    exports2.FilterByDimension = FilterByDimension;
    exports2.FindingsFound = FindingsFound;
    exports2.FleetActivityStatus = FleetActivityStatus;
    exports2.FleetCapacityReservationTenancy = FleetCapacityReservationTenancy;
    exports2.FleetCapacityReservationUsageStrategy = FleetCapacityReservationUsageStrategy;
    exports2.FleetEventType = FleetEventType;
    exports2.FleetExcessCapacityTerminationPolicy = FleetExcessCapacityTerminationPolicy;
    exports2.FleetInstanceMatchCriteria = FleetInstanceMatchCriteria;
    exports2.FleetOnDemandAllocationStrategy = FleetOnDemandAllocationStrategy;
    exports2.FleetReplacementStrategy = FleetReplacementStrategy;
    exports2.FleetReservationType = FleetReservationType;
    exports2.FleetStateCode = FleetStateCode;
    exports2.FleetType = FleetType;
    exports2.FlexibleEnaQueuesSupport = FlexibleEnaQueuesSupport;
    exports2.FlowLogsResourceType = FlowLogsResourceType;
    exports2.FpgaImageAttributeName = FpgaImageAttributeName;
    exports2.FpgaImageStateCode = FpgaImageStateCode;
    exports2.GatewayAssociationState = GatewayAssociationState;
    exports2.GatewayType = GatewayType;
    exports2.GetActiveVpnTunnelStatusCommand = GetActiveVpnTunnelStatusCommand;
    exports2.GetAllowedImagesSettingsCommand = GetAllowedImagesSettingsCommand;
    exports2.GetAssociatedEnclaveCertificateIamRolesCommand = GetAssociatedEnclaveCertificateIamRolesCommand;
    exports2.GetAssociatedIpv6PoolCidrsCommand = GetAssociatedIpv6PoolCidrsCommand;
    exports2.GetAwsNetworkPerformanceDataCommand = GetAwsNetworkPerformanceDataCommand;
    exports2.GetCapacityManagerAttributesCommand = GetCapacityManagerAttributesCommand;
    exports2.GetCapacityManagerMetricDataCommand = GetCapacityManagerMetricDataCommand;
    exports2.GetCapacityManagerMetricDimensionsCommand = GetCapacityManagerMetricDimensionsCommand;
    exports2.GetCapacityManagerMonitoredTagKeysCommand = GetCapacityManagerMonitoredTagKeysCommand;
    exports2.GetCapacityReservationUsageCommand = GetCapacityReservationUsageCommand;
    exports2.GetCoipPoolUsageCommand = GetCoipPoolUsageCommand;
    exports2.GetConsoleOutputCommand = GetConsoleOutputCommand;
    exports2.GetConsoleScreenshotCommand = GetConsoleScreenshotCommand;
    exports2.GetDeclarativePoliciesReportSummaryCommand = GetDeclarativePoliciesReportSummaryCommand;
    exports2.GetDefaultCreditSpecificationCommand = GetDefaultCreditSpecificationCommand;
    exports2.GetEbsDefaultKmsKeyIdCommand = GetEbsDefaultKmsKeyIdCommand;
    exports2.GetEbsEncryptionByDefaultCommand = GetEbsEncryptionByDefaultCommand;
    exports2.GetEnabledIpamPolicyCommand = GetEnabledIpamPolicyCommand;
    exports2.GetFlowLogsIntegrationTemplateCommand = GetFlowLogsIntegrationTemplateCommand;
    exports2.GetGroupsForCapacityReservationCommand = GetGroupsForCapacityReservationCommand;
    exports2.GetHostReservationPurchasePreviewCommand = GetHostReservationPurchasePreviewCommand;
    exports2.GetImageAncestryCommand = GetImageAncestryCommand;
    exports2.GetImageBlockPublicAccessStateCommand = GetImageBlockPublicAccessStateCommand;
    exports2.GetInstanceMetadataDefaultsCommand = GetInstanceMetadataDefaultsCommand;
    exports2.GetInstanceTpmEkPubCommand = GetInstanceTpmEkPubCommand;
    exports2.GetInstanceTypesFromInstanceRequirementsCommand = GetInstanceTypesFromInstanceRequirementsCommand;
    exports2.GetInstanceUefiDataCommand = GetInstanceUefiDataCommand;
    exports2.GetIpamAddressHistoryCommand = GetIpamAddressHistoryCommand;
    exports2.GetIpamDiscoveredAccountsCommand = GetIpamDiscoveredAccountsCommand;
    exports2.GetIpamDiscoveredPublicAddressesCommand = GetIpamDiscoveredPublicAddressesCommand;
    exports2.GetIpamDiscoveredResourceCidrsCommand = GetIpamDiscoveredResourceCidrsCommand;
    exports2.GetIpamPolicyAllocationRulesCommand = GetIpamPolicyAllocationRulesCommand;
    exports2.GetIpamPolicyOrganizationTargetsCommand = GetIpamPolicyOrganizationTargetsCommand;
    exports2.GetIpamPoolAllocationsCommand = GetIpamPoolAllocationsCommand;
    exports2.GetIpamPoolCidrsCommand = GetIpamPoolCidrsCommand;
    exports2.GetIpamPrefixListResolverRulesCommand = GetIpamPrefixListResolverRulesCommand;
    exports2.GetIpamPrefixListResolverVersionEntriesCommand = GetIpamPrefixListResolverVersionEntriesCommand;
    exports2.GetIpamPrefixListResolverVersionsCommand = GetIpamPrefixListResolverVersionsCommand;
    exports2.GetIpamResourceCidrsCommand = GetIpamResourceCidrsCommand;
    exports2.GetLaunchTemplateDataCommand = GetLaunchTemplateDataCommand;
    exports2.GetManagedPrefixListAssociationsCommand = GetManagedPrefixListAssociationsCommand;
    exports2.GetManagedPrefixListEntriesCommand = GetManagedPrefixListEntriesCommand;
    exports2.GetManagedResourceVisibilityCommand = GetManagedResourceVisibilityCommand;
    exports2.GetNetworkInsightsAccessScopeAnalysisFindingsCommand = GetNetworkInsightsAccessScopeAnalysisFindingsCommand;
    exports2.GetNetworkInsightsAccessScopeContentCommand = GetNetworkInsightsAccessScopeContentCommand;
    exports2.GetPasswordDataCommand = GetPasswordDataCommand;
    exports2.GetReservedInstancesExchangeQuoteCommand = GetReservedInstancesExchangeQuoteCommand;
    exports2.GetRouteServerAssociationsCommand = GetRouteServerAssociationsCommand;
    exports2.GetRouteServerPropagationsCommand = GetRouteServerPropagationsCommand;
    exports2.GetRouteServerRoutingDatabaseCommand = GetRouteServerRoutingDatabaseCommand;
    exports2.GetSecurityGroupsForVpcCommand = GetSecurityGroupsForVpcCommand;
    exports2.GetSerialConsoleAccessStatusCommand = GetSerialConsoleAccessStatusCommand;
    exports2.GetSnapshotBlockPublicAccessStateCommand = GetSnapshotBlockPublicAccessStateCommand;
    exports2.GetSpotPlacementScoresCommand = GetSpotPlacementScoresCommand;
    exports2.GetSubnetCidrReservationsCommand = GetSubnetCidrReservationsCommand;
    exports2.GetTransitGatewayAttachmentPropagationsCommand = GetTransitGatewayAttachmentPropagationsCommand;
    exports2.GetTransitGatewayMeteringPolicyEntriesCommand = GetTransitGatewayMeteringPolicyEntriesCommand;
    exports2.GetTransitGatewayMulticastDomainAssociationsCommand = GetTransitGatewayMulticastDomainAssociationsCommand;
    exports2.GetTransitGatewayPolicyTableAssociationsCommand = GetTransitGatewayPolicyTableAssociationsCommand;
    exports2.GetTransitGatewayPolicyTableEntriesCommand = GetTransitGatewayPolicyTableEntriesCommand;
    exports2.GetTransitGatewayPrefixListReferencesCommand = GetTransitGatewayPrefixListReferencesCommand;
    exports2.GetTransitGatewayRouteTableAssociationsCommand = GetTransitGatewayRouteTableAssociationsCommand;
    exports2.GetTransitGatewayRouteTablePropagationsCommand = GetTransitGatewayRouteTablePropagationsCommand;
    exports2.GetVerifiedAccessEndpointPolicyCommand = GetVerifiedAccessEndpointPolicyCommand;
    exports2.GetVerifiedAccessEndpointTargetsCommand = GetVerifiedAccessEndpointTargetsCommand;
    exports2.GetVerifiedAccessGroupPolicyCommand = GetVerifiedAccessGroupPolicyCommand;
    exports2.GetVpcResourcesBlockingEncryptionEnforcementCommand = GetVpcResourcesBlockingEncryptionEnforcementCommand;
    exports2.GetVpnConnectionDeviceSampleConfigurationCommand = GetVpnConnectionDeviceSampleConfigurationCommand;
    exports2.GetVpnConnectionDeviceTypesCommand = GetVpnConnectionDeviceTypesCommand;
    exports2.GetVpnTunnelReplacementStatusCommand = GetVpnTunnelReplacementStatusCommand;
    exports2.GroupBy = GroupBy;
    exports2.HaStatus = HaStatus;
    exports2.HostMaintenance = HostMaintenance;
    exports2.HostRecovery = HostRecovery;
    exports2.HostTenancy = HostTenancy;
    exports2.HostnameType = HostnameType;
    exports2.HttpTokensEnforcedState = HttpTokensEnforcedState;
    exports2.HttpTokensState = HttpTokensState;
    exports2.HypervisorType = HypervisorType;
    exports2.IamInstanceProfileAssociationState = IamInstanceProfileAssociationState;
    exports2.Igmpv2SupportValue = Igmpv2SupportValue;
    exports2.ImageAttributeName = ImageAttributeName;
    exports2.ImageBlockPublicAccessDisabledState = ImageBlockPublicAccessDisabledState;
    exports2.ImageBlockPublicAccessEnabledState = ImageBlockPublicAccessEnabledState;
    exports2.ImageReferenceOptionName = ImageReferenceOptionName;
    exports2.ImageReferenceResourceType = ImageReferenceResourceType;
    exports2.ImageState = ImageState;
    exports2.ImageTypeValues = ImageTypeValues;
    exports2.ImdsSupportValues = ImdsSupportValues;
    exports2.ImportClientVpnClientCertificateRevocationListCommand = ImportClientVpnClientCertificateRevocationListCommand;
    exports2.ImportImageCommand = ImportImageCommand;
    exports2.ImportInstanceCommand = ImportInstanceCommand;
    exports2.ImportKeyPairCommand = ImportKeyPairCommand;
    exports2.ImportSnapshotCommand = ImportSnapshotCommand;
    exports2.ImportVolumeCommand = ImportVolumeCommand;
    exports2.IngestionStatus = IngestionStatus;
    exports2.InitializationType = InitializationType;
    exports2.InstanceAttributeName = InstanceAttributeName;
    exports2.InstanceAutoRecoveryState = InstanceAutoRecoveryState;
    exports2.InstanceBandwidthWeighting = InstanceBandwidthWeighting;
    exports2.InstanceBootModeValues = InstanceBootModeValues;
    exports2.InstanceEventWindowState = InstanceEventWindowState;
    exports2.InstanceGeneration = InstanceGeneration;
    exports2.InstanceHealthStatus = InstanceHealthStatus;
    exports2.InstanceInterruptionBehavior = InstanceInterruptionBehavior;
    exports2.InstanceLifecycle = InstanceLifecycle;
    exports2.InstanceLifecycleType = InstanceLifecycleType;
    exports2.InstanceMatchCriteria = InstanceMatchCriteria;
    exports2.InstanceMetadataEndpointState = InstanceMetadataEndpointState;
    exports2.InstanceMetadataOptionsState = InstanceMetadataOptionsState;
    exports2.InstanceMetadataProtocolState = InstanceMetadataProtocolState;
    exports2.InstanceMetadataTagsState = InstanceMetadataTagsState;
    exports2.InstanceRebootMigrationState = InstanceRebootMigrationState;
    exports2.InstanceStateName = InstanceStateName;
    exports2.InstanceStorageEncryptionSupport = InstanceStorageEncryptionSupport;
    exports2.InstanceTypeHypervisor = InstanceTypeHypervisor;
    exports2.InterfacePermissionType = InterfacePermissionType;
    exports2.InterfaceProtocolType = InterfaceProtocolType;
    exports2.InternetGatewayBlockMode = InternetGatewayBlockMode;
    exports2.InternetGatewayExclusionMode = InternetGatewayExclusionMode;
    exports2.InterruptibleCapacityReservationAllocationStatus = InterruptibleCapacityReservationAllocationStatus;
    exports2.InterruptionType = InterruptionType;
    exports2.IpAddressType = IpAddressType;
    exports2.IpSource = IpSource;
    exports2.IpamAddressHistoryResourceType = IpamAddressHistoryResourceType;
    exports2.IpamAssociatedResourceDiscoveryStatus = IpamAssociatedResourceDiscoveryStatus;
    exports2.IpamComplianceStatus = IpamComplianceStatus;
    exports2.IpamDiscoveryFailureCode = IpamDiscoveryFailureCode;
    exports2.IpamExternalResourceVerificationTokenState = IpamExternalResourceVerificationTokenState;
    exports2.IpamManagementState = IpamManagementState;
    exports2.IpamMeteredAccount = IpamMeteredAccount;
    exports2.IpamNetworkInterfaceAttachmentStatus = IpamNetworkInterfaceAttachmentStatus;
    exports2.IpamOverlapStatus = IpamOverlapStatus;
    exports2.IpamPolicyManagedBy = IpamPolicyManagedBy;
    exports2.IpamPolicyResourceType = IpamPolicyResourceType;
    exports2.IpamPolicyState = IpamPolicyState;
    exports2.IpamPoolAllocationResourceType = IpamPoolAllocationResourceType;
    exports2.IpamPoolAwsService = IpamPoolAwsService;
    exports2.IpamPoolCidrFailureCode = IpamPoolCidrFailureCode;
    exports2.IpamPoolCidrState = IpamPoolCidrState;
    exports2.IpamPoolPublicIpSource = IpamPoolPublicIpSource;
    exports2.IpamPoolSourceResourceType = IpamPoolSourceResourceType;
    exports2.IpamPoolState = IpamPoolState;
    exports2.IpamPrefixListResolverRuleConditionOperation = IpamPrefixListResolverRuleConditionOperation;
    exports2.IpamPrefixListResolverRuleType = IpamPrefixListResolverRuleType;
    exports2.IpamPrefixListResolverState = IpamPrefixListResolverState;
    exports2.IpamPrefixListResolverTargetState = IpamPrefixListResolverTargetState;
    exports2.IpamPrefixListResolverVersionCreationStatus = IpamPrefixListResolverVersionCreationStatus;
    exports2.IpamPublicAddressAssociationStatus = IpamPublicAddressAssociationStatus;
    exports2.IpamPublicAddressAwsService = IpamPublicAddressAwsService;
    exports2.IpamPublicAddressType = IpamPublicAddressType;
    exports2.IpamResourceCidrIpSource = IpamResourceCidrIpSource;
    exports2.IpamResourceDiscoveryAssociationState = IpamResourceDiscoveryAssociationState;
    exports2.IpamResourceDiscoveryState = IpamResourceDiscoveryState;
    exports2.IpamResourceType = IpamResourceType;
    exports2.IpamScopeExternalAuthorityType = IpamScopeExternalAuthorityType;
    exports2.IpamScopeState = IpamScopeState;
    exports2.IpamScopeType = IpamScopeType;
    exports2.IpamState = IpamState;
    exports2.IpamTier = IpamTier;
    exports2.Ipv6AddressAttribute = Ipv6AddressAttribute;
    exports2.Ipv6SupportValue = Ipv6SupportValue;
    exports2.KeyFormat = KeyFormat;
    exports2.KeyType = KeyType;
    exports2.LaunchTemplateAutoRecoveryState = LaunchTemplateAutoRecoveryState;
    exports2.LaunchTemplateErrorCode = LaunchTemplateErrorCode;
    exports2.LaunchTemplateHttpTokensState = LaunchTemplateHttpTokensState;
    exports2.LaunchTemplateInstanceMetadataEndpointState = LaunchTemplateInstanceMetadataEndpointState;
    exports2.LaunchTemplateInstanceMetadataOptionsState = LaunchTemplateInstanceMetadataOptionsState;
    exports2.LaunchTemplateInstanceMetadataProtocolIpv6 = LaunchTemplateInstanceMetadataProtocolIpv6;
    exports2.LaunchTemplateInstanceMetadataTagsState = LaunchTemplateInstanceMetadataTagsState;
    exports2.ListImagesInRecycleBinCommand = ListImagesInRecycleBinCommand;
    exports2.ListSnapshotsInRecycleBinCommand = ListSnapshotsInRecycleBinCommand;
    exports2.ListVolumesInRecycleBinCommand = ListVolumesInRecycleBinCommand;
    exports2.ListingState = ListingState;
    exports2.ListingStatus = ListingStatus;
    exports2.LocalGatewayRouteState = LocalGatewayRouteState;
    exports2.LocalGatewayRouteTableMode = LocalGatewayRouteTableMode;
    exports2.LocalGatewayRouteType = LocalGatewayRouteType;
    exports2.LocalGatewayVirtualInterfaceConfigurationState = LocalGatewayVirtualInterfaceConfigurationState;
    exports2.LocalGatewayVirtualInterfaceGroupConfigurationState = LocalGatewayVirtualInterfaceGroupConfigurationState;
    exports2.LocalStorage = LocalStorage;
    exports2.LocalStorageType = LocalStorageType;
    exports2.LocationType = LocationType;
    exports2.LockMode = LockMode;
    exports2.LockSnapshotCommand = LockSnapshotCommand;
    exports2.LockState = LockState;
    exports2.LogDestinationType = LogDestinationType;
    exports2.MacModificationTaskState = MacModificationTaskState;
    exports2.MacModificationTaskType = MacModificationTaskType;
    exports2.MacSystemIntegrityProtectionSettingStatus = MacSystemIntegrityProtectionSettingStatus;
    exports2.ManagedBy = ManagedBy;
    exports2.ManagedResourceDefaultVisibility = ManagedResourceDefaultVisibility;
    exports2.MarketType = MarketType;
    exports2.MembershipType = MembershipType;
    exports2.MetadataDefaultHttpTokensState = MetadataDefaultHttpTokensState;
    exports2.Metric = Metric;
    exports2.MetricType = MetricType;
    exports2.ModifyAddressAttributeCommand = ModifyAddressAttributeCommand;
    exports2.ModifyAvailabilityZoneGroupCommand = ModifyAvailabilityZoneGroupCommand;
    exports2.ModifyAvailabilityZoneOptInStatus = ModifyAvailabilityZoneOptInStatus;
    exports2.ModifyCapacityReservationCommand = ModifyCapacityReservationCommand;
    exports2.ModifyCapacityReservationFleetCommand = ModifyCapacityReservationFleetCommand;
    exports2.ModifyClientVpnEndpointCommand = ModifyClientVpnEndpointCommand;
    exports2.ModifyDefaultCreditSpecificationCommand = ModifyDefaultCreditSpecificationCommand;
    exports2.ModifyEbsDefaultKmsKeyIdCommand = ModifyEbsDefaultKmsKeyIdCommand;
    exports2.ModifyFleetCommand = ModifyFleetCommand;
    exports2.ModifyFpgaImageAttributeCommand = ModifyFpgaImageAttributeCommand;
    exports2.ModifyHostsCommand = ModifyHostsCommand;
    exports2.ModifyIdFormatCommand = ModifyIdFormatCommand;
    exports2.ModifyIdentityIdFormatCommand = ModifyIdentityIdFormatCommand;
    exports2.ModifyImageAttributeCommand = ModifyImageAttributeCommand;
    exports2.ModifyInstanceAttributeCommand = ModifyInstanceAttributeCommand;
    exports2.ModifyInstanceCapacityReservationAttributesCommand = ModifyInstanceCapacityReservationAttributesCommand;
    exports2.ModifyInstanceConnectEndpointCommand = ModifyInstanceConnectEndpointCommand;
    exports2.ModifyInstanceCpuOptionsCommand = ModifyInstanceCpuOptionsCommand;
    exports2.ModifyInstanceCreditSpecificationCommand = ModifyInstanceCreditSpecificationCommand;
    exports2.ModifyInstanceEventStartTimeCommand = ModifyInstanceEventStartTimeCommand;
    exports2.ModifyInstanceEventWindowCommand = ModifyInstanceEventWindowCommand;
    exports2.ModifyInstanceMaintenanceOptionsCommand = ModifyInstanceMaintenanceOptionsCommand;
    exports2.ModifyInstanceMetadataDefaultsCommand = ModifyInstanceMetadataDefaultsCommand;
    exports2.ModifyInstanceMetadataOptionsCommand = ModifyInstanceMetadataOptionsCommand;
    exports2.ModifyInstanceNetworkPerformanceOptionsCommand = ModifyInstanceNetworkPerformanceOptionsCommand;
    exports2.ModifyInstancePlacementCommand = ModifyInstancePlacementCommand;
    exports2.ModifyIpamCommand = ModifyIpamCommand;
    exports2.ModifyIpamPolicyAllocationRulesCommand = ModifyIpamPolicyAllocationRulesCommand;
    exports2.ModifyIpamPoolCommand = ModifyIpamPoolCommand;
    exports2.ModifyIpamPrefixListResolverCommand = ModifyIpamPrefixListResolverCommand;
    exports2.ModifyIpamPrefixListResolverTargetCommand = ModifyIpamPrefixListResolverTargetCommand;
    exports2.ModifyIpamResourceCidrCommand = ModifyIpamResourceCidrCommand;
    exports2.ModifyIpamResourceDiscoveryCommand = ModifyIpamResourceDiscoveryCommand;
    exports2.ModifyIpamScopeCommand = ModifyIpamScopeCommand;
    exports2.ModifyLaunchTemplateCommand = ModifyLaunchTemplateCommand;
    exports2.ModifyLocalGatewayRouteCommand = ModifyLocalGatewayRouteCommand;
    exports2.ModifyManagedPrefixListCommand = ModifyManagedPrefixListCommand;
    exports2.ModifyManagedResourceVisibilityCommand = ModifyManagedResourceVisibilityCommand;
    exports2.ModifyNetworkInterfaceAttributeCommand = ModifyNetworkInterfaceAttributeCommand;
    exports2.ModifyPrivateDnsNameOptionsCommand = ModifyPrivateDnsNameOptionsCommand;
    exports2.ModifyPublicIpDnsNameOptionsCommand = ModifyPublicIpDnsNameOptionsCommand;
    exports2.ModifyReservedInstancesCommand = ModifyReservedInstancesCommand;
    exports2.ModifyRouteServerCommand = ModifyRouteServerCommand;
    exports2.ModifySecurityGroupRulesCommand = ModifySecurityGroupRulesCommand;
    exports2.ModifySnapshotAttributeCommand = ModifySnapshotAttributeCommand;
    exports2.ModifySnapshotTierCommand = ModifySnapshotTierCommand;
    exports2.ModifySpotFleetRequestCommand = ModifySpotFleetRequestCommand;
    exports2.ModifySubnetAttributeCommand = ModifySubnetAttributeCommand;
    exports2.ModifyTrafficMirrorFilterNetworkServicesCommand = ModifyTrafficMirrorFilterNetworkServicesCommand;
    exports2.ModifyTrafficMirrorFilterRuleCommand = ModifyTrafficMirrorFilterRuleCommand;
    exports2.ModifyTrafficMirrorSessionCommand = ModifyTrafficMirrorSessionCommand;
    exports2.ModifyTransitGatewayCommand = ModifyTransitGatewayCommand;
    exports2.ModifyTransitGatewayMeteringPolicyCommand = ModifyTransitGatewayMeteringPolicyCommand;
    exports2.ModifyTransitGatewayPrefixListReferenceCommand = ModifyTransitGatewayPrefixListReferenceCommand;
    exports2.ModifyTransitGatewayVpcAttachmentCommand = ModifyTransitGatewayVpcAttachmentCommand;
    exports2.ModifyVerifiedAccessEndpointCommand = ModifyVerifiedAccessEndpointCommand;
    exports2.ModifyVerifiedAccessEndpointPolicyCommand = ModifyVerifiedAccessEndpointPolicyCommand;
    exports2.ModifyVerifiedAccessGroupCommand = ModifyVerifiedAccessGroupCommand;
    exports2.ModifyVerifiedAccessGroupPolicyCommand = ModifyVerifiedAccessGroupPolicyCommand;
    exports2.ModifyVerifiedAccessInstanceCommand = ModifyVerifiedAccessInstanceCommand;
    exports2.ModifyVerifiedAccessInstanceLoggingConfigurationCommand = ModifyVerifiedAccessInstanceLoggingConfigurationCommand;
    exports2.ModifyVerifiedAccessTrustProviderCommand = ModifyVerifiedAccessTrustProviderCommand;
    exports2.ModifyVolumeAttributeCommand = ModifyVolumeAttributeCommand;
    exports2.ModifyVolumeCommand = ModifyVolumeCommand;
    exports2.ModifyVpcAttributeCommand = ModifyVpcAttributeCommand;
    exports2.ModifyVpcBlockPublicAccessExclusionCommand = ModifyVpcBlockPublicAccessExclusionCommand;
    exports2.ModifyVpcBlockPublicAccessOptionsCommand = ModifyVpcBlockPublicAccessOptionsCommand;
    exports2.ModifyVpcEncryptionControlCommand = ModifyVpcEncryptionControlCommand;
    exports2.ModifyVpcEndpointCommand = ModifyVpcEndpointCommand;
    exports2.ModifyVpcEndpointConnectionNotificationCommand = ModifyVpcEndpointConnectionNotificationCommand;
    exports2.ModifyVpcEndpointServiceConfigurationCommand = ModifyVpcEndpointServiceConfigurationCommand;
    exports2.ModifyVpcEndpointServicePayerResponsibilityCommand = ModifyVpcEndpointServicePayerResponsibilityCommand;
    exports2.ModifyVpcEndpointServicePermissionsCommand = ModifyVpcEndpointServicePermissionsCommand;
    exports2.ModifyVpcPeeringConnectionOptionsCommand = ModifyVpcPeeringConnectionOptionsCommand;
    exports2.ModifyVpcTenancyCommand = ModifyVpcTenancyCommand;
    exports2.ModifyVpnConnectionCommand = ModifyVpnConnectionCommand;
    exports2.ModifyVpnConnectionOptionsCommand = ModifyVpnConnectionOptionsCommand;
    exports2.ModifyVpnTunnelCertificateCommand = ModifyVpnTunnelCertificateCommand;
    exports2.ModifyVpnTunnelOptionsCommand = ModifyVpnTunnelOptionsCommand;
    exports2.MonitorInstancesCommand = MonitorInstancesCommand;
    exports2.MonitoringState = MonitoringState;
    exports2.MoveAddressToVpcCommand = MoveAddressToVpcCommand;
    exports2.MoveByoipCidrToIpamCommand = MoveByoipCidrToIpamCommand;
    exports2.MoveCapacityReservationInstancesCommand = MoveCapacityReservationInstancesCommand;
    exports2.MoveStatus = MoveStatus;
    exports2.MulticastSupportValue = MulticastSupportValue;
    exports2.NatGatewayAddressStatus = NatGatewayAddressStatus;
    exports2.NatGatewayApplianceModifyState = NatGatewayApplianceModifyState;
    exports2.NatGatewayApplianceState = NatGatewayApplianceState;
    exports2.NatGatewayApplianceType = NatGatewayApplianceType;
    exports2.NatGatewayState = NatGatewayState;
    exports2.NestedVirtualizationSpecification = NestedVirtualizationSpecification;
    exports2.NetworkInterfaceAttribute = NetworkInterfaceAttribute;
    exports2.NetworkInterfaceCreationType = NetworkInterfaceCreationType;
    exports2.NetworkInterfacePermissionStateCode = NetworkInterfacePermissionStateCode;
    exports2.NetworkInterfaceStatus = NetworkInterfaceStatus;
    exports2.NetworkInterfaceType = NetworkInterfaceType;
    exports2.NitroEnclavesSupport = NitroEnclavesSupport;
    exports2.NitroTpmSupport = NitroTpmSupport;
    exports2.OfferingClassType = OfferingClassType;
    exports2.OfferingTypeValues = OfferingTypeValues;
    exports2.OnDemandAllocationStrategy = OnDemandAllocationStrategy;
    exports2.OperationType = OperationType;
    exports2.OutputFormat = OutputFormat;
    exports2.PartitionLoadFrequency = PartitionLoadFrequency;
    exports2.PayerResponsibility = PayerResponsibility;
    exports2.PaymentOption = PaymentOption;
    exports2.PeriodType = PeriodType;
    exports2.PermissionGroup = PermissionGroup;
    exports2.PhcSupport = PhcSupport;
    exports2.PlacementGroupState = PlacementGroupState;
    exports2.PlacementGroupStrategy = PlacementGroupStrategy;
    exports2.PlacementStrategy = PlacementStrategy;
    exports2.PlatformValues = PlatformValues;
    exports2.PrefixListState = PrefixListState;
    exports2.PrincipalType = PrincipalType;
    exports2.ProductCodeValues = ProductCodeValues;
    exports2.Protocol = Protocol;
    exports2.ProtocolValue = ProtocolValue;
    exports2.ProvisionByoipCidrCommand = ProvisionByoipCidrCommand;
    exports2.ProvisionIpamByoasnCommand = ProvisionIpamByoasnCommand;
    exports2.ProvisionIpamPoolCidrCommand = ProvisionIpamPoolCidrCommand;
    exports2.ProvisionPublicIpv4PoolCidrCommand = ProvisionPublicIpv4PoolCidrCommand;
    exports2.PublicIpDnsOption = PublicIpDnsOption;
    exports2.PurchaseCapacityBlockCommand = PurchaseCapacityBlockCommand;
    exports2.PurchaseCapacityBlockExtensionCommand = PurchaseCapacityBlockExtensionCommand;
    exports2.PurchaseHostReservationCommand = PurchaseHostReservationCommand;
    exports2.PurchaseReservedInstancesOfferingCommand = PurchaseReservedInstancesOfferingCommand;
    exports2.PurchaseScheduledInstancesCommand = PurchaseScheduledInstancesCommand;
    exports2.RIProductDescription = RIProductDescription;
    exports2.RebootInstancesCommand = RebootInstancesCommand;
    exports2.RebootMigrationSupport = RebootMigrationSupport;
    exports2.RecurringChargeFrequency = RecurringChargeFrequency;
    exports2.RegisterImageCommand = RegisterImageCommand;
    exports2.RegisterInstanceEventNotificationAttributesCommand = RegisterInstanceEventNotificationAttributesCommand;
    exports2.RegisterTransitGatewayMulticastGroupMembersCommand = RegisterTransitGatewayMulticastGroupMembersCommand;
    exports2.RegisterTransitGatewayMulticastGroupSourcesCommand = RegisterTransitGatewayMulticastGroupSourcesCommand;
    exports2.RejectCapacityReservationBillingOwnershipCommand = RejectCapacityReservationBillingOwnershipCommand;
    exports2.RejectTransitGatewayClientVpnAttachmentCommand = RejectTransitGatewayClientVpnAttachmentCommand;
    exports2.RejectTransitGatewayMulticastDomainAssociationsCommand = RejectTransitGatewayMulticastDomainAssociationsCommand;
    exports2.RejectTransitGatewayPeeringAttachmentCommand = RejectTransitGatewayPeeringAttachmentCommand;
    exports2.RejectTransitGatewayVpcAttachmentCommand = RejectTransitGatewayVpcAttachmentCommand;
    exports2.RejectVpcEndpointConnectionsCommand = RejectVpcEndpointConnectionsCommand;
    exports2.RejectVpcPeeringConnectionCommand = RejectVpcPeeringConnectionCommand;
    exports2.ReleaseAddressCommand = ReleaseAddressCommand;
    exports2.ReleaseHostsCommand = ReleaseHostsCommand;
    exports2.ReleaseIpamPoolAllocationCommand = ReleaseIpamPoolAllocationCommand;
    exports2.ReplaceIamInstanceProfileAssociationCommand = ReplaceIamInstanceProfileAssociationCommand;
    exports2.ReplaceImageCriteriaInAllowedImagesSettingsCommand = ReplaceImageCriteriaInAllowedImagesSettingsCommand;
    exports2.ReplaceNetworkAclAssociationCommand = ReplaceNetworkAclAssociationCommand;
    exports2.ReplaceNetworkAclEntryCommand = ReplaceNetworkAclEntryCommand;
    exports2.ReplaceRootVolumeTaskState = ReplaceRootVolumeTaskState;
    exports2.ReplaceRouteCommand = ReplaceRouteCommand;
    exports2.ReplaceRouteTableAssociationCommand = ReplaceRouteTableAssociationCommand;
    exports2.ReplaceTransitGatewayRouteCommand = ReplaceTransitGatewayRouteCommand;
    exports2.ReplaceVpnTunnelCommand = ReplaceVpnTunnelCommand;
    exports2.ReplacementStrategy = ReplacementStrategy;
    exports2.ReportInstanceReasonCodes = ReportInstanceReasonCodes;
    exports2.ReportInstanceStatusCommand = ReportInstanceStatusCommand;
    exports2.ReportState = ReportState;
    exports2.ReportStatusType = ReportStatusType;
    exports2.RequestSpotFleetCommand = RequestSpotFleetCommand;
    exports2.RequestSpotInstancesCommand = RequestSpotInstancesCommand;
    exports2.ReservationEndDateType = ReservationEndDateType;
    exports2.ReservationState = ReservationState;
    exports2.ReservationType = ReservationType;
    exports2.ReservedInstanceState = ReservedInstanceState;
    exports2.ResetAddressAttributeCommand = ResetAddressAttributeCommand;
    exports2.ResetEbsDefaultKmsKeyIdCommand = ResetEbsDefaultKmsKeyIdCommand;
    exports2.ResetFpgaImageAttributeCommand = ResetFpgaImageAttributeCommand;
    exports2.ResetFpgaImageAttributeName = ResetFpgaImageAttributeName;
    exports2.ResetImageAttributeCommand = ResetImageAttributeCommand;
    exports2.ResetImageAttributeName = ResetImageAttributeName;
    exports2.ResetInstanceAttributeCommand = ResetInstanceAttributeCommand;
    exports2.ResetNetworkInterfaceAttributeCommand = ResetNetworkInterfaceAttributeCommand;
    exports2.ResetSnapshotAttributeCommand = ResetSnapshotAttributeCommand;
    exports2.ResourceType = ResourceType;
    exports2.RestoreAddressToClassicCommand = RestoreAddressToClassicCommand;
    exports2.RestoreImageFromRecycleBinCommand = RestoreImageFromRecycleBinCommand;
    exports2.RestoreManagedPrefixListVersionCommand = RestoreManagedPrefixListVersionCommand;
    exports2.RestoreSnapshotFromRecycleBinCommand = RestoreSnapshotFromRecycleBinCommand;
    exports2.RestoreSnapshotTierCommand = RestoreSnapshotTierCommand;
    exports2.RestoreVolumeFromRecycleBinCommand = RestoreVolumeFromRecycleBinCommand;
    exports2.RevokeClientVpnIngressCommand = RevokeClientVpnIngressCommand;
    exports2.RevokeSecurityGroupEgressCommand = RevokeSecurityGroupEgressCommand;
    exports2.RevokeSecurityGroupIngressCommand = RevokeSecurityGroupIngressCommand;
    exports2.RootDeviceType = RootDeviceType;
    exports2.RouteOrigin = RouteOrigin;
    exports2.RouteServerAssociationState = RouteServerAssociationState;
    exports2.RouteServerBfdState = RouteServerBfdState;
    exports2.RouteServerBgpState = RouteServerBgpState;
    exports2.RouteServerEndpointState = RouteServerEndpointState;
    exports2.RouteServerPeerLivenessMode = RouteServerPeerLivenessMode;
    exports2.RouteServerPeerState = RouteServerPeerState;
    exports2.RouteServerPersistRoutesAction = RouteServerPersistRoutesAction;
    exports2.RouteServerPersistRoutesState = RouteServerPersistRoutesState;
    exports2.RouteServerPropagationState = RouteServerPropagationState;
    exports2.RouteServerRouteInstallationStatus = RouteServerRouteInstallationStatus;
    exports2.RouteServerRouteStatus = RouteServerRouteStatus;
    exports2.RouteServerState = RouteServerState;
    exports2.RouteState = RouteState;
    exports2.RouteTableAssociationStateCode = RouteTableAssociationStateCode;
    exports2.RuleAction = RuleAction;
    exports2.RunInstancesCommand = RunInstancesCommand;
    exports2.RunScheduledInstancesCommand = RunScheduledInstancesCommand;
    exports2.SSEType = SSEType;
    exports2.Schedule = Schedule;
    exports2.Scope = Scope;
    exports2.SearchLocalGatewayRoutesCommand = SearchLocalGatewayRoutesCommand;
    exports2.SearchTransitGatewayMulticastGroupsCommand = SearchTransitGatewayMulticastGroupsCommand;
    exports2.SearchTransitGatewayRoutesCommand = SearchTransitGatewayRoutesCommand;
    exports2.SecondaryInterfaceStatus = SecondaryInterfaceStatus;
    exports2.SecondaryInterfaceType = SecondaryInterfaceType;
    exports2.SecondaryNetworkCidrBlockAssociationState = SecondaryNetworkCidrBlockAssociationState;
    exports2.SecondaryNetworkState = SecondaryNetworkState;
    exports2.SecondaryNetworkType = SecondaryNetworkType;
    exports2.SecondarySubnetCidrBlockAssociationState = SecondarySubnetCidrBlockAssociationState;
    exports2.SecondarySubnetState = SecondarySubnetState;
    exports2.SecurityGroupReferencingSupportValue = SecurityGroupReferencingSupportValue;
    exports2.SecurityGroupVpcAssociationState = SecurityGroupVpcAssociationState;
    exports2.SelfServicePortal = SelfServicePortal;
    exports2.SendDiagnosticInterruptCommand = SendDiagnosticInterruptCommand;
    exports2.ServiceConnectivityType = ServiceConnectivityType;
    exports2.ServiceLinkVirtualInterfaceConfigurationState = ServiceLinkVirtualInterfaceConfigurationState;
    exports2.ServiceManaged = ServiceManaged;
    exports2.ServiceState = ServiceState;
    exports2.ServiceType = ServiceType;
    exports2.ShutdownBehavior = ShutdownBehavior;
    exports2.SnapshotAttributeName = SnapshotAttributeName;
    exports2.SnapshotBlockPublicAccessState = SnapshotBlockPublicAccessState;
    exports2.SnapshotLocationEnum = SnapshotLocationEnum;
    exports2.SnapshotReturnCodes = SnapshotReturnCodes;
    exports2.SnapshotState = SnapshotState;
    exports2.SpotAllocationStrategy = SpotAllocationStrategy;
    exports2.SpotInstanceInterruptionBehavior = SpotInstanceInterruptionBehavior;
    exports2.SpotInstanceState = SpotInstanceState;
    exports2.SpotInstanceType = SpotInstanceType;
    exports2.SpreadLevel = SpreadLevel;
    exports2.SqlServerLicenseUsage = SqlServerLicenseUsage;
    exports2.StartDeclarativePoliciesReportCommand = StartDeclarativePoliciesReportCommand;
    exports2.StartInstancesCommand = StartInstancesCommand;
    exports2.StartNetworkInsightsAccessScopeAnalysisCommand = StartNetworkInsightsAccessScopeAnalysisCommand;
    exports2.StartNetworkInsightsAnalysisCommand = StartNetworkInsightsAnalysisCommand;
    exports2.StartVpcEndpointServicePrivateDnsVerificationCommand = StartVpcEndpointServicePrivateDnsVerificationCommand;
    exports2.State = State;
    exports2.StaticSourcesSupportValue = StaticSourcesSupportValue;
    exports2.StatisticType = StatisticType;
    exports2.Status = Status;
    exports2.StatusName = StatusName;
    exports2.StatusType = StatusType;
    exports2.StopInstancesCommand = StopInstancesCommand;
    exports2.StorageTier = StorageTier;
    exports2.SubnetCidrBlockStateCode = SubnetCidrBlockStateCode;
    exports2.SubnetCidrReservationType = SubnetCidrReservationType;
    exports2.SubnetState = SubnetState;
    exports2.SummaryStatus = SummaryStatus;
    exports2.SupportedAdditionalProcessorFeature = SupportedAdditionalProcessorFeature;
    exports2.TargetCapacityUnitType = TargetCapacityUnitType;
    exports2.TargetStorageTier = TargetStorageTier;
    exports2.TelemetryStatus = TelemetryStatus;
    exports2.Tenancy = Tenancy;
    exports2.TerminateClientVpnConnectionsCommand = TerminateClientVpnConnectionsCommand;
    exports2.TerminateInstancesCommand = TerminateInstancesCommand;
    exports2.TieringOperationStatus = TieringOperationStatus;
    exports2.TokenState = TokenState;
    exports2.TpmSupportValues = TpmSupportValues;
    exports2.TrafficDirection = TrafficDirection;
    exports2.TrafficIpAddressType = TrafficIpAddressType;
    exports2.TrafficMirrorFilterRuleField = TrafficMirrorFilterRuleField;
    exports2.TrafficMirrorNetworkService = TrafficMirrorNetworkService;
    exports2.TrafficMirrorRuleAction = TrafficMirrorRuleAction;
    exports2.TrafficMirrorSessionField = TrafficMirrorSessionField;
    exports2.TrafficMirrorTargetType = TrafficMirrorTargetType;
    exports2.TrafficType = TrafficType;
    exports2.TransferType = TransferType;
    exports2.TransitGatewayAssociationState = TransitGatewayAssociationState;
    exports2.TransitGatewayAttachmentResourceType = TransitGatewayAttachmentResourceType;
    exports2.TransitGatewayAttachmentState = TransitGatewayAttachmentState;
    exports2.TransitGatewayAttachmentStatusType = TransitGatewayAttachmentStatusType;
    exports2.TransitGatewayConnectPeerState = TransitGatewayConnectPeerState;
    exports2.TransitGatewayMeteringPayerType = TransitGatewayMeteringPayerType;
    exports2.TransitGatewayMeteringPolicyEntryState = TransitGatewayMeteringPolicyEntryState;
    exports2.TransitGatewayMeteringPolicyState = TransitGatewayMeteringPolicyState;
    exports2.TransitGatewayMulitcastDomainAssociationState = TransitGatewayMulitcastDomainAssociationState;
    exports2.TransitGatewayMulticastDomainState = TransitGatewayMulticastDomainState;
    exports2.TransitGatewayPolicyTableState = TransitGatewayPolicyTableState;
    exports2.TransitGatewayPrefixListReferenceState = TransitGatewayPrefixListReferenceState;
    exports2.TransitGatewayPropagationState = TransitGatewayPropagationState;
    exports2.TransitGatewayRouteState = TransitGatewayRouteState;
    exports2.TransitGatewayRouteTableAnnouncementDirection = TransitGatewayRouteTableAnnouncementDirection;
    exports2.TransitGatewayRouteTableAnnouncementState = TransitGatewayRouteTableAnnouncementState;
    exports2.TransitGatewayRouteTableState = TransitGatewayRouteTableState;
    exports2.TransitGatewayRouteType = TransitGatewayRouteType;
    exports2.TransitGatewayState = TransitGatewayState;
    exports2.TransportProtocol = TransportProtocol;
    exports2.TrustProviderType = TrustProviderType;
    exports2.TunnelInsideIpVersion = TunnelInsideIpVersion;
    exports2.UnassignIpv6AddressesCommand = UnassignIpv6AddressesCommand;
    exports2.UnassignPrivateIpAddressesCommand = UnassignPrivateIpAddressesCommand;
    exports2.UnassignPrivateNatGatewayAddressCommand = UnassignPrivateNatGatewayAddressCommand;
    exports2.UnlimitedSupportedInstanceFamily = UnlimitedSupportedInstanceFamily;
    exports2.UnlockSnapshotCommand = UnlockSnapshotCommand;
    exports2.UnmonitorInstancesCommand = UnmonitorInstancesCommand;
    exports2.UnsuccessfulInstanceCreditSpecificationErrorCode = UnsuccessfulInstanceCreditSpecificationErrorCode;
    exports2.UpdateCapacityManagerMonitoredTagKeysCommand = UpdateCapacityManagerMonitoredTagKeysCommand;
    exports2.UpdateCapacityManagerOrganizationsAccessCommand = UpdateCapacityManagerOrganizationsAccessCommand;
    exports2.UpdateInterruptibleCapacityReservationAllocationCommand = UpdateInterruptibleCapacityReservationAllocationCommand;
    exports2.UpdateSecurityGroupRuleDescriptionsEgressCommand = UpdateSecurityGroupRuleDescriptionsEgressCommand;
    exports2.UpdateSecurityGroupRuleDescriptionsIngressCommand = UpdateSecurityGroupRuleDescriptionsIngressCommand;
    exports2.UsageClassType = UsageClassType;
    exports2.UserTrustProviderType = UserTrustProviderType;
    exports2.VerificationMethod = VerificationMethod;
    exports2.VerifiedAccessEndpointAttachmentType = VerifiedAccessEndpointAttachmentType;
    exports2.VerifiedAccessEndpointProtocol = VerifiedAccessEndpointProtocol;
    exports2.VerifiedAccessEndpointStatusCode = VerifiedAccessEndpointStatusCode;
    exports2.VerifiedAccessEndpointType = VerifiedAccessEndpointType;
    exports2.VerifiedAccessLogDeliveryStatusCode = VerifiedAccessLogDeliveryStatusCode;
    exports2.VirtualizationType = VirtualizationType;
    exports2.VolumeAttachmentState = VolumeAttachmentState;
    exports2.VolumeAttributeName = VolumeAttributeName;
    exports2.VolumeModificationState = VolumeModificationState;
    exports2.VolumeState = VolumeState;
    exports2.VolumeStatusInfoStatus = VolumeStatusInfoStatus;
    exports2.VolumeStatusName = VolumeStatusName;
    exports2.VolumeType = VolumeType;
    exports2.VpcAttributeName = VpcAttributeName;
    exports2.VpcBlockPublicAccessExclusionState = VpcBlockPublicAccessExclusionState;
    exports2.VpcBlockPublicAccessExclusionsAllowed = VpcBlockPublicAccessExclusionsAllowed;
    exports2.VpcBlockPublicAccessState = VpcBlockPublicAccessState;
    exports2.VpcCidrBlockStateCode = VpcCidrBlockStateCode;
    exports2.VpcEncryptionControlExclusionState = VpcEncryptionControlExclusionState;
    exports2.VpcEncryptionControlExclusionStateInput = VpcEncryptionControlExclusionStateInput;
    exports2.VpcEncryptionControlMode = VpcEncryptionControlMode;
    exports2.VpcEncryptionControlState = VpcEncryptionControlState;
    exports2.VpcEndpointType = VpcEndpointType;
    exports2.VpcPeeringConnectionStateReasonCode = VpcPeeringConnectionStateReasonCode;
    exports2.VpcState = VpcState;
    exports2.VpcTenancy = VpcTenancy;
    exports2.VpnConcentratorType = VpnConcentratorType;
    exports2.VpnEcmpSupportValue = VpnEcmpSupportValue;
    exports2.VpnProtocol = VpnProtocol;
    exports2.VpnState = VpnState;
    exports2.VpnStaticRouteSource = VpnStaticRouteSource;
    exports2.VpnTunnelBandwidth = VpnTunnelBandwidth;
    exports2.VpnTunnelProvisioningStatus = VpnTunnelProvisioningStatus;
    exports2.WeekDay = WeekDay;
    exports2.WithdrawByoipCidrCommand = WithdrawByoipCidrCommand;
    exports2._InstanceType = _InstanceType;
    exports2.paginateDescribeAddressTransfers = paginateDescribeAddressTransfers;
    exports2.paginateDescribeAddressesAttribute = paginateDescribeAddressesAttribute;
    exports2.paginateDescribeAwsNetworkPerformanceMetricSubscriptions = paginateDescribeAwsNetworkPerformanceMetricSubscriptions;
    exports2.paginateDescribeByoipCidrs = paginateDescribeByoipCidrs;
    exports2.paginateDescribeCapacityBlockExtensionHistory = paginateDescribeCapacityBlockExtensionHistory;
    exports2.paginateDescribeCapacityBlockExtensionOfferings = paginateDescribeCapacityBlockExtensionOfferings;
    exports2.paginateDescribeCapacityBlockOfferings = paginateDescribeCapacityBlockOfferings;
    exports2.paginateDescribeCapacityBlockStatus = paginateDescribeCapacityBlockStatus;
    exports2.paginateDescribeCapacityBlocks = paginateDescribeCapacityBlocks;
    exports2.paginateDescribeCapacityManagerDataExports = paginateDescribeCapacityManagerDataExports;
    exports2.paginateDescribeCapacityReservationBillingRequests = paginateDescribeCapacityReservationBillingRequests;
    exports2.paginateDescribeCapacityReservationFleets = paginateDescribeCapacityReservationFleets;
    exports2.paginateDescribeCapacityReservations = paginateDescribeCapacityReservations;
    exports2.paginateDescribeCarrierGateways = paginateDescribeCarrierGateways;
    exports2.paginateDescribeClassicLinkInstances = paginateDescribeClassicLinkInstances;
    exports2.paginateDescribeClientVpnAuthorizationRules = paginateDescribeClientVpnAuthorizationRules;
    exports2.paginateDescribeClientVpnConnections = paginateDescribeClientVpnConnections;
    exports2.paginateDescribeClientVpnEndpoints = paginateDescribeClientVpnEndpoints;
    exports2.paginateDescribeClientVpnRoutes = paginateDescribeClientVpnRoutes;
    exports2.paginateDescribeClientVpnTargetNetworks = paginateDescribeClientVpnTargetNetworks;
    exports2.paginateDescribeCoipPools = paginateDescribeCoipPools;
    exports2.paginateDescribeDhcpOptions = paginateDescribeDhcpOptions;
    exports2.paginateDescribeEgressOnlyInternetGateways = paginateDescribeEgressOnlyInternetGateways;
    exports2.paginateDescribeExportImageTasks = paginateDescribeExportImageTasks;
    exports2.paginateDescribeFastLaunchImages = paginateDescribeFastLaunchImages;
    exports2.paginateDescribeFastSnapshotRestores = paginateDescribeFastSnapshotRestores;
    exports2.paginateDescribeFleets = paginateDescribeFleets;
    exports2.paginateDescribeFlowLogs = paginateDescribeFlowLogs;
    exports2.paginateDescribeFpgaImages = paginateDescribeFpgaImages;
    exports2.paginateDescribeHostReservationOfferings = paginateDescribeHostReservationOfferings;
    exports2.paginateDescribeHostReservations = paginateDescribeHostReservations;
    exports2.paginateDescribeHosts = paginateDescribeHosts;
    exports2.paginateDescribeIamInstanceProfileAssociations = paginateDescribeIamInstanceProfileAssociations;
    exports2.paginateDescribeImageReferences = paginateDescribeImageReferences;
    exports2.paginateDescribeImageUsageReportEntries = paginateDescribeImageUsageReportEntries;
    exports2.paginateDescribeImageUsageReports = paginateDescribeImageUsageReports;
    exports2.paginateDescribeImages = paginateDescribeImages;
    exports2.paginateDescribeImportImageTasks = paginateDescribeImportImageTasks;
    exports2.paginateDescribeImportSnapshotTasks = paginateDescribeImportSnapshotTasks;
    exports2.paginateDescribeInstanceConnectEndpoints = paginateDescribeInstanceConnectEndpoints;
    exports2.paginateDescribeInstanceCreditSpecifications = paginateDescribeInstanceCreditSpecifications;
    exports2.paginateDescribeInstanceEventWindows = paginateDescribeInstanceEventWindows;
    exports2.paginateDescribeInstanceImageMetadata = paginateDescribeInstanceImageMetadata;
    exports2.paginateDescribeInstanceStatus = paginateDescribeInstanceStatus;
    exports2.paginateDescribeInstanceTopology = paginateDescribeInstanceTopology;
    exports2.paginateDescribeInstanceTypeOfferings = paginateDescribeInstanceTypeOfferings;
    exports2.paginateDescribeInstanceTypes = paginateDescribeInstanceTypes;
    exports2.paginateDescribeInstances = paginateDescribeInstances;
    exports2.paginateDescribeInternetGateways = paginateDescribeInternetGateways;
    exports2.paginateDescribeIpamPools = paginateDescribeIpamPools;
    exports2.paginateDescribeIpamPrefixListResolverTargets = paginateDescribeIpamPrefixListResolverTargets;
    exports2.paginateDescribeIpamPrefixListResolvers = paginateDescribeIpamPrefixListResolvers;
    exports2.paginateDescribeIpamResourceDiscoveries = paginateDescribeIpamResourceDiscoveries;
    exports2.paginateDescribeIpamResourceDiscoveryAssociations = paginateDescribeIpamResourceDiscoveryAssociations;
    exports2.paginateDescribeIpamScopes = paginateDescribeIpamScopes;
    exports2.paginateDescribeIpams = paginateDescribeIpams;
    exports2.paginateDescribeIpv6Pools = paginateDescribeIpv6Pools;
    exports2.paginateDescribeLaunchTemplateVersions = paginateDescribeLaunchTemplateVersions;
    exports2.paginateDescribeLaunchTemplates = paginateDescribeLaunchTemplates;
    exports2.paginateDescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociations = paginateDescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociations;
    exports2.paginateDescribeLocalGatewayRouteTableVpcAssociations = paginateDescribeLocalGatewayRouteTableVpcAssociations;
    exports2.paginateDescribeLocalGatewayRouteTables = paginateDescribeLocalGatewayRouteTables;
    exports2.paginateDescribeLocalGatewayVirtualInterfaceGroups = paginateDescribeLocalGatewayVirtualInterfaceGroups;
    exports2.paginateDescribeLocalGatewayVirtualInterfaces = paginateDescribeLocalGatewayVirtualInterfaces;
    exports2.paginateDescribeLocalGateways = paginateDescribeLocalGateways;
    exports2.paginateDescribeMacHosts = paginateDescribeMacHosts;
    exports2.paginateDescribeMacModificationTasks = paginateDescribeMacModificationTasks;
    exports2.paginateDescribeManagedPrefixLists = paginateDescribeManagedPrefixLists;
    exports2.paginateDescribeMovingAddresses = paginateDescribeMovingAddresses;
    exports2.paginateDescribeNatGateways = paginateDescribeNatGateways;
    exports2.paginateDescribeNetworkAcls = paginateDescribeNetworkAcls;
    exports2.paginateDescribeNetworkInsightsAccessScopeAnalyses = paginateDescribeNetworkInsightsAccessScopeAnalyses;
    exports2.paginateDescribeNetworkInsightsAccessScopes = paginateDescribeNetworkInsightsAccessScopes;
    exports2.paginateDescribeNetworkInsightsAnalyses = paginateDescribeNetworkInsightsAnalyses;
    exports2.paginateDescribeNetworkInsightsPaths = paginateDescribeNetworkInsightsPaths;
    exports2.paginateDescribeNetworkInterfacePermissions = paginateDescribeNetworkInterfacePermissions;
    exports2.paginateDescribeNetworkInterfaces = paginateDescribeNetworkInterfaces;
    exports2.paginateDescribePrefixLists = paginateDescribePrefixLists;
    exports2.paginateDescribePrincipalIdFormat = paginateDescribePrincipalIdFormat;
    exports2.paginateDescribePublicIpv4Pools = paginateDescribePublicIpv4Pools;
    exports2.paginateDescribeReplaceRootVolumeTasks = paginateDescribeReplaceRootVolumeTasks;
    exports2.paginateDescribeReservedInstancesModifications = paginateDescribeReservedInstancesModifications;
    exports2.paginateDescribeReservedInstancesOfferings = paginateDescribeReservedInstancesOfferings;
    exports2.paginateDescribeRouteServerEndpoints = paginateDescribeRouteServerEndpoints;
    exports2.paginateDescribeRouteServerPeers = paginateDescribeRouteServerPeers;
    exports2.paginateDescribeRouteServers = paginateDescribeRouteServers;
    exports2.paginateDescribeRouteTables = paginateDescribeRouteTables;
    exports2.paginateDescribeScheduledInstanceAvailability = paginateDescribeScheduledInstanceAvailability;
    exports2.paginateDescribeScheduledInstances = paginateDescribeScheduledInstances;
    exports2.paginateDescribeSecondaryInterfaces = paginateDescribeSecondaryInterfaces;
    exports2.paginateDescribeSecondaryNetworks = paginateDescribeSecondaryNetworks;
    exports2.paginateDescribeSecondarySubnets = paginateDescribeSecondarySubnets;
    exports2.paginateDescribeSecurityGroupRules = paginateDescribeSecurityGroupRules;
    exports2.paginateDescribeSecurityGroupVpcAssociations = paginateDescribeSecurityGroupVpcAssociations;
    exports2.paginateDescribeSecurityGroups = paginateDescribeSecurityGroups;
    exports2.paginateDescribeSnapshotTierStatus = paginateDescribeSnapshotTierStatus;
    exports2.paginateDescribeSnapshots = paginateDescribeSnapshots;
    exports2.paginateDescribeSpotFleetRequests = paginateDescribeSpotFleetRequests;
    exports2.paginateDescribeSpotInstanceRequests = paginateDescribeSpotInstanceRequests;
    exports2.paginateDescribeSpotPriceHistory = paginateDescribeSpotPriceHistory;
    exports2.paginateDescribeStaleSecurityGroups = paginateDescribeStaleSecurityGroups;
    exports2.paginateDescribeStoreImageTasks = paginateDescribeStoreImageTasks;
    exports2.paginateDescribeSubnets = paginateDescribeSubnets;
    exports2.paginateDescribeTags = paginateDescribeTags;
    exports2.paginateDescribeTrafficMirrorFilters = paginateDescribeTrafficMirrorFilters;
    exports2.paginateDescribeTrafficMirrorSessions = paginateDescribeTrafficMirrorSessions;
    exports2.paginateDescribeTrafficMirrorTargets = paginateDescribeTrafficMirrorTargets;
    exports2.paginateDescribeTransitGatewayAttachments = paginateDescribeTransitGatewayAttachments;
    exports2.paginateDescribeTransitGatewayConnectPeers = paginateDescribeTransitGatewayConnectPeers;
    exports2.paginateDescribeTransitGatewayConnects = paginateDescribeTransitGatewayConnects;
    exports2.paginateDescribeTransitGatewayMulticastDomains = paginateDescribeTransitGatewayMulticastDomains;
    exports2.paginateDescribeTransitGatewayPeeringAttachments = paginateDescribeTransitGatewayPeeringAttachments;
    exports2.paginateDescribeTransitGatewayPolicyTables = paginateDescribeTransitGatewayPolicyTables;
    exports2.paginateDescribeTransitGatewayRouteTableAnnouncements = paginateDescribeTransitGatewayRouteTableAnnouncements;
    exports2.paginateDescribeTransitGatewayRouteTables = paginateDescribeTransitGatewayRouteTables;
    exports2.paginateDescribeTransitGatewayVpcAttachments = paginateDescribeTransitGatewayVpcAttachments;
    exports2.paginateDescribeTransitGateways = paginateDescribeTransitGateways;
    exports2.paginateDescribeTrunkInterfaceAssociations = paginateDescribeTrunkInterfaceAssociations;
    exports2.paginateDescribeVerifiedAccessEndpoints = paginateDescribeVerifiedAccessEndpoints;
    exports2.paginateDescribeVerifiedAccessGroups = paginateDescribeVerifiedAccessGroups;
    exports2.paginateDescribeVerifiedAccessInstanceLoggingConfigurations = paginateDescribeVerifiedAccessInstanceLoggingConfigurations;
    exports2.paginateDescribeVerifiedAccessInstances = paginateDescribeVerifiedAccessInstances;
    exports2.paginateDescribeVerifiedAccessTrustProviders = paginateDescribeVerifiedAccessTrustProviders;
    exports2.paginateDescribeVolumeStatus = paginateDescribeVolumeStatus;
    exports2.paginateDescribeVolumes = paginateDescribeVolumes;
    exports2.paginateDescribeVolumesModifications = paginateDescribeVolumesModifications;
    exports2.paginateDescribeVpcClassicLinkDnsSupport = paginateDescribeVpcClassicLinkDnsSupport;
    exports2.paginateDescribeVpcEndpointConnectionNotifications = paginateDescribeVpcEndpointConnectionNotifications;
    exports2.paginateDescribeVpcEndpointConnections = paginateDescribeVpcEndpointConnections;
    exports2.paginateDescribeVpcEndpointServiceConfigurations = paginateDescribeVpcEndpointServiceConfigurations;
    exports2.paginateDescribeVpcEndpointServicePermissions = paginateDescribeVpcEndpointServicePermissions;
    exports2.paginateDescribeVpcEndpoints = paginateDescribeVpcEndpoints;
    exports2.paginateDescribeVpcPeeringConnections = paginateDescribeVpcPeeringConnections;
    exports2.paginateDescribeVpcs = paginateDescribeVpcs;
    exports2.paginateDescribeVpnConcentrators = paginateDescribeVpnConcentrators;
    exports2.paginateGetAssociatedIpv6PoolCidrs = paginateGetAssociatedIpv6PoolCidrs;
    exports2.paginateGetAwsNetworkPerformanceData = paginateGetAwsNetworkPerformanceData;
    exports2.paginateGetCapacityManagerMetricData = paginateGetCapacityManagerMetricData;
    exports2.paginateGetCapacityManagerMetricDimensions = paginateGetCapacityManagerMetricDimensions;
    exports2.paginateGetCapacityManagerMonitoredTagKeys = paginateGetCapacityManagerMonitoredTagKeys;
    exports2.paginateGetGroupsForCapacityReservation = paginateGetGroupsForCapacityReservation;
    exports2.paginateGetInstanceTypesFromInstanceRequirements = paginateGetInstanceTypesFromInstanceRequirements;
    exports2.paginateGetIpamAddressHistory = paginateGetIpamAddressHistory;
    exports2.paginateGetIpamDiscoveredAccounts = paginateGetIpamDiscoveredAccounts;
    exports2.paginateGetIpamDiscoveredResourceCidrs = paginateGetIpamDiscoveredResourceCidrs;
    exports2.paginateGetIpamPoolAllocations = paginateGetIpamPoolAllocations;
    exports2.paginateGetIpamPoolCidrs = paginateGetIpamPoolCidrs;
    exports2.paginateGetIpamPrefixListResolverRules = paginateGetIpamPrefixListResolverRules;
    exports2.paginateGetIpamPrefixListResolverVersionEntries = paginateGetIpamPrefixListResolverVersionEntries;
    exports2.paginateGetIpamPrefixListResolverVersions = paginateGetIpamPrefixListResolverVersions;
    exports2.paginateGetIpamResourceCidrs = paginateGetIpamResourceCidrs;
    exports2.paginateGetManagedPrefixListAssociations = paginateGetManagedPrefixListAssociations;
    exports2.paginateGetManagedPrefixListEntries = paginateGetManagedPrefixListEntries;
    exports2.paginateGetNetworkInsightsAccessScopeAnalysisFindings = paginateGetNetworkInsightsAccessScopeAnalysisFindings;
    exports2.paginateGetSecurityGroupsForVpc = paginateGetSecurityGroupsForVpc;
    exports2.paginateGetSpotPlacementScores = paginateGetSpotPlacementScores;
    exports2.paginateGetTransitGatewayAttachmentPropagations = paginateGetTransitGatewayAttachmentPropagations;
    exports2.paginateGetTransitGatewayMulticastDomainAssociations = paginateGetTransitGatewayMulticastDomainAssociations;
    exports2.paginateGetTransitGatewayPolicyTableAssociations = paginateGetTransitGatewayPolicyTableAssociations;
    exports2.paginateGetTransitGatewayPrefixListReferences = paginateGetTransitGatewayPrefixListReferences;
    exports2.paginateGetTransitGatewayRouteTableAssociations = paginateGetTransitGatewayRouteTableAssociations;
    exports2.paginateGetTransitGatewayRouteTablePropagations = paginateGetTransitGatewayRouteTablePropagations;
    exports2.paginateGetVpnConnectionDeviceTypes = paginateGetVpnConnectionDeviceTypes;
    exports2.paginateListImagesInRecycleBin = paginateListImagesInRecycleBin;
    exports2.paginateListSnapshotsInRecycleBin = paginateListSnapshotsInRecycleBin;
    exports2.paginateSearchLocalGatewayRoutes = paginateSearchLocalGatewayRoutes;
    exports2.paginateSearchTransitGatewayMulticastGroups = paginateSearchTransitGatewayMulticastGroups;
    exports2.paginateSearchTransitGatewayRoutes = paginateSearchTransitGatewayRoutes;
    exports2.waitForBundleTaskComplete = waitForBundleTaskComplete;
    exports2.waitForConversionTaskCancelled = waitForConversionTaskCancelled;
    exports2.waitForConversionTaskCompleted = waitForConversionTaskCompleted;
    exports2.waitForConversionTaskDeleted = waitForConversionTaskDeleted;
    exports2.waitForCustomerGatewayAvailable = waitForCustomerGatewayAvailable;
    exports2.waitForExportTaskCancelled = waitForExportTaskCancelled;
    exports2.waitForExportTaskCompleted = waitForExportTaskCompleted;
    exports2.waitForImageAvailable = waitForImageAvailable;
    exports2.waitForImageExists = waitForImageExists;
    exports2.waitForImageUsageReportAvailable = waitForImageUsageReportAvailable;
    exports2.waitForInstanceExists = waitForInstanceExists;
    exports2.waitForInstanceRunning = waitForInstanceRunning;
    exports2.waitForInstanceStatusOk = waitForInstanceStatusOk;
    exports2.waitForInstanceStopped = waitForInstanceStopped;
    exports2.waitForInstanceTerminated = waitForInstanceTerminated;
    exports2.waitForInternetGatewayExists = waitForInternetGatewayExists;
    exports2.waitForKeyPairExists = waitForKeyPairExists;
    exports2.waitForNatGatewayAvailable = waitForNatGatewayAvailable;
    exports2.waitForNatGatewayDeleted = waitForNatGatewayDeleted;
    exports2.waitForNetworkInterfaceAvailable = waitForNetworkInterfaceAvailable;
    exports2.waitForPasswordDataAvailable = waitForPasswordDataAvailable;
    exports2.waitForSecondaryNetworkCreateComplete = waitForSecondaryNetworkCreateComplete;
    exports2.waitForSecondaryNetworkDeleteComplete = waitForSecondaryNetworkDeleteComplete;
    exports2.waitForSecondarySubnetCreateComplete = waitForSecondarySubnetCreateComplete;
    exports2.waitForSecondarySubnetDeleteComplete = waitForSecondarySubnetDeleteComplete;
    exports2.waitForSecurityGroupExists = waitForSecurityGroupExists;
    exports2.waitForSecurityGroupVpcAssociationAssociated = waitForSecurityGroupVpcAssociationAssociated;
    exports2.waitForSecurityGroupVpcAssociationDisassociated = waitForSecurityGroupVpcAssociationDisassociated;
    exports2.waitForSnapshotCompleted = waitForSnapshotCompleted;
    exports2.waitForSnapshotImported = waitForSnapshotImported;
    exports2.waitForSpotInstanceRequestFulfilled = waitForSpotInstanceRequestFulfilled;
    exports2.waitForStoreImageTaskComplete = waitForStoreImageTaskComplete;
    exports2.waitForSubnetAvailable = waitForSubnetAvailable;
    exports2.waitForSystemStatusOk = waitForSystemStatusOk;
    exports2.waitForVolumeAvailable = waitForVolumeAvailable;
    exports2.waitForVolumeDeleted = waitForVolumeDeleted;
    exports2.waitForVolumeInUse = waitForVolumeInUse;
    exports2.waitForVpcAvailable = waitForVpcAvailable;
    exports2.waitForVpcExists = waitForVpcExists;
    exports2.waitForVpcPeeringConnectionDeleted = waitForVpcPeeringConnectionDeleted;
    exports2.waitForVpcPeeringConnectionExists = waitForVpcPeeringConnectionExists;
    exports2.waitForVpnConnectionAvailable = waitForVpnConnectionAvailable;
    exports2.waitForVpnConnectionDeleted = waitForVpnConnectionDeleted;
    exports2.waitUntilBundleTaskComplete = waitUntilBundleTaskComplete;
    exports2.waitUntilConversionTaskCancelled = waitUntilConversionTaskCancelled;
    exports2.waitUntilConversionTaskCompleted = waitUntilConversionTaskCompleted;
    exports2.waitUntilConversionTaskDeleted = waitUntilConversionTaskDeleted;
    exports2.waitUntilCustomerGatewayAvailable = waitUntilCustomerGatewayAvailable;
    exports2.waitUntilExportTaskCancelled = waitUntilExportTaskCancelled;
    exports2.waitUntilExportTaskCompleted = waitUntilExportTaskCompleted;
    exports2.waitUntilImageAvailable = waitUntilImageAvailable;
    exports2.waitUntilImageExists = waitUntilImageExists;
    exports2.waitUntilImageUsageReportAvailable = waitUntilImageUsageReportAvailable;
    exports2.waitUntilInstanceExists = waitUntilInstanceExists;
    exports2.waitUntilInstanceRunning = waitUntilInstanceRunning;
    exports2.waitUntilInstanceStatusOk = waitUntilInstanceStatusOk;
    exports2.waitUntilInstanceStopped = waitUntilInstanceStopped;
    exports2.waitUntilInstanceTerminated = waitUntilInstanceTerminated;
    exports2.waitUntilInternetGatewayExists = waitUntilInternetGatewayExists;
    exports2.waitUntilKeyPairExists = waitUntilKeyPairExists;
    exports2.waitUntilNatGatewayAvailable = waitUntilNatGatewayAvailable;
    exports2.waitUntilNatGatewayDeleted = waitUntilNatGatewayDeleted;
    exports2.waitUntilNetworkInterfaceAvailable = waitUntilNetworkInterfaceAvailable;
    exports2.waitUntilPasswordDataAvailable = waitUntilPasswordDataAvailable;
    exports2.waitUntilSecondaryNetworkCreateComplete = waitUntilSecondaryNetworkCreateComplete;
    exports2.waitUntilSecondaryNetworkDeleteComplete = waitUntilSecondaryNetworkDeleteComplete;
    exports2.waitUntilSecondarySubnetCreateComplete = waitUntilSecondarySubnetCreateComplete;
    exports2.waitUntilSecondarySubnetDeleteComplete = waitUntilSecondarySubnetDeleteComplete;
    exports2.waitUntilSecurityGroupExists = waitUntilSecurityGroupExists;
    exports2.waitUntilSecurityGroupVpcAssociationAssociated = waitUntilSecurityGroupVpcAssociationAssociated;
    exports2.waitUntilSecurityGroupVpcAssociationDisassociated = waitUntilSecurityGroupVpcAssociationDisassociated;
    exports2.waitUntilSnapshotCompleted = waitUntilSnapshotCompleted;
    exports2.waitUntilSnapshotImported = waitUntilSnapshotImported;
    exports2.waitUntilSpotInstanceRequestFulfilled = waitUntilSpotInstanceRequestFulfilled;
    exports2.waitUntilStoreImageTaskComplete = waitUntilStoreImageTaskComplete;
    exports2.waitUntilSubnetAvailable = waitUntilSubnetAvailable;
    exports2.waitUntilSystemStatusOk = waitUntilSystemStatusOk;
    exports2.waitUntilVolumeAvailable = waitUntilVolumeAvailable;
    exports2.waitUntilVolumeDeleted = waitUntilVolumeDeleted;
    exports2.waitUntilVolumeInUse = waitUntilVolumeInUse;
    exports2.waitUntilVpcAvailable = waitUntilVpcAvailable;
    exports2.waitUntilVpcExists = waitUntilVpcExists;
    exports2.waitUntilVpcPeeringConnectionDeleted = waitUntilVpcPeeringConnectionDeleted;
    exports2.waitUntilVpcPeeringConnectionExists = waitUntilVpcPeeringConnectionExists;
    exports2.waitUntilVpnConnectionAvailable = waitUntilVpnConnectionAvailable;
    exports2.waitUntilVpnConnectionDeleted = waitUntilVpnConnectionDeleted;
    Object.prototype.hasOwnProperty.call(schemas_0, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: schemas_0["__proto__"]
    });
    Object.keys(schemas_0).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = schemas_0[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-ecs/dist-cjs/auth/httpAuthSchemeProvider.js
var require_httpAuthSchemeProvider12 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecs/dist-cjs/auth/httpAuthSchemeProvider.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.resolveHttpAuthSchemeConfig = exports2.defaultECSHttpAuthSchemeProvider = exports2.defaultECSHttpAuthSchemeParametersProvider = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var util_middleware_1 = require_dist_cjs6();
    var defaultECSHttpAuthSchemeParametersProvider = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, util_middleware_1.getSmithyContext)(context).operation,
        region: await (0, util_middleware_1.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultECSHttpAuthSchemeParametersProvider");
    exports2.defaultECSHttpAuthSchemeParametersProvider = defaultECSHttpAuthSchemeParametersProvider;
    function createAwsAuthSigv4HttpAuthOption32(authParameters) {
      return {
        schemeId: "aws.auth#sigv4",
        signingProperties: {
          name: "ecs",
          region: authParameters.region
        },
        propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
          signingProperties: {
            config: config2,
            context
          }
        }), "propertiesExtractor")
      };
    }
    __name(createAwsAuthSigv4HttpAuthOption32, "createAwsAuthSigv4HttpAuthOption");
    var defaultECSHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption32(authParameters));
        }
      }
      return options;
    }, "defaultECSHttpAuthSchemeProvider");
    exports2.defaultECSHttpAuthSchemeProvider = defaultECSHttpAuthSchemeProvider;
    var resolveHttpAuthSchemeConfig32 = /* @__PURE__ */ __name((config2) => {
      const config_0 = (0, httpAuthSchemes_1.resolveAwsSdkSigV4Config)(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, util_middleware_1.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
    exports2.resolveHttpAuthSchemeConfig = resolveHttpAuthSchemeConfig32;
  }
});

// ../../node_modules/@aws-sdk/client-ecs/package.json
var require_package12 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecs/package.json"(exports2, module2) {
    module2.exports = {
      name: "@aws-sdk/client-ecs",
      description: "AWS SDK for JavaScript Ecs Client for Node.js, Browser and React Native",
      version: "3.1036.0",
      scripts: {
        build: "concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline client-ecs",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        "extract:docs": "api-extractor run --local",
        "generate:client": "node ../../scripts/generate-clients/single-service --solo ecs",
        "test:e2e": "yarn g:vitest run -c vitest.config.e2e.mts --mode development",
        "test:e2e:watch": "yarn g:vitest watch -c vitest.config.e2e.mts",
        "test:index": "tsc --noEmit ./test/index-types.ts && node ./test/index-objects.spec.mjs"
      },
      main: "./dist-cjs/index.js",
      types: "./dist-types/index.d.ts",
      module: "./dist-es/index.js",
      sideEffects: false,
      dependencies: {
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.5",
        "@aws-sdk/credential-provider-node": "^3.972.36",
        "@aws-sdk/middleware-host-header": "^3.972.10",
        "@aws-sdk/middleware-logger": "^3.972.10",
        "@aws-sdk/middleware-recursion-detection": "^3.972.11",
        "@aws-sdk/middleware-user-agent": "^3.972.35",
        "@aws-sdk/region-config-resolver": "^3.972.13",
        "@aws-sdk/types": "^3.973.8",
        "@aws-sdk/util-endpoints": "^3.996.8",
        "@aws-sdk/util-user-agent-browser": "^3.972.10",
        "@aws-sdk/util-user-agent-node": "^3.973.21",
        "@smithy/config-resolver": "^4.4.17",
        "@smithy/core": "^3.23.17",
        "@smithy/fetch-http-handler": "^5.3.17",
        "@smithy/hash-node": "^4.2.14",
        "@smithy/invalid-dependency": "^4.2.14",
        "@smithy/middleware-content-length": "^4.2.14",
        "@smithy/middleware-endpoint": "^4.4.32",
        "@smithy/middleware-retry": "^4.5.5",
        "@smithy/middleware-serde": "^4.2.20",
        "@smithy/middleware-stack": "^4.2.14",
        "@smithy/node-config-provider": "^4.3.14",
        "@smithy/node-http-handler": "^4.6.1",
        "@smithy/protocol-http": "^5.3.14",
        "@smithy/smithy-client": "^4.12.13",
        "@smithy/types": "^4.14.1",
        "@smithy/url-parser": "^4.2.14",
        "@smithy/util-base64": "^4.3.2",
        "@smithy/util-body-length-browser": "^4.2.2",
        "@smithy/util-body-length-node": "^4.2.3",
        "@smithy/util-defaults-mode-browser": "^4.3.49",
        "@smithy/util-defaults-mode-node": "^4.2.54",
        "@smithy/util-endpoints": "^3.4.2",
        "@smithy/util-middleware": "^4.2.14",
        "@smithy/util-retry": "^4.3.4",
        "@smithy/util-utf8": "^4.2.2",
        "@smithy/util-waiter": "^4.2.16",
        tslib: "^2.6.2"
      },
      devDependencies: {
        "@tsconfig/node20": "20.1.8",
        "@types/node": "^20.14.8",
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3"
      },
      engines: {
        node: ">=20.0.0"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "dist-*/**"
      ],
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      browser: {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.browser"
      },
      "react-native": {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.native"
      },
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/clients/client-ecs",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "clients/client-ecs"
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ecs/dist-cjs/endpoint/bdd.js
var require_bdd12 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecs/dist-cjs/endpoint/bdd.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.bdd = void 0;
    var util_endpoints_1 = require_dist_cjs20();
    var k32 = "ref";
    var a32 = -1;
    var b32 = true;
    var c32 = "isSet";
    var d32 = "PartitionResult";
    var e32 = "booleanEquals";
    var f32 = "getAttr";
    var g32 = { [k32]: "Endpoint" };
    var h32 = { [k32]: d32 };
    var i32 = {};
    var j32 = [{ [k32]: "Region" }];
    var _data32 = {
      conditions: [
        [c32, [g32]],
        [c32, j32],
        ["aws.partition", j32, d32],
        [e32, [{ [k32]: "UseFIPS" }, b32]],
        [e32, [{ [k32]: "UseDualStack" }, b32]],
        [e32, [{ fn: f32, argv: [h32, "supportsDualStack"] }, b32]],
        [e32, [{ fn: f32, argv: [h32, "supportsFIPS"] }, b32]]
      ],
      results: [
        [a32],
        [a32, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a32, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [g32, i32],
        ["https://ecs-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", i32],
        [a32, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://ecs-fips.{Region}.{PartitionResult#dnsSuffix}", i32],
        [a32, "FIPS is enabled but this partition does not support FIPS"],
        ["https://ecs.{Region}.{PartitionResult#dualStackDnsSuffix}", i32],
        [a32, "DualStack is enabled but this partition does not support DualStack"],
        ["https://ecs.{Region}.{PartitionResult#dnsSuffix}", i32],
        [a32, "Invalid Configuration: Missing Region"]
      ]
    };
    var root32 = 2;
    var r32 = 1e8;
    var nodes32 = new Int32Array([
      -1,
      1,
      -1,
      0,
      12,
      3,
      1,
      4,
      r32 + 11,
      2,
      5,
      r32 + 11,
      3,
      8,
      6,
      4,
      7,
      r32 + 10,
      5,
      r32 + 8,
      r32 + 9,
      4,
      10,
      9,
      6,
      r32 + 6,
      r32 + 7,
      5,
      11,
      r32 + 5,
      6,
      r32 + 4,
      r32 + 5,
      3,
      r32 + 1,
      13,
      4,
      r32 + 2,
      r32 + 3
    ]);
    exports2.bdd = util_endpoints_1.BinaryDecisionDiagram.from(nodes32, root32, _data32.conditions, _data32.results);
  }
});

// ../../node_modules/@aws-sdk/client-ecs/dist-cjs/endpoint/endpointResolver.js
var require_endpointResolver12 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecs/dist-cjs/endpoint/endpointResolver.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.defaultEndpointResolver = void 0;
    var util_endpoints_1 = require_dist_cjs21();
    var util_endpoints_2 = require_dist_cjs20();
    var bdd_1 = require_bdd12();
    var cache32 = new util_endpoints_2.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    var defaultEndpointResolver32 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache32.get(endpointParams, () => (0, util_endpoints_2.decideEndpoint)(bdd_1.bdd, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    exports2.defaultEndpointResolver = defaultEndpointResolver32;
    util_endpoints_2.customEndpointFunctions.aws = util_endpoints_1.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-ecs/dist-cjs/models/ECSServiceException.js
var require_ECSServiceException = __commonJS({
  "../../node_modules/@aws-sdk/client-ecs/dist-cjs/models/ECSServiceException.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ECSServiceException = exports2.__ServiceException = void 0;
    var smithy_client_1 = require_dist_cjs34();
    Object.defineProperty(exports2, "__ServiceException", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return smithy_client_1.ServiceException;
    }, "get") });
    var ECSServiceException = class _ECSServiceException extends smithy_client_1.ServiceException {
      static {
        __name(this, "ECSServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _ECSServiceException.prototype);
      }
    };
    exports2.ECSServiceException = ECSServiceException;
  }
});

// ../../node_modules/@aws-sdk/client-ecs/dist-cjs/models/errors.js
var require_errors11 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecs/dist-cjs/models/errors.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.BlockedException = exports2.TaskSetNotFoundException = exports2.ServiceDeploymentNotFoundException = exports2.ConflictException = exports2.ResourceNotFoundException = exports2.ServiceNotActiveException = exports2.PlatformTaskDefinitionIncompatibilityException = exports2.DaemonNotFoundException = exports2.DaemonNotActiveException = exports2.PlatformUnknownException = exports2.NoUpdateAvailableException = exports2.MissingVersionException = exports2.AttributeLimitExceededException = exports2.ServiceNotFoundException = exports2.TargetNotFoundException = exports2.ResourceInUseException = exports2.TargetNotConnectedException = exports2.ClusterContainsTasksException = exports2.ClusterContainsServicesException = exports2.ClusterContainsContainerInstancesException = exports2.ClusterContainsCapacityProviderException = exports2.NamespaceNotFoundException = exports2.UpdateInProgressException = exports2.UnsupportedFeatureException = exports2.ServerException = exports2.LimitExceededException = exports2.InvalidParameterException = exports2.ClusterNotFoundException = exports2.ClientException = exports2.AccessDeniedException = void 0;
    var ECSServiceException_1 = require_ECSServiceException();
    var AccessDeniedException13 = class _AccessDeniedException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "AccessDeniedException");
      }
      name = "AccessDeniedException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "AccessDeniedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AccessDeniedException.prototype);
      }
    };
    exports2.AccessDeniedException = AccessDeniedException13;
    var ClientException = class _ClientException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "ClientException");
      }
      name = "ClientException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ClientException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ClientException.prototype);
      }
    };
    exports2.ClientException = ClientException;
    var ClusterNotFoundException = class _ClusterNotFoundException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "ClusterNotFoundException");
      }
      name = "ClusterNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ClusterNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ClusterNotFoundException.prototype);
      }
    };
    exports2.ClusterNotFoundException = ClusterNotFoundException;
    var InvalidParameterException2 = class _InvalidParameterException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "InvalidParameterException");
      }
      name = "InvalidParameterException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidParameterException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidParameterException.prototype);
      }
    };
    exports2.InvalidParameterException = InvalidParameterException2;
    var LimitExceededException2 = class _LimitExceededException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "LimitExceededException");
      }
      name = "LimitExceededException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "LimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _LimitExceededException.prototype);
      }
    };
    exports2.LimitExceededException = LimitExceededException2;
    var ServerException = class _ServerException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "ServerException");
      }
      name = "ServerException";
      $fault = "server";
      constructor(opts) {
        super({
          name: "ServerException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _ServerException.prototype);
      }
    };
    exports2.ServerException = ServerException;
    var UnsupportedFeatureException = class _UnsupportedFeatureException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "UnsupportedFeatureException");
      }
      name = "UnsupportedFeatureException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "UnsupportedFeatureException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnsupportedFeatureException.prototype);
      }
    };
    exports2.UnsupportedFeatureException = UnsupportedFeatureException;
    var UpdateInProgressException = class _UpdateInProgressException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "UpdateInProgressException");
      }
      name = "UpdateInProgressException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "UpdateInProgressException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UpdateInProgressException.prototype);
      }
    };
    exports2.UpdateInProgressException = UpdateInProgressException;
    var NamespaceNotFoundException = class _NamespaceNotFoundException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "NamespaceNotFoundException");
      }
      name = "NamespaceNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "NamespaceNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _NamespaceNotFoundException.prototype);
      }
    };
    exports2.NamespaceNotFoundException = NamespaceNotFoundException;
    var ClusterContainsCapacityProviderException = class _ClusterContainsCapacityProviderException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "ClusterContainsCapacityProviderException");
      }
      name = "ClusterContainsCapacityProviderException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ClusterContainsCapacityProviderException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ClusterContainsCapacityProviderException.prototype);
      }
    };
    exports2.ClusterContainsCapacityProviderException = ClusterContainsCapacityProviderException;
    var ClusterContainsContainerInstancesException = class _ClusterContainsContainerInstancesException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "ClusterContainsContainerInstancesException");
      }
      name = "ClusterContainsContainerInstancesException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ClusterContainsContainerInstancesException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ClusterContainsContainerInstancesException.prototype);
      }
    };
    exports2.ClusterContainsContainerInstancesException = ClusterContainsContainerInstancesException;
    var ClusterContainsServicesException = class _ClusterContainsServicesException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "ClusterContainsServicesException");
      }
      name = "ClusterContainsServicesException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ClusterContainsServicesException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ClusterContainsServicesException.prototype);
      }
    };
    exports2.ClusterContainsServicesException = ClusterContainsServicesException;
    var ClusterContainsTasksException = class _ClusterContainsTasksException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "ClusterContainsTasksException");
      }
      name = "ClusterContainsTasksException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ClusterContainsTasksException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ClusterContainsTasksException.prototype);
      }
    };
    exports2.ClusterContainsTasksException = ClusterContainsTasksException;
    var TargetNotConnectedException = class _TargetNotConnectedException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "TargetNotConnectedException");
      }
      name = "TargetNotConnectedException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TargetNotConnectedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TargetNotConnectedException.prototype);
      }
    };
    exports2.TargetNotConnectedException = TargetNotConnectedException;
    var ResourceInUseException = class _ResourceInUseException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "ResourceInUseException");
      }
      name = "ResourceInUseException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ResourceInUseException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceInUseException.prototype);
      }
    };
    exports2.ResourceInUseException = ResourceInUseException;
    var TargetNotFoundException = class _TargetNotFoundException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "TargetNotFoundException");
      }
      name = "TargetNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TargetNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TargetNotFoundException.prototype);
      }
    };
    exports2.TargetNotFoundException = TargetNotFoundException;
    var ServiceNotFoundException = class _ServiceNotFoundException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "ServiceNotFoundException");
      }
      name = "ServiceNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ServiceNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ServiceNotFoundException.prototype);
      }
    };
    exports2.ServiceNotFoundException = ServiceNotFoundException;
    var AttributeLimitExceededException = class _AttributeLimitExceededException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "AttributeLimitExceededException");
      }
      name = "AttributeLimitExceededException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "AttributeLimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AttributeLimitExceededException.prototype);
      }
    };
    exports2.AttributeLimitExceededException = AttributeLimitExceededException;
    var MissingVersionException = class _MissingVersionException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "MissingVersionException");
      }
      name = "MissingVersionException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "MissingVersionException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _MissingVersionException.prototype);
      }
    };
    exports2.MissingVersionException = MissingVersionException;
    var NoUpdateAvailableException = class _NoUpdateAvailableException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "NoUpdateAvailableException");
      }
      name = "NoUpdateAvailableException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "NoUpdateAvailableException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _NoUpdateAvailableException.prototype);
      }
    };
    exports2.NoUpdateAvailableException = NoUpdateAvailableException;
    var PlatformUnknownException = class _PlatformUnknownException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "PlatformUnknownException");
      }
      name = "PlatformUnknownException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "PlatformUnknownException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _PlatformUnknownException.prototype);
      }
    };
    exports2.PlatformUnknownException = PlatformUnknownException;
    var DaemonNotActiveException = class _DaemonNotActiveException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "DaemonNotActiveException");
      }
      name = "DaemonNotActiveException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "DaemonNotActiveException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DaemonNotActiveException.prototype);
      }
    };
    exports2.DaemonNotActiveException = DaemonNotActiveException;
    var DaemonNotFoundException = class _DaemonNotFoundException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "DaemonNotFoundException");
      }
      name = "DaemonNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "DaemonNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DaemonNotFoundException.prototype);
      }
    };
    exports2.DaemonNotFoundException = DaemonNotFoundException;
    var PlatformTaskDefinitionIncompatibilityException = class _PlatformTaskDefinitionIncompatibilityException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "PlatformTaskDefinitionIncompatibilityException");
      }
      name = "PlatformTaskDefinitionIncompatibilityException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "PlatformTaskDefinitionIncompatibilityException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _PlatformTaskDefinitionIncompatibilityException.prototype);
      }
    };
    exports2.PlatformTaskDefinitionIncompatibilityException = PlatformTaskDefinitionIncompatibilityException;
    var ServiceNotActiveException = class _ServiceNotActiveException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "ServiceNotActiveException");
      }
      name = "ServiceNotActiveException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ServiceNotActiveException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ServiceNotActiveException.prototype);
      }
    };
    exports2.ServiceNotActiveException = ServiceNotActiveException;
    var ResourceNotFoundException12 = class _ResourceNotFoundException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "ResourceNotFoundException");
      }
      name = "ResourceNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ResourceNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceNotFoundException.prototype);
      }
    };
    exports2.ResourceNotFoundException = ResourceNotFoundException12;
    var ConflictException = class _ConflictException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "ConflictException");
      }
      name = "ConflictException";
      $fault = "client";
      resourceIds;
      constructor(opts) {
        super({
          name: "ConflictException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ConflictException.prototype);
        this.resourceIds = opts.resourceIds;
      }
    };
    exports2.ConflictException = ConflictException;
    var ServiceDeploymentNotFoundException = class _ServiceDeploymentNotFoundException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "ServiceDeploymentNotFoundException");
      }
      name = "ServiceDeploymentNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ServiceDeploymentNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ServiceDeploymentNotFoundException.prototype);
      }
    };
    exports2.ServiceDeploymentNotFoundException = ServiceDeploymentNotFoundException;
    var TaskSetNotFoundException = class _TaskSetNotFoundException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "TaskSetNotFoundException");
      }
      name = "TaskSetNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TaskSetNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TaskSetNotFoundException.prototype);
      }
    };
    exports2.TaskSetNotFoundException = TaskSetNotFoundException;
    var BlockedException = class _BlockedException extends ECSServiceException_1.ECSServiceException {
      static {
        __name(this, "BlockedException");
      }
      name = "BlockedException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "BlockedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _BlockedException.prototype);
      }
    };
    exports2.BlockedException = BlockedException;
  }
});

// ../../node_modules/@aws-sdk/client-ecs/dist-cjs/schemas/schemas_0.js
var require_schemas_012 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecs/dist-cjs/schemas/schemas_0.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ClusterServiceConnectDefaults$ = exports2.ClusterConfiguration$ = exports2.Cluster$ = exports2.CapacityReservationRequest$ = exports2.CapacityProviderStrategyItem$ = exports2.CapacityProvider$ = exports2.CanaryConfiguration$ = exports2.BaselineEbsBandwidthMbpsRequest$ = exports2.AwsVpcConfiguration$ = exports2.AutoScalingGroupProviderUpdate$ = exports2.AutoScalingGroupProvider$ = exports2.AutoRepairConfiguration$ = exports2.Attribute$ = exports2.AttachmentStateChange$ = exports2.Attachment$ = exports2.AdvancedConfiguration$ = exports2.AcceleratorTotalMemoryMiBRequest$ = exports2.AcceleratorCountRequest$ = exports2.errorTypeRegistries = exports2.UpdateInProgressException$ = exports2.UnsupportedFeatureException$ = exports2.TaskSetNotFoundException$ = exports2.TargetNotFoundException$ = exports2.TargetNotConnectedException$ = exports2.ServiceNotFoundException$ = exports2.ServiceNotActiveException$ = exports2.ServiceDeploymentNotFoundException$ = exports2.ServerException$ = exports2.ResourceNotFoundException$ = exports2.ResourceInUseException$ = exports2.PlatformUnknownException$ = exports2.PlatformTaskDefinitionIncompatibilityException$ = exports2.NoUpdateAvailableException$ = exports2.NamespaceNotFoundException$ = exports2.MissingVersionException$ = exports2.LimitExceededException$ = exports2.InvalidParameterException$ = exports2.DaemonNotFoundException$ = exports2.DaemonNotActiveException$ = exports2.ConflictException$ = exports2.ClusterNotFoundException$ = exports2.ClusterContainsTasksException$ = exports2.ClusterContainsServicesException$ = exports2.ClusterContainsContainerInstancesException$ = exports2.ClusterContainsCapacityProviderException$ = exports2.ClientException$ = exports2.BlockedException$ = exports2.AttributeLimitExceededException$ = exports2.AccessDeniedException$ = exports2.ECSServiceException$ = void 0;
    exports2.DeleteCapacityProviderRequest$ = exports2.DeleteAttributesResponse$ = exports2.DeleteAttributesRequest$ = exports2.DeleteAccountSettingResponse$ = exports2.DeleteAccountSettingRequest$ = exports2.DaemonVolume$ = exports2.DaemonTaskDefinitionSummary$ = exports2.DaemonTaskDefinition$ = exports2.DaemonSummary$ = exports2.DaemonRollback$ = exports2.DaemonRevisionDetail$ = exports2.DaemonRevision$ = exports2.DaemonLinuxParameters$ = exports2.DaemonDetail$ = exports2.DaemonDeploymentSummary$ = exports2.DaemonDeploymentRevisionDetail$ = exports2.DaemonDeploymentConfiguration$ = exports2.DaemonDeploymentCapacityProvider$ = exports2.DaemonDeploymentAlarms$ = exports2.DaemonDeployment$ = exports2.DaemonContainerImage$ = exports2.DaemonContainerDefinition$ = exports2.DaemonCircuitBreaker$ = exports2.DaemonCapacityProvider$ = exports2.DaemonAlarmConfiguration$ = exports2.CreateTaskSetResponse$ = exports2.CreateTaskSetRequest$ = exports2.CreateServiceResponse$ = exports2.CreateServiceRequest$ = exports2.CreateManagedInstancesProviderConfiguration$ = exports2.CreateExpressGatewayServiceResponse$ = exports2.CreateExpressGatewayServiceRequest$ = exports2.CreatedAt$ = exports2.CreateDaemonResponse$ = exports2.CreateDaemonRequest$ = exports2.CreateClusterResponse$ = exports2.CreateClusterRequest$ = exports2.CreateCapacityProviderResponse$ = exports2.CreateCapacityProviderRequest$ = exports2.ContainerStateChange$ = exports2.ContainerRestartPolicy$ = exports2.ContainerOverride$ = exports2.ContainerInstanceHealthStatus$ = exports2.ContainerInstance$ = exports2.ContainerImage$ = exports2.ContainerDependency$ = exports2.ContainerDefinition$ = exports2.Container$ = exports2.ClusterSetting$ = exports2.ClusterServiceConnectDefaultsRequest$ = void 0;
    exports2.DescribeTaskDefinitionResponse$ = exports2.DescribeTaskDefinitionRequest$ = exports2.DescribeServicesResponse$ = exports2.DescribeServicesRequest$ = exports2.DescribeServiceRevisionsResponse$ = exports2.DescribeServiceRevisionsRequest$ = exports2.DescribeServiceDeploymentsResponse$ = exports2.DescribeServiceDeploymentsRequest$ = exports2.DescribeExpressGatewayServiceResponse$ = exports2.DescribeExpressGatewayServiceRequest$ = exports2.DescribeDaemonTaskDefinitionResponse$ = exports2.DescribeDaemonTaskDefinitionRequest$ = exports2.DescribeDaemonRevisionsResponse$ = exports2.DescribeDaemonRevisionsRequest$ = exports2.DescribeDaemonResponse$ = exports2.DescribeDaemonRequest$ = exports2.DescribeDaemonDeploymentsResponse$ = exports2.DescribeDaemonDeploymentsRequest$ = exports2.DescribeContainerInstancesResponse$ = exports2.DescribeContainerInstancesRequest$ = exports2.DescribeClustersResponse$ = exports2.DescribeClustersRequest$ = exports2.DescribeCapacityProvidersResponse$ = exports2.DescribeCapacityProvidersRequest$ = exports2.DeregisterTaskDefinitionResponse$ = exports2.DeregisterTaskDefinitionRequest$ = exports2.DeregisterContainerInstanceResponse$ = exports2.DeregisterContainerInstanceRequest$ = exports2.DeploymentLifecycleHook$ = exports2.DeploymentEphemeralStorage$ = exports2.DeploymentController$ = exports2.DeploymentConfiguration$ = exports2.DeploymentCircuitBreaker$ = exports2.DeploymentAlarms$ = exports2.Deployment$ = exports2.DeleteTaskSetResponse$ = exports2.DeleteTaskSetRequest$ = exports2.DeleteTaskDefinitionsResponse$ = exports2.DeleteTaskDefinitionsRequest$ = exports2.DeleteServiceResponse$ = exports2.DeleteServiceRequest$ = exports2.DeleteExpressGatewayServiceResponse$ = exports2.DeleteExpressGatewayServiceRequest$ = exports2.DeleteDaemonTaskDefinitionResponse$ = exports2.DeleteDaemonTaskDefinitionRequest$ = exports2.DeleteDaemonResponse$ = exports2.DeleteDaemonRequest$ = exports2.DeleteClusterResponse$ = exports2.DeleteClusterRequest$ = exports2.DeleteCapacityProviderResponse$ = void 0;
    exports2.ListAttributesRequest$ = exports2.ListAccountSettingsResponse$ = exports2.ListAccountSettingsRequest$ = exports2.LinuxParameters$ = exports2.LinearConfiguration$ = exports2.KeyValuePair$ = exports2.KernelCapabilities$ = exports2.InstanceRequirementsRequest$ = exports2.InstanceLaunchTemplateUpdate$ = exports2.InstanceLaunchTemplate$ = exports2.InstanceHealthCheckResult$ = exports2.IngressPathSummary$ = exports2.InfrastructureOptimization$ = exports2.InferenceAcceleratorOverride$ = exports2.InferenceAccelerator$ = exports2.HostVolumeProperties$ = exports2.HostEntry$ = exports2.HealthCheck$ = exports2.GetTaskProtectionResponse$ = exports2.GetTaskProtectionRequest$ = exports2.FSxWindowsFileServerVolumeConfiguration$ = exports2.FSxWindowsFileServerAuthorizationConfig$ = exports2.FirelensConfiguration$ = exports2.Failure$ = exports2.ExpressGatewayServiceStatus$ = exports2.ExpressGatewayServiceNetworkConfiguration$ = exports2.ExpressGatewayServiceConfiguration$ = exports2.ExpressGatewayServiceAwsLogsConfiguration$ = exports2.ExpressGatewayScalingTarget$ = exports2.ExpressGatewayRepositoryCredentials$ = exports2.ExpressGatewayContainer$ = exports2.ExecuteCommandResponse$ = exports2.ExecuteCommandRequest$ = exports2.ExecuteCommandLogConfiguration$ = exports2.ExecuteCommandConfiguration$ = exports2.EphemeralStorage$ = exports2.EnvironmentFile$ = exports2.EFSVolumeConfiguration$ = exports2.EFSAuthorizationConfig$ = exports2.ECSManagedResources$ = exports2.ECSExpressGatewayService$ = exports2.EBSTagSpecification$ = exports2.DockerVolumeConfiguration$ = exports2.DiscoverPollEndpointResponse$ = exports2.DiscoverPollEndpointRequest$ = exports2.Device$ = exports2.DescribeTasksResponse$ = exports2.DescribeTasksRequest$ = exports2.DescribeTaskSetsResponse$ = exports2.DescribeTaskSetsRequest$ = void 0;
    exports2.MountPoint$ = exports2.MemoryMiBRequest$ = exports2.MemoryGiBPerVCpuRequest$ = exports2.ManagedTargetGroup$ = exports2.ManagedStorageConfiguration$ = exports2.ManagedSecurityGroup$ = exports2.ManagedScaling$ = exports2.ManagedScalableTarget$ = exports2.ManagedMetricAlarm$ = exports2.ManagedLogGroup$ = exports2.ManagedLoadBalancer$ = exports2.ManagedListenerRule$ = exports2.ManagedListener$ = exports2.ManagedInstancesStorageConfiguration$ = exports2.ManagedInstancesProvider$ = exports2.ManagedInstancesNetworkConfiguration$ = exports2.ManagedInstancesLocalStorageConfiguration$ = exports2.ManagedIngressPath$ = exports2.ManagedCertificate$ = exports2.ManagedAutoScaling$ = exports2.ManagedApplicationAutoScalingPolicy$ = exports2.ManagedAgentStateChange$ = exports2.ManagedAgent$ = exports2.LogConfiguration$ = exports2.LoadBalancer$ = exports2.ListTasksResponse$ = exports2.ListTasksRequest$ = exports2.ListTaskDefinitionsResponse$ = exports2.ListTaskDefinitionsRequest$ = exports2.ListTaskDefinitionFamiliesResponse$ = exports2.ListTaskDefinitionFamiliesRequest$ = exports2.ListTagsForResourceResponse$ = exports2.ListTagsForResourceRequest$ = exports2.ListServicesResponse$ = exports2.ListServicesRequest$ = exports2.ListServicesByNamespaceResponse$ = exports2.ListServicesByNamespaceRequest$ = exports2.ListServiceDeploymentsResponse$ = exports2.ListServiceDeploymentsRequest$ = exports2.ListDaemonTaskDefinitionsResponse$ = exports2.ListDaemonTaskDefinitionsRequest$ = exports2.ListDaemonsResponse$ = exports2.ListDaemonsRequest$ = exports2.ListDaemonDeploymentsResponse$ = exports2.ListDaemonDeploymentsRequest$ = exports2.ListContainerInstancesResponse$ = exports2.ListContainerInstancesRequest$ = exports2.ListClustersResponse$ = exports2.ListClustersRequest$ = exports2.ListAttributesResponse$ = void 0;
    exports2.ServiceDeploymentAlarms$ = exports2.ServiceDeployment$ = exports2.ServiceCurrentRevisionSummary$ = exports2.ServiceConnectTlsConfiguration$ = exports2.ServiceConnectTlsCertificateAuthority$ = exports2.ServiceConnectTestTrafficRules$ = exports2.ServiceConnectTestTrafficHeaderRules$ = exports2.ServiceConnectTestTrafficHeaderMatchRules$ = exports2.ServiceConnectServiceResource$ = exports2.ServiceConnectService$ = exports2.ServiceConnectConfiguration$ = exports2.ServiceConnectClientAlias$ = exports2.ServiceConnectAccessLogConfiguration$ = exports2.Service$ = exports2.Secret$ = exports2.Scale$ = exports2.S3FilesVolumeConfiguration$ = exports2.RuntimePlatform$ = exports2.RunTaskResponse$ = exports2.RunTaskRequest$ = exports2.Rollback$ = exports2.ResourceRequirement$ = exports2.Resource$ = exports2.ResolvedConfiguration$ = exports2.RepositoryCredentials$ = exports2.RegisterTaskDefinitionResponse$ = exports2.RegisterTaskDefinitionRequest$ = exports2.RegisterDaemonTaskDefinitionResponse$ = exports2.RegisterDaemonTaskDefinitionRequest$ = exports2.RegisterContainerInstanceResponse$ = exports2.RegisterContainerInstanceRequest$ = exports2.PutClusterCapacityProvidersResponse$ = exports2.PutClusterCapacityProvidersRequest$ = exports2.PutAttributesResponse$ = exports2.PutAttributesRequest$ = exports2.PutAccountSettingResponse$ = exports2.PutAccountSettingRequest$ = exports2.PutAccountSettingDefaultResponse$ = exports2.PutAccountSettingDefaultRequest$ = exports2.ProxyConfiguration$ = exports2.ProtectedTask$ = exports2.PortMapping$ = exports2.PlatformDevice$ = exports2.PlacementStrategy$ = exports2.PlacementConstraint$ = exports2.NetworkInterfaceCountRequest$ = exports2.NetworkInterface$ = exports2.NetworkConfiguration$ = exports2.NetworkBinding$ = exports2.NetworkBandwidthGbpsRequest$ = void 0;
    exports2.UpdateContainerAgentResponse$ = exports2.UpdateContainerAgentRequest$ = exports2.UpdateClusterSettingsResponse$ = exports2.UpdateClusterSettingsRequest$ = exports2.UpdateClusterResponse$ = exports2.UpdateClusterRequest$ = exports2.UpdateCapacityProviderResponse$ = exports2.UpdateCapacityProviderRequest$ = exports2.UntagResourceResponse$ = exports2.UntagResourceRequest$ = exports2.Ulimit$ = exports2.TotalLocalStorageGBRequest$ = exports2.Tmpfs$ = exports2.TimeoutConfiguration$ = exports2.TaskVolumeConfiguration$ = exports2.TaskSet$ = exports2.TaskOverride$ = exports2.TaskManagedEBSVolumeTerminationPolicy$ = exports2.TaskManagedEBSVolumeConfiguration$ = exports2.TaskEphemeralStorage$ = exports2.TaskDefinitionPlacementConstraint$ = exports2.TaskDefinition$ = exports2.Task$ = exports2.TagResourceResponse$ = exports2.TagResourceRequest$ = exports2.Tag$ = exports2.SystemControl$ = exports2.SubmitTaskStateChangeResponse$ = exports2.SubmitTaskStateChangeRequest$ = exports2.SubmitContainerStateChangeResponse$ = exports2.SubmitContainerStateChangeRequest$ = exports2.SubmitAttachmentStateChangesResponse$ = exports2.SubmitAttachmentStateChangesRequest$ = exports2.StopTaskResponse$ = exports2.StopTaskRequest$ = exports2.StopServiceDeploymentResponse$ = exports2.StopServiceDeploymentRequest$ = exports2.StartTaskResponse$ = exports2.StartTaskRequest$ = exports2.Setting$ = exports2.Session$ = exports2.ServiceVolumeConfiguration$ = exports2.ServiceRevisionSummary$ = exports2.ServiceRevisionLoadBalancer$ = exports2.ServiceRevision$ = exports2.ServiceRegistry$ = exports2.ServiceManagedEBSVolumeConfiguration$ = exports2.ServiceEvent$ = exports2.ServiceDeploymentCircuitBreaker$ = exports2.ServiceDeploymentBrief$ = void 0;
    exports2.DescribeServices$ = exports2.DescribeServiceRevisions$ = exports2.DescribeServiceDeployments$ = exports2.DescribeExpressGatewayService$ = exports2.DescribeDaemonTaskDefinition$ = exports2.DescribeDaemonRevisions$ = exports2.DescribeDaemonDeployments$ = exports2.DescribeDaemon$ = exports2.DescribeContainerInstances$ = exports2.DescribeClusters$ = exports2.DescribeCapacityProviders$ = exports2.DeregisterTaskDefinition$ = exports2.DeregisterContainerInstance$ = exports2.DeleteTaskSet$ = exports2.DeleteTaskDefinitions$ = exports2.DeleteService$ = exports2.DeleteExpressGatewayService$ = exports2.DeleteDaemonTaskDefinition$ = exports2.DeleteDaemon$ = exports2.DeleteCluster$ = exports2.DeleteCapacityProvider$ = exports2.DeleteAttributes$ = exports2.DeleteAccountSetting$ = exports2.CreateTaskSet$ = exports2.CreateService$ = exports2.CreateExpressGatewayService$ = exports2.CreateDaemon$ = exports2.CreateCluster$ = exports2.CreateCapacityProvider$ = exports2.VpcLatticeConfiguration$ = exports2.VolumeFrom$ = exports2.Volume$ = exports2.VersionInfo$ = exports2.VCpuCountRangeRequest$ = exports2.UpdateTaskSetResponse$ = exports2.UpdateTaskSetRequest$ = exports2.UpdateTaskProtectionResponse$ = exports2.UpdateTaskProtectionRequest$ = exports2.UpdateServiceResponse$ = exports2.UpdateServiceRequest$ = exports2.UpdateServicePrimaryTaskSetResponse$ = exports2.UpdateServicePrimaryTaskSetRequest$ = exports2.UpdateManagedInstancesProviderConfiguration$ = exports2.UpdateExpressGatewayServiceResponse$ = exports2.UpdateExpressGatewayServiceRequest$ = exports2.UpdatedExpressGatewayService$ = exports2.UpdateDaemonResponse$ = exports2.UpdateDaemonRequest$ = exports2.UpdateContainerInstancesStateResponse$ = exports2.UpdateContainerInstancesStateRequest$ = void 0;
    exports2.UpdateTaskSet$ = exports2.UpdateTaskProtection$ = exports2.UpdateServicePrimaryTaskSet$ = exports2.UpdateService$ = exports2.UpdateExpressGatewayService$ = exports2.UpdateDaemon$ = exports2.UpdateContainerInstancesState$ = exports2.UpdateContainerAgent$ = exports2.UpdateClusterSettings$ = exports2.UpdateCluster$ = exports2.UpdateCapacityProvider$ = exports2.UntagResource$ = exports2.TagResource$ = exports2.SubmitTaskStateChange$ = exports2.SubmitContainerStateChange$ = exports2.SubmitAttachmentStateChanges$ = exports2.StopTask$ = exports2.StopServiceDeployment$ = exports2.StartTask$ = exports2.RunTask$ = exports2.RegisterTaskDefinition$ = exports2.RegisterDaemonTaskDefinition$ = exports2.RegisterContainerInstance$ = exports2.PutClusterCapacityProviders$ = exports2.PutAttributes$ = exports2.PutAccountSettingDefault$ = exports2.PutAccountSetting$ = exports2.ListTasks$ = exports2.ListTaskDefinitions$ = exports2.ListTaskDefinitionFamilies$ = exports2.ListTagsForResource$ = exports2.ListServicesByNamespace$ = exports2.ListServices$ = exports2.ListServiceDeployments$ = exports2.ListDaemonTaskDefinitions$ = exports2.ListDaemons$ = exports2.ListDaemonDeployments$ = exports2.ListContainerInstances$ = exports2.ListClusters$ = exports2.ListAttributes$ = exports2.ListAccountSettings$ = exports2.GetTaskProtection$ = exports2.ExecuteCommand$ = exports2.DiscoverPollEndpoint$ = exports2.DescribeTaskSets$ = exports2.DescribeTasks$ = exports2.DescribeTaskDefinition$ = void 0;
    var _A10 = "Attachment";
    var _AC = "AdvancedConfiguration";
    var _ACR = "AcceleratorCountRequest";
    var _AD = "AttachmentDetails";
    var _ADE13 = "AccessDeniedException";
    var _AIT = "AllowedInstanceType";
    var _AITS = "AllowedInstanceTypeSet";
    var _ALEE = "AttributeLimitExceededException";
    var _AM = "AcceleratorManufacturer";
    var _AMS = "AcceleratorManufacturerSet";
    var _AN = "AcceleratorName";
    var _ANS = "AcceleratorNameSet";
    var _ARC = "AutoRepairConfiguration";
    var _ASC = "AttachmentStateChange";
    var _ASCt = "AttachmentStateChanges";
    var _ASGP = "AutoScalingGroupProvider";
    var _ASGPU = "AutoScalingGroupProviderUpdate";
    var _AT13 = "AcceleratorType";
    var _ATMMBR = "AcceleratorTotalMemoryMiBRequest";
    var _ATS = "AcceleratorTypeSet";
    var _AVC = "AwsVpcConfiguration";
    var _At = "Attribute";
    var _Att = "Attachments";
    var _Attr = "Attributes";
    var _BE = "BlockedException";
    var _BEBMR = "BaselineEbsBandwidthMbpsRequest";
    var _C11 = "Cluster";
    var _CA10 = "CreatedAt";
    var _CC = "CanaryConfiguration";
    var _CCCIE = "ClusterContainsContainerInstancesException";
    var _CCCPE = "ClusterContainsCapacityProviderException";
    var _CCP = "CreateCapacityProvider";
    var _CCPR = "CreateCapacityProviderRequest";
    var _CCPRr = "CreateCapacityProviderResponse";
    var _CCR = "CreateClusterRequest";
    var _CCRr = "CreateClusterResponse";
    var _CCSE = "ClusterContainsServicesException";
    var _CCTE = "ClusterContainsTasksException";
    var _CCl = "ClusterConfiguration";
    var _CCr = "CreateCluster";
    var _CD = "ContainerDefinition";
    var _CDR = "CreateDaemonRequest";
    var _CDRr = "CreateDaemonResponse";
    var _CDo = "ContainerDependency";
    var _CDon = "ContainerDefinitions";
    var _CDont = "ContainerDependencies";
    var _CDr = "CreateDaemon";
    var _CE = "ClientException";
    var _CEGS = "CreateExpressGatewayService";
    var _CEGSR = "CreateExpressGatewayServiceRequest";
    var _CEGSRr = "CreateExpressGatewayServiceResponse";
    var _CEo = "ConflictException";
    var _CI = "ContainerImage";
    var _CIHS = "ContainerInstanceHealthStatus";
    var _CIo = "ContainerInstance";
    var _CIon = "ContainerImages";
    var _CIont = "ContainerInstances";
    var _CM = "CpuManufacturer";
    var _CMIPC = "CreateManagedInstancesProviderConfiguration";
    var _CMS = "CpuManufacturerSet";
    var _CNFE = "ClusterNotFoundException";
    var _CO = "ContainerOverride";
    var _COo = "ContainerOverrides";
    var _CP = "CapacityProvider";
    var _CPS = "CapacityProviderStrategy";
    var _CPSI = "CapacityProviderStrategyItem";
    var _CPa = "CapacityProviders";
    var _CRP = "ContainerRestartPolicy";
    var _CRR = "CapacityReservationRequest";
    var _CS4 = "ClusterSetting";
    var _CSC = "ContainerStateChange";
    var _CSCD = "ClusterServiceConnectDefaults";
    var _CSCDR = "ClusterServiceConnectDefaultsRequest";
    var _CSCo = "ContainerStateChanges";
    var _CSR = "CreateServiceRequest";
    var _CSRr = "CreateServiceResponse";
    var _CSl = "ClusterSettings";
    var _CSr = "CreateService";
    var _CTS = "CreateTaskSet";
    var _CTSR = "CreateTaskSetRequest";
    var _CTSRr = "CreateTaskSetResponse";
    var _Cl = "Clusters";
    var _Co = "Container";
    var _Con = "Containers";
    var _D = "Deployment";
    var _DA = "DeploymentAlarms";
    var _DAC = "DaemonAlarmConfiguration";
    var _DAR = "DeleteAttributesRequest";
    var _DARe = "DeleteAttributesResponse";
    var _DAS = "DeleteAccountSetting";
    var _DASR = "DeleteAccountSettingRequest";
    var _DASRe = "DeleteAccountSettingResponse";
    var _DAe = "DeleteAttributes";
    var _DC = "DeploymentConfiguration";
    var _DCB = "DaemonCircuitBreaker";
    var _DCBe = "DeploymentCircuitBreaker";
    var _DCD = "DaemonContainerDefinition";
    var _DCDL = "DaemonContainerDefinitionList";
    var _DCI = "DaemonContainerImage";
    var _DCIR = "DeregisterContainerInstanceRequest";
    var _DCIRe = "DeregisterContainerInstanceResponse";
    var _DCIRes = "DescribeContainerInstancesRequest";
    var _DCIResc = "DescribeContainerInstancesResponse";
    var _DCIa = "DaemonContainerImages";
    var _DCIe = "DeregisterContainerInstance";
    var _DCIes = "DescribeContainerInstances";
    var _DCP = "DaemonCapacityProvider";
    var _DCPL = "DaemonCapacityProviderList";
    var _DCPR = "DeleteCapacityProviderRequest";
    var _DCPRe = "DeleteCapacityProviderResponse";
    var _DCPRes = "DescribeCapacityProvidersRequest";
    var _DCPResc = "DescribeCapacityProvidersResponse";
    var _DCPe = "DeleteCapacityProvider";
    var _DCPes = "DescribeCapacityProviders";
    var _DCR = "DeleteClusterRequest";
    var _DCRe = "DeleteClusterResponse";
    var _DCRes = "DescribeClustersRequest";
    var _DCResc = "DescribeClustersResponse";
    var _DCe = "DeploymentController";
    var _DCel = "DeleteCluster";
    var _DCes = "DescribeClusters";
    var _DD = "DaemonDeployment";
    var _DDA = "DaemonDeploymentAlarms";
    var _DDC = "DaemonDeploymentConfiguration";
    var _DDCP = "DaemonDeploymentCapacityProvider";
    var _DDCPL = "DaemonDeploymentCapacityProviderList";
    var _DDD = "DescribeDaemonDeployments";
    var _DDDR = "DescribeDaemonDeploymentsRequest";
    var _DDDRe = "DescribeDaemonDeploymentsResponse";
    var _DDL = "DaemonDeploymentList";
    var _DDR = "DeleteDaemonRequest";
    var _DDRD = "DaemonDeploymentRevisionDetail";
    var _DDRDL = "DaemonDeploymentRevisionDetailList";
    var _DDRR = "DescribeDaemonRevisionsRequest";
    var _DDRRe = "DescribeDaemonRevisionsResponse";
    var _DDRe = "DeleteDaemonResponse";
    var _DDRes = "DescribeDaemonRequest";
    var _DDResc = "DescribeDaemonResponse";
    var _DDRescr = "DescribeDaemonRevisions";
    var _DDS = "DaemonDeploymentSummary";
    var _DDSL = "DaemonDeploymentSummaryList";
    var _DDTD = "DeleteDaemonTaskDefinition";
    var _DDTDR = "DeleteDaemonTaskDefinitionRequest";
    var _DDTDRe = "DeleteDaemonTaskDefinitionResponse";
    var _DDTDRes = "DescribeDaemonTaskDefinitionRequest";
    var _DDTDResc = "DescribeDaemonTaskDefinitionResponse";
    var _DDTDe = "DescribeDaemonTaskDefinition";
    var _DDa = "DaemonDetail";
    var _DDe = "DeleteDaemon";
    var _DDes = "DescribeDaemon";
    var _DEGS = "DeleteExpressGatewayService";
    var _DEGSR = "DeleteExpressGatewayServiceRequest";
    var _DEGSRe = "DeleteExpressGatewayServiceResponse";
    var _DEGSRes = "DescribeExpressGatewayServiceRequest";
    var _DEGSResc = "DescribeExpressGatewayServiceResponse";
    var _DEGSe = "DescribeExpressGatewayService";
    var _DES = "DeploymentEphemeralStorage";
    var _DL = "DevicesList";
    var _DLH = "DeploymentLifecycleHook";
    var _DLHL = "DeploymentLifecycleHookList";
    var _DLP = "DaemonLinuxParameters";
    var _DNAE = "DaemonNotActiveException";
    var _DNFE = "DaemonNotFoundException";
    var _DPE = "DiscoverPollEndpoint";
    var _DPER = "DiscoverPollEndpointRequest";
    var _DPERi = "DiscoverPollEndpointResponse";
    var _DR = "DaemonRevision";
    var _DRD = "DaemonRevisionDetail";
    var _DRDL = "DaemonRevisionDetailList";
    var _DRa = "DaemonRollback";
    var _DRae = "DaemonRevisions";
    var _DS10 = "DaemonSummary";
    var _DSD = "DescribeServiceDeployments";
    var _DSDR = "DescribeServiceDeploymentsRequest";
    var _DSDRe = "DescribeServiceDeploymentsResponse";
    var _DSL = "DaemonSummariesList";
    var _DSR = "DeleteServiceRequest";
    var _DSRR = "DescribeServiceRevisionsRequest";
    var _DSRRe = "DescribeServiceRevisionsResponse";
    var _DSRe = "DeleteServiceResponse";
    var _DSRes = "DescribeServicesRequest";
    var _DSResc = "DescribeServicesResponse";
    var _DSRescr = "DescribeServiceRevisions";
    var _DSe = "DeleteService";
    var _DSes = "DescribeServices";
    var _DT = "DescribeTasks";
    var _DTD = "DaemonTaskDefinition";
    var _DTDR = "DeleteTaskDefinitionsRequest";
    var _DTDRe = "DeleteTaskDefinitionsResponse";
    var _DTDRer = "DeregisterTaskDefinitionRequest";
    var _DTDRere = "DeregisterTaskDefinitionResponse";
    var _DTDRes = "DescribeTaskDefinitionRequest";
    var _DTDResc = "DescribeTaskDefinitionResponse";
    var _DTDS = "DaemonTaskDefinitionSummary";
    var _DTDSa = "DaemonTaskDefinitionSummaries";
    var _DTDe = "DeleteTaskDefinitions";
    var _DTDer = "DeregisterTaskDefinition";
    var _DTDes = "DescribeTaskDefinition";
    var _DTR = "DescribeTasksRequest";
    var _DTRe = "DescribeTasksResponse";
    var _DTS = "DeleteTaskSet";
    var _DTSR = "DeleteTaskSetRequest";
    var _DTSRe = "DeleteTaskSetResponse";
    var _DTSRes = "DescribeTaskSetsRequest";
    var _DTSResc = "DescribeTaskSetsResponse";
    var _DTSe = "DescribeTaskSets";
    var _DV = "DaemonVolume";
    var _DVC = "DockerVolumeConfiguration";
    var _DVL = "DaemonVolumeList";
    var _De = "Device";
    var _Dep = "Deployments";
    var _EBSTS = "EBSTagSpecification";
    var _EBSTSa = "EBSTagSpecifications";
    var _EC = "ExecuteCommand";
    var _ECC = "ExecuteCommandConfiguration";
    var _ECLC = "ExecuteCommandLogConfiguration";
    var _ECR = "ExecuteCommandRequest";
    var _ECRx = "ExecuteCommandResponse";
    var _ECSEGS = "ECSExpressGatewayService";
    var _ECSMR = "ECSManagedResources";
    var _EF = "EnvironmentFile";
    var _EFSAC = "EFSAuthorizationConfig";
    var _EFSVC = "EFSVolumeConfiguration";
    var _EFn = "EnvironmentFiles";
    var _EGC = "ExpressGatewayContainer";
    var _EGRC = "ExpressGatewayRepositoryCredentials";
    var _EGSALC = "ExpressGatewayServiceAwsLogsConfiguration";
    var _EGSC = "ExpressGatewayServiceConfiguration";
    var _EGSCx = "ExpressGatewayServiceConfigurations";
    var _EGSNC = "ExpressGatewayServiceNetworkConfiguration";
    var _EGSS = "ExpressGatewayServiceStatus";
    var _EGST = "ExpressGatewayScalingTarget";
    var _EIT = "ExcludedInstanceType";
    var _EITS = "ExcludedInstanceTypeSet";
    var _ES = "EphemeralStorage";
    var _EV = "EnvironmentVariables";
    var _F = "Failure";
    var _FC = "FirelensConfiguration";
    var _FSWFSAC = "FSxWindowsFileServerAuthorizationConfig";
    var _FSWFSVC = "FSxWindowsFileServerVolumeConfiguration";
    var _Fa = "Failures";
    var _GTP = "GetTaskProtection";
    var _GTPR = "GetTaskProtectionRequest";
    var _GTPRe = "GetTaskProtectionResponse";
    var _HC = "HealthCheck";
    var _HE = "HostEntry";
    var _HEL = "HostEntryList";
    var _HVP = "HostVolumeProperties";
    var _IA = "InferenceAccelerator";
    var _IAO = "InferenceAcceleratorOverride";
    var _IAOn = "InferenceAcceleratorOverrides";
    var _IAn = "InferenceAccelerators";
    var _IG = "InstanceGeneration";
    var _IGS = "InstanceGenerationSet";
    var _IHCR = "InstanceHealthCheckResult";
    var _IHCRL = "InstanceHealthCheckResultList";
    var _ILT = "InstanceLaunchTemplate";
    var _ILTU = "InstanceLaunchTemplateUpdate";
    var _IO = "InfrastructureOptimization";
    var _IPE2 = "InvalidParameterException";
    var _IPS = "IngressPathSummary";
    var _IPSn = "IngressPathSummaries";
    var _IRR = "InstanceRequirementsRequest";
    var _KC = "KernelCapabilities";
    var _KVP = "KeyValuePair";
    var _LA = "ListAttributes";
    var _LAR = "ListAttributesRequest";
    var _LARi = "ListAttributesResponse";
    var _LAS = "ListAccountSettings";
    var _LASR = "ListAccountSettingsRequest";
    var _LASRi = "ListAccountSettingsResponse";
    var _LB = "LoadBalancer";
    var _LBo = "LoadBalancers";
    var _LC = "LinearConfiguration";
    var _LCI = "ListContainerInstances";
    var _LCIR = "ListContainerInstancesRequest";
    var _LCIRi = "ListContainerInstancesResponse";
    var _LCR = "ListClustersRequest";
    var _LCRi = "ListClustersResponse";
    var _LCi = "ListClusters";
    var _LCo = "LogConfiguration";
    var _LD = "ListDaemons";
    var _LDD = "ListDaemonDeployments";
    var _LDDR = "ListDaemonDeploymentsRequest";
    var _LDDRi = "ListDaemonDeploymentsResponse";
    var _LDR = "ListDaemonsRequest";
    var _LDRi = "ListDaemonsResponse";
    var _LDTD = "ListDaemonTaskDefinitions";
    var _LDTDR = "ListDaemonTaskDefinitionsRequest";
    var _LDTDRi = "ListDaemonTaskDefinitionsResponse";
    var _LEE2 = "LimitExceededException";
    var _LP = "LinuxParameters";
    var _LS = "ListServices";
    var _LSBN = "ListServicesByNamespace";
    var _LSBNR = "ListServicesByNamespaceRequest";
    var _LSBNRi = "ListServicesByNamespaceResponse";
    var _LSD = "ListServiceDeployments";
    var _LSDR = "ListServiceDeploymentsRequest";
    var _LSDRi = "ListServiceDeploymentsResponse";
    var _LSR = "ListServicesRequest";
    var _LSRi = "ListServicesResponse";
    var _LST = "LocalStorageType";
    var _LSTS = "LocalStorageTypeSet";
    var _LT = "ListTasks";
    var _LTD = "ListTaskDefinitions";
    var _LTDF = "ListTaskDefinitionFamilies";
    var _LTDFR = "ListTaskDefinitionFamiliesRequest";
    var _LTDFRi = "ListTaskDefinitionFamiliesResponse";
    var _LTDR = "ListTaskDefinitionsRequest";
    var _LTDRi = "ListTaskDefinitionsResponse";
    var _LTFR = "ListTagsForResource";
    var _LTFRR = "ListTagsForResourceRequest";
    var _LTFRRi = "ListTagsForResourceResponse";
    var _LTR = "ListTasksRequest";
    var _LTRi = "ListTasksResponse";
    var _MA = "ManagedAgent";
    var _MAASP = "ManagedApplicationAutoScalingPolicy";
    var _MAASPa = "ManagedApplicationAutoScalingPolicies";
    var _MAS = "ManagedAutoScaling";
    var _MASC = "ManagedAgentStateChange";
    var _MASCa = "ManagedAgentStateChanges";
    var _MAa = "ManagedAgents";
    var _MC = "ManagedCertificate";
    var _MGBPVCR = "MemoryGiBPerVCpuRequest";
    var _MILSC = "ManagedInstancesLocalStorageConfiguration";
    var _MINC = "ManagedInstancesNetworkConfiguration";
    var _MIP = "ManagedIngressPath";
    var _MIPa = "ManagedInstancesProvider";
    var _MIPan = "ManagedIngressPaths";
    var _MISC = "ManagedInstancesStorageConfiguration";
    var _ML = "ManagedListener";
    var _MLB = "ManagedLoadBalancer";
    var _MLG = "ManagedLogGroup";
    var _MLGa = "ManagedLogGroups";
    var _MLR = "ManagedListenerRule";
    var _MMA = "ManagedMetricAlarm";
    var _MMAa = "ManagedMetricAlarms";
    var _MMBR = "MemoryMiBRequest";
    var _MP = "MountPoint";
    var _MPL = "MountPointList";
    var _MS = "ManagedScaling";
    var _MSC = "ManagedStorageConfiguration";
    var _MSG = "ManagedSecurityGroup";
    var _MSGa = "ManagedSecurityGroups";
    var _MST = "ManagedScalableTarget";
    var _MTG = "ManagedTargetGroup";
    var _MTGa = "ManagedTargetGroups";
    var _MVE = "MissingVersionException";
    var _NB = "NetworkBinding";
    var _NBGR = "NetworkBandwidthGbpsRequest";
    var _NBe = "NetworkBindings";
    var _NC = "NetworkConfiguration";
    var _NI = "NetworkInterface";
    var _NICR = "NetworkInterfaceCountRequest";
    var _NIe = "NetworkInterfaces";
    var _NNFE = "NamespaceNotFoundException";
    var _NUAE = "NoUpdateAvailableException";
    var _PA10 = "PutAttributes";
    var _PAR = "PutAttributesRequest";
    var _PARu = "PutAttributesResponse";
    var _PAS = "PutAccountSetting";
    var _PASD = "PutAccountSettingDefault";
    var _PASDR = "PutAccountSettingDefaultRequest";
    var _PASDRu = "PutAccountSettingDefaultResponse";
    var _PASR = "PutAccountSettingRequest";
    var _PASRu = "PutAccountSettingResponse";
    var _PC10 = "PlacementConstraint";
    var _PCCP = "PutClusterCapacityProviders";
    var _PCCPR = "PutClusterCapacityProvidersRequest";
    var _PCCPRu = "PutClusterCapacityProvidersResponse";
    var _PCP = "ProxyConfigurationProperties";
    var _PCl = "PlacementConstraints";
    var _PCr10 = "ProxyConfiguration";
    var _PD = "PlatformDevice";
    var _PDl = "PlatformDevices";
    var _PM = "PortMapping";
    var _PML = "PortMappingList";
    var _PS = "PlacementStrategy";
    var _PSl = "PlacementStrategies";
    var _PT = "ProtectedTask";
    var _PTDIE = "PlatformTaskDefinitionIncompatibilityException";
    var _PTr = "ProtectedTasks";
    var _PUE = "PlatformUnknownException";
    var _R = "Resource";
    var _RA10 = "RequiresAttributes";
    var _RC10 = "RepositoryCredentials";
    var _RCI = "RegisterContainerInstance";
    var _RCIR = "RegisterContainerInstanceRequest";
    var _RCIRe = "RegisterContainerInstanceResponse";
    var _RCe = "ResolvedConfiguration";
    var _RDTD = "RegisterDaemonTaskDefinition";
    var _RDTDR = "RegisterDaemonTaskDefinitionRequest";
    var _RDTDRe = "RegisterDaemonTaskDefinitionResponse";
    var _RIUE = "ResourceInUseException";
    var _RNFE11 = "ResourceNotFoundException";
    var _RP = "RuntimePlatform";
    var _RR = "ResourceRequirement";
    var _RRe = "ResourceRequirements";
    var _RT13 = "RunTask";
    var _RTD = "RegisterTaskDefinition";
    var _RTDR = "RegisterTaskDefinitionRequest";
    var _RTDRe = "RegisterTaskDefinitionResponse";
    var _RTR = "RunTaskRequest";
    var _RTRu = "RunTaskResponse";
    var _Re = "Resources";
    var _Ro = "Rollback";
    var _S = "Scale";
    var _SASC = "SubmitAttachmentStateChanges";
    var _SASCR = "SubmitAttachmentStateChangesRequest";
    var _SASCRu = "SubmitAttachmentStateChangesResponse";
    var _SC = "SystemControl";
    var _SCALC = "ServiceConnectAccessLogConfiguration";
    var _SCC = "ServiceConnectConfiguration";
    var _SCCA = "ServiceConnectClientAlias";
    var _SCCAL = "ServiceConnectClientAliasList";
    var _SCRS = "ServiceCurrentRevisionSummary";
    var _SCRSL = "ServiceCurrentRevisionSummaryList";
    var _SCS = "ServiceConnectService";
    var _SCSC = "SubmitContainerStateChange";
    var _SCSCR = "SubmitContainerStateChangeRequest";
    var _SCSCRu = "SubmitContainerStateChangeResponse";
    var _SCSL = "ServiceConnectServiceList";
    var _SCSR = "ServiceConnectServiceResource";
    var _SCSRL = "ServiceConnectServiceResourceList";
    var _SCTC = "ServiceConnectTlsConfiguration";
    var _SCTCA = "ServiceConnectTlsCertificateAuthority";
    var _SCTTHMR = "ServiceConnectTestTrafficHeaderMatchRules";
    var _SCTTHR = "ServiceConnectTestTrafficHeaderRules";
    var _SCTTR = "ServiceConnectTestTrafficRules";
    var _SCy = "SystemControls";
    var _SD = "ServiceDeployment";
    var _SDA = "ServiceDeploymentAlarms";
    var _SDB = "ServiceDeploymentBrief";
    var _SDBe = "ServiceDeploymentsBrief";
    var _SDCB = "ServiceDeploymentCircuitBreaker";
    var _SDNFE = "ServiceDeploymentNotFoundException";
    var _SDe = "ServiceDeployments";
    var _SE = "ServerException";
    var _SEe = "ServiceEvent";
    var _SEer = "ServiceEvents";
    var _SFVC = "S3FilesVolumeConfiguration";
    var _SL = "SecretList";
    var _SMEBSVC = "ServiceManagedEBSVolumeConfiguration";
    var _SNAE = "ServiceNotActiveException";
    var _SNFE = "ServiceNotFoundException";
    var _SR = "ServiceRegistry";
    var _SRLB = "ServiceRevisionLoadBalancer";
    var _SRLBe = "ServiceRevisionLoadBalancers";
    var _SRS = "ServiceRevisionSummary";
    var _SRSL = "ServiceRevisionsSummaryList";
    var _SRe = "ServiceRevision";
    var _SRer = "ServiceRegistries";
    var _SRerv = "ServiceRevisions";
    var _SS = "SensitiveString";
    var _SSD = "StopServiceDeployment";
    var _SSDR = "StopServiceDeploymentRequest";
    var _SSDRt = "StopServiceDeploymentResponse";
    var _ST11 = "StartTask";
    var _STR = "StartTaskRequest";
    var _STRt = "StartTaskResponse";
    var _STRto = "StopTaskRequest";
    var _STRtop = "StopTaskResponse";
    var _STSC = "SubmitTaskStateChange";
    var _STSCR = "SubmitTaskStateChangeRequest";
    var _STSCRu = "SubmitTaskStateChangeResponse";
    var _STt = "StopTask";
    var _SVC = "ServiceVolumeConfiguration";
    var _SVCe = "ServiceVolumeConfigurations";
    var _Se = "Secret";
    var _Ser = "Service";
    var _Serv = "Services";
    var _Ses = "Session";
    var _Set = "Setting";
    var _Sett = "Settings";
    var _St = "Statistics";
    var _T10 = "Tag";
    var _TC10 = "TimeoutConfiguration";
    var _TD = "TaskDefinition";
    var _TDL = "TaskDefinitionList";
    var _TDPC = "TaskDefinitionPlacementConstraint";
    var _TDPCa = "TaskDefinitionPlacementConstraints";
    var _TES = "TaskEphemeralStorage";
    var _TL = "TmpfsList";
    var _TLSGBR = "TotalLocalStorageGBRequest";
    var _TMEBSVC = "TaskManagedEBSVolumeConfiguration";
    var _TMEBSVTP = "TaskManagedEBSVolumeTerminationPolicy";
    var _TNCE = "TargetNotConnectedException";
    var _TNFE = "TargetNotFoundException";
    var _TO = "TaskOverride";
    var _TR = "TagResource";
    var _TRR = "TagResourceRequest";
    var _TRRa = "TagResourceResponse";
    var _TS = "TaskSet";
    var _TSNFE = "TaskSetNotFoundException";
    var _TSa = "TaskSets";
    var _TVC = "TaskVolumeConfiguration";
    var _TVCa = "TaskVolumeConfigurations";
    var _Ta10 = "Task";
    var _Tag = "Tags";
    var _Tas = "Tasks";
    var _Tm = "Tmpfs";
    var _U = "Ulimit";
    var _UC = "UpdateCluster";
    var _UCA = "UpdateContainerAgent";
    var _UCAR = "UpdateContainerAgentRequest";
    var _UCARp = "UpdateContainerAgentResponse";
    var _UCIS = "UpdateContainerInstancesState";
    var _UCISR = "UpdateContainerInstancesStateRequest";
    var _UCISRp = "UpdateContainerInstancesStateResponse";
    var _UCP = "UpdateCapacityProvider";
    var _UCPR = "UpdateCapacityProviderRequest";
    var _UCPRp = "UpdateCapacityProviderResponse";
    var _UCR = "UpdateClusterRequest";
    var _UCRp = "UpdateClusterResponse";
    var _UCS = "UpdateClusterSettings";
    var _UCSR = "UpdateClusterSettingsRequest";
    var _UCSRp = "UpdateClusterSettingsResponse";
    var _UD = "UpdateDaemon";
    var _UDR = "UpdateDaemonRequest";
    var _UDRp = "UpdateDaemonResponse";
    var _UEGS = "UpdatedExpressGatewayService";
    var _UEGSR = "UpdateExpressGatewayServiceRequest";
    var _UEGSRp = "UpdateExpressGatewayServiceResponse";
    var _UEGSp = "UpdateExpressGatewayService";
    var _UFE = "UnsupportedFeatureException";
    var _UIPE = "UpdateInProgressException";
    var _UL = "UlimitList";
    var _UMIPC = "UpdateManagedInstancesProviderConfiguration";
    var _UR = "UntagResource";
    var _URR = "UntagResourceRequest";
    var _URRn = "UntagResourceResponse";
    var _US = "UpdateService";
    var _USPTS = "UpdateServicePrimaryTaskSet";
    var _USPTSR = "UpdateServicePrimaryTaskSetRequest";
    var _USPTSRp = "UpdateServicePrimaryTaskSetResponse";
    var _USR = "UpdateServiceRequest";
    var _USRp = "UpdateServiceResponse";
    var _UTP = "UpdateTaskProtection";
    var _UTPR = "UpdateTaskProtectionRequest";
    var _UTPRp = "UpdateTaskProtectionResponse";
    var _UTS = "UpdateTaskSet";
    var _UTSR = "UpdateTaskSetRequest";
    var _UTSRp = "UpdateTaskSetResponse";
    var _V10 = "Volume";
    var _VCCRR = "VCpuCountRangeRequest";
    var _VF = "VolumeFrom";
    var _VFL = "VolumeFromList";
    var _VI = "VersionInfo";
    var _VL = "VolumeList";
    var _VLC = "VpcLatticeConfiguration";
    var _VLCp = "VpcLatticeConfigurations";
    var _a10 = "attachments";
    var _aA = "attachmentArn";
    var _aASP = "applicationAutoScalingPolicies";
    var _aC = "agentConnected";
    var _aCc = "activeConfigurations";
    var _aCcc = "acceleratorCount";
    var _aCd = "advancedConfiguration";
    var _aCu = "authorizationConfig";
    var _aCw = "awsvpcConfiguration";
    var _aH = "agentHash";
    var _aI10 = "attachmentId";
    var _aIT = "allowedInstanceTypes";
    var _aLC = "awsLogsConfiguration";
    var _aLCc = "accessLogConfiguration";
    var _aM = "acceleratorManufacturers";
    var _aN = "alarmNames";
    var _aNc = "acceleratorNames";
    var _aNt = "attributeName";
    var _aP = "appProtocol";
    var _aPA = "accessPointArn";
    var _aPAA = "awsPcaAuthorityArn";
    var _aPI = "assignPublicIp";
    var _aPIc = "accessPointId";
    var _aRC = "autoRepairConfiguration";
    var _aS = "actionsStatus";
    var _aSC = "activeServicesCount";
    var _aSGA = "autoScalingGroupArn";
    var _aSGP = "autoScalingGroupProvider";
    var _aSM = "autoScalingMetric";
    var _aSTV = "autoScalingTargetValue";
    var _aSt = "attachmentsStatus";
    var _aSu = "autoScaling";
    var _aT22 = "accessType";
    var _aTGA = "alternateTargetGroupArn";
    var _aTMMB = "acceleratorTotalMemoryMiB";
    var _aTc = "acceleratorTypes";
    var _aUS = "agentUpdateStatus";
    var _aV = "attributeValue";
    var _aVg = "agentVersion";
    var _aZ = "availabilityZone";
    var _aZR = "availabilityZoneRebalancing";
    var _ac = "acknowledgment";
    var _ad = "add";
    var _af = "after";
    var _al = "alarms";
    var _ar = "arn";
    var _at = "attributes";
    var _au = "autoprovision";
    var _b = "base";
    var _bEBM = "baselineEbsBandwidthMbps";
    var _bIP = "bindIP";
    var _bM = "bareMetal";
    var _bP = "burstablePerformance";
    var _bTIM = "bakeTimeInMinutes";
    var _be = "before";
    var _c32 = "client";
    var _cA = "clusterArn";
    var _cAL = "configuredAtLaunch";
    var _cAl = "clusterArns";
    var _cAli = "clientAliases";
    var _cAo = "containerArn";
    var _cAon = "connectivityAt";
    var _cAp = "cpuArchitecture";
    var _cAr = "createdAt";
    var _cB = "circuitBreaker";
    var _cBTIM = "canaryBakeTimeInMinutes";
    var _cBr = "createdBy";
    var _cC = "canaryConfiguration";
    var _cD = "containerDefinitions";
    var _cDC = "computedDesiredCount";
    var _cDu = "currentDeployment";
    var _cI13 = "containerImages";
    var _cIA = "containerInstanceArn";
    var _cIAo = "containerInstanceArns";
    var _cIo = "containerInstance";
    var _cIon = "containerInstances";
    var _cM = "cpuManufacturers";
    var _cN = "clusterName";
    var _cNo = "containerName";
    var _cO = "containerOverrides";
    var _cOT = "capacityOptionType";
    var _cP = "canaryPercent";
    var _cPA = "capacityProviderArn";
    var _cPAa = "capacityProviderArns";
    var _cPN = "capacityProviderName";
    var _cPR = "containerPortRange";
    var _cPS = "capacityProviderStrategy";
    var _cPa = "capacityProvider";
    var _cPap = "capacityProviders";
    var _cPo = "containerPath";
    var _cPon = "containerPort";
    var _cPr = "credentialsParameter";
    var _cR = "currentRevisions";
    var _cRa = "capacityReservations";
    var _cS4 = "credentialSpecs";
    var _cSD = "currentServiceDeployment";
    var _cSR = "currentServiceRevisions";
    var _cT = "clientToken";
    var _cWEE = "cloudWatchEncryptionEnabled";
    var _cWLGN = "cloudWatchLogGroupName";
    var _ca = "capabilities";
    var _ce = "certificate";
    var _cl = "cluster";
    var _clu = "clusters";
    var _co13 = "configuration";
    var _com = "command";
    var _comp = "compatibilities";
    var _con = "condition";
    var _conn = "connectivity";
    var _cont = "container";
    var _conta = "containers";
    var _cou = "count";
    var _cp = "cpu";
    var _d = "details";
    var _dA = "daemonArn";
    var _dAe = "deploymentArn";
    var _dAer = "deregisteredAt";
    var _dAi = "discoveryArn";
    var _dC4 = "deploymentConfiguration";
    var _dCB = "deploymentCircuitBreaker";
    var _dCPS = "defaultCapacityProviderStrategy";
    var _dCe = "desiredCount";
    var _dCep = "deploymentController";
    var _dD = "daemonDeployments";
    var _dDA = "daemonDeploymentArn";
    var _dDAa = "daemonDeploymentArns";
    var _dIC = "drainingInstanceCount";
    var _dL = "dockerLabels";
    var _dN = "disableNetworking";
    var _dNa = "daemonName";
    var _dNe = "deviceName";
    var _dNi = "discoveryName";
    var _dNn = "dnsName";
    var _dNo = "domainName";
    var _dO = "dependsOn";
    var _dOT = "deleteOnTermination";
    var _dOr = "driverOpts";
    var _dP = "drainPercent";
    var _dR = "daemonRevisions";
    var _dRA = "daemonRevisionArn";
    var _dRAa = "daemonRevisionArns";
    var _dRAe = "deleteRequestedAt";
    var _dS = "dnsServers";
    var _dSD = "dnsSearchDomains";
    var _dSL = "daemonSummariesList";
    var _dSO = "dockerSecurityOptions";
    var _dSe = "desiredStatus";
    var _dT = "deviceType";
    var _dTD = "daemonTaskDefinition";
    var _dTDA = "daemonTaskDefinitionArn";
    var _dTDa = "daemonTaskDefinitions";
    var _dV = "doubleValue";
    var _dVC = "dockerVolumeConfiguration";
    var _dVo = "dockerVersion";
    var _da = "daemon";
    var _de = "devices";
    var _dep = "deployments";
    var _det = "detail";
    var _do = "domain";
    var _dr = "driver";
    var _dro = "drop";
    var _e32 = "error";
    var _eC = "exitCode";
    var _eCC = "executeCommandConfiguration";
    var _eD = "expirationDate";
    var _eEC = "enableExecuteCommand";
    var _eECSMT = "enableECSManagedTags";
    var _eF = "environmentFiles";
    var _eFI = "enableFaultInjection";
    var _eH = "extraHosts";
    var _eI13 = "externalId";
    var _eII = "ec2InstanceId";
    var _eIM = "expiresInMinutes";
    var _eIPA = "ec2InstanceProfileArn";
    var _eIT = "excludedInstanceTypes";
    var _eMR = "ecsManagedResources";
    var _eP = "entryPoint";
    var _eRA = "executionRoleArn";
    var _eS = "effectiveSettings";
    var _eSA = "executionStoppedAt";
    var _eSp = "ephemeralStorage";
    var _eVC = "efsVolumeConfiguration";
    var _en = "environment";
    var _ena = "enabled";
    var _enab = "enable";
    var _enc = "encrypted";
    var _end = "endpoint";
    var _es = "essential";
    var _ev = "events";
    var _ex10 = "expression";
    var _exa = "exact";
    var _f = "family";
    var _fA = "finishedAt";
    var _fC = "firelensConfiguration";
    var _fCa = "failureCount";
    var _fE = "fipsEnabled";
    var _fES = "fargateEphemeralStorage";
    var _fESKKI = "fargateEphemeralStorageKmsKeyId";
    var _fND = "forceNewDeployment";
    var _fP = "familyPrefix";
    var _fSA = "fileSystemArn";
    var _fSI = "fileSystemId";
    var _fT = "failedTasks";
    var _fTi = "filesystemType";
    var _fWFSVC = "fsxWindowsFileServerVolumeConfiguration";
    var _fa = "failures";
    var _fam = "families";
    var _fi = "filter";
    var _fie = "field";
    var _fo = "force";
    var _for = "format";
    var _g = "group";
    var _gDE = "guardDutyEnabled";
    var _gI = "gpuIds";
    var _h22 = "hostname";
    var _hC = "healthCheck";
    var _hCGPS = "healthCheckGracePeriodSeconds";
    var _hCP = "healthCheckPath";
    var _hCPe = "healthCheckPort";
    var _hD = "hookDetails";
    var _hE32 = "httpError";
    var _hL = "hardLimit";
    var _hP = "hostPath";
    var _hPR = "hostPortRange";
    var _hPo = "hostPort";
    var _hS = "healthStatus";
    var _hTA = "hookTargetArn";
    var _he = "header";
    var _ho = "host";
    var _i = "id";
    var _iA = "ipAddress";
    var _iAO = "inferenceAcceleratorOverrides";
    var _iAn = "inferenceAccelerators";
    var _iAp = "ipv6Address";
    var _iCA = "issuerCertificateAuthority";
    var _iD = "imageDigest";
    var _iEC = "ignoredExitCodes";
    var _iG = "instanceGenerations";
    var _iID = "instanceIdentityDocument";
    var _iIDS = "instanceIdentityDocumentSignature";
    var _iLT = "instanceLaunchTemplate";
    var _iM = "ipcMode";
    var _iMTP = "instanceMetadataTagsPropagation";
    var _iO = "infrastructureOptimization";
    var _iP = "ingressPaths";
    var _iPE = "initProcessEnabled";
    var _iPO = "ingressPortOverride";
    var _iQP = "includeQueryParameters";
    var _iR = "instanceRequirements";
    var _iRA = "infrastructureRoleArn";
    var _iTS = "idleTimeoutSeconds";
    var _iV = "integerValue";
    var _iWP = "instanceWarmupPeriod";
    var _ia = "iam";
    var _im = "image";
    var _in = "interactive";
    var _inc = "include";
    var _int = "interval";
    var _io = "iops";
    var _it = "item";
    var _k = "key";
    var _kK = "kmsKey";
    var _kKI = "kmsKeyId";
    var _l = "links";
    var _lB = "loadBalancers";
    var _lBN = "loadBalancerName";
    var _lBSG = "loadBalancerSecurityGroups";
    var _lBo = "loadBalancer";
    var _lC = "logConfiguration";
    var _lCi = "linearConfiguration";
    var _lD = "logDriver";
    var _lG = "logGroups";
    var _lGN = "logGroupName";
    var _lGo = "logGroup";
    var _lH = "lifecycleHooks";
    var _lP = "linuxParameters";
    var _lS = "lastStatus";
    var _lSA = "lastStartedAt";
    var _lSC = "lastStatusChange";
    var _lSCo = "localStorageConfiguration";
    var _lSP = "logStreamPrefix";
    var _lST = "localStorageTypes";
    var _lSi = "lifecycleStages";
    var _lSif = "lifecycleStage";
    var _lSo = "localStorage";
    var _lT = "launchType";
    var _lU = "lastUpdated";
    var _lV = "longValue";
    var _la = "labels";
    var _li = "listener";
    var _lo = "logging";
    var _m29 = "message";
    var _mA = "managedAgents";
    var _mAN = "managedAgentName";
    var _mAe = "metricAlarms";
    var _mC = "minCapacity";
    var _mCa = "maxCapacity";
    var _mD = "managedDraining";
    var _mEBSV = "managedEBSVolume";
    var _mGBPVC = "memoryGiBPerVCpu";
    var _mHP = "minimumHealthyPercent";
    var _mIP = "managedInstancesProvider";
    var _mMB = "memoryMiB";
    var _mO = "mountOptions";
    var _mP = "mountPoints";
    var _mPa = "maximumPercent";
    var _mR = "memoryReservation";
    var _mRa = "maxResults";
    var _mS = "managedScaling";
    var _mSC = "managedStorageConfiguration";
    var _mSPAPOOODP = "maxSpotPriceAsPercentageOfOptimalOnDemandPrice";
    var _mSSS = "minimumScalingStepSize";
    var _mSSSa = "maximumScalingStepSize";
    var _mSa = "maxSwap";
    var _mTC = "minTaskCount";
    var _mTCa = "maxTaskCount";
    var _mTP = "managedTerminationProtection";
    var _ma = "max";
    var _me = "memory";
    var _met = "metric";
    var _mi = "min";
    var _mo = "monitoring";
    var _n = "name";
    var _nB = "networkBindings";
    var _nBG = "networkBandwidthGbps";
    var _nC = "networkConfiguration";
    var _nI = "networkInterfaces";
    var _nIC = "networkInterfaceCount";
    var _nM = "networkMode";
    var _nT = "nextToken";
    var _na = "namespace";
    var _o = "options";
    var _oDMPPOLP = "onDemandMaxPricePercentageOverLowestPrice";
    var _oS = "overallStatus";
    var _oSF = "operatingSystemFamily";
    var _ov = "overrides";
    var _p = "privileged";
    var _pA = "principalArn";
    var _pC = "primaryContainer";
    var _pCe = "pendingCount";
    var _pCl = "placementConstraints";
    var _pCr = "proxyConfiguration";
    var _pD = "platformDevices";
    var _pE = "protectionEnabled";
    var _pF = "platformFamily";
    var _pIA = "privateIpv4Address";
    var _pLR = "productionListenerRule";
    var _pM = "portMappings";
    var _pMi = "pidMode";
    var _pN = "portName";
    var _pRTS = "perRequestTimeoutSeconds";
    var _pS = "placementStrategy";
    var _pSA = "pullStartedAt";
    var _pSAu = "pullStoppedAt";
    var _pT = "pseudoTerminal";
    var _pTC = "pendingTasksCount";
    var _pTCe = "pendingTaskCount";
    var _pTS = "primaryTaskSet";
    var _pTo = "policyType";
    var _pTr = "propagateTags";
    var _pTro = "protectedTasks";
    var _pV = "platformVersion";
    var _pe = "permissions";
    var _po = "port";
    var _pr = "protocol";
    var _pro = "properties";
    var _r4 = "reason";
    var _rA = "roleArn";
    var _rAP = "restartAttemptPeriod";
    var _rAe = "registeredAt";
    var _rAeg = "registryArn";
    var _rAeq = "requiresAttributes";
    var _rAes = "resourceArn";
    var _rB = "registeredBy";
    var _rC10 = "repositoryCredentials";
    var _rCIC = "registeredContainerInstancesCount";
    var _rCP = "rollbackCapacityProviders";
    var _rCe = "requiresCompatibilities";
    var _rCes = "resolvedConfiguration";
    var _rCu = "runningCount";
    var _rD = "rootDirectory";
    var _rGA = "reservationGroupArn";
    var _rHS = "requireHibernateSupport";
    var _rI = "resourceIds";
    var _rIC = "runningInstanceCount";
    var _rIe = "referenceId";
    var _rIu = "runtimeId";
    var _rMT = "resourceManagementType";
    var _rO = "readOnly";
    var _rP = "reservationPreference";
    var _rPTW = "requestedProductionTrafficWeight";
    var _rPe = "restartPolicy";
    var _rPu = "runtimePlatform";
    var _rR = "resourceRequirements";
    var _rRF = "readonlyRootFilesystem";
    var _rRe = "remainingResources";
    var _rReg = "registeredResources";
    var _rS = "rolloutState";
    var _rSR = "rolloutStateReason";
    var _rT13 = "resourceType";
    var _rTC = "runningTasksCount";
    var _rTCe = "requestedTaskCount";
    var _rTCu = "runningTaskCount";
    var _rTDRA = "rollbackTargetDaemonRevisionArn";
    var _rTTW = "requestedTestTrafficWeight";
    var _re = "revision";
    var _ret = "retries";
    var _ro = "role";
    var _rol = "rollback";
    var _ru = "rule";
    var _s32 = "smithy.ts.sdk.synthetic.com.amazonaws.ecs";
    var _sA = "startedAt";
    var _sAe = "serviceArn";
    var _sAer = "serviceArns";
    var _sAt = "stoppedAt";
    var _sAto = "stoppingAt";
    var _sB = "startedBy";
    var _sBN = "s3BucketName";
    var _sBTIM = "stepBakeTimeInMinutes";
    var _sC = "systemControls";
    var _sCC = "serviceConnectConfiguration";
    var _sCD = "serviceConnectDefaults";
    var _sCE = "serviceConnectEndpoint";
    var _sCR = "serviceConnectResources";
    var _sCo = "sourceContainer";
    var _sCt = "statusCode";
    var _sCto = "storageConfiguration";
    var _sCtop = "stopCode";
    var _sD = "serviceDeployments";
    var _sDA = "serviceDeploymentArns";
    var _sDAe = "serviceDeploymentArn";
    var _sDR = "sourceDaemonRevisions";
    var _sEE = "s3EncryptionEnabled";
    var _sG = "securityGroups";
    var _sGI = "securityGroupIds";
    var _sI = "subnetIds";
    var _sIA = "scaleInAfter";
    var _sIGB = "sizeInGiB";
    var _sIe = "sessionId";
    var _sIn = "snapshotId";
    var _sKP = "s3KeyPrefix";
    var _sL = "softLimit";
    var _sMPPOLP = "spotMaxPricePercentageOverLowestPrice";
    var _sMS = "sharedMemorySize";
    var _sN = "serviceName";
    var _sO = "secretOptions";
    var _sP = "startPeriod";
    var _sPo = "sourcePath";
    var _sPt = "stepPercent";
    var _sR = "statusReason";
    var _sRA = "serviceRevisionArns";
    var _sRAe = "serviceRevisionArn";
    var _sRe = "serviceRegistries";
    var _sRer = "serviceRevisions";
    var _sRt = "stoppedReason";
    var _sS = "schedulingStrategy";
    var _sSA = "stabilityStatusAt";
    var _sSG = "serviceSecurityGroups";
    var _sSGB = "storageSizeGiB";
    var _sSR = "sourceServiceRevisions";
    var _sSV = "stringSetValue";
    var _sSt = "stabilityStatus";
    var _sT19 = "startTimeout";
    var _sTc = "scalingTarget";
    var _sTca = "scalableTarget";
    var _sTt = "stopTimeout";
    var _sTto = "stopType";
    var _sU = "streamUrl";
    var _sV = "sourceVolume";
    var _sVC = "s3filesVolumeConfiguration";
    var _sc4 = "scale";
    var _sch = "scheme";
    var _sco = "scope";
    var _se14 = "server";
    var _sec = "secrets";
    var _ser = "service";
    var _serv = "services";
    var _ses = "session";
    var _set = "settings";
    var _sett = "setting";
    var _si = "size";
    var _so = "sort";
    var _st = "status";
    var _sta = "statistics";
    var _str = "strategy";
    var _su = "subnets";
    var _sw = "swappiness";
    var _t = "type";
    var _tA = "taskArn";
    var _tAN = "triggeredAlarmNames";
    var _tAa = "taskArns";
    var _tC = "targetCapacity";
    var _tCa = "targetConfiguration";
    var _tD = "taskDefinition";
    var _tDA = "taskDefinitionArns";
    var _tDAa = "taskDefinitionArn";
    var _tDIC = "totalDrainingInstanceCount";
    var _tDR = "targetDaemonRevision";
    var _tDRA = "targetDaemonRevisionArn";
    var _tDa = "taskDefinitions";
    var _tE = "telemetryEndpoint";
    var _tEP = "transitEncryptionPort";
    var _tEr = "transitEncryption";
    var _tG = "targetGroups";
    var _tGA = "targetGroupArn";
    var _tI10 = "targetId";
    var _tK = "tagKeys";
    var _tLR = "testListenerRule";
    var _tLSGB = "totalLocalStorageGB";
    var _tP = "terminationPolicy";
    var _tR = "totalResources";
    var _tRA = "taskRoleArn";
    var _tRC = "totalRunningCount";
    var _tRIC = "totalRunningInstanceCount";
    var _tS = "taskSet";
    var _tSA = "taskSetArn";
    var _tSR = "targetServiceRevision";
    var _tSRA = "targetServiceRevisionArn";
    var _tSa = "taskSets";
    var _tSag = "tagSpecifications";
    var _tT13 = "targetType";
    var _tTR = "testTrafficRules";
    var _tV = "targetValue";
    var _tVo = "tokenValue";
    var _ta = "tags";
    var _tas = "tasks";
    var _task = "task";
    var _th = "threshold";
    var _thr = "throughput";
    var _ti = "timeout";
    var _tl = "tls";
    var _tm = "tmpfs";
    var _u = "user";
    var _uA = "updatedAt";
    var _uLS = "useLocalStorage";
    var _uS = "updateStatus";
    var _uSR = "updateStatusReason";
    var _ul = "ulimits";
    var _un = "unit";
    var _v = "value";
    var _vC = "versionConsistency";
    var _vCC = "vCpuCount";
    var _vCo = "volumeConfigurations";
    var _vF = "volumesFrom";
    var _vFa = "valueFrom";
    var _vI = "versionInfo";
    var _vIR = "volumeInitializationRate";
    var _vLC = "vpcLatticeConfigurations";
    var _vT = "volumeType";
    var _ve = "version";
    var _vo = "volumes";
    var _w = "weight";
    var _wD = "workingDirectory";
    var _xN = "xmlName";
    var n032 = "com.amazonaws.ecs";
    var schema_1 = (init_schema4(), __toCommonJS(schema_exports));
    var ECSServiceException_1 = require_ECSServiceException();
    var errors_1 = require_errors11();
    var _s_registry32 = schema_1.TypeRegistry.for(_s32);
    exports2.ECSServiceException$ = [-3, _s32, "ECSServiceException", 0, [], []];
    _s_registry32.registerError(exports2.ECSServiceException$, ECSServiceException_1.ECSServiceException);
    var n0_registry32 = schema_1.TypeRegistry.for(n032);
    exports2.AccessDeniedException$ = [
      -3,
      n032,
      _ADE13,
      { [_e32]: _c32, [_hE32]: 403 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.AccessDeniedException$, errors_1.AccessDeniedException);
    exports2.AttributeLimitExceededException$ = [
      -3,
      n032,
      _ALEE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.AttributeLimitExceededException$, errors_1.AttributeLimitExceededException);
    exports2.BlockedException$ = [
      -3,
      n032,
      _BE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.BlockedException$, errors_1.BlockedException);
    exports2.ClientException$ = [
      -3,
      n032,
      _CE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ClientException$, errors_1.ClientException);
    exports2.ClusterContainsCapacityProviderException$ = [
      -3,
      n032,
      _CCCPE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ClusterContainsCapacityProviderException$, errors_1.ClusterContainsCapacityProviderException);
    exports2.ClusterContainsContainerInstancesException$ = [
      -3,
      n032,
      _CCCIE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ClusterContainsContainerInstancesException$, errors_1.ClusterContainsContainerInstancesException);
    exports2.ClusterContainsServicesException$ = [
      -3,
      n032,
      _CCSE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ClusterContainsServicesException$, errors_1.ClusterContainsServicesException);
    exports2.ClusterContainsTasksException$ = [
      -3,
      n032,
      _CCTE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ClusterContainsTasksException$, errors_1.ClusterContainsTasksException);
    exports2.ClusterNotFoundException$ = [
      -3,
      n032,
      _CNFE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ClusterNotFoundException$, errors_1.ClusterNotFoundException);
    exports2.ConflictException$ = [
      -3,
      n032,
      _CEo,
      { [_e32]: _c32 },
      [_rI, _m29],
      [64 | 0, 0]
    ];
    n0_registry32.registerError(exports2.ConflictException$, errors_1.ConflictException);
    exports2.DaemonNotActiveException$ = [
      -3,
      n032,
      _DNAE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.DaemonNotActiveException$, errors_1.DaemonNotActiveException);
    exports2.DaemonNotFoundException$ = [
      -3,
      n032,
      _DNFE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.DaemonNotFoundException$, errors_1.DaemonNotFoundException);
    exports2.InvalidParameterException$ = [
      -3,
      n032,
      _IPE2,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidParameterException$, errors_1.InvalidParameterException);
    exports2.LimitExceededException$ = [
      -3,
      n032,
      _LEE2,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.LimitExceededException$, errors_1.LimitExceededException);
    exports2.MissingVersionException$ = [
      -3,
      n032,
      _MVE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.MissingVersionException$, errors_1.MissingVersionException);
    exports2.NamespaceNotFoundException$ = [
      -3,
      n032,
      _NNFE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.NamespaceNotFoundException$, errors_1.NamespaceNotFoundException);
    exports2.NoUpdateAvailableException$ = [
      -3,
      n032,
      _NUAE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.NoUpdateAvailableException$, errors_1.NoUpdateAvailableException);
    exports2.PlatformTaskDefinitionIncompatibilityException$ = [
      -3,
      n032,
      _PTDIE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.PlatformTaskDefinitionIncompatibilityException$, errors_1.PlatformTaskDefinitionIncompatibilityException);
    exports2.PlatformUnknownException$ = [
      -3,
      n032,
      _PUE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.PlatformUnknownException$, errors_1.PlatformUnknownException);
    exports2.ResourceInUseException$ = [
      -3,
      n032,
      _RIUE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ResourceInUseException$, errors_1.ResourceInUseException);
    exports2.ResourceNotFoundException$ = [
      -3,
      n032,
      _RNFE11,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ResourceNotFoundException$, errors_1.ResourceNotFoundException);
    exports2.ServerException$ = [
      -3,
      n032,
      _SE,
      { [_e32]: _se14 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ServerException$, errors_1.ServerException);
    exports2.ServiceDeploymentNotFoundException$ = [
      -3,
      n032,
      _SDNFE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ServiceDeploymentNotFoundException$, errors_1.ServiceDeploymentNotFoundException);
    exports2.ServiceNotActiveException$ = [
      -3,
      n032,
      _SNAE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ServiceNotActiveException$, errors_1.ServiceNotActiveException);
    exports2.ServiceNotFoundException$ = [
      -3,
      n032,
      _SNFE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ServiceNotFoundException$, errors_1.ServiceNotFoundException);
    exports2.TargetNotConnectedException$ = [
      -3,
      n032,
      _TNCE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.TargetNotConnectedException$, errors_1.TargetNotConnectedException);
    exports2.TargetNotFoundException$ = [
      -3,
      n032,
      _TNFE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.TargetNotFoundException$, errors_1.TargetNotFoundException);
    exports2.TaskSetNotFoundException$ = [
      -3,
      n032,
      _TSNFE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.TaskSetNotFoundException$, errors_1.TaskSetNotFoundException);
    exports2.UnsupportedFeatureException$ = [
      -3,
      n032,
      _UFE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.UnsupportedFeatureException$, errors_1.UnsupportedFeatureException);
    exports2.UpdateInProgressException$ = [
      -3,
      n032,
      _UIPE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.UpdateInProgressException$, errors_1.UpdateInProgressException);
    exports2.errorTypeRegistries = [
      _s_registry32,
      n0_registry32
    ];
    var SensitiveString = [0, n032, _SS, 8, 0];
    exports2.AcceleratorCountRequest$ = [
      3,
      n032,
      _ACR,
      0,
      [_mi, _ma],
      [1, 1]
    ];
    exports2.AcceleratorTotalMemoryMiBRequest$ = [
      3,
      n032,
      _ATMMBR,
      0,
      [_mi, _ma],
      [1, 1]
    ];
    exports2.AdvancedConfiguration$ = [
      3,
      n032,
      _AC,
      0,
      [_aTGA, _pLR, _tLR, _rA],
      [0, 0, 0, 0]
    ];
    exports2.Attachment$ = [
      3,
      n032,
      _A10,
      0,
      [_i, _t, _st, _d],
      [0, 0, 0, () => AttachmentDetails]
    ];
    exports2.AttachmentStateChange$ = [
      3,
      n032,
      _ASC,
      0,
      [_aA, _st],
      [0, 0],
      2
    ];
    exports2.Attribute$ = [
      3,
      n032,
      _At,
      0,
      [_n, _v, _tT13, _tI10],
      [0, 0, 0, 0],
      1
    ];
    exports2.AutoRepairConfiguration$ = [
      3,
      n032,
      _ARC,
      0,
      [_aS],
      [0]
    ];
    exports2.AutoScalingGroupProvider$ = [
      3,
      n032,
      _ASGP,
      0,
      [_aSGA, _mS, _mTP, _mD],
      [0, () => exports2.ManagedScaling$, 0, 0],
      1
    ];
    exports2.AutoScalingGroupProviderUpdate$ = [
      3,
      n032,
      _ASGPU,
      0,
      [_mS, _mTP, _mD],
      [() => exports2.ManagedScaling$, 0, 0]
    ];
    exports2.AwsVpcConfiguration$ = [
      3,
      n032,
      _AVC,
      0,
      [_su, _sG, _aPI],
      [64 | 0, 64 | 0, 0],
      1
    ];
    exports2.BaselineEbsBandwidthMbpsRequest$ = [
      3,
      n032,
      _BEBMR,
      0,
      [_mi, _ma],
      [1, 1]
    ];
    exports2.CanaryConfiguration$ = [
      3,
      n032,
      _CC,
      0,
      [_cP, _cBTIM],
      [1, 1]
    ];
    exports2.CapacityProvider$ = [
      3,
      n032,
      _CP,
      0,
      [_cPA, _n, _cl, _st, _aSGP, _mIP, _uS, _uSR, _ta, _t],
      [0, 0, 0, 0, () => exports2.AutoScalingGroupProvider$, [() => exports2.ManagedInstancesProvider$, 0], 0, 0, () => Tags, 0]
    ];
    exports2.CapacityProviderStrategyItem$ = [
      3,
      n032,
      _CPSI,
      0,
      [_cPa, _w, _b],
      [0, 1, 1],
      1
    ];
    exports2.CapacityReservationRequest$ = [
      3,
      n032,
      _CRR,
      0,
      [_rGA, _rP],
      [0, 0]
    ];
    exports2.Cluster$ = [
      3,
      n032,
      _C11,
      0,
      [_cA, _cN, _co13, _st, _rCIC, _rTC, _pTC, _aSC, _sta, _ta, _set, _cPap, _dCPS, _a10, _aSt, _sCD],
      [0, 0, () => exports2.ClusterConfiguration$, 0, 1, 1, 1, 1, () => Statistics, () => Tags, () => ClusterSettings, 64 | 0, () => CapacityProviderStrategy, () => Attachments, 0, () => exports2.ClusterServiceConnectDefaults$]
    ];
    exports2.ClusterConfiguration$ = [
      3,
      n032,
      _CCl,
      0,
      [_eCC, _mSC],
      [() => exports2.ExecuteCommandConfiguration$, () => exports2.ManagedStorageConfiguration$]
    ];
    exports2.ClusterServiceConnectDefaults$ = [
      3,
      n032,
      _CSCD,
      0,
      [_na],
      [0]
    ];
    exports2.ClusterServiceConnectDefaultsRequest$ = [
      3,
      n032,
      _CSCDR,
      0,
      [_na],
      [0],
      1
    ];
    exports2.ClusterSetting$ = [
      3,
      n032,
      _CS4,
      0,
      [_n, _v],
      [0, 0]
    ];
    exports2.Container$ = [
      3,
      n032,
      _Co,
      0,
      [_cAo, _tA, _n, _im, _iD, _rIu, _lS, _eC, _r4, _nB, _nI, _hS, _mA, _cp, _me, _mR, _gI],
      [0, 0, 0, 0, 0, 0, 0, 1, 0, () => NetworkBindings, () => NetworkInterfaces, 0, () => ManagedAgents, 0, 0, 0, 64 | 0]
    ];
    exports2.ContainerDefinition$ = [
      3,
      n032,
      _CD,
      0,
      [_n, _im, _rC10, _cp, _me, _mR, _l, _pM, _es, _rPe, _eP, _com, _en, _eF, _mP, _vF, _lP, _sec, _dO, _sT19, _sTt, _vC, _h22, _u, _wD, _dN, _p, _rRF, _dS, _dSD, _eH, _dSO, _in, _pT, _dL, _ul, _lC, _hC, _sC, _rR, _fC, _cS4],
      [0, 0, [() => exports2.RepositoryCredentials$, 0], 1, 1, 1, 64 | 0, () => PortMappingList, 2, () => exports2.ContainerRestartPolicy$, 64 | 0, 64 | 0, [() => EnvironmentVariables, 0], () => EnvironmentFiles, () => MountPointList, () => VolumeFromList, () => exports2.LinuxParameters$, () => SecretList, () => ContainerDependencies, 1, 1, 0, 0, 0, 0, 2, 2, 2, 64 | 0, 64 | 0, () => HostEntryList, 64 | 0, 2, 2, 128 | 0, () => UlimitList, () => exports2.LogConfiguration$, () => exports2.HealthCheck$, () => SystemControls, () => ResourceRequirements, () => exports2.FirelensConfiguration$, 64 | 0]
    ];
    exports2.ContainerDependency$ = [
      3,
      n032,
      _CDo,
      0,
      [_cNo, _con],
      [0, 0],
      2
    ];
    exports2.ContainerImage$ = [
      3,
      n032,
      _CI,
      0,
      [_cNo, _iD, _im],
      [0, 0, 0]
    ];
    exports2.ContainerInstance$ = [
      3,
      n032,
      _CIo,
      0,
      [_cIA, _eII, _cPN, _ve, _vI, _rRe, _rReg, _st, _sR, _aC, _rTC, _pTC, _aUS, _at, _rAe, _a10, _ta, _hS],
      [0, 0, 0, 1, () => exports2.VersionInfo$, () => Resources, () => Resources, 0, 0, 2, 1, 1, 0, () => Attributes, 4, () => Attachments, () => Tags, () => exports2.ContainerInstanceHealthStatus$]
    ];
    exports2.ContainerInstanceHealthStatus$ = [
      3,
      n032,
      _CIHS,
      0,
      [_oS, _d],
      [0, () => InstanceHealthCheckResultList]
    ];
    exports2.ContainerOverride$ = [
      3,
      n032,
      _CO,
      0,
      [_n, _com, _en, _eF, _cp, _me, _mR, _rR],
      [0, 64 | 0, [() => EnvironmentVariables, 0], () => EnvironmentFiles, 1, 1, 1, () => ResourceRequirements]
    ];
    exports2.ContainerRestartPolicy$ = [
      3,
      n032,
      _CRP,
      0,
      [_ena, _iEC, _rAP],
      [2, 64 | 1, 1],
      1
    ];
    exports2.ContainerStateChange$ = [
      3,
      n032,
      _CSC,
      0,
      [_cNo, _iD, _rIu, _eC, _nB, _r4, _st],
      [0, 0, 0, 1, () => NetworkBindings, 0, 0]
    ];
    exports2.CreateCapacityProviderRequest$ = [
      3,
      n032,
      _CCPR,
      0,
      [_n, _cl, _aSGP, _mIP, _ta],
      [0, 0, () => exports2.AutoScalingGroupProvider$, [() => exports2.CreateManagedInstancesProviderConfiguration$, 0], () => Tags],
      1
    ];
    exports2.CreateCapacityProviderResponse$ = [
      3,
      n032,
      _CCPRr,
      0,
      [_cPa],
      [[() => exports2.CapacityProvider$, 0]]
    ];
    exports2.CreateClusterRequest$ = [
      3,
      n032,
      _CCR,
      0,
      [_cN, _ta, _set, _co13, _cPap, _dCPS, _sCD],
      [0, () => Tags, () => ClusterSettings, () => exports2.ClusterConfiguration$, 64 | 0, () => CapacityProviderStrategy, () => exports2.ClusterServiceConnectDefaultsRequest$]
    ];
    exports2.CreateClusterResponse$ = [
      3,
      n032,
      _CCRr,
      0,
      [_cl],
      [() => exports2.Cluster$]
    ];
    exports2.CreateDaemonRequest$ = [
      3,
      n032,
      _CDR,
      0,
      [_dNa, _dTDA, _cPAa, _cA, _dC4, _ta, _pTr, _eECSMT, _eEC, _cT],
      [0, 0, 64 | 0, 0, () => exports2.DaemonDeploymentConfiguration$, () => Tags, 0, 2, 2, 0],
      3
    ];
    exports2.CreateDaemonResponse$ = [
      3,
      n032,
      _CDRr,
      0,
      [_dA, _st, _cAr, _dAe],
      [0, 0, 4, 0]
    ];
    exports2.CreatedAt$ = [
      3,
      n032,
      _CA10,
      0,
      [_be, _af],
      [4, 4]
    ];
    exports2.CreateExpressGatewayServiceRequest$ = [
      3,
      n032,
      _CEGSR,
      0,
      [_eRA, _iRA, _pC, _sN, _cl, _hCP, _tRA, _nC, _cp, _me, _sTc, _ta],
      [0, 0, [() => exports2.ExpressGatewayContainer$, 0], 0, 0, 0, 0, () => exports2.ExpressGatewayServiceNetworkConfiguration$, 0, 0, () => exports2.ExpressGatewayScalingTarget$, () => Tags],
      3
    ];
    exports2.CreateExpressGatewayServiceResponse$ = [
      3,
      n032,
      _CEGSRr,
      0,
      [_ser],
      [[() => exports2.ECSExpressGatewayService$, 0]]
    ];
    exports2.CreateManagedInstancesProviderConfiguration$ = [
      3,
      n032,
      _CMIPC,
      0,
      [_iRA, _iLT, _pTr, _iO, _aRC],
      [0, [() => exports2.InstanceLaunchTemplate$, 0], 0, () => exports2.InfrastructureOptimization$, () => exports2.AutoRepairConfiguration$],
      2
    ];
    exports2.CreateServiceRequest$ = [
      3,
      n032,
      _CSR,
      0,
      [_sN, _cl, _tD, _aZR, _lB, _sRe, _dCe, _cT, _lT, _cPS, _pV, _ro, _dC4, _pCl, _pS, _nC, _hCGPS, _sS, _dCep, _ta, _eECSMT, _pTr, _eEC, _sCC, _vCo, _vLC],
      [0, 0, 0, 0, () => LoadBalancers, () => ServiceRegistries, 1, 0, 0, () => CapacityProviderStrategy, 0, 0, () => exports2.DeploymentConfiguration$, () => PlacementConstraints, () => PlacementStrategies, () => exports2.NetworkConfiguration$, 1, 0, () => exports2.DeploymentController$, () => Tags, 2, 0, 2, () => exports2.ServiceConnectConfiguration$, () => ServiceVolumeConfigurations, () => VpcLatticeConfigurations],
      1
    ];
    exports2.CreateServiceResponse$ = [
      3,
      n032,
      _CSRr,
      0,
      [_ser],
      [() => exports2.Service$]
    ];
    exports2.CreateTaskSetRequest$ = [
      3,
      n032,
      _CTSR,
      0,
      [_ser, _cl, _tD, _eI13, _nC, _lB, _sRe, _lT, _cPS, _pV, _sc4, _cT, _ta],
      [0, 0, 0, 0, () => exports2.NetworkConfiguration$, () => LoadBalancers, () => ServiceRegistries, 0, () => CapacityProviderStrategy, 0, () => exports2.Scale$, 0, () => Tags],
      3
    ];
    exports2.CreateTaskSetResponse$ = [
      3,
      n032,
      _CTSRr,
      0,
      [_tS],
      [() => exports2.TaskSet$]
    ];
    exports2.DaemonAlarmConfiguration$ = [
      3,
      n032,
      _DAC,
      0,
      [_aN, _enab],
      [64 | 0, 2]
    ];
    exports2.DaemonCapacityProvider$ = [
      3,
      n032,
      _DCP,
      0,
      [_ar, _rCu],
      [0, 1]
    ];
    exports2.DaemonCircuitBreaker$ = [
      3,
      n032,
      _DCB,
      0,
      [_fCa, _st, _th],
      [1, 0, 1]
    ];
    exports2.DaemonContainerDefinition$ = [
      3,
      n032,
      _DCD,
      0,
      [_im, _n, _me, _mR, _rC10, _hC, _cp, _es, _eP, _com, _wD, _eF, _en, _sec, _rRF, _mP, _lC, _fC, _p, _u, _ul, _lP, _dO, _sT19, _sTt, _sC, _in, _pT, _rPe],
      [0, 0, 1, 1, [() => exports2.RepositoryCredentials$, 0], () => exports2.HealthCheck$, 1, 2, 64 | 0, 64 | 0, 0, () => EnvironmentFiles, [() => EnvironmentVariables, 0], () => SecretList, 2, () => MountPointList, () => exports2.LogConfiguration$, () => exports2.FirelensConfiguration$, 2, 0, () => UlimitList, () => exports2.DaemonLinuxParameters$, () => ContainerDependencies, 1, 1, () => SystemControls, 2, 2, () => exports2.ContainerRestartPolicy$],
      1
    ];
    exports2.DaemonContainerImage$ = [
      3,
      n032,
      _DCI,
      0,
      [_cNo, _iD, _im],
      [0, 0, 0]
    ];
    exports2.DaemonDeployment$ = [
      3,
      n032,
      _DD,
      0,
      [_dDA, _cA, _st, _sR, _tDR, _sDR, _cB, _al, _rol, _dC4, _cAr, _sA, _sAt, _fA],
      [0, 0, 0, 0, () => exports2.DaemonDeploymentRevisionDetail$, () => DaemonDeploymentRevisionDetailList, () => exports2.DaemonCircuitBreaker$, () => exports2.DaemonDeploymentAlarms$, () => exports2.DaemonRollback$, () => exports2.DaemonDeploymentConfiguration$, 4, 4, 4, 4]
    ];
    exports2.DaemonDeploymentAlarms$ = [
      3,
      n032,
      _DDA,
      0,
      [_st, _aN, _tAN],
      [0, 64 | 0, 64 | 0]
    ];
    exports2.DaemonDeploymentCapacityProvider$ = [
      3,
      n032,
      _DDCP,
      0,
      [_ar, _rIC, _dIC],
      [0, 1, 1]
    ];
    exports2.DaemonDeploymentConfiguration$ = [
      3,
      n032,
      _DDC,
      0,
      [_dP, _al, _bTIM],
      [1, () => exports2.DaemonAlarmConfiguration$, 1]
    ];
    exports2.DaemonDeploymentRevisionDetail$ = [
      3,
      n032,
      _DDRD,
      0,
      [_ar, _cPap, _tRIC, _tDIC],
      [0, () => DaemonDeploymentCapacityProviderList, 1, 1]
    ];
    exports2.DaemonDeploymentSummary$ = [
      3,
      n032,
      _DDS,
      0,
      [_dDA, _dA, _cA, _st, _sR, _tDRA, _cAr, _sA, _sAt, _fA],
      [0, 0, 0, 0, 0, 0, 4, 4, 4, 4]
    ];
    exports2.DaemonDetail$ = [
      3,
      n032,
      _DDa,
      0,
      [_dA, _cA, _st, _cR, _dAe, _cAr, _uA],
      [0, 0, 0, () => DaemonRevisionDetailList, 0, 4, 4]
    ];
    exports2.DaemonLinuxParameters$ = [
      3,
      n032,
      _DLP,
      0,
      [_ca, _de, _iPE, _tm],
      [() => exports2.KernelCapabilities$, () => DevicesList, 2, () => TmpfsList]
    ];
    exports2.DaemonRevision$ = [
      3,
      n032,
      _DR,
      0,
      [_dRA, _cA, _dA, _dTDA, _cAr, _cI13, _pTr, _eECSMT, _eEC],
      [0, 0, 0, 0, 4, () => DaemonContainerImages, 0, 2, 2]
    ];
    exports2.DaemonRevisionDetail$ = [
      3,
      n032,
      _DRD,
      0,
      [_ar, _cPap, _tRC],
      [0, () => DaemonCapacityProviderList, 1]
    ];
    exports2.DaemonRollback$ = [
      3,
      n032,
      _DRa,
      0,
      [_r4, _sA, _rTDRA, _rCP],
      [0, 4, 0, 64 | 0]
    ];
    exports2.DaemonSummary$ = [
      3,
      n032,
      _DS10,
      0,
      [_dA, _st, _cAr, _uA],
      [0, 0, 4, 4]
    ];
    exports2.DaemonTaskDefinition$ = [
      3,
      n032,
      _DTD,
      0,
      [_dTDA, _f, _re, _tRA, _eRA, _cD, _vo, _cp, _me, _st, _rAe, _dRAe, _rB],
      [0, 0, 1, 0, 0, [() => DaemonContainerDefinitionList, 0], () => DaemonVolumeList, 0, 0, 0, 4, 4, 0]
    ];
    exports2.DaemonTaskDefinitionSummary$ = [
      3,
      n032,
      _DTDS,
      0,
      [_ar, _rAe, _rB, _dRAe, _st],
      [0, 4, 0, 4, 0]
    ];
    exports2.DaemonVolume$ = [
      3,
      n032,
      _DV,
      0,
      [_n, _ho],
      [0, () => exports2.HostVolumeProperties$]
    ];
    exports2.DeleteAccountSettingRequest$ = [
      3,
      n032,
      _DASR,
      0,
      [_n, _pA],
      [0, 0],
      1
    ];
    exports2.DeleteAccountSettingResponse$ = [
      3,
      n032,
      _DASRe,
      0,
      [_sett],
      [() => exports2.Setting$]
    ];
    exports2.DeleteAttributesRequest$ = [
      3,
      n032,
      _DAR,
      0,
      [_at, _cl],
      [() => Attributes, 0],
      1
    ];
    exports2.DeleteAttributesResponse$ = [
      3,
      n032,
      _DARe,
      0,
      [_at],
      [() => Attributes]
    ];
    exports2.DeleteCapacityProviderRequest$ = [
      3,
      n032,
      _DCPR,
      0,
      [_cPa, _cl],
      [0, 0],
      1
    ];
    exports2.DeleteCapacityProviderResponse$ = [
      3,
      n032,
      _DCPRe,
      0,
      [_cPa],
      [[() => exports2.CapacityProvider$, 0]]
    ];
    exports2.DeleteClusterRequest$ = [
      3,
      n032,
      _DCR,
      0,
      [_cl],
      [0],
      1
    ];
    exports2.DeleteClusterResponse$ = [
      3,
      n032,
      _DCRe,
      0,
      [_cl],
      [() => exports2.Cluster$]
    ];
    exports2.DeleteDaemonRequest$ = [
      3,
      n032,
      _DDR,
      0,
      [_dA],
      [0],
      1
    ];
    exports2.DeleteDaemonResponse$ = [
      3,
      n032,
      _DDRe,
      0,
      [_dA, _st, _cAr, _uA, _dAe],
      [0, 0, 4, 4, 0]
    ];
    exports2.DeleteDaemonTaskDefinitionRequest$ = [
      3,
      n032,
      _DDTDR,
      0,
      [_dTD],
      [0],
      1
    ];
    exports2.DeleteDaemonTaskDefinitionResponse$ = [
      3,
      n032,
      _DDTDRe,
      0,
      [_dTDA],
      [0]
    ];
    exports2.DeleteExpressGatewayServiceRequest$ = [
      3,
      n032,
      _DEGSR,
      0,
      [_sAe],
      [0],
      1
    ];
    exports2.DeleteExpressGatewayServiceResponse$ = [
      3,
      n032,
      _DEGSRe,
      0,
      [_ser],
      [[() => exports2.ECSExpressGatewayService$, 0]]
    ];
    exports2.DeleteServiceRequest$ = [
      3,
      n032,
      _DSR,
      0,
      [_ser, _cl, _fo],
      [0, 0, 2],
      1
    ];
    exports2.DeleteServiceResponse$ = [
      3,
      n032,
      _DSRe,
      0,
      [_ser],
      [() => exports2.Service$]
    ];
    exports2.DeleteTaskDefinitionsRequest$ = [
      3,
      n032,
      _DTDR,
      0,
      [_tDa],
      [64 | 0],
      1
    ];
    exports2.DeleteTaskDefinitionsResponse$ = [
      3,
      n032,
      _DTDRe,
      0,
      [_tDa, _fa],
      [[() => TaskDefinitionList, 0], () => Failures]
    ];
    exports2.DeleteTaskSetRequest$ = [
      3,
      n032,
      _DTSR,
      0,
      [_cl, _ser, _tS, _fo],
      [0, 0, 0, 2],
      3
    ];
    exports2.DeleteTaskSetResponse$ = [
      3,
      n032,
      _DTSRe,
      0,
      [_tS],
      [() => exports2.TaskSet$]
    ];
    exports2.Deployment$ = [
      3,
      n032,
      _D,
      0,
      [_i, _st, _tD, _dCe, _pCe, _rCu, _fT, _cAr, _uA, _cPS, _lT, _pV, _pF, _nC, _rS, _rSR, _sCC, _sCR, _vCo, _fES, _vLC],
      [0, 0, 0, 1, 1, 1, 1, 4, 4, () => CapacityProviderStrategy, 0, 0, 0, () => exports2.NetworkConfiguration$, 0, 0, () => exports2.ServiceConnectConfiguration$, () => ServiceConnectServiceResourceList, () => ServiceVolumeConfigurations, () => exports2.DeploymentEphemeralStorage$, () => VpcLatticeConfigurations]
    ];
    exports2.DeploymentAlarms$ = [
      3,
      n032,
      _DA,
      0,
      [_aN, _rol, _enab],
      [64 | 0, 2, 2],
      3
    ];
    exports2.DeploymentCircuitBreaker$ = [
      3,
      n032,
      _DCBe,
      0,
      [_enab, _rol],
      [2, 2],
      2
    ];
    exports2.DeploymentConfiguration$ = [
      3,
      n032,
      _DC,
      0,
      [_dCB, _mPa, _mHP, _al, _str, _bTIM, _lH, _lCi, _cC],
      [() => exports2.DeploymentCircuitBreaker$, 1, 1, () => exports2.DeploymentAlarms$, 0, 1, () => DeploymentLifecycleHookList, () => exports2.LinearConfiguration$, () => exports2.CanaryConfiguration$]
    ];
    exports2.DeploymentController$ = [
      3,
      n032,
      _DCe,
      0,
      [_t],
      [0],
      1
    ];
    exports2.DeploymentEphemeralStorage$ = [
      3,
      n032,
      _DES,
      0,
      [_kKI],
      [0]
    ];
    exports2.DeploymentLifecycleHook$ = [
      3,
      n032,
      _DLH,
      0,
      [_hTA, _rA, _lSi, _hD],
      [0, 0, 64 | 0, 15]
    ];
    exports2.DeregisterContainerInstanceRequest$ = [
      3,
      n032,
      _DCIR,
      0,
      [_cIo, _cl, _fo],
      [0, 0, 2],
      1
    ];
    exports2.DeregisterContainerInstanceResponse$ = [
      3,
      n032,
      _DCIRe,
      0,
      [_cIo],
      [() => exports2.ContainerInstance$]
    ];
    exports2.DeregisterTaskDefinitionRequest$ = [
      3,
      n032,
      _DTDRer,
      0,
      [_tD],
      [0],
      1
    ];
    exports2.DeregisterTaskDefinitionResponse$ = [
      3,
      n032,
      _DTDRere,
      0,
      [_tD],
      [[() => exports2.TaskDefinition$, 0]]
    ];
    exports2.DescribeCapacityProvidersRequest$ = [
      3,
      n032,
      _DCPRes,
      0,
      [_cPap, _cl, _inc, _mRa, _nT],
      [64 | 0, 0, 64 | 0, 1, 0]
    ];
    exports2.DescribeCapacityProvidersResponse$ = [
      3,
      n032,
      _DCPResc,
      0,
      [_cPap, _fa, _nT],
      [[() => CapacityProviders, 0], () => Failures, 0]
    ];
    exports2.DescribeClustersRequest$ = [
      3,
      n032,
      _DCRes,
      0,
      [_clu, _inc],
      [64 | 0, 64 | 0]
    ];
    exports2.DescribeClustersResponse$ = [
      3,
      n032,
      _DCResc,
      0,
      [_clu, _fa],
      [() => Clusters, () => Failures]
    ];
    exports2.DescribeContainerInstancesRequest$ = [
      3,
      n032,
      _DCIRes,
      0,
      [_cIon, _cl, _inc],
      [64 | 0, 0, 64 | 0],
      1
    ];
    exports2.DescribeContainerInstancesResponse$ = [
      3,
      n032,
      _DCIResc,
      0,
      [_cIon, _fa],
      [() => ContainerInstances, () => Failures]
    ];
    exports2.DescribeDaemonDeploymentsRequest$ = [
      3,
      n032,
      _DDDR,
      0,
      [_dDAa],
      [64 | 0],
      1
    ];
    exports2.DescribeDaemonDeploymentsResponse$ = [
      3,
      n032,
      _DDDRe,
      0,
      [_fa, _dD],
      [() => Failures, () => DaemonDeploymentList]
    ];
    exports2.DescribeDaemonRequest$ = [
      3,
      n032,
      _DDRes,
      0,
      [_dA],
      [0],
      1
    ];
    exports2.DescribeDaemonResponse$ = [
      3,
      n032,
      _DDResc,
      0,
      [_da],
      [() => exports2.DaemonDetail$]
    ];
    exports2.DescribeDaemonRevisionsRequest$ = [
      3,
      n032,
      _DDRR,
      0,
      [_dRAa],
      [64 | 0],
      1
    ];
    exports2.DescribeDaemonRevisionsResponse$ = [
      3,
      n032,
      _DDRRe,
      0,
      [_dR, _fa],
      [() => DaemonRevisions, () => Failures]
    ];
    exports2.DescribeDaemonTaskDefinitionRequest$ = [
      3,
      n032,
      _DDTDRes,
      0,
      [_dTD],
      [0],
      1
    ];
    exports2.DescribeDaemonTaskDefinitionResponse$ = [
      3,
      n032,
      _DDTDResc,
      0,
      [_dTD],
      [[() => exports2.DaemonTaskDefinition$, 0]]
    ];
    exports2.DescribeExpressGatewayServiceRequest$ = [
      3,
      n032,
      _DEGSRes,
      0,
      [_sAe, _inc],
      [0, 64 | 0],
      1
    ];
    exports2.DescribeExpressGatewayServiceResponse$ = [
      3,
      n032,
      _DEGSResc,
      0,
      [_ser],
      [[() => exports2.ECSExpressGatewayService$, 0]]
    ];
    exports2.DescribeServiceDeploymentsRequest$ = [
      3,
      n032,
      _DSDR,
      0,
      [_sDA],
      [64 | 0],
      1
    ];
    exports2.DescribeServiceDeploymentsResponse$ = [
      3,
      n032,
      _DSDRe,
      0,
      [_sD, _fa],
      [() => ServiceDeployments, () => Failures]
    ];
    exports2.DescribeServiceRevisionsRequest$ = [
      3,
      n032,
      _DSRR,
      0,
      [_sRA],
      [64 | 0],
      1
    ];
    exports2.DescribeServiceRevisionsResponse$ = [
      3,
      n032,
      _DSRRe,
      0,
      [_sRer, _fa],
      [() => ServiceRevisions, () => Failures]
    ];
    exports2.DescribeServicesRequest$ = [
      3,
      n032,
      _DSRes,
      0,
      [_serv, _cl, _inc],
      [64 | 0, 0, 64 | 0],
      1
    ];
    exports2.DescribeServicesResponse$ = [
      3,
      n032,
      _DSResc,
      0,
      [_serv, _fa],
      [() => Services, () => Failures]
    ];
    exports2.DescribeTaskDefinitionRequest$ = [
      3,
      n032,
      _DTDRes,
      0,
      [_tD, _inc],
      [0, 64 | 0],
      1
    ];
    exports2.DescribeTaskDefinitionResponse$ = [
      3,
      n032,
      _DTDResc,
      0,
      [_tD, _ta],
      [[() => exports2.TaskDefinition$, 0], () => Tags]
    ];
    exports2.DescribeTaskSetsRequest$ = [
      3,
      n032,
      _DTSRes,
      0,
      [_cl, _ser, _tSa, _inc],
      [0, 0, 64 | 0, 64 | 0],
      2
    ];
    exports2.DescribeTaskSetsResponse$ = [
      3,
      n032,
      _DTSResc,
      0,
      [_tSa, _fa],
      [() => TaskSets, () => Failures]
    ];
    exports2.DescribeTasksRequest$ = [
      3,
      n032,
      _DTR,
      0,
      [_tas, _cl, _inc],
      [64 | 0, 0, 64 | 0],
      1
    ];
    exports2.DescribeTasksResponse$ = [
      3,
      n032,
      _DTRe,
      0,
      [_tas, _fa],
      [[() => Tasks, 0], () => Failures]
    ];
    exports2.Device$ = [
      3,
      n032,
      _De,
      0,
      [_hP, _cPo, _pe],
      [0, 0, 64 | 0],
      1
    ];
    exports2.DiscoverPollEndpointRequest$ = [
      3,
      n032,
      _DPER,
      0,
      [_cIo, _cl],
      [0, 0]
    ];
    exports2.DiscoverPollEndpointResponse$ = [
      3,
      n032,
      _DPERi,
      0,
      [_end, _tE, _sCE],
      [0, 0, 0]
    ];
    exports2.DockerVolumeConfiguration$ = [
      3,
      n032,
      _DVC,
      0,
      [_sco, _au, _dr, _dOr, _la],
      [0, 2, 0, 128 | 0, 128 | 0]
    ];
    exports2.EBSTagSpecification$ = [
      3,
      n032,
      _EBSTS,
      0,
      [_rT13, _ta, _pTr],
      [0, () => Tags, 0],
      1
    ];
    exports2.ECSExpressGatewayService$ = [
      3,
      n032,
      _ECSEGS,
      0,
      [_cl, _sN, _sAe, _iRA, _st, _cDu, _aCc, _ta, _cAr, _uA],
      [0, 0, 0, 0, () => exports2.ExpressGatewayServiceStatus$, 0, [() => ExpressGatewayServiceConfigurations, 0], () => Tags, 4, 4]
    ];
    exports2.ECSManagedResources$ = [
      3,
      n032,
      _ECSMR,
      0,
      [_iP, _aSu, _mAe, _sSG, _lG],
      [() => ManagedIngressPaths, () => exports2.ManagedAutoScaling$, () => ManagedMetricAlarms, () => ManagedSecurityGroups, () => ManagedLogGroups]
    ];
    exports2.EFSAuthorizationConfig$ = [
      3,
      n032,
      _EFSAC,
      0,
      [_aPIc, _ia],
      [0, 0]
    ];
    exports2.EFSVolumeConfiguration$ = [
      3,
      n032,
      _EFSVC,
      0,
      [_fSI, _rD, _tEr, _tEP, _aCu],
      [0, 0, 0, 1, () => exports2.EFSAuthorizationConfig$],
      1
    ];
    exports2.EnvironmentFile$ = [
      3,
      n032,
      _EF,
      0,
      [_v, _t],
      [0, 0],
      2
    ];
    exports2.EphemeralStorage$ = [
      3,
      n032,
      _ES,
      0,
      [_sIGB],
      [1],
      1
    ];
    exports2.ExecuteCommandConfiguration$ = [
      3,
      n032,
      _ECC,
      0,
      [_kKI, _lo, _lC],
      [0, 0, () => exports2.ExecuteCommandLogConfiguration$]
    ];
    exports2.ExecuteCommandLogConfiguration$ = [
      3,
      n032,
      _ECLC,
      0,
      [_cWLGN, _cWEE, _sBN, _sEE, _sKP],
      [0, 2, 0, 2, 0]
    ];
    exports2.ExecuteCommandRequest$ = [
      3,
      n032,
      _ECR,
      0,
      [_com, _in, _task, _cl, _cont],
      [0, 2, 0, 0, 0],
      3
    ];
    exports2.ExecuteCommandResponse$ = [
      3,
      n032,
      _ECRx,
      0,
      [_cA, _cAo, _cNo, _in, _ses, _tA],
      [0, 0, 0, 2, [() => exports2.Session$, 0], 0]
    ];
    exports2.ExpressGatewayContainer$ = [
      3,
      n032,
      _EGC,
      0,
      [_im, _cPon, _aLC, _rC10, _com, _en, _sec],
      [0, 1, () => exports2.ExpressGatewayServiceAwsLogsConfiguration$, () => exports2.ExpressGatewayRepositoryCredentials$, 64 | 0, [() => EnvironmentVariables, 0], () => SecretList],
      1
    ];
    exports2.ExpressGatewayRepositoryCredentials$ = [
      3,
      n032,
      _EGRC,
      0,
      [_cPr],
      [0]
    ];
    exports2.ExpressGatewayScalingTarget$ = [
      3,
      n032,
      _EGST,
      0,
      [_mTC, _mTCa, _aSM, _aSTV],
      [1, 1, 0, 1]
    ];
    exports2.ExpressGatewayServiceAwsLogsConfiguration$ = [
      3,
      n032,
      _EGSALC,
      0,
      [_lGo, _lSP],
      [0, 0],
      2
    ];
    exports2.ExpressGatewayServiceConfiguration$ = [
      3,
      n032,
      _EGSC,
      0,
      [_sRAe, _eRA, _tRA, _cp, _me, _nC, _hCP, _pC, _sTc, _iP, _cAr],
      [0, 0, 0, 0, 0, () => exports2.ExpressGatewayServiceNetworkConfiguration$, 0, [() => exports2.ExpressGatewayContainer$, 0], () => exports2.ExpressGatewayScalingTarget$, () => IngressPathSummaries, 4]
    ];
    exports2.ExpressGatewayServiceNetworkConfiguration$ = [
      3,
      n032,
      _EGSNC,
      0,
      [_sG, _su],
      [64 | 0, 64 | 0]
    ];
    exports2.ExpressGatewayServiceStatus$ = [
      3,
      n032,
      _EGSS,
      0,
      [_sCt, _sR],
      [0, 0]
    ];
    exports2.Failure$ = [
      3,
      n032,
      _F,
      0,
      [_ar, _r4, _det],
      [0, 0, 0]
    ];
    exports2.FirelensConfiguration$ = [
      3,
      n032,
      _FC,
      0,
      [_t, _o],
      [0, 128 | 0],
      1
    ];
    exports2.FSxWindowsFileServerAuthorizationConfig$ = [
      3,
      n032,
      _FSWFSAC,
      0,
      [_cPr, _do],
      [0, 0],
      2
    ];
    exports2.FSxWindowsFileServerVolumeConfiguration$ = [
      3,
      n032,
      _FSWFSVC,
      0,
      [_fSI, _rD, _aCu],
      [0, 0, () => exports2.FSxWindowsFileServerAuthorizationConfig$],
      3
    ];
    exports2.GetTaskProtectionRequest$ = [
      3,
      n032,
      _GTPR,
      0,
      [_cl, _tas],
      [0, 64 | 0],
      1
    ];
    exports2.GetTaskProtectionResponse$ = [
      3,
      n032,
      _GTPRe,
      0,
      [_pTro, _fa],
      [() => ProtectedTasks, () => Failures]
    ];
    exports2.HealthCheck$ = [
      3,
      n032,
      _HC,
      0,
      [_com, _int, _ti, _ret, _sP],
      [64 | 0, 1, 1, 1, 1],
      1
    ];
    exports2.HostEntry$ = [
      3,
      n032,
      _HE,
      0,
      [_h22, _iA],
      [0, 0],
      2
    ];
    exports2.HostVolumeProperties$ = [
      3,
      n032,
      _HVP,
      0,
      [_sPo],
      [0]
    ];
    exports2.InferenceAccelerator$ = [
      3,
      n032,
      _IA,
      0,
      [_dNe, _dT],
      [0, 0],
      2
    ];
    exports2.InferenceAcceleratorOverride$ = [
      3,
      n032,
      _IAO,
      0,
      [_dNe, _dT],
      [0, 0]
    ];
    exports2.InfrastructureOptimization$ = [
      3,
      n032,
      _IO,
      0,
      [_sIA],
      [1]
    ];
    exports2.IngressPathSummary$ = [
      3,
      n032,
      _IPS,
      0,
      [_aT22, _end],
      [0, 0],
      2
    ];
    exports2.InstanceHealthCheckResult$ = [
      3,
      n032,
      _IHCR,
      0,
      [_t, _st, _sR, _lU, _lSC],
      [0, 0, 0, 4, 4]
    ];
    exports2.InstanceLaunchTemplate$ = [
      3,
      n032,
      _ILT,
      0,
      [_eIPA, _nC, _sCto, _lSCo, _mo, _cOT, _iMTP, _iR, _fE, _cRa],
      [0, () => exports2.ManagedInstancesNetworkConfiguration$, () => exports2.ManagedInstancesStorageConfiguration$, () => exports2.ManagedInstancesLocalStorageConfiguration$, 0, 0, 2, [() => exports2.InstanceRequirementsRequest$, 0], 2, () => exports2.CapacityReservationRequest$],
      2
    ];
    exports2.InstanceLaunchTemplateUpdate$ = [
      3,
      n032,
      _ILTU,
      0,
      [_eIPA, _nC, _sCto, _iMTP, _lSCo, _mo, _iR, _cRa],
      [0, () => exports2.ManagedInstancesNetworkConfiguration$, () => exports2.ManagedInstancesStorageConfiguration$, 2, () => exports2.ManagedInstancesLocalStorageConfiguration$, 0, [() => exports2.InstanceRequirementsRequest$, 0], () => exports2.CapacityReservationRequest$]
    ];
    exports2.InstanceRequirementsRequest$ = [
      3,
      n032,
      _IRR,
      0,
      [_vCC, _mMB, _cM, _mGBPVC, _eIT, _iG, _sMPPOLP, _oDMPPOLP, _bM, _bP, _rHS, _nIC, _lSo, _lST, _tLSGB, _bEBM, _aTc, _aCcc, _aM, _aNc, _aTMMB, _nBG, _aIT, _mSPAPOOODP],
      [() => exports2.VCpuCountRangeRequest$, () => exports2.MemoryMiBRequest$, [() => CpuManufacturerSet, { [_xN]: _CM }], () => exports2.MemoryGiBPerVCpuRequest$, [() => ExcludedInstanceTypeSet, { [_xN]: _EIT }], [() => InstanceGenerationSet, { [_xN]: _IG }], 1, 1, 0, 0, 2, () => exports2.NetworkInterfaceCountRequest$, 0, [() => LocalStorageTypeSet, { [_xN]: _LST }], () => exports2.TotalLocalStorageGBRequest$, () => exports2.BaselineEbsBandwidthMbpsRequest$, [() => AcceleratorTypeSet, { [_xN]: _AT13 }], () => exports2.AcceleratorCountRequest$, [() => AcceleratorManufacturerSet, { [_xN]: _AM }], [() => AcceleratorNameSet, { [_xN]: _AN }], () => exports2.AcceleratorTotalMemoryMiBRequest$, () => exports2.NetworkBandwidthGbpsRequest$, [() => AllowedInstanceTypeSet, { [_xN]: _AIT }], 1],
      2
    ];
    exports2.KernelCapabilities$ = [
      3,
      n032,
      _KC,
      0,
      [_ad, _dro],
      [64 | 0, 64 | 0]
    ];
    exports2.KeyValuePair$ = [
      3,
      n032,
      _KVP,
      0,
      [_n, _v],
      [0, 0]
    ];
    exports2.LinearConfiguration$ = [
      3,
      n032,
      _LC,
      0,
      [_sPt, _sBTIM],
      [1, 1]
    ];
    exports2.LinuxParameters$ = [
      3,
      n032,
      _LP,
      0,
      [_ca, _de, _iPE, _sMS, _tm, _mSa, _sw],
      [() => exports2.KernelCapabilities$, () => DevicesList, 2, 1, () => TmpfsList, 1, 1]
    ];
    exports2.ListAccountSettingsRequest$ = [
      3,
      n032,
      _LASR,
      0,
      [_n, _v, _pA, _eS, _nT, _mRa],
      [0, 0, 0, 2, 0, 1]
    ];
    exports2.ListAccountSettingsResponse$ = [
      3,
      n032,
      _LASRi,
      0,
      [_set, _nT],
      [() => Settings2, 0]
    ];
    exports2.ListAttributesRequest$ = [
      3,
      n032,
      _LAR,
      0,
      [_tT13, _cl, _aNt, _aV, _nT, _mRa],
      [0, 0, 0, 0, 0, 1],
      1
    ];
    exports2.ListAttributesResponse$ = [
      3,
      n032,
      _LARi,
      0,
      [_at, _nT],
      [() => Attributes, 0]
    ];
    exports2.ListClustersRequest$ = [
      3,
      n032,
      _LCR,
      0,
      [_nT, _mRa],
      [0, 1]
    ];
    exports2.ListClustersResponse$ = [
      3,
      n032,
      _LCRi,
      0,
      [_cAl, _nT],
      [64 | 0, 0]
    ];
    exports2.ListContainerInstancesRequest$ = [
      3,
      n032,
      _LCIR,
      0,
      [_cl, _fi, _nT, _mRa, _st],
      [0, 0, 0, 1, 0]
    ];
    exports2.ListContainerInstancesResponse$ = [
      3,
      n032,
      _LCIRi,
      0,
      [_cIAo, _nT],
      [64 | 0, 0]
    ];
    exports2.ListDaemonDeploymentsRequest$ = [
      3,
      n032,
      _LDDR,
      0,
      [_dA, _st, _cAr, _mRa, _nT],
      [0, 64 | 0, () => exports2.CreatedAt$, 1, 0],
      1
    ];
    exports2.ListDaemonDeploymentsResponse$ = [
      3,
      n032,
      _LDDRi,
      0,
      [_nT, _dD],
      [0, () => DaemonDeploymentSummaryList]
    ];
    exports2.ListDaemonsRequest$ = [
      3,
      n032,
      _LDR,
      0,
      [_cA, _cPAa, _mRa, _nT],
      [0, 64 | 0, 1, 0]
    ];
    exports2.ListDaemonsResponse$ = [
      3,
      n032,
      _LDRi,
      0,
      [_dSL, _nT],
      [() => DaemonSummariesList, 0]
    ];
    exports2.ListDaemonTaskDefinitionsRequest$ = [
      3,
      n032,
      _LDTDR,
      0,
      [_fP, _f, _re, _st, _so, _nT, _mRa],
      [0, 0, 0, 0, 0, 0, 1]
    ];
    exports2.ListDaemonTaskDefinitionsResponse$ = [
      3,
      n032,
      _LDTDRi,
      0,
      [_dTDa, _nT],
      [() => DaemonTaskDefinitionSummaries, 0]
    ];
    exports2.ListServiceDeploymentsRequest$ = [
      3,
      n032,
      _LSDR,
      0,
      [_ser, _cl, _st, _cAr, _nT, _mRa],
      [0, 0, 64 | 0, () => exports2.CreatedAt$, 0, 1],
      1
    ];
    exports2.ListServiceDeploymentsResponse$ = [
      3,
      n032,
      _LSDRi,
      0,
      [_sD, _nT],
      [() => ServiceDeploymentsBrief, 0]
    ];
    exports2.ListServicesByNamespaceRequest$ = [
      3,
      n032,
      _LSBNR,
      0,
      [_na, _nT, _mRa],
      [0, 0, 1],
      1
    ];
    exports2.ListServicesByNamespaceResponse$ = [
      3,
      n032,
      _LSBNRi,
      0,
      [_sAer, _nT],
      [64 | 0, 0]
    ];
    exports2.ListServicesRequest$ = [
      3,
      n032,
      _LSR,
      0,
      [_cl, _nT, _mRa, _lT, _sS, _rMT],
      [0, 0, 1, 0, 0, 0]
    ];
    exports2.ListServicesResponse$ = [
      3,
      n032,
      _LSRi,
      0,
      [_sAer, _nT],
      [64 | 0, 0]
    ];
    exports2.ListTagsForResourceRequest$ = [
      3,
      n032,
      _LTFRR,
      0,
      [_rAes],
      [0],
      1
    ];
    exports2.ListTagsForResourceResponse$ = [
      3,
      n032,
      _LTFRRi,
      0,
      [_ta],
      [() => Tags]
    ];
    exports2.ListTaskDefinitionFamiliesRequest$ = [
      3,
      n032,
      _LTDFR,
      0,
      [_fP, _st, _nT, _mRa],
      [0, 0, 0, 1]
    ];
    exports2.ListTaskDefinitionFamiliesResponse$ = [
      3,
      n032,
      _LTDFRi,
      0,
      [_fam, _nT],
      [64 | 0, 0]
    ];
    exports2.ListTaskDefinitionsRequest$ = [
      3,
      n032,
      _LTDR,
      0,
      [_fP, _st, _so, _nT, _mRa],
      [0, 0, 0, 0, 1]
    ];
    exports2.ListTaskDefinitionsResponse$ = [
      3,
      n032,
      _LTDRi,
      0,
      [_tDA, _nT],
      [64 | 0, 0]
    ];
    exports2.ListTasksRequest$ = [
      3,
      n032,
      _LTR,
      0,
      [_cl, _cIo, _f, _nT, _mRa, _sB, _sN, _dSe, _lT, _dNa],
      [0, 0, 0, 0, 1, 0, 0, 0, 0, 0]
    ];
    exports2.ListTasksResponse$ = [
      3,
      n032,
      _LTRi,
      0,
      [_tAa, _nT],
      [64 | 0, 0]
    ];
    exports2.LoadBalancer$ = [
      3,
      n032,
      _LB,
      0,
      [_tGA, _lBN, _cNo, _cPon, _aCd],
      [0, 0, 0, 1, () => exports2.AdvancedConfiguration$]
    ];
    exports2.LogConfiguration$ = [
      3,
      n032,
      _LCo,
      0,
      [_lD, _o, _sO],
      [0, 128 | 0, () => SecretList],
      1
    ];
    exports2.ManagedAgent$ = [
      3,
      n032,
      _MA,
      0,
      [_lSA, _n, _r4, _lS],
      [4, 0, 0, 0]
    ];
    exports2.ManagedAgentStateChange$ = [
      3,
      n032,
      _MASC,
      0,
      [_cNo, _mAN, _st, _r4],
      [0, 0, 0, 0],
      3
    ];
    exports2.ManagedApplicationAutoScalingPolicy$ = [
      3,
      n032,
      _MAASP,
      0,
      [_st, _uA, _pTo, _tV, _met, _ar, _sR],
      [0, 4, 0, 1, 0, 0, 0],
      5
    ];
    exports2.ManagedAutoScaling$ = [
      3,
      n032,
      _MAS,
      0,
      [_sTca, _aASP],
      [() => exports2.ManagedScalableTarget$, () => ManagedApplicationAutoScalingPolicies]
    ];
    exports2.ManagedCertificate$ = [
      3,
      n032,
      _MC,
      0,
      [_st, _uA, _dNo, _ar, _sR],
      [0, 4, 0, 0, 0],
      3
    ];
    exports2.ManagedIngressPath$ = [
      3,
      n032,
      _MIP,
      0,
      [_aT22, _end, _lBo, _lBSG, _ce, _li, _ru, _tG],
      [0, 0, () => exports2.ManagedLoadBalancer$, () => ManagedSecurityGroups, () => exports2.ManagedCertificate$, () => exports2.ManagedListener$, () => exports2.ManagedListenerRule$, () => ManagedTargetGroups],
      2
    ];
    exports2.ManagedInstancesLocalStorageConfiguration$ = [
      3,
      n032,
      _MILSC,
      0,
      [_uLS],
      [2]
    ];
    exports2.ManagedInstancesNetworkConfiguration$ = [
      3,
      n032,
      _MINC,
      0,
      [_su, _sG],
      [64 | 0, 64 | 0]
    ];
    exports2.ManagedInstancesProvider$ = [
      3,
      n032,
      _MIPa,
      0,
      [_iRA, _iLT, _pTr, _iO, _aRC],
      [0, [() => exports2.InstanceLaunchTemplate$, 0], 0, () => exports2.InfrastructureOptimization$, () => exports2.AutoRepairConfiguration$]
    ];
    exports2.ManagedInstancesStorageConfiguration$ = [
      3,
      n032,
      _MISC,
      0,
      [_sSGB],
      [1]
    ];
    exports2.ManagedListener$ = [
      3,
      n032,
      _ML,
      0,
      [_st, _uA, _ar, _sR],
      [0, 4, 0, 0],
      2
    ];
    exports2.ManagedListenerRule$ = [
      3,
      n032,
      _MLR,
      0,
      [_st, _uA, _ar, _sR],
      [0, 4, 0, 0],
      2
    ];
    exports2.ManagedLoadBalancer$ = [
      3,
      n032,
      _MLB,
      0,
      [_st, _uA, _sch, _ar, _sR, _sI, _sGI],
      [0, 4, 0, 0, 0, 64 | 0, 64 | 0],
      3
    ];
    exports2.ManagedLogGroup$ = [
      3,
      n032,
      _MLG,
      0,
      [_st, _uA, _lGN, _ar, _sR],
      [0, 4, 0, 0, 0],
      3
    ];
    exports2.ManagedMetricAlarm$ = [
      3,
      n032,
      _MMA,
      0,
      [_st, _uA, _ar, _sR],
      [0, 4, 0, 0],
      2
    ];
    exports2.ManagedScalableTarget$ = [
      3,
      n032,
      _MST,
      0,
      [_st, _uA, _mC, _mCa, _ar, _sR],
      [0, 4, 1, 1, 0, 0],
      4
    ];
    exports2.ManagedScaling$ = [
      3,
      n032,
      _MS,
      0,
      [_st, _tC, _mSSS, _mSSSa, _iWP],
      [0, 1, 1, 1, 1]
    ];
    exports2.ManagedSecurityGroup$ = [
      3,
      n032,
      _MSG,
      0,
      [_st, _uA, _ar, _sR],
      [0, 4, 0, 0],
      2
    ];
    exports2.ManagedStorageConfiguration$ = [
      3,
      n032,
      _MSC,
      0,
      [_kKI, _fESKKI],
      [0, 0]
    ];
    exports2.ManagedTargetGroup$ = [
      3,
      n032,
      _MTG,
      0,
      [_st, _uA, _hCP, _hCPe, _po, _ar, _sR],
      [0, 4, 0, 1, 1, 0, 0],
      5
    ];
    exports2.MemoryGiBPerVCpuRequest$ = [
      3,
      n032,
      _MGBPVCR,
      0,
      [_mi, _ma],
      [1, 1]
    ];
    exports2.MemoryMiBRequest$ = [
      3,
      n032,
      _MMBR,
      0,
      [_mi, _ma],
      [1, 1],
      1
    ];
    exports2.MountPoint$ = [
      3,
      n032,
      _MP,
      0,
      [_sV, _cPo, _rO],
      [0, 0, 2]
    ];
    exports2.NetworkBandwidthGbpsRequest$ = [
      3,
      n032,
      _NBGR,
      0,
      [_mi, _ma],
      [1, 1]
    ];
    exports2.NetworkBinding$ = [
      3,
      n032,
      _NB,
      0,
      [_bIP, _cPon, _hPo, _pr, _cPR, _hPR],
      [0, 1, 1, 0, 0, 0]
    ];
    exports2.NetworkConfiguration$ = [
      3,
      n032,
      _NC,
      0,
      [_aCw],
      [() => exports2.AwsVpcConfiguration$]
    ];
    exports2.NetworkInterface$ = [
      3,
      n032,
      _NI,
      0,
      [_aI10, _pIA, _iAp],
      [0, 0, 0]
    ];
    exports2.NetworkInterfaceCountRequest$ = [
      3,
      n032,
      _NICR,
      0,
      [_mi, _ma],
      [1, 1]
    ];
    exports2.PlacementConstraint$ = [
      3,
      n032,
      _PC10,
      0,
      [_t, _ex10],
      [0, 0]
    ];
    exports2.PlacementStrategy$ = [
      3,
      n032,
      _PS,
      0,
      [_t, _fie],
      [0, 0]
    ];
    exports2.PlatformDevice$ = [
      3,
      n032,
      _PD,
      0,
      [_i, _t],
      [0, 0],
      2
    ];
    exports2.PortMapping$ = [
      3,
      n032,
      _PM,
      0,
      [_cPon, _hPo, _pr, _n, _aP, _cPR],
      [1, 1, 0, 0, 0, 0]
    ];
    exports2.ProtectedTask$ = [
      3,
      n032,
      _PT,
      0,
      [_tA, _pE, _eD],
      [0, 2, 4]
    ];
    exports2.ProxyConfiguration$ = [
      3,
      n032,
      _PCr10,
      0,
      [_cNo, _t, _pro],
      [0, 0, () => ProxyConfigurationProperties],
      1
    ];
    exports2.PutAccountSettingDefaultRequest$ = [
      3,
      n032,
      _PASDR,
      0,
      [_n, _v],
      [0, 0],
      2
    ];
    exports2.PutAccountSettingDefaultResponse$ = [
      3,
      n032,
      _PASDRu,
      0,
      [_sett],
      [() => exports2.Setting$]
    ];
    exports2.PutAccountSettingRequest$ = [
      3,
      n032,
      _PASR,
      0,
      [_n, _v, _pA],
      [0, 0, 0],
      2
    ];
    exports2.PutAccountSettingResponse$ = [
      3,
      n032,
      _PASRu,
      0,
      [_sett],
      [() => exports2.Setting$]
    ];
    exports2.PutAttributesRequest$ = [
      3,
      n032,
      _PAR,
      0,
      [_at, _cl],
      [() => Attributes, 0],
      1
    ];
    exports2.PutAttributesResponse$ = [
      3,
      n032,
      _PARu,
      0,
      [_at],
      [() => Attributes]
    ];
    exports2.PutClusterCapacityProvidersRequest$ = [
      3,
      n032,
      _PCCPR,
      0,
      [_cl, _cPap, _dCPS],
      [0, 64 | 0, () => CapacityProviderStrategy],
      3
    ];
    exports2.PutClusterCapacityProvidersResponse$ = [
      3,
      n032,
      _PCCPRu,
      0,
      [_cl],
      [() => exports2.Cluster$]
    ];
    exports2.RegisterContainerInstanceRequest$ = [
      3,
      n032,
      _RCIR,
      0,
      [_cl, _iID, _iIDS, _tR, _vI, _cIA, _at, _pD, _ta],
      [0, 0, 0, () => Resources, () => exports2.VersionInfo$, 0, () => Attributes, () => PlatformDevices, () => Tags]
    ];
    exports2.RegisterContainerInstanceResponse$ = [
      3,
      n032,
      _RCIRe,
      0,
      [_cIo],
      [() => exports2.ContainerInstance$]
    ];
    exports2.RegisterDaemonTaskDefinitionRequest$ = [
      3,
      n032,
      _RDTDR,
      0,
      [_f, _cD, _tRA, _eRA, _cp, _me, _vo, _ta],
      [0, [() => DaemonContainerDefinitionList, 0], 0, 0, 0, 0, () => DaemonVolumeList, () => Tags],
      2
    ];
    exports2.RegisterDaemonTaskDefinitionResponse$ = [
      3,
      n032,
      _RDTDRe,
      0,
      [_dTDA],
      [0]
    ];
    exports2.RegisterTaskDefinitionRequest$ = [
      3,
      n032,
      _RTDR,
      0,
      [_f, _cD, _tRA, _eRA, _nM, _vo, _pCl, _rCe, _cp, _me, _ta, _pMi, _iM, _pCr, _iAn, _eSp, _rPu, _eFI],
      [0, [() => ContainerDefinitions, 0], 0, 0, 0, () => VolumeList, () => TaskDefinitionPlacementConstraints, 64 | 0, 0, 0, () => Tags, 0, 0, () => exports2.ProxyConfiguration$, () => InferenceAccelerators, () => exports2.EphemeralStorage$, () => exports2.RuntimePlatform$, 2],
      2
    ];
    exports2.RegisterTaskDefinitionResponse$ = [
      3,
      n032,
      _RTDRe,
      0,
      [_tD, _ta],
      [[() => exports2.TaskDefinition$, 0], () => Tags]
    ];
    exports2.RepositoryCredentials$ = [
      3,
      n032,
      _RC10,
      8,
      [_cPr],
      [0],
      1
    ];
    exports2.ResolvedConfiguration$ = [
      3,
      n032,
      _RCe,
      0,
      [_lB],
      [() => ServiceRevisionLoadBalancers]
    ];
    exports2.Resource$ = [
      3,
      n032,
      _R,
      0,
      [_n, _t, _dV, _lV, _iV, _sSV],
      [0, 0, 1, 1, 1, 64 | 0]
    ];
    exports2.ResourceRequirement$ = [
      3,
      n032,
      _RR,
      0,
      [_v, _t],
      [0, 0],
      2
    ];
    exports2.Rollback$ = [
      3,
      n032,
      _Ro,
      0,
      [_r4, _sA, _sRAe],
      [0, 4, 0]
    ];
    exports2.RunTaskRequest$ = [
      3,
      n032,
      _RTR,
      0,
      [_tD, _cPS, _cl, _cou, _eECSMT, _eEC, _g, _lT, _nC, _ov, _pCl, _pS, _pV, _pTr, _rIe, _sB, _ta, _cT, _vCo],
      [0, () => CapacityProviderStrategy, 0, 1, 2, 2, 0, 0, () => exports2.NetworkConfiguration$, [() => exports2.TaskOverride$, 0], () => PlacementConstraints, () => PlacementStrategies, 0, 0, 0, 0, () => Tags, [0, 4], () => TaskVolumeConfigurations],
      1
    ];
    exports2.RunTaskResponse$ = [
      3,
      n032,
      _RTRu,
      0,
      [_tas, _fa],
      [[() => Tasks, 0], () => Failures]
    ];
    exports2.RuntimePlatform$ = [
      3,
      n032,
      _RP,
      0,
      [_cAp, _oSF],
      [0, 0]
    ];
    exports2.S3FilesVolumeConfiguration$ = [
      3,
      n032,
      _SFVC,
      0,
      [_fSA, _rD, _tEP, _aPA],
      [0, 0, 1, 0],
      1
    ];
    exports2.Scale$ = [
      3,
      n032,
      _S,
      0,
      [_v, _un],
      [1, 0]
    ];
    exports2.Secret$ = [
      3,
      n032,
      _Se,
      0,
      [_n, _vFa],
      [0, 0],
      2
    ];
    exports2.Service$ = [
      3,
      n032,
      _Ser,
      0,
      [_sAe, _sN, _cA, _lB, _sRe, _st, _dCe, _rCu, _pCe, _lT, _cPS, _pV, _pF, _tD, _dC4, _tSa, _dep, _rA, _ev, _cAr, _cSD, _cSR, _pCl, _pS, _nC, _hCGPS, _sS, _dCep, _ta, _cBr, _eECSMT, _pTr, _eEC, _aZR, _rMT],
      [0, 0, 0, () => LoadBalancers, () => ServiceRegistries, 0, 1, 1, 1, 0, () => CapacityProviderStrategy, 0, 0, 0, () => exports2.DeploymentConfiguration$, () => TaskSets, () => Deployments2, 0, () => ServiceEvents, 4, 0, () => ServiceCurrentRevisionSummaryList, () => PlacementConstraints, () => PlacementStrategies, () => exports2.NetworkConfiguration$, 1, 0, () => exports2.DeploymentController$, () => Tags, 0, 2, 0, 2, 0, 0]
    ];
    exports2.ServiceConnectAccessLogConfiguration$ = [
      3,
      n032,
      _SCALC,
      0,
      [_for, _iQP],
      [0, 0],
      1
    ];
    exports2.ServiceConnectClientAlias$ = [
      3,
      n032,
      _SCCA,
      0,
      [_po, _dNn, _tTR],
      [1, 0, () => exports2.ServiceConnectTestTrafficRules$],
      1
    ];
    exports2.ServiceConnectConfiguration$ = [
      3,
      n032,
      _SCC,
      0,
      [_ena, _na, _serv, _lC, _aLCc],
      [2, 0, () => ServiceConnectServiceList, () => exports2.LogConfiguration$, () => exports2.ServiceConnectAccessLogConfiguration$],
      1
    ];
    exports2.ServiceConnectService$ = [
      3,
      n032,
      _SCS,
      0,
      [_pN, _dNi, _cAli, _iPO, _ti, _tl],
      [0, 0, () => ServiceConnectClientAliasList, 1, () => exports2.TimeoutConfiguration$, () => exports2.ServiceConnectTlsConfiguration$],
      1
    ];
    exports2.ServiceConnectServiceResource$ = [
      3,
      n032,
      _SCSR,
      0,
      [_dNi, _dAi],
      [0, 0]
    ];
    exports2.ServiceConnectTestTrafficHeaderMatchRules$ = [
      3,
      n032,
      _SCTTHMR,
      0,
      [_exa],
      [0],
      1
    ];
    exports2.ServiceConnectTestTrafficHeaderRules$ = [
      3,
      n032,
      _SCTTHR,
      0,
      [_n, _v],
      [0, () => exports2.ServiceConnectTestTrafficHeaderMatchRules$],
      1
    ];
    exports2.ServiceConnectTestTrafficRules$ = [
      3,
      n032,
      _SCTTR,
      0,
      [_he],
      [() => exports2.ServiceConnectTestTrafficHeaderRules$],
      1
    ];
    exports2.ServiceConnectTlsCertificateAuthority$ = [
      3,
      n032,
      _SCTCA,
      0,
      [_aPAA],
      [0]
    ];
    exports2.ServiceConnectTlsConfiguration$ = [
      3,
      n032,
      _SCTC,
      0,
      [_iCA, _kK, _rA],
      [() => exports2.ServiceConnectTlsCertificateAuthority$, 0, 0],
      1
    ];
    exports2.ServiceCurrentRevisionSummary$ = [
      3,
      n032,
      _SCRS,
      0,
      [_ar, _rTCe, _rTCu, _pTCe],
      [0, 1, 1, 1]
    ];
    exports2.ServiceDeployment$ = [
      3,
      n032,
      _SD,
      0,
      [_sDAe, _sAe, _cA, _cAr, _sA, _fA, _sAt, _uA, _sSR, _tSR, _st, _sR, _lSif, _dC4, _rol, _dCB, _al],
      [0, 0, 0, 4, 4, 4, 4, 4, () => ServiceRevisionsSummaryList, () => exports2.ServiceRevisionSummary$, 0, 0, 0, () => exports2.DeploymentConfiguration$, () => exports2.Rollback$, () => exports2.ServiceDeploymentCircuitBreaker$, () => exports2.ServiceDeploymentAlarms$]
    ];
    exports2.ServiceDeploymentAlarms$ = [
      3,
      n032,
      _SDA,
      0,
      [_st, _aN, _tAN],
      [0, 64 | 0, 64 | 0]
    ];
    exports2.ServiceDeploymentBrief$ = [
      3,
      n032,
      _SDB,
      0,
      [_sDAe, _sAe, _cA, _sA, _cAr, _fA, _tSRA, _st, _sR],
      [0, 0, 0, 4, 4, 4, 0, 0, 0]
    ];
    exports2.ServiceDeploymentCircuitBreaker$ = [
      3,
      n032,
      _SDCB,
      0,
      [_st, _fCa, _th],
      [0, 1, 1]
    ];
    exports2.ServiceEvent$ = [
      3,
      n032,
      _SEe,
      0,
      [_i, _cAr, _m29],
      [0, 4, 0]
    ];
    exports2.ServiceManagedEBSVolumeConfiguration$ = [
      3,
      n032,
      _SMEBSVC,
      0,
      [_rA, _enc, _kKI, _vT, _sIGB, _sIn, _vIR, _io, _thr, _tSag, _fTi],
      [0, 2, 0, 0, 1, 0, 1, 1, 1, () => EBSTagSpecifications, 0],
      1
    ];
    exports2.ServiceRegistry$ = [
      3,
      n032,
      _SR,
      0,
      [_rAeg, _po, _cNo, _cPon],
      [0, 1, 0, 1]
    ];
    exports2.ServiceRevision$ = [
      3,
      n032,
      _SRe,
      0,
      [_sRAe, _sAe, _cA, _tD, _cPS, _lT, _pV, _pF, _lB, _sRe, _nC, _cI13, _gDE, _sCC, _vCo, _fES, _cAr, _vLC, _rCes, _eMR],
      [0, 0, 0, 0, () => CapacityProviderStrategy, 0, 0, 0, () => LoadBalancers, () => ServiceRegistries, () => exports2.NetworkConfiguration$, () => ContainerImages, 2, () => exports2.ServiceConnectConfiguration$, () => ServiceVolumeConfigurations, () => exports2.DeploymentEphemeralStorage$, 4, () => VpcLatticeConfigurations, () => exports2.ResolvedConfiguration$, () => exports2.ECSManagedResources$]
    ];
    exports2.ServiceRevisionLoadBalancer$ = [
      3,
      n032,
      _SRLB,
      0,
      [_tGA, _pLR],
      [0, 0]
    ];
    exports2.ServiceRevisionSummary$ = [
      3,
      n032,
      _SRS,
      0,
      [_ar, _rTCe, _rTCu, _pTCe, _rTTW, _rPTW],
      [0, 1, 1, 1, 1, 1]
    ];
    exports2.ServiceVolumeConfiguration$ = [
      3,
      n032,
      _SVC,
      0,
      [_n, _mEBSV],
      [0, () => exports2.ServiceManagedEBSVolumeConfiguration$],
      1
    ];
    exports2.Session$ = [
      3,
      n032,
      _Ses,
      0,
      [_sIe, _sU, _tVo],
      [0, 0, [() => SensitiveString, 0]]
    ];
    exports2.Setting$ = [
      3,
      n032,
      _Set,
      0,
      [_n, _v, _pA, _t],
      [0, 0, 0, 0]
    ];
    exports2.StartTaskRequest$ = [
      3,
      n032,
      _STR,
      0,
      [_cIon, _tD, _cl, _eECSMT, _eEC, _g, _nC, _ov, _pTr, _rIe, _sB, _ta, _vCo],
      [64 | 0, 0, 0, 2, 2, 0, () => exports2.NetworkConfiguration$, [() => exports2.TaskOverride$, 0], 0, 0, 0, () => Tags, () => TaskVolumeConfigurations],
      2
    ];
    exports2.StartTaskResponse$ = [
      3,
      n032,
      _STRt,
      0,
      [_tas, _fa],
      [[() => Tasks, 0], () => Failures]
    ];
    exports2.StopServiceDeploymentRequest$ = [
      3,
      n032,
      _SSDR,
      0,
      [_sDAe, _sTto],
      [0, 0],
      1
    ];
    exports2.StopServiceDeploymentResponse$ = [
      3,
      n032,
      _SSDRt,
      0,
      [_sDAe],
      [0]
    ];
    exports2.StopTaskRequest$ = [
      3,
      n032,
      _STRto,
      0,
      [_task, _cl, _r4],
      [0, 0, 0],
      1
    ];
    exports2.StopTaskResponse$ = [
      3,
      n032,
      _STRtop,
      0,
      [_task],
      [[() => exports2.Task$, 0]]
    ];
    exports2.SubmitAttachmentStateChangesRequest$ = [
      3,
      n032,
      _SASCR,
      0,
      [_a10, _cl],
      [() => AttachmentStateChanges, 0],
      1
    ];
    exports2.SubmitAttachmentStateChangesResponse$ = [
      3,
      n032,
      _SASCRu,
      0,
      [_ac],
      [0]
    ];
    exports2.SubmitContainerStateChangeRequest$ = [
      3,
      n032,
      _SCSCR,
      0,
      [_cl, _task, _cNo, _rIu, _st, _eC, _r4, _nB],
      [0, 0, 0, 0, 0, 1, 0, () => NetworkBindings]
    ];
    exports2.SubmitContainerStateChangeResponse$ = [
      3,
      n032,
      _SCSCRu,
      0,
      [_ac],
      [0]
    ];
    exports2.SubmitTaskStateChangeRequest$ = [
      3,
      n032,
      _STSCR,
      0,
      [_cl, _task, _st, _r4, _conta, _a10, _mA, _pSA, _pSAu, _eSA],
      [0, 0, 0, 0, () => ContainerStateChanges, () => AttachmentStateChanges, () => ManagedAgentStateChanges, 4, 4, 4]
    ];
    exports2.SubmitTaskStateChangeResponse$ = [
      3,
      n032,
      _STSCRu,
      0,
      [_ac],
      [0]
    ];
    exports2.SystemControl$ = [
      3,
      n032,
      _SC,
      0,
      [_na, _v],
      [0, 0]
    ];
    exports2.Tag$ = [
      3,
      n032,
      _T10,
      0,
      [_k, _v],
      [0, 0]
    ];
    exports2.TagResourceRequest$ = [
      3,
      n032,
      _TRR,
      0,
      [_rAes, _ta],
      [0, () => Tags],
      2
    ];
    exports2.TagResourceResponse$ = [
      3,
      n032,
      _TRRa,
      0,
      [],
      []
    ];
    exports2.Task$ = [
      3,
      n032,
      _Ta10,
      0,
      [_a10, _at, _aZ, _cPN, _cA, _conn, _cAon, _cIA, _conta, _cp, _cAr, _dSe, _eEC, _eSA, _g, _hS, _iAn, _lS, _lT, _me, _ov, _pV, _pF, _pSA, _pSAu, _sA, _sB, _sCtop, _sAt, _sRt, _sAto, _ta, _tA, _tDAa, _ve, _eSp, _fES],
      [() => Attachments, () => Attributes, 0, 0, 0, 0, 4, 0, () => Containers, 0, 4, 0, 2, 4, 0, 0, () => InferenceAccelerators, 0, 0, 0, [() => exports2.TaskOverride$, 0], 0, 0, 4, 4, 4, 0, 0, 4, 0, 4, () => Tags, 0, 0, 1, () => exports2.EphemeralStorage$, () => exports2.TaskEphemeralStorage$]
    ];
    exports2.TaskDefinition$ = [
      3,
      n032,
      _TD,
      0,
      [_tDAa, _cD, _f, _tRA, _eRA, _nM, _re, _vo, _st, _rAeq, _pCl, _comp, _rPu, _rCe, _cp, _me, _iAn, _pMi, _iM, _pCr, _rAe, _dAer, _dRAe, _rB, _eSp, _eFI],
      [0, [() => ContainerDefinitions, 0], 0, 0, 0, 0, 1, () => VolumeList, 0, () => RequiresAttributes, () => TaskDefinitionPlacementConstraints, 64 | 0, () => exports2.RuntimePlatform$, 64 | 0, 0, 0, () => InferenceAccelerators, 0, 0, () => exports2.ProxyConfiguration$, 4, 4, 4, 0, () => exports2.EphemeralStorage$, 2]
    ];
    exports2.TaskDefinitionPlacementConstraint$ = [
      3,
      n032,
      _TDPC,
      0,
      [_t, _ex10],
      [0, 0]
    ];
    exports2.TaskEphemeralStorage$ = [
      3,
      n032,
      _TES,
      0,
      [_sIGB, _kKI],
      [1, 0]
    ];
    exports2.TaskManagedEBSVolumeConfiguration$ = [
      3,
      n032,
      _TMEBSVC,
      0,
      [_rA, _enc, _kKI, _vT, _sIGB, _sIn, _vIR, _io, _thr, _tSag, _tP, _fTi],
      [0, 2, 0, 0, 1, 0, 1, 1, 1, () => EBSTagSpecifications, () => exports2.TaskManagedEBSVolumeTerminationPolicy$, 0],
      1
    ];
    exports2.TaskManagedEBSVolumeTerminationPolicy$ = [
      3,
      n032,
      _TMEBSVTP,
      0,
      [_dOT],
      [2],
      1
    ];
    exports2.TaskOverride$ = [
      3,
      n032,
      _TO,
      0,
      [_cO, _cp, _iAO, _eRA, _me, _tRA, _eSp],
      [[() => ContainerOverrides, 0], 0, () => InferenceAcceleratorOverrides, 0, 0, 0, () => exports2.EphemeralStorage$]
    ];
    exports2.TaskSet$ = [
      3,
      n032,
      _TS,
      0,
      [_i, _tSA, _sAe, _cA, _sB, _eI13, _st, _tD, _cDC, _pCe, _rCu, _cAr, _uA, _lT, _cPS, _pV, _pF, _nC, _lB, _sRe, _sc4, _sSt, _sSA, _ta, _fES],
      [0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 4, 4, 0, () => CapacityProviderStrategy, 0, 0, () => exports2.NetworkConfiguration$, () => LoadBalancers, () => ServiceRegistries, () => exports2.Scale$, 0, 4, () => Tags, () => exports2.DeploymentEphemeralStorage$]
    ];
    exports2.TaskVolumeConfiguration$ = [
      3,
      n032,
      _TVC,
      0,
      [_n, _mEBSV],
      [0, () => exports2.TaskManagedEBSVolumeConfiguration$],
      1
    ];
    exports2.TimeoutConfiguration$ = [
      3,
      n032,
      _TC10,
      0,
      [_iTS, _pRTS],
      [1, 1]
    ];
    exports2.Tmpfs$ = [
      3,
      n032,
      _Tm,
      0,
      [_cPo, _si, _mO],
      [0, 1, 64 | 0],
      2
    ];
    exports2.TotalLocalStorageGBRequest$ = [
      3,
      n032,
      _TLSGBR,
      0,
      [_mi, _ma],
      [1, 1]
    ];
    exports2.Ulimit$ = [
      3,
      n032,
      _U,
      0,
      [_n, _sL, _hL],
      [0, 1, 1],
      3
    ];
    exports2.UntagResourceRequest$ = [
      3,
      n032,
      _URR,
      0,
      [_rAes, _tK],
      [0, 64 | 0],
      2
    ];
    exports2.UntagResourceResponse$ = [
      3,
      n032,
      _URRn,
      0,
      [],
      []
    ];
    exports2.UpdateCapacityProviderRequest$ = [
      3,
      n032,
      _UCPR,
      0,
      [_n, _cl, _aSGP, _mIP],
      [0, 0, () => exports2.AutoScalingGroupProviderUpdate$, [() => exports2.UpdateManagedInstancesProviderConfiguration$, 0]],
      1
    ];
    exports2.UpdateCapacityProviderResponse$ = [
      3,
      n032,
      _UCPRp,
      0,
      [_cPa],
      [[() => exports2.CapacityProvider$, 0]]
    ];
    exports2.UpdateClusterRequest$ = [
      3,
      n032,
      _UCR,
      0,
      [_cl, _set, _co13, _sCD],
      [0, () => ClusterSettings, () => exports2.ClusterConfiguration$, () => exports2.ClusterServiceConnectDefaultsRequest$],
      1
    ];
    exports2.UpdateClusterResponse$ = [
      3,
      n032,
      _UCRp,
      0,
      [_cl],
      [() => exports2.Cluster$]
    ];
    exports2.UpdateClusterSettingsRequest$ = [
      3,
      n032,
      _UCSR,
      0,
      [_cl, _set],
      [0, () => ClusterSettings],
      2
    ];
    exports2.UpdateClusterSettingsResponse$ = [
      3,
      n032,
      _UCSRp,
      0,
      [_cl],
      [() => exports2.Cluster$]
    ];
    exports2.UpdateContainerAgentRequest$ = [
      3,
      n032,
      _UCAR,
      0,
      [_cIo, _cl],
      [0, 0],
      1
    ];
    exports2.UpdateContainerAgentResponse$ = [
      3,
      n032,
      _UCARp,
      0,
      [_cIo],
      [() => exports2.ContainerInstance$]
    ];
    exports2.UpdateContainerInstancesStateRequest$ = [
      3,
      n032,
      _UCISR,
      0,
      [_cIon, _st, _cl],
      [64 | 0, 0, 0],
      2
    ];
    exports2.UpdateContainerInstancesStateResponse$ = [
      3,
      n032,
      _UCISRp,
      0,
      [_cIon, _fa],
      [() => ContainerInstances, () => Failures]
    ];
    exports2.UpdateDaemonRequest$ = [
      3,
      n032,
      _UDR,
      0,
      [_dA, _dTDA, _cPAa, _dC4, _pTr, _eECSMT, _eEC],
      [0, 0, 64 | 0, () => exports2.DaemonDeploymentConfiguration$, 0, 2, 2],
      3
    ];
    exports2.UpdateDaemonResponse$ = [
      3,
      n032,
      _UDRp,
      0,
      [_dA, _st, _cAr, _uA, _dAe],
      [0, 0, 4, 4, 0]
    ];
    exports2.UpdatedExpressGatewayService$ = [
      3,
      n032,
      _UEGS,
      0,
      [_sAe, _cl, _sN, _st, _tCa, _cAr, _uA],
      [0, 0, 0, () => exports2.ExpressGatewayServiceStatus$, [() => exports2.ExpressGatewayServiceConfiguration$, 0], 4, 4]
    ];
    exports2.UpdateExpressGatewayServiceRequest$ = [
      3,
      n032,
      _UEGSR,
      0,
      [_sAe, _eRA, _hCP, _pC, _tRA, _nC, _cp, _me, _sTc],
      [0, 0, 0, [() => exports2.ExpressGatewayContainer$, 0], 0, () => exports2.ExpressGatewayServiceNetworkConfiguration$, 0, 0, () => exports2.ExpressGatewayScalingTarget$],
      1
    ];
    exports2.UpdateExpressGatewayServiceResponse$ = [
      3,
      n032,
      _UEGSRp,
      0,
      [_ser],
      [[() => exports2.UpdatedExpressGatewayService$, 0]]
    ];
    exports2.UpdateManagedInstancesProviderConfiguration$ = [
      3,
      n032,
      _UMIPC,
      0,
      [_iRA, _iLT, _pTr, _iO, _aRC],
      [0, [() => exports2.InstanceLaunchTemplateUpdate$, 0], 0, () => exports2.InfrastructureOptimization$, () => exports2.AutoRepairConfiguration$],
      2
    ];
    exports2.UpdateServicePrimaryTaskSetRequest$ = [
      3,
      n032,
      _USPTSR,
      0,
      [_cl, _ser, _pTS],
      [0, 0, 0],
      3
    ];
    exports2.UpdateServicePrimaryTaskSetResponse$ = [
      3,
      n032,
      _USPTSRp,
      0,
      [_tS],
      [() => exports2.TaskSet$]
    ];
    exports2.UpdateServiceRequest$ = [
      3,
      n032,
      _USR,
      0,
      [_ser, _cl, _dCe, _tD, _cPS, _dC4, _aZR, _nC, _pCl, _pS, _pV, _fND, _hCGPS, _dCep, _eEC, _eECSMT, _lB, _pTr, _sRe, _sCC, _vCo, _vLC],
      [0, 0, 1, 0, () => CapacityProviderStrategy, () => exports2.DeploymentConfiguration$, 0, () => exports2.NetworkConfiguration$, () => PlacementConstraints, () => PlacementStrategies, 0, 2, 1, () => exports2.DeploymentController$, 2, 2, () => LoadBalancers, 0, () => ServiceRegistries, () => exports2.ServiceConnectConfiguration$, () => ServiceVolumeConfigurations, () => VpcLatticeConfigurations],
      1
    ];
    exports2.UpdateServiceResponse$ = [
      3,
      n032,
      _USRp,
      0,
      [_ser],
      [() => exports2.Service$]
    ];
    exports2.UpdateTaskProtectionRequest$ = [
      3,
      n032,
      _UTPR,
      0,
      [_cl, _tas, _pE, _eIM],
      [0, 64 | 0, 2, 1],
      3
    ];
    exports2.UpdateTaskProtectionResponse$ = [
      3,
      n032,
      _UTPRp,
      0,
      [_pTro, _fa],
      [() => ProtectedTasks, () => Failures]
    ];
    exports2.UpdateTaskSetRequest$ = [
      3,
      n032,
      _UTSR,
      0,
      [_cl, _ser, _tS, _sc4],
      [0, 0, 0, () => exports2.Scale$],
      4
    ];
    exports2.UpdateTaskSetResponse$ = [
      3,
      n032,
      _UTSRp,
      0,
      [_tS],
      [() => exports2.TaskSet$]
    ];
    exports2.VCpuCountRangeRequest$ = [
      3,
      n032,
      _VCCRR,
      0,
      [_mi, _ma],
      [1, 1],
      1
    ];
    exports2.VersionInfo$ = [
      3,
      n032,
      _VI,
      0,
      [_aVg, _aH, _dVo],
      [0, 0, 0]
    ];
    exports2.Volume$ = [
      3,
      n032,
      _V10,
      0,
      [_n, _ho, _dVC, _eVC, _sVC, _fWFSVC, _cAL],
      [0, () => exports2.HostVolumeProperties$, () => exports2.DockerVolumeConfiguration$, () => exports2.EFSVolumeConfiguration$, () => exports2.S3FilesVolumeConfiguration$, () => exports2.FSxWindowsFileServerVolumeConfiguration$, 2]
    ];
    exports2.VolumeFrom$ = [
      3,
      n032,
      _VF,
      0,
      [_sCo, _rO],
      [0, 2]
    ];
    exports2.VpcLatticeConfiguration$ = [
      3,
      n032,
      _VLC,
      0,
      [_rA, _tGA, _pN],
      [0, 0, 0],
      3
    ];
    var AcceleratorManufacturerSet = [
      1,
      n032,
      _AMS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var AcceleratorNameSet = [
      1,
      n032,
      _ANS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var AcceleratorTypeSet = [
      1,
      n032,
      _ATS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var AllowedInstanceTypeSet = [
      1,
      n032,
      _AITS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var AttachmentDetails = [
      1,
      n032,
      _AD,
      0,
      () => exports2.KeyValuePair$
    ];
    var Attachments = [
      1,
      n032,
      _Att,
      0,
      () => exports2.Attachment$
    ];
    var AttachmentStateChanges = [
      1,
      n032,
      _ASCt,
      0,
      () => exports2.AttachmentStateChange$
    ];
    var Attributes = [
      1,
      n032,
      _Attr,
      0,
      () => exports2.Attribute$
    ];
    var CapacityProviderFieldList = 64 | 0;
    var CapacityProviders = [
      1,
      n032,
      _CPa,
      0,
      [
        () => exports2.CapacityProvider$,
        0
      ]
    ];
    var CapacityProviderStrategy = [
      1,
      n032,
      _CPS,
      0,
      () => exports2.CapacityProviderStrategyItem$
    ];
    var ClusterFieldList = 64 | 0;
    var Clusters = [
      1,
      n032,
      _Cl,
      0,
      () => exports2.Cluster$
    ];
    var ClusterSettings = [
      1,
      n032,
      _CSl,
      0,
      () => exports2.ClusterSetting$
    ];
    var CompatibilityList = 64 | 0;
    var ContainerDefinitions = [
      1,
      n032,
      _CDon,
      0,
      [
        () => exports2.ContainerDefinition$,
        0
      ]
    ];
    var ContainerDependencies = [
      1,
      n032,
      _CDont,
      0,
      () => exports2.ContainerDependency$
    ];
    var ContainerImages = [
      1,
      n032,
      _CIon,
      0,
      () => exports2.ContainerImage$
    ];
    var ContainerInstanceFieldList = 64 | 0;
    var ContainerInstances = [
      1,
      n032,
      _CIont,
      0,
      () => exports2.ContainerInstance$
    ];
    var ContainerOverrides = [
      1,
      n032,
      _COo,
      0,
      [
        () => exports2.ContainerOverride$,
        0
      ]
    ];
    var Containers = [
      1,
      n032,
      _Con,
      0,
      () => exports2.Container$
    ];
    var ContainerStateChanges = [
      1,
      n032,
      _CSCo,
      0,
      () => exports2.ContainerStateChange$
    ];
    var CpuManufacturerSet = [
      1,
      n032,
      _CMS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var DaemonCapacityProviderList = [
      1,
      n032,
      _DCPL,
      0,
      () => exports2.DaemonCapacityProvider$
    ];
    var DaemonContainerDefinitionList = [
      1,
      n032,
      _DCDL,
      0,
      [
        () => exports2.DaemonContainerDefinition$,
        0
      ]
    ];
    var DaemonContainerImages = [
      1,
      n032,
      _DCIa,
      0,
      () => exports2.DaemonContainerImage$
    ];
    var DaemonDeploymentCapacityProviderList = [
      1,
      n032,
      _DDCPL,
      0,
      () => exports2.DaemonDeploymentCapacityProvider$
    ];
    var DaemonDeploymentList = [
      1,
      n032,
      _DDL,
      0,
      () => exports2.DaemonDeployment$
    ];
    var DaemonDeploymentRevisionDetailList = [
      1,
      n032,
      _DDRDL,
      0,
      () => exports2.DaemonDeploymentRevisionDetail$
    ];
    var DaemonDeploymentStatusList = 64 | 0;
    var DaemonDeploymentSummaryList = [
      1,
      n032,
      _DDSL,
      0,
      () => exports2.DaemonDeploymentSummary$
    ];
    var DaemonRevisionDetailList = [
      1,
      n032,
      _DRDL,
      0,
      () => exports2.DaemonRevisionDetail$
    ];
    var DaemonRevisions = [
      1,
      n032,
      _DRae,
      0,
      () => exports2.DaemonRevision$
    ];
    var DaemonSummariesList = [
      1,
      n032,
      _DSL,
      0,
      () => exports2.DaemonSummary$
    ];
    var DaemonTaskDefinitionSummaries = [
      1,
      n032,
      _DTDSa,
      0,
      () => exports2.DaemonTaskDefinitionSummary$
    ];
    var DaemonVolumeList = [
      1,
      n032,
      _DVL,
      0,
      () => exports2.DaemonVolume$
    ];
    var DeploymentLifecycleHookList = [
      1,
      n032,
      _DLHL,
      0,
      () => exports2.DeploymentLifecycleHook$
    ];
    var DeploymentLifecycleHookStageList = 64 | 0;
    var Deployments2 = [
      1,
      n032,
      _Dep,
      0,
      () => exports2.Deployment$
    ];
    var DeviceCgroupPermissions = 64 | 0;
    var DevicesList = [
      1,
      n032,
      _DL,
      0,
      () => exports2.Device$
    ];
    var EBSTagSpecifications = [
      1,
      n032,
      _EBSTSa,
      0,
      () => exports2.EBSTagSpecification$
    ];
    var EnvironmentFiles = [
      1,
      n032,
      _EFn,
      0,
      () => exports2.EnvironmentFile$
    ];
    var EnvironmentVariables = [
      1,
      n032,
      _EV,
      8,
      () => exports2.KeyValuePair$
    ];
    var ExcludedInstanceTypeSet = [
      1,
      n032,
      _EITS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var ExpressGatewayServiceConfigurations = [
      1,
      n032,
      _EGSCx,
      0,
      [
        () => exports2.ExpressGatewayServiceConfiguration$,
        0
      ]
    ];
    var ExpressGatewayServiceIncludeList = 64 | 0;
    var Failures = [
      1,
      n032,
      _Fa,
      0,
      () => exports2.Failure$
    ];
    var GpuIds = 64 | 0;
    var HostEntryList = [
      1,
      n032,
      _HEL,
      0,
      () => exports2.HostEntry$
    ];
    var InferenceAcceleratorOverrides = [
      1,
      n032,
      _IAOn,
      0,
      () => exports2.InferenceAcceleratorOverride$
    ];
    var InferenceAccelerators = [
      1,
      n032,
      _IAn,
      0,
      () => exports2.InferenceAccelerator$
    ];
    var IngressPathSummaries = [
      1,
      n032,
      _IPSn,
      0,
      () => exports2.IngressPathSummary$
    ];
    var InstanceGenerationSet = [
      1,
      n032,
      _IGS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var InstanceHealthCheckResultList = [
      1,
      n032,
      _IHCRL,
      0,
      () => exports2.InstanceHealthCheckResult$
    ];
    var IntegerList = 64 | 1;
    var LoadBalancers = [
      1,
      n032,
      _LBo,
      0,
      () => exports2.LoadBalancer$
    ];
    var LocalStorageTypeSet = [
      1,
      n032,
      _LSTS,
      0,
      [
        0,
        { [_xN]: _it }
      ]
    ];
    var ManagedAgents = [
      1,
      n032,
      _MAa,
      0,
      () => exports2.ManagedAgent$
    ];
    var ManagedAgentStateChanges = [
      1,
      n032,
      _MASCa,
      0,
      () => exports2.ManagedAgentStateChange$
    ];
    var ManagedApplicationAutoScalingPolicies = [
      1,
      n032,
      _MAASPa,
      0,
      () => exports2.ManagedApplicationAutoScalingPolicy$
    ];
    var ManagedIngressPaths = [
      1,
      n032,
      _MIPan,
      0,
      () => exports2.ManagedIngressPath$
    ];
    var ManagedLogGroups = [
      1,
      n032,
      _MLGa,
      0,
      () => exports2.ManagedLogGroup$
    ];
    var ManagedMetricAlarms = [
      1,
      n032,
      _MMAa,
      0,
      () => exports2.ManagedMetricAlarm$
    ];
    var ManagedSecurityGroups = [
      1,
      n032,
      _MSGa,
      0,
      () => exports2.ManagedSecurityGroup$
    ];
    var ManagedTargetGroups = [
      1,
      n032,
      _MTGa,
      0,
      () => exports2.ManagedTargetGroup$
    ];
    var MountPointList = [
      1,
      n032,
      _MPL,
      0,
      () => exports2.MountPoint$
    ];
    var NetworkBindings = [
      1,
      n032,
      _NBe,
      0,
      () => exports2.NetworkBinding$
    ];
    var NetworkInterfaces = [
      1,
      n032,
      _NIe,
      0,
      () => exports2.NetworkInterface$
    ];
    var PlacementConstraints = [
      1,
      n032,
      _PCl,
      0,
      () => exports2.PlacementConstraint$
    ];
    var PlacementStrategies = [
      1,
      n032,
      _PSl,
      0,
      () => exports2.PlacementStrategy$
    ];
    var PlatformDevices = [
      1,
      n032,
      _PDl,
      0,
      () => exports2.PlatformDevice$
    ];
    var PortMappingList = [
      1,
      n032,
      _PML,
      0,
      () => exports2.PortMapping$
    ];
    var ProtectedTasks = [
      1,
      n032,
      _PTr,
      0,
      () => exports2.ProtectedTask$
    ];
    var ProxyConfigurationProperties = [
      1,
      n032,
      _PCP,
      0,
      () => exports2.KeyValuePair$
    ];
    var RequiresAttributes = [
      1,
      n032,
      _RA10,
      0,
      () => exports2.Attribute$
    ];
    var ResourceIds = 64 | 0;
    var ResourceRequirements = [
      1,
      n032,
      _RRe,
      0,
      () => exports2.ResourceRequirement$
    ];
    var Resources = [
      1,
      n032,
      _Re,
      0,
      () => exports2.Resource$
    ];
    var SecretList = [
      1,
      n032,
      _SL,
      0,
      () => exports2.Secret$
    ];
    var ServiceConnectClientAliasList = [
      1,
      n032,
      _SCCAL,
      0,
      () => exports2.ServiceConnectClientAlias$
    ];
    var ServiceConnectServiceList = [
      1,
      n032,
      _SCSL,
      0,
      () => exports2.ServiceConnectService$
    ];
    var ServiceConnectServiceResourceList = [
      1,
      n032,
      _SCSRL,
      0,
      () => exports2.ServiceConnectServiceResource$
    ];
    var ServiceCurrentRevisionSummaryList = [
      1,
      n032,
      _SCRSL,
      0,
      () => exports2.ServiceCurrentRevisionSummary$
    ];
    var ServiceDeployments = [
      1,
      n032,
      _SDe,
      0,
      () => exports2.ServiceDeployment$
    ];
    var ServiceDeploymentsBrief = [
      1,
      n032,
      _SDBe,
      0,
      () => exports2.ServiceDeploymentBrief$
    ];
    var ServiceDeploymentStatusList = 64 | 0;
    var ServiceEvents = [
      1,
      n032,
      _SEer,
      0,
      () => exports2.ServiceEvent$
    ];
    var ServiceFieldList = 64 | 0;
    var ServiceRegistries = [
      1,
      n032,
      _SRer,
      0,
      () => exports2.ServiceRegistry$
    ];
    var ServiceRevisionLoadBalancers = [
      1,
      n032,
      _SRLBe,
      0,
      () => exports2.ServiceRevisionLoadBalancer$
    ];
    var ServiceRevisions = [
      1,
      n032,
      _SRerv,
      0,
      () => exports2.ServiceRevision$
    ];
    var ServiceRevisionsSummaryList = [
      1,
      n032,
      _SRSL,
      0,
      () => exports2.ServiceRevisionSummary$
    ];
    var Services = [
      1,
      n032,
      _Serv,
      0,
      () => exports2.Service$
    ];
    var ServiceVolumeConfigurations = [
      1,
      n032,
      _SVCe,
      0,
      () => exports2.ServiceVolumeConfiguration$
    ];
    var Settings2 = [
      1,
      n032,
      _Sett,
      0,
      () => exports2.Setting$
    ];
    var Statistics = [
      1,
      n032,
      _St,
      0,
      () => exports2.KeyValuePair$
    ];
    var StringList = 64 | 0;
    var SystemControls = [
      1,
      n032,
      _SCy,
      0,
      () => exports2.SystemControl$
    ];
    var TagKeys = 64 | 0;
    var Tags = [
      1,
      n032,
      _Tag,
      0,
      () => exports2.Tag$
    ];
    var TaskDefinitionFieldList = 64 | 0;
    var TaskDefinitionList = [
      1,
      n032,
      _TDL,
      0,
      [
        () => exports2.TaskDefinition$,
        0
      ]
    ];
    var TaskDefinitionPlacementConstraints = [
      1,
      n032,
      _TDPCa,
      0,
      () => exports2.TaskDefinitionPlacementConstraint$
    ];
    var TaskFieldList = 64 | 0;
    var Tasks = [
      1,
      n032,
      _Tas,
      0,
      [
        () => exports2.Task$,
        0
      ]
    ];
    var TaskSetFieldList = 64 | 0;
    var TaskSets = [
      1,
      n032,
      _TSa,
      0,
      () => exports2.TaskSet$
    ];
    var TaskVolumeConfigurations = [
      1,
      n032,
      _TVCa,
      0,
      () => exports2.TaskVolumeConfiguration$
    ];
    var TmpfsList = [
      1,
      n032,
      _TL,
      0,
      () => exports2.Tmpfs$
    ];
    var UlimitList = [
      1,
      n032,
      _UL,
      0,
      () => exports2.Ulimit$
    ];
    var VolumeFromList = [
      1,
      n032,
      _VFL,
      0,
      () => exports2.VolumeFrom$
    ];
    var VolumeList = [
      1,
      n032,
      _VL,
      0,
      () => exports2.Volume$
    ];
    var VpcLatticeConfigurations = [
      1,
      n032,
      _VLCp,
      0,
      () => exports2.VpcLatticeConfiguration$
    ];
    var DockerLabelsMap = 128 | 0;
    var FirelensConfigurationOptionsMap = 128 | 0;
    var LogConfigurationOptionsMap = 128 | 0;
    var StringMap = 128 | 0;
    exports2.CreateCapacityProvider$ = [
      9,
      n032,
      _CCP,
      2,
      () => exports2.CreateCapacityProviderRequest$,
      () => exports2.CreateCapacityProviderResponse$
    ];
    exports2.CreateCluster$ = [
      9,
      n032,
      _CCr,
      0,
      () => exports2.CreateClusterRequest$,
      () => exports2.CreateClusterResponse$
    ];
    exports2.CreateDaemon$ = [
      9,
      n032,
      _CDr,
      0,
      () => exports2.CreateDaemonRequest$,
      () => exports2.CreateDaemonResponse$
    ];
    exports2.CreateExpressGatewayService$ = [
      9,
      n032,
      _CEGS,
      0,
      () => exports2.CreateExpressGatewayServiceRequest$,
      () => exports2.CreateExpressGatewayServiceResponse$
    ];
    exports2.CreateService$ = [
      9,
      n032,
      _CSr,
      0,
      () => exports2.CreateServiceRequest$,
      () => exports2.CreateServiceResponse$
    ];
    exports2.CreateTaskSet$ = [
      9,
      n032,
      _CTS,
      0,
      () => exports2.CreateTaskSetRequest$,
      () => exports2.CreateTaskSetResponse$
    ];
    exports2.DeleteAccountSetting$ = [
      9,
      n032,
      _DAS,
      0,
      () => exports2.DeleteAccountSettingRequest$,
      () => exports2.DeleteAccountSettingResponse$
    ];
    exports2.DeleteAttributes$ = [
      9,
      n032,
      _DAe,
      0,
      () => exports2.DeleteAttributesRequest$,
      () => exports2.DeleteAttributesResponse$
    ];
    exports2.DeleteCapacityProvider$ = [
      9,
      n032,
      _DCPe,
      2,
      () => exports2.DeleteCapacityProviderRequest$,
      () => exports2.DeleteCapacityProviderResponse$
    ];
    exports2.DeleteCluster$ = [
      9,
      n032,
      _DCel,
      2,
      () => exports2.DeleteClusterRequest$,
      () => exports2.DeleteClusterResponse$
    ];
    exports2.DeleteDaemon$ = [
      9,
      n032,
      _DDe,
      2,
      () => exports2.DeleteDaemonRequest$,
      () => exports2.DeleteDaemonResponse$
    ];
    exports2.DeleteDaemonTaskDefinition$ = [
      9,
      n032,
      _DDTD,
      0,
      () => exports2.DeleteDaemonTaskDefinitionRequest$,
      () => exports2.DeleteDaemonTaskDefinitionResponse$
    ];
    exports2.DeleteExpressGatewayService$ = [
      9,
      n032,
      _DEGS,
      0,
      () => exports2.DeleteExpressGatewayServiceRequest$,
      () => exports2.DeleteExpressGatewayServiceResponse$
    ];
    exports2.DeleteService$ = [
      9,
      n032,
      _DSe,
      2,
      () => exports2.DeleteServiceRequest$,
      () => exports2.DeleteServiceResponse$
    ];
    exports2.DeleteTaskDefinitions$ = [
      9,
      n032,
      _DTDe,
      0,
      () => exports2.DeleteTaskDefinitionsRequest$,
      () => exports2.DeleteTaskDefinitionsResponse$
    ];
    exports2.DeleteTaskSet$ = [
      9,
      n032,
      _DTS,
      2,
      () => exports2.DeleteTaskSetRequest$,
      () => exports2.DeleteTaskSetResponse$
    ];
    exports2.DeregisterContainerInstance$ = [
      9,
      n032,
      _DCIe,
      0,
      () => exports2.DeregisterContainerInstanceRequest$,
      () => exports2.DeregisterContainerInstanceResponse$
    ];
    exports2.DeregisterTaskDefinition$ = [
      9,
      n032,
      _DTDer,
      0,
      () => exports2.DeregisterTaskDefinitionRequest$,
      () => exports2.DeregisterTaskDefinitionResponse$
    ];
    exports2.DescribeCapacityProviders$ = [
      9,
      n032,
      _DCPes,
      0,
      () => exports2.DescribeCapacityProvidersRequest$,
      () => exports2.DescribeCapacityProvidersResponse$
    ];
    exports2.DescribeClusters$ = [
      9,
      n032,
      _DCes,
      0,
      () => exports2.DescribeClustersRequest$,
      () => exports2.DescribeClustersResponse$
    ];
    exports2.DescribeContainerInstances$ = [
      9,
      n032,
      _DCIes,
      0,
      () => exports2.DescribeContainerInstancesRequest$,
      () => exports2.DescribeContainerInstancesResponse$
    ];
    exports2.DescribeDaemon$ = [
      9,
      n032,
      _DDes,
      0,
      () => exports2.DescribeDaemonRequest$,
      () => exports2.DescribeDaemonResponse$
    ];
    exports2.DescribeDaemonDeployments$ = [
      9,
      n032,
      _DDD,
      0,
      () => exports2.DescribeDaemonDeploymentsRequest$,
      () => exports2.DescribeDaemonDeploymentsResponse$
    ];
    exports2.DescribeDaemonRevisions$ = [
      9,
      n032,
      _DDRescr,
      0,
      () => exports2.DescribeDaemonRevisionsRequest$,
      () => exports2.DescribeDaemonRevisionsResponse$
    ];
    exports2.DescribeDaemonTaskDefinition$ = [
      9,
      n032,
      _DDTDe,
      0,
      () => exports2.DescribeDaemonTaskDefinitionRequest$,
      () => exports2.DescribeDaemonTaskDefinitionResponse$
    ];
    exports2.DescribeExpressGatewayService$ = [
      9,
      n032,
      _DEGSe,
      0,
      () => exports2.DescribeExpressGatewayServiceRequest$,
      () => exports2.DescribeExpressGatewayServiceResponse$
    ];
    exports2.DescribeServiceDeployments$ = [
      9,
      n032,
      _DSD,
      0,
      () => exports2.DescribeServiceDeploymentsRequest$,
      () => exports2.DescribeServiceDeploymentsResponse$
    ];
    exports2.DescribeServiceRevisions$ = [
      9,
      n032,
      _DSRescr,
      0,
      () => exports2.DescribeServiceRevisionsRequest$,
      () => exports2.DescribeServiceRevisionsResponse$
    ];
    exports2.DescribeServices$ = [
      9,
      n032,
      _DSes,
      0,
      () => exports2.DescribeServicesRequest$,
      () => exports2.DescribeServicesResponse$
    ];
    exports2.DescribeTaskDefinition$ = [
      9,
      n032,
      _DTDes,
      0,
      () => exports2.DescribeTaskDefinitionRequest$,
      () => exports2.DescribeTaskDefinitionResponse$
    ];
    exports2.DescribeTasks$ = [
      9,
      n032,
      _DT,
      0,
      () => exports2.DescribeTasksRequest$,
      () => exports2.DescribeTasksResponse$
    ];
    exports2.DescribeTaskSets$ = [
      9,
      n032,
      _DTSe,
      0,
      () => exports2.DescribeTaskSetsRequest$,
      () => exports2.DescribeTaskSetsResponse$
    ];
    exports2.DiscoverPollEndpoint$ = [
      9,
      n032,
      _DPE,
      0,
      () => exports2.DiscoverPollEndpointRequest$,
      () => exports2.DiscoverPollEndpointResponse$
    ];
    exports2.ExecuteCommand$ = [
      9,
      n032,
      _EC,
      0,
      () => exports2.ExecuteCommandRequest$,
      () => exports2.ExecuteCommandResponse$
    ];
    exports2.GetTaskProtection$ = [
      9,
      n032,
      _GTP,
      0,
      () => exports2.GetTaskProtectionRequest$,
      () => exports2.GetTaskProtectionResponse$
    ];
    exports2.ListAccountSettings$ = [
      9,
      n032,
      _LAS,
      0,
      () => exports2.ListAccountSettingsRequest$,
      () => exports2.ListAccountSettingsResponse$
    ];
    exports2.ListAttributes$ = [
      9,
      n032,
      _LA,
      0,
      () => exports2.ListAttributesRequest$,
      () => exports2.ListAttributesResponse$
    ];
    exports2.ListClusters$ = [
      9,
      n032,
      _LCi,
      0,
      () => exports2.ListClustersRequest$,
      () => exports2.ListClustersResponse$
    ];
    exports2.ListContainerInstances$ = [
      9,
      n032,
      _LCI,
      0,
      () => exports2.ListContainerInstancesRequest$,
      () => exports2.ListContainerInstancesResponse$
    ];
    exports2.ListDaemonDeployments$ = [
      9,
      n032,
      _LDD,
      0,
      () => exports2.ListDaemonDeploymentsRequest$,
      () => exports2.ListDaemonDeploymentsResponse$
    ];
    exports2.ListDaemons$ = [
      9,
      n032,
      _LD,
      0,
      () => exports2.ListDaemonsRequest$,
      () => exports2.ListDaemonsResponse$
    ];
    exports2.ListDaemonTaskDefinitions$ = [
      9,
      n032,
      _LDTD,
      0,
      () => exports2.ListDaemonTaskDefinitionsRequest$,
      () => exports2.ListDaemonTaskDefinitionsResponse$
    ];
    exports2.ListServiceDeployments$ = [
      9,
      n032,
      _LSD,
      0,
      () => exports2.ListServiceDeploymentsRequest$,
      () => exports2.ListServiceDeploymentsResponse$
    ];
    exports2.ListServices$ = [
      9,
      n032,
      _LS,
      0,
      () => exports2.ListServicesRequest$,
      () => exports2.ListServicesResponse$
    ];
    exports2.ListServicesByNamespace$ = [
      9,
      n032,
      _LSBN,
      0,
      () => exports2.ListServicesByNamespaceRequest$,
      () => exports2.ListServicesByNamespaceResponse$
    ];
    exports2.ListTagsForResource$ = [
      9,
      n032,
      _LTFR,
      0,
      () => exports2.ListTagsForResourceRequest$,
      () => exports2.ListTagsForResourceResponse$
    ];
    exports2.ListTaskDefinitionFamilies$ = [
      9,
      n032,
      _LTDF,
      0,
      () => exports2.ListTaskDefinitionFamiliesRequest$,
      () => exports2.ListTaskDefinitionFamiliesResponse$
    ];
    exports2.ListTaskDefinitions$ = [
      9,
      n032,
      _LTD,
      0,
      () => exports2.ListTaskDefinitionsRequest$,
      () => exports2.ListTaskDefinitionsResponse$
    ];
    exports2.ListTasks$ = [
      9,
      n032,
      _LT,
      0,
      () => exports2.ListTasksRequest$,
      () => exports2.ListTasksResponse$
    ];
    exports2.PutAccountSetting$ = [
      9,
      n032,
      _PAS,
      0,
      () => exports2.PutAccountSettingRequest$,
      () => exports2.PutAccountSettingResponse$
    ];
    exports2.PutAccountSettingDefault$ = [
      9,
      n032,
      _PASD,
      0,
      () => exports2.PutAccountSettingDefaultRequest$,
      () => exports2.PutAccountSettingDefaultResponse$
    ];
    exports2.PutAttributes$ = [
      9,
      n032,
      _PA10,
      0,
      () => exports2.PutAttributesRequest$,
      () => exports2.PutAttributesResponse$
    ];
    exports2.PutClusterCapacityProviders$ = [
      9,
      n032,
      _PCCP,
      0,
      () => exports2.PutClusterCapacityProvidersRequest$,
      () => exports2.PutClusterCapacityProvidersResponse$
    ];
    exports2.RegisterContainerInstance$ = [
      9,
      n032,
      _RCI,
      0,
      () => exports2.RegisterContainerInstanceRequest$,
      () => exports2.RegisterContainerInstanceResponse$
    ];
    exports2.RegisterDaemonTaskDefinition$ = [
      9,
      n032,
      _RDTD,
      0,
      () => exports2.RegisterDaemonTaskDefinitionRequest$,
      () => exports2.RegisterDaemonTaskDefinitionResponse$
    ];
    exports2.RegisterTaskDefinition$ = [
      9,
      n032,
      _RTD,
      0,
      () => exports2.RegisterTaskDefinitionRequest$,
      () => exports2.RegisterTaskDefinitionResponse$
    ];
    exports2.RunTask$ = [
      9,
      n032,
      _RT13,
      0,
      () => exports2.RunTaskRequest$,
      () => exports2.RunTaskResponse$
    ];
    exports2.StartTask$ = [
      9,
      n032,
      _ST11,
      0,
      () => exports2.StartTaskRequest$,
      () => exports2.StartTaskResponse$
    ];
    exports2.StopServiceDeployment$ = [
      9,
      n032,
      _SSD,
      0,
      () => exports2.StopServiceDeploymentRequest$,
      () => exports2.StopServiceDeploymentResponse$
    ];
    exports2.StopTask$ = [
      9,
      n032,
      _STt,
      0,
      () => exports2.StopTaskRequest$,
      () => exports2.StopTaskResponse$
    ];
    exports2.SubmitAttachmentStateChanges$ = [
      9,
      n032,
      _SASC,
      0,
      () => exports2.SubmitAttachmentStateChangesRequest$,
      () => exports2.SubmitAttachmentStateChangesResponse$
    ];
    exports2.SubmitContainerStateChange$ = [
      9,
      n032,
      _SCSC,
      0,
      () => exports2.SubmitContainerStateChangeRequest$,
      () => exports2.SubmitContainerStateChangeResponse$
    ];
    exports2.SubmitTaskStateChange$ = [
      9,
      n032,
      _STSC,
      0,
      () => exports2.SubmitTaskStateChangeRequest$,
      () => exports2.SubmitTaskStateChangeResponse$
    ];
    exports2.TagResource$ = [
      9,
      n032,
      _TR,
      0,
      () => exports2.TagResourceRequest$,
      () => exports2.TagResourceResponse$
    ];
    exports2.UntagResource$ = [
      9,
      n032,
      _UR,
      0,
      () => exports2.UntagResourceRequest$,
      () => exports2.UntagResourceResponse$
    ];
    exports2.UpdateCapacityProvider$ = [
      9,
      n032,
      _UCP,
      0,
      () => exports2.UpdateCapacityProviderRequest$,
      () => exports2.UpdateCapacityProviderResponse$
    ];
    exports2.UpdateCluster$ = [
      9,
      n032,
      _UC,
      0,
      () => exports2.UpdateClusterRequest$,
      () => exports2.UpdateClusterResponse$
    ];
    exports2.UpdateClusterSettings$ = [
      9,
      n032,
      _UCS,
      0,
      () => exports2.UpdateClusterSettingsRequest$,
      () => exports2.UpdateClusterSettingsResponse$
    ];
    exports2.UpdateContainerAgent$ = [
      9,
      n032,
      _UCA,
      0,
      () => exports2.UpdateContainerAgentRequest$,
      () => exports2.UpdateContainerAgentResponse$
    ];
    exports2.UpdateContainerInstancesState$ = [
      9,
      n032,
      _UCIS,
      0,
      () => exports2.UpdateContainerInstancesStateRequest$,
      () => exports2.UpdateContainerInstancesStateResponse$
    ];
    exports2.UpdateDaemon$ = [
      9,
      n032,
      _UD,
      0,
      () => exports2.UpdateDaemonRequest$,
      () => exports2.UpdateDaemonResponse$
    ];
    exports2.UpdateExpressGatewayService$ = [
      9,
      n032,
      _UEGSp,
      0,
      () => exports2.UpdateExpressGatewayServiceRequest$,
      () => exports2.UpdateExpressGatewayServiceResponse$
    ];
    exports2.UpdateService$ = [
      9,
      n032,
      _US,
      0,
      () => exports2.UpdateServiceRequest$,
      () => exports2.UpdateServiceResponse$
    ];
    exports2.UpdateServicePrimaryTaskSet$ = [
      9,
      n032,
      _USPTS,
      0,
      () => exports2.UpdateServicePrimaryTaskSetRequest$,
      () => exports2.UpdateServicePrimaryTaskSetResponse$
    ];
    exports2.UpdateTaskProtection$ = [
      9,
      n032,
      _UTP,
      0,
      () => exports2.UpdateTaskProtectionRequest$,
      () => exports2.UpdateTaskProtectionResponse$
    ];
    exports2.UpdateTaskSet$ = [
      9,
      n032,
      _UTS,
      0,
      () => exports2.UpdateTaskSetRequest$,
      () => exports2.UpdateTaskSetResponse$
    ];
  }
});

// ../../node_modules/@aws-sdk/client-ecs/dist-cjs/runtimeConfig.shared.js
var require_runtimeConfig_shared13 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecs/dist-cjs/runtimeConfig.shared.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var protocols_1 = (init_protocols8(), __toCommonJS(protocols_exports5));
    var smithy_client_1 = require_dist_cjs34();
    var url_parser_1 = require_dist_cjs18();
    var util_base64_1 = require_dist_cjs10();
    var util_utf8_1 = require_dist_cjs9();
    var httpAuthSchemeProvider_1 = require_httpAuthSchemeProvider12();
    var endpointResolver_1 = require_endpointResolver12();
    var schemas_0_1 = require_schemas_012();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2014-11-13",
        base64Decoder: config2?.base64Decoder ?? util_base64_1.fromBase64,
        base64Encoder: config2?.base64Encoder ?? util_base64_1.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? endpointResolver_1.defaultEndpointResolver,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? httpAuthSchemeProvider_1.defaultECSHttpAuthSchemeProvider,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new httpAuthSchemes_1.AwsSdkSigV4Signer()
          }
        ],
        logger: config2?.logger ?? new smithy_client_1.NoOpLogger(),
        protocol: config2?.protocol ?? protocols_1.AwsJson1_1Protocol,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.ecs",
          errorTypeRegistries: schemas_0_1.errorTypeRegistries,
          xmlNamespace: "http://ecs.amazonaws.com/doc/2014-11-13/",
          version: "2014-11-13",
          serviceTarget: "AmazonEC2ContainerServiceV20141113"
        },
        serviceId: config2?.serviceId ?? "ECS",
        urlParser: config2?.urlParser ?? url_parser_1.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? util_utf8_1.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? util_utf8_1.toUtf8
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-ecs/dist-cjs/runtimeConfig.js
var require_runtimeConfig13 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecs/dist-cjs/runtimeConfig.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var package_json_1 = tslib_1.__importDefault(require_package12());
    var client_1 = (init_client8(), __toCommonJS(client_exports7));
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var credential_provider_node_1 = require_dist_cjs122();
    var util_user_agent_node_1 = require_dist_cjs113();
    var config_resolver_1 = require_dist_cjs25();
    var hash_node_1 = require_dist_cjs44();
    var middleware_retry_1 = require_dist_cjs106();
    var node_config_provider_1 = require_dist_cjs29();
    var node_http_handler_1 = require_dist_cjs13();
    var smithy_client_1 = require_dist_cjs34();
    var util_body_length_node_1 = require_dist_cjs45();
    var util_defaults_mode_node_1 = require_dist_cjs46();
    var util_retry_1 = require_dist_cjs22();
    var runtimeConfig_shared_1 = require_runtimeConfig_shared13();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      (0, smithy_client_1.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, util_defaults_mode_node_1.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(smithy_client_1.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = (0, runtimeConfig_shared_1.getRuntimeConfig)(config2);
      (0, client_1.emitWarningIfUnsupportedVersion)(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, node_config_provider_1.loadConfig)(httpAuthSchemes_1.NODE_AUTH_SCHEME_PREFERENCE_OPTIONS, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? util_body_length_node_1.calculateBodyLength,
        credentialDefaultProvider: config2?.credentialDefaultProvider ?? credential_provider_node_1.defaultProvider,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, util_user_agent_node_1.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_json_1.default.version }),
        maxAttempts: config2?.maxAttempts ?? (0, node_config_provider_1.loadConfig)(middleware_retry_1.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_REGION_CONFIG_OPTIONS, { ...config_resolver_1.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: node_http_handler_1.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, node_config_provider_1.loadConfig)({
          ...middleware_retry_1.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || util_retry_1.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? hash_node_1.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? node_http_handler_1.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, node_config_provider_1.loadConfig)(util_user_agent_node_1.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-ecs/dist-cjs/index.js
var require_dist_cjs164 = __commonJS({
  "../../node_modules/@aws-sdk/client-ecs/dist-cjs/index.js"(exports2) {
    "use strict";
    var middlewareHostHeader = require_dist_cjs3();
    var middlewareLogger = require_dist_cjs4();
    var middlewareRecursionDetection = require_dist_cjs5();
    var middlewareUserAgent = require_dist_cjs104();
    var configResolver = require_dist_cjs25();
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var schema = (init_schema4(), __toCommonJS(schema_exports));
    var middlewareContentLength = require_dist_cjs26();
    var middlewareEndpoint = require_dist_cjs31();
    var middlewareRetry = require_dist_cjs106();
    var smithyClient = require_dist_cjs34();
    var httpAuthSchemeProvider = require_httpAuthSchemeProvider12();
    var runtimeConfig = require_runtimeConfig13();
    var regionConfigResolver = require_dist_cjs48();
    var protocolHttp = require_dist_cjs2();
    var schemas_0 = require_schemas_012();
    var utilWaiter = require_dist_cjs156();
    var errors = require_errors11();
    var ECSServiceException = require_ECSServiceException();
    var resolveClientEndpointParameters32 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "ecs"
      });
    }, "resolveClientEndpointParameters");
    var commonParams32 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
    var getHttpAuthExtensionConfiguration32 = /* @__PURE__ */ __name((runtimeConfig2) => {
      const _httpAuthSchemes = runtimeConfig2.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig2.httpAuthSchemeProvider;
      let _credentials = runtimeConfig2.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider2) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider2;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    var resolveHttpAuthRuntimeConfig32 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
    var resolveRuntimeExtensions32 = /* @__PURE__ */ __name((runtimeConfig2, extensions) => {
      const extensionConfiguration = Object.assign(regionConfigResolver.getAwsRegionExtensionConfiguration(runtimeConfig2), smithyClient.getDefaultExtensionConfiguration(runtimeConfig2), protocolHttp.getHttpHandlerExtensionConfiguration(runtimeConfig2), getHttpAuthExtensionConfiguration32(runtimeConfig2));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig2, regionConfigResolver.resolveAwsRegionExtensionConfiguration(extensionConfiguration), smithyClient.resolveDefaultRuntimeConfig(extensionConfiguration), protocolHttp.resolveHttpHandlerRuntimeConfig(extensionConfiguration), resolveHttpAuthRuntimeConfig32(extensionConfiguration));
    }, "resolveRuntimeExtensions");
    var ECSClient2 = class extends smithyClient.Client {
      static {
        __name(this, "ECSClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = runtimeConfig.getRuntimeConfig(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters32(_config_0);
        const _config_2 = middlewareUserAgent.resolveUserAgentConfig(_config_1);
        const _config_3 = middlewareRetry.resolveRetryConfig(_config_2);
        const _config_4 = configResolver.resolveRegionConfig(_config_3);
        const _config_5 = middlewareHostHeader.resolveHostHeaderConfig(_config_4);
        const _config_6 = middlewareEndpoint.resolveEndpointConfig(_config_5);
        const _config_7 = httpAuthSchemeProvider.resolveHttpAuthSchemeConfig(_config_6);
        const _config_8 = resolveRuntimeExtensions32(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(schema.getSchemaSerdePlugin(this.config));
        this.middlewareStack.use(middlewareUserAgent.getUserAgentPlugin(this.config));
        this.middlewareStack.use(middlewareRetry.getRetryPlugin(this.config));
        this.middlewareStack.use(middlewareContentLength.getContentLengthPlugin(this.config));
        this.middlewareStack.use(middlewareHostHeader.getHostHeaderPlugin(this.config));
        this.middlewareStack.use(middlewareLogger.getLoggerPlugin(this.config));
        this.middlewareStack.use(middlewareRecursionDetection.getRecursionDetectionPlugin(this.config));
        this.middlewareStack.use(core.getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: httpAuthSchemeProvider.defaultECSHttpAuthSchemeParametersProvider,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new core.DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(core.getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
    var CreateCapacityProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "CreateCapacityProvider", {}).n("ECSClient", "CreateCapacityProviderCommand").sc(schemas_0.CreateCapacityProvider$).build() {
      static {
        __name(this, "CreateCapacityProviderCommand");
      }
    };
    var CreateClusterCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "CreateCluster", {}).n("ECSClient", "CreateClusterCommand").sc(schemas_0.CreateCluster$).build() {
      static {
        __name(this, "CreateClusterCommand");
      }
    };
    var CreateDaemonCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "CreateDaemon", {}).n("ECSClient", "CreateDaemonCommand").sc(schemas_0.CreateDaemon$).build() {
      static {
        __name(this, "CreateDaemonCommand");
      }
    };
    var CreateExpressGatewayServiceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "CreateExpressGatewayService", {}).n("ECSClient", "CreateExpressGatewayServiceCommand").sc(schemas_0.CreateExpressGatewayService$).build() {
      static {
        __name(this, "CreateExpressGatewayServiceCommand");
      }
    };
    var CreateServiceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "CreateService", {}).n("ECSClient", "CreateServiceCommand").sc(schemas_0.CreateService$).build() {
      static {
        __name(this, "CreateServiceCommand");
      }
    };
    var CreateTaskSetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "CreateTaskSet", {}).n("ECSClient", "CreateTaskSetCommand").sc(schemas_0.CreateTaskSet$).build() {
      static {
        __name(this, "CreateTaskSetCommand");
      }
    };
    var DeleteAccountSettingCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "DeleteAccountSetting", {}).n("ECSClient", "DeleteAccountSettingCommand").sc(schemas_0.DeleteAccountSetting$).build() {
      static {
        __name(this, "DeleteAccountSettingCommand");
      }
    };
    var DeleteAttributesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "DeleteAttributes", {}).n("ECSClient", "DeleteAttributesCommand").sc(schemas_0.DeleteAttributes$).build() {
      static {
        __name(this, "DeleteAttributesCommand");
      }
    };
    var DeleteCapacityProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "DeleteCapacityProvider", {}).n("ECSClient", "DeleteCapacityProviderCommand").sc(schemas_0.DeleteCapacityProvider$).build() {
      static {
        __name(this, "DeleteCapacityProviderCommand");
      }
    };
    var DeleteClusterCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "DeleteCluster", {}).n("ECSClient", "DeleteClusterCommand").sc(schemas_0.DeleteCluster$).build() {
      static {
        __name(this, "DeleteClusterCommand");
      }
    };
    var DeleteDaemonCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "DeleteDaemon", {}).n("ECSClient", "DeleteDaemonCommand").sc(schemas_0.DeleteDaemon$).build() {
      static {
        __name(this, "DeleteDaemonCommand");
      }
    };
    var DeleteDaemonTaskDefinitionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "DeleteDaemonTaskDefinition", {}).n("ECSClient", "DeleteDaemonTaskDefinitionCommand").sc(schemas_0.DeleteDaemonTaskDefinition$).build() {
      static {
        __name(this, "DeleteDaemonTaskDefinitionCommand");
      }
    };
    var DeleteExpressGatewayServiceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "DeleteExpressGatewayService", {}).n("ECSClient", "DeleteExpressGatewayServiceCommand").sc(schemas_0.DeleteExpressGatewayService$).build() {
      static {
        __name(this, "DeleteExpressGatewayServiceCommand");
      }
    };
    var DeleteServiceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "DeleteService", {}).n("ECSClient", "DeleteServiceCommand").sc(schemas_0.DeleteService$).build() {
      static {
        __name(this, "DeleteServiceCommand");
      }
    };
    var DeleteTaskDefinitionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "DeleteTaskDefinitions", {}).n("ECSClient", "DeleteTaskDefinitionsCommand").sc(schemas_0.DeleteTaskDefinitions$).build() {
      static {
        __name(this, "DeleteTaskDefinitionsCommand");
      }
    };
    var DeleteTaskSetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "DeleteTaskSet", {}).n("ECSClient", "DeleteTaskSetCommand").sc(schemas_0.DeleteTaskSet$).build() {
      static {
        __name(this, "DeleteTaskSetCommand");
      }
    };
    var DeregisterContainerInstanceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "DeregisterContainerInstance", {}).n("ECSClient", "DeregisterContainerInstanceCommand").sc(schemas_0.DeregisterContainerInstance$).build() {
      static {
        __name(this, "DeregisterContainerInstanceCommand");
      }
    };
    var DeregisterTaskDefinitionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "DeregisterTaskDefinition", {}).n("ECSClient", "DeregisterTaskDefinitionCommand").sc(schemas_0.DeregisterTaskDefinition$).build() {
      static {
        __name(this, "DeregisterTaskDefinitionCommand");
      }
    };
    var DescribeCapacityProvidersCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "DescribeCapacityProviders", {}).n("ECSClient", "DescribeCapacityProvidersCommand").sc(schemas_0.DescribeCapacityProviders$).build() {
      static {
        __name(this, "DescribeCapacityProvidersCommand");
      }
    };
    var DescribeClustersCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "DescribeClusters", {}).n("ECSClient", "DescribeClustersCommand").sc(schemas_0.DescribeClusters$).build() {
      static {
        __name(this, "DescribeClustersCommand");
      }
    };
    var DescribeContainerInstancesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "DescribeContainerInstances", {}).n("ECSClient", "DescribeContainerInstancesCommand").sc(schemas_0.DescribeContainerInstances$).build() {
      static {
        __name(this, "DescribeContainerInstancesCommand");
      }
    };
    var DescribeDaemonCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "DescribeDaemon", {}).n("ECSClient", "DescribeDaemonCommand").sc(schemas_0.DescribeDaemon$).build() {
      static {
        __name(this, "DescribeDaemonCommand");
      }
    };
    var DescribeDaemonDeploymentsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "DescribeDaemonDeployments", {}).n("ECSClient", "DescribeDaemonDeploymentsCommand").sc(schemas_0.DescribeDaemonDeployments$).build() {
      static {
        __name(this, "DescribeDaemonDeploymentsCommand");
      }
    };
    var DescribeDaemonRevisionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "DescribeDaemonRevisions", {}).n("ECSClient", "DescribeDaemonRevisionsCommand").sc(schemas_0.DescribeDaemonRevisions$).build() {
      static {
        __name(this, "DescribeDaemonRevisionsCommand");
      }
    };
    var DescribeDaemonTaskDefinitionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "DescribeDaemonTaskDefinition", {}).n("ECSClient", "DescribeDaemonTaskDefinitionCommand").sc(schemas_0.DescribeDaemonTaskDefinition$).build() {
      static {
        __name(this, "DescribeDaemonTaskDefinitionCommand");
      }
    };
    var DescribeExpressGatewayServiceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "DescribeExpressGatewayService", {}).n("ECSClient", "DescribeExpressGatewayServiceCommand").sc(schemas_0.DescribeExpressGatewayService$).build() {
      static {
        __name(this, "DescribeExpressGatewayServiceCommand");
      }
    };
    var DescribeServiceDeploymentsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "DescribeServiceDeployments", {}).n("ECSClient", "DescribeServiceDeploymentsCommand").sc(schemas_0.DescribeServiceDeployments$).build() {
      static {
        __name(this, "DescribeServiceDeploymentsCommand");
      }
    };
    var DescribeServiceRevisionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "DescribeServiceRevisions", {}).n("ECSClient", "DescribeServiceRevisionsCommand").sc(schemas_0.DescribeServiceRevisions$).build() {
      static {
        __name(this, "DescribeServiceRevisionsCommand");
      }
    };
    var DescribeServicesCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "DescribeServices", {}).n("ECSClient", "DescribeServicesCommand").sc(schemas_0.DescribeServices$).build() {
      static {
        __name(this, "DescribeServicesCommand");
      }
    };
    var DescribeTaskDefinitionCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "DescribeTaskDefinition", {}).n("ECSClient", "DescribeTaskDefinitionCommand").sc(schemas_0.DescribeTaskDefinition$).build() {
      static {
        __name(this, "DescribeTaskDefinitionCommand");
      }
    };
    var DescribeTasksCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "DescribeTasks", {}).n("ECSClient", "DescribeTasksCommand").sc(schemas_0.DescribeTasks$).build() {
      static {
        __name(this, "DescribeTasksCommand");
      }
    };
    var DescribeTaskSetsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "DescribeTaskSets", {}).n("ECSClient", "DescribeTaskSetsCommand").sc(schemas_0.DescribeTaskSets$).build() {
      static {
        __name(this, "DescribeTaskSetsCommand");
      }
    };
    var DiscoverPollEndpointCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "DiscoverPollEndpoint", {}).n("ECSClient", "DiscoverPollEndpointCommand").sc(schemas_0.DiscoverPollEndpoint$).build() {
      static {
        __name(this, "DiscoverPollEndpointCommand");
      }
    };
    var ExecuteCommandCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "ExecuteCommand", {}).n("ECSClient", "ExecuteCommandCommand").sc(schemas_0.ExecuteCommand$).build() {
      static {
        __name(this, "ExecuteCommandCommand");
      }
    };
    var GetTaskProtectionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "GetTaskProtection", {}).n("ECSClient", "GetTaskProtectionCommand").sc(schemas_0.GetTaskProtection$).build() {
      static {
        __name(this, "GetTaskProtectionCommand");
      }
    };
    var ListAccountSettingsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "ListAccountSettings", {}).n("ECSClient", "ListAccountSettingsCommand").sc(schemas_0.ListAccountSettings$).build() {
      static {
        __name(this, "ListAccountSettingsCommand");
      }
    };
    var ListAttributesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "ListAttributes", {}).n("ECSClient", "ListAttributesCommand").sc(schemas_0.ListAttributes$).build() {
      static {
        __name(this, "ListAttributesCommand");
      }
    };
    var ListClustersCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "ListClusters", {}).n("ECSClient", "ListClustersCommand").sc(schemas_0.ListClusters$).build() {
      static {
        __name(this, "ListClustersCommand");
      }
    };
    var ListContainerInstancesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "ListContainerInstances", {}).n("ECSClient", "ListContainerInstancesCommand").sc(schemas_0.ListContainerInstances$).build() {
      static {
        __name(this, "ListContainerInstancesCommand");
      }
    };
    var ListDaemonDeploymentsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "ListDaemonDeployments", {}).n("ECSClient", "ListDaemonDeploymentsCommand").sc(schemas_0.ListDaemonDeployments$).build() {
      static {
        __name(this, "ListDaemonDeploymentsCommand");
      }
    };
    var ListDaemonsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "ListDaemons", {}).n("ECSClient", "ListDaemonsCommand").sc(schemas_0.ListDaemons$).build() {
      static {
        __name(this, "ListDaemonsCommand");
      }
    };
    var ListDaemonTaskDefinitionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "ListDaemonTaskDefinitions", {}).n("ECSClient", "ListDaemonTaskDefinitionsCommand").sc(schemas_0.ListDaemonTaskDefinitions$).build() {
      static {
        __name(this, "ListDaemonTaskDefinitionsCommand");
      }
    };
    var ListServiceDeploymentsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "ListServiceDeployments", {}).n("ECSClient", "ListServiceDeploymentsCommand").sc(schemas_0.ListServiceDeployments$).build() {
      static {
        __name(this, "ListServiceDeploymentsCommand");
      }
    };
    var ListServicesByNamespaceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "ListServicesByNamespace", {}).n("ECSClient", "ListServicesByNamespaceCommand").sc(schemas_0.ListServicesByNamespace$).build() {
      static {
        __name(this, "ListServicesByNamespaceCommand");
      }
    };
    var ListServicesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "ListServices", {}).n("ECSClient", "ListServicesCommand").sc(schemas_0.ListServices$).build() {
      static {
        __name(this, "ListServicesCommand");
      }
    };
    var ListTagsForResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "ListTagsForResource", {}).n("ECSClient", "ListTagsForResourceCommand").sc(schemas_0.ListTagsForResource$).build() {
      static {
        __name(this, "ListTagsForResourceCommand");
      }
    };
    var ListTaskDefinitionFamiliesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "ListTaskDefinitionFamilies", {}).n("ECSClient", "ListTaskDefinitionFamiliesCommand").sc(schemas_0.ListTaskDefinitionFamilies$).build() {
      static {
        __name(this, "ListTaskDefinitionFamiliesCommand");
      }
    };
    var ListTaskDefinitionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "ListTaskDefinitions", {}).n("ECSClient", "ListTaskDefinitionsCommand").sc(schemas_0.ListTaskDefinitions$).build() {
      static {
        __name(this, "ListTaskDefinitionsCommand");
      }
    };
    var ListTasksCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "ListTasks", {}).n("ECSClient", "ListTasksCommand").sc(schemas_0.ListTasks$).build() {
      static {
        __name(this, "ListTasksCommand");
      }
    };
    var PutAccountSettingCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "PutAccountSetting", {}).n("ECSClient", "PutAccountSettingCommand").sc(schemas_0.PutAccountSetting$).build() {
      static {
        __name(this, "PutAccountSettingCommand");
      }
    };
    var PutAccountSettingDefaultCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "PutAccountSettingDefault", {}).n("ECSClient", "PutAccountSettingDefaultCommand").sc(schemas_0.PutAccountSettingDefault$).build() {
      static {
        __name(this, "PutAccountSettingDefaultCommand");
      }
    };
    var PutAttributesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "PutAttributes", {}).n("ECSClient", "PutAttributesCommand").sc(schemas_0.PutAttributes$).build() {
      static {
        __name(this, "PutAttributesCommand");
      }
    };
    var PutClusterCapacityProvidersCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "PutClusterCapacityProviders", {}).n("ECSClient", "PutClusterCapacityProvidersCommand").sc(schemas_0.PutClusterCapacityProviders$).build() {
      static {
        __name(this, "PutClusterCapacityProvidersCommand");
      }
    };
    var RegisterContainerInstanceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "RegisterContainerInstance", {}).n("ECSClient", "RegisterContainerInstanceCommand").sc(schemas_0.RegisterContainerInstance$).build() {
      static {
        __name(this, "RegisterContainerInstanceCommand");
      }
    };
    var RegisterDaemonTaskDefinitionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "RegisterDaemonTaskDefinition", {}).n("ECSClient", "RegisterDaemonTaskDefinitionCommand").sc(schemas_0.RegisterDaemonTaskDefinition$).build() {
      static {
        __name(this, "RegisterDaemonTaskDefinitionCommand");
      }
    };
    var RegisterTaskDefinitionCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "RegisterTaskDefinition", {}).n("ECSClient", "RegisterTaskDefinitionCommand").sc(schemas_0.RegisterTaskDefinition$).build() {
      static {
        __name(this, "RegisterTaskDefinitionCommand");
      }
    };
    var RunTaskCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "RunTask", {}).n("ECSClient", "RunTaskCommand").sc(schemas_0.RunTask$).build() {
      static {
        __name(this, "RunTaskCommand");
      }
    };
    var StartTaskCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "StartTask", {}).n("ECSClient", "StartTaskCommand").sc(schemas_0.StartTask$).build() {
      static {
        __name(this, "StartTaskCommand");
      }
    };
    var StopServiceDeploymentCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "StopServiceDeployment", {}).n("ECSClient", "StopServiceDeploymentCommand").sc(schemas_0.StopServiceDeployment$).build() {
      static {
        __name(this, "StopServiceDeploymentCommand");
      }
    };
    var StopTaskCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "StopTask", {}).n("ECSClient", "StopTaskCommand").sc(schemas_0.StopTask$).build() {
      static {
        __name(this, "StopTaskCommand");
      }
    };
    var SubmitAttachmentStateChangesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "SubmitAttachmentStateChanges", {}).n("ECSClient", "SubmitAttachmentStateChangesCommand").sc(schemas_0.SubmitAttachmentStateChanges$).build() {
      static {
        __name(this, "SubmitAttachmentStateChangesCommand");
      }
    };
    var SubmitContainerStateChangeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "SubmitContainerStateChange", {}).n("ECSClient", "SubmitContainerStateChangeCommand").sc(schemas_0.SubmitContainerStateChange$).build() {
      static {
        __name(this, "SubmitContainerStateChangeCommand");
      }
    };
    var SubmitTaskStateChangeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "SubmitTaskStateChange", {}).n("ECSClient", "SubmitTaskStateChangeCommand").sc(schemas_0.SubmitTaskStateChange$).build() {
      static {
        __name(this, "SubmitTaskStateChangeCommand");
      }
    };
    var TagResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "TagResource", {}).n("ECSClient", "TagResourceCommand").sc(schemas_0.TagResource$).build() {
      static {
        __name(this, "TagResourceCommand");
      }
    };
    var UntagResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "UntagResource", {}).n("ECSClient", "UntagResourceCommand").sc(schemas_0.UntagResource$).build() {
      static {
        __name(this, "UntagResourceCommand");
      }
    };
    var UpdateCapacityProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "UpdateCapacityProvider", {}).n("ECSClient", "UpdateCapacityProviderCommand").sc(schemas_0.UpdateCapacityProvider$).build() {
      static {
        __name(this, "UpdateCapacityProviderCommand");
      }
    };
    var UpdateClusterCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "UpdateCluster", {}).n("ECSClient", "UpdateClusterCommand").sc(schemas_0.UpdateCluster$).build() {
      static {
        __name(this, "UpdateClusterCommand");
      }
    };
    var UpdateClusterSettingsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "UpdateClusterSettings", {}).n("ECSClient", "UpdateClusterSettingsCommand").sc(schemas_0.UpdateClusterSettings$).build() {
      static {
        __name(this, "UpdateClusterSettingsCommand");
      }
    };
    var UpdateContainerAgentCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "UpdateContainerAgent", {}).n("ECSClient", "UpdateContainerAgentCommand").sc(schemas_0.UpdateContainerAgent$).build() {
      static {
        __name(this, "UpdateContainerAgentCommand");
      }
    };
    var UpdateContainerInstancesStateCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "UpdateContainerInstancesState", {}).n("ECSClient", "UpdateContainerInstancesStateCommand").sc(schemas_0.UpdateContainerInstancesState$).build() {
      static {
        __name(this, "UpdateContainerInstancesStateCommand");
      }
    };
    var UpdateDaemonCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "UpdateDaemon", {}).n("ECSClient", "UpdateDaemonCommand").sc(schemas_0.UpdateDaemon$).build() {
      static {
        __name(this, "UpdateDaemonCommand");
      }
    };
    var UpdateExpressGatewayServiceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "UpdateExpressGatewayService", {}).n("ECSClient", "UpdateExpressGatewayServiceCommand").sc(schemas_0.UpdateExpressGatewayService$).build() {
      static {
        __name(this, "UpdateExpressGatewayServiceCommand");
      }
    };
    var UpdateServiceCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "UpdateService", {}).n("ECSClient", "UpdateServiceCommand").sc(schemas_0.UpdateService$).build() {
      static {
        __name(this, "UpdateServiceCommand");
      }
    };
    var UpdateServicePrimaryTaskSetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "UpdateServicePrimaryTaskSet", {}).n("ECSClient", "UpdateServicePrimaryTaskSetCommand").sc(schemas_0.UpdateServicePrimaryTaskSet$).build() {
      static {
        __name(this, "UpdateServicePrimaryTaskSetCommand");
      }
    };
    var UpdateTaskProtectionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "UpdateTaskProtection", {}).n("ECSClient", "UpdateTaskProtectionCommand").sc(schemas_0.UpdateTaskProtection$).build() {
      static {
        __name(this, "UpdateTaskProtectionCommand");
      }
    };
    var UpdateTaskSetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonEC2ContainerServiceV20141113", "UpdateTaskSet", {}).n("ECSClient", "UpdateTaskSetCommand").sc(schemas_0.UpdateTaskSet$).build() {
      static {
        __name(this, "UpdateTaskSetCommand");
      }
    };
    var paginateListAccountSettings = core.createPaginator(ECSClient2, ListAccountSettingsCommand, "nextToken", "nextToken", "maxResults");
    var paginateListAttributes = core.createPaginator(ECSClient2, ListAttributesCommand, "nextToken", "nextToken", "maxResults");
    var paginateListClusters = core.createPaginator(ECSClient2, ListClustersCommand2, "nextToken", "nextToken", "maxResults");
    var paginateListContainerInstances = core.createPaginator(ECSClient2, ListContainerInstancesCommand, "nextToken", "nextToken", "maxResults");
    var paginateListServicesByNamespace = core.createPaginator(ECSClient2, ListServicesByNamespaceCommand, "nextToken", "nextToken", "maxResults");
    var paginateListServices = core.createPaginator(ECSClient2, ListServicesCommand, "nextToken", "nextToken", "maxResults");
    var paginateListTaskDefinitionFamilies = core.createPaginator(ECSClient2, ListTaskDefinitionFamiliesCommand, "nextToken", "nextToken", "maxResults");
    var paginateListTaskDefinitions = core.createPaginator(ECSClient2, ListTaskDefinitionsCommand, "nextToken", "nextToken", "maxResults");
    var paginateListTasks = core.createPaginator(ECSClient2, ListTasksCommand2, "nextToken", "nextToken", "maxResults");
    var checkState$8 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeDaemonCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.daemon.status;
          }, "returnComparator");
          if (returnComparator() === "ACTIVE") {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.daemon.status;
          }, "returnComparator");
          if (returnComparator() === "DELETE_IN_PROGRESS") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$8");
    var waitForDaemonActive = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$8);
    }, "waitForDaemonActive");
    var waitUntilDaemonActive = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$8);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilDaemonActive");
    var checkState$7 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeDaemonDeploymentsCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.daemonDeployments);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.status;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "STOPPED";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.failures);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.reason;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "MISSING") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$7");
    var waitForDaemonDeploymentStopped = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$7);
    }, "waitForDaemonDeploymentStopped");
    var waitUntilDaemonDeploymentStopped = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$7);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilDaemonDeploymentStopped");
    var checkState$6 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeDaemonDeploymentsCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.daemonDeployments);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.status;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "SUCCESSFUL";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.daemonDeployments);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.status;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "STOPPED") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.daemonDeployments);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.status;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "ROLLBACK_FAILED") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.daemonDeployments);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.status;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "ROLLBACK_SUCCESSFUL") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.failures);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.reason;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "MISSING") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$6");
    var waitForDaemonDeploymentSuccessful = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$6);
    }, "waitForDaemonDeploymentSuccessful");
    var waitUntilDaemonDeploymentSuccessful = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$6);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilDaemonDeploymentSuccessful");
    var checkState$5 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeDaemonTaskDefinitionCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.daemonTaskDefinition.status;
          }, "returnComparator");
          if (returnComparator() === "ACTIVE") {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.daemonTaskDefinition.status;
          }, "returnComparator");
          if (returnComparator() === "DELETE_IN_PROGRESS") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.daemonTaskDefinition.status;
          }, "returnComparator");
          if (returnComparator() === "DELETED") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$5");
    var waitForDaemonTaskDefinitionActive = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$5);
    }, "waitForDaemonTaskDefinitionActive");
    var waitUntilDaemonTaskDefinitionActive = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$5);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilDaemonTaskDefinitionActive");
    var checkState$4 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeDaemonTaskDefinitionCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.daemonTaskDefinition.status;
          }, "returnComparator");
          if (returnComparator() === "DELETED") {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$4");
    var waitForDaemonTaskDefinitionDeleted = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$4);
    }, "waitForDaemonTaskDefinitionDeleted");
    var waitUntilDaemonTaskDefinitionDeleted = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$4);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilDaemonTaskDefinitionDeleted");
    var checkState$3 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeServicesCommand2(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.failures);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.reason;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "MISSING") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.services);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.status;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "INACTIVE") {
              return { state: utilWaiter.WaiterState.SUCCESS, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$3");
    var waitForServicesInactive = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 600 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$3);
    }, "waitForServicesInactive");
    var waitUntilServicesInactive = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 600 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$3);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilServicesInactive");
    var checkState$2 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeServicesCommand2(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.failures);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.reason;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "MISSING") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.services);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.status;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "DRAINING") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.services);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.status;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "INACTIVE") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let filterRes_2 = result2.services.filter((element_1) => {
              return !(element_1.deployments.length == 1 && element_1.runningCount == element_1.desiredCount);
            });
            return filterRes_2.length == 0;
          }, "returnComparator");
          if (returnComparator() == true) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$2");
    var waitForServicesStable = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 600 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$2);
    }, "waitForServicesStable");
    var waitUntilServicesStable2 = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 600 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$2);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilServicesStable");
    var checkState$1 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeTasksCommand2(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.tasks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.lastStatus;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "STOPPED") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.failures);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.reason;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "MISSING") {
              return { state: utilWaiter.WaiterState.FAILURE, reason };
            }
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.tasks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.lastStatus;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "RUNNING";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$1");
    var waitForTasksRunning = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 6, maxDelay: 600 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$1);
    }, "waitForTasksRunning");
    var waitUntilTasksRunning = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 6, maxDelay: 600 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$1);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilTasksRunning");
    var checkState = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeTasksCommand2(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.tasks);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.lastStatus;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "STOPPED";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState");
    var waitForTasksStopped = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 6, maxDelay: 600 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState);
    }, "waitForTasksStopped");
    var waitUntilTasksStopped = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 6, maxDelay: 600 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilTasksStopped");
    var commands32 = {
      CreateCapacityProviderCommand,
      CreateClusterCommand,
      CreateDaemonCommand,
      CreateExpressGatewayServiceCommand,
      CreateServiceCommand,
      CreateTaskSetCommand,
      DeleteAccountSettingCommand,
      DeleteAttributesCommand,
      DeleteCapacityProviderCommand,
      DeleteClusterCommand,
      DeleteDaemonCommand,
      DeleteDaemonTaskDefinitionCommand,
      DeleteExpressGatewayServiceCommand,
      DeleteServiceCommand,
      DeleteTaskDefinitionsCommand,
      DeleteTaskSetCommand,
      DeregisterContainerInstanceCommand,
      DeregisterTaskDefinitionCommand,
      DescribeCapacityProvidersCommand,
      DescribeClustersCommand,
      DescribeContainerInstancesCommand,
      DescribeDaemonCommand,
      DescribeDaemonDeploymentsCommand,
      DescribeDaemonRevisionsCommand,
      DescribeDaemonTaskDefinitionCommand,
      DescribeExpressGatewayServiceCommand,
      DescribeServiceDeploymentsCommand,
      DescribeServiceRevisionsCommand,
      DescribeServicesCommand: DescribeServicesCommand2,
      DescribeTaskDefinitionCommand: DescribeTaskDefinitionCommand2,
      DescribeTasksCommand: DescribeTasksCommand2,
      DescribeTaskSetsCommand,
      DiscoverPollEndpointCommand,
      ExecuteCommandCommand,
      GetTaskProtectionCommand,
      ListAccountSettingsCommand,
      ListAttributesCommand,
      ListClustersCommand: ListClustersCommand2,
      ListContainerInstancesCommand,
      ListDaemonDeploymentsCommand,
      ListDaemonsCommand,
      ListDaemonTaskDefinitionsCommand,
      ListServiceDeploymentsCommand,
      ListServicesCommand,
      ListServicesByNamespaceCommand,
      ListTagsForResourceCommand,
      ListTaskDefinitionFamiliesCommand,
      ListTaskDefinitionsCommand,
      ListTasksCommand: ListTasksCommand2,
      PutAccountSettingCommand,
      PutAccountSettingDefaultCommand,
      PutAttributesCommand,
      PutClusterCapacityProvidersCommand,
      RegisterContainerInstanceCommand,
      RegisterDaemonTaskDefinitionCommand,
      RegisterTaskDefinitionCommand: RegisterTaskDefinitionCommand2,
      RunTaskCommand,
      StartTaskCommand,
      StopServiceDeploymentCommand,
      StopTaskCommand,
      SubmitAttachmentStateChangesCommand,
      SubmitContainerStateChangeCommand,
      SubmitTaskStateChangeCommand,
      TagResourceCommand,
      UntagResourceCommand,
      UpdateCapacityProviderCommand,
      UpdateClusterCommand,
      UpdateClusterSettingsCommand,
      UpdateContainerAgentCommand,
      UpdateContainerInstancesStateCommand,
      UpdateDaemonCommand,
      UpdateExpressGatewayServiceCommand,
      UpdateServiceCommand: UpdateServiceCommand2,
      UpdateServicePrimaryTaskSetCommand,
      UpdateTaskProtectionCommand,
      UpdateTaskSetCommand
    };
    var paginators = {
      paginateListAccountSettings,
      paginateListAttributes,
      paginateListClusters,
      paginateListContainerInstances,
      paginateListServices,
      paginateListServicesByNamespace,
      paginateListTaskDefinitionFamilies,
      paginateListTaskDefinitions,
      paginateListTasks
    };
    var waiters = {
      waitUntilDaemonActive,
      waitUntilDaemonDeploymentSuccessful,
      waitUntilDaemonDeploymentStopped,
      waitUntilDaemonTaskDefinitionActive,
      waitUntilDaemonTaskDefinitionDeleted,
      waitUntilServicesInactive,
      waitUntilServicesStable: waitUntilServicesStable2,
      waitUntilTasksRunning,
      waitUntilTasksStopped
    };
    var ECS = class extends ECSClient2 {
      static {
        __name(this, "ECS");
      }
    };
    smithyClient.createAggregatedClient(commands32, ECS, { paginators, waiters });
    var AcceleratorManufacturer = {
      AMAZON_WEB_SERVICES: "amazon-web-services",
      AMD: "amd",
      HABANA: "habana",
      NVIDIA: "nvidia",
      XILINX: "xilinx"
    };
    var AcceleratorName = {
      A100: "a100",
      A10G: "a10g",
      H100: "h100",
      INFERENTIA: "inferentia",
      K520: "k520",
      K80: "k80",
      M60: "m60",
      RADEON_PRO_V520: "radeon-pro-v520",
      T4: "t4",
      T4G: "t4g",
      V100: "v100",
      VU9P: "vu9p"
    };
    var AcceleratorType = {
      FPGA: "fpga",
      GPU: "gpu",
      INFERENCE: "inference"
    };
    var AccessType = {
      PRIVATE: "PRIVATE",
      PUBLIC: "PUBLIC"
    };
    var AgentUpdateStatus = {
      FAILED: "FAILED",
      PENDING: "PENDING",
      STAGED: "STAGED",
      STAGING: "STAGING",
      UPDATED: "UPDATED",
      UPDATING: "UPDATING"
    };
    var ManagedDraining = {
      DISABLED: "DISABLED",
      ENABLED: "ENABLED"
    };
    var ManagedScalingStatus = {
      DISABLED: "DISABLED",
      ENABLED: "ENABLED"
    };
    var ManagedTerminationProtection = {
      DISABLED: "DISABLED",
      ENABLED: "ENABLED"
    };
    var AutoRepairActionsStatus = {
      DISABLED: "DISABLED",
      ENABLED: "ENABLED"
    };
    var CapacityOptionType = {
      ON_DEMAND: "ON_DEMAND",
      RESERVED: "RESERVED",
      SPOT: "SPOT"
    };
    var CapacityReservationPreference = {
      RESERVATIONS_EXCLUDED: "RESERVATIONS_EXCLUDED",
      RESERVATIONS_FIRST: "RESERVATIONS_FIRST",
      RESERVATIONS_ONLY: "RESERVATIONS_ONLY"
    };
    var BareMetal = {
      EXCLUDED: "excluded",
      INCLUDED: "included",
      REQUIRED: "required"
    };
    var BurstablePerformance = {
      EXCLUDED: "excluded",
      INCLUDED: "included",
      REQUIRED: "required"
    };
    var CpuManufacturer = {
      AMAZON_WEB_SERVICES: "amazon-web-services",
      AMD: "amd",
      INTEL: "intel"
    };
    var InstanceGeneration = {
      CURRENT: "current",
      PREVIOUS: "previous"
    };
    var LocalStorage = {
      EXCLUDED: "excluded",
      INCLUDED: "included",
      REQUIRED: "required"
    };
    var LocalStorageType = {
      HDD: "hdd",
      SSD: "ssd"
    };
    var ManagedInstancesMonitoringOptions = {
      BASIC: "BASIC",
      DETAILED: "DETAILED"
    };
    var PropagateMITags = {
      CAPACITY_PROVIDER: "CAPACITY_PROVIDER",
      NONE: "NONE"
    };
    var CapacityProviderStatus = {
      ACTIVE: "ACTIVE",
      DEPROVISIONING: "DEPROVISIONING",
      INACTIVE: "INACTIVE",
      PROVISIONING: "PROVISIONING"
    };
    var CapacityProviderType = {
      EC2_AUTOSCALING: "EC2_AUTOSCALING",
      FARGATE: "FARGATE",
      FARGATE_SPOT: "FARGATE_SPOT",
      MANAGED_INSTANCES: "MANAGED_INSTANCES"
    };
    var CapacityProviderUpdateStatus = {
      CREATE_COMPLETE: "CREATE_COMPLETE",
      CREATE_FAILED: "CREATE_FAILED",
      CREATE_IN_PROGRESS: "CREATE_IN_PROGRESS",
      DELETE_COMPLETE: "DELETE_COMPLETE",
      DELETE_FAILED: "DELETE_FAILED",
      DELETE_IN_PROGRESS: "DELETE_IN_PROGRESS",
      UPDATE_COMPLETE: "UPDATE_COMPLETE",
      UPDATE_FAILED: "UPDATE_FAILED",
      UPDATE_IN_PROGRESS: "UPDATE_IN_PROGRESS"
    };
    var CapacityProviderField = {
      TAGS: "TAGS"
    };
    var ExecuteCommandLogging = {
      DEFAULT: "DEFAULT",
      NONE: "NONE",
      OVERRIDE: "OVERRIDE"
    };
    var ClusterSettingName = {
      CONTAINER_INSIGHTS: "containerInsights"
    };
    var TargetType = {
      CONTAINER_INSTANCE: "container-instance"
    };
    var InstanceHealthCheckState = {
      IMPAIRED: "IMPAIRED",
      INITIALIZING: "INITIALIZING",
      INSUFFICIENT_DATA: "INSUFFICIENT_DATA",
      OK: "OK"
    };
    var InstanceHealthCheckType = {
      ACCELERATED_COMPUTE: "ACCELERATED_COMPUTE",
      CONTAINER_RUNTIME: "CONTAINER_RUNTIME",
      DAEMON: "DAEMON"
    };
    var ClusterField = {
      ATTACHMENTS: "ATTACHMENTS",
      CONFIGURATIONS: "CONFIGURATIONS",
      SETTINGS: "SETTINGS",
      STATISTICS: "STATISTICS",
      TAGS: "TAGS"
    };
    var ContainerInstanceStatus = {
      ACTIVE: "ACTIVE",
      DEREGISTERING: "DEREGISTERING",
      DRAINING: "DRAINING",
      REGISTERING: "REGISTERING",
      REGISTRATION_FAILED: "REGISTRATION_FAILED"
    };
    var TransportProtocol = {
      TCP: "tcp",
      UDP: "udp"
    };
    var ManagedAgentName = {
      ExecuteCommandAgent: "ExecuteCommandAgent"
    };
    var ContainerInstanceField = {
      CONTAINER_INSTANCE_HEALTH: "CONTAINER_INSTANCE_HEALTH",
      TAGS: "TAGS"
    };
    var DesiredStatus = {
      PENDING: "PENDING",
      RUNNING: "RUNNING",
      STOPPED: "STOPPED"
    };
    var LaunchType = {
      EC2: "EC2",
      EXTERNAL: "EXTERNAL",
      FARGATE: "FARGATE",
      MANAGED_INSTANCES: "MANAGED_INSTANCES"
    };
    var PlatformDeviceType = {
      GPU: "GPU"
    };
    var DaemonDeploymentRollbackMonitorsStatus = {
      DISABLED: "DISABLED",
      MONITORING: "MONITORING",
      MONITORING_COMPLETE: "MONITORING_COMPLETE",
      TRIGGERED: "TRIGGERED"
    };
    var DaemonDeploymentStatus = {
      IN_PROGRESS: "IN_PROGRESS",
      PENDING: "PENDING",
      ROLLBACK_FAILED: "ROLLBACK_FAILED",
      ROLLBACK_IN_PROGRESS: "ROLLBACK_IN_PROGRESS",
      ROLLBACK_SUCCESSFUL: "ROLLBACK_SUCCESSFUL",
      STOPPED: "STOPPED",
      STOP_REQUESTED: "STOP_REQUESTED",
      SUCCESSFUL: "SUCCESSFUL"
    };
    var DaemonPropagateTags = {
      DAEMON: "DAEMON",
      NONE: "NONE"
    };
    var DaemonStatus = {
      ACTIVE: "ACTIVE",
      DELETE_IN_PROGRESS: "DELETE_IN_PROGRESS"
    };
    var ContainerCondition = {
      COMPLETE: "COMPLETE",
      HEALTHY: "HEALTHY",
      START: "START",
      SUCCESS: "SUCCESS"
    };
    var EnvironmentFileType = {
      S3: "s3"
    };
    var FirelensConfigurationType = {
      FLUENTBIT: "fluentbit",
      FLUENTD: "fluentd"
    };
    var DeviceCgroupPermission = {
      MKNOD: "mknod",
      READ: "read",
      WRITE: "write"
    };
    var LogDriver = {
      AWSFIRELENS: "awsfirelens",
      AWSLOGS: "awslogs",
      FLUENTD: "fluentd",
      GELF: "gelf",
      JOURNALD: "journald",
      JSON_FILE: "json-file",
      SPLUNK: "splunk",
      SYSLOG: "syslog"
    };
    var UlimitName = {
      CORE: "core",
      CPU: "cpu",
      DATA: "data",
      FSIZE: "fsize",
      LOCKS: "locks",
      MEMLOCK: "memlock",
      MSGQUEUE: "msgqueue",
      NICE: "nice",
      NOFILE: "nofile",
      NPROC: "nproc",
      RSS: "rss",
      RTPRIO: "rtprio",
      RTTIME: "rttime",
      SIGPENDING: "sigpending",
      STACK: "stack"
    };
    var DaemonTaskDefinitionStatus = {
      ACTIVE: "ACTIVE",
      DELETED: "DELETED",
      DELETE_IN_PROGRESS: "DELETE_IN_PROGRESS"
    };
    var DaemonTaskDefinitionRevisionFilter = {
      LAST_REGISTERED: "LAST_REGISTERED"
    };
    var SortOrder = {
      ASC: "ASC",
      DESC: "DESC"
    };
    var DaemonTaskDefinitionStatusFilter = {
      ACTIVE: "ACTIVE",
      ALL: "ALL",
      DELETE_IN_PROGRESS: "DELETE_IN_PROGRESS"
    };
    var SettingName = {
      AWSVPC_TRUNKING: "awsvpcTrunking",
      CONTAINER_INSIGHTS: "containerInsights",
      CONTAINER_INSTANCE_LONG_ARN_FORMAT: "containerInstanceLongArnFormat",
      DEFAULT_LOG_DRIVER_MODE: "defaultLogDriverMode",
      FARGATE_EVENT_WINDOWS: "fargateEventWindows",
      FARGATE_FIPS_MODE: "fargateFIPSMode",
      FARGATE_TASK_RETIREMENT_WAIT_PERIOD: "fargateTaskRetirementWaitPeriod",
      GUARD_DUTY_ACTIVATE: "guardDutyActivate",
      SERVICE_LONG_ARN_FORMAT: "serviceLongArnFormat",
      TAG_RESOURCE_AUTHORIZATION: "tagResourceAuthorization",
      TASK_LONG_ARN_FORMAT: "taskLongArnFormat"
    };
    var SettingType = {
      AWS_MANAGED: "aws_managed",
      USER: "user"
    };
    var Compatibility = {
      EC2: "EC2",
      EXTERNAL: "EXTERNAL",
      FARGATE: "FARGATE",
      MANAGED_INSTANCES: "MANAGED_INSTANCES"
    };
    var ApplicationProtocol = {
      GRPC: "grpc",
      HTTP: "http",
      HTTP2: "http2"
    };
    var ResourceType = {
      GPU: "GPU",
      INFERENCE_ACCELERATOR: "InferenceAccelerator"
    };
    var VersionConsistency = {
      DISABLED: "disabled",
      ENABLED: "enabled"
    };
    var IpcMode = {
      HOST: "host",
      NONE: "none",
      TASK: "task"
    };
    var NetworkMode = {
      AWSVPC: "awsvpc",
      BRIDGE: "bridge",
      HOST: "host",
      NONE: "none"
    };
    var PidMode = {
      HOST: "host",
      TASK: "task"
    };
    var TaskDefinitionPlacementConstraintType = {
      MEMBER_OF: "memberOf"
    };
    var ProxyConfigurationType = {
      APPMESH: "APPMESH"
    };
    var CPUArchitecture = {
      ARM64: "ARM64",
      X86_64: "X86_64"
    };
    var OSFamily = {
      LINUX: "LINUX",
      WINDOWS_SERVER_2004_CORE: "WINDOWS_SERVER_2004_CORE",
      WINDOWS_SERVER_2016_FULL: "WINDOWS_SERVER_2016_FULL",
      WINDOWS_SERVER_2019_CORE: "WINDOWS_SERVER_2019_CORE",
      WINDOWS_SERVER_2019_FULL: "WINDOWS_SERVER_2019_FULL",
      WINDOWS_SERVER_2022_CORE: "WINDOWS_SERVER_2022_CORE",
      WINDOWS_SERVER_2022_FULL: "WINDOWS_SERVER_2022_FULL",
      WINDOWS_SERVER_2025_CORE: "WINDOWS_SERVER_2025_CORE",
      WINDOWS_SERVER_2025_FULL: "WINDOWS_SERVER_2025_FULL",
      WINDOWS_SERVER_20H2_CORE: "WINDOWS_SERVER_20H2_CORE"
    };
    var TaskDefinitionStatus = {
      ACTIVE: "ACTIVE",
      DELETE_IN_PROGRESS: "DELETE_IN_PROGRESS",
      INACTIVE: "INACTIVE"
    };
    var Scope = {
      SHARED: "shared",
      TASK: "task"
    };
    var EFSAuthorizationConfigIAM = {
      DISABLED: "DISABLED",
      ENABLED: "ENABLED"
    };
    var EFSTransitEncryption = {
      DISABLED: "DISABLED",
      ENABLED: "ENABLED"
    };
    var TaskDefinitionField = {
      TAGS: "TAGS"
    };
    var TaskDefinitionFamilyStatus = {
      ACTIVE: "ACTIVE",
      ALL: "ALL",
      INACTIVE: "INACTIVE"
    };
    var ServiceDeploymentRollbackMonitorsStatus = {
      DISABLED: "DISABLED",
      MONITORING: "MONITORING",
      MONITORING_COMPLETE: "MONITORING_COMPLETE",
      TRIGGERED: "TRIGGERED"
    };
    var DeploymentLifecycleHookStage = {
      POST_PRODUCTION_TRAFFIC_SHIFT: "POST_PRODUCTION_TRAFFIC_SHIFT",
      POST_SCALE_UP: "POST_SCALE_UP",
      POST_TEST_TRAFFIC_SHIFT: "POST_TEST_TRAFFIC_SHIFT",
      PRE_SCALE_UP: "PRE_SCALE_UP",
      PRODUCTION_TRAFFIC_SHIFT: "PRODUCTION_TRAFFIC_SHIFT",
      RECONCILE_SERVICE: "RECONCILE_SERVICE",
      TEST_TRAFFIC_SHIFT: "TEST_TRAFFIC_SHIFT"
    };
    var DeploymentStrategy = {
      BLUE_GREEN: "BLUE_GREEN",
      CANARY: "CANARY",
      LINEAR: "LINEAR",
      ROLLING: "ROLLING"
    };
    var ServiceDeploymentLifecycleStage = {
      BAKE_TIME: "BAKE_TIME",
      CLEAN_UP: "CLEAN_UP",
      POST_PRODUCTION_TRAFFIC_SHIFT: "POST_PRODUCTION_TRAFFIC_SHIFT",
      POST_SCALE_UP: "POST_SCALE_UP",
      POST_TEST_TRAFFIC_SHIFT: "POST_TEST_TRAFFIC_SHIFT",
      PRE_SCALE_UP: "PRE_SCALE_UP",
      PRODUCTION_TRAFFIC_SHIFT: "PRODUCTION_TRAFFIC_SHIFT",
      RECONCILE_SERVICE: "RECONCILE_SERVICE",
      SCALE_UP: "SCALE_UP",
      TEST_TRAFFIC_SHIFT: "TEST_TRAFFIC_SHIFT"
    };
    var ServiceDeploymentStatus = {
      IN_PROGRESS: "IN_PROGRESS",
      PENDING: "PENDING",
      ROLLBACK_FAILED: "ROLLBACK_FAILED",
      ROLLBACK_IN_PROGRESS: "ROLLBACK_IN_PROGRESS",
      ROLLBACK_REQUESTED: "ROLLBACK_REQUESTED",
      ROLLBACK_SUCCESSFUL: "ROLLBACK_SUCCESSFUL",
      STOPPED: "STOPPED",
      STOP_REQUESTED: "STOP_REQUESTED",
      SUCCESSFUL: "SUCCESSFUL"
    };
    var ExpressGatewayServiceScalingMetric = {
      AverageCPUUtilization: "AVERAGE_CPU",
      AverageMemoryUtilization: "AVERAGE_MEMORY",
      RequestCountPerTarget: "REQUEST_COUNT_PER_TARGET"
    };
    var ExpressGatewayServiceStatusCode = {
      ACTIVE: "ACTIVE",
      DRAINING: "DRAINING",
      INACTIVE: "INACTIVE"
    };
    var AvailabilityZoneRebalancing = {
      DISABLED: "DISABLED",
      ENABLED: "ENABLED"
    };
    var DeploymentControllerType = {
      CODE_DEPLOY: "CODE_DEPLOY",
      ECS: "ECS",
      EXTERNAL: "EXTERNAL"
    };
    var AssignPublicIp = {
      DISABLED: "DISABLED",
      ENABLED: "ENABLED"
    };
    var PlacementConstraintType = {
      DISTINCT_INSTANCE: "distinctInstance",
      MEMBER_OF: "memberOf"
    };
    var PlacementStrategyType = {
      BINPACK: "binpack",
      RANDOM: "random",
      SPREAD: "spread"
    };
    var PropagateTags = {
      NONE: "NONE",
      SERVICE: "SERVICE",
      TASK_DEFINITION: "TASK_DEFINITION"
    };
    var SchedulingStrategy = {
      DAEMON: "DAEMON",
      REPLICA: "REPLICA"
    };
    var ServiceConnectAccessLoggingFormat = {
      JSON: "JSON",
      TEXT: "TEXT"
    };
    var ServiceConnectIncludeQueryParameters = {
      DISABLED: "DISABLED",
      ENABLED: "ENABLED"
    };
    var TaskFilesystemType = {
      EXT3: "ext3",
      EXT4: "ext4",
      NTFS: "ntfs",
      XFS: "xfs"
    };
    var EBSResourceType = {
      VOLUME: "volume"
    };
    var DeploymentRolloutState = {
      COMPLETED: "COMPLETED",
      FAILED: "FAILED",
      IN_PROGRESS: "IN_PROGRESS"
    };
    var ResourceManagementType = {
      CUSTOMER: "CUSTOMER",
      ECS: "ECS"
    };
    var ScaleUnit = {
      PERCENT: "PERCENT"
    };
    var StabilityStatus = {
      STABILIZING: "STABILIZING",
      STEADY_STATE: "STEADY_STATE"
    };
    var ExpressGatewayServiceInclude = {
      TAGS: "TAGS"
    };
    var ServiceField = {
      TAGS: "TAGS"
    };
    var StopServiceDeploymentStopType = {
      ABORT: "ABORT",
      ROLLBACK: "ROLLBACK"
    };
    var ManagedResourceStatus = {
      ACTIVE: "ACTIVE",
      DELETED: "DELETED",
      DEPROVISIONING: "DEPROVISIONING",
      FAILED: "FAILED",
      PROVISIONING: "PROVISIONING"
    };
    var TaskField = {
      TAGS: "TAGS"
    };
    var Connectivity = {
      CONNECTED: "CONNECTED",
      DISCONNECTED: "DISCONNECTED"
    };
    var HealthStatus = {
      HEALTHY: "HEALTHY",
      UNHEALTHY: "UNHEALTHY",
      UNKNOWN: "UNKNOWN"
    };
    var TaskStopCode = {
      ESSENTIAL_CONTAINER_EXITED: "EssentialContainerExited",
      SERVICE_SCHEDULER_INITIATED: "ServiceSchedulerInitiated",
      SPOT_INTERRUPTION: "SpotInterruption",
      TASK_FAILED_TO_START: "TaskFailedToStart",
      TERMINATION_NOTICE: "TerminationNotice",
      USER_INITIATED: "UserInitiated"
    };
    var TaskSetField = {
      TAGS: "TAGS"
    };
    exports2.$Command = smithyClient.Command;
    exports2.__Client = smithyClient.Client;
    exports2.ECSServiceException = ECSServiceException.ECSServiceException;
    exports2.AcceleratorManufacturer = AcceleratorManufacturer;
    exports2.AcceleratorName = AcceleratorName;
    exports2.AcceleratorType = AcceleratorType;
    exports2.AccessType = AccessType;
    exports2.AgentUpdateStatus = AgentUpdateStatus;
    exports2.ApplicationProtocol = ApplicationProtocol;
    exports2.AssignPublicIp = AssignPublicIp;
    exports2.AutoRepairActionsStatus = AutoRepairActionsStatus;
    exports2.AvailabilityZoneRebalancing = AvailabilityZoneRebalancing;
    exports2.BareMetal = BareMetal;
    exports2.BurstablePerformance = BurstablePerformance;
    exports2.CPUArchitecture = CPUArchitecture;
    exports2.CapacityOptionType = CapacityOptionType;
    exports2.CapacityProviderField = CapacityProviderField;
    exports2.CapacityProviderStatus = CapacityProviderStatus;
    exports2.CapacityProviderType = CapacityProviderType;
    exports2.CapacityProviderUpdateStatus = CapacityProviderUpdateStatus;
    exports2.CapacityReservationPreference = CapacityReservationPreference;
    exports2.ClusterField = ClusterField;
    exports2.ClusterSettingName = ClusterSettingName;
    exports2.Compatibility = Compatibility;
    exports2.Connectivity = Connectivity;
    exports2.ContainerCondition = ContainerCondition;
    exports2.ContainerInstanceField = ContainerInstanceField;
    exports2.ContainerInstanceStatus = ContainerInstanceStatus;
    exports2.CpuManufacturer = CpuManufacturer;
    exports2.CreateCapacityProviderCommand = CreateCapacityProviderCommand;
    exports2.CreateClusterCommand = CreateClusterCommand;
    exports2.CreateDaemonCommand = CreateDaemonCommand;
    exports2.CreateExpressGatewayServiceCommand = CreateExpressGatewayServiceCommand;
    exports2.CreateServiceCommand = CreateServiceCommand;
    exports2.CreateTaskSetCommand = CreateTaskSetCommand;
    exports2.DaemonDeploymentRollbackMonitorsStatus = DaemonDeploymentRollbackMonitorsStatus;
    exports2.DaemonDeploymentStatus = DaemonDeploymentStatus;
    exports2.DaemonPropagateTags = DaemonPropagateTags;
    exports2.DaemonStatus = DaemonStatus;
    exports2.DaemonTaskDefinitionRevisionFilter = DaemonTaskDefinitionRevisionFilter;
    exports2.DaemonTaskDefinitionStatus = DaemonTaskDefinitionStatus;
    exports2.DaemonTaskDefinitionStatusFilter = DaemonTaskDefinitionStatusFilter;
    exports2.DeleteAccountSettingCommand = DeleteAccountSettingCommand;
    exports2.DeleteAttributesCommand = DeleteAttributesCommand;
    exports2.DeleteCapacityProviderCommand = DeleteCapacityProviderCommand;
    exports2.DeleteClusterCommand = DeleteClusterCommand;
    exports2.DeleteDaemonCommand = DeleteDaemonCommand;
    exports2.DeleteDaemonTaskDefinitionCommand = DeleteDaemonTaskDefinitionCommand;
    exports2.DeleteExpressGatewayServiceCommand = DeleteExpressGatewayServiceCommand;
    exports2.DeleteServiceCommand = DeleteServiceCommand;
    exports2.DeleteTaskDefinitionsCommand = DeleteTaskDefinitionsCommand;
    exports2.DeleteTaskSetCommand = DeleteTaskSetCommand;
    exports2.DeploymentControllerType = DeploymentControllerType;
    exports2.DeploymentLifecycleHookStage = DeploymentLifecycleHookStage;
    exports2.DeploymentRolloutState = DeploymentRolloutState;
    exports2.DeploymentStrategy = DeploymentStrategy;
    exports2.DeregisterContainerInstanceCommand = DeregisterContainerInstanceCommand;
    exports2.DeregisterTaskDefinitionCommand = DeregisterTaskDefinitionCommand;
    exports2.DescribeCapacityProvidersCommand = DescribeCapacityProvidersCommand;
    exports2.DescribeClustersCommand = DescribeClustersCommand;
    exports2.DescribeContainerInstancesCommand = DescribeContainerInstancesCommand;
    exports2.DescribeDaemonCommand = DescribeDaemonCommand;
    exports2.DescribeDaemonDeploymentsCommand = DescribeDaemonDeploymentsCommand;
    exports2.DescribeDaemonRevisionsCommand = DescribeDaemonRevisionsCommand;
    exports2.DescribeDaemonTaskDefinitionCommand = DescribeDaemonTaskDefinitionCommand;
    exports2.DescribeExpressGatewayServiceCommand = DescribeExpressGatewayServiceCommand;
    exports2.DescribeServiceDeploymentsCommand = DescribeServiceDeploymentsCommand;
    exports2.DescribeServiceRevisionsCommand = DescribeServiceRevisionsCommand;
    exports2.DescribeServicesCommand = DescribeServicesCommand2;
    exports2.DescribeTaskDefinitionCommand = DescribeTaskDefinitionCommand2;
    exports2.DescribeTaskSetsCommand = DescribeTaskSetsCommand;
    exports2.DescribeTasksCommand = DescribeTasksCommand2;
    exports2.DesiredStatus = DesiredStatus;
    exports2.DeviceCgroupPermission = DeviceCgroupPermission;
    exports2.DiscoverPollEndpointCommand = DiscoverPollEndpointCommand;
    exports2.EBSResourceType = EBSResourceType;
    exports2.ECS = ECS;
    exports2.ECSClient = ECSClient2;
    exports2.EFSAuthorizationConfigIAM = EFSAuthorizationConfigIAM;
    exports2.EFSTransitEncryption = EFSTransitEncryption;
    exports2.EnvironmentFileType = EnvironmentFileType;
    exports2.ExecuteCommandCommand = ExecuteCommandCommand;
    exports2.ExecuteCommandLogging = ExecuteCommandLogging;
    exports2.ExpressGatewayServiceInclude = ExpressGatewayServiceInclude;
    exports2.ExpressGatewayServiceScalingMetric = ExpressGatewayServiceScalingMetric;
    exports2.ExpressGatewayServiceStatusCode = ExpressGatewayServiceStatusCode;
    exports2.FirelensConfigurationType = FirelensConfigurationType;
    exports2.GetTaskProtectionCommand = GetTaskProtectionCommand;
    exports2.HealthStatus = HealthStatus;
    exports2.InstanceGeneration = InstanceGeneration;
    exports2.InstanceHealthCheckState = InstanceHealthCheckState;
    exports2.InstanceHealthCheckType = InstanceHealthCheckType;
    exports2.IpcMode = IpcMode;
    exports2.LaunchType = LaunchType;
    exports2.ListAccountSettingsCommand = ListAccountSettingsCommand;
    exports2.ListAttributesCommand = ListAttributesCommand;
    exports2.ListClustersCommand = ListClustersCommand2;
    exports2.ListContainerInstancesCommand = ListContainerInstancesCommand;
    exports2.ListDaemonDeploymentsCommand = ListDaemonDeploymentsCommand;
    exports2.ListDaemonTaskDefinitionsCommand = ListDaemonTaskDefinitionsCommand;
    exports2.ListDaemonsCommand = ListDaemonsCommand;
    exports2.ListServiceDeploymentsCommand = ListServiceDeploymentsCommand;
    exports2.ListServicesByNamespaceCommand = ListServicesByNamespaceCommand;
    exports2.ListServicesCommand = ListServicesCommand;
    exports2.ListTagsForResourceCommand = ListTagsForResourceCommand;
    exports2.ListTaskDefinitionFamiliesCommand = ListTaskDefinitionFamiliesCommand;
    exports2.ListTaskDefinitionsCommand = ListTaskDefinitionsCommand;
    exports2.ListTasksCommand = ListTasksCommand2;
    exports2.LocalStorage = LocalStorage;
    exports2.LocalStorageType = LocalStorageType;
    exports2.LogDriver = LogDriver;
    exports2.ManagedAgentName = ManagedAgentName;
    exports2.ManagedDraining = ManagedDraining;
    exports2.ManagedInstancesMonitoringOptions = ManagedInstancesMonitoringOptions;
    exports2.ManagedResourceStatus = ManagedResourceStatus;
    exports2.ManagedScalingStatus = ManagedScalingStatus;
    exports2.ManagedTerminationProtection = ManagedTerminationProtection;
    exports2.NetworkMode = NetworkMode;
    exports2.OSFamily = OSFamily;
    exports2.PidMode = PidMode;
    exports2.PlacementConstraintType = PlacementConstraintType;
    exports2.PlacementStrategyType = PlacementStrategyType;
    exports2.PlatformDeviceType = PlatformDeviceType;
    exports2.PropagateMITags = PropagateMITags;
    exports2.PropagateTags = PropagateTags;
    exports2.ProxyConfigurationType = ProxyConfigurationType;
    exports2.PutAccountSettingCommand = PutAccountSettingCommand;
    exports2.PutAccountSettingDefaultCommand = PutAccountSettingDefaultCommand;
    exports2.PutAttributesCommand = PutAttributesCommand;
    exports2.PutClusterCapacityProvidersCommand = PutClusterCapacityProvidersCommand;
    exports2.RegisterContainerInstanceCommand = RegisterContainerInstanceCommand;
    exports2.RegisterDaemonTaskDefinitionCommand = RegisterDaemonTaskDefinitionCommand;
    exports2.RegisterTaskDefinitionCommand = RegisterTaskDefinitionCommand2;
    exports2.ResourceManagementType = ResourceManagementType;
    exports2.ResourceType = ResourceType;
    exports2.RunTaskCommand = RunTaskCommand;
    exports2.ScaleUnit = ScaleUnit;
    exports2.SchedulingStrategy = SchedulingStrategy;
    exports2.Scope = Scope;
    exports2.ServiceConnectAccessLoggingFormat = ServiceConnectAccessLoggingFormat;
    exports2.ServiceConnectIncludeQueryParameters = ServiceConnectIncludeQueryParameters;
    exports2.ServiceDeploymentLifecycleStage = ServiceDeploymentLifecycleStage;
    exports2.ServiceDeploymentRollbackMonitorsStatus = ServiceDeploymentRollbackMonitorsStatus;
    exports2.ServiceDeploymentStatus = ServiceDeploymentStatus;
    exports2.ServiceField = ServiceField;
    exports2.SettingName = SettingName;
    exports2.SettingType = SettingType;
    exports2.SortOrder = SortOrder;
    exports2.StabilityStatus = StabilityStatus;
    exports2.StartTaskCommand = StartTaskCommand;
    exports2.StopServiceDeploymentCommand = StopServiceDeploymentCommand;
    exports2.StopServiceDeploymentStopType = StopServiceDeploymentStopType;
    exports2.StopTaskCommand = StopTaskCommand;
    exports2.SubmitAttachmentStateChangesCommand = SubmitAttachmentStateChangesCommand;
    exports2.SubmitContainerStateChangeCommand = SubmitContainerStateChangeCommand;
    exports2.SubmitTaskStateChangeCommand = SubmitTaskStateChangeCommand;
    exports2.TagResourceCommand = TagResourceCommand;
    exports2.TargetType = TargetType;
    exports2.TaskDefinitionFamilyStatus = TaskDefinitionFamilyStatus;
    exports2.TaskDefinitionField = TaskDefinitionField;
    exports2.TaskDefinitionPlacementConstraintType = TaskDefinitionPlacementConstraintType;
    exports2.TaskDefinitionStatus = TaskDefinitionStatus;
    exports2.TaskField = TaskField;
    exports2.TaskFilesystemType = TaskFilesystemType;
    exports2.TaskSetField = TaskSetField;
    exports2.TaskStopCode = TaskStopCode;
    exports2.TransportProtocol = TransportProtocol;
    exports2.UlimitName = UlimitName;
    exports2.UntagResourceCommand = UntagResourceCommand;
    exports2.UpdateCapacityProviderCommand = UpdateCapacityProviderCommand;
    exports2.UpdateClusterCommand = UpdateClusterCommand;
    exports2.UpdateClusterSettingsCommand = UpdateClusterSettingsCommand;
    exports2.UpdateContainerAgentCommand = UpdateContainerAgentCommand;
    exports2.UpdateContainerInstancesStateCommand = UpdateContainerInstancesStateCommand;
    exports2.UpdateDaemonCommand = UpdateDaemonCommand;
    exports2.UpdateExpressGatewayServiceCommand = UpdateExpressGatewayServiceCommand;
    exports2.UpdateServiceCommand = UpdateServiceCommand2;
    exports2.UpdateServicePrimaryTaskSetCommand = UpdateServicePrimaryTaskSetCommand;
    exports2.UpdateTaskProtectionCommand = UpdateTaskProtectionCommand;
    exports2.UpdateTaskSetCommand = UpdateTaskSetCommand;
    exports2.VersionConsistency = VersionConsistency;
    exports2.paginateListAccountSettings = paginateListAccountSettings;
    exports2.paginateListAttributes = paginateListAttributes;
    exports2.paginateListClusters = paginateListClusters;
    exports2.paginateListContainerInstances = paginateListContainerInstances;
    exports2.paginateListServices = paginateListServices;
    exports2.paginateListServicesByNamespace = paginateListServicesByNamespace;
    exports2.paginateListTaskDefinitionFamilies = paginateListTaskDefinitionFamilies;
    exports2.paginateListTaskDefinitions = paginateListTaskDefinitions;
    exports2.paginateListTasks = paginateListTasks;
    exports2.waitForDaemonActive = waitForDaemonActive;
    exports2.waitForDaemonDeploymentStopped = waitForDaemonDeploymentStopped;
    exports2.waitForDaemonDeploymentSuccessful = waitForDaemonDeploymentSuccessful;
    exports2.waitForDaemonTaskDefinitionActive = waitForDaemonTaskDefinitionActive;
    exports2.waitForDaemonTaskDefinitionDeleted = waitForDaemonTaskDefinitionDeleted;
    exports2.waitForServicesInactive = waitForServicesInactive;
    exports2.waitForServicesStable = waitForServicesStable;
    exports2.waitForTasksRunning = waitForTasksRunning;
    exports2.waitForTasksStopped = waitForTasksStopped;
    exports2.waitUntilDaemonActive = waitUntilDaemonActive;
    exports2.waitUntilDaemonDeploymentStopped = waitUntilDaemonDeploymentStopped;
    exports2.waitUntilDaemonDeploymentSuccessful = waitUntilDaemonDeploymentSuccessful;
    exports2.waitUntilDaemonTaskDefinitionActive = waitUntilDaemonTaskDefinitionActive;
    exports2.waitUntilDaemonTaskDefinitionDeleted = waitUntilDaemonTaskDefinitionDeleted;
    exports2.waitUntilServicesInactive = waitUntilServicesInactive;
    exports2.waitUntilServicesStable = waitUntilServicesStable2;
    exports2.waitUntilTasksRunning = waitUntilTasksRunning;
    exports2.waitUntilTasksStopped = waitUntilTasksStopped;
    Object.prototype.hasOwnProperty.call(schemas_0, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: schemas_0["__proto__"]
    });
    Object.keys(schemas_0).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = schemas_0[k32];
    });
    Object.prototype.hasOwnProperty.call(errors, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: errors["__proto__"]
    });
    Object.keys(errors).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = errors[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-elastic-load-balancing-v2/dist-cjs/auth/httpAuthSchemeProvider.js
var require_httpAuthSchemeProvider13 = __commonJS({
  "../../node_modules/@aws-sdk/client-elastic-load-balancing-v2/dist-cjs/auth/httpAuthSchemeProvider.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.resolveHttpAuthSchemeConfig = exports2.defaultElasticLoadBalancingV2HttpAuthSchemeProvider = exports2.defaultElasticLoadBalancingV2HttpAuthSchemeParametersProvider = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var util_middleware_1 = require_dist_cjs6();
    var defaultElasticLoadBalancingV2HttpAuthSchemeParametersProvider = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, util_middleware_1.getSmithyContext)(context).operation,
        region: await (0, util_middleware_1.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultElasticLoadBalancingV2HttpAuthSchemeParametersProvider");
    exports2.defaultElasticLoadBalancingV2HttpAuthSchemeParametersProvider = defaultElasticLoadBalancingV2HttpAuthSchemeParametersProvider;
    function createAwsAuthSigv4HttpAuthOption32(authParameters) {
      return {
        schemeId: "aws.auth#sigv4",
        signingProperties: {
          name: "elasticloadbalancing",
          region: authParameters.region
        },
        propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
          signingProperties: {
            config: config2,
            context
          }
        }), "propertiesExtractor")
      };
    }
    __name(createAwsAuthSigv4HttpAuthOption32, "createAwsAuthSigv4HttpAuthOption");
    var defaultElasticLoadBalancingV2HttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption32(authParameters));
        }
      }
      return options;
    }, "defaultElasticLoadBalancingV2HttpAuthSchemeProvider");
    exports2.defaultElasticLoadBalancingV2HttpAuthSchemeProvider = defaultElasticLoadBalancingV2HttpAuthSchemeProvider;
    var resolveHttpAuthSchemeConfig32 = /* @__PURE__ */ __name((config2) => {
      const config_0 = (0, httpAuthSchemes_1.resolveAwsSdkSigV4Config)(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, util_middleware_1.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
    exports2.resolveHttpAuthSchemeConfig = resolveHttpAuthSchemeConfig32;
  }
});

// ../../node_modules/@aws-sdk/client-elastic-load-balancing-v2/package.json
var require_package13 = __commonJS({
  "../../node_modules/@aws-sdk/client-elastic-load-balancing-v2/package.json"(exports2, module2) {
    module2.exports = {
      name: "@aws-sdk/client-elastic-load-balancing-v2",
      description: "AWS SDK for JavaScript Elastic Load Balancing V2 Client for Node.js, Browser and React Native",
      version: "3.1036.0",
      scripts: {
        build: "concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline client-elastic-load-balancing-v2",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        "extract:docs": "api-extractor run --local",
        "generate:client": "node ../../scripts/generate-clients/single-service --solo elastic-load-balancing-v2",
        "test:e2e": "yarn g:vitest run -c vitest.config.e2e.mts --mode development",
        "test:e2e:watch": "yarn g:vitest watch -c vitest.config.e2e.mts",
        "test:index": "tsc --noEmit ./test/index-types.ts && node ./test/index-objects.spec.mjs"
      },
      main: "./dist-cjs/index.js",
      types: "./dist-types/index.d.ts",
      module: "./dist-es/index.js",
      sideEffects: false,
      dependencies: {
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.5",
        "@aws-sdk/credential-provider-node": "^3.972.36",
        "@aws-sdk/middleware-host-header": "^3.972.10",
        "@aws-sdk/middleware-logger": "^3.972.10",
        "@aws-sdk/middleware-recursion-detection": "^3.972.11",
        "@aws-sdk/middleware-user-agent": "^3.972.35",
        "@aws-sdk/region-config-resolver": "^3.972.13",
        "@aws-sdk/types": "^3.973.8",
        "@aws-sdk/util-endpoints": "^3.996.8",
        "@aws-sdk/util-user-agent-browser": "^3.972.10",
        "@aws-sdk/util-user-agent-node": "^3.973.21",
        "@smithy/config-resolver": "^4.4.17",
        "@smithy/core": "^3.23.17",
        "@smithy/fetch-http-handler": "^5.3.17",
        "@smithy/hash-node": "^4.2.14",
        "@smithy/invalid-dependency": "^4.2.14",
        "@smithy/middleware-content-length": "^4.2.14",
        "@smithy/middleware-endpoint": "^4.4.32",
        "@smithy/middleware-retry": "^4.5.5",
        "@smithy/middleware-serde": "^4.2.20",
        "@smithy/middleware-stack": "^4.2.14",
        "@smithy/node-config-provider": "^4.3.14",
        "@smithy/node-http-handler": "^4.6.1",
        "@smithy/protocol-http": "^5.3.14",
        "@smithy/smithy-client": "^4.12.13",
        "@smithy/types": "^4.14.1",
        "@smithy/url-parser": "^4.2.14",
        "@smithy/util-base64": "^4.3.2",
        "@smithy/util-body-length-browser": "^4.2.2",
        "@smithy/util-body-length-node": "^4.2.3",
        "@smithy/util-defaults-mode-browser": "^4.3.49",
        "@smithy/util-defaults-mode-node": "^4.2.54",
        "@smithy/util-endpoints": "^3.4.2",
        "@smithy/util-middleware": "^4.2.14",
        "@smithy/util-retry": "^4.3.4",
        "@smithy/util-utf8": "^4.2.2",
        "@smithy/util-waiter": "^4.2.16",
        tslib: "^2.6.2"
      },
      devDependencies: {
        "@tsconfig/node20": "20.1.8",
        "@types/node": "^20.14.8",
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3"
      },
      engines: {
        node: ">=20.0.0"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "dist-*/**"
      ],
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      browser: {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.browser"
      },
      "react-native": {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.native"
      },
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/clients/client-elastic-load-balancing-v2",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "clients/client-elastic-load-balancing-v2"
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-elastic-load-balancing-v2/dist-cjs/endpoint/bdd.js
var require_bdd13 = __commonJS({
  "../../node_modules/@aws-sdk/client-elastic-load-balancing-v2/dist-cjs/endpoint/bdd.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.bdd = void 0;
    var util_endpoints_1 = require_dist_cjs20();
    var k32 = "ref";
    var a32 = -1;
    var b32 = true;
    var c32 = "isSet";
    var d32 = "PartitionResult";
    var e32 = "booleanEquals";
    var f32 = "getAttr";
    var g32 = { [k32]: "Endpoint" };
    var h32 = { [k32]: d32 };
    var i32 = {};
    var j32 = [{ [k32]: "Region" }];
    var _data32 = {
      conditions: [
        [c32, [g32]],
        [c32, j32],
        ["aws.partition", j32, d32],
        [e32, [{ [k32]: "UseFIPS" }, b32]],
        [e32, [{ [k32]: "UseDualStack" }, b32]],
        [e32, [{ fn: f32, argv: [h32, "supportsDualStack"] }, b32]],
        [e32, [{ fn: f32, argv: [h32, "supportsFIPS"] }, b32]],
        ["stringEquals", [{ fn: f32, argv: [h32, "name"] }, "aws-us-gov"]]
      ],
      results: [
        [a32],
        [a32, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a32, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [g32, i32],
        ["https://elasticloadbalancing-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", i32],
        [a32, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://elasticloadbalancing.{Region}.amazonaws.com", i32],
        ["https://elasticloadbalancing-fips.{Region}.{PartitionResult#dnsSuffix}", i32],
        [a32, "FIPS is enabled but this partition does not support FIPS"],
        ["https://elasticloadbalancing.{Region}.{PartitionResult#dualStackDnsSuffix}", i32],
        [a32, "DualStack is enabled but this partition does not support DualStack"],
        ["https://elasticloadbalancing.{Region}.{PartitionResult#dnsSuffix}", i32],
        [a32, "Invalid Configuration: Missing Region"]
      ]
    };
    var root32 = 2;
    var r32 = 1e8;
    var nodes32 = new Int32Array([
      -1,
      1,
      -1,
      0,
      13,
      3,
      1,
      4,
      r32 + 12,
      2,
      5,
      r32 + 12,
      3,
      8,
      6,
      4,
      7,
      r32 + 11,
      5,
      r32 + 9,
      r32 + 10,
      4,
      11,
      9,
      6,
      10,
      r32 + 8,
      7,
      r32 + 6,
      r32 + 7,
      5,
      12,
      r32 + 5,
      6,
      r32 + 4,
      r32 + 5,
      3,
      r32 + 1,
      14,
      4,
      r32 + 2,
      r32 + 3
    ]);
    exports2.bdd = util_endpoints_1.BinaryDecisionDiagram.from(nodes32, root32, _data32.conditions, _data32.results);
  }
});

// ../../node_modules/@aws-sdk/client-elastic-load-balancing-v2/dist-cjs/endpoint/endpointResolver.js
var require_endpointResolver13 = __commonJS({
  "../../node_modules/@aws-sdk/client-elastic-load-balancing-v2/dist-cjs/endpoint/endpointResolver.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.defaultEndpointResolver = void 0;
    var util_endpoints_1 = require_dist_cjs21();
    var util_endpoints_2 = require_dist_cjs20();
    var bdd_1 = require_bdd13();
    var cache32 = new util_endpoints_2.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    var defaultEndpointResolver32 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache32.get(endpointParams, () => (0, util_endpoints_2.decideEndpoint)(bdd_1.bdd, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    exports2.defaultEndpointResolver = defaultEndpointResolver32;
    util_endpoints_2.customEndpointFunctions.aws = util_endpoints_1.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-elastic-load-balancing-v2/dist-cjs/models/ElasticLoadBalancingV2ServiceException.js
var require_ElasticLoadBalancingV2ServiceException = __commonJS({
  "../../node_modules/@aws-sdk/client-elastic-load-balancing-v2/dist-cjs/models/ElasticLoadBalancingV2ServiceException.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ElasticLoadBalancingV2ServiceException = exports2.__ServiceException = void 0;
    var smithy_client_1 = require_dist_cjs34();
    Object.defineProperty(exports2, "__ServiceException", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return smithy_client_1.ServiceException;
    }, "get") });
    var ElasticLoadBalancingV2ServiceException = class _ElasticLoadBalancingV2ServiceException extends smithy_client_1.ServiceException {
      static {
        __name(this, "ElasticLoadBalancingV2ServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _ElasticLoadBalancingV2ServiceException.prototype);
      }
    };
    exports2.ElasticLoadBalancingV2ServiceException = ElasticLoadBalancingV2ServiceException;
  }
});

// ../../node_modules/@aws-sdk/client-elastic-load-balancing-v2/dist-cjs/models/errors.js
var require_errors12 = __commonJS({
  "../../node_modules/@aws-sdk/client-elastic-load-balancing-v2/dist-cjs/models/errors.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.TrustStoreInUseException = exports2.TrustStoreAssociationNotFoundException = exports2.DeleteAssociationSameAccountException = exports2.TooManyTrustStoresException = exports2.InvalidCaCertificatesBundleException = exports2.DuplicateTrustStoreNameException = exports2.DuplicateTargetGroupNameException = exports2.TooManyTargetGroupsException = exports2.TooManyRulesException = exports2.PriorityInUseException = exports2.TooManyLoadBalancersException = exports2.SubnetNotFoundException = exports2.ResourceInUseException = exports2.OperationNotPermittedException = exports2.InvalidSubnetException = exports2.InvalidSecurityGroupException = exports2.InvalidSchemeException = exports2.DuplicateLoadBalancerNameException = exports2.UnsupportedProtocolException = exports2.TrustStoreNotReadyException = exports2.TooManyUniqueTargetGroupsPerLoadBalancerException = exports2.TooManyTargetsException = exports2.TooManyRegistrationsForTargetIdException = exports2.TooManyListenersException = exports2.TooManyActionsException = exports2.TargetGroupAssociationLimitException = exports2.SSLPolicyNotFoundException = exports2.InvalidLoadBalancerActionException = exports2.InvalidConfigurationRequestException = exports2.IncompatibleProtocolsException = exports2.DuplicateListenerException = exports2.CapacityUnitsLimitExceededException = exports2.CapacityReservationPendingException = exports2.CapacityDecreaseRequestsLimitExceededException = exports2.CaCertificatesBundleNotFoundException = exports2.AvailabilityZoneNotSupportedException = exports2.ALPNPolicyNotSupportedException = exports2.AllocationIdNotFoundException = exports2.TooManyTrustStoreRevocationEntriesException = exports2.RevocationContentNotFoundException = exports2.InvalidRevocationContentException = exports2.TrustStoreNotFoundException = exports2.TooManyTagsException = exports2.TargetGroupNotFoundException = exports2.RuleNotFoundException = exports2.LoadBalancerNotFoundException = exports2.DuplicateTagKeysException = exports2.TooManyCertificatesException = exports2.ListenerNotFoundException = exports2.CertificateNotFoundException = void 0;
    exports2.PriorRequestNotCompleteException = exports2.InsufficientCapacityException = exports2.ResourceNotFoundException = exports2.RevocationIdNotFoundException = exports2.HealthUnavailableException = exports2.InvalidTargetException = void 0;
    var ElasticLoadBalancingV2ServiceException_1 = require_ElasticLoadBalancingV2ServiceException();
    var CertificateNotFoundException = class _CertificateNotFoundException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "CertificateNotFoundException");
      }
      name = "CertificateNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "CertificateNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CertificateNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.CertificateNotFoundException = CertificateNotFoundException;
    var ListenerNotFoundException = class _ListenerNotFoundException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "ListenerNotFoundException");
      }
      name = "ListenerNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "ListenerNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ListenerNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ListenerNotFoundException = ListenerNotFoundException;
    var TooManyCertificatesException = class _TooManyCertificatesException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "TooManyCertificatesException");
      }
      name = "TooManyCertificatesException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "TooManyCertificatesException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyCertificatesException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.TooManyCertificatesException = TooManyCertificatesException;
    var DuplicateTagKeysException = class _DuplicateTagKeysException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "DuplicateTagKeysException");
      }
      name = "DuplicateTagKeysException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "DuplicateTagKeysException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DuplicateTagKeysException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.DuplicateTagKeysException = DuplicateTagKeysException;
    var LoadBalancerNotFoundException = class _LoadBalancerNotFoundException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "LoadBalancerNotFoundException");
      }
      name = "LoadBalancerNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "LoadBalancerNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _LoadBalancerNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.LoadBalancerNotFoundException = LoadBalancerNotFoundException;
    var RuleNotFoundException = class _RuleNotFoundException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "RuleNotFoundException");
      }
      name = "RuleNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "RuleNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _RuleNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.RuleNotFoundException = RuleNotFoundException;
    var TargetGroupNotFoundException = class _TargetGroupNotFoundException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "TargetGroupNotFoundException");
      }
      name = "TargetGroupNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "TargetGroupNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TargetGroupNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.TargetGroupNotFoundException = TargetGroupNotFoundException;
    var TooManyTagsException = class _TooManyTagsException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "TooManyTagsException");
      }
      name = "TooManyTagsException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "TooManyTagsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyTagsException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.TooManyTagsException = TooManyTagsException;
    var TrustStoreNotFoundException = class _TrustStoreNotFoundException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "TrustStoreNotFoundException");
      }
      name = "TrustStoreNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "TrustStoreNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TrustStoreNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.TrustStoreNotFoundException = TrustStoreNotFoundException;
    var InvalidRevocationContentException = class _InvalidRevocationContentException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "InvalidRevocationContentException");
      }
      name = "InvalidRevocationContentException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidRevocationContentException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidRevocationContentException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidRevocationContentException = InvalidRevocationContentException;
    var RevocationContentNotFoundException = class _RevocationContentNotFoundException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "RevocationContentNotFoundException");
      }
      name = "RevocationContentNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "RevocationContentNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _RevocationContentNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.RevocationContentNotFoundException = RevocationContentNotFoundException;
    var TooManyTrustStoreRevocationEntriesException = class _TooManyTrustStoreRevocationEntriesException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "TooManyTrustStoreRevocationEntriesException");
      }
      name = "TooManyTrustStoreRevocationEntriesException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "TooManyTrustStoreRevocationEntriesException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyTrustStoreRevocationEntriesException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.TooManyTrustStoreRevocationEntriesException = TooManyTrustStoreRevocationEntriesException;
    var AllocationIdNotFoundException = class _AllocationIdNotFoundException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "AllocationIdNotFoundException");
      }
      name = "AllocationIdNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "AllocationIdNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AllocationIdNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.AllocationIdNotFoundException = AllocationIdNotFoundException;
    var ALPNPolicyNotSupportedException = class _ALPNPolicyNotSupportedException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "ALPNPolicyNotSupportedException");
      }
      name = "ALPNPolicyNotSupportedException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "ALPNPolicyNotSupportedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ALPNPolicyNotSupportedException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ALPNPolicyNotSupportedException = ALPNPolicyNotSupportedException;
    var AvailabilityZoneNotSupportedException = class _AvailabilityZoneNotSupportedException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "AvailabilityZoneNotSupportedException");
      }
      name = "AvailabilityZoneNotSupportedException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "AvailabilityZoneNotSupportedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AvailabilityZoneNotSupportedException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.AvailabilityZoneNotSupportedException = AvailabilityZoneNotSupportedException;
    var CaCertificatesBundleNotFoundException = class _CaCertificatesBundleNotFoundException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "CaCertificatesBundleNotFoundException");
      }
      name = "CaCertificatesBundleNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "CaCertificatesBundleNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CaCertificatesBundleNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.CaCertificatesBundleNotFoundException = CaCertificatesBundleNotFoundException;
    var CapacityDecreaseRequestsLimitExceededException = class _CapacityDecreaseRequestsLimitExceededException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "CapacityDecreaseRequestsLimitExceededException");
      }
      name = "CapacityDecreaseRequestsLimitExceededException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "CapacityDecreaseRequestsLimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CapacityDecreaseRequestsLimitExceededException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.CapacityDecreaseRequestsLimitExceededException = CapacityDecreaseRequestsLimitExceededException;
    var CapacityReservationPendingException = class _CapacityReservationPendingException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "CapacityReservationPendingException");
      }
      name = "CapacityReservationPendingException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "CapacityReservationPendingException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CapacityReservationPendingException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.CapacityReservationPendingException = CapacityReservationPendingException;
    var CapacityUnitsLimitExceededException = class _CapacityUnitsLimitExceededException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "CapacityUnitsLimitExceededException");
      }
      name = "CapacityUnitsLimitExceededException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "CapacityUnitsLimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CapacityUnitsLimitExceededException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.CapacityUnitsLimitExceededException = CapacityUnitsLimitExceededException;
    var DuplicateListenerException = class _DuplicateListenerException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "DuplicateListenerException");
      }
      name = "DuplicateListenerException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "DuplicateListenerException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DuplicateListenerException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.DuplicateListenerException = DuplicateListenerException;
    var IncompatibleProtocolsException = class _IncompatibleProtocolsException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "IncompatibleProtocolsException");
      }
      name = "IncompatibleProtocolsException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "IncompatibleProtocolsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _IncompatibleProtocolsException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.IncompatibleProtocolsException = IncompatibleProtocolsException;
    var InvalidConfigurationRequestException = class _InvalidConfigurationRequestException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "InvalidConfigurationRequestException");
      }
      name = "InvalidConfigurationRequestException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidConfigurationRequestException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidConfigurationRequestException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidConfigurationRequestException = InvalidConfigurationRequestException;
    var InvalidLoadBalancerActionException = class _InvalidLoadBalancerActionException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "InvalidLoadBalancerActionException");
      }
      name = "InvalidLoadBalancerActionException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidLoadBalancerActionException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidLoadBalancerActionException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidLoadBalancerActionException = InvalidLoadBalancerActionException;
    var SSLPolicyNotFoundException = class _SSLPolicyNotFoundException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "SSLPolicyNotFoundException");
      }
      name = "SSLPolicyNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "SSLPolicyNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _SSLPolicyNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.SSLPolicyNotFoundException = SSLPolicyNotFoundException;
    var TargetGroupAssociationLimitException = class _TargetGroupAssociationLimitException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "TargetGroupAssociationLimitException");
      }
      name = "TargetGroupAssociationLimitException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "TargetGroupAssociationLimitException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TargetGroupAssociationLimitException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.TargetGroupAssociationLimitException = TargetGroupAssociationLimitException;
    var TooManyActionsException = class _TooManyActionsException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "TooManyActionsException");
      }
      name = "TooManyActionsException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "TooManyActionsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyActionsException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.TooManyActionsException = TooManyActionsException;
    var TooManyListenersException = class _TooManyListenersException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "TooManyListenersException");
      }
      name = "TooManyListenersException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "TooManyListenersException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyListenersException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.TooManyListenersException = TooManyListenersException;
    var TooManyRegistrationsForTargetIdException = class _TooManyRegistrationsForTargetIdException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "TooManyRegistrationsForTargetIdException");
      }
      name = "TooManyRegistrationsForTargetIdException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "TooManyRegistrationsForTargetIdException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyRegistrationsForTargetIdException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.TooManyRegistrationsForTargetIdException = TooManyRegistrationsForTargetIdException;
    var TooManyTargetsException = class _TooManyTargetsException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "TooManyTargetsException");
      }
      name = "TooManyTargetsException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "TooManyTargetsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyTargetsException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.TooManyTargetsException = TooManyTargetsException;
    var TooManyUniqueTargetGroupsPerLoadBalancerException = class _TooManyUniqueTargetGroupsPerLoadBalancerException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "TooManyUniqueTargetGroupsPerLoadBalancerException");
      }
      name = "TooManyUniqueTargetGroupsPerLoadBalancerException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "TooManyUniqueTargetGroupsPerLoadBalancerException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyUniqueTargetGroupsPerLoadBalancerException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.TooManyUniqueTargetGroupsPerLoadBalancerException = TooManyUniqueTargetGroupsPerLoadBalancerException;
    var TrustStoreNotReadyException = class _TrustStoreNotReadyException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "TrustStoreNotReadyException");
      }
      name = "TrustStoreNotReadyException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "TrustStoreNotReadyException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TrustStoreNotReadyException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.TrustStoreNotReadyException = TrustStoreNotReadyException;
    var UnsupportedProtocolException = class _UnsupportedProtocolException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "UnsupportedProtocolException");
      }
      name = "UnsupportedProtocolException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "UnsupportedProtocolException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnsupportedProtocolException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.UnsupportedProtocolException = UnsupportedProtocolException;
    var DuplicateLoadBalancerNameException = class _DuplicateLoadBalancerNameException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "DuplicateLoadBalancerNameException");
      }
      name = "DuplicateLoadBalancerNameException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "DuplicateLoadBalancerNameException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DuplicateLoadBalancerNameException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.DuplicateLoadBalancerNameException = DuplicateLoadBalancerNameException;
    var InvalidSchemeException = class _InvalidSchemeException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "InvalidSchemeException");
      }
      name = "InvalidSchemeException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidSchemeException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidSchemeException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidSchemeException = InvalidSchemeException;
    var InvalidSecurityGroupException = class _InvalidSecurityGroupException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "InvalidSecurityGroupException");
      }
      name = "InvalidSecurityGroupException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidSecurityGroupException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidSecurityGroupException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidSecurityGroupException = InvalidSecurityGroupException;
    var InvalidSubnetException = class _InvalidSubnetException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "InvalidSubnetException");
      }
      name = "InvalidSubnetException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidSubnetException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidSubnetException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidSubnetException = InvalidSubnetException;
    var OperationNotPermittedException = class _OperationNotPermittedException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "OperationNotPermittedException");
      }
      name = "OperationNotPermittedException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "OperationNotPermittedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _OperationNotPermittedException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.OperationNotPermittedException = OperationNotPermittedException;
    var ResourceInUseException = class _ResourceInUseException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "ResourceInUseException");
      }
      name = "ResourceInUseException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "ResourceInUseException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceInUseException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ResourceInUseException = ResourceInUseException;
    var SubnetNotFoundException = class _SubnetNotFoundException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "SubnetNotFoundException");
      }
      name = "SubnetNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "SubnetNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _SubnetNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.SubnetNotFoundException = SubnetNotFoundException;
    var TooManyLoadBalancersException = class _TooManyLoadBalancersException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "TooManyLoadBalancersException");
      }
      name = "TooManyLoadBalancersException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "TooManyLoadBalancersException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyLoadBalancersException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.TooManyLoadBalancersException = TooManyLoadBalancersException;
    var PriorityInUseException = class _PriorityInUseException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "PriorityInUseException");
      }
      name = "PriorityInUseException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "PriorityInUseException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _PriorityInUseException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.PriorityInUseException = PriorityInUseException;
    var TooManyRulesException = class _TooManyRulesException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "TooManyRulesException");
      }
      name = "TooManyRulesException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "TooManyRulesException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyRulesException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.TooManyRulesException = TooManyRulesException;
    var TooManyTargetGroupsException = class _TooManyTargetGroupsException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "TooManyTargetGroupsException");
      }
      name = "TooManyTargetGroupsException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "TooManyTargetGroupsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyTargetGroupsException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.TooManyTargetGroupsException = TooManyTargetGroupsException;
    var DuplicateTargetGroupNameException = class _DuplicateTargetGroupNameException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "DuplicateTargetGroupNameException");
      }
      name = "DuplicateTargetGroupNameException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "DuplicateTargetGroupNameException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DuplicateTargetGroupNameException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.DuplicateTargetGroupNameException = DuplicateTargetGroupNameException;
    var DuplicateTrustStoreNameException = class _DuplicateTrustStoreNameException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "DuplicateTrustStoreNameException");
      }
      name = "DuplicateTrustStoreNameException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "DuplicateTrustStoreNameException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DuplicateTrustStoreNameException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.DuplicateTrustStoreNameException = DuplicateTrustStoreNameException;
    var InvalidCaCertificatesBundleException = class _InvalidCaCertificatesBundleException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "InvalidCaCertificatesBundleException");
      }
      name = "InvalidCaCertificatesBundleException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidCaCertificatesBundleException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidCaCertificatesBundleException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidCaCertificatesBundleException = InvalidCaCertificatesBundleException;
    var TooManyTrustStoresException = class _TooManyTrustStoresException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "TooManyTrustStoresException");
      }
      name = "TooManyTrustStoresException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "TooManyTrustStoresException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyTrustStoresException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.TooManyTrustStoresException = TooManyTrustStoresException;
    var DeleteAssociationSameAccountException = class _DeleteAssociationSameAccountException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "DeleteAssociationSameAccountException");
      }
      name = "DeleteAssociationSameAccountException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "DeleteAssociationSameAccountException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DeleteAssociationSameAccountException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.DeleteAssociationSameAccountException = DeleteAssociationSameAccountException;
    var TrustStoreAssociationNotFoundException = class _TrustStoreAssociationNotFoundException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "TrustStoreAssociationNotFoundException");
      }
      name = "TrustStoreAssociationNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "TrustStoreAssociationNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TrustStoreAssociationNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.TrustStoreAssociationNotFoundException = TrustStoreAssociationNotFoundException;
    var TrustStoreInUseException = class _TrustStoreInUseException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "TrustStoreInUseException");
      }
      name = "TrustStoreInUseException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "TrustStoreInUseException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TrustStoreInUseException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.TrustStoreInUseException = TrustStoreInUseException;
    var InvalidTargetException = class _InvalidTargetException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "InvalidTargetException");
      }
      name = "InvalidTargetException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidTargetException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidTargetException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidTargetException = InvalidTargetException;
    var HealthUnavailableException = class _HealthUnavailableException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "HealthUnavailableException");
      }
      name = "HealthUnavailableException";
      $fault = "server";
      Message;
      constructor(opts) {
        super({
          name: "HealthUnavailableException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _HealthUnavailableException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.HealthUnavailableException = HealthUnavailableException;
    var RevocationIdNotFoundException = class _RevocationIdNotFoundException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "RevocationIdNotFoundException");
      }
      name = "RevocationIdNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "RevocationIdNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _RevocationIdNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.RevocationIdNotFoundException = RevocationIdNotFoundException;
    var ResourceNotFoundException12 = class _ResourceNotFoundException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "ResourceNotFoundException");
      }
      name = "ResourceNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "ResourceNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ResourceNotFoundException = ResourceNotFoundException12;
    var InsufficientCapacityException = class _InsufficientCapacityException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "InsufficientCapacityException");
      }
      name = "InsufficientCapacityException";
      $fault = "server";
      Message;
      constructor(opts) {
        super({
          name: "InsufficientCapacityException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _InsufficientCapacityException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InsufficientCapacityException = InsufficientCapacityException;
    var PriorRequestNotCompleteException = class _PriorRequestNotCompleteException extends ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException {
      static {
        __name(this, "PriorRequestNotCompleteException");
      }
      name = "PriorRequestNotCompleteException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "PriorRequestNotCompleteException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _PriorRequestNotCompleteException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.PriorRequestNotCompleteException = PriorRequestNotCompleteException;
  }
});

// ../../node_modules/@aws-sdk/client-elastic-load-balancing-v2/dist-cjs/schemas/schemas_0.js
var require_schemas_013 = __commonJS({
  "../../node_modules/@aws-sdk/client-elastic-load-balancing-v2/dist-cjs/schemas/schemas_0.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.TooManyTrustStoreRevocationEntriesException$ = exports2.TooManyTargetsException$ = exports2.TooManyTargetGroupsException$ = exports2.TooManyTagsException$ = exports2.TooManyRulesException$ = exports2.TooManyRegistrationsForTargetIdException$ = exports2.TooManyLoadBalancersException$ = exports2.TooManyListenersException$ = exports2.TooManyCertificatesException$ = exports2.TooManyActionsException$ = exports2.TargetGroupNotFoundException$ = exports2.TargetGroupAssociationLimitException$ = exports2.SubnetNotFoundException$ = exports2.SSLPolicyNotFoundException$ = exports2.RuleNotFoundException$ = exports2.RevocationIdNotFoundException$ = exports2.RevocationContentNotFoundException$ = exports2.ResourceNotFoundException$ = exports2.ResourceInUseException$ = exports2.PriorRequestNotCompleteException$ = exports2.PriorityInUseException$ = exports2.OperationNotPermittedException$ = exports2.LoadBalancerNotFoundException$ = exports2.ListenerNotFoundException$ = exports2.InvalidTargetException$ = exports2.InvalidSubnetException$ = exports2.InvalidSecurityGroupException$ = exports2.InvalidSchemeException$ = exports2.InvalidRevocationContentException$ = exports2.InvalidLoadBalancerActionException$ = exports2.InvalidConfigurationRequestException$ = exports2.InvalidCaCertificatesBundleException$ = exports2.InsufficientCapacityException$ = exports2.IncompatibleProtocolsException$ = exports2.HealthUnavailableException$ = exports2.DuplicateTrustStoreNameException$ = exports2.DuplicateTargetGroupNameException$ = exports2.DuplicateTagKeysException$ = exports2.DuplicateLoadBalancerNameException$ = exports2.DuplicateListenerException$ = exports2.DeleteAssociationSameAccountException$ = exports2.CertificateNotFoundException$ = exports2.CapacityUnitsLimitExceededException$ = exports2.CapacityReservationPendingException$ = exports2.CapacityDecreaseRequestsLimitExceededException$ = exports2.CaCertificatesBundleNotFoundException$ = exports2.AvailabilityZoneNotSupportedException$ = exports2.ALPNPolicyNotSupportedException$ = exports2.AllocationIdNotFoundException$ = exports2.ElasticLoadBalancingV2ServiceException$ = void 0;
    exports2.DescribeCapacityReservationInput$ = exports2.DescribeAccountLimitsOutput$ = exports2.DescribeAccountLimitsInput$ = exports2.DeregisterTargetsOutput$ = exports2.DeregisterTargetsInput$ = exports2.DeleteTrustStoreOutput$ = exports2.DeleteTrustStoreInput$ = exports2.DeleteTargetGroupOutput$ = exports2.DeleteTargetGroupInput$ = exports2.DeleteSharedTrustStoreAssociationOutput$ = exports2.DeleteSharedTrustStoreAssociationInput$ = exports2.DeleteRuleOutput$ = exports2.DeleteRuleInput$ = exports2.DeleteLoadBalancerOutput$ = exports2.DeleteLoadBalancerInput$ = exports2.DeleteListenerOutput$ = exports2.DeleteListenerInput$ = exports2.CreateTrustStoreOutput$ = exports2.CreateTrustStoreInput$ = exports2.CreateTargetGroupOutput$ = exports2.CreateTargetGroupInput$ = exports2.CreateRuleOutput$ = exports2.CreateRuleInput$ = exports2.CreateLoadBalancerOutput$ = exports2.CreateLoadBalancerInput$ = exports2.CreateListenerOutput$ = exports2.CreateListenerInput$ = exports2.Cipher$ = exports2.Certificate$ = exports2.CapacityReservationStatus$ = exports2.AvailabilityZone$ = exports2.AuthenticateOidcActionConfig$ = exports2.AuthenticateCognitoActionConfig$ = exports2.AnomalyDetection$ = exports2.AdministrativeOverride$ = exports2.AddTrustStoreRevocationsOutput$ = exports2.AddTrustStoreRevocationsInput$ = exports2.AddTagsOutput$ = exports2.AddTagsInput$ = exports2.AddListenerCertificatesOutput$ = exports2.AddListenerCertificatesInput$ = exports2.Action$ = exports2.errorTypeRegistries = exports2.UnsupportedProtocolException$ = exports2.TrustStoreNotReadyException$ = exports2.TrustStoreNotFoundException$ = exports2.TrustStoreInUseException$ = exports2.TrustStoreAssociationNotFoundException$ = exports2.TooManyUniqueTargetGroupsPerLoadBalancerException$ = exports2.TooManyTrustStoresException$ = void 0;
    exports2.LoadBalancerAddress$ = exports2.LoadBalancer$ = exports2.ListenerAttribute$ = exports2.Listener$ = exports2.Limit$ = exports2.JwtValidationActionConfig$ = exports2.JwtValidationActionAdditionalClaim$ = exports2.IpamPools$ = exports2.HttpRequestMethodConditionConfig$ = exports2.HttpHeaderConditionConfig$ = exports2.HostHeaderRewriteConfig$ = exports2.HostHeaderConditionConfig$ = exports2.GetTrustStoreRevocationContentOutput$ = exports2.GetTrustStoreRevocationContentInput$ = exports2.GetTrustStoreCaCertificatesBundleOutput$ = exports2.GetTrustStoreCaCertificatesBundleInput$ = exports2.GetResourcePolicyOutput$ = exports2.GetResourcePolicyInput$ = exports2.ForwardActionConfig$ = exports2.FixedResponseActionConfig$ = exports2.DescribeTrustStoresOutput$ = exports2.DescribeTrustStoresInput$ = exports2.DescribeTrustStoreRevocationsOutput$ = exports2.DescribeTrustStoreRevocationsInput$ = exports2.DescribeTrustStoreRevocation$ = exports2.DescribeTrustStoreAssociationsOutput$ = exports2.DescribeTrustStoreAssociationsInput$ = exports2.DescribeTargetHealthOutput$ = exports2.DescribeTargetHealthInput$ = exports2.DescribeTargetGroupsOutput$ = exports2.DescribeTargetGroupsInput$ = exports2.DescribeTargetGroupAttributesOutput$ = exports2.DescribeTargetGroupAttributesInput$ = exports2.DescribeTagsOutput$ = exports2.DescribeTagsInput$ = exports2.DescribeSSLPoliciesOutput$ = exports2.DescribeSSLPoliciesInput$ = exports2.DescribeRulesOutput$ = exports2.DescribeRulesInput$ = exports2.DescribeLoadBalancersOutput$ = exports2.DescribeLoadBalancersInput$ = exports2.DescribeLoadBalancerAttributesOutput$ = exports2.DescribeLoadBalancerAttributesInput$ = exports2.DescribeListenersOutput$ = exports2.DescribeListenersInput$ = exports2.DescribeListenerCertificatesOutput$ = exports2.DescribeListenerCertificatesInput$ = exports2.DescribeListenerAttributesOutput$ = exports2.DescribeListenerAttributesInput$ = exports2.DescribeCapacityReservationOutput$ = void 0;
    exports2.SourceIpConditionConfig$ = exports2.SetSubnetsOutput$ = exports2.SetSubnetsInput$ = exports2.SetSecurityGroupsOutput$ = exports2.SetSecurityGroupsInput$ = exports2.SetRulePrioritiesOutput$ = exports2.SetRulePrioritiesInput$ = exports2.SetIpAddressTypeOutput$ = exports2.SetIpAddressTypeInput$ = exports2.RuleTransform$ = exports2.RulePriorityPair$ = exports2.RuleCondition$ = exports2.Rule$ = exports2.RewriteConfig$ = exports2.RevocationContent$ = exports2.RemoveTrustStoreRevocationsOutput$ = exports2.RemoveTrustStoreRevocationsInput$ = exports2.RemoveTagsOutput$ = exports2.RemoveTagsInput$ = exports2.RemoveListenerCertificatesOutput$ = exports2.RemoveListenerCertificatesInput$ = exports2.RegisterTargetsOutput$ = exports2.RegisterTargetsInput$ = exports2.RedirectActionConfig$ = exports2.QueryStringKeyValuePair$ = exports2.QueryStringConditionConfig$ = exports2.PathPatternConditionConfig$ = exports2.MutualAuthenticationAttributes$ = exports2.ModifyTrustStoreOutput$ = exports2.ModifyTrustStoreInput$ = exports2.ModifyTargetGroupOutput$ = exports2.ModifyTargetGroupInput$ = exports2.ModifyTargetGroupAttributesOutput$ = exports2.ModifyTargetGroupAttributesInput$ = exports2.ModifyRuleOutput$ = exports2.ModifyRuleInput$ = exports2.ModifyLoadBalancerAttributesOutput$ = exports2.ModifyLoadBalancerAttributesInput$ = exports2.ModifyListenerOutput$ = exports2.ModifyListenerInput$ = exports2.ModifyListenerAttributesOutput$ = exports2.ModifyListenerAttributesInput$ = exports2.ModifyIpPoolsOutput$ = exports2.ModifyIpPoolsInput$ = exports2.ModifyCapacityReservationOutput$ = exports2.ModifyCapacityReservationInput$ = exports2.MinimumLoadBalancerCapacity$ = exports2.Matcher$ = exports2.LoadBalancerState$ = exports2.LoadBalancerAttribute$ = void 0;
    exports2.GetTrustStoreRevocationContent$ = exports2.GetTrustStoreCaCertificatesBundle$ = exports2.GetResourcePolicy$ = exports2.DescribeTrustStores$ = exports2.DescribeTrustStoreRevocations$ = exports2.DescribeTrustStoreAssociations$ = exports2.DescribeTargetHealth$ = exports2.DescribeTargetGroups$ = exports2.DescribeTargetGroupAttributes$ = exports2.DescribeTags$ = exports2.DescribeSSLPolicies$ = exports2.DescribeRules$ = exports2.DescribeLoadBalancers$ = exports2.DescribeLoadBalancerAttributes$ = exports2.DescribeListeners$ = exports2.DescribeListenerCertificates$ = exports2.DescribeListenerAttributes$ = exports2.DescribeCapacityReservation$ = exports2.DescribeAccountLimits$ = exports2.DeregisterTargets$ = exports2.DeleteTrustStore$ = exports2.DeleteTargetGroup$ = exports2.DeleteSharedTrustStoreAssociation$ = exports2.DeleteRule$ = exports2.DeleteLoadBalancer$ = exports2.DeleteListener$ = exports2.CreateTrustStore$ = exports2.CreateTargetGroup$ = exports2.CreateRule$ = exports2.CreateLoadBalancer$ = exports2.CreateListener$ = exports2.AddTrustStoreRevocations$ = exports2.AddTags$ = exports2.AddListenerCertificates$ = exports2.ZonalCapacityReservationState$ = exports2.UrlRewriteConfig$ = exports2.TrustStoreRevocation$ = exports2.TrustStoreAssociation$ = exports2.TrustStore$ = exports2.TargetHealthDescription$ = exports2.TargetHealth$ = exports2.TargetGroupTuple$ = exports2.TargetGroupStickinessConfig$ = exports2.TargetGroupAttribute$ = exports2.TargetGroup$ = exports2.TargetDescription$ = exports2.TagDescription$ = exports2.Tag$ = exports2.SubnetMapping$ = exports2.SslPolicy$ = void 0;
    exports2.SetSubnets$ = exports2.SetSecurityGroups$ = exports2.SetRulePriorities$ = exports2.SetIpAddressType$ = exports2.RemoveTrustStoreRevocations$ = exports2.RemoveTags$ = exports2.RemoveListenerCertificates$ = exports2.RegisterTargets$ = exports2.ModifyTrustStore$ = exports2.ModifyTargetGroupAttributes$ = exports2.ModifyTargetGroup$ = exports2.ModifyRule$ = exports2.ModifyLoadBalancerAttributes$ = exports2.ModifyListenerAttributes$ = exports2.ModifyListener$ = exports2.ModifyIpPools$ = exports2.ModifyCapacityReservation$ = void 0;
    var _A10 = "Action";
    var _AC = "AdditionalClaims";
    var _ACAC = "AuthenticateCognitoActionConfig";
    var _ACC = "AuthenticateCognitoConfig";
    var _AD = "AnomalyDetection";
    var _AE = "AuthorizationEndpoint";
    var _AI2 = "AllocationId";
    var _AINFE = "AllocationIdNotFoundException";
    var _ALC = "AddListenerCertificates";
    var _ALCI = "AddListenerCertificatesInput";
    var _ALCO = "AddListenerCertificatesOutput";
    var _ALPNPNSE = "ALPNPolicyNotSupportedException";
    var _AO = "AdministrativeOverride";
    var _AOAC = "AuthenticateOidcActionConfig";
    var _AOC = "AuthenticateOidcConfig";
    var _AP = "AlpnPolicy";
    var _AREP = "AuthenticationRequestExtraParams";
    var _AT13 = "AddTags";
    var _ATI = "AddTagsInput";
    var _ATO = "AddTagsOutput";
    var _ATSCN = "AdvertiseTrustStoreCaNames";
    var _ATSR = "AddTrustStoreRevocations";
    var _ATSRI = "AddTrustStoreRevocationsInput";
    var _ATSRO = "AddTrustStoreRevocationsOutput";
    var _AZ = "AvailabilityZone";
    var _AZNSE = "AvailabilityZoneNotSupportedException";
    var _AZv = "AvailabilityZones";
    var _Ac = "Actions";
    var _At = "Attributes";
    var _C11 = "Certificates";
    var _CA10 = "CertificateArn";
    var _CCBNFE = "CaCertificatesBundleNotFoundException";
    var _CCBSB = "CaCertificatesBundleS3Bucket";
    var _CCBSK = "CaCertificatesBundleS3Key";
    var _CCBSOV = "CaCertificatesBundleS3ObjectVersion";
    var _CDRLEE = "CapacityDecreaseRequestsLimitExceededException";
    var _CHZI = "CanonicalHostedZoneId";
    var _CI = "ClientId";
    var _CL = "CertificateList";
    var _CLB = "CreateLoadBalancer";
    var _CLBI = "CreateLoadBalancerInput";
    var _CLBO = "CreateLoadBalancerOutput";
    var _CLI = "CreateListenerInput";
    var _CLO = "CreateListenerOutput";
    var _CLr = "CreateListener";
    var _CNFE = "CertificateNotFoundException";
    var _COIP = "CustomerOwnedIpv4Pool";
    var _CR = "CreateRule";
    var _CRI = "CreateRuleInput";
    var _CRO = "CreateRuleOutput";
    var _CRPE = "CapacityReservationPendingException";
    var _CRS = "CapacityReservationStatus";
    var _CRSa = "CapacityReservationState";
    var _CS4 = "ClientSecret";
    var _CT4 = "ContentType";
    var _CTG = "CreateTargetGroup";
    var _CTGI = "CreateTargetGroupInput";
    var _CTGO = "CreateTargetGroupOutput";
    var _CTS = "CreateTrustStore";
    var _CTSI = "CreateTrustStoreInput";
    var _CTSO = "CreateTrustStoreOutput";
    var _CTr = "CreatedTime";
    var _CU = "CapacityUnits";
    var _CULEE = "CapacityUnitsLimitExceededException";
    var _Ce = "Certificate";
    var _Ci = "Cipher";
    var _Cip = "Ciphers";
    var _Co = "Code";
    var _Con = "Conditions";
    var _D = "Description";
    var _DA = "DefaultActions";
    var _DAL = "DescribeAccountLimits";
    var _DALI = "DescribeAccountLimitsInput";
    var _DALO = "DescribeAccountLimitsOutput";
    var _DASAE = "DeleteAssociationSameAccountException";
    var _DCR = "DescribeCapacityReservation";
    var _DCRI = "DescribeCapacityReservationInput";
    var _DCRO = "DescribeCapacityReservationOutput";
    var _DL = "DeleteListener";
    var _DLA = "DescribeListenerAttributes";
    var _DLAI = "DescribeListenerAttributesInput";
    var _DLAO = "DescribeListenerAttributesOutput";
    var _DLB = "DeleteLoadBalancer";
    var _DLBA = "DescribeLoadBalancerAttributes";
    var _DLBAI = "DescribeLoadBalancerAttributesInput";
    var _DLBAO = "DescribeLoadBalancerAttributesOutput";
    var _DLBI = "DeleteLoadBalancerInput";
    var _DLBIe = "DescribeLoadBalancersInput";
    var _DLBNE = "DuplicateLoadBalancerNameException";
    var _DLBO = "DeleteLoadBalancerOutput";
    var _DLBOe = "DescribeLoadBalancersOutput";
    var _DLBe = "DescribeLoadBalancers";
    var _DLC = "DescribeListenerCertificates";
    var _DLCI = "DescribeListenerCertificatesInput";
    var _DLCO = "DescribeListenerCertificatesOutput";
    var _DLE = "DuplicateListenerException";
    var _DLI = "DeleteListenerInput";
    var _DLIe = "DescribeListenersInput";
    var _DLO = "DeleteListenerOutput";
    var _DLOe = "DescribeListenersOutput";
    var _DLe = "DescribeListeners";
    var _DNSN = "DNSName";
    var _DR = "DeleteRule";
    var _DRI = "DeleteRuleInput";
    var _DRIe = "DescribeRulesInput";
    var _DRO = "DeleteRuleOutput";
    var _DROe = "DescribeRulesOutput";
    var _DRR = "DecreaseRequestsRemaining";
    var _DRe = "DescribeRules";
    var _DS10 = "DurationSeconds";
    var _DSSLP = "DescribeSSLPolicies";
    var _DSSLPI = "DescribeSSLPoliciesInput";
    var _DSSLPO = "DescribeSSLPoliciesOutput";
    var _DSTSA = "DeleteSharedTrustStoreAssociation";
    var _DSTSAI = "DeleteSharedTrustStoreAssociationInput";
    var _DSTSAO = "DeleteSharedTrustStoreAssociationOutput";
    var _DT = "DeregisterTargets";
    var _DTG = "DeleteTargetGroup";
    var _DTGA = "DescribeTargetGroupAttributes";
    var _DTGAI = "DescribeTargetGroupAttributesInput";
    var _DTGAO = "DescribeTargetGroupAttributesOutput";
    var _DTGI = "DeleteTargetGroupInput";
    var _DTGIe = "DescribeTargetGroupsInput";
    var _DTGNE = "DuplicateTargetGroupNameException";
    var _DTGO = "DeleteTargetGroupOutput";
    var _DTGOe = "DescribeTargetGroupsOutput";
    var _DTGe = "DescribeTargetGroups";
    var _DTH = "DescribeTargetHealth";
    var _DTHI = "DescribeTargetHealthInput";
    var _DTHO = "DescribeTargetHealthOutput";
    var _DTI = "DeregisterTargetsInput";
    var _DTIe = "DescribeTagsInput";
    var _DTKE = "DuplicateTagKeysException";
    var _DTO = "DeregisterTargetsOutput";
    var _DTOe = "DescribeTagsOutput";
    var _DTS = "DeleteTrustStore";
    var _DTSA = "DescribeTrustStoreAssociations";
    var _DTSAI = "DescribeTrustStoreAssociationsInput";
    var _DTSAO = "DescribeTrustStoreAssociationsOutput";
    var _DTSI = "DeleteTrustStoreInput";
    var _DTSIe = "DescribeTrustStoresInput";
    var _DTSNE = "DuplicateTrustStoreNameException";
    var _DTSO = "DeleteTrustStoreOutput";
    var _DTSOe = "DescribeTrustStoresOutput";
    var _DTSR = "DescribeTrustStoreRevocation";
    var _DTSRI = "DescribeTrustStoreRevocationsInput";
    var _DTSRO = "DescribeTrustStoreRevocationsOutput";
    var _DTSRR = "DescribeTrustStoreRevocationResponse";
    var _DTSRe = "DescribeTrustStoreRevocations";
    var _DTSe = "DescribeTrustStores";
    var _DTe = "DescribeTags";
    var _E11 = "Enabled";
    var _ECU = "EffectiveCapacityUnits";
    var _EPFISN = "EnablePrefixForIpv6SourceNat";
    var _ESGIROPLT = "EnforceSecurityGroupInboundRulesOnPrivateLinkTraffic";
    var _F = "Format";
    var _FAC = "ForwardActionConfig";
    var _FC = "ForwardConfig";
    var _FRAC = "FixedResponseActionConfig";
    var _FRC = "FixedResponseConfig";
    var _Fi = "Field";
    var _GC = "GrpcCode";
    var _GRP = "GetResourcePolicy";
    var _GRPI = "GetResourcePolicyInput";
    var _GRPO = "GetResourcePolicyOutput";
    var _GTSCCB = "GetTrustStoreCaCertificatesBundle";
    var _GTSCCBI = "GetTrustStoreCaCertificatesBundleInput";
    var _GTSCCBO = "GetTrustStoreCaCertificatesBundleOutput";
    var _GTSRC = "GetTrustStoreRevocationContent";
    var _GTSRCI = "GetTrustStoreRevocationContentInput";
    var _GTSRCO = "GetTrustStoreRevocationContentOutput";
    var _H = "Host";
    var _HC = "HttpCode";
    var _HCE = "HealthCheckEnabled";
    var _HCIS = "HealthCheckIntervalSeconds";
    var _HCP = "HealthCheckProtocol";
    var _HCPe = "HealthCheckPort";
    var _HCPea = "HealthCheckPath";
    var _HCTS = "HealthCheckTimeoutSeconds";
    var _HHC = "HostHeaderConfig";
    var _HHCC = "HostHeaderConditionConfig";
    var _HHCCt = "HttpHeaderConditionConfig";
    var _HHCt = "HttpHeaderConfig";
    var _HHN = "HttpHeaderName";
    var _HHRC = "HostHeaderRewriteConfig";
    var _HRMC = "HttpRequestMethodConfig";
    var _HRMCC = "HttpRequestMethodConditionConfig";
    var _HTC = "HealthyThresholdCount";
    var _HUE = "HealthUnavailableException";
    var _I = "Issuer";
    var _IA = "IpAddress";
    var _IAT = "IpAddressType";
    var _ICCBE = "InvalidCaCertificatesBundleException";
    var _ICCE = "IgnoreClientCertificateExpiry";
    var _ICE4 = "InsufficientCapacityException";
    var _ICRE = "InvalidConfigurationRequestException";
    var _ID = "IsDefault";
    var _IIPI = "Ipv4IpamPoolId";
    var _ILBAE = "InvalidLoadBalancerActionException";
    var _IP = "IpamPools";
    var _IPA = "IPv6Address";
    var _IPE2 = "IncompatibleProtocolsException";
    var _IRCE = "InvalidRevocationContentException";
    var _ISE13 = "InvalidSchemeException";
    var _ISEn4 = "InvalidSubnetException";
    var _ISGE = "InvalidSecurityGroupException";
    var _ITE = "InvalidTargetException";
    var _Id = "Id";
    var _In = "Include";
    var _JE = "JwksEndpoint";
    var _JVAAC = "JwtValidationActionAdditionalClaim";
    var _JVAACw = "JwtValidationActionAdditionalClaims";
    var _JVAC = "JwtValidationActionConfig";
    var _JVC = "JwtValidationConfig";
    var _K10 = "Key";
    var _L2 = "Listeners";
    var _LA = "ListenerArn";
    var _LAi = "ListenerArns";
    var _LAis = "ListenerAttribute";
    var _LAist = "ListenerAttributes";
    var _LB = "LoadBalancers";
    var _LBA = "LoadBalancerAddresses";
    var _LBAo = "LoadBalancerArn";
    var _LBAoa = "LoadBalancerArns";
    var _LBAoad = "LoadBalancerAddress";
    var _LBAoada = "LoadBalancerAttribute";
    var _LBAoadal = "LoadBalancerAttributes";
    var _LBN = "LoadBalancerName";
    var _LBNFE = "LoadBalancerNotFoundException";
    var _LBS = "LoadBalancerState";
    var _LBT = "LoadBalancerType";
    var _LBo = "LoadBalancer";
    var _LMT = "LastModifiedTime";
    var _LNFE = "ListenerNotFoundException";
    var _Li = "Limits";
    var _Lim = "Limit";
    var _Lis = "Listener";
    var _Lo = "Location";
    var _M = "Message";
    var _MA = "MutualAuthentication";
    var _MAA = "MutualAuthenticationAttributes";
    var _MB = "MessageBody";
    var _MCR = "ModifyCapacityReservation";
    var _MCRI = "ModifyCapacityReservationInput";
    var _MCRO = "ModifyCapacityReservationOutput";
    var _MIE = "MitigationInEffect";
    var _MIP = "ModifyIpPools";
    var _MIPI = "ModifyIpPoolsInput";
    var _MIPO = "ModifyIpPoolsOutput";
    var _ML = "ModifyListener";
    var _MLA = "ModifyListenerAttributes";
    var _MLAI = "ModifyListenerAttributesInput";
    var _MLAO = "ModifyListenerAttributesOutput";
    var _MLBA = "ModifyLoadBalancerAttributes";
    var _MLBAI = "ModifyLoadBalancerAttributesInput";
    var _MLBAO = "ModifyLoadBalancerAttributesOutput";
    var _MLBC = "MinimumLoadBalancerCapacity";
    var _MLI = "ModifyListenerInput";
    var _MLO = "ModifyListenerOutput";
    var _MR = "ModifyRule";
    var _MRI = "ModifyRuleInput";
    var _MRO = "ModifyRuleOutput";
    var _MTG = "ModifyTargetGroup";
    var _MTGA = "ModifyTargetGroupAttributes";
    var _MTGAI = "ModifyTargetGroupAttributesInput";
    var _MTGAO = "ModifyTargetGroupAttributesOutput";
    var _MTGI = "ModifyTargetGroupInput";
    var _MTGO = "ModifyTargetGroupOutput";
    var _MTS = "ModifyTrustStore";
    var _MTSI = "ModifyTrustStoreInput";
    var _MTSO = "ModifyTrustStoreOutput";
    var _Ma = "Matcher";
    var _Mar = "Marker";
    var _Max = "Max";
    var _Mo = "Mode";
    var _N = "Name";
    var _NM = "NextMarker";
    var _NOCC = "NumberOfCaCertificates";
    var _NORE = "NumberOfRevokedEntries";
    var _Na = "Names";
    var _O = "Order";
    var _OI = "OutpostId";
    var _ONPE = "OperationNotPermittedException";
    var _OUR = "OnUnauthenticatedRequest";
    var _P10 = "Priority";
    var _PIPA = "PrivateIPv4Address";
    var _PIUE = "PriorityInUseException";
    var _PPC = "PathPatternConfig";
    var _PPCC = "PathPatternConditionConfig";
    var _PRNCE = "PriorRequestNotCompleteException";
    var _PS = "PageSize";
    var _PV = "ProtocolVersion";
    var _Pa = "Path";
    var _Po = "Port";
    var _Pol = "Policy";
    var _Pr10 = "Protocol";
    var _Q = "Query";
    var _QSC = "QueryStringConfig";
    var _QSCC = "QueryStringConditionConfig";
    var _QSI = "QuicServerId";
    var _QSKVP = "QueryStringKeyValuePair";
    var _QSKVPL = "QueryStringKeyValuePairList";
    var _R = "Reason";
    var _RA10 = "ResourceArns";
    var _RAC = "RedirectActionConfig";
    var _RAe = "ResourceArn";
    var _RAu = "RuleArn";
    var _RAul = "RuleArns";
    var _RC10 = "RedirectConfig";
    var _RCL = "RewriteConfigList";
    var _RCLu = "RuleConditionList";
    var _RCNFE = "RevocationContentNotFoundException";
    var _RCR = "ResetCapacityReservation";
    var _RCe = "RevocationContents";
    var _RCev = "RevocationContent";
    var _RCew = "RewriteConfig";
    var _RCu = "RuleCondition";
    var _RI = "RevocationId";
    var _RINFE = "RevocationIdNotFoundException";
    var _RIP = "RemoveIpamPools";
    var _RIUE = "ResourceInUseException";
    var _RIe = "RevocationIds";
    var _RLC = "RemoveListenerCertificates";
    var _RLCI = "RemoveListenerCertificatesInput";
    var _RLCO = "RemoveListenerCertificatesOutput";
    var _RNFE11 = "ResourceNotFoundException";
    var _RNFEu = "RuleNotFoundException";
    var _RP = "RulePriorities";
    var _RPL = "RulePriorityList";
    var _RPP = "RulePriorityPair";
    var _RT13 = "RevocationType";
    var _RTI = "RegisterTargetsInput";
    var _RTIe = "RemoveTagsInput";
    var _RTL = "RuleTransformList";
    var _RTO = "RegisterTargetsOutput";
    var _RTOe = "RemoveTagsOutput";
    var _RTSR = "RemoveTrustStoreRevocations";
    var _RTSRI = "RemoveTrustStoreRevocationsInput";
    var _RTSRO = "RemoveTrustStoreRevocationsOutput";
    var _RTe = "ResetTransforms";
    var _RTeg = "RegisterTargets";
    var _RTem = "RemoveTags";
    var _RTu = "RuleTransform";
    var _RV = "RegexValues";
    var _Re = "Result";
    var _Reg = "Regex";
    var _Rep = "Replace";
    var _Rew = "Rewrites";
    var _Ru = "Rules";
    var _Rul = "Rule";
    var _S = "State";
    var _SB = "S3Bucket";
    var _SC = "StatusCode";
    var _SCN = "SessionCookieName";
    var _SG = "SecurityGroups";
    var _SGI = "SecurityGroupIds";
    var _SI10 = "SubnetId";
    var _SIAT = "SetIpAddressType";
    var _SIATI = "SetIpAddressTypeInput";
    var _SIATO = "SetIpAddressTypeOutput";
    var _SIC = "SourceIpConfig";
    var _SICC = "SourceIpConditionConfig";
    var _SK2 = "S3Key";
    var _SLBT = "SupportedLoadBalancerTypes";
    var _SM = "SubnetMappings";
    var _SMu = "SubnetMapping";
    var _SNFE = "SubnetNotFoundException";
    var _SNIP = "SourceNatIpv6Prefixes";
    var _SNIPo = "SourceNatIpv6Prefix";
    var _SOV = "S3ObjectVersion";
    var _SP = "SslPolicy";
    var _SPs = "SslPolicies";
    var _SPsl = "SslProtocols";
    var _SRP = "SetRulePriorities";
    var _SRPI = "SetRulePrioritiesInput";
    var _SRPO = "SetRulePrioritiesOutput";
    var _SS = "SetSubnets";
    var _SSG = "SetSecurityGroups";
    var _SSGI = "SetSecurityGroupsInput";
    var _SSGO = "SetSecurityGroupsOutput";
    var _SSI = "SetSubnetsInput";
    var _SSLPNFE = "SSLPolicyNotFoundException";
    var _SSO = "SetSubnetsOutput";
    var _ST11 = "SessionTimeout";
    var _Sc = "Scope";
    var _Sch = "Scheme";
    var _St = "Status";
    var _Su = "Subnets";
    var _T10 = "Type";
    var _TCP = "TargetControlPort";
    var _TD = "TagDescriptions";
    var _TDa = "TagDescription";
    var _TDar = "TargetDescription";
    var _TDarg = "TargetDescriptions";
    var _TE = "TokenEndpoint";
    var _TG = "TargetGroups";
    var _TGA = "TargetGroupArn";
    var _TGALE = "TargetGroupAssociationLimitException";
    var _TGAa = "TargetGroupArns";
    var _TGAar = "TargetGroupAttribute";
    var _TGAarg = "TargetGroupAttributes";
    var _TGL = "TargetGroupList";
    var _TGN = "TargetGroupName";
    var _TGNFE = "TargetGroupNotFoundException";
    var _TGSC = "TargetGroupStickinessConfig";
    var _TGT = "TargetGroupTuple";
    var _TGa = "TargetGroup";
    var _TH = "TargetHealth";
    var _THD = "TargetHealthDescriptions";
    var _THDa = "TargetHealthDescription";
    var _TK = "TagKeys";
    var _TL = "TagList";
    var _TMAE = "TooManyActionsException";
    var _TMCE = "TooManyCertificatesException";
    var _TMLBE = "TooManyLoadBalancersException";
    var _TMLE = "TooManyListenersException";
    var _TMRE20 = "TooManyRulesException";
    var _TMRFTIE = "TooManyRegistrationsForTargetIdException";
    var _TMTE = "TooManyTagsException";
    var _TMTEo = "TooManyTargetsException";
    var _TMTGE = "TooManyTargetGroupsException";
    var _TMTSE = "TooManyTrustStoresException";
    var _TMTSREE = "TooManyTrustStoreRevocationEntriesException";
    var _TMUTGPLBE = "TooManyUniqueTargetGroupsPerLoadBalancerException";
    var _TRE = "TotalRevokedEntries";
    var _TS = "TrustStores";
    var _TSA = "TrustStoreArn";
    var _TSANFE = "TrustStoreAssociationNotFoundException";
    var _TSAS = "TrustStoreAssociationStatus";
    var _TSAr = "TrustStoreAssociations";
    var _TSAru = "TrustStoreArns";
    var _TSArus = "TrustStoreAssociation";
    var _TSIUE = "TrustStoreInUseException";
    var _TSNFE = "TrustStoreNotFoundException";
    var _TSNRE = "TrustStoreNotReadyException";
    var _TSR = "TrustStoreRevocations";
    var _TSRr = "TrustStoreRevocation";
    var _TSr = "TrustStore";
    var _TT = "TargetType";
    var _Ta10 = "Tags";
    var _Tag = "Tag";
    var _Tar = "Targets";
    var _Targ = "Target";
    var _Tr = "Transforms";
    var _UECS = "UseExistingClientSecret";
    var _UIE = "UserInfoEndpoint";
    var _UPA = "UserPoolArn";
    var _UPCI = "UserPoolClientId";
    var _UPD = "UserPoolDomain";
    var _UPE = "UnsupportedProtocolException";
    var _URC = "UrlRewriteConfig";
    var _UTC = "UnhealthyThresholdCount";
    var _V10 = "Values";
    var _VI = "VpcId";
    var _Va = "Value";
    var _W = "Weight";
    var _ZCRS = "ZonalCapacityReservationState";
    var _ZCRSo = "ZonalCapacityReservationStates";
    var _ZN = "ZoneName";
    var _aQE10 = "awsQueryError";
    var _c32 = "client";
    var _e32 = "error";
    var _hE32 = "httpError";
    var _s32 = "smithy.ts.sdk.synthetic.com.amazonaws.elasticloadbalancingv2";
    var _se14 = "server";
    var n032 = "com.amazonaws.elasticloadbalancingv2";
    var schema_1 = (init_schema4(), __toCommonJS(schema_exports));
    var ElasticLoadBalancingV2ServiceException_1 = require_ElasticLoadBalancingV2ServiceException();
    var errors_1 = require_errors12();
    var _s_registry32 = schema_1.TypeRegistry.for(_s32);
    exports2.ElasticLoadBalancingV2ServiceException$ = [-3, _s32, "ElasticLoadBalancingV2ServiceException", 0, [], []];
    _s_registry32.registerError(exports2.ElasticLoadBalancingV2ServiceException$, ElasticLoadBalancingV2ServiceException_1.ElasticLoadBalancingV2ServiceException);
    var n0_registry32 = schema_1.TypeRegistry.for(n032);
    exports2.AllocationIdNotFoundException$ = [
      -3,
      n032,
      _AINFE,
      { [_aQE10]: [`AllocationIdNotFound`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.AllocationIdNotFoundException$, errors_1.AllocationIdNotFoundException);
    exports2.ALPNPolicyNotSupportedException$ = [
      -3,
      n032,
      _ALPNPNSE,
      { [_aQE10]: [`ALPNPolicyNotFound`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ALPNPolicyNotSupportedException$, errors_1.ALPNPolicyNotSupportedException);
    exports2.AvailabilityZoneNotSupportedException$ = [
      -3,
      n032,
      _AZNSE,
      { [_aQE10]: [`AvailabilityZoneNotSupported`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.AvailabilityZoneNotSupportedException$, errors_1.AvailabilityZoneNotSupportedException);
    exports2.CaCertificatesBundleNotFoundException$ = [
      -3,
      n032,
      _CCBNFE,
      { [_aQE10]: [`CaCertificatesBundleNotFound`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.CaCertificatesBundleNotFoundException$, errors_1.CaCertificatesBundleNotFoundException);
    exports2.CapacityDecreaseRequestsLimitExceededException$ = [
      -3,
      n032,
      _CDRLEE,
      { [_aQE10]: [`CapacityDecreaseRequestLimitExceeded`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.CapacityDecreaseRequestsLimitExceededException$, errors_1.CapacityDecreaseRequestsLimitExceededException);
    exports2.CapacityReservationPendingException$ = [
      -3,
      n032,
      _CRPE,
      { [_aQE10]: [`CapacityReservationPending`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.CapacityReservationPendingException$, errors_1.CapacityReservationPendingException);
    exports2.CapacityUnitsLimitExceededException$ = [
      -3,
      n032,
      _CULEE,
      { [_aQE10]: [`CapacityUnitsLimitExceeded`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.CapacityUnitsLimitExceededException$, errors_1.CapacityUnitsLimitExceededException);
    exports2.CertificateNotFoundException$ = [
      -3,
      n032,
      _CNFE,
      { [_aQE10]: [`CertificateNotFound`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.CertificateNotFoundException$, errors_1.CertificateNotFoundException);
    exports2.DeleteAssociationSameAccountException$ = [
      -3,
      n032,
      _DASAE,
      { [_aQE10]: [`DeleteAssociationSameAccount`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.DeleteAssociationSameAccountException$, errors_1.DeleteAssociationSameAccountException);
    exports2.DuplicateListenerException$ = [
      -3,
      n032,
      _DLE,
      { [_aQE10]: [`DuplicateListener`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.DuplicateListenerException$, errors_1.DuplicateListenerException);
    exports2.DuplicateLoadBalancerNameException$ = [
      -3,
      n032,
      _DLBNE,
      { [_aQE10]: [`DuplicateLoadBalancerName`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.DuplicateLoadBalancerNameException$, errors_1.DuplicateLoadBalancerNameException);
    exports2.DuplicateTagKeysException$ = [
      -3,
      n032,
      _DTKE,
      { [_aQE10]: [`DuplicateTagKeys`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.DuplicateTagKeysException$, errors_1.DuplicateTagKeysException);
    exports2.DuplicateTargetGroupNameException$ = [
      -3,
      n032,
      _DTGNE,
      { [_aQE10]: [`DuplicateTargetGroupName`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.DuplicateTargetGroupNameException$, errors_1.DuplicateTargetGroupNameException);
    exports2.DuplicateTrustStoreNameException$ = [
      -3,
      n032,
      _DTSNE,
      { [_aQE10]: [`DuplicateTrustStoreName`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.DuplicateTrustStoreNameException$, errors_1.DuplicateTrustStoreNameException);
    exports2.HealthUnavailableException$ = [
      -3,
      n032,
      _HUE,
      { [_aQE10]: [`HealthUnavailable`, 500], [_e32]: _se14, [_hE32]: 500 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.HealthUnavailableException$, errors_1.HealthUnavailableException);
    exports2.IncompatibleProtocolsException$ = [
      -3,
      n032,
      _IPE2,
      { [_aQE10]: [`IncompatibleProtocols`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.IncompatibleProtocolsException$, errors_1.IncompatibleProtocolsException);
    exports2.InsufficientCapacityException$ = [
      -3,
      n032,
      _ICE4,
      { [_aQE10]: [`InsufficientCapacity`, 500], [_e32]: _se14, [_hE32]: 500 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InsufficientCapacityException$, errors_1.InsufficientCapacityException);
    exports2.InvalidCaCertificatesBundleException$ = [
      -3,
      n032,
      _ICCBE,
      { [_aQE10]: [`InvalidCaCertificatesBundle`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidCaCertificatesBundleException$, errors_1.InvalidCaCertificatesBundleException);
    exports2.InvalidConfigurationRequestException$ = [
      -3,
      n032,
      _ICRE,
      { [_aQE10]: [`InvalidConfigurationRequest`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidConfigurationRequestException$, errors_1.InvalidConfigurationRequestException);
    exports2.InvalidLoadBalancerActionException$ = [
      -3,
      n032,
      _ILBAE,
      { [_aQE10]: [`InvalidLoadBalancerAction`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidLoadBalancerActionException$, errors_1.InvalidLoadBalancerActionException);
    exports2.InvalidRevocationContentException$ = [
      -3,
      n032,
      _IRCE,
      { [_aQE10]: [`InvalidRevocationContent`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidRevocationContentException$, errors_1.InvalidRevocationContentException);
    exports2.InvalidSchemeException$ = [
      -3,
      n032,
      _ISE13,
      { [_aQE10]: [`InvalidScheme`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidSchemeException$, errors_1.InvalidSchemeException);
    exports2.InvalidSecurityGroupException$ = [
      -3,
      n032,
      _ISGE,
      { [_aQE10]: [`InvalidSecurityGroup`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidSecurityGroupException$, errors_1.InvalidSecurityGroupException);
    exports2.InvalidSubnetException$ = [
      -3,
      n032,
      _ISEn4,
      { [_aQE10]: [`InvalidSubnet`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidSubnetException$, errors_1.InvalidSubnetException);
    exports2.InvalidTargetException$ = [
      -3,
      n032,
      _ITE,
      { [_aQE10]: [`InvalidTarget`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidTargetException$, errors_1.InvalidTargetException);
    exports2.ListenerNotFoundException$ = [
      -3,
      n032,
      _LNFE,
      { [_aQE10]: [`ListenerNotFound`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ListenerNotFoundException$, errors_1.ListenerNotFoundException);
    exports2.LoadBalancerNotFoundException$ = [
      -3,
      n032,
      _LBNFE,
      { [_aQE10]: [`LoadBalancerNotFound`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.LoadBalancerNotFoundException$, errors_1.LoadBalancerNotFoundException);
    exports2.OperationNotPermittedException$ = [
      -3,
      n032,
      _ONPE,
      { [_aQE10]: [`OperationNotPermitted`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.OperationNotPermittedException$, errors_1.OperationNotPermittedException);
    exports2.PriorityInUseException$ = [
      -3,
      n032,
      _PIUE,
      { [_aQE10]: [`PriorityInUse`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.PriorityInUseException$, errors_1.PriorityInUseException);
    exports2.PriorRequestNotCompleteException$ = [
      -3,
      n032,
      _PRNCE,
      { [_aQE10]: [`PriorRequestNotComplete`, 429], [_e32]: _c32, [_hE32]: 429 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.PriorRequestNotCompleteException$, errors_1.PriorRequestNotCompleteException);
    exports2.ResourceInUseException$ = [
      -3,
      n032,
      _RIUE,
      { [_aQE10]: [`ResourceInUse`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ResourceInUseException$, errors_1.ResourceInUseException);
    exports2.ResourceNotFoundException$ = [
      -3,
      n032,
      _RNFE11,
      { [_aQE10]: [`ResourceNotFound`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ResourceNotFoundException$, errors_1.ResourceNotFoundException);
    exports2.RevocationContentNotFoundException$ = [
      -3,
      n032,
      _RCNFE,
      { [_aQE10]: [`RevocationContentNotFound`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.RevocationContentNotFoundException$, errors_1.RevocationContentNotFoundException);
    exports2.RevocationIdNotFoundException$ = [
      -3,
      n032,
      _RINFE,
      { [_aQE10]: [`RevocationIdNotFound`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.RevocationIdNotFoundException$, errors_1.RevocationIdNotFoundException);
    exports2.RuleNotFoundException$ = [
      -3,
      n032,
      _RNFEu,
      { [_aQE10]: [`RuleNotFound`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.RuleNotFoundException$, errors_1.RuleNotFoundException);
    exports2.SSLPolicyNotFoundException$ = [
      -3,
      n032,
      _SSLPNFE,
      { [_aQE10]: [`SSLPolicyNotFound`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.SSLPolicyNotFoundException$, errors_1.SSLPolicyNotFoundException);
    exports2.SubnetNotFoundException$ = [
      -3,
      n032,
      _SNFE,
      { [_aQE10]: [`SubnetNotFound`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.SubnetNotFoundException$, errors_1.SubnetNotFoundException);
    exports2.TargetGroupAssociationLimitException$ = [
      -3,
      n032,
      _TGALE,
      { [_aQE10]: [`TargetGroupAssociationLimit`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.TargetGroupAssociationLimitException$, errors_1.TargetGroupAssociationLimitException);
    exports2.TargetGroupNotFoundException$ = [
      -3,
      n032,
      _TGNFE,
      { [_aQE10]: [`TargetGroupNotFound`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.TargetGroupNotFoundException$, errors_1.TargetGroupNotFoundException);
    exports2.TooManyActionsException$ = [
      -3,
      n032,
      _TMAE,
      { [_aQE10]: [`TooManyActions`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.TooManyActionsException$, errors_1.TooManyActionsException);
    exports2.TooManyCertificatesException$ = [
      -3,
      n032,
      _TMCE,
      { [_aQE10]: [`TooManyCertificates`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.TooManyCertificatesException$, errors_1.TooManyCertificatesException);
    exports2.TooManyListenersException$ = [
      -3,
      n032,
      _TMLE,
      { [_aQE10]: [`TooManyListeners`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.TooManyListenersException$, errors_1.TooManyListenersException);
    exports2.TooManyLoadBalancersException$ = [
      -3,
      n032,
      _TMLBE,
      { [_aQE10]: [`TooManyLoadBalancers`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.TooManyLoadBalancersException$, errors_1.TooManyLoadBalancersException);
    exports2.TooManyRegistrationsForTargetIdException$ = [
      -3,
      n032,
      _TMRFTIE,
      { [_aQE10]: [`TooManyRegistrationsForTargetId`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.TooManyRegistrationsForTargetIdException$, errors_1.TooManyRegistrationsForTargetIdException);
    exports2.TooManyRulesException$ = [
      -3,
      n032,
      _TMRE20,
      { [_aQE10]: [`TooManyRules`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.TooManyRulesException$, errors_1.TooManyRulesException);
    exports2.TooManyTagsException$ = [
      -3,
      n032,
      _TMTE,
      { [_aQE10]: [`TooManyTags`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.TooManyTagsException$, errors_1.TooManyTagsException);
    exports2.TooManyTargetGroupsException$ = [
      -3,
      n032,
      _TMTGE,
      { [_aQE10]: [`TooManyTargetGroups`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.TooManyTargetGroupsException$, errors_1.TooManyTargetGroupsException);
    exports2.TooManyTargetsException$ = [
      -3,
      n032,
      _TMTEo,
      { [_aQE10]: [`TooManyTargets`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.TooManyTargetsException$, errors_1.TooManyTargetsException);
    exports2.TooManyTrustStoreRevocationEntriesException$ = [
      -3,
      n032,
      _TMTSREE,
      { [_aQE10]: [`TooManyTrustStoreRevocationEntries`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.TooManyTrustStoreRevocationEntriesException$, errors_1.TooManyTrustStoreRevocationEntriesException);
    exports2.TooManyTrustStoresException$ = [
      -3,
      n032,
      _TMTSE,
      { [_aQE10]: [`TooManyTrustStores`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.TooManyTrustStoresException$, errors_1.TooManyTrustStoresException);
    exports2.TooManyUniqueTargetGroupsPerLoadBalancerException$ = [
      -3,
      n032,
      _TMUTGPLBE,
      { [_aQE10]: [`TooManyUniqueTargetGroupsPerLoadBalancer`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.TooManyUniqueTargetGroupsPerLoadBalancerException$, errors_1.TooManyUniqueTargetGroupsPerLoadBalancerException);
    exports2.TrustStoreAssociationNotFoundException$ = [
      -3,
      n032,
      _TSANFE,
      { [_aQE10]: [`AssociationNotFound`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.TrustStoreAssociationNotFoundException$, errors_1.TrustStoreAssociationNotFoundException);
    exports2.TrustStoreInUseException$ = [
      -3,
      n032,
      _TSIUE,
      { [_aQE10]: [`TrustStoreInUse`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.TrustStoreInUseException$, errors_1.TrustStoreInUseException);
    exports2.TrustStoreNotFoundException$ = [
      -3,
      n032,
      _TSNFE,
      { [_aQE10]: [`TrustStoreNotFound`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.TrustStoreNotFoundException$, errors_1.TrustStoreNotFoundException);
    exports2.TrustStoreNotReadyException$ = [
      -3,
      n032,
      _TSNRE,
      { [_aQE10]: [`TrustStoreNotReady`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.TrustStoreNotReadyException$, errors_1.TrustStoreNotReadyException);
    exports2.UnsupportedProtocolException$ = [
      -3,
      n032,
      _UPE,
      { [_aQE10]: [`UnsupportedProtocol`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.UnsupportedProtocolException$, errors_1.UnsupportedProtocolException);
    exports2.errorTypeRegistries = [
      _s_registry32,
      n0_registry32
    ];
    exports2.Action$ = [
      3,
      n032,
      _A10,
      0,
      [_T10, _TGA, _AOC, _ACC, _O, _RC10, _FRC, _FC, _JVC],
      [0, 0, () => exports2.AuthenticateOidcActionConfig$, () => exports2.AuthenticateCognitoActionConfig$, 1, () => exports2.RedirectActionConfig$, () => exports2.FixedResponseActionConfig$, () => exports2.ForwardActionConfig$, () => exports2.JwtValidationActionConfig$],
      1
    ];
    exports2.AddListenerCertificatesInput$ = [
      3,
      n032,
      _ALCI,
      0,
      [_LA, _C11],
      [0, () => CertificateList],
      2
    ];
    exports2.AddListenerCertificatesOutput$ = [
      3,
      n032,
      _ALCO,
      0,
      [_C11],
      [() => CertificateList]
    ];
    exports2.AddTagsInput$ = [
      3,
      n032,
      _ATI,
      0,
      [_RA10, _Ta10],
      [64 | 0, () => TagList],
      2
    ];
    exports2.AddTagsOutput$ = [
      3,
      n032,
      _ATO,
      0,
      [],
      []
    ];
    exports2.AddTrustStoreRevocationsInput$ = [
      3,
      n032,
      _ATSRI,
      0,
      [_TSA, _RCe],
      [0, () => RevocationContents],
      1
    ];
    exports2.AddTrustStoreRevocationsOutput$ = [
      3,
      n032,
      _ATSRO,
      0,
      [_TSR],
      [() => TrustStoreRevocations]
    ];
    exports2.AdministrativeOverride$ = [
      3,
      n032,
      _AO,
      0,
      [_S, _R, _D],
      [0, 0, 0]
    ];
    exports2.AnomalyDetection$ = [
      3,
      n032,
      _AD,
      0,
      [_Re, _MIE],
      [0, 0]
    ];
    exports2.AuthenticateCognitoActionConfig$ = [
      3,
      n032,
      _ACAC,
      0,
      [_UPA, _UPCI, _UPD, _SCN, _Sc, _ST11, _AREP, _OUR],
      [0, 0, 0, 0, 0, 1, 128 | 0, 0],
      3
    ];
    exports2.AuthenticateOidcActionConfig$ = [
      3,
      n032,
      _AOAC,
      0,
      [_I, _AE, _TE, _UIE, _CI, _CS4, _SCN, _Sc, _ST11, _AREP, _OUR, _UECS],
      [0, 0, 0, 0, 0, 0, 0, 0, 1, 128 | 0, 0, 2],
      5
    ];
    exports2.AvailabilityZone$ = [
      3,
      n032,
      _AZ,
      0,
      [_ZN, _SI10, _OI, _LBA, _SNIP],
      [0, 0, 0, () => LoadBalancerAddresses, 64 | 0]
    ];
    exports2.CapacityReservationStatus$ = [
      3,
      n032,
      _CRS,
      0,
      [_Co, _R],
      [0, 0]
    ];
    exports2.Certificate$ = [
      3,
      n032,
      _Ce,
      0,
      [_CA10, _ID],
      [0, 2]
    ];
    exports2.Cipher$ = [
      3,
      n032,
      _Ci,
      0,
      [_N, _P10],
      [0, 1]
    ];
    exports2.CreateListenerInput$ = [
      3,
      n032,
      _CLI,
      0,
      [_LBAo, _DA, _Pr10, _Po, _SP, _C11, _AP, _Ta10, _MA],
      [0, () => Actions, 0, 1, 0, () => CertificateList, 64 | 0, () => TagList, () => exports2.MutualAuthenticationAttributes$],
      2
    ];
    exports2.CreateListenerOutput$ = [
      3,
      n032,
      _CLO,
      0,
      [_L2],
      [() => Listeners]
    ];
    exports2.CreateLoadBalancerInput$ = [
      3,
      n032,
      _CLBI,
      0,
      [_N, _Su, _SM, _SG, _Sch, _Ta10, _T10, _IAT, _COIP, _EPFISN, _IP],
      [0, 64 | 0, () => SubnetMappings, 64 | 0, 0, () => TagList, 0, 0, 0, 0, () => exports2.IpamPools$],
      1
    ];
    exports2.CreateLoadBalancerOutput$ = [
      3,
      n032,
      _CLBO,
      0,
      [_LB],
      [() => LoadBalancers]
    ];
    exports2.CreateRuleInput$ = [
      3,
      n032,
      _CRI,
      0,
      [_LA, _Con, _P10, _Ac, _Ta10, _Tr],
      [0, () => RuleConditionList, 1, () => Actions, () => TagList, () => RuleTransformList],
      4
    ];
    exports2.CreateRuleOutput$ = [
      3,
      n032,
      _CRO,
      0,
      [_Ru],
      [() => Rules]
    ];
    exports2.CreateTargetGroupInput$ = [
      3,
      n032,
      _CTGI,
      0,
      [_N, _Pr10, _PV, _Po, _VI, _HCP, _HCPe, _HCE, _HCPea, _HCIS, _HCTS, _HTC, _UTC, _Ma, _TT, _Ta10, _IAT, _TCP],
      [0, 0, 0, 1, 0, 0, 0, 2, 0, 1, 1, 1, 1, () => exports2.Matcher$, 0, () => TagList, 0, 1],
      1
    ];
    exports2.CreateTargetGroupOutput$ = [
      3,
      n032,
      _CTGO,
      0,
      [_TG],
      [() => TargetGroups]
    ];
    exports2.CreateTrustStoreInput$ = [
      3,
      n032,
      _CTSI,
      0,
      [_N, _CCBSB, _CCBSK, _CCBSOV, _Ta10],
      [0, 0, 0, 0, () => TagList],
      3
    ];
    exports2.CreateTrustStoreOutput$ = [
      3,
      n032,
      _CTSO,
      0,
      [_TS],
      [() => TrustStores]
    ];
    exports2.DeleteListenerInput$ = [
      3,
      n032,
      _DLI,
      0,
      [_LA],
      [0],
      1
    ];
    exports2.DeleteListenerOutput$ = [
      3,
      n032,
      _DLO,
      0,
      [],
      []
    ];
    exports2.DeleteLoadBalancerInput$ = [
      3,
      n032,
      _DLBI,
      0,
      [_LBAo],
      [0],
      1
    ];
    exports2.DeleteLoadBalancerOutput$ = [
      3,
      n032,
      _DLBO,
      0,
      [],
      []
    ];
    exports2.DeleteRuleInput$ = [
      3,
      n032,
      _DRI,
      0,
      [_RAu],
      [0],
      1
    ];
    exports2.DeleteRuleOutput$ = [
      3,
      n032,
      _DRO,
      0,
      [],
      []
    ];
    exports2.DeleteSharedTrustStoreAssociationInput$ = [
      3,
      n032,
      _DSTSAI,
      0,
      [_TSA, _RAe],
      [0, 0],
      2
    ];
    exports2.DeleteSharedTrustStoreAssociationOutput$ = [
      3,
      n032,
      _DSTSAO,
      0,
      [],
      []
    ];
    exports2.DeleteTargetGroupInput$ = [
      3,
      n032,
      _DTGI,
      0,
      [_TGA],
      [0],
      1
    ];
    exports2.DeleteTargetGroupOutput$ = [
      3,
      n032,
      _DTGO,
      0,
      [],
      []
    ];
    exports2.DeleteTrustStoreInput$ = [
      3,
      n032,
      _DTSI,
      0,
      [_TSA],
      [0],
      1
    ];
    exports2.DeleteTrustStoreOutput$ = [
      3,
      n032,
      _DTSO,
      0,
      [],
      []
    ];
    exports2.DeregisterTargetsInput$ = [
      3,
      n032,
      _DTI,
      0,
      [_TGA, _Tar],
      [0, () => TargetDescriptions],
      2
    ];
    exports2.DeregisterTargetsOutput$ = [
      3,
      n032,
      _DTO,
      0,
      [],
      []
    ];
    exports2.DescribeAccountLimitsInput$ = [
      3,
      n032,
      _DALI,
      0,
      [_Mar, _PS],
      [0, 1]
    ];
    exports2.DescribeAccountLimitsOutput$ = [
      3,
      n032,
      _DALO,
      0,
      [_Li, _NM],
      [() => Limits, 0]
    ];
    exports2.DescribeCapacityReservationInput$ = [
      3,
      n032,
      _DCRI,
      0,
      [_LBAo],
      [0],
      1
    ];
    exports2.DescribeCapacityReservationOutput$ = [
      3,
      n032,
      _DCRO,
      0,
      [_LMT, _DRR, _MLBC, _CRSa],
      [4, 1, () => exports2.MinimumLoadBalancerCapacity$, () => ZonalCapacityReservationStates]
    ];
    exports2.DescribeListenerAttributesInput$ = [
      3,
      n032,
      _DLAI,
      0,
      [_LA],
      [0],
      1
    ];
    exports2.DescribeListenerAttributesOutput$ = [
      3,
      n032,
      _DLAO,
      0,
      [_At],
      [() => ListenerAttributes]
    ];
    exports2.DescribeListenerCertificatesInput$ = [
      3,
      n032,
      _DLCI,
      0,
      [_LA, _Mar, _PS],
      [0, 0, 1],
      1
    ];
    exports2.DescribeListenerCertificatesOutput$ = [
      3,
      n032,
      _DLCO,
      0,
      [_C11, _NM],
      [() => CertificateList, 0]
    ];
    exports2.DescribeListenersInput$ = [
      3,
      n032,
      _DLIe,
      0,
      [_LBAo, _LAi, _Mar, _PS],
      [0, 64 | 0, 0, 1]
    ];
    exports2.DescribeListenersOutput$ = [
      3,
      n032,
      _DLOe,
      0,
      [_L2, _NM],
      [() => Listeners, 0]
    ];
    exports2.DescribeLoadBalancerAttributesInput$ = [
      3,
      n032,
      _DLBAI,
      0,
      [_LBAo],
      [0],
      1
    ];
    exports2.DescribeLoadBalancerAttributesOutput$ = [
      3,
      n032,
      _DLBAO,
      0,
      [_At],
      [() => LoadBalancerAttributes]
    ];
    exports2.DescribeLoadBalancersInput$ = [
      3,
      n032,
      _DLBIe,
      0,
      [_LBAoa, _Na, _Mar, _PS],
      [64 | 0, 64 | 0, 0, 1]
    ];
    exports2.DescribeLoadBalancersOutput$ = [
      3,
      n032,
      _DLBOe,
      0,
      [_LB, _NM],
      [() => LoadBalancers, 0]
    ];
    exports2.DescribeRulesInput$ = [
      3,
      n032,
      _DRIe,
      0,
      [_LA, _RAul, _Mar, _PS],
      [0, 64 | 0, 0, 1]
    ];
    exports2.DescribeRulesOutput$ = [
      3,
      n032,
      _DROe,
      0,
      [_Ru, _NM],
      [() => Rules, 0]
    ];
    exports2.DescribeSSLPoliciesInput$ = [
      3,
      n032,
      _DSSLPI,
      0,
      [_Na, _Mar, _PS, _LBT],
      [64 | 0, 0, 1, 0]
    ];
    exports2.DescribeSSLPoliciesOutput$ = [
      3,
      n032,
      _DSSLPO,
      0,
      [_SPs, _NM],
      [() => SslPolicies, 0]
    ];
    exports2.DescribeTagsInput$ = [
      3,
      n032,
      _DTIe,
      0,
      [_RA10],
      [64 | 0],
      1
    ];
    exports2.DescribeTagsOutput$ = [
      3,
      n032,
      _DTOe,
      0,
      [_TD],
      [() => TagDescriptions]
    ];
    exports2.DescribeTargetGroupAttributesInput$ = [
      3,
      n032,
      _DTGAI,
      0,
      [_TGA],
      [0],
      1
    ];
    exports2.DescribeTargetGroupAttributesOutput$ = [
      3,
      n032,
      _DTGAO,
      0,
      [_At],
      [() => TargetGroupAttributes]
    ];
    exports2.DescribeTargetGroupsInput$ = [
      3,
      n032,
      _DTGIe,
      0,
      [_LBAo, _TGAa, _Na, _Mar, _PS],
      [0, 64 | 0, 64 | 0, 0, 1]
    ];
    exports2.DescribeTargetGroupsOutput$ = [
      3,
      n032,
      _DTGOe,
      0,
      [_TG, _NM],
      [() => TargetGroups, 0]
    ];
    exports2.DescribeTargetHealthInput$ = [
      3,
      n032,
      _DTHI,
      0,
      [_TGA, _Tar, _In],
      [0, () => TargetDescriptions, 64 | 0],
      1
    ];
    exports2.DescribeTargetHealthOutput$ = [
      3,
      n032,
      _DTHO,
      0,
      [_THD],
      [() => TargetHealthDescriptions]
    ];
    exports2.DescribeTrustStoreAssociationsInput$ = [
      3,
      n032,
      _DTSAI,
      0,
      [_TSA, _Mar, _PS],
      [0, 0, 1],
      1
    ];
    exports2.DescribeTrustStoreAssociationsOutput$ = [
      3,
      n032,
      _DTSAO,
      0,
      [_TSAr, _NM],
      [() => TrustStoreAssociations, 0]
    ];
    exports2.DescribeTrustStoreRevocation$ = [
      3,
      n032,
      _DTSR,
      0,
      [_TSA, _RI, _RT13, _NORE],
      [0, 1, 0, 1]
    ];
    exports2.DescribeTrustStoreRevocationsInput$ = [
      3,
      n032,
      _DTSRI,
      0,
      [_TSA, _RIe, _Mar, _PS],
      [0, 64 | 1, 0, 1],
      1
    ];
    exports2.DescribeTrustStoreRevocationsOutput$ = [
      3,
      n032,
      _DTSRO,
      0,
      [_TSR, _NM],
      [() => DescribeTrustStoreRevocationResponse, 0]
    ];
    exports2.DescribeTrustStoresInput$ = [
      3,
      n032,
      _DTSIe,
      0,
      [_TSAru, _Na, _Mar, _PS],
      [64 | 0, 64 | 0, 0, 1]
    ];
    exports2.DescribeTrustStoresOutput$ = [
      3,
      n032,
      _DTSOe,
      0,
      [_TS, _NM],
      [() => TrustStores, 0]
    ];
    exports2.FixedResponseActionConfig$ = [
      3,
      n032,
      _FRAC,
      0,
      [_SC, _MB, _CT4],
      [0, 0, 0],
      1
    ];
    exports2.ForwardActionConfig$ = [
      3,
      n032,
      _FAC,
      0,
      [_TG, _TGSC],
      [() => TargetGroupList, () => exports2.TargetGroupStickinessConfig$]
    ];
    exports2.GetResourcePolicyInput$ = [
      3,
      n032,
      _GRPI,
      0,
      [_RAe],
      [0],
      1
    ];
    exports2.GetResourcePolicyOutput$ = [
      3,
      n032,
      _GRPO,
      0,
      [_Pol],
      [0]
    ];
    exports2.GetTrustStoreCaCertificatesBundleInput$ = [
      3,
      n032,
      _GTSCCBI,
      0,
      [_TSA],
      [0],
      1
    ];
    exports2.GetTrustStoreCaCertificatesBundleOutput$ = [
      3,
      n032,
      _GTSCCBO,
      0,
      [_Lo],
      [0]
    ];
    exports2.GetTrustStoreRevocationContentInput$ = [
      3,
      n032,
      _GTSRCI,
      0,
      [_TSA, _RI],
      [0, 1],
      2
    ];
    exports2.GetTrustStoreRevocationContentOutput$ = [
      3,
      n032,
      _GTSRCO,
      0,
      [_Lo],
      [0]
    ];
    exports2.HostHeaderConditionConfig$ = [
      3,
      n032,
      _HHCC,
      0,
      [_V10, _RV],
      [64 | 0, 64 | 0]
    ];
    exports2.HostHeaderRewriteConfig$ = [
      3,
      n032,
      _HHRC,
      0,
      [_Rew],
      [() => RewriteConfigList]
    ];
    exports2.HttpHeaderConditionConfig$ = [
      3,
      n032,
      _HHCCt,
      0,
      [_HHN, _V10, _RV],
      [0, 64 | 0, 64 | 0]
    ];
    exports2.HttpRequestMethodConditionConfig$ = [
      3,
      n032,
      _HRMCC,
      0,
      [_V10],
      [64 | 0]
    ];
    exports2.IpamPools$ = [
      3,
      n032,
      _IP,
      0,
      [_IIPI],
      [0]
    ];
    exports2.JwtValidationActionAdditionalClaim$ = [
      3,
      n032,
      _JVAAC,
      0,
      [_F, _N, _V10],
      [0, 0, 64 | 0],
      3
    ];
    exports2.JwtValidationActionConfig$ = [
      3,
      n032,
      _JVAC,
      0,
      [_JE, _I, _AC],
      [0, 0, () => JwtValidationActionAdditionalClaims],
      2
    ];
    exports2.Limit$ = [
      3,
      n032,
      _Lim,
      0,
      [_N, _Max],
      [0, 0]
    ];
    exports2.Listener$ = [
      3,
      n032,
      _Lis,
      0,
      [_LA, _LBAo, _Po, _Pr10, _C11, _SP, _DA, _AP, _MA],
      [0, 0, 1, 0, () => CertificateList, 0, () => Actions, 64 | 0, () => exports2.MutualAuthenticationAttributes$]
    ];
    exports2.ListenerAttribute$ = [
      3,
      n032,
      _LAis,
      0,
      [_K10, _Va],
      [0, 0]
    ];
    exports2.LoadBalancer$ = [
      3,
      n032,
      _LBo,
      0,
      [_LBAo, _DNSN, _CHZI, _CTr, _LBN, _Sch, _VI, _S, _T10, _AZv, _SG, _IAT, _COIP, _ESGIROPLT, _EPFISN, _IP],
      [0, 0, 0, 4, 0, 0, 0, () => exports2.LoadBalancerState$, 0, () => AvailabilityZones, 64 | 0, 0, 0, 0, 0, () => exports2.IpamPools$]
    ];
    exports2.LoadBalancerAddress$ = [
      3,
      n032,
      _LBAoad,
      0,
      [_IA, _AI2, _PIPA, _IPA],
      [0, 0, 0, 0]
    ];
    exports2.LoadBalancerAttribute$ = [
      3,
      n032,
      _LBAoada,
      0,
      [_K10, _Va],
      [0, 0]
    ];
    exports2.LoadBalancerState$ = [
      3,
      n032,
      _LBS,
      0,
      [_Co, _R],
      [0, 0]
    ];
    exports2.Matcher$ = [
      3,
      n032,
      _Ma,
      0,
      [_HC, _GC],
      [0, 0]
    ];
    exports2.MinimumLoadBalancerCapacity$ = [
      3,
      n032,
      _MLBC,
      0,
      [_CU],
      [1]
    ];
    exports2.ModifyCapacityReservationInput$ = [
      3,
      n032,
      _MCRI,
      0,
      [_LBAo, _MLBC, _RCR],
      [0, () => exports2.MinimumLoadBalancerCapacity$, 2],
      1
    ];
    exports2.ModifyCapacityReservationOutput$ = [
      3,
      n032,
      _MCRO,
      0,
      [_LMT, _DRR, _MLBC, _CRSa],
      [4, 1, () => exports2.MinimumLoadBalancerCapacity$, () => ZonalCapacityReservationStates]
    ];
    exports2.ModifyIpPoolsInput$ = [
      3,
      n032,
      _MIPI,
      0,
      [_LBAo, _IP, _RIP],
      [0, () => exports2.IpamPools$, 64 | 0],
      1
    ];
    exports2.ModifyIpPoolsOutput$ = [
      3,
      n032,
      _MIPO,
      0,
      [_IP],
      [() => exports2.IpamPools$]
    ];
    exports2.ModifyListenerAttributesInput$ = [
      3,
      n032,
      _MLAI,
      0,
      [_LA, _At],
      [0, () => ListenerAttributes],
      2
    ];
    exports2.ModifyListenerAttributesOutput$ = [
      3,
      n032,
      _MLAO,
      0,
      [_At],
      [() => ListenerAttributes]
    ];
    exports2.ModifyListenerInput$ = [
      3,
      n032,
      _MLI,
      0,
      [_LA, _Po, _Pr10, _SP, _C11, _DA, _AP, _MA],
      [0, 1, 0, 0, () => CertificateList, () => Actions, 64 | 0, () => exports2.MutualAuthenticationAttributes$],
      1
    ];
    exports2.ModifyListenerOutput$ = [
      3,
      n032,
      _MLO,
      0,
      [_L2],
      [() => Listeners]
    ];
    exports2.ModifyLoadBalancerAttributesInput$ = [
      3,
      n032,
      _MLBAI,
      0,
      [_LBAo, _At],
      [0, () => LoadBalancerAttributes],
      2
    ];
    exports2.ModifyLoadBalancerAttributesOutput$ = [
      3,
      n032,
      _MLBAO,
      0,
      [_At],
      [() => LoadBalancerAttributes]
    ];
    exports2.ModifyRuleInput$ = [
      3,
      n032,
      _MRI,
      0,
      [_RAu, _Con, _Ac, _Tr, _RTe],
      [0, () => RuleConditionList, () => Actions, () => RuleTransformList, 2],
      1
    ];
    exports2.ModifyRuleOutput$ = [
      3,
      n032,
      _MRO,
      0,
      [_Ru],
      [() => Rules]
    ];
    exports2.ModifyTargetGroupAttributesInput$ = [
      3,
      n032,
      _MTGAI,
      0,
      [_TGA, _At],
      [0, () => TargetGroupAttributes],
      2
    ];
    exports2.ModifyTargetGroupAttributesOutput$ = [
      3,
      n032,
      _MTGAO,
      0,
      [_At],
      [() => TargetGroupAttributes]
    ];
    exports2.ModifyTargetGroupInput$ = [
      3,
      n032,
      _MTGI,
      0,
      [_TGA, _HCP, _HCPe, _HCPea, _HCE, _HCIS, _HCTS, _HTC, _UTC, _Ma],
      [0, 0, 0, 0, 2, 1, 1, 1, 1, () => exports2.Matcher$],
      1
    ];
    exports2.ModifyTargetGroupOutput$ = [
      3,
      n032,
      _MTGO,
      0,
      [_TG],
      [() => TargetGroups]
    ];
    exports2.ModifyTrustStoreInput$ = [
      3,
      n032,
      _MTSI,
      0,
      [_TSA, _CCBSB, _CCBSK, _CCBSOV],
      [0, 0, 0, 0],
      3
    ];
    exports2.ModifyTrustStoreOutput$ = [
      3,
      n032,
      _MTSO,
      0,
      [_TS],
      [() => TrustStores]
    ];
    exports2.MutualAuthenticationAttributes$ = [
      3,
      n032,
      _MAA,
      0,
      [_Mo, _TSA, _ICCE, _TSAS, _ATSCN],
      [0, 0, 2, 0, 0]
    ];
    exports2.PathPatternConditionConfig$ = [
      3,
      n032,
      _PPCC,
      0,
      [_V10, _RV],
      [64 | 0, 64 | 0]
    ];
    exports2.QueryStringConditionConfig$ = [
      3,
      n032,
      _QSCC,
      0,
      [_V10],
      [() => QueryStringKeyValuePairList]
    ];
    exports2.QueryStringKeyValuePair$ = [
      3,
      n032,
      _QSKVP,
      0,
      [_K10, _Va],
      [0, 0]
    ];
    exports2.RedirectActionConfig$ = [
      3,
      n032,
      _RAC,
      0,
      [_SC, _Pr10, _Po, _H, _Pa, _Q],
      [0, 0, 0, 0, 0, 0],
      1
    ];
    exports2.RegisterTargetsInput$ = [
      3,
      n032,
      _RTI,
      0,
      [_TGA, _Tar],
      [0, () => TargetDescriptions],
      2
    ];
    exports2.RegisterTargetsOutput$ = [
      3,
      n032,
      _RTO,
      0,
      [],
      []
    ];
    exports2.RemoveListenerCertificatesInput$ = [
      3,
      n032,
      _RLCI,
      0,
      [_LA, _C11],
      [0, () => CertificateList],
      2
    ];
    exports2.RemoveListenerCertificatesOutput$ = [
      3,
      n032,
      _RLCO,
      0,
      [],
      []
    ];
    exports2.RemoveTagsInput$ = [
      3,
      n032,
      _RTIe,
      0,
      [_RA10, _TK],
      [64 | 0, 64 | 0],
      2
    ];
    exports2.RemoveTagsOutput$ = [
      3,
      n032,
      _RTOe,
      0,
      [],
      []
    ];
    exports2.RemoveTrustStoreRevocationsInput$ = [
      3,
      n032,
      _RTSRI,
      0,
      [_TSA, _RIe],
      [0, 64 | 1],
      2
    ];
    exports2.RemoveTrustStoreRevocationsOutput$ = [
      3,
      n032,
      _RTSRO,
      0,
      [],
      []
    ];
    exports2.RevocationContent$ = [
      3,
      n032,
      _RCev,
      0,
      [_SB, _SK2, _SOV, _RT13],
      [0, 0, 0, 0]
    ];
    exports2.RewriteConfig$ = [
      3,
      n032,
      _RCew,
      0,
      [_Reg, _Rep],
      [0, 0],
      2
    ];
    exports2.Rule$ = [
      3,
      n032,
      _Rul,
      0,
      [_RAu, _P10, _Con, _Ac, _ID, _Tr],
      [0, 0, () => RuleConditionList, () => Actions, 2, () => RuleTransformList]
    ];
    exports2.RuleCondition$ = [
      3,
      n032,
      _RCu,
      0,
      [_Fi, _V10, _HHC, _PPC, _HHCt, _QSC, _HRMC, _SIC, _RV],
      [0, 64 | 0, () => exports2.HostHeaderConditionConfig$, () => exports2.PathPatternConditionConfig$, () => exports2.HttpHeaderConditionConfig$, () => exports2.QueryStringConditionConfig$, () => exports2.HttpRequestMethodConditionConfig$, () => exports2.SourceIpConditionConfig$, 64 | 0]
    ];
    exports2.RulePriorityPair$ = [
      3,
      n032,
      _RPP,
      0,
      [_RAu, _P10],
      [0, 1]
    ];
    exports2.RuleTransform$ = [
      3,
      n032,
      _RTu,
      0,
      [_T10, _HHRC, _URC],
      [0, () => exports2.HostHeaderRewriteConfig$, () => exports2.UrlRewriteConfig$],
      1
    ];
    exports2.SetIpAddressTypeInput$ = [
      3,
      n032,
      _SIATI,
      0,
      [_LBAo, _IAT],
      [0, 0],
      2
    ];
    exports2.SetIpAddressTypeOutput$ = [
      3,
      n032,
      _SIATO,
      0,
      [_IAT],
      [0]
    ];
    exports2.SetRulePrioritiesInput$ = [
      3,
      n032,
      _SRPI,
      0,
      [_RP],
      [() => RulePriorityList],
      1
    ];
    exports2.SetRulePrioritiesOutput$ = [
      3,
      n032,
      _SRPO,
      0,
      [_Ru],
      [() => Rules]
    ];
    exports2.SetSecurityGroupsInput$ = [
      3,
      n032,
      _SSGI,
      0,
      [_LBAo, _SG, _ESGIROPLT],
      [0, 64 | 0, 0],
      2
    ];
    exports2.SetSecurityGroupsOutput$ = [
      3,
      n032,
      _SSGO,
      0,
      [_SGI, _ESGIROPLT],
      [64 | 0, 0]
    ];
    exports2.SetSubnetsInput$ = [
      3,
      n032,
      _SSI,
      0,
      [_LBAo, _Su, _SM, _IAT, _EPFISN],
      [0, 64 | 0, () => SubnetMappings, 0, 0],
      1
    ];
    exports2.SetSubnetsOutput$ = [
      3,
      n032,
      _SSO,
      0,
      [_AZv, _IAT, _EPFISN],
      [() => AvailabilityZones, 0, 0]
    ];
    exports2.SourceIpConditionConfig$ = [
      3,
      n032,
      _SICC,
      0,
      [_V10],
      [64 | 0]
    ];
    exports2.SslPolicy$ = [
      3,
      n032,
      _SP,
      0,
      [_SPsl, _Cip, _N, _SLBT],
      [64 | 0, () => Ciphers, 0, 64 | 0]
    ];
    exports2.SubnetMapping$ = [
      3,
      n032,
      _SMu,
      0,
      [_SI10, _AI2, _PIPA, _IPA, _SNIPo],
      [0, 0, 0, 0, 0]
    ];
    exports2.Tag$ = [
      3,
      n032,
      _Tag,
      0,
      [_K10, _Va],
      [0, 0],
      1
    ];
    exports2.TagDescription$ = [
      3,
      n032,
      _TDa,
      0,
      [_RAe, _Ta10],
      [0, () => TagList]
    ];
    exports2.TargetDescription$ = [
      3,
      n032,
      _TDar,
      0,
      [_Id, _Po, _AZ, _QSI],
      [0, 1, 0, 0],
      1
    ];
    exports2.TargetGroup$ = [
      3,
      n032,
      _TGa,
      0,
      [_TGA, _TGN, _Pr10, _Po, _VI, _HCP, _HCPe, _HCE, _HCIS, _HCTS, _HTC, _UTC, _HCPea, _Ma, _LBAoa, _TT, _PV, _IAT, _TCP],
      [0, 0, 0, 1, 0, 0, 0, 2, 1, 1, 1, 1, 0, () => exports2.Matcher$, 64 | 0, 0, 0, 0, 1]
    ];
    exports2.TargetGroupAttribute$ = [
      3,
      n032,
      _TGAar,
      0,
      [_K10, _Va],
      [0, 0]
    ];
    exports2.TargetGroupStickinessConfig$ = [
      3,
      n032,
      _TGSC,
      0,
      [_E11, _DS10],
      [2, 1]
    ];
    exports2.TargetGroupTuple$ = [
      3,
      n032,
      _TGT,
      0,
      [_TGA, _W],
      [0, 1]
    ];
    exports2.TargetHealth$ = [
      3,
      n032,
      _TH,
      0,
      [_S, _R, _D],
      [0, 0, 0]
    ];
    exports2.TargetHealthDescription$ = [
      3,
      n032,
      _THDa,
      0,
      [_Targ, _HCPe, _TH, _AD, _AO],
      [() => exports2.TargetDescription$, 0, () => exports2.TargetHealth$, () => exports2.AnomalyDetection$, () => exports2.AdministrativeOverride$]
    ];
    exports2.TrustStore$ = [
      3,
      n032,
      _TSr,
      0,
      [_N, _TSA, _St, _NOCC, _TRE],
      [0, 0, 0, 1, 1]
    ];
    exports2.TrustStoreAssociation$ = [
      3,
      n032,
      _TSArus,
      0,
      [_RAe],
      [0]
    ];
    exports2.TrustStoreRevocation$ = [
      3,
      n032,
      _TSRr,
      0,
      [_TSA, _RI, _RT13, _NORE],
      [0, 1, 0, 1]
    ];
    exports2.UrlRewriteConfig$ = [
      3,
      n032,
      _URC,
      0,
      [_Rew],
      [() => RewriteConfigList]
    ];
    exports2.ZonalCapacityReservationState$ = [
      3,
      n032,
      _ZCRS,
      0,
      [_S, _AZ, _ECU],
      [() => exports2.CapacityReservationStatus$, 0, 1]
    ];
    var Actions = [
      1,
      n032,
      _Ac,
      0,
      () => exports2.Action$
    ];
    var AlpnPolicyName = 64 | 0;
    var AvailabilityZones = [
      1,
      n032,
      _AZv,
      0,
      () => exports2.AvailabilityZone$
    ];
    var CertificateList = [
      1,
      n032,
      _CL,
      0,
      () => exports2.Certificate$
    ];
    var Ciphers = [
      1,
      n032,
      _Cip,
      0,
      () => exports2.Cipher$
    ];
    var DescribeTrustStoreRevocationResponse = [
      1,
      n032,
      _DTSRR,
      0,
      () => exports2.DescribeTrustStoreRevocation$
    ];
    var JwtValidationActionAdditionalClaims = [
      1,
      n032,
      _JVAACw,
      0,
      () => exports2.JwtValidationActionAdditionalClaim$
    ];
    var JwtValidationActionAdditionalClaimValues = 64 | 0;
    var Limits = [
      1,
      n032,
      _Li,
      0,
      () => exports2.Limit$
    ];
    var ListenerArns = 64 | 0;
    var ListenerAttributes = [
      1,
      n032,
      _LAist,
      0,
      () => exports2.ListenerAttribute$
    ];
    var Listeners = [
      1,
      n032,
      _L2,
      0,
      () => exports2.Listener$
    ];
    var ListOfDescribeTargetHealthIncludeOptions = 64 | 0;
    var ListOfString = 64 | 0;
    var LoadBalancerAddresses = [
      1,
      n032,
      _LBA,
      0,
      () => exports2.LoadBalancerAddress$
    ];
    var LoadBalancerArns = 64 | 0;
    var LoadBalancerAttributes = [
      1,
      n032,
      _LBAoadal,
      0,
      () => exports2.LoadBalancerAttribute$
    ];
    var LoadBalancerNames = 64 | 0;
    var LoadBalancers = [
      1,
      n032,
      _LB,
      0,
      () => exports2.LoadBalancer$
    ];
    var QueryStringKeyValuePairList = [
      1,
      n032,
      _QSKVPL,
      0,
      () => exports2.QueryStringKeyValuePair$
    ];
    var RemoveIpamPools = 64 | 0;
    var ResourceArns = 64 | 0;
    var RevocationContents = [
      1,
      n032,
      _RCe,
      0,
      () => exports2.RevocationContent$
    ];
    var RevocationIds = 64 | 1;
    var RewriteConfigList = [
      1,
      n032,
      _RCL,
      0,
      () => exports2.RewriteConfig$
    ];
    var RuleArns = 64 | 0;
    var RuleConditionList = [
      1,
      n032,
      _RCLu,
      0,
      () => exports2.RuleCondition$
    ];
    var RulePriorityList = [
      1,
      n032,
      _RPL,
      0,
      () => exports2.RulePriorityPair$
    ];
    var Rules = [
      1,
      n032,
      _Ru,
      0,
      () => exports2.Rule$
    ];
    var RuleTransformList = [
      1,
      n032,
      _RTL,
      0,
      () => exports2.RuleTransform$
    ];
    var SecurityGroups = 64 | 0;
    var SourceNatIpv6Prefixes = 64 | 0;
    var SslPolicies = [
      1,
      n032,
      _SPs,
      0,
      () => exports2.SslPolicy$
    ];
    var SslPolicyNames = 64 | 0;
    var SslProtocols = 64 | 0;
    var SubnetMappings = [
      1,
      n032,
      _SM,
      0,
      () => exports2.SubnetMapping$
    ];
    var Subnets = 64 | 0;
    var TagDescriptions = [
      1,
      n032,
      _TD,
      0,
      () => exports2.TagDescription$
    ];
    var TagKeys = 64 | 0;
    var TagList = [
      1,
      n032,
      _TL,
      0,
      () => exports2.Tag$
    ];
    var TargetDescriptions = [
      1,
      n032,
      _TDarg,
      0,
      () => exports2.TargetDescription$
    ];
    var TargetGroupArns = 64 | 0;
    var TargetGroupAttributes = [
      1,
      n032,
      _TGAarg,
      0,
      () => exports2.TargetGroupAttribute$
    ];
    var TargetGroupList = [
      1,
      n032,
      _TGL,
      0,
      () => exports2.TargetGroupTuple$
    ];
    var TargetGroupNames = 64 | 0;
    var TargetGroups = [
      1,
      n032,
      _TG,
      0,
      () => exports2.TargetGroup$
    ];
    var TargetHealthDescriptions = [
      1,
      n032,
      _THD,
      0,
      () => exports2.TargetHealthDescription$
    ];
    var TrustStoreArns = 64 | 0;
    var TrustStoreAssociations = [
      1,
      n032,
      _TSAr,
      0,
      () => exports2.TrustStoreAssociation$
    ];
    var TrustStoreNames = 64 | 0;
    var TrustStoreRevocations = [
      1,
      n032,
      _TSR,
      0,
      () => exports2.TrustStoreRevocation$
    ];
    var TrustStores = [
      1,
      n032,
      _TS,
      0,
      () => exports2.TrustStore$
    ];
    var ZonalCapacityReservationStates = [
      1,
      n032,
      _ZCRSo,
      0,
      () => exports2.ZonalCapacityReservationState$
    ];
    var AuthenticateCognitoActionAuthenticationRequestExtraParams = 128 | 0;
    var AuthenticateOidcActionAuthenticationRequestExtraParams = 128 | 0;
    exports2.AddListenerCertificates$ = [
      9,
      n032,
      _ALC,
      0,
      () => exports2.AddListenerCertificatesInput$,
      () => exports2.AddListenerCertificatesOutput$
    ];
    exports2.AddTags$ = [
      9,
      n032,
      _AT13,
      0,
      () => exports2.AddTagsInput$,
      () => exports2.AddTagsOutput$
    ];
    exports2.AddTrustStoreRevocations$ = [
      9,
      n032,
      _ATSR,
      0,
      () => exports2.AddTrustStoreRevocationsInput$,
      () => exports2.AddTrustStoreRevocationsOutput$
    ];
    exports2.CreateListener$ = [
      9,
      n032,
      _CLr,
      0,
      () => exports2.CreateListenerInput$,
      () => exports2.CreateListenerOutput$
    ];
    exports2.CreateLoadBalancer$ = [
      9,
      n032,
      _CLB,
      0,
      () => exports2.CreateLoadBalancerInput$,
      () => exports2.CreateLoadBalancerOutput$
    ];
    exports2.CreateRule$ = [
      9,
      n032,
      _CR,
      0,
      () => exports2.CreateRuleInput$,
      () => exports2.CreateRuleOutput$
    ];
    exports2.CreateTargetGroup$ = [
      9,
      n032,
      _CTG,
      0,
      () => exports2.CreateTargetGroupInput$,
      () => exports2.CreateTargetGroupOutput$
    ];
    exports2.CreateTrustStore$ = [
      9,
      n032,
      _CTS,
      0,
      () => exports2.CreateTrustStoreInput$,
      () => exports2.CreateTrustStoreOutput$
    ];
    exports2.DeleteListener$ = [
      9,
      n032,
      _DL,
      0,
      () => exports2.DeleteListenerInput$,
      () => exports2.DeleteListenerOutput$
    ];
    exports2.DeleteLoadBalancer$ = [
      9,
      n032,
      _DLB,
      0,
      () => exports2.DeleteLoadBalancerInput$,
      () => exports2.DeleteLoadBalancerOutput$
    ];
    exports2.DeleteRule$ = [
      9,
      n032,
      _DR,
      0,
      () => exports2.DeleteRuleInput$,
      () => exports2.DeleteRuleOutput$
    ];
    exports2.DeleteSharedTrustStoreAssociation$ = [
      9,
      n032,
      _DSTSA,
      0,
      () => exports2.DeleteSharedTrustStoreAssociationInput$,
      () => exports2.DeleteSharedTrustStoreAssociationOutput$
    ];
    exports2.DeleteTargetGroup$ = [
      9,
      n032,
      _DTG,
      0,
      () => exports2.DeleteTargetGroupInput$,
      () => exports2.DeleteTargetGroupOutput$
    ];
    exports2.DeleteTrustStore$ = [
      9,
      n032,
      _DTS,
      0,
      () => exports2.DeleteTrustStoreInput$,
      () => exports2.DeleteTrustStoreOutput$
    ];
    exports2.DeregisterTargets$ = [
      9,
      n032,
      _DT,
      0,
      () => exports2.DeregisterTargetsInput$,
      () => exports2.DeregisterTargetsOutput$
    ];
    exports2.DescribeAccountLimits$ = [
      9,
      n032,
      _DAL,
      0,
      () => exports2.DescribeAccountLimitsInput$,
      () => exports2.DescribeAccountLimitsOutput$
    ];
    exports2.DescribeCapacityReservation$ = [
      9,
      n032,
      _DCR,
      0,
      () => exports2.DescribeCapacityReservationInput$,
      () => exports2.DescribeCapacityReservationOutput$
    ];
    exports2.DescribeListenerAttributes$ = [
      9,
      n032,
      _DLA,
      0,
      () => exports2.DescribeListenerAttributesInput$,
      () => exports2.DescribeListenerAttributesOutput$
    ];
    exports2.DescribeListenerCertificates$ = [
      9,
      n032,
      _DLC,
      0,
      () => exports2.DescribeListenerCertificatesInput$,
      () => exports2.DescribeListenerCertificatesOutput$
    ];
    exports2.DescribeListeners$ = [
      9,
      n032,
      _DLe,
      0,
      () => exports2.DescribeListenersInput$,
      () => exports2.DescribeListenersOutput$
    ];
    exports2.DescribeLoadBalancerAttributes$ = [
      9,
      n032,
      _DLBA,
      0,
      () => exports2.DescribeLoadBalancerAttributesInput$,
      () => exports2.DescribeLoadBalancerAttributesOutput$
    ];
    exports2.DescribeLoadBalancers$ = [
      9,
      n032,
      _DLBe,
      0,
      () => exports2.DescribeLoadBalancersInput$,
      () => exports2.DescribeLoadBalancersOutput$
    ];
    exports2.DescribeRules$ = [
      9,
      n032,
      _DRe,
      0,
      () => exports2.DescribeRulesInput$,
      () => exports2.DescribeRulesOutput$
    ];
    exports2.DescribeSSLPolicies$ = [
      9,
      n032,
      _DSSLP,
      0,
      () => exports2.DescribeSSLPoliciesInput$,
      () => exports2.DescribeSSLPoliciesOutput$
    ];
    exports2.DescribeTags$ = [
      9,
      n032,
      _DTe,
      0,
      () => exports2.DescribeTagsInput$,
      () => exports2.DescribeTagsOutput$
    ];
    exports2.DescribeTargetGroupAttributes$ = [
      9,
      n032,
      _DTGA,
      0,
      () => exports2.DescribeTargetGroupAttributesInput$,
      () => exports2.DescribeTargetGroupAttributesOutput$
    ];
    exports2.DescribeTargetGroups$ = [
      9,
      n032,
      _DTGe,
      0,
      () => exports2.DescribeTargetGroupsInput$,
      () => exports2.DescribeTargetGroupsOutput$
    ];
    exports2.DescribeTargetHealth$ = [
      9,
      n032,
      _DTH,
      0,
      () => exports2.DescribeTargetHealthInput$,
      () => exports2.DescribeTargetHealthOutput$
    ];
    exports2.DescribeTrustStoreAssociations$ = [
      9,
      n032,
      _DTSA,
      0,
      () => exports2.DescribeTrustStoreAssociationsInput$,
      () => exports2.DescribeTrustStoreAssociationsOutput$
    ];
    exports2.DescribeTrustStoreRevocations$ = [
      9,
      n032,
      _DTSRe,
      0,
      () => exports2.DescribeTrustStoreRevocationsInput$,
      () => exports2.DescribeTrustStoreRevocationsOutput$
    ];
    exports2.DescribeTrustStores$ = [
      9,
      n032,
      _DTSe,
      0,
      () => exports2.DescribeTrustStoresInput$,
      () => exports2.DescribeTrustStoresOutput$
    ];
    exports2.GetResourcePolicy$ = [
      9,
      n032,
      _GRP,
      0,
      () => exports2.GetResourcePolicyInput$,
      () => exports2.GetResourcePolicyOutput$
    ];
    exports2.GetTrustStoreCaCertificatesBundle$ = [
      9,
      n032,
      _GTSCCB,
      0,
      () => exports2.GetTrustStoreCaCertificatesBundleInput$,
      () => exports2.GetTrustStoreCaCertificatesBundleOutput$
    ];
    exports2.GetTrustStoreRevocationContent$ = [
      9,
      n032,
      _GTSRC,
      0,
      () => exports2.GetTrustStoreRevocationContentInput$,
      () => exports2.GetTrustStoreRevocationContentOutput$
    ];
    exports2.ModifyCapacityReservation$ = [
      9,
      n032,
      _MCR,
      0,
      () => exports2.ModifyCapacityReservationInput$,
      () => exports2.ModifyCapacityReservationOutput$
    ];
    exports2.ModifyIpPools$ = [
      9,
      n032,
      _MIP,
      0,
      () => exports2.ModifyIpPoolsInput$,
      () => exports2.ModifyIpPoolsOutput$
    ];
    exports2.ModifyListener$ = [
      9,
      n032,
      _ML,
      0,
      () => exports2.ModifyListenerInput$,
      () => exports2.ModifyListenerOutput$
    ];
    exports2.ModifyListenerAttributes$ = [
      9,
      n032,
      _MLA,
      0,
      () => exports2.ModifyListenerAttributesInput$,
      () => exports2.ModifyListenerAttributesOutput$
    ];
    exports2.ModifyLoadBalancerAttributes$ = [
      9,
      n032,
      _MLBA,
      0,
      () => exports2.ModifyLoadBalancerAttributesInput$,
      () => exports2.ModifyLoadBalancerAttributesOutput$
    ];
    exports2.ModifyRule$ = [
      9,
      n032,
      _MR,
      0,
      () => exports2.ModifyRuleInput$,
      () => exports2.ModifyRuleOutput$
    ];
    exports2.ModifyTargetGroup$ = [
      9,
      n032,
      _MTG,
      0,
      () => exports2.ModifyTargetGroupInput$,
      () => exports2.ModifyTargetGroupOutput$
    ];
    exports2.ModifyTargetGroupAttributes$ = [
      9,
      n032,
      _MTGA,
      0,
      () => exports2.ModifyTargetGroupAttributesInput$,
      () => exports2.ModifyTargetGroupAttributesOutput$
    ];
    exports2.ModifyTrustStore$ = [
      9,
      n032,
      _MTS,
      0,
      () => exports2.ModifyTrustStoreInput$,
      () => exports2.ModifyTrustStoreOutput$
    ];
    exports2.RegisterTargets$ = [
      9,
      n032,
      _RTeg,
      0,
      () => exports2.RegisterTargetsInput$,
      () => exports2.RegisterTargetsOutput$
    ];
    exports2.RemoveListenerCertificates$ = [
      9,
      n032,
      _RLC,
      0,
      () => exports2.RemoveListenerCertificatesInput$,
      () => exports2.RemoveListenerCertificatesOutput$
    ];
    exports2.RemoveTags$ = [
      9,
      n032,
      _RTem,
      0,
      () => exports2.RemoveTagsInput$,
      () => exports2.RemoveTagsOutput$
    ];
    exports2.RemoveTrustStoreRevocations$ = [
      9,
      n032,
      _RTSR,
      0,
      () => exports2.RemoveTrustStoreRevocationsInput$,
      () => exports2.RemoveTrustStoreRevocationsOutput$
    ];
    exports2.SetIpAddressType$ = [
      9,
      n032,
      _SIAT,
      0,
      () => exports2.SetIpAddressTypeInput$,
      () => exports2.SetIpAddressTypeOutput$
    ];
    exports2.SetRulePriorities$ = [
      9,
      n032,
      _SRP,
      0,
      () => exports2.SetRulePrioritiesInput$,
      () => exports2.SetRulePrioritiesOutput$
    ];
    exports2.SetSecurityGroups$ = [
      9,
      n032,
      _SSG,
      0,
      () => exports2.SetSecurityGroupsInput$,
      () => exports2.SetSecurityGroupsOutput$
    ];
    exports2.SetSubnets$ = [
      9,
      n032,
      _SS,
      0,
      () => exports2.SetSubnetsInput$,
      () => exports2.SetSubnetsOutput$
    ];
  }
});

// ../../node_modules/@aws-sdk/client-elastic-load-balancing-v2/dist-cjs/runtimeConfig.shared.js
var require_runtimeConfig_shared14 = __commonJS({
  "../../node_modules/@aws-sdk/client-elastic-load-balancing-v2/dist-cjs/runtimeConfig.shared.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var protocols_1 = (init_protocols8(), __toCommonJS(protocols_exports5));
    var smithy_client_1 = require_dist_cjs34();
    var url_parser_1 = require_dist_cjs18();
    var util_base64_1 = require_dist_cjs10();
    var util_utf8_1 = require_dist_cjs9();
    var httpAuthSchemeProvider_1 = require_httpAuthSchemeProvider13();
    var endpointResolver_1 = require_endpointResolver13();
    var schemas_0_1 = require_schemas_013();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2015-12-01",
        base64Decoder: config2?.base64Decoder ?? util_base64_1.fromBase64,
        base64Encoder: config2?.base64Encoder ?? util_base64_1.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? endpointResolver_1.defaultEndpointResolver,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? httpAuthSchemeProvider_1.defaultElasticLoadBalancingV2HttpAuthSchemeProvider,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new httpAuthSchemes_1.AwsSdkSigV4Signer()
          }
        ],
        logger: config2?.logger ?? new smithy_client_1.NoOpLogger(),
        protocol: config2?.protocol ?? protocols_1.AwsQueryProtocol,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.elasticloadbalancingv2",
          errorTypeRegistries: schemas_0_1.errorTypeRegistries,
          xmlNamespace: "http://elasticloadbalancing.amazonaws.com/doc/2015-12-01/",
          version: "2015-12-01",
          serviceTarget: "ElasticLoadBalancing_v10"
        },
        serviceId: config2?.serviceId ?? "Elastic Load Balancing v2",
        urlParser: config2?.urlParser ?? url_parser_1.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? util_utf8_1.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? util_utf8_1.toUtf8
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-elastic-load-balancing-v2/dist-cjs/runtimeConfig.js
var require_runtimeConfig14 = __commonJS({
  "../../node_modules/@aws-sdk/client-elastic-load-balancing-v2/dist-cjs/runtimeConfig.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var package_json_1 = tslib_1.__importDefault(require_package13());
    var client_1 = (init_client8(), __toCommonJS(client_exports7));
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var credential_provider_node_1 = require_dist_cjs122();
    var util_user_agent_node_1 = require_dist_cjs113();
    var config_resolver_1 = require_dist_cjs25();
    var hash_node_1 = require_dist_cjs44();
    var middleware_retry_1 = require_dist_cjs106();
    var node_config_provider_1 = require_dist_cjs29();
    var node_http_handler_1 = require_dist_cjs13();
    var smithy_client_1 = require_dist_cjs34();
    var util_body_length_node_1 = require_dist_cjs45();
    var util_defaults_mode_node_1 = require_dist_cjs46();
    var util_retry_1 = require_dist_cjs22();
    var runtimeConfig_shared_1 = require_runtimeConfig_shared14();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      (0, smithy_client_1.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, util_defaults_mode_node_1.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(smithy_client_1.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = (0, runtimeConfig_shared_1.getRuntimeConfig)(config2);
      (0, client_1.emitWarningIfUnsupportedVersion)(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, node_config_provider_1.loadConfig)(httpAuthSchemes_1.NODE_AUTH_SCHEME_PREFERENCE_OPTIONS, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? util_body_length_node_1.calculateBodyLength,
        credentialDefaultProvider: config2?.credentialDefaultProvider ?? credential_provider_node_1.defaultProvider,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, util_user_agent_node_1.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_json_1.default.version }),
        maxAttempts: config2?.maxAttempts ?? (0, node_config_provider_1.loadConfig)(middleware_retry_1.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_REGION_CONFIG_OPTIONS, { ...config_resolver_1.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: node_http_handler_1.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, node_config_provider_1.loadConfig)({
          ...middleware_retry_1.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || util_retry_1.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? hash_node_1.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? node_http_handler_1.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, node_config_provider_1.loadConfig)(util_user_agent_node_1.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-elastic-load-balancing-v2/dist-cjs/index.js
var require_dist_cjs165 = __commonJS({
  "../../node_modules/@aws-sdk/client-elastic-load-balancing-v2/dist-cjs/index.js"(exports2) {
    "use strict";
    var middlewareHostHeader = require_dist_cjs3();
    var middlewareLogger = require_dist_cjs4();
    var middlewareRecursionDetection = require_dist_cjs5();
    var middlewareUserAgent = require_dist_cjs104();
    var configResolver = require_dist_cjs25();
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var schema = (init_schema4(), __toCommonJS(schema_exports));
    var middlewareContentLength = require_dist_cjs26();
    var middlewareEndpoint = require_dist_cjs31();
    var middlewareRetry = require_dist_cjs106();
    var smithyClient = require_dist_cjs34();
    var httpAuthSchemeProvider = require_httpAuthSchemeProvider13();
    var runtimeConfig = require_runtimeConfig14();
    var regionConfigResolver = require_dist_cjs48();
    var protocolHttp = require_dist_cjs2();
    var schemas_0 = require_schemas_013();
    var utilWaiter = require_dist_cjs156();
    var errors = require_errors12();
    var ElasticLoadBalancingV2ServiceException = require_ElasticLoadBalancingV2ServiceException();
    var resolveClientEndpointParameters32 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "elasticloadbalancing"
      });
    }, "resolveClientEndpointParameters");
    var commonParams32 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
    var getHttpAuthExtensionConfiguration32 = /* @__PURE__ */ __name((runtimeConfig2) => {
      const _httpAuthSchemes = runtimeConfig2.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig2.httpAuthSchemeProvider;
      let _credentials = runtimeConfig2.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider2) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider2;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    var resolveHttpAuthRuntimeConfig32 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
    var resolveRuntimeExtensions32 = /* @__PURE__ */ __name((runtimeConfig2, extensions) => {
      const extensionConfiguration = Object.assign(regionConfigResolver.getAwsRegionExtensionConfiguration(runtimeConfig2), smithyClient.getDefaultExtensionConfiguration(runtimeConfig2), protocolHttp.getHttpHandlerExtensionConfiguration(runtimeConfig2), getHttpAuthExtensionConfiguration32(runtimeConfig2));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig2, regionConfigResolver.resolveAwsRegionExtensionConfiguration(extensionConfiguration), smithyClient.resolveDefaultRuntimeConfig(extensionConfiguration), protocolHttp.resolveHttpHandlerRuntimeConfig(extensionConfiguration), resolveHttpAuthRuntimeConfig32(extensionConfiguration));
    }, "resolveRuntimeExtensions");
    var ElasticLoadBalancingV2Client2 = class extends smithyClient.Client {
      static {
        __name(this, "ElasticLoadBalancingV2Client");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = runtimeConfig.getRuntimeConfig(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters32(_config_0);
        const _config_2 = middlewareUserAgent.resolveUserAgentConfig(_config_1);
        const _config_3 = middlewareRetry.resolveRetryConfig(_config_2);
        const _config_4 = configResolver.resolveRegionConfig(_config_3);
        const _config_5 = middlewareHostHeader.resolveHostHeaderConfig(_config_4);
        const _config_6 = middlewareEndpoint.resolveEndpointConfig(_config_5);
        const _config_7 = httpAuthSchemeProvider.resolveHttpAuthSchemeConfig(_config_6);
        const _config_8 = resolveRuntimeExtensions32(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(schema.getSchemaSerdePlugin(this.config));
        this.middlewareStack.use(middlewareUserAgent.getUserAgentPlugin(this.config));
        this.middlewareStack.use(middlewareRetry.getRetryPlugin(this.config));
        this.middlewareStack.use(middlewareContentLength.getContentLengthPlugin(this.config));
        this.middlewareStack.use(middlewareHostHeader.getHostHeaderPlugin(this.config));
        this.middlewareStack.use(middlewareLogger.getLoggerPlugin(this.config));
        this.middlewareStack.use(middlewareRecursionDetection.getRecursionDetectionPlugin(this.config));
        this.middlewareStack.use(core.getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: httpAuthSchemeProvider.defaultElasticLoadBalancingV2HttpAuthSchemeParametersProvider,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new core.DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(core.getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
    var AddListenerCertificatesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "AddListenerCertificates", {}).n("ElasticLoadBalancingV2Client", "AddListenerCertificatesCommand").sc(schemas_0.AddListenerCertificates$).build() {
      static {
        __name(this, "AddListenerCertificatesCommand");
      }
    };
    var AddTagsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "AddTags", {}).n("ElasticLoadBalancingV2Client", "AddTagsCommand").sc(schemas_0.AddTags$).build() {
      static {
        __name(this, "AddTagsCommand");
      }
    };
    var AddTrustStoreRevocationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "AddTrustStoreRevocations", {}).n("ElasticLoadBalancingV2Client", "AddTrustStoreRevocationsCommand").sc(schemas_0.AddTrustStoreRevocations$).build() {
      static {
        __name(this, "AddTrustStoreRevocationsCommand");
      }
    };
    var CreateListenerCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "CreateListener", {}).n("ElasticLoadBalancingV2Client", "CreateListenerCommand").sc(schemas_0.CreateListener$).build() {
      static {
        __name(this, "CreateListenerCommand");
      }
    };
    var CreateLoadBalancerCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "CreateLoadBalancer", {}).n("ElasticLoadBalancingV2Client", "CreateLoadBalancerCommand").sc(schemas_0.CreateLoadBalancer$).build() {
      static {
        __name(this, "CreateLoadBalancerCommand");
      }
    };
    var CreateRuleCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "CreateRule", {}).n("ElasticLoadBalancingV2Client", "CreateRuleCommand").sc(schemas_0.CreateRule$).build() {
      static {
        __name(this, "CreateRuleCommand");
      }
    };
    var CreateTargetGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "CreateTargetGroup", {}).n("ElasticLoadBalancingV2Client", "CreateTargetGroupCommand").sc(schemas_0.CreateTargetGroup$).build() {
      static {
        __name(this, "CreateTargetGroupCommand");
      }
    };
    var CreateTrustStoreCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "CreateTrustStore", {}).n("ElasticLoadBalancingV2Client", "CreateTrustStoreCommand").sc(schemas_0.CreateTrustStore$).build() {
      static {
        __name(this, "CreateTrustStoreCommand");
      }
    };
    var DeleteListenerCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "DeleteListener", {}).n("ElasticLoadBalancingV2Client", "DeleteListenerCommand").sc(schemas_0.DeleteListener$).build() {
      static {
        __name(this, "DeleteListenerCommand");
      }
    };
    var DeleteLoadBalancerCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "DeleteLoadBalancer", {}).n("ElasticLoadBalancingV2Client", "DeleteLoadBalancerCommand").sc(schemas_0.DeleteLoadBalancer$).build() {
      static {
        __name(this, "DeleteLoadBalancerCommand");
      }
    };
    var DeleteRuleCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "DeleteRule", {}).n("ElasticLoadBalancingV2Client", "DeleteRuleCommand").sc(schemas_0.DeleteRule$).build() {
      static {
        __name(this, "DeleteRuleCommand");
      }
    };
    var DeleteSharedTrustStoreAssociationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "DeleteSharedTrustStoreAssociation", {}).n("ElasticLoadBalancingV2Client", "DeleteSharedTrustStoreAssociationCommand").sc(schemas_0.DeleteSharedTrustStoreAssociation$).build() {
      static {
        __name(this, "DeleteSharedTrustStoreAssociationCommand");
      }
    };
    var DeleteTargetGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "DeleteTargetGroup", {}).n("ElasticLoadBalancingV2Client", "DeleteTargetGroupCommand").sc(schemas_0.DeleteTargetGroup$).build() {
      static {
        __name(this, "DeleteTargetGroupCommand");
      }
    };
    var DeleteTrustStoreCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "DeleteTrustStore", {}).n("ElasticLoadBalancingV2Client", "DeleteTrustStoreCommand").sc(schemas_0.DeleteTrustStore$).build() {
      static {
        __name(this, "DeleteTrustStoreCommand");
      }
    };
    var DeregisterTargetsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "DeregisterTargets", {}).n("ElasticLoadBalancingV2Client", "DeregisterTargetsCommand").sc(schemas_0.DeregisterTargets$).build() {
      static {
        __name(this, "DeregisterTargetsCommand");
      }
    };
    var DescribeAccountLimitsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "DescribeAccountLimits", {}).n("ElasticLoadBalancingV2Client", "DescribeAccountLimitsCommand").sc(schemas_0.DescribeAccountLimits$).build() {
      static {
        __name(this, "DescribeAccountLimitsCommand");
      }
    };
    var DescribeCapacityReservationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "DescribeCapacityReservation", {}).n("ElasticLoadBalancingV2Client", "DescribeCapacityReservationCommand").sc(schemas_0.DescribeCapacityReservation$).build() {
      static {
        __name(this, "DescribeCapacityReservationCommand");
      }
    };
    var DescribeListenerAttributesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "DescribeListenerAttributes", {}).n("ElasticLoadBalancingV2Client", "DescribeListenerAttributesCommand").sc(schemas_0.DescribeListenerAttributes$).build() {
      static {
        __name(this, "DescribeListenerAttributesCommand");
      }
    };
    var DescribeListenerCertificatesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "DescribeListenerCertificates", {}).n("ElasticLoadBalancingV2Client", "DescribeListenerCertificatesCommand").sc(schemas_0.DescribeListenerCertificates$).build() {
      static {
        __name(this, "DescribeListenerCertificatesCommand");
      }
    };
    var DescribeListenersCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "DescribeListeners", {}).n("ElasticLoadBalancingV2Client", "DescribeListenersCommand").sc(schemas_0.DescribeListeners$).build() {
      static {
        __name(this, "DescribeListenersCommand");
      }
    };
    var DescribeLoadBalancerAttributesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "DescribeLoadBalancerAttributes", {}).n("ElasticLoadBalancingV2Client", "DescribeLoadBalancerAttributesCommand").sc(schemas_0.DescribeLoadBalancerAttributes$).build() {
      static {
        __name(this, "DescribeLoadBalancerAttributesCommand");
      }
    };
    var DescribeLoadBalancersCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "DescribeLoadBalancers", {}).n("ElasticLoadBalancingV2Client", "DescribeLoadBalancersCommand").sc(schemas_0.DescribeLoadBalancers$).build() {
      static {
        __name(this, "DescribeLoadBalancersCommand");
      }
    };
    var DescribeRulesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "DescribeRules", {}).n("ElasticLoadBalancingV2Client", "DescribeRulesCommand").sc(schemas_0.DescribeRules$).build() {
      static {
        __name(this, "DescribeRulesCommand");
      }
    };
    var DescribeSSLPoliciesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "DescribeSSLPolicies", {}).n("ElasticLoadBalancingV2Client", "DescribeSSLPoliciesCommand").sc(schemas_0.DescribeSSLPolicies$).build() {
      static {
        __name(this, "DescribeSSLPoliciesCommand");
      }
    };
    var DescribeTagsCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "DescribeTags", {}).n("ElasticLoadBalancingV2Client", "DescribeTagsCommand").sc(schemas_0.DescribeTags$).build() {
      static {
        __name(this, "DescribeTagsCommand");
      }
    };
    var DescribeTargetGroupAttributesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "DescribeTargetGroupAttributes", {}).n("ElasticLoadBalancingV2Client", "DescribeTargetGroupAttributesCommand").sc(schemas_0.DescribeTargetGroupAttributes$).build() {
      static {
        __name(this, "DescribeTargetGroupAttributesCommand");
      }
    };
    var DescribeTargetGroupsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "DescribeTargetGroups", {}).n("ElasticLoadBalancingV2Client", "DescribeTargetGroupsCommand").sc(schemas_0.DescribeTargetGroups$).build() {
      static {
        __name(this, "DescribeTargetGroupsCommand");
      }
    };
    var DescribeTargetHealthCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "DescribeTargetHealth", {}).n("ElasticLoadBalancingV2Client", "DescribeTargetHealthCommand").sc(schemas_0.DescribeTargetHealth$).build() {
      static {
        __name(this, "DescribeTargetHealthCommand");
      }
    };
    var DescribeTrustStoreAssociationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "DescribeTrustStoreAssociations", {}).n("ElasticLoadBalancingV2Client", "DescribeTrustStoreAssociationsCommand").sc(schemas_0.DescribeTrustStoreAssociations$).build() {
      static {
        __name(this, "DescribeTrustStoreAssociationsCommand");
      }
    };
    var DescribeTrustStoreRevocationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "DescribeTrustStoreRevocations", {}).n("ElasticLoadBalancingV2Client", "DescribeTrustStoreRevocationsCommand").sc(schemas_0.DescribeTrustStoreRevocations$).build() {
      static {
        __name(this, "DescribeTrustStoreRevocationsCommand");
      }
    };
    var DescribeTrustStoresCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "DescribeTrustStores", {}).n("ElasticLoadBalancingV2Client", "DescribeTrustStoresCommand").sc(schemas_0.DescribeTrustStores$).build() {
      static {
        __name(this, "DescribeTrustStoresCommand");
      }
    };
    var GetResourcePolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "GetResourcePolicy", {}).n("ElasticLoadBalancingV2Client", "GetResourcePolicyCommand").sc(schemas_0.GetResourcePolicy$).build() {
      static {
        __name(this, "GetResourcePolicyCommand");
      }
    };
    var GetTrustStoreCaCertificatesBundleCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "GetTrustStoreCaCertificatesBundle", {}).n("ElasticLoadBalancingV2Client", "GetTrustStoreCaCertificatesBundleCommand").sc(schemas_0.GetTrustStoreCaCertificatesBundle$).build() {
      static {
        __name(this, "GetTrustStoreCaCertificatesBundleCommand");
      }
    };
    var GetTrustStoreRevocationContentCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "GetTrustStoreRevocationContent", {}).n("ElasticLoadBalancingV2Client", "GetTrustStoreRevocationContentCommand").sc(schemas_0.GetTrustStoreRevocationContent$).build() {
      static {
        __name(this, "GetTrustStoreRevocationContentCommand");
      }
    };
    var ModifyCapacityReservationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "ModifyCapacityReservation", {}).n("ElasticLoadBalancingV2Client", "ModifyCapacityReservationCommand").sc(schemas_0.ModifyCapacityReservation$).build() {
      static {
        __name(this, "ModifyCapacityReservationCommand");
      }
    };
    var ModifyIpPoolsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "ModifyIpPools", {}).n("ElasticLoadBalancingV2Client", "ModifyIpPoolsCommand").sc(schemas_0.ModifyIpPools$).build() {
      static {
        __name(this, "ModifyIpPoolsCommand");
      }
    };
    var ModifyListenerAttributesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "ModifyListenerAttributes", {}).n("ElasticLoadBalancingV2Client", "ModifyListenerAttributesCommand").sc(schemas_0.ModifyListenerAttributes$).build() {
      static {
        __name(this, "ModifyListenerAttributesCommand");
      }
    };
    var ModifyListenerCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "ModifyListener", {}).n("ElasticLoadBalancingV2Client", "ModifyListenerCommand").sc(schemas_0.ModifyListener$).build() {
      static {
        __name(this, "ModifyListenerCommand");
      }
    };
    var ModifyLoadBalancerAttributesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "ModifyLoadBalancerAttributes", {}).n("ElasticLoadBalancingV2Client", "ModifyLoadBalancerAttributesCommand").sc(schemas_0.ModifyLoadBalancerAttributes$).build() {
      static {
        __name(this, "ModifyLoadBalancerAttributesCommand");
      }
    };
    var ModifyRuleCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "ModifyRule", {}).n("ElasticLoadBalancingV2Client", "ModifyRuleCommand").sc(schemas_0.ModifyRule$).build() {
      static {
        __name(this, "ModifyRuleCommand");
      }
    };
    var ModifyTargetGroupAttributesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "ModifyTargetGroupAttributes", {}).n("ElasticLoadBalancingV2Client", "ModifyTargetGroupAttributesCommand").sc(schemas_0.ModifyTargetGroupAttributes$).build() {
      static {
        __name(this, "ModifyTargetGroupAttributesCommand");
      }
    };
    var ModifyTargetGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "ModifyTargetGroup", {}).n("ElasticLoadBalancingV2Client", "ModifyTargetGroupCommand").sc(schemas_0.ModifyTargetGroup$).build() {
      static {
        __name(this, "ModifyTargetGroupCommand");
      }
    };
    var ModifyTrustStoreCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "ModifyTrustStore", {}).n("ElasticLoadBalancingV2Client", "ModifyTrustStoreCommand").sc(schemas_0.ModifyTrustStore$).build() {
      static {
        __name(this, "ModifyTrustStoreCommand");
      }
    };
    var RegisterTargetsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "RegisterTargets", {}).n("ElasticLoadBalancingV2Client", "RegisterTargetsCommand").sc(schemas_0.RegisterTargets$).build() {
      static {
        __name(this, "RegisterTargetsCommand");
      }
    };
    var RemoveListenerCertificatesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "RemoveListenerCertificates", {}).n("ElasticLoadBalancingV2Client", "RemoveListenerCertificatesCommand").sc(schemas_0.RemoveListenerCertificates$).build() {
      static {
        __name(this, "RemoveListenerCertificatesCommand");
      }
    };
    var RemoveTagsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "RemoveTags", {}).n("ElasticLoadBalancingV2Client", "RemoveTagsCommand").sc(schemas_0.RemoveTags$).build() {
      static {
        __name(this, "RemoveTagsCommand");
      }
    };
    var RemoveTrustStoreRevocationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "RemoveTrustStoreRevocations", {}).n("ElasticLoadBalancingV2Client", "RemoveTrustStoreRevocationsCommand").sc(schemas_0.RemoveTrustStoreRevocations$).build() {
      static {
        __name(this, "RemoveTrustStoreRevocationsCommand");
      }
    };
    var SetIpAddressTypeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "SetIpAddressType", {}).n("ElasticLoadBalancingV2Client", "SetIpAddressTypeCommand").sc(schemas_0.SetIpAddressType$).build() {
      static {
        __name(this, "SetIpAddressTypeCommand");
      }
    };
    var SetRulePrioritiesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "SetRulePriorities", {}).n("ElasticLoadBalancingV2Client", "SetRulePrioritiesCommand").sc(schemas_0.SetRulePriorities$).build() {
      static {
        __name(this, "SetRulePrioritiesCommand");
      }
    };
    var SetSecurityGroupsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "SetSecurityGroups", {}).n("ElasticLoadBalancingV2Client", "SetSecurityGroupsCommand").sc(schemas_0.SetSecurityGroups$).build() {
      static {
        __name(this, "SetSecurityGroupsCommand");
      }
    };
    var SetSubnetsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("ElasticLoadBalancing_v10", "SetSubnets", {}).n("ElasticLoadBalancingV2Client", "SetSubnetsCommand").sc(schemas_0.SetSubnets$).build() {
      static {
        __name(this, "SetSubnetsCommand");
      }
    };
    var paginateDescribeAccountLimits = core.createPaginator(ElasticLoadBalancingV2Client2, DescribeAccountLimitsCommand, "Marker", "NextMarker", "");
    var paginateDescribeListenerCertificates = core.createPaginator(ElasticLoadBalancingV2Client2, DescribeListenerCertificatesCommand, "Marker", "NextMarker", "");
    var paginateDescribeListeners2 = core.createPaginator(ElasticLoadBalancingV2Client2, DescribeListenersCommand2, "Marker", "NextMarker", "");
    var paginateDescribeLoadBalancers2 = core.createPaginator(ElasticLoadBalancingV2Client2, DescribeLoadBalancersCommand2, "Marker", "NextMarker", "");
    var paginateDescribeRules = core.createPaginator(ElasticLoadBalancingV2Client2, DescribeRulesCommand, "Marker", "NextMarker", "");
    var paginateDescribeTargetGroups = core.createPaginator(ElasticLoadBalancingV2Client2, DescribeTargetGroupsCommand, "Marker", "NextMarker", "");
    var paginateDescribeTrustStoreAssociations = core.createPaginator(ElasticLoadBalancingV2Client2, DescribeTrustStoreAssociationsCommand, "Marker", "NextMarker", "PageSize");
    var paginateDescribeTrustStoreRevocations = core.createPaginator(ElasticLoadBalancingV2Client2, DescribeTrustStoreRevocationsCommand, "Marker", "NextMarker", "PageSize");
    var paginateDescribeTrustStores = core.createPaginator(ElasticLoadBalancingV2Client2, DescribeTrustStoresCommand, "Marker", "NextMarker", "PageSize");
    var checkState$4 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeLoadBalancersCommand2(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.LoadBalancers);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State.Code;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "active";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.LoadBalancers);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State.Code;
            });
            return projection_3;
          }, "returnComparator");
          for (let anyStringEq_4 of returnComparator()) {
            if (anyStringEq_4 == "provisioning") {
              return { state: utilWaiter.WaiterState.RETRY, reason };
            }
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "LoadBalancerNotFoundException") {
          return { state: utilWaiter.WaiterState.RETRY, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$4");
    var waitForLoadBalancerAvailable = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$4);
    }, "waitForLoadBalancerAvailable");
    var waitUntilLoadBalancerAvailable = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$4);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilLoadBalancerAvailable");
    var checkState$3 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeLoadBalancersCommand2(input));
        reason = result2;
        return { state: utilWaiter.WaiterState.SUCCESS, reason };
      } catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "LoadBalancerNotFoundException") {
          return { state: utilWaiter.WaiterState.RETRY, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$3");
    var waitForLoadBalancerExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$3);
    }, "waitForLoadBalancerExists");
    var waitUntilLoadBalancerExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$3);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilLoadBalancerExists");
    var checkState$2 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeLoadBalancersCommand2(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.LoadBalancers);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.State.Code;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "active";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.RETRY, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "LoadBalancerNotFoundException") {
          return { state: utilWaiter.WaiterState.SUCCESS, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$2");
    var waitForLoadBalancersDeleted = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$2);
    }, "waitForLoadBalancersDeleted");
    var waitUntilLoadBalancersDeleted = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$2);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilLoadBalancersDeleted");
    var checkState$1 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeTargetHealthCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.TargetHealthDescriptions);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.TargetHealth.State;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "unused";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "InvalidTargetException") {
          return { state: utilWaiter.WaiterState.SUCCESS, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$1");
    var waitForTargetDeregistered = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$1);
    }, "waitForTargetDeregistered");
    var waitUntilTargetDeregistered = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$1);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilTargetDeregistered");
    var checkState = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new DescribeTargetHealthCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            let flat_1 = [].concat(...result2.TargetHealthDescriptions);
            let projection_3 = flat_1.map((element_2) => {
              return element_2.TargetHealth.State;
            });
            return projection_3;
          }, "returnComparator");
          let allStringEq_5 = returnComparator().length > 0;
          for (let element_4 of returnComparator()) {
            allStringEq_5 = allStringEq_5 && element_4 == "healthy";
          }
          if (allStringEq_5) {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "InvalidInstance") {
          return { state: utilWaiter.WaiterState.RETRY, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState");
    var waitForTargetInService = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState);
    }, "waitForTargetInService");
    var waitUntilTargetInService = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 15, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilTargetInService");
    var commands32 = {
      AddListenerCertificatesCommand,
      AddTagsCommand,
      AddTrustStoreRevocationsCommand,
      CreateListenerCommand,
      CreateLoadBalancerCommand,
      CreateRuleCommand,
      CreateTargetGroupCommand,
      CreateTrustStoreCommand,
      DeleteListenerCommand,
      DeleteLoadBalancerCommand,
      DeleteRuleCommand,
      DeleteSharedTrustStoreAssociationCommand,
      DeleteTargetGroupCommand,
      DeleteTrustStoreCommand,
      DeregisterTargetsCommand,
      DescribeAccountLimitsCommand,
      DescribeCapacityReservationCommand,
      DescribeListenerAttributesCommand,
      DescribeListenerCertificatesCommand,
      DescribeListenersCommand: DescribeListenersCommand2,
      DescribeLoadBalancerAttributesCommand,
      DescribeLoadBalancersCommand: DescribeLoadBalancersCommand2,
      DescribeRulesCommand,
      DescribeSSLPoliciesCommand,
      DescribeTagsCommand: DescribeTagsCommand2,
      DescribeTargetGroupAttributesCommand,
      DescribeTargetGroupsCommand,
      DescribeTargetHealthCommand,
      DescribeTrustStoreAssociationsCommand,
      DescribeTrustStoreRevocationsCommand,
      DescribeTrustStoresCommand,
      GetResourcePolicyCommand,
      GetTrustStoreCaCertificatesBundleCommand,
      GetTrustStoreRevocationContentCommand,
      ModifyCapacityReservationCommand,
      ModifyIpPoolsCommand,
      ModifyListenerCommand,
      ModifyListenerAttributesCommand,
      ModifyLoadBalancerAttributesCommand,
      ModifyRuleCommand,
      ModifyTargetGroupCommand,
      ModifyTargetGroupAttributesCommand,
      ModifyTrustStoreCommand,
      RegisterTargetsCommand,
      RemoveListenerCertificatesCommand,
      RemoveTagsCommand,
      RemoveTrustStoreRevocationsCommand,
      SetIpAddressTypeCommand,
      SetRulePrioritiesCommand,
      SetSecurityGroupsCommand,
      SetSubnetsCommand
    };
    var paginators = {
      paginateDescribeAccountLimits,
      paginateDescribeListenerCertificates,
      paginateDescribeListeners: paginateDescribeListeners2,
      paginateDescribeLoadBalancers: paginateDescribeLoadBalancers2,
      paginateDescribeRules,
      paginateDescribeTargetGroups,
      paginateDescribeTrustStoreAssociations,
      paginateDescribeTrustStoreRevocations,
      paginateDescribeTrustStores
    };
    var waiters = {
      waitUntilLoadBalancerAvailable,
      waitUntilLoadBalancerExists,
      waitUntilLoadBalancersDeleted,
      waitUntilTargetDeregistered,
      waitUntilTargetInService
    };
    var ElasticLoadBalancingV2 = class extends ElasticLoadBalancingV2Client2 {
      static {
        __name(this, "ElasticLoadBalancingV2");
      }
    };
    smithyClient.createAggregatedClient(commands32, ElasticLoadBalancingV2, { paginators, waiters });
    var AuthenticateCognitoActionConditionalBehaviorEnum = {
      ALLOW: "allow",
      AUTHENTICATE: "authenticate",
      DENY: "deny"
    };
    var AuthenticateOidcActionConditionalBehaviorEnum = {
      ALLOW: "allow",
      AUTHENTICATE: "authenticate",
      DENY: "deny"
    };
    var JwtValidationActionAdditionalClaimFormatEnum = {
      SINGLE_STRING: "single-string",
      SPACE_SEPARATED_VALUES: "space-separated-values",
      STRING_ARRAY: "string-array"
    };
    var RedirectActionStatusCodeEnum = {
      HTTP_301: "HTTP_301",
      HTTP_302: "HTTP_302"
    };
    var ActionTypeEnum = {
      AUTHENTICATE_COGNITO: "authenticate-cognito",
      AUTHENTICATE_OIDC: "authenticate-oidc",
      FIXED_RESPONSE: "fixed-response",
      FORWARD: "forward",
      JWT_VALIDATION: "jwt-validation",
      REDIRECT: "redirect"
    };
    var RevocationType = {
      CRL: "CRL"
    };
    var TargetAdministrativeOverrideReasonEnum = {
      INTERNAL_ERROR: "AdministrativeOverride.Unknown",
      NO_OVERRIDE_ENGAGED: "AdministrativeOverride.NoOverride",
      ZONAL_SHIFT_DELEGATED_TO_DNS: "AdministrativeOverride.ZonalShiftDelegatedToDns",
      ZONAL_SHIFT_ENGAGED: "AdministrativeOverride.ZonalShiftActive"
    };
    var TargetAdministrativeOverrideStateEnum = {
      NO_OVERRIDE: "no_override",
      UNKNOWN: "unknown",
      ZONAL_SHIFT_ACTIVE: "zonal_shift_active",
      ZONAL_SHIFT_DELEGATED_TO_DNS: "zonal_shift_delegated_to_dns"
    };
    var AdvertiseTrustStoreCaNamesEnum = {
      off: "off",
      on: "on"
    };
    var MitigationInEffectEnum = {
      NO: "no",
      YES: "yes"
    };
    var AnomalyResultEnum = {
      ANOMALOUS: "anomalous",
      NORMAL: "normal"
    };
    var CapacityReservationStateEnum = {
      FAILED: "failed",
      PENDING: "pending",
      PROVISIONED: "provisioned",
      REBALANCING: "rebalancing"
    };
    var TrustStoreAssociationStatusEnum = {
      ACTIVE: "active",
      REMOVED: "removed"
    };
    var ProtocolEnum = {
      GENEVE: "GENEVE",
      HTTP: "HTTP",
      HTTPS: "HTTPS",
      QUIC: "QUIC",
      TCP: "TCP",
      TCP_QUIC: "TCP_QUIC",
      TCP_UDP: "TCP_UDP",
      TLS: "TLS",
      UDP: "UDP"
    };
    var EnablePrefixForIpv6SourceNatEnum = {
      OFF: "off",
      ON: "on"
    };
    var IpAddressType = {
      DUALSTACK: "dualstack",
      DUALSTACK_WITHOUT_PUBLIC_IPV4: "dualstack-without-public-ipv4",
      IPV4: "ipv4"
    };
    var LoadBalancerSchemeEnum = {
      INTERNAL: "internal",
      INTERNET_FACING: "internet-facing"
    };
    var LoadBalancerTypeEnum = {
      APPLICATION: "application",
      GATEWAY: "gateway",
      NETWORK: "network"
    };
    var LoadBalancerStateEnum = {
      ACTIVE: "active",
      ACTIVE_IMPAIRED: "active_impaired",
      FAILED: "failed",
      PROVISIONING: "provisioning"
    };
    var TransformTypeEnum = {
      HOST_HEADER_REWRITE: "host-header-rewrite",
      URL_REWRITE: "url-rewrite"
    };
    var TargetGroupIpAddressTypeEnum = {
      IPV4: "ipv4",
      IPV6: "ipv6"
    };
    var TargetTypeEnum = {
      ALB: "alb",
      INSTANCE: "instance",
      IP: "ip",
      LAMBDA: "lambda"
    };
    var TrustStoreStatus = {
      ACTIVE: "ACTIVE",
      CREATING: "CREATING"
    };
    var DescribeTargetHealthInputIncludeEnum = {
      ALL: "All",
      ANOMALY: "AnomalyDetection"
    };
    var TargetHealthReasonEnum = {
      DEREGISTRATION_IN_PROGRESS: "Target.DeregistrationInProgress",
      FAILED_HEALTH_CHECKS: "Target.FailedHealthChecks",
      HEALTH_CHECK_DISABLED: "Target.HealthCheckDisabled",
      INITIAL_HEALTH_CHECKING: "Elb.InitialHealthChecking",
      INTERNAL_ERROR: "Elb.InternalError",
      INVALID_STATE: "Target.InvalidState",
      IP_UNUSABLE: "Target.IpUnusable",
      NOT_IN_USE: "Target.NotInUse",
      NOT_REGISTERED: "Target.NotRegistered",
      REGISTRATION_IN_PROGRESS: "Elb.RegistrationInProgress",
      RESPONSE_CODE_MISMATCH: "Target.ResponseCodeMismatch",
      TIMEOUT: "Target.Timeout"
    };
    var TargetHealthStateEnum = {
      DRAINING: "draining",
      HEALTHY: "healthy",
      INITIAL: "initial",
      UNAVAILABLE: "unavailable",
      UNHEALTHY: "unhealthy",
      UNHEALTHY_DRAINING: "unhealthy.draining",
      UNUSED: "unused"
    };
    var RemoveIpamPoolEnum = {
      ipv4: "ipv4"
    };
    var EnforceSecurityGroupInboundRulesOnPrivateLinkTrafficEnum = {
      off: "off",
      on: "on"
    };
    exports2.$Command = smithyClient.Command;
    exports2.__Client = smithyClient.Client;
    exports2.ElasticLoadBalancingV2ServiceException = ElasticLoadBalancingV2ServiceException.ElasticLoadBalancingV2ServiceException;
    exports2.ActionTypeEnum = ActionTypeEnum;
    exports2.AddListenerCertificatesCommand = AddListenerCertificatesCommand;
    exports2.AddTagsCommand = AddTagsCommand;
    exports2.AddTrustStoreRevocationsCommand = AddTrustStoreRevocationsCommand;
    exports2.AdvertiseTrustStoreCaNamesEnum = AdvertiseTrustStoreCaNamesEnum;
    exports2.AnomalyResultEnum = AnomalyResultEnum;
    exports2.AuthenticateCognitoActionConditionalBehaviorEnum = AuthenticateCognitoActionConditionalBehaviorEnum;
    exports2.AuthenticateOidcActionConditionalBehaviorEnum = AuthenticateOidcActionConditionalBehaviorEnum;
    exports2.CapacityReservationStateEnum = CapacityReservationStateEnum;
    exports2.CreateListenerCommand = CreateListenerCommand;
    exports2.CreateLoadBalancerCommand = CreateLoadBalancerCommand;
    exports2.CreateRuleCommand = CreateRuleCommand;
    exports2.CreateTargetGroupCommand = CreateTargetGroupCommand;
    exports2.CreateTrustStoreCommand = CreateTrustStoreCommand;
    exports2.DeleteListenerCommand = DeleteListenerCommand;
    exports2.DeleteLoadBalancerCommand = DeleteLoadBalancerCommand;
    exports2.DeleteRuleCommand = DeleteRuleCommand;
    exports2.DeleteSharedTrustStoreAssociationCommand = DeleteSharedTrustStoreAssociationCommand;
    exports2.DeleteTargetGroupCommand = DeleteTargetGroupCommand;
    exports2.DeleteTrustStoreCommand = DeleteTrustStoreCommand;
    exports2.DeregisterTargetsCommand = DeregisterTargetsCommand;
    exports2.DescribeAccountLimitsCommand = DescribeAccountLimitsCommand;
    exports2.DescribeCapacityReservationCommand = DescribeCapacityReservationCommand;
    exports2.DescribeListenerAttributesCommand = DescribeListenerAttributesCommand;
    exports2.DescribeListenerCertificatesCommand = DescribeListenerCertificatesCommand;
    exports2.DescribeListenersCommand = DescribeListenersCommand2;
    exports2.DescribeLoadBalancerAttributesCommand = DescribeLoadBalancerAttributesCommand;
    exports2.DescribeLoadBalancersCommand = DescribeLoadBalancersCommand2;
    exports2.DescribeRulesCommand = DescribeRulesCommand;
    exports2.DescribeSSLPoliciesCommand = DescribeSSLPoliciesCommand;
    exports2.DescribeTagsCommand = DescribeTagsCommand2;
    exports2.DescribeTargetGroupAttributesCommand = DescribeTargetGroupAttributesCommand;
    exports2.DescribeTargetGroupsCommand = DescribeTargetGroupsCommand;
    exports2.DescribeTargetHealthCommand = DescribeTargetHealthCommand;
    exports2.DescribeTargetHealthInputIncludeEnum = DescribeTargetHealthInputIncludeEnum;
    exports2.DescribeTrustStoreAssociationsCommand = DescribeTrustStoreAssociationsCommand;
    exports2.DescribeTrustStoreRevocationsCommand = DescribeTrustStoreRevocationsCommand;
    exports2.DescribeTrustStoresCommand = DescribeTrustStoresCommand;
    exports2.ElasticLoadBalancingV2 = ElasticLoadBalancingV2;
    exports2.ElasticLoadBalancingV2Client = ElasticLoadBalancingV2Client2;
    exports2.EnablePrefixForIpv6SourceNatEnum = EnablePrefixForIpv6SourceNatEnum;
    exports2.EnforceSecurityGroupInboundRulesOnPrivateLinkTrafficEnum = EnforceSecurityGroupInboundRulesOnPrivateLinkTrafficEnum;
    exports2.GetResourcePolicyCommand = GetResourcePolicyCommand;
    exports2.GetTrustStoreCaCertificatesBundleCommand = GetTrustStoreCaCertificatesBundleCommand;
    exports2.GetTrustStoreRevocationContentCommand = GetTrustStoreRevocationContentCommand;
    exports2.IpAddressType = IpAddressType;
    exports2.JwtValidationActionAdditionalClaimFormatEnum = JwtValidationActionAdditionalClaimFormatEnum;
    exports2.LoadBalancerSchemeEnum = LoadBalancerSchemeEnum;
    exports2.LoadBalancerStateEnum = LoadBalancerStateEnum;
    exports2.LoadBalancerTypeEnum = LoadBalancerTypeEnum;
    exports2.MitigationInEffectEnum = MitigationInEffectEnum;
    exports2.ModifyCapacityReservationCommand = ModifyCapacityReservationCommand;
    exports2.ModifyIpPoolsCommand = ModifyIpPoolsCommand;
    exports2.ModifyListenerAttributesCommand = ModifyListenerAttributesCommand;
    exports2.ModifyListenerCommand = ModifyListenerCommand;
    exports2.ModifyLoadBalancerAttributesCommand = ModifyLoadBalancerAttributesCommand;
    exports2.ModifyRuleCommand = ModifyRuleCommand;
    exports2.ModifyTargetGroupAttributesCommand = ModifyTargetGroupAttributesCommand;
    exports2.ModifyTargetGroupCommand = ModifyTargetGroupCommand;
    exports2.ModifyTrustStoreCommand = ModifyTrustStoreCommand;
    exports2.ProtocolEnum = ProtocolEnum;
    exports2.RedirectActionStatusCodeEnum = RedirectActionStatusCodeEnum;
    exports2.RegisterTargetsCommand = RegisterTargetsCommand;
    exports2.RemoveIpamPoolEnum = RemoveIpamPoolEnum;
    exports2.RemoveListenerCertificatesCommand = RemoveListenerCertificatesCommand;
    exports2.RemoveTagsCommand = RemoveTagsCommand;
    exports2.RemoveTrustStoreRevocationsCommand = RemoveTrustStoreRevocationsCommand;
    exports2.RevocationType = RevocationType;
    exports2.SetIpAddressTypeCommand = SetIpAddressTypeCommand;
    exports2.SetRulePrioritiesCommand = SetRulePrioritiesCommand;
    exports2.SetSecurityGroupsCommand = SetSecurityGroupsCommand;
    exports2.SetSubnetsCommand = SetSubnetsCommand;
    exports2.TargetAdministrativeOverrideReasonEnum = TargetAdministrativeOverrideReasonEnum;
    exports2.TargetAdministrativeOverrideStateEnum = TargetAdministrativeOverrideStateEnum;
    exports2.TargetGroupIpAddressTypeEnum = TargetGroupIpAddressTypeEnum;
    exports2.TargetHealthReasonEnum = TargetHealthReasonEnum;
    exports2.TargetHealthStateEnum = TargetHealthStateEnum;
    exports2.TargetTypeEnum = TargetTypeEnum;
    exports2.TransformTypeEnum = TransformTypeEnum;
    exports2.TrustStoreAssociationStatusEnum = TrustStoreAssociationStatusEnum;
    exports2.TrustStoreStatus = TrustStoreStatus;
    exports2.paginateDescribeAccountLimits = paginateDescribeAccountLimits;
    exports2.paginateDescribeListenerCertificates = paginateDescribeListenerCertificates;
    exports2.paginateDescribeListeners = paginateDescribeListeners2;
    exports2.paginateDescribeLoadBalancers = paginateDescribeLoadBalancers2;
    exports2.paginateDescribeRules = paginateDescribeRules;
    exports2.paginateDescribeTargetGroups = paginateDescribeTargetGroups;
    exports2.paginateDescribeTrustStoreAssociations = paginateDescribeTrustStoreAssociations;
    exports2.paginateDescribeTrustStoreRevocations = paginateDescribeTrustStoreRevocations;
    exports2.paginateDescribeTrustStores = paginateDescribeTrustStores;
    exports2.waitForLoadBalancerAvailable = waitForLoadBalancerAvailable;
    exports2.waitForLoadBalancerExists = waitForLoadBalancerExists;
    exports2.waitForLoadBalancersDeleted = waitForLoadBalancersDeleted;
    exports2.waitForTargetDeregistered = waitForTargetDeregistered;
    exports2.waitForTargetInService = waitForTargetInService;
    exports2.waitUntilLoadBalancerAvailable = waitUntilLoadBalancerAvailable;
    exports2.waitUntilLoadBalancerExists = waitUntilLoadBalancerExists;
    exports2.waitUntilLoadBalancersDeleted = waitUntilLoadBalancersDeleted;
    exports2.waitUntilTargetDeregistered = waitUntilTargetDeregistered;
    exports2.waitUntilTargetInService = waitUntilTargetInService;
    Object.prototype.hasOwnProperty.call(schemas_0, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: schemas_0["__proto__"]
    });
    Object.keys(schemas_0).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = schemas_0[k32];
    });
    Object.prototype.hasOwnProperty.call(errors, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: errors["__proto__"]
    });
    Object.keys(errors).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = errors[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-iam/dist-cjs/auth/httpAuthSchemeProvider.js
var require_httpAuthSchemeProvider14 = __commonJS({
  "../../node_modules/@aws-sdk/client-iam/dist-cjs/auth/httpAuthSchemeProvider.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.resolveHttpAuthSchemeConfig = exports2.defaultIAMHttpAuthSchemeProvider = exports2.defaultIAMHttpAuthSchemeParametersProvider = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var util_middleware_1 = require_dist_cjs6();
    var defaultIAMHttpAuthSchemeParametersProvider = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, util_middleware_1.getSmithyContext)(context).operation,
        region: await (0, util_middleware_1.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultIAMHttpAuthSchemeParametersProvider");
    exports2.defaultIAMHttpAuthSchemeParametersProvider = defaultIAMHttpAuthSchemeParametersProvider;
    function createAwsAuthSigv4HttpAuthOption32(authParameters) {
      return {
        schemeId: "aws.auth#sigv4",
        signingProperties: {
          name: "iam",
          region: authParameters.region
        },
        propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
          signingProperties: {
            config: config2,
            context
          }
        }), "propertiesExtractor")
      };
    }
    __name(createAwsAuthSigv4HttpAuthOption32, "createAwsAuthSigv4HttpAuthOption");
    var defaultIAMHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption32(authParameters));
        }
      }
      return options;
    }, "defaultIAMHttpAuthSchemeProvider");
    exports2.defaultIAMHttpAuthSchemeProvider = defaultIAMHttpAuthSchemeProvider;
    var resolveHttpAuthSchemeConfig32 = /* @__PURE__ */ __name((config2) => {
      const config_0 = (0, httpAuthSchemes_1.resolveAwsSdkSigV4Config)(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, util_middleware_1.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
    exports2.resolveHttpAuthSchemeConfig = resolveHttpAuthSchemeConfig32;
  }
});

// ../../node_modules/@aws-sdk/client-iam/package.json
var require_package14 = __commonJS({
  "../../node_modules/@aws-sdk/client-iam/package.json"(exports2, module2) {
    module2.exports = {
      name: "@aws-sdk/client-iam",
      description: "AWS SDK for JavaScript Iam Client for Node.js, Browser and React Native",
      version: "3.1036.0",
      scripts: {
        build: "concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline client-iam",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        "extract:docs": "api-extractor run --local",
        "generate:client": "node ../../scripts/generate-clients/single-service --solo iam",
        test: "yarn g:vitest run --passWithNoTests",
        "test:e2e": "yarn g:vitest run -c vitest.config.e2e.mts --mode development",
        "test:e2e:watch": "yarn g:vitest watch -c vitest.config.e2e.mts",
        "test:index": "tsc --noEmit ./test/index-types.ts && node ./test/index-objects.spec.mjs",
        "test:integration": "yarn g:vitest run --passWithNoTests -c vitest.config.integ.mts",
        "test:integration:watch": "yarn g:vitest run --passWithNoTests -c vitest.config.integ.mts",
        "test:watch": "yarn g:vitest watch --passWithNoTests"
      },
      main: "./dist-cjs/index.js",
      types: "./dist-types/index.d.ts",
      module: "./dist-es/index.js",
      sideEffects: false,
      dependencies: {
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.5",
        "@aws-sdk/credential-provider-node": "^3.972.36",
        "@aws-sdk/middleware-host-header": "^3.972.10",
        "@aws-sdk/middleware-logger": "^3.972.10",
        "@aws-sdk/middleware-recursion-detection": "^3.972.11",
        "@aws-sdk/middleware-user-agent": "^3.972.35",
        "@aws-sdk/region-config-resolver": "^3.972.13",
        "@aws-sdk/types": "^3.973.8",
        "@aws-sdk/util-endpoints": "^3.996.8",
        "@aws-sdk/util-user-agent-browser": "^3.972.10",
        "@aws-sdk/util-user-agent-node": "^3.973.21",
        "@smithy/config-resolver": "^4.4.17",
        "@smithy/core": "^3.23.17",
        "@smithy/fetch-http-handler": "^5.3.17",
        "@smithy/hash-node": "^4.2.14",
        "@smithy/invalid-dependency": "^4.2.14",
        "@smithy/middleware-content-length": "^4.2.14",
        "@smithy/middleware-endpoint": "^4.4.32",
        "@smithy/middleware-retry": "^4.5.5",
        "@smithy/middleware-serde": "^4.2.20",
        "@smithy/middleware-stack": "^4.2.14",
        "@smithy/node-config-provider": "^4.3.14",
        "@smithy/node-http-handler": "^4.6.1",
        "@smithy/protocol-http": "^5.3.14",
        "@smithy/smithy-client": "^4.12.13",
        "@smithy/types": "^4.14.1",
        "@smithy/url-parser": "^4.2.14",
        "@smithy/util-base64": "^4.3.2",
        "@smithy/util-body-length-browser": "^4.2.2",
        "@smithy/util-body-length-node": "^4.2.3",
        "@smithy/util-defaults-mode-browser": "^4.3.49",
        "@smithy/util-defaults-mode-node": "^4.2.54",
        "@smithy/util-endpoints": "^3.4.2",
        "@smithy/util-middleware": "^4.2.14",
        "@smithy/util-retry": "^4.3.4",
        "@smithy/util-utf8": "^4.2.2",
        "@smithy/util-waiter": "^4.2.16",
        tslib: "^2.6.2"
      },
      devDependencies: {
        "@smithy/snapshot-testing": "^2.0.8",
        "@tsconfig/node20": "20.1.8",
        "@types/node": "^20.14.8",
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3",
        vitest: "^4.0.17"
      },
      engines: {
        node: ">=20.0.0"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "dist-*/**"
      ],
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      browser: {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.browser"
      },
      "react-native": {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.native"
      },
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/clients/client-iam",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "clients/client-iam"
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-iam/dist-cjs/endpoint/bdd.js
var require_bdd14 = __commonJS({
  "../../node_modules/@aws-sdk/client-iam/dist-cjs/endpoint/bdd.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.bdd = void 0;
    var util_endpoints_1 = require_dist_cjs20();
    var t = "ref";
    var u = "authSchemes";
    var v = "name";
    var w = "signingRegion";
    var a32 = -1;
    var b32 = true;
    var c32 = "isSet";
    var d32 = "PartitionResult";
    var e32 = "booleanEquals";
    var f32 = "stringEquals";
    var g32 = "getAttr";
    var h32 = "sigv4";
    var i32 = { [t]: "Endpoint" };
    var j32 = { "fn": g32, "argv": [{ [t]: d32 }, "name"] };
    var k32 = { [t]: d32 };
    var l20 = { [u]: [{ [v]: h32, [w]: "us-east-1" }] };
    var m20 = { [u]: [{ [v]: h32, [w]: "cn-north-1" }] };
    var n10 = { [u]: [{ [v]: h32, [w]: "us-gov-west-1" }] };
    var o10 = { [u]: [{ [v]: h32, [w]: "us-iso-east-1" }] };
    var p10 = { [u]: [{ [v]: h32, [w]: "us-isob-east-1" }] };
    var q10 = { [u]: [{ [v]: h32, [w]: "{PartitionResult#implicitGlobalRegion}" }] };
    var s = [{ [t]: "Region" }];
    var _data32 = {
      conditions: [
        [c32, [i32]],
        [c32, s],
        ["aws.partition", s, d32],
        [e32, [{ [t]: "UseFIPS" }, b32]],
        [e32, [{ [t]: "UseDualStack" }, b32]],
        [f32, [j32, "aws"]],
        [f32, [j32, "aws-cn"]],
        [f32, [j32, "aws-us-gov"]],
        [e32, [{ fn: g32, argv: [k32, "supportsDualStack"] }, b32]],
        [f32, [j32, "aws-iso"]],
        [f32, [j32, "aws-iso-b"]],
        [e32, [{ fn: g32, argv: [k32, "supportsFIPS"] }, b32]],
        [f32, [j32, "aws-iso-e"]],
        [f32, [j32, "aws-iso-f"]],
        [f32, [j32, "aws-eusc"]]
      ],
      results: [
        [a32],
        [a32, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a32, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [i32, {}],
        ["https://iam.global.api.aws", l20],
        ["https://iam-fips.global.api.aws", l20],
        ["https://iam.global.api.amazonwebservices.com.cn", m20],
        ["https://iam.cn-north-1.amazonaws.com.cn", m20],
        ["https://iam.us-gov.api.aws", n10],
        ["https://iam.us-gov.amazonaws.com", n10],
        ["https://iam.us-iso-east-1.c2s.ic.gov", o10],
        ["https://iam-fips.us-iso-east-1.c2s.ic.gov", o10],
        ["https://iam.us-isob-east-1.sc2s.sgov.gov", p10],
        ["https://iam-fips.us-isob-east-1.sc2s.sgov.gov", p10],
        ["https://iam.eu-isoe-west-1.cloud.adc-e.uk", { [u]: [{ [v]: h32, [w]: "eu-isoe-west-1" }] }],
        ["https://iam.us-isof-south-1.csp.hci.ic.gov", { [u]: [{ [v]: h32, [w]: "us-isof-south-1" }] }],
        ["https://iam.eusc-de-east-1.amazonaws.eu", { [u]: [{ [v]: h32, [w]: "eusc-de-east-1" }] }],
        ["https://iam-fips.{PartitionResult#dualStackDnsSuffix}", q10],
        [a32, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://iam-fips.{PartitionResult#dnsSuffix}", q10],
        [a32, "FIPS is enabled but this partition does not support FIPS"],
        ["https://iam.{PartitionResult#dualStackDnsSuffix}", q10],
        [a32, "DualStack is enabled but this partition does not support DualStack"],
        ["https://iam.{PartitionResult#dnsSuffix}", q10],
        [a32, "Invalid Configuration: Missing Region"]
      ]
    };
    var root32 = 2;
    var r32 = 1e8;
    var nodes32 = new Int32Array([
      -1,
      1,
      -1,
      0,
      27,
      3,
      1,
      4,
      r32 + 24,
      2,
      5,
      r32 + 24,
      3,
      18,
      6,
      4,
      14,
      7,
      6,
      r32 + 7,
      8,
      7,
      r32 + 9,
      9,
      9,
      r32 + 10,
      10,
      10,
      r32 + 12,
      11,
      12,
      r32 + 14,
      12,
      13,
      r32 + 15,
      13,
      14,
      r32 + 16,
      r32 + 23,
      5,
      r32 + 4,
      15,
      6,
      r32 + 6,
      16,
      7,
      r32 + 8,
      17,
      8,
      r32 + 21,
      r32 + 22,
      4,
      23,
      19,
      7,
      r32 + 9,
      20,
      9,
      r32 + 11,
      21,
      10,
      r32 + 13,
      22,
      11,
      r32 + 19,
      r32 + 20,
      5,
      r32 + 5,
      24,
      7,
      r32 + 8,
      25,
      8,
      26,
      r32 + 18,
      11,
      r32 + 17,
      r32 + 18,
      3,
      r32 + 1,
      28,
      4,
      r32 + 2,
      r32 + 3
    ]);
    exports2.bdd = util_endpoints_1.BinaryDecisionDiagram.from(nodes32, root32, _data32.conditions, _data32.results);
  }
});

// ../../node_modules/@aws-sdk/client-iam/dist-cjs/endpoint/endpointResolver.js
var require_endpointResolver14 = __commonJS({
  "../../node_modules/@aws-sdk/client-iam/dist-cjs/endpoint/endpointResolver.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.defaultEndpointResolver = void 0;
    var util_endpoints_1 = require_dist_cjs21();
    var util_endpoints_2 = require_dist_cjs20();
    var bdd_1 = require_bdd14();
    var cache32 = new util_endpoints_2.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    var defaultEndpointResolver32 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache32.get(endpointParams, () => (0, util_endpoints_2.decideEndpoint)(bdd_1.bdd, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    exports2.defaultEndpointResolver = defaultEndpointResolver32;
    util_endpoints_2.customEndpointFunctions.aws = util_endpoints_1.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-iam/dist-cjs/models/IAMServiceException.js
var require_IAMServiceException = __commonJS({
  "../../node_modules/@aws-sdk/client-iam/dist-cjs/models/IAMServiceException.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.IAMServiceException = exports2.__ServiceException = void 0;
    var smithy_client_1 = require_dist_cjs34();
    Object.defineProperty(exports2, "__ServiceException", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return smithy_client_1.ServiceException;
    }, "get") });
    var IAMServiceException = class _IAMServiceException extends smithy_client_1.ServiceException {
      static {
        __name(this, "IAMServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _IAMServiceException.prototype);
      }
    };
    exports2.IAMServiceException = IAMServiceException;
  }
});

// ../../node_modules/@aws-sdk/client-iam/dist-cjs/models/errors.js
var require_errors13 = __commonJS({
  "../../node_modules/@aws-sdk/client-iam/dist-cjs/models/errors.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.InvalidPublicKeyException = exports2.DuplicateSSHPublicKeyException = exports2.InvalidCertificateException = exports2.DuplicateCertificateException = exports2.MalformedCertificateException = exports2.KeyPairMismatchException = exports2.PolicyEvaluationException = exports2.UnrecognizedPublicKeyEncodingException = exports2.CredentialReportNotReadyException = exports2.CredentialReportNotPresentException = exports2.CredentialReportExpiredException = exports2.ReportGenerationLimitExceededException = exports2.FeatureEnabledException = exports2.CallerIsNotManagementAccountException = exports2.InvalidAuthenticationCodeException = exports2.FeatureDisabledException = exports2.ServiceAccessNotEnabledException = exports2.OrganizationNotInAllFeaturesModeException = exports2.OrganizationNotFoundException = exports2.DeleteConflictException = exports2.ServiceNotSupportedException = exports2.MalformedPolicyDocumentException = exports2.OpenIdIdpCommunicationErrorException = exports2.PasswordPolicyViolationException = exports2.InvalidUserTypeException = exports2.EntityTemporarilyUnmodifiableException = exports2.PolicyNotAttachableException = exports2.UnmodifiableEntityException = exports2.EntityAlreadyExistsException = exports2.LimitExceededException = exports2.InvalidInputException = exports2.AccountNotManagementOrDelegatedAdministratorException = exports2.ServiceFailureException = exports2.NoSuchEntityException = exports2.ConcurrentModificationException = void 0;
    var IAMServiceException_1 = require_IAMServiceException();
    var ConcurrentModificationException = class _ConcurrentModificationException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "ConcurrentModificationException");
      }
      name = "ConcurrentModificationException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ConcurrentModificationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ConcurrentModificationException.prototype);
      }
    };
    exports2.ConcurrentModificationException = ConcurrentModificationException;
    var NoSuchEntityException = class _NoSuchEntityException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "NoSuchEntityException");
      }
      name = "NoSuchEntityException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "NoSuchEntityException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _NoSuchEntityException.prototype);
      }
    };
    exports2.NoSuchEntityException = NoSuchEntityException;
    var ServiceFailureException = class _ServiceFailureException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "ServiceFailureException");
      }
      name = "ServiceFailureException";
      $fault = "server";
      constructor(opts) {
        super({
          name: "ServiceFailureException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _ServiceFailureException.prototype);
      }
    };
    exports2.ServiceFailureException = ServiceFailureException;
    var AccountNotManagementOrDelegatedAdministratorException = class _AccountNotManagementOrDelegatedAdministratorException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "AccountNotManagementOrDelegatedAdministratorException");
      }
      name = "AccountNotManagementOrDelegatedAdministratorException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "AccountNotManagementOrDelegatedAdministratorException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AccountNotManagementOrDelegatedAdministratorException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.AccountNotManagementOrDelegatedAdministratorException = AccountNotManagementOrDelegatedAdministratorException;
    var InvalidInputException = class _InvalidInputException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "InvalidInputException");
      }
      name = "InvalidInputException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidInputException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidInputException.prototype);
      }
    };
    exports2.InvalidInputException = InvalidInputException;
    var LimitExceededException2 = class _LimitExceededException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "LimitExceededException");
      }
      name = "LimitExceededException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "LimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _LimitExceededException.prototype);
      }
    };
    exports2.LimitExceededException = LimitExceededException2;
    var EntityAlreadyExistsException = class _EntityAlreadyExistsException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "EntityAlreadyExistsException");
      }
      name = "EntityAlreadyExistsException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "EntityAlreadyExistsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _EntityAlreadyExistsException.prototype);
      }
    };
    exports2.EntityAlreadyExistsException = EntityAlreadyExistsException;
    var UnmodifiableEntityException = class _UnmodifiableEntityException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "UnmodifiableEntityException");
      }
      name = "UnmodifiableEntityException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "UnmodifiableEntityException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnmodifiableEntityException.prototype);
      }
    };
    exports2.UnmodifiableEntityException = UnmodifiableEntityException;
    var PolicyNotAttachableException = class _PolicyNotAttachableException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "PolicyNotAttachableException");
      }
      name = "PolicyNotAttachableException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "PolicyNotAttachableException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _PolicyNotAttachableException.prototype);
      }
    };
    exports2.PolicyNotAttachableException = PolicyNotAttachableException;
    var EntityTemporarilyUnmodifiableException = class _EntityTemporarilyUnmodifiableException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "EntityTemporarilyUnmodifiableException");
      }
      name = "EntityTemporarilyUnmodifiableException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "EntityTemporarilyUnmodifiableException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _EntityTemporarilyUnmodifiableException.prototype);
      }
    };
    exports2.EntityTemporarilyUnmodifiableException = EntityTemporarilyUnmodifiableException;
    var InvalidUserTypeException = class _InvalidUserTypeException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "InvalidUserTypeException");
      }
      name = "InvalidUserTypeException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidUserTypeException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidUserTypeException.prototype);
      }
    };
    exports2.InvalidUserTypeException = InvalidUserTypeException;
    var PasswordPolicyViolationException = class _PasswordPolicyViolationException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "PasswordPolicyViolationException");
      }
      name = "PasswordPolicyViolationException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "PasswordPolicyViolationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _PasswordPolicyViolationException.prototype);
      }
    };
    exports2.PasswordPolicyViolationException = PasswordPolicyViolationException;
    var OpenIdIdpCommunicationErrorException = class _OpenIdIdpCommunicationErrorException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "OpenIdIdpCommunicationErrorException");
      }
      name = "OpenIdIdpCommunicationErrorException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "OpenIdIdpCommunicationErrorException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _OpenIdIdpCommunicationErrorException.prototype);
      }
    };
    exports2.OpenIdIdpCommunicationErrorException = OpenIdIdpCommunicationErrorException;
    var MalformedPolicyDocumentException10 = class _MalformedPolicyDocumentException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "MalformedPolicyDocumentException");
      }
      name = "MalformedPolicyDocumentException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "MalformedPolicyDocumentException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _MalformedPolicyDocumentException.prototype);
      }
    };
    exports2.MalformedPolicyDocumentException = MalformedPolicyDocumentException10;
    var ServiceNotSupportedException = class _ServiceNotSupportedException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "ServiceNotSupportedException");
      }
      name = "ServiceNotSupportedException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ServiceNotSupportedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ServiceNotSupportedException.prototype);
      }
    };
    exports2.ServiceNotSupportedException = ServiceNotSupportedException;
    var DeleteConflictException = class _DeleteConflictException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "DeleteConflictException");
      }
      name = "DeleteConflictException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "DeleteConflictException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DeleteConflictException.prototype);
      }
    };
    exports2.DeleteConflictException = DeleteConflictException;
    var OrganizationNotFoundException = class _OrganizationNotFoundException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "OrganizationNotFoundException");
      }
      name = "OrganizationNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "OrganizationNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _OrganizationNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.OrganizationNotFoundException = OrganizationNotFoundException;
    var OrganizationNotInAllFeaturesModeException = class _OrganizationNotInAllFeaturesModeException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "OrganizationNotInAllFeaturesModeException");
      }
      name = "OrganizationNotInAllFeaturesModeException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "OrganizationNotInAllFeaturesModeException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _OrganizationNotInAllFeaturesModeException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.OrganizationNotInAllFeaturesModeException = OrganizationNotInAllFeaturesModeException;
    var ServiceAccessNotEnabledException = class _ServiceAccessNotEnabledException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "ServiceAccessNotEnabledException");
      }
      name = "ServiceAccessNotEnabledException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "ServiceAccessNotEnabledException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ServiceAccessNotEnabledException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ServiceAccessNotEnabledException = ServiceAccessNotEnabledException;
    var FeatureDisabledException = class _FeatureDisabledException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "FeatureDisabledException");
      }
      name = "FeatureDisabledException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "FeatureDisabledException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _FeatureDisabledException.prototype);
      }
    };
    exports2.FeatureDisabledException = FeatureDisabledException;
    var InvalidAuthenticationCodeException = class _InvalidAuthenticationCodeException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "InvalidAuthenticationCodeException");
      }
      name = "InvalidAuthenticationCodeException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidAuthenticationCodeException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidAuthenticationCodeException.prototype);
      }
    };
    exports2.InvalidAuthenticationCodeException = InvalidAuthenticationCodeException;
    var CallerIsNotManagementAccountException = class _CallerIsNotManagementAccountException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "CallerIsNotManagementAccountException");
      }
      name = "CallerIsNotManagementAccountException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "CallerIsNotManagementAccountException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CallerIsNotManagementAccountException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.CallerIsNotManagementAccountException = CallerIsNotManagementAccountException;
    var FeatureEnabledException = class _FeatureEnabledException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "FeatureEnabledException");
      }
      name = "FeatureEnabledException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "FeatureEnabledException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _FeatureEnabledException.prototype);
      }
    };
    exports2.FeatureEnabledException = FeatureEnabledException;
    var ReportGenerationLimitExceededException = class _ReportGenerationLimitExceededException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "ReportGenerationLimitExceededException");
      }
      name = "ReportGenerationLimitExceededException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ReportGenerationLimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ReportGenerationLimitExceededException.prototype);
      }
    };
    exports2.ReportGenerationLimitExceededException = ReportGenerationLimitExceededException;
    var CredentialReportExpiredException = class _CredentialReportExpiredException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "CredentialReportExpiredException");
      }
      name = "CredentialReportExpiredException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "CredentialReportExpiredException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CredentialReportExpiredException.prototype);
      }
    };
    exports2.CredentialReportExpiredException = CredentialReportExpiredException;
    var CredentialReportNotPresentException = class _CredentialReportNotPresentException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "CredentialReportNotPresentException");
      }
      name = "CredentialReportNotPresentException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "CredentialReportNotPresentException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CredentialReportNotPresentException.prototype);
      }
    };
    exports2.CredentialReportNotPresentException = CredentialReportNotPresentException;
    var CredentialReportNotReadyException = class _CredentialReportNotReadyException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "CredentialReportNotReadyException");
      }
      name = "CredentialReportNotReadyException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "CredentialReportNotReadyException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CredentialReportNotReadyException.prototype);
      }
    };
    exports2.CredentialReportNotReadyException = CredentialReportNotReadyException;
    var UnrecognizedPublicKeyEncodingException = class _UnrecognizedPublicKeyEncodingException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "UnrecognizedPublicKeyEncodingException");
      }
      name = "UnrecognizedPublicKeyEncodingException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "UnrecognizedPublicKeyEncodingException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnrecognizedPublicKeyEncodingException.prototype);
      }
    };
    exports2.UnrecognizedPublicKeyEncodingException = UnrecognizedPublicKeyEncodingException;
    var PolicyEvaluationException = class _PolicyEvaluationException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "PolicyEvaluationException");
      }
      name = "PolicyEvaluationException";
      $fault = "server";
      constructor(opts) {
        super({
          name: "PolicyEvaluationException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _PolicyEvaluationException.prototype);
      }
    };
    exports2.PolicyEvaluationException = PolicyEvaluationException;
    var KeyPairMismatchException = class _KeyPairMismatchException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "KeyPairMismatchException");
      }
      name = "KeyPairMismatchException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "KeyPairMismatchException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _KeyPairMismatchException.prototype);
      }
    };
    exports2.KeyPairMismatchException = KeyPairMismatchException;
    var MalformedCertificateException = class _MalformedCertificateException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "MalformedCertificateException");
      }
      name = "MalformedCertificateException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "MalformedCertificateException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _MalformedCertificateException.prototype);
      }
    };
    exports2.MalformedCertificateException = MalformedCertificateException;
    var DuplicateCertificateException = class _DuplicateCertificateException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "DuplicateCertificateException");
      }
      name = "DuplicateCertificateException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "DuplicateCertificateException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DuplicateCertificateException.prototype);
      }
    };
    exports2.DuplicateCertificateException = DuplicateCertificateException;
    var InvalidCertificateException = class _InvalidCertificateException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "InvalidCertificateException");
      }
      name = "InvalidCertificateException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidCertificateException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidCertificateException.prototype);
      }
    };
    exports2.InvalidCertificateException = InvalidCertificateException;
    var DuplicateSSHPublicKeyException = class _DuplicateSSHPublicKeyException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "DuplicateSSHPublicKeyException");
      }
      name = "DuplicateSSHPublicKeyException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "DuplicateSSHPublicKeyException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DuplicateSSHPublicKeyException.prototype);
      }
    };
    exports2.DuplicateSSHPublicKeyException = DuplicateSSHPublicKeyException;
    var InvalidPublicKeyException = class _InvalidPublicKeyException extends IAMServiceException_1.IAMServiceException {
      static {
        __name(this, "InvalidPublicKeyException");
      }
      name = "InvalidPublicKeyException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidPublicKeyException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidPublicKeyException.prototype);
      }
    };
    exports2.InvalidPublicKeyException = InvalidPublicKeyException;
  }
});

// ../../node_modules/@aws-sdk/client-iam/dist-cjs/schemas/schemas_0.js
var require_schemas_014 = __commonJS({
  "../../node_modules/@aws-sdk/client-iam/dist-cjs/schemas/schemas_0.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.AttachRolePolicyRequest$ = exports2.AttachGroupPolicyRequest$ = exports2.AttachedPolicy$ = exports2.AttachedPermissionsBoundary$ = exports2.AssociateDelegationRequestRequest$ = exports2.AddUserToGroupRequest$ = exports2.AddRoleToInstanceProfileRequest$ = exports2.AddClientIDToOpenIDConnectProviderRequest$ = exports2.AccessKeyMetadata$ = exports2.AccessKeyLastUsed$ = exports2.AccessKey$ = exports2.AccessDetail$ = exports2.AcceptDelegationRequestRequest$ = exports2.errorTypeRegistries = exports2.UnrecognizedPublicKeyEncodingException$ = exports2.UnmodifiableEntityException$ = exports2.ServiceNotSupportedException$ = exports2.ServiceFailureException$ = exports2.ServiceAccessNotEnabledException$ = exports2.ReportGenerationLimitExceededException$ = exports2.PolicyNotAttachableException$ = exports2.PolicyEvaluationException$ = exports2.PasswordPolicyViolationException$ = exports2.OrganizationNotInAllFeaturesModeException$ = exports2.OrganizationNotFoundException$ = exports2.OpenIdIdpCommunicationErrorException$ = exports2.NoSuchEntityException$ = exports2.MalformedPolicyDocumentException$ = exports2.MalformedCertificateException$ = exports2.LimitExceededException$ = exports2.KeyPairMismatchException$ = exports2.InvalidUserTypeException$ = exports2.InvalidPublicKeyException$ = exports2.InvalidInputException$ = exports2.InvalidCertificateException$ = exports2.InvalidAuthenticationCodeException$ = exports2.FeatureEnabledException$ = exports2.FeatureDisabledException$ = exports2.EntityTemporarilyUnmodifiableException$ = exports2.EntityAlreadyExistsException$ = exports2.DuplicateSSHPublicKeyException$ = exports2.DuplicateCertificateException$ = exports2.DeleteConflictException$ = exports2.CredentialReportNotReadyException$ = exports2.CredentialReportNotPresentException$ = exports2.CredentialReportExpiredException$ = exports2.ConcurrentModificationException$ = exports2.CallerIsNotManagementAccountException$ = exports2.AccountNotManagementOrDelegatedAdministratorException$ = exports2.IAMServiceException$ = void 0;
    exports2.DeleteServiceLinkedRoleRequest$ = exports2.DeleteServerCertificateRequest$ = exports2.DeleteSAMLProviderRequest$ = exports2.DeleteRoleRequest$ = exports2.DeleteRolePolicyRequest$ = exports2.DeleteRolePermissionsBoundaryRequest$ = exports2.DeletePolicyVersionRequest$ = exports2.DeletePolicyRequest$ = exports2.DeleteOpenIDConnectProviderRequest$ = exports2.DeleteLoginProfileRequest$ = exports2.DeleteInstanceProfileRequest$ = exports2.DeleteGroupRequest$ = exports2.DeleteGroupPolicyRequest$ = exports2.DeleteAccountAliasRequest$ = exports2.DeleteAccessKeyRequest$ = exports2.DelegationRequest$ = exports2.DelegationPermission$ = exports2.DeactivateMFADeviceRequest$ = exports2.CreateVirtualMFADeviceResponse$ = exports2.CreateVirtualMFADeviceRequest$ = exports2.CreateUserResponse$ = exports2.CreateUserRequest$ = exports2.CreateServiceSpecificCredentialResponse$ = exports2.CreateServiceSpecificCredentialRequest$ = exports2.CreateServiceLinkedRoleResponse$ = exports2.CreateServiceLinkedRoleRequest$ = exports2.CreateSAMLProviderResponse$ = exports2.CreateSAMLProviderRequest$ = exports2.CreateRoleResponse$ = exports2.CreateRoleRequest$ = exports2.CreatePolicyVersionResponse$ = exports2.CreatePolicyVersionRequest$ = exports2.CreatePolicyResponse$ = exports2.CreatePolicyRequest$ = exports2.CreateOpenIDConnectProviderResponse$ = exports2.CreateOpenIDConnectProviderRequest$ = exports2.CreateLoginProfileResponse$ = exports2.CreateLoginProfileRequest$ = exports2.CreateInstanceProfileResponse$ = exports2.CreateInstanceProfileRequest$ = exports2.CreateGroupResponse$ = exports2.CreateGroupRequest$ = exports2.CreateDelegationRequestResponse$ = exports2.CreateDelegationRequestRequest$ = exports2.CreateAccountAliasRequest$ = exports2.CreateAccessKeyResponse$ = exports2.CreateAccessKeyRequest$ = exports2.ContextEntry$ = exports2.ChangePasswordRequest$ = exports2.AttachUserPolicyRequest$ = void 0;
    exports2.GetInstanceProfileRequest$ = exports2.GetHumanReadableSummaryResponse$ = exports2.GetHumanReadableSummaryRequest$ = exports2.GetGroupResponse$ = exports2.GetGroupRequest$ = exports2.GetGroupPolicyResponse$ = exports2.GetGroupPolicyRequest$ = exports2.GetDelegationRequestResponse$ = exports2.GetDelegationRequestRequest$ = exports2.GetCredentialReportResponse$ = exports2.GetContextKeysForPrincipalPolicyRequest$ = exports2.GetContextKeysForPolicyResponse$ = exports2.GetContextKeysForCustomPolicyRequest$ = exports2.GetAccountSummaryResponse$ = exports2.GetAccountPasswordPolicyResponse$ = exports2.GetAccountAuthorizationDetailsResponse$ = exports2.GetAccountAuthorizationDetailsRequest$ = exports2.GetAccessKeyLastUsedResponse$ = exports2.GetAccessKeyLastUsedRequest$ = exports2.GenerateServiceLastAccessedDetailsResponse$ = exports2.GenerateServiceLastAccessedDetailsRequest$ = exports2.GenerateOrganizationsAccessReportResponse$ = exports2.GenerateOrganizationsAccessReportRequest$ = exports2.GenerateCredentialReportResponse$ = exports2.EvaluationResult$ = exports2.ErrorDetails$ = exports2.EntityInfo$ = exports2.EntityDetails$ = exports2.EnableOutboundWebIdentityFederationResponse$ = exports2.EnableOrganizationsRootSessionsResponse$ = exports2.EnableOrganizationsRootSessionsRequest$ = exports2.EnableOrganizationsRootCredentialsManagementResponse$ = exports2.EnableOrganizationsRootCredentialsManagementRequest$ = exports2.EnableMFADeviceRequest$ = exports2.DisableOrganizationsRootSessionsResponse$ = exports2.DisableOrganizationsRootSessionsRequest$ = exports2.DisableOrganizationsRootCredentialsManagementResponse$ = exports2.DisableOrganizationsRootCredentialsManagementRequest$ = exports2.DetachUserPolicyRequest$ = exports2.DetachRolePolicyRequest$ = exports2.DetachGroupPolicyRequest$ = exports2.DeletionTaskFailureReasonType$ = exports2.DeleteVirtualMFADeviceRequest$ = exports2.DeleteUserRequest$ = exports2.DeleteUserPolicyRequest$ = exports2.DeleteUserPermissionsBoundaryRequest$ = exports2.DeleteSSHPublicKeyRequest$ = exports2.DeleteSigningCertificateRequest$ = exports2.DeleteServiceSpecificCredentialRequest$ = exports2.DeleteServiceLinkedRoleResponse$ = void 0;
    exports2.ListEntitiesForPolicyRequest$ = exports2.ListDelegationRequestsResponse$ = exports2.ListDelegationRequestsRequest$ = exports2.ListAttachedUserPoliciesResponse$ = exports2.ListAttachedUserPoliciesRequest$ = exports2.ListAttachedRolePoliciesResponse$ = exports2.ListAttachedRolePoliciesRequest$ = exports2.ListAttachedGroupPoliciesResponse$ = exports2.ListAttachedGroupPoliciesRequest$ = exports2.ListAccountAliasesResponse$ = exports2.ListAccountAliasesRequest$ = exports2.ListAccessKeysResponse$ = exports2.ListAccessKeysRequest$ = exports2.InstanceProfile$ = exports2.GroupDetail$ = exports2.Group$ = exports2.GetUserResponse$ = exports2.GetUserRequest$ = exports2.GetUserPolicyResponse$ = exports2.GetUserPolicyRequest$ = exports2.GetSSHPublicKeyResponse$ = exports2.GetSSHPublicKeyRequest$ = exports2.GetServiceLinkedRoleDeletionStatusResponse$ = exports2.GetServiceLinkedRoleDeletionStatusRequest$ = exports2.GetServiceLastAccessedDetailsWithEntitiesResponse$ = exports2.GetServiceLastAccessedDetailsWithEntitiesRequest$ = exports2.GetServiceLastAccessedDetailsResponse$ = exports2.GetServiceLastAccessedDetailsRequest$ = exports2.GetServerCertificateResponse$ = exports2.GetServerCertificateRequest$ = exports2.GetSAMLProviderResponse$ = exports2.GetSAMLProviderRequest$ = exports2.GetRoleResponse$ = exports2.GetRoleRequest$ = exports2.GetRolePolicyResponse$ = exports2.GetRolePolicyRequest$ = exports2.GetPolicyVersionResponse$ = exports2.GetPolicyVersionRequest$ = exports2.GetPolicyResponse$ = exports2.GetPolicyRequest$ = exports2.GetOutboundWebIdentityFederationInfoResponse$ = exports2.GetOrganizationsAccessReportResponse$ = exports2.GetOrganizationsAccessReportRequest$ = exports2.GetOpenIDConnectProviderResponse$ = exports2.GetOpenIDConnectProviderRequest$ = exports2.GetMFADeviceResponse$ = exports2.GetMFADeviceRequest$ = exports2.GetLoginProfileResponse$ = exports2.GetLoginProfileRequest$ = exports2.GetInstanceProfileResponse$ = void 0;
    exports2.ListSigningCertificatesResponse$ = exports2.ListSigningCertificatesRequest$ = exports2.ListServiceSpecificCredentialsResponse$ = exports2.ListServiceSpecificCredentialsRequest$ = exports2.ListServerCertificateTagsResponse$ = exports2.ListServerCertificateTagsRequest$ = exports2.ListServerCertificatesResponse$ = exports2.ListServerCertificatesRequest$ = exports2.ListSAMLProviderTagsResponse$ = exports2.ListSAMLProviderTagsRequest$ = exports2.ListSAMLProvidersResponse$ = exports2.ListSAMLProvidersRequest$ = exports2.ListRoleTagsResponse$ = exports2.ListRoleTagsRequest$ = exports2.ListRolesResponse$ = exports2.ListRolesRequest$ = exports2.ListRolePoliciesResponse$ = exports2.ListRolePoliciesRequest$ = exports2.ListPolicyVersionsResponse$ = exports2.ListPolicyVersionsRequest$ = exports2.ListPolicyTagsResponse$ = exports2.ListPolicyTagsRequest$ = exports2.ListPoliciesResponse$ = exports2.ListPoliciesRequest$ = exports2.ListPoliciesGrantingServiceAccessResponse$ = exports2.ListPoliciesGrantingServiceAccessRequest$ = exports2.ListPoliciesGrantingServiceAccessEntry$ = exports2.ListOrganizationsFeaturesResponse$ = exports2.ListOrganizationsFeaturesRequest$ = exports2.ListOpenIDConnectProviderTagsResponse$ = exports2.ListOpenIDConnectProviderTagsRequest$ = exports2.ListOpenIDConnectProvidersResponse$ = exports2.ListOpenIDConnectProvidersRequest$ = exports2.ListMFADeviceTagsResponse$ = exports2.ListMFADeviceTagsRequest$ = exports2.ListMFADevicesResponse$ = exports2.ListMFADevicesRequest$ = exports2.ListInstanceProfileTagsResponse$ = exports2.ListInstanceProfileTagsRequest$ = exports2.ListInstanceProfilesResponse$ = exports2.ListInstanceProfilesRequest$ = exports2.ListInstanceProfilesForRoleResponse$ = exports2.ListInstanceProfilesForRoleRequest$ = exports2.ListGroupsResponse$ = exports2.ListGroupsRequest$ = exports2.ListGroupsForUserResponse$ = exports2.ListGroupsForUserRequest$ = exports2.ListGroupPoliciesResponse$ = exports2.ListGroupPoliciesRequest$ = exports2.ListEntitiesForPolicyResponse$ = void 0;
    exports2.ServiceSpecificCredential$ = exports2.ServiceLastAccessed$ = exports2.ServerCertificateMetadata$ = exports2.ServerCertificate$ = exports2.SendDelegationTokenRequest$ = exports2.SAMLProviderListEntry$ = exports2.SAMLPrivateKey$ = exports2.RoleUsageType$ = exports2.RoleLastUsed$ = exports2.RoleDetail$ = exports2.Role$ = exports2.ResyncMFADeviceRequest$ = exports2.ResourceSpecificResult$ = exports2.ResetServiceSpecificCredentialResponse$ = exports2.ResetServiceSpecificCredentialRequest$ = exports2.RemoveUserFromGroupRequest$ = exports2.RemoveRoleFromInstanceProfileRequest$ = exports2.RemoveClientIDFromOpenIDConnectProviderRequest$ = exports2.RejectDelegationRequestRequest$ = exports2.PutUserPolicyRequest$ = exports2.PutUserPermissionsBoundaryRequest$ = exports2.PutRolePolicyRequest$ = exports2.PutRolePermissionsBoundaryRequest$ = exports2.PutGroupPolicyRequest$ = exports2.Position$ = exports2.PolicyVersion$ = exports2.PolicyUser$ = exports2.PolicyRole$ = exports2.PolicyParameter$ = exports2.PolicyGroup$ = exports2.PolicyGrantingServiceAccess$ = exports2.PolicyDetail$ = exports2.Policy$ = exports2.PermissionsBoundaryDecisionDetail$ = exports2.PasswordPolicy$ = exports2.OrganizationsDecisionDetail$ = exports2.OpenIDConnectProviderListEntry$ = exports2.MFADevice$ = exports2.ManagedPolicyDetail$ = exports2.LoginProfile$ = exports2.ListVirtualMFADevicesResponse$ = exports2.ListVirtualMFADevicesRequest$ = exports2.ListUserTagsResponse$ = exports2.ListUserTagsRequest$ = exports2.ListUsersResponse$ = exports2.ListUsersRequest$ = exports2.ListUserPoliciesResponse$ = exports2.ListUserPoliciesRequest$ = exports2.ListSSHPublicKeysResponse$ = exports2.ListSSHPublicKeysRequest$ = void 0;
    exports2.UploadSigningCertificateResponse$ = exports2.UploadSigningCertificateRequest$ = exports2.UploadServerCertificateResponse$ = exports2.UploadServerCertificateRequest$ = exports2.UpdateUserRequest$ = exports2.UpdateSSHPublicKeyRequest$ = exports2.UpdateSigningCertificateRequest$ = exports2.UpdateServiceSpecificCredentialRequest$ = exports2.UpdateServerCertificateRequest$ = exports2.UpdateSAMLProviderResponse$ = exports2.UpdateSAMLProviderRequest$ = exports2.UpdateRoleResponse$ = exports2.UpdateRoleRequest$ = exports2.UpdateRoleDescriptionResponse$ = exports2.UpdateRoleDescriptionRequest$ = exports2.UpdateOpenIDConnectProviderThumbprintRequest$ = exports2.UpdateLoginProfileRequest$ = exports2.UpdateGroupRequest$ = exports2.UpdateDelegationRequestRequest$ = exports2.UpdateAssumeRolePolicyRequest$ = exports2.UpdateAccountPasswordPolicyRequest$ = exports2.UpdateAccessKeyRequest$ = exports2.UntagUserRequest$ = exports2.UntagServerCertificateRequest$ = exports2.UntagSAMLProviderRequest$ = exports2.UntagRoleRequest$ = exports2.UntagPolicyRequest$ = exports2.UntagOpenIDConnectProviderRequest$ = exports2.UntagMFADeviceRequest$ = exports2.UntagInstanceProfileRequest$ = exports2.TrackedActionLastAccessed$ = exports2.TagUserRequest$ = exports2.TagServerCertificateRequest$ = exports2.TagSAMLProviderRequest$ = exports2.TagRoleRequest$ = exports2.TagPolicyRequest$ = exports2.TagOpenIDConnectProviderRequest$ = exports2.TagMFADeviceRequest$ = exports2.TagInstanceProfileRequest$ = exports2.Tag$ = exports2.Statement$ = exports2.SSHPublicKeyMetadata$ = exports2.SSHPublicKey$ = exports2.SimulatePrincipalPolicyRequest$ = exports2.SimulatePolicyResponse$ = exports2.SimulateCustomPolicyRequest$ = exports2.SigningCertificate$ = exports2.SetSecurityTokenServicePreferencesRequest$ = exports2.SetDefaultPolicyVersionRequest$ = exports2.ServiceSpecificCredentialMetadata$ = void 0;
    exports2.DeleteUser$ = exports2.DeleteSSHPublicKey$ = exports2.DeleteSigningCertificate$ = exports2.DeleteServiceSpecificCredential$ = exports2.DeleteServiceLinkedRole$ = exports2.DeleteServerCertificate$ = exports2.DeleteSAMLProvider$ = exports2.DeleteRolePolicy$ = exports2.DeleteRolePermissionsBoundary$ = exports2.DeleteRole$ = exports2.DeletePolicyVersion$ = exports2.DeletePolicy$ = exports2.DeleteOpenIDConnectProvider$ = exports2.DeleteLoginProfile$ = exports2.DeleteInstanceProfile$ = exports2.DeleteGroupPolicy$ = exports2.DeleteGroup$ = exports2.DeleteAccountPasswordPolicy$ = exports2.DeleteAccountAlias$ = exports2.DeleteAccessKey$ = exports2.DeactivateMFADevice$ = exports2.CreateVirtualMFADevice$ = exports2.CreateUser$ = exports2.CreateServiceSpecificCredential$ = exports2.CreateServiceLinkedRole$ = exports2.CreateSAMLProvider$ = exports2.CreateRole$ = exports2.CreatePolicyVersion$ = exports2.CreatePolicy$ = exports2.CreateOpenIDConnectProvider$ = exports2.CreateLoginProfile$ = exports2.CreateInstanceProfile$ = exports2.CreateGroup$ = exports2.CreateDelegationRequest$ = exports2.CreateAccountAlias$ = exports2.CreateAccessKey$ = exports2.ChangePassword$ = exports2.AttachUserPolicy$ = exports2.AttachRolePolicy$ = exports2.AttachGroupPolicy$ = exports2.AssociateDelegationRequest$ = exports2.AddUserToGroup$ = exports2.AddRoleToInstanceProfile$ = exports2.AddClientIDToOpenIDConnectProvider$ = exports2.AcceptDelegationRequest$ = exports2.VirtualMFADevice$ = exports2.UserDetail$ = exports2.User$ = exports2.UploadSSHPublicKeyResponse$ = exports2.UploadSSHPublicKeyRequest$ = void 0;
    exports2.ListAttachedUserPolicies$ = exports2.ListAttachedRolePolicies$ = exports2.ListAttachedGroupPolicies$ = exports2.ListAccountAliases$ = exports2.ListAccessKeys$ = exports2.GetUserPolicy$ = exports2.GetUser$ = exports2.GetSSHPublicKey$ = exports2.GetServiceLinkedRoleDeletionStatus$ = exports2.GetServiceLastAccessedDetailsWithEntities$ = exports2.GetServiceLastAccessedDetails$ = exports2.GetServerCertificate$ = exports2.GetSAMLProvider$ = exports2.GetRolePolicy$ = exports2.GetRole$ = exports2.GetPolicyVersion$ = exports2.GetPolicy$ = exports2.GetOutboundWebIdentityFederationInfo$ = exports2.GetOrganizationsAccessReport$ = exports2.GetOpenIDConnectProvider$ = exports2.GetMFADevice$ = exports2.GetLoginProfile$ = exports2.GetInstanceProfile$ = exports2.GetHumanReadableSummary$ = exports2.GetGroupPolicy$ = exports2.GetGroup$ = exports2.GetDelegationRequest$ = exports2.GetCredentialReport$ = exports2.GetContextKeysForPrincipalPolicy$ = exports2.GetContextKeysForCustomPolicy$ = exports2.GetAccountSummary$ = exports2.GetAccountPasswordPolicy$ = exports2.GetAccountAuthorizationDetails$ = exports2.GetAccessKeyLastUsed$ = exports2.GenerateServiceLastAccessedDetails$ = exports2.GenerateOrganizationsAccessReport$ = exports2.GenerateCredentialReport$ = exports2.EnableOutboundWebIdentityFederation$ = exports2.EnableOrganizationsRootSessions$ = exports2.EnableOrganizationsRootCredentialsManagement$ = exports2.EnableMFADevice$ = exports2.DisableOutboundWebIdentityFederation$ = exports2.DisableOrganizationsRootSessions$ = exports2.DisableOrganizationsRootCredentialsManagement$ = exports2.DetachUserPolicy$ = exports2.DetachRolePolicy$ = exports2.DetachGroupPolicy$ = exports2.DeleteVirtualMFADevice$ = exports2.DeleteUserPolicy$ = exports2.DeleteUserPermissionsBoundary$ = void 0;
    exports2.TagOpenIDConnectProvider$ = exports2.TagMFADevice$ = exports2.TagInstanceProfile$ = exports2.SimulatePrincipalPolicy$ = exports2.SimulateCustomPolicy$ = exports2.SetSecurityTokenServicePreferences$ = exports2.SetDefaultPolicyVersion$ = exports2.SendDelegationToken$ = exports2.ResyncMFADevice$ = exports2.ResetServiceSpecificCredential$ = exports2.RemoveUserFromGroup$ = exports2.RemoveRoleFromInstanceProfile$ = exports2.RemoveClientIDFromOpenIDConnectProvider$ = exports2.RejectDelegationRequest$ = exports2.PutUserPolicy$ = exports2.PutUserPermissionsBoundary$ = exports2.PutRolePolicy$ = exports2.PutRolePermissionsBoundary$ = exports2.PutGroupPolicy$ = exports2.ListVirtualMFADevices$ = exports2.ListUserTags$ = exports2.ListUsers$ = exports2.ListUserPolicies$ = exports2.ListSSHPublicKeys$ = exports2.ListSigningCertificates$ = exports2.ListServiceSpecificCredentials$ = exports2.ListServerCertificateTags$ = exports2.ListServerCertificates$ = exports2.ListSAMLProviderTags$ = exports2.ListSAMLProviders$ = exports2.ListRoleTags$ = exports2.ListRoles$ = exports2.ListRolePolicies$ = exports2.ListPolicyVersions$ = exports2.ListPolicyTags$ = exports2.ListPoliciesGrantingServiceAccess$ = exports2.ListPolicies$ = exports2.ListOrganizationsFeatures$ = exports2.ListOpenIDConnectProviderTags$ = exports2.ListOpenIDConnectProviders$ = exports2.ListMFADeviceTags$ = exports2.ListMFADevices$ = exports2.ListInstanceProfileTags$ = exports2.ListInstanceProfilesForRole$ = exports2.ListInstanceProfiles$ = exports2.ListGroupsForUser$ = exports2.ListGroups$ = exports2.ListGroupPolicies$ = exports2.ListEntitiesForPolicy$ = exports2.ListDelegationRequests$ = void 0;
    exports2.UploadSSHPublicKey$ = exports2.UploadSigningCertificate$ = exports2.UploadServerCertificate$ = exports2.UpdateUser$ = exports2.UpdateSSHPublicKey$ = exports2.UpdateSigningCertificate$ = exports2.UpdateServiceSpecificCredential$ = exports2.UpdateServerCertificate$ = exports2.UpdateSAMLProvider$ = exports2.UpdateRoleDescription$ = exports2.UpdateRole$ = exports2.UpdateOpenIDConnectProviderThumbprint$ = exports2.UpdateLoginProfile$ = exports2.UpdateGroup$ = exports2.UpdateDelegationRequest$ = exports2.UpdateAssumeRolePolicy$ = exports2.UpdateAccountPasswordPolicy$ = exports2.UpdateAccessKey$ = exports2.UntagUser$ = exports2.UntagServerCertificate$ = exports2.UntagSAMLProvider$ = exports2.UntagRole$ = exports2.UntagPolicy$ = exports2.UntagOpenIDConnectProvider$ = exports2.UntagMFADevice$ = exports2.UntagInstanceProfile$ = exports2.TagUser$ = exports2.TagServerCertificate$ = exports2.TagSAMLProvider$ = exports2.TagRole$ = exports2.TagPolicy$ = void 0;
    var _A10 = "Arn";
    var _AA = "AccountAlias";
    var _AAc = "AccountAliases";
    var _ABO = "AllowedByOrganizations";
    var _ABPB = "AllowedByPermissionsBoundary";
    var _AC = "AuthenticationCode1";
    var _ACIDTOIDCP = "AddClientIDToOpenIDConnectProvider";
    var _ACIDTOIDCPR = "AddClientIDToOpenIDConnectProviderRequest";
    var _ACt = "AttachmentCount";
    var _ACu = "AuthenticationCode2";
    var _AD = "AccessDetail";
    var _ADR = "AcceptDelegationRequest";
    var _ADRR = "AcceptDelegationRequestRequest";
    var _ADRRs = "AssociateDelegationRequestRequest";
    var _ADRs = "AssociateDelegationRequest";
    var _ADc = "AccessDetails";
    var _AEM = "AssertionEncryptionMode";
    var _AGP = "AttachGroupPolicy";
    var _AGPR = "AttachGroupPolicyRequest";
    var _AI2 = "ApproverId";
    var _AK = "AccessKey";
    var _AKI11 = "AccessKeyId";
    var _AKLU = "AccessKeyLastUsed";
    var _AKM = "AccessKeyMetadata";
    var _AMP = "AttachedManagedPolicies";
    var _AN = "ActionNames";
    var _ANMODAE = "AccountNotManagementOrDelegatedAdministratorException";
    var _ANc = "ActionName";
    var _AP = "AttachedPolicy";
    var _APB = "AttachedPermissionsBoundary";
    var _APK = "AddPrivateKey";
    var _APt = "AttachedPolicies";
    var _ARP = "AttachRolePolicy";
    var _ARPD = "AssumeRolePolicyDocument";
    var _ARPR = "AttachRolePolicyRequest";
    var _ARTIP = "AddRoleToInstanceProfile";
    var _ARTIPR = "AddRoleToInstanceProfileRequest";
    var _AS = "AssignmentStatus";
    var _AU = "AllUsers";
    var _AUP = "AttachUserPolicy";
    var _AUPR = "AttachUserPolicyRequest";
    var _AUTCP = "AllowUsersToChangePassword";
    var _AUTG = "AddUserToGroup";
    var _AUTGR = "AddUserToGroupRequest";
    var _AWSSN = "AWSServiceName";
    var _BD = "BootstrapDatum";
    var _BSS = "Base32StringSeed";
    var _C11 = "Code";
    var _CA10 = "CallerArn";
    var _CAA = "CreateAccountAlias";
    var _CAAR = "CreateAccountAliasRequest";
    var _CAD = "CredentialAgeDays";
    var _CAK = "CreateAccessKey";
    var _CAKR = "CreateAccessKeyRequest";
    var _CAKRr = "CreateAccessKeyResponse";
    var _CB = "CertificateBody";
    var _CC = "CertificateChain";
    var _CD = "CreateDate";
    var _CDL = "ConsoleDeepLink";
    var _CDR = "CreateDelegationRequest";
    var _CDRR = "CreateDelegationRequestRequest";
    var _CDRRr = "CreateDelegationRequestResponse";
    var _CE = "ContextEntry";
    var _CELT = "ContextEntryListType";
    var _CEo = "ContextEntries";
    var _CG = "CreateGroup";
    var _CGR = "CreateGroupRequest";
    var _CGRr = "CreateGroupResponse";
    var _CI = "CertificateId";
    var _CID = "ClientID";
    var _CIDL = "ClientIDList";
    var _CINMAE = "CallerIsNotManagementAccountException";
    var _CIP = "CreateInstanceProfile";
    var _CIPR = "CreateInstanceProfileRequest";
    var _CIPRr = "CreateInstanceProfileResponse";
    var _CKN = "ContextKeyName";
    var _CKNo = "ContextKeyNames";
    var _CKT = "ContextKeyType";
    var _CKV = "ContextKeyValues";
    var _CLP = "CreateLoginProfile";
    var _CLPR = "CreateLoginProfileRequest";
    var _CLPRr = "CreateLoginProfileResponse";
    var _CME = "ConcurrentModificationException";
    var _COIDCP = "CreateOpenIDConnectProvider";
    var _COIDCPR = "CreateOpenIDConnectProviderRequest";
    var _COIDCPRr = "CreateOpenIDConnectProviderResponse";
    var _CP = "ChangePassword";
    var _CPR = "ChangePasswordRequest";
    var _CPRr = "CreatePolicyRequest";
    var _CPRre = "CreatePolicyResponse";
    var _CPV = "CreatePolicyVersion";
    var _CPVR = "CreatePolicyVersionRequest";
    var _CPVRr = "CreatePolicyVersionResponse";
    var _CPr = "CreatePolicy";
    var _CR = "CreateRole";
    var _CREE = "CredentialReportExpiredException";
    var _CRNPE = "CredentialReportNotPresentException";
    var _CRNRE = "CredentialReportNotReadyException";
    var _CRR = "CreateRoleRequest";
    var _CRRr = "CreateRoleResponse";
    var _CS4 = "CustomSuffix";
    var _CSAMLP = "CreateSAMLProvider";
    var _CSAMLPR = "CreateSAMLProviderRequest";
    var _CSAMLPRr = "CreateSAMLProviderResponse";
    var _CSLR = "CreateServiceLinkedRole";
    var _CSLRR = "CreateServiceLinkedRoleRequest";
    var _CSLRRr = "CreateServiceLinkedRoleResponse";
    var _CSSC = "CreateServiceSpecificCredential";
    var _CSSCR = "CreateServiceSpecificCredentialRequest";
    var _CSSCRr = "CreateServiceSpecificCredentialResponse";
    var _CU = "CreateUser";
    var _CUR = "CreateUserRequest";
    var _CURr = "CreateUserResponse";
    var _CVMFAD = "CreateVirtualMFADevice";
    var _CVMFADR = "CreateVirtualMFADeviceRequest";
    var _CVMFADRr = "CreateVirtualMFADeviceResponse";
    var _Ce = "Certifications";
    var _Cer = "Certificates";
    var _Cert = "Certificate";
    var _Co = "Content";
    var _Col = "Column";
    var _D = "Description";
    var _DAA = "DeleteAccountAlias";
    var _DAAR = "DeleteAccountAliasRequest";
    var _DAK = "DeleteAccessKey";
    var _DAKR = "DeleteAccessKeyRequest";
    var _DAPP = "DeleteAccountPasswordPolicy";
    var _DCE = "DeleteConflictException";
    var _DCEu = "DuplicateCertificateException";
    var _DG = "DeleteGroup";
    var _DGP = "DeleteGroupPolicy";
    var _DGPR = "DeleteGroupPolicyRequest";
    var _DGPRe = "DetachGroupPolicyRequest";
    var _DGPe = "DetachGroupPolicy";
    var _DGR = "DeleteGroupRequest";
    var _DIP = "DeleteInstanceProfile";
    var _DIPR = "DeleteInstanceProfileRequest";
    var _DLP = "DeleteLoginProfile";
    var _DLPR = "DeleteLoginProfileRequest";
    var _DMFAD = "DeactivateMFADevice";
    var _DMFADR = "DeactivateMFADeviceRequest";
    var _DOIDCP = "DeleteOpenIDConnectProvider";
    var _DOIDCPR = "DeleteOpenIDConnectProviderRequest";
    var _DORCM = "DisableOrganizationsRootCredentialsManagement";
    var _DORCMR = "DisableOrganizationsRootCredentialsManagementRequest";
    var _DORCMRi = "DisableOrganizationsRootCredentialsManagementResponse";
    var _DORS = "DisableOrganizationsRootSessions";
    var _DORSR = "DisableOrganizationsRootSessionsRequest";
    var _DORSRi = "DisableOrganizationsRootSessionsResponse";
    var _DOWIF = "DisableOutboundWebIdentityFederation";
    var _DP = "DelegationPermission";
    var _DPC = "DelegationPermissionCheck";
    var _DPR = "DeletePolicyRequest";
    var _DPV = "DeletePolicyVersion";
    var _DPVR = "DeletePolicyVersionRequest";
    var _DPe = "DeletePolicy";
    var _DR = "DelegationRequest";
    var _DRI = "DelegationRequestId";
    var _DRP = "DeleteRolePolicy";
    var _DRPB = "DeleteRolePermissionsBoundary";
    var _DRPBR = "DeleteRolePermissionsBoundaryRequest";
    var _DRPR = "DeleteRolePolicyRequest";
    var _DRPRe = "DetachRolePolicyRequest";
    var _DRPe = "DetachRolePolicy";
    var _DRR = "DeleteRoleRequest";
    var _DRe = "DelegationRequests";
    var _DRel = "DeleteRole";
    var _DSAMLP = "DeleteSAMLProvider";
    var _DSAMLPR = "DeleteSAMLProviderRequest";
    var _DSC = "DeleteServerCertificate";
    var _DSCR = "DeleteServerCertificateRequest";
    var _DSCRe = "DeleteSigningCertificateRequest";
    var _DSCe = "DeleteSigningCertificate";
    var _DSLR = "DeleteServiceLinkedRole";
    var _DSLRR = "DeleteServiceLinkedRoleRequest";
    var _DSLRRe = "DeleteServiceLinkedRoleResponse";
    var _DSSC = "DeleteServiceSpecificCredential";
    var _DSSCR = "DeleteServiceSpecificCredentialRequest";
    var _DSSHPK = "DeleteSSHPublicKey";
    var _DSSHPKE = "DuplicateSSHPublicKeyException";
    var _DSSHPKR = "DeleteSSHPublicKeyRequest";
    var _DTFRT = "DeletionTaskFailureReasonType";
    var _DTI = "DeletionTaskId";
    var _DU = "DeleteUser";
    var _DUP = "DeleteUserPolicy";
    var _DUPB = "DeleteUserPermissionsBoundary";
    var _DUPBR = "DeleteUserPermissionsBoundaryRequest";
    var _DUPR = "DeleteUserPolicyRequest";
    var _DUPRe = "DetachUserPolicyRequest";
    var _DUPe = "DetachUserPolicy";
    var _DUR = "DeleteUserRequest";
    var _DVI = "DefaultVersionId";
    var _DVMFAD = "DeleteVirtualMFADevice";
    var _DVMFADR = "DeleteVirtualMFADeviceRequest";
    var _Do = "Document";
    var _E11 = "Error";
    var _EA = "EntityArn";
    var _EAEE = "EntityAlreadyExistsException";
    var _EAN = "EvalActionName";
    var _ED = "EntityDetails";
    var _EDD = "EvalDecisionDetails";
    var _EDL = "EntityDetailsList";
    var _EDn = "EnableDate";
    var _EDr = "ErrorDetails";
    var _EDv = "EvalDecision";
    var _EDx = "ExpirationDate";
    var _EF = "EnabledFeatures";
    var _EFn = "EntityFilter";
    var _EI10 = "EntityInfo";
    var _EMFAD = "EnableMFADevice";
    var _EMFADR = "EnableMFADeviceRequest";
    var _EN = "EntityName";
    var _EORCM = "EnableOrganizationsRootCredentialsManagement";
    var _EORCMR = "EnableOrganizationsRootCredentialsManagementRequest";
    var _EORCMRn = "EnableOrganizationsRootCredentialsManagementResponse";
    var _EORS = "EnableOrganizationsRootSessions";
    var _EORSR = "EnableOrganizationsRootSessionsRequest";
    var _EORSRn = "EnableOrganizationsRootSessionsResponse";
    var _EOWIF = "EnableOutboundWebIdentityFederation";
    var _EOWIFR = "EnableOutboundWebIdentityFederationResponse";
    var _EP = "EntityPath";
    var _EPn = "EndPosition";
    var _EPx = "ExpirePasswords";
    var _ER = "EvaluationResult";
    var _ERD = "EvalResourceDecision";
    var _ERLT = "EvaluationResultsListType";
    var _ERN = "EvalResourceName";
    var _ERv = "EvaluationResults";
    var _ET = "ExpirationTime";
    var _ETUE = "EntityTemporarilyUnmodifiableException";
    var _ETn = "EntityType";
    var _En = "Encoding";
    var _Ex = "Expiration";
    var _F = "Filter";
    var _FDE = "FeatureDisabledException";
    var _FEE = "FeatureEnabledException";
    var _Fi = "Fingerprint";
    var _G = "Group";
    var _GAAD = "GetAccountAuthorizationDetails";
    var _GAADR = "GetAccountAuthorizationDetailsRequest";
    var _GAADRe = "GetAccountAuthorizationDetailsResponse";
    var _GAKLU = "GetAccessKeyLastUsed";
    var _GAKLUR = "GetAccessKeyLastUsedRequest";
    var _GAKLURe = "GetAccessKeyLastUsedResponse";
    var _GAPP = "GetAccountPasswordPolicy";
    var _GAPPR = "GetAccountPasswordPolicyResponse";
    var _GAS = "GetAccountSummary";
    var _GASR = "GetAccountSummaryResponse";
    var _GCKFCP = "GetContextKeysForCustomPolicy";
    var _GCKFCPR = "GetContextKeysForCustomPolicyRequest";
    var _GCKFPP = "GetContextKeysForPrincipalPolicy";
    var _GCKFPPR = "GetContextKeysForPrincipalPolicyRequest";
    var _GCKFPR = "GetContextKeysForPolicyResponse";
    var _GCR = "GenerateCredentialReport";
    var _GCRR = "GenerateCredentialReportResponse";
    var _GCRRe = "GetCredentialReportResponse";
    var _GCRe = "GetCredentialReport";
    var _GD = "GroupDetail";
    var _GDL = "GroupDetailList";
    var _GDR = "GetDelegationRequest";
    var _GDRR = "GetDelegationRequestRequest";
    var _GDRRe = "GetDelegationRequestResponse";
    var _GETV = "GlobalEndpointTokenVersion";
    var _GG = "GetGroup";
    var _GGP = "GetGroupPolicy";
    var _GGPR = "GetGroupPolicyRequest";
    var _GGPRe = "GetGroupPolicyResponse";
    var _GGR = "GetGroupRequest";
    var _GGRe = "GetGroupResponse";
    var _GHRS = "GetHumanReadableSummary";
    var _GHRSR = "GetHumanReadableSummaryRequest";
    var _GHRSRe = "GetHumanReadableSummaryResponse";
    var _GI2 = "GroupId";
    var _GIP = "GetInstanceProfile";
    var _GIPR = "GetInstanceProfileRequest";
    var _GIPRe = "GetInstanceProfileResponse";
    var _GL = "GroupList";
    var _GLP = "GetLoginProfile";
    var _GLPR = "GetLoginProfileRequest";
    var _GLPRe = "GetLoginProfileResponse";
    var _GMFAD = "GetMFADevice";
    var _GMFADR = "GetMFADeviceRequest";
    var _GMFADRe = "GetMFADeviceResponse";
    var _GN = "GroupName";
    var _GOAR = "GenerateOrganizationsAccessReport";
    var _GOARR = "GenerateOrganizationsAccessReportRequest";
    var _GOARRe = "GenerateOrganizationsAccessReportResponse";
    var _GOARRet = "GetOrganizationsAccessReportRequest";
    var _GOARRetr = "GetOrganizationsAccessReportResponse";
    var _GOARe = "GetOrganizationsAccessReport";
    var _GOIDCP = "GetOpenIDConnectProvider";
    var _GOIDCPR = "GetOpenIDConnectProviderRequest";
    var _GOIDCPRe = "GetOpenIDConnectProviderResponse";
    var _GOWIFI = "GetOutboundWebIdentityFederationInfo";
    var _GOWIFIR = "GetOutboundWebIdentityFederationInfoResponse";
    var _GP = "GetPolicy";
    var _GPL = "GroupPolicyList";
    var _GPR = "GetPolicyRequest";
    var _GPRe = "GetPolicyResponse";
    var _GPV = "GetPolicyVersion";
    var _GPVR = "GetPolicyVersionRequest";
    var _GPVRe = "GetPolicyVersionResponse";
    var _GR = "GetRole";
    var _GRP = "GetRolePolicy";
    var _GRPR = "GetRolePolicyRequest";
    var _GRPRe = "GetRolePolicyResponse";
    var _GRR = "GetRoleRequest";
    var _GRRe = "GetRoleResponse";
    var _GSAMLP = "GetSAMLProvider";
    var _GSAMLPR = "GetSAMLProviderRequest";
    var _GSAMLPRe = "GetSAMLProviderResponse";
    var _GSC = "GetServerCertificate";
    var _GSCR = "GetServerCertificateRequest";
    var _GSCRe = "GetServerCertificateResponse";
    var _GSLAD = "GenerateServiceLastAccessedDetails";
    var _GSLADR = "GenerateServiceLastAccessedDetailsRequest";
    var _GSLADRe = "GenerateServiceLastAccessedDetailsResponse";
    var _GSLADRet = "GetServiceLastAccessedDetailsRequest";
    var _GSLADRete = "GetServiceLastAccessedDetailsResponse";
    var _GSLADWE = "GetServiceLastAccessedDetailsWithEntities";
    var _GSLADWER = "GetServiceLastAccessedDetailsWithEntitiesRequest";
    var _GSLADWERe = "GetServiceLastAccessedDetailsWithEntitiesResponse";
    var _GSLADe = "GetServiceLastAccessedDetails";
    var _GSLRDS = "GetServiceLinkedRoleDeletionStatus";
    var _GSLRDSR = "GetServiceLinkedRoleDeletionStatusRequest";
    var _GSLRDSRe = "GetServiceLinkedRoleDeletionStatusResponse";
    var _GSSHPK = "GetSSHPublicKey";
    var _GSSHPKR = "GetSSHPublicKeyRequest";
    var _GSSHPKRe = "GetSSHPublicKeyResponse";
    var _GT = "GeneratedTime";
    var _GU = "GetUser";
    var _GUP = "GetUserPolicy";
    var _GUPR = "GetUserPolicyRequest";
    var _GUPRe = "GetUserPolicyResponse";
    var _GUR = "GetUserRequest";
    var _GURe = "GetUserResponse";
    var _Gr = "Granularity";
    var _Gro = "Groups";
    var _HE = "HardExpiry";
    var _I = "Id";
    var _IA = "IsAttachable";
    var _IACE = "InvalidAuthenticationCodeException";
    var _ICE4 = "InvalidCertificateException";
    var _IDV = "IsDefaultVersion";
    var _II2 = "IssuerIdentifier";
    var _IIE = "InvalidInputException";
    var _IP = "InstanceProfile";
    var _IPI2 = "InstanceProfileId";
    var _IPKE = "InvalidPublicKeyException";
    var _IPL = "InstanceProfileList";
    var _IPN = "InstanceProfileName";
    var _IPn = "InstanceProfiles";
    var _IT4 = "IsTruncated";
    var _IUTE = "InvalidUserTypeException";
    var _JCD = "JobCreationDate";
    var _JCDo = "JobCompletionDate";
    var _JI = "JobId";
    var _JS = "JobStatus";
    var _JT = "JobType";
    var _JVE = "JwtVendingEnabled";
    var _K10 = "Key";
    var _KI = "KeyId";
    var _KPME = "KeyPairMismatchException";
    var _L2 = "Locale";
    var _LA = "LastAuthenticated";
    var _LAA = "ListAccountAliases";
    var _LAAR = "ListAccountAliasesRequest";
    var _LAARi = "ListAccountAliasesResponse";
    var _LAE = "LastAuthenticatedEntity";
    var _LAEa = "LastAccessedEntity";
    var _LAGP = "ListAttachedGroupPolicies";
    var _LAGPR = "ListAttachedGroupPoliciesRequest";
    var _LAGPRi = "ListAttachedGroupPoliciesResponse";
    var _LAK = "ListAccessKeys";
    var _LAKR = "ListAccessKeysRequest";
    var _LAKRi = "ListAccessKeysResponse";
    var _LAR = "LastAuthenticatedRegion";
    var _LARP = "ListAttachedRolePolicies";
    var _LARPR = "ListAttachedRolePoliciesRequest";
    var _LARPRi = "ListAttachedRolePoliciesResponse";
    var _LARa = "LastAccessedRegion";
    var _LAT = "LastAuthenticatedTime";
    var _LATa = "LastAccessedTime";
    var _LAUP = "ListAttachedUserPolicies";
    var _LAUPR = "ListAttachedUserPoliciesRequest";
    var _LAUPRi = "ListAttachedUserPoliciesResponse";
    var _LDR = "ListDelegationRequests";
    var _LDRR = "ListDelegationRequestsRequest";
    var _LDRRi = "ListDelegationRequestsResponse";
    var _LEE2 = "LimitExceededException";
    var _LEFP = "ListEntitiesForPolicy";
    var _LEFPR = "ListEntitiesForPolicyRequest";
    var _LEFPRi = "ListEntitiesForPolicyResponse";
    var _LG = "ListGroups";
    var _LGFU = "ListGroupsForUser";
    var _LGFUR = "ListGroupsForUserRequest";
    var _LGFURi = "ListGroupsForUserResponse";
    var _LGP = "ListGroupPolicies";
    var _LGPR = "ListGroupPoliciesRequest";
    var _LGPRi = "ListGroupPoliciesResponse";
    var _LGR = "ListGroupsRequest";
    var _LGRi = "ListGroupsResponse";
    var _LIP = "ListInstanceProfiles";
    var _LIPFR = "ListInstanceProfilesForRole";
    var _LIPFRR = "ListInstanceProfilesForRoleRequest";
    var _LIPFRRi = "ListInstanceProfilesForRoleResponse";
    var _LIPR = "ListInstanceProfilesRequest";
    var _LIPRi = "ListInstanceProfilesResponse";
    var _LIPT = "ListInstanceProfileTags";
    var _LIPTR = "ListInstanceProfileTagsRequest";
    var _LIPTRi = "ListInstanceProfileTagsResponse";
    var _LMFAD = "ListMFADevices";
    var _LMFADR = "ListMFADevicesRequest";
    var _LMFADRi = "ListMFADevicesResponse";
    var _LMFADT = "ListMFADeviceTags";
    var _LMFADTR = "ListMFADeviceTagsRequest";
    var _LMFADTRi = "ListMFADeviceTagsResponse";
    var _LOF = "ListOrganizationsFeatures";
    var _LOFR = "ListOrganizationsFeaturesRequest";
    var _LOFRi = "ListOrganizationsFeaturesResponse";
    var _LOIDCP = "ListOpenIDConnectProviders";
    var _LOIDCPR = "ListOpenIDConnectProvidersRequest";
    var _LOIDCPRi = "ListOpenIDConnectProvidersResponse";
    var _LOIDCPT = "ListOpenIDConnectProviderTags";
    var _LOIDCPTR = "ListOpenIDConnectProviderTagsRequest";
    var _LOIDCPTRi = "ListOpenIDConnectProviderTagsResponse";
    var _LP = "LoginProfile";
    var _LPGSA = "ListPoliciesGrantingServiceAccess";
    var _LPGSAE = "ListPoliciesGrantingServiceAccessEntry";
    var _LPGSAR = "ListPoliciesGrantingServiceAccessRequest";
    var _LPGSARi = "ListPoliciesGrantingServiceAccessResponse";
    var _LPR = "ListPoliciesRequest";
    var _LPRi = "ListPoliciesResponse";
    var _LPT = "ListPolicyTags";
    var _LPTR = "ListPolicyTagsRequest";
    var _LPTRi = "ListPolicyTagsResponse";
    var _LPV = "ListPolicyVersions";
    var _LPVR = "ListPolicyVersionsRequest";
    var _LPVRi = "ListPolicyVersionsResponse";
    var _LPi = "ListPolicies";
    var _LR = "ListRoles";
    var _LRP = "ListRolePolicies";
    var _LRPR = "ListRolePoliciesRequest";
    var _LRPRi = "ListRolePoliciesResponse";
    var _LRR = "ListRolesRequest";
    var _LRRi = "ListRolesResponse";
    var _LRT = "ListRoleTags";
    var _LRTR = "ListRoleTagsRequest";
    var _LRTRi = "ListRoleTagsResponse";
    var _LSAMLP = "ListSAMLProviders";
    var _LSAMLPR = "ListSAMLProvidersRequest";
    var _LSAMLPRi = "ListSAMLProvidersResponse";
    var _LSAMLPT = "ListSAMLProviderTags";
    var _LSAMLPTR = "ListSAMLProviderTagsRequest";
    var _LSAMLPTRi = "ListSAMLProviderTagsResponse";
    var _LSC = "ListServerCertificates";
    var _LSCR = "ListServerCertificatesRequest";
    var _LSCRi = "ListServerCertificatesResponse";
    var _LSCRis = "ListSigningCertificatesRequest";
    var _LSCRist = "ListSigningCertificatesResponse";
    var _LSCT = "ListServerCertificateTags";
    var _LSCTR = "ListServerCertificateTagsRequest";
    var _LSCTRi = "ListServerCertificateTagsResponse";
    var _LSCi = "ListSigningCertificates";
    var _LSSC = "ListServiceSpecificCredentials";
    var _LSSCR = "ListServiceSpecificCredentialsRequest";
    var _LSSCRi = "ListServiceSpecificCredentialsResponse";
    var _LSSHPK = "ListSSHPublicKeys";
    var _LSSHPKR = "ListSSHPublicKeysRequest";
    var _LSSHPKRi = "ListSSHPublicKeysResponse";
    var _LU = "ListUsers";
    var _LUD = "LastUsedDate";
    var _LUP = "ListUserPolicies";
    var _LUPR = "ListUserPoliciesRequest";
    var _LUPRi = "ListUserPoliciesResponse";
    var _LUR = "ListUsersRequest";
    var _LURi = "ListUsersResponse";
    var _LUT = "ListUserTags";
    var _LUTR = "ListUserTagsRequest";
    var _LUTRi = "ListUserTagsResponse";
    var _LVMFAD = "ListVirtualMFADevices";
    var _LVMFADR = "ListVirtualMFADevicesRequest";
    var _LVMFADRi = "ListVirtualMFADevicesResponse";
    var _Li = "Line";
    var _M = "Message";
    var _MCE = "MalformedCertificateException";
    var _MCV = "MissingContextValues";
    var _MFAD = "MFADevices";
    var _MFADe = "MFADevice";
    var _MI = "MaxItems";
    var _MPA = "MaxPasswordAge";
    var _MPD = "ManagedPolicyDetail";
    var _MPDE10 = "MalformedPolicyDocumentException";
    var _MPDLT = "ManagedPolicyDetailListType";
    var _MPL = "MinimumPasswordLength";
    var _MS = "MatchedStatements";
    var _MSD = "MaxSessionDuration";
    var _Ma = "Marker";
    var _N = "Name";
    var _NC = "NotificationChannel";
    var _NGN = "NewGroupName";
    var _NOSA = "NumberOfServicesAccessible";
    var _NOSNA = "NumberOfServicesNotAccessed";
    var _NP = "NewPassword";
    var _NPe = "NewPath";
    var _NSCN = "NewServerCertificateName";
    var _NSEE = "NoSuchEntityException";
    var _NUN = "NewUserName";
    var _No = "Notes";
    var _OA = "OnlyAttached";
    var _OAI = "OwnerAccountId";
    var _ODD = "OrganizationsDecisionDetail";
    var _OI = "OwnerId";
    var _OIDCPA = "OpenIDConnectProviderArn";
    var _OIDCPL = "OpenIDConnectProviderList";
    var _OIDCPLE = "OpenIDConnectProviderListEntry";
    var _OIDCPLT = "OpenIDConnectProviderListType";
    var _OIICEE = "OpenIdIdpCommunicationErrorException";
    var _OIr = "OrganizationId";
    var _ONFE = "OrganizationNotFoundException";
    var _ONIAFME = "OrganizationNotInAllFeaturesModeException";
    var _OP = "OldPassword";
    var _OPI = "OrganizationsPolicyId";
    var _OSBO = "OnlySendByOwner";
    var _P10 = "Permissions";
    var _PA10 = "PolicyArn";
    var _PB = "PermissionsBoundary";
    var _PBA = "PermissionsBoundaryArn";
    var _PBDD = "PermissionsBoundaryDecisionDetail";
    var _PBPIL = "PermissionsBoundaryPolicyInputList";
    var _PBT = "PermissionsBoundaryType";
    var _PBUC = "PermissionsBoundaryUsageCount";
    var _PCR = "PermissionCheckResult";
    var _PCS = "PermissionCheckStatus";
    var _PD = "PolicyDocument";
    var _PDo = "PolicyDetail";
    var _PEE = "PolicyEvaluationException";
    var _PG = "PolicyGroups";
    var _PGLT = "PolicyGroupListType";
    var _PGP = "PutGroupPolicy";
    var _PGPR = "PutGroupPolicyRequest";
    var _PGSA = "PoliciesGrantingServiceAccess";
    var _PGSAo = "PolicyGrantingServiceAccess";
    var _PGo = "PolicyGroup";
    var _PI10 = "PolicyId";
    var _PIL = "PolicyInputList";
    var _PK = "PrivateKey";
    var _PKL = "PrivateKeyList";
    var _PLU = "PasswordLastUsed";
    var _PN = "PolicyName";
    var _PNAE = "PolicyNotAttachableException";
    var _PNo = "PolicyNames";
    var _PP = "PermissionPolicy";
    var _PPVE = "PasswordPolicyViolationException";
    var _PPa = "PasswordPolicy";
    var _PPat = "PathPrefix";
    var _PPo = "PolicyParameter";
    var _PR = "PolicyRoles";
    var _PRLT = "PolicyRoleListType";
    var _PRP = "PasswordReusePrevention";
    var _PRPB = "PutRolePermissionsBoundary";
    var _PRPBR = "PutRolePermissionsBoundaryRequest";
    var _PRPR = "PutRolePolicyRequest";
    var _PRPu = "PutRolePolicy";
    var _PRR = "PasswordResetRequired";
    var _PRo = "PolicyRole";
    var _PSA = "PolicySourceArn";
    var _PT = "PolicyType";
    var _PTA = "PolicyTemplateArn";
    var _PU = "PolicyUsers";
    var _PUF = "PolicyUsageFilter";
    var _PULT = "PolicyUserListType";
    var _PUP = "PutUserPolicy";
    var _PUPB = "PutUserPermissionsBoundary";
    var _PUPBR = "PutUserPermissionsBoundaryRequest";
    var _PUPR = "PutUserPolicyRequest";
    var _PUo = "PolicyUser";
    var _PV = "PolicyVersion";
    var _PVL = "PolicyVersionList";
    var _Pa = "Path";
    var _Par = "Parameters";
    var _Pas = "Password";
    var _Po = "Policy";
    var _Pol = "Policies";
    var _Pos = "Position";
    var _QRCPNG = "QRCodePNG";
    var _R = "Region";
    var _RA10 = "ResourceArns";
    var _RCIDFOIDCP = "RemoveClientIDFromOpenIDConnectProvider";
    var _RCIDFOIDCPR = "RemoveClientIDFromOpenIDConnectProviderRequest";
    var _RD = "RoleDetail";
    var _RDL = "RoleDetailList";
    var _RDR = "RejectDelegationRequest";
    var _RDRR = "RejectDelegationRequestRequest";
    var _RF = "ReportFormat";
    var _RGLEE = "ReportGenerationLimitExceededException";
    var _RHO = "ResourceHandlingOption";
    var _RI = "RequestorId";
    var _RIo = "RoleId";
    var _RLC = "RequireLowercaseCharacters";
    var _RLU = "RoleLastUsed";
    var _RM = "RequestMessage";
    var _RMFAD = "ResyncMFADevice";
    var _RMFADR = "ResyncMFADeviceRequest";
    var _RN = "RoleName";
    var _RNe = "RequestorName";
    var _RNeq = "RequireNumbers";
    var _RO = "ResourceOwner";
    var _RP = "ResourcePolicy";
    var _RPK = "RemovePrivateKey";
    var _RPL = "RolePolicyList";
    var _RPRA = "RolePermissionRestrictionArns";
    var _RR = "RejectionReason";
    var _RRFIP = "RemoveRoleFromInstanceProfile";
    var _RRFIPR = "RemoveRoleFromInstanceProfileRequest";
    var _RS = "RequireSymbols";
    var _RSR = "ResourceSpecificResults";
    var _RSRLT = "ResourceSpecificResultListType";
    var _RSRe = "ResourceSpecificResult";
    var _RSSC = "ResetServiceSpecificCredential";
    var _RSSCR = "ResetServiceSpecificCredentialRequest";
    var _RSSCRe = "ResetServiceSpecificCredentialResponse";
    var _RU = "RedirectUrl";
    var _RUC = "RequireUppercaseCharacters";
    var _RUFG = "RemoveUserFromGroup";
    var _RUFGR = "RemoveUserFromGroupRequest";
    var _RUL = "RoleUsageList";
    var _RULT = "RoleUsageListType";
    var _RUT = "RoleUsageType";
    var _RWI = "RequestorWorkflowId";
    var _Re = "Reason";
    var _Res = "Resources";
    var _Ro = "Role";
    var _Rol = "Roles";
    var _S = "Status";
    var _SAD = "SetAsDefault";
    var _SAK10 = "SecretAccessKey";
    var _SAMLMD = "SAMLMetadataDocument";
    var _SAMLPA = "SAMLProviderArn";
    var _SAMLPK = "SAMLPrivateKey";
    var _SAMLPL = "SAMLProviderList";
    var _SAMLPLE = "SAMLProviderListEntry";
    var _SAMLPLT = "SAMLProviderListType";
    var _SAMLPUUID = "SAMLProviderUUID";
    var _SANEE = "ServiceAccessNotEnabledException";
    var _SC = "SummaryContent";
    var _SCA = "ServiceCredentialAlias";
    var _SCI = "ServerCertificateId";
    var _SCM = "ServerCertificateMetadata";
    var _SCML = "ServerCertificateMetadataList";
    var _SCN = "ServerCertificateName";
    var _SCP = "SimulateCustomPolicy";
    var _SCPR = "SimulateCustomPolicyRequest";
    var _SCS = "ServiceCredentialSecret";
    var _SCe = "ServerCertificate";
    var _SCi = "SigningCertificate";
    var _SD = "SessionDuration";
    var _SDPV = "SetDefaultPolicyVersion";
    var _SDPVR = "SetDefaultPolicyVersionRequest";
    var _SDT = "SendDelegationToken";
    var _SDTR = "SendDelegationTokenRequest";
    var _SFE = "ServiceFailureException";
    var _SK2 = "SortKey";
    var _SLA = "ServicesLastAccessed";
    var _SLAe = "ServiceLastAccessed";
    var _SLT = "StatementListType";
    var _SM = "SummaryMap";
    var _SN10 = "ServiceName";
    var _SNSE = "ServiceNotSupportedException";
    var _SNe = "ServiceNamespace";
    var _SNer = "SerialNumber";
    var _SNerv = "ServiceNamespaces";
    var _SP = "ServicePassword";
    var _SPI = "SourcePolicyId";
    var _SPP = "SimulatePrincipalPolicy";
    var _SPPR = "SimulatePrincipalPolicyRequest";
    var _SPR = "SimulatePolicyResponse";
    var _SPT = "SourcePolicyType";
    var _SPt = "StartPosition";
    var _SS = "SummaryState";
    var _SSC = "ServiceSpecificCredential";
    var _SSCI = "ServiceSpecificCredentialId";
    var _SSCLT = "ServiceSpecificCredentialsListType";
    var _SSCM = "ServiceSpecificCredentialMetadata";
    var _SSCe = "ServiceSpecificCredentials";
    var _SSHPK = "SSHPublicKey";
    var _SSHPKB = "SSHPublicKeyBody";
    var _SSHPKI = "SSHPublicKeyId";
    var _SSHPKLT = "SSHPublicKeyListType";
    var _SSHPKM = "SSHPublicKeyMetadata";
    var _SSHPKu = "SSHPublicKeys";
    var _SSTSP = "SetSecurityTokenServicePreferences";
    var _SSTSPR = "SetSecurityTokenServicePreferencesRequest";
    var _SUN = "ServiceUserName";
    var _Sc = "Scope";
    var _St = "State";
    var _Sta = "Statement";
    var _T10 = "Tags";
    var _TAE = "TotalAuthenticatedEntities";
    var _TALA = "TrackedActionsLastAccessed";
    var _TALAr = "TrackedActionLastAccessed";
    var _TIP = "TagInstanceProfile";
    var _TIPR = "TagInstanceProfileRequest";
    var _TK = "TagKeys";
    var _TL = "ThumbprintList";
    var _TMFAD = "TagMFADevice";
    var _TMFADR = "TagMFADeviceRequest";
    var _TOIDCP = "TagOpenIDConnectProvider";
    var _TOIDCPR = "TagOpenIDConnectProviderRequest";
    var _TP = "TagPolicy";
    var _TPR = "TagPolicyRequest";
    var _TR = "TagRole";
    var _TRR = "TagRoleRequest";
    var _TSAMLP = "TagSAMLProvider";
    var _TSAMLPR = "TagSAMLProviderRequest";
    var _TSC = "TagServerCertificate";
    var _TSCR = "TagServerCertificateRequest";
    var _TU = "TagUser";
    var _TUR = "TagUserRequest";
    var _Ta10 = "Tag";
    var _Ti = "Timestamp";
    var _Ty = "Type";
    var _U = "Url";
    var _UAK = "UpdateAccessKey";
    var _UAKR = "UpdateAccessKeyRequest";
    var _UAPP = "UpdateAccountPasswordPolicy";
    var _UAPPR = "UpdateAccountPasswordPolicyRequest";
    var _UARP = "UpdateAssumeRolePolicy";
    var _UARPR = "UpdateAssumeRolePolicyRequest";
    var _UD = "UpdateDate";
    var _UDL = "UserDetailList";
    var _UDR = "UpdateDelegationRequest";
    var _UDRR = "UpdateDelegationRequestRequest";
    var _UDp = "UploadDate";
    var _UDs = "UserDetail";
    var _UEE = "UnmodifiableEntityException";
    var _UG = "UpdateGroup";
    var _UGR = "UpdateGroupRequest";
    var _UI = "UserId";
    var _UIP = "UntagInstanceProfile";
    var _UIPR = "UntagInstanceProfileRequest";
    var _ULP = "UpdateLoginProfile";
    var _ULPR = "UpdateLoginProfileRequest";
    var _UMFAD = "UntagMFADevice";
    var _UMFADR = "UntagMFADeviceRequest";
    var _UN = "UserName";
    var _UOIDCP = "UntagOpenIDConnectProvider";
    var _UOIDCPR = "UntagOpenIDConnectProviderRequest";
    var _UOIDCPT = "UpdateOpenIDConnectProviderThumbprint";
    var _UOIDCPTR = "UpdateOpenIDConnectProviderThumbprintRequest";
    var _UP = "UntagPolicy";
    var _UPKEE = "UnrecognizedPublicKeyEncodingException";
    var _UPL = "UserPolicyList";
    var _UPR = "UntagPolicyRequest";
    var _UR = "UntagRole";
    var _URD = "UpdateRoleDescription";
    var _URDR = "UpdateRoleDescriptionRequest";
    var _URDRp = "UpdateRoleDescriptionResponse";
    var _URR = "UntagRoleRequest";
    var _URRp = "UpdateRoleRequest";
    var _URRpd = "UpdateRoleResponse";
    var _URp = "UpdateRole";
    var _USAMLP = "UntagSAMLProvider";
    var _USAMLPR = "UntagSAMLProviderRequest";
    var _USAMLPRp = "UpdateSAMLProviderRequest";
    var _USAMLPRpd = "UpdateSAMLProviderResponse";
    var _USAMLPp = "UpdateSAMLProvider";
    var _USC = "UntagServerCertificate";
    var _USCR = "UntagServerCertificateRequest";
    var _USCRp = "UpdateServerCertificateRequest";
    var _USCRpd = "UpdateSigningCertificateRequest";
    var _USCRpl = "UploadServerCertificateRequest";
    var _USCRplo = "UploadServerCertificateResponse";
    var _USCRploa = "UploadSigningCertificateRequest";
    var _USCRpload = "UploadSigningCertificateResponse";
    var _USCp = "UpdateServerCertificate";
    var _USCpd = "UpdateSigningCertificate";
    var _USCpl = "UploadServerCertificate";
    var _USCplo = "UploadSigningCertificate";
    var _USSC = "UpdateServiceSpecificCredential";
    var _USSCR = "UpdateServiceSpecificCredentialRequest";
    var _USSHPK = "UpdateSSHPublicKey";
    var _USSHPKR = "UpdateSSHPublicKeyRequest";
    var _USSHPKRp = "UploadSSHPublicKeyRequest";
    var _USSHPKRpl = "UploadSSHPublicKeyResponse";
    var _USSHPKp = "UploadSSHPublicKey";
    var _UT = "UpdatedTime";
    var _UU = "UntagUser";
    var _UUR = "UntagUserRequest";
    var _UURp = "UpdateUserRequest";
    var _UUp = "UpdateUser";
    var _Us = "User";
    var _Use = "Users";
    var _V10 = "Versions";
    var _VI = "VersionId";
    var _VMFAD = "VirtualMFADevice";
    var _VMFADN = "VirtualMFADeviceName";
    var _VMFADi = "VirtualMFADevices";
    var _VU = "ValidUntil";
    var _Va = "Values";
    var _Val = "Value";
    var _aKMLT = "accessKeyMetadataListType";
    var _aKST10 = "accessKeySecretType";
    var _aPLT = "attachedPoliciesListType";
    var _aQE10 = "awsQueryError";
    var _c32 = "client";
    var _cLT = "certificateListType";
    var _dRLT = "delegationRequestsListType";
    var _e32 = "error";
    var _eDLT = "entityDetailsListType";
    var _gDLT = "groupDetailListType";
    var _gLT = "groupListType";
    var _hE32 = "httpError";
    var _iPLT = "instanceProfileListType";
    var _iT13 = "isTruncated";
    var _lPGSARLT = "listPolicyGrantingServiceAccessResponseListType";
    var _m29 = "message";
    var _mDLT = "mfaDeviceListType";
    var _pDLT10 = "policyDetailListType";
    var _pDVLT = "policyDocumentVersionListType";
    var _pGSALT = "policyGrantingServiceAccessListType";
    var _pKL = "privateKeyList";
    var _pKT = "privateKeyType";
    var _pLT = "policyListType";
    var _pPLT = "policyParameterListType";
    var _pT = "passwordType";
    var _rDLT = "roleDetailListType";
    var _rLT = "roleListType";
    var _s32 = "smithy.ts.sdk.synthetic.com.amazonaws.iam";
    var _sCMLT = "serverCertificateMetadataListType";
    var _sCS = "serviceCredentialSecret";
    var _sP = "servicePassword";
    var _se14 = "server";
    var _tLT10 = "tagListType";
    var _uDLT = "userDetailListType";
    var _uLT = "userListType";
    var _vMFADLT = "virtualMFADeviceListType";
    var n032 = "com.amazonaws.iam";
    var schema_1 = (init_schema4(), __toCommonJS(schema_exports));
    var errors_1 = require_errors13();
    var IAMServiceException_1 = require_IAMServiceException();
    var _s_registry32 = schema_1.TypeRegistry.for(_s32);
    exports2.IAMServiceException$ = [-3, _s32, "IAMServiceException", 0, [], []];
    _s_registry32.registerError(exports2.IAMServiceException$, IAMServiceException_1.IAMServiceException);
    var n0_registry32 = schema_1.TypeRegistry.for(n032);
    exports2.AccountNotManagementOrDelegatedAdministratorException$ = [
      -3,
      n032,
      _ANMODAE,
      { [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.AccountNotManagementOrDelegatedAdministratorException$, errors_1.AccountNotManagementOrDelegatedAdministratorException);
    exports2.CallerIsNotManagementAccountException$ = [
      -3,
      n032,
      _CINMAE,
      { [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.CallerIsNotManagementAccountException$, errors_1.CallerIsNotManagementAccountException);
    exports2.ConcurrentModificationException$ = [
      -3,
      n032,
      _CME,
      { [_aQE10]: [`ConcurrentModification`, 409], [_e32]: _c32, [_hE32]: 409 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ConcurrentModificationException$, errors_1.ConcurrentModificationException);
    exports2.CredentialReportExpiredException$ = [
      -3,
      n032,
      _CREE,
      { [_aQE10]: [`ReportExpired`, 410], [_e32]: _c32, [_hE32]: 410 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.CredentialReportExpiredException$, errors_1.CredentialReportExpiredException);
    exports2.CredentialReportNotPresentException$ = [
      -3,
      n032,
      _CRNPE,
      { [_aQE10]: [`ReportNotPresent`, 410], [_e32]: _c32, [_hE32]: 410 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.CredentialReportNotPresentException$, errors_1.CredentialReportNotPresentException);
    exports2.CredentialReportNotReadyException$ = [
      -3,
      n032,
      _CRNRE,
      { [_aQE10]: [`ReportInProgress`, 404], [_e32]: _c32, [_hE32]: 404 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.CredentialReportNotReadyException$, errors_1.CredentialReportNotReadyException);
    exports2.DeleteConflictException$ = [
      -3,
      n032,
      _DCE,
      { [_aQE10]: [`DeleteConflict`, 409], [_e32]: _c32, [_hE32]: 409 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.DeleteConflictException$, errors_1.DeleteConflictException);
    exports2.DuplicateCertificateException$ = [
      -3,
      n032,
      _DCEu,
      { [_aQE10]: [`DuplicateCertificate`, 409], [_e32]: _c32, [_hE32]: 409 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.DuplicateCertificateException$, errors_1.DuplicateCertificateException);
    exports2.DuplicateSSHPublicKeyException$ = [
      -3,
      n032,
      _DSSHPKE,
      { [_aQE10]: [`DuplicateSSHPublicKey`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.DuplicateSSHPublicKeyException$, errors_1.DuplicateSSHPublicKeyException);
    exports2.EntityAlreadyExistsException$ = [
      -3,
      n032,
      _EAEE,
      { [_aQE10]: [`EntityAlreadyExists`, 409], [_e32]: _c32, [_hE32]: 409 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.EntityAlreadyExistsException$, errors_1.EntityAlreadyExistsException);
    exports2.EntityTemporarilyUnmodifiableException$ = [
      -3,
      n032,
      _ETUE,
      { [_aQE10]: [`EntityTemporarilyUnmodifiable`, 409], [_e32]: _c32, [_hE32]: 409 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.EntityTemporarilyUnmodifiableException$, errors_1.EntityTemporarilyUnmodifiableException);
    exports2.FeatureDisabledException$ = [
      -3,
      n032,
      _FDE,
      { [_aQE10]: [`FeatureDisabled`, 404], [_e32]: _c32, [_hE32]: 404 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.FeatureDisabledException$, errors_1.FeatureDisabledException);
    exports2.FeatureEnabledException$ = [
      -3,
      n032,
      _FEE,
      { [_aQE10]: [`FeatureEnabled`, 409], [_e32]: _c32, [_hE32]: 409 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.FeatureEnabledException$, errors_1.FeatureEnabledException);
    exports2.InvalidAuthenticationCodeException$ = [
      -3,
      n032,
      _IACE,
      { [_aQE10]: [`InvalidAuthenticationCode`, 403], [_e32]: _c32, [_hE32]: 403 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidAuthenticationCodeException$, errors_1.InvalidAuthenticationCodeException);
    exports2.InvalidCertificateException$ = [
      -3,
      n032,
      _ICE4,
      { [_aQE10]: [`InvalidCertificate`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidCertificateException$, errors_1.InvalidCertificateException);
    exports2.InvalidInputException$ = [
      -3,
      n032,
      _IIE,
      { [_aQE10]: [`InvalidInput`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidInputException$, errors_1.InvalidInputException);
    exports2.InvalidPublicKeyException$ = [
      -3,
      n032,
      _IPKE,
      { [_aQE10]: [`InvalidPublicKey`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidPublicKeyException$, errors_1.InvalidPublicKeyException);
    exports2.InvalidUserTypeException$ = [
      -3,
      n032,
      _IUTE,
      { [_aQE10]: [`InvalidUserType`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidUserTypeException$, errors_1.InvalidUserTypeException);
    exports2.KeyPairMismatchException$ = [
      -3,
      n032,
      _KPME,
      { [_aQE10]: [`KeyPairMismatch`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.KeyPairMismatchException$, errors_1.KeyPairMismatchException);
    exports2.LimitExceededException$ = [
      -3,
      n032,
      _LEE2,
      { [_aQE10]: [`LimitExceeded`, 409], [_e32]: _c32, [_hE32]: 409 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.LimitExceededException$, errors_1.LimitExceededException);
    exports2.MalformedCertificateException$ = [
      -3,
      n032,
      _MCE,
      { [_aQE10]: [`MalformedCertificate`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.MalformedCertificateException$, errors_1.MalformedCertificateException);
    exports2.MalformedPolicyDocumentException$ = [
      -3,
      n032,
      _MPDE10,
      { [_aQE10]: [`MalformedPolicyDocument`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.MalformedPolicyDocumentException$, errors_1.MalformedPolicyDocumentException);
    exports2.NoSuchEntityException$ = [
      -3,
      n032,
      _NSEE,
      { [_aQE10]: [`NoSuchEntity`, 404], [_e32]: _c32, [_hE32]: 404 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.NoSuchEntityException$, errors_1.NoSuchEntityException);
    exports2.OpenIdIdpCommunicationErrorException$ = [
      -3,
      n032,
      _OIICEE,
      { [_aQE10]: [`OpenIdIdpCommunicationError`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.OpenIdIdpCommunicationErrorException$, errors_1.OpenIdIdpCommunicationErrorException);
    exports2.OrganizationNotFoundException$ = [
      -3,
      n032,
      _ONFE,
      { [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.OrganizationNotFoundException$, errors_1.OrganizationNotFoundException);
    exports2.OrganizationNotInAllFeaturesModeException$ = [
      -3,
      n032,
      _ONIAFME,
      { [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.OrganizationNotInAllFeaturesModeException$, errors_1.OrganizationNotInAllFeaturesModeException);
    exports2.PasswordPolicyViolationException$ = [
      -3,
      n032,
      _PPVE,
      { [_aQE10]: [`PasswordPolicyViolation`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.PasswordPolicyViolationException$, errors_1.PasswordPolicyViolationException);
    exports2.PolicyEvaluationException$ = [
      -3,
      n032,
      _PEE,
      { [_aQE10]: [`PolicyEvaluation`, 500], [_e32]: _se14, [_hE32]: 500 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.PolicyEvaluationException$, errors_1.PolicyEvaluationException);
    exports2.PolicyNotAttachableException$ = [
      -3,
      n032,
      _PNAE,
      { [_aQE10]: [`PolicyNotAttachable`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.PolicyNotAttachableException$, errors_1.PolicyNotAttachableException);
    exports2.ReportGenerationLimitExceededException$ = [
      -3,
      n032,
      _RGLEE,
      { [_aQE10]: [`ReportGenerationLimitExceeded`, 409], [_e32]: _c32, [_hE32]: 409 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ReportGenerationLimitExceededException$, errors_1.ReportGenerationLimitExceededException);
    exports2.ServiceAccessNotEnabledException$ = [
      -3,
      n032,
      _SANEE,
      { [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ServiceAccessNotEnabledException$, errors_1.ServiceAccessNotEnabledException);
    exports2.ServiceFailureException$ = [
      -3,
      n032,
      _SFE,
      { [_aQE10]: [`ServiceFailure`, 500], [_e32]: _se14, [_hE32]: 500 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ServiceFailureException$, errors_1.ServiceFailureException);
    exports2.ServiceNotSupportedException$ = [
      -3,
      n032,
      _SNSE,
      { [_aQE10]: [`NotSupportedService`, 404], [_e32]: _c32, [_hE32]: 404 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ServiceNotSupportedException$, errors_1.ServiceNotSupportedException);
    exports2.UnmodifiableEntityException$ = [
      -3,
      n032,
      _UEE,
      { [_aQE10]: [`UnmodifiableEntity`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.UnmodifiableEntityException$, errors_1.UnmodifiableEntityException);
    exports2.UnrecognizedPublicKeyEncodingException$ = [
      -3,
      n032,
      _UPKEE,
      { [_aQE10]: [`UnrecognizedPublicKeyEncoding`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.UnrecognizedPublicKeyEncodingException$, errors_1.UnrecognizedPublicKeyEncodingException);
    exports2.errorTypeRegistries = [
      _s_registry32,
      n0_registry32
    ];
    var accessKeySecretType10 = [0, n032, _aKST10, 8, 0];
    var BootstrapDatum = [0, n032, _BD, 8, 21];
    var passwordType = [0, n032, _pT, 8, 0];
    var privateKeyType = [0, n032, _pKT, 8, 0];
    var serviceCredentialSecret = [0, n032, _sCS, 8, 0];
    var servicePassword = [0, n032, _sP, 8, 0];
    exports2.AcceptDelegationRequestRequest$ = [
      3,
      n032,
      _ADRR,
      0,
      [_DRI],
      [0],
      1
    ];
    exports2.AccessDetail$ = [
      3,
      n032,
      _AD,
      0,
      [_SN10, _SNe, _R, _EP, _LAT, _TAE],
      [0, 0, 0, 0, 4, 1],
      2
    ];
    exports2.AccessKey$ = [
      3,
      n032,
      _AK,
      0,
      [_UN, _AKI11, _S, _SAK10, _CD],
      [0, 0, 0, [() => accessKeySecretType10, 0], 4],
      4
    ];
    exports2.AccessKeyLastUsed$ = [
      3,
      n032,
      _AKLU,
      0,
      [_SN10, _R, _LUD],
      [0, 0, 4],
      2
    ];
    exports2.AccessKeyMetadata$ = [
      3,
      n032,
      _AKM,
      0,
      [_UN, _AKI11, _S, _CD],
      [0, 0, 0, 4]
    ];
    exports2.AddClientIDToOpenIDConnectProviderRequest$ = [
      3,
      n032,
      _ACIDTOIDCPR,
      0,
      [_OIDCPA, _CID],
      [0, 0],
      2
    ];
    exports2.AddRoleToInstanceProfileRequest$ = [
      3,
      n032,
      _ARTIPR,
      0,
      [_IPN, _RN],
      [0, 0],
      2
    ];
    exports2.AddUserToGroupRequest$ = [
      3,
      n032,
      _AUTGR,
      0,
      [_GN, _UN],
      [0, 0],
      2
    ];
    exports2.AssociateDelegationRequestRequest$ = [
      3,
      n032,
      _ADRRs,
      0,
      [_DRI],
      [0],
      1
    ];
    exports2.AttachedPermissionsBoundary$ = [
      3,
      n032,
      _APB,
      0,
      [_PBT, _PBA],
      [0, 0]
    ];
    exports2.AttachedPolicy$ = [
      3,
      n032,
      _AP,
      0,
      [_PN, _PA10],
      [0, 0]
    ];
    exports2.AttachGroupPolicyRequest$ = [
      3,
      n032,
      _AGPR,
      0,
      [_GN, _PA10],
      [0, 0],
      2
    ];
    exports2.AttachRolePolicyRequest$ = [
      3,
      n032,
      _ARPR,
      0,
      [_RN, _PA10],
      [0, 0],
      2
    ];
    exports2.AttachUserPolicyRequest$ = [
      3,
      n032,
      _AUPR,
      0,
      [_UN, _PA10],
      [0, 0],
      2
    ];
    exports2.ChangePasswordRequest$ = [
      3,
      n032,
      _CPR,
      0,
      [_OP, _NP],
      [[() => passwordType, 0], [() => passwordType, 0]],
      2
    ];
    exports2.ContextEntry$ = [
      3,
      n032,
      _CE,
      0,
      [_CKN, _CKV, _CKT],
      [0, 64 | 0, 0]
    ];
    exports2.CreateAccessKeyRequest$ = [
      3,
      n032,
      _CAKR,
      0,
      [_UN],
      [0]
    ];
    exports2.CreateAccessKeyResponse$ = [
      3,
      n032,
      _CAKRr,
      0,
      [_AK],
      [[() => exports2.AccessKey$, 0]],
      1
    ];
    exports2.CreateAccountAliasRequest$ = [
      3,
      n032,
      _CAAR,
      0,
      [_AA],
      [0],
      1
    ];
    exports2.CreateDelegationRequestRequest$ = [
      3,
      n032,
      _CDRR,
      0,
      [_D, _P10, _RWI, _NC, _SD, _OAI, _RM, _RU, _OSBO],
      [0, () => exports2.DelegationPermission$, 0, 0, 1, 0, 0, 0, 2],
      5
    ];
    exports2.CreateDelegationRequestResponse$ = [
      3,
      n032,
      _CDRRr,
      0,
      [_CDL, _DRI],
      [0, 0]
    ];
    exports2.CreateGroupRequest$ = [
      3,
      n032,
      _CGR,
      0,
      [_GN, _Pa],
      [0, 0],
      1
    ];
    exports2.CreateGroupResponse$ = [
      3,
      n032,
      _CGRr,
      0,
      [_G],
      [() => exports2.Group$],
      1
    ];
    exports2.CreateInstanceProfileRequest$ = [
      3,
      n032,
      _CIPR,
      0,
      [_IPN, _Pa, _T10],
      [0, 0, () => tagListType10],
      1
    ];
    exports2.CreateInstanceProfileResponse$ = [
      3,
      n032,
      _CIPRr,
      0,
      [_IP],
      [() => exports2.InstanceProfile$],
      1
    ];
    exports2.CreateLoginProfileRequest$ = [
      3,
      n032,
      _CLPR,
      0,
      [_UN, _Pas, _PRR],
      [0, [() => passwordType, 0], 2]
    ];
    exports2.CreateLoginProfileResponse$ = [
      3,
      n032,
      _CLPRr,
      0,
      [_LP],
      [() => exports2.LoginProfile$],
      1
    ];
    exports2.CreateOpenIDConnectProviderRequest$ = [
      3,
      n032,
      _COIDCPR,
      0,
      [_U, _CIDL, _TL, _T10],
      [0, 64 | 0, 64 | 0, () => tagListType10],
      1
    ];
    exports2.CreateOpenIDConnectProviderResponse$ = [
      3,
      n032,
      _COIDCPRr,
      0,
      [_OIDCPA, _T10],
      [0, () => tagListType10]
    ];
    exports2.CreatePolicyRequest$ = [
      3,
      n032,
      _CPRr,
      0,
      [_PN, _PD, _Pa, _D, _T10],
      [0, 0, 0, 0, () => tagListType10],
      2
    ];
    exports2.CreatePolicyResponse$ = [
      3,
      n032,
      _CPRre,
      0,
      [_Po],
      [() => exports2.Policy$]
    ];
    exports2.CreatePolicyVersionRequest$ = [
      3,
      n032,
      _CPVR,
      0,
      [_PA10, _PD, _SAD],
      [0, 0, 2],
      2
    ];
    exports2.CreatePolicyVersionResponse$ = [
      3,
      n032,
      _CPVRr,
      0,
      [_PV],
      [() => exports2.PolicyVersion$]
    ];
    exports2.CreateRoleRequest$ = [
      3,
      n032,
      _CRR,
      0,
      [_RN, _ARPD, _Pa, _D, _MSD, _PB, _T10],
      [0, 0, 0, 0, 1, 0, () => tagListType10],
      2
    ];
    exports2.CreateRoleResponse$ = [
      3,
      n032,
      _CRRr,
      0,
      [_Ro],
      [() => exports2.Role$],
      1
    ];
    exports2.CreateSAMLProviderRequest$ = [
      3,
      n032,
      _CSAMLPR,
      0,
      [_SAMLMD, _N, _T10, _AEM, _APK],
      [0, 0, () => tagListType10, 0, [() => privateKeyType, 0]],
      2
    ];
    exports2.CreateSAMLProviderResponse$ = [
      3,
      n032,
      _CSAMLPRr,
      0,
      [_SAMLPA, _T10],
      [0, () => tagListType10]
    ];
    exports2.CreateServiceLinkedRoleRequest$ = [
      3,
      n032,
      _CSLRR,
      0,
      [_AWSSN, _D, _CS4],
      [0, 0, 0],
      1
    ];
    exports2.CreateServiceLinkedRoleResponse$ = [
      3,
      n032,
      _CSLRRr,
      0,
      [_Ro],
      [() => exports2.Role$]
    ];
    exports2.CreateServiceSpecificCredentialRequest$ = [
      3,
      n032,
      _CSSCR,
      0,
      [_UN, _SN10, _CAD],
      [0, 0, 1],
      2
    ];
    exports2.CreateServiceSpecificCredentialResponse$ = [
      3,
      n032,
      _CSSCRr,
      0,
      [_SSC],
      [[() => exports2.ServiceSpecificCredential$, 0]]
    ];
    exports2.CreateUserRequest$ = [
      3,
      n032,
      _CUR,
      0,
      [_UN, _Pa, _PB, _T10],
      [0, 0, 0, () => tagListType10],
      1
    ];
    exports2.CreateUserResponse$ = [
      3,
      n032,
      _CURr,
      0,
      [_Us],
      [() => exports2.User$]
    ];
    exports2.CreateVirtualMFADeviceRequest$ = [
      3,
      n032,
      _CVMFADR,
      0,
      [_VMFADN, _Pa, _T10],
      [0, 0, () => tagListType10],
      1
    ];
    exports2.CreateVirtualMFADeviceResponse$ = [
      3,
      n032,
      _CVMFADRr,
      0,
      [_VMFAD],
      [[() => exports2.VirtualMFADevice$, 0]],
      1
    ];
    exports2.DeactivateMFADeviceRequest$ = [
      3,
      n032,
      _DMFADR,
      0,
      [_SNer, _UN],
      [0, 0],
      1
    ];
    exports2.DelegationPermission$ = [
      3,
      n032,
      _DP,
      0,
      [_PTA, _Par],
      [0, () => policyParameterListType]
    ];
    exports2.DelegationRequest$ = [
      3,
      n032,
      _DR,
      0,
      [_DRI, _OAI, _D, _RM, _P10, _PP, _RPRA, _OI, _AI2, _St, _ET, _RI, _RNe, _CD, _SD, _RU, _No, _RR, _OSBO, _UT],
      [0, 0, 0, 0, () => exports2.DelegationPermission$, 0, 64 | 0, 0, 0, 0, 4, 0, 0, 4, 1, 0, 0, 0, 2, 4]
    ];
    exports2.DeleteAccessKeyRequest$ = [
      3,
      n032,
      _DAKR,
      0,
      [_AKI11, _UN],
      [0, 0],
      1
    ];
    exports2.DeleteAccountAliasRequest$ = [
      3,
      n032,
      _DAAR,
      0,
      [_AA],
      [0],
      1
    ];
    exports2.DeleteGroupPolicyRequest$ = [
      3,
      n032,
      _DGPR,
      0,
      [_GN, _PN],
      [0, 0],
      2
    ];
    exports2.DeleteGroupRequest$ = [
      3,
      n032,
      _DGR,
      0,
      [_GN],
      [0],
      1
    ];
    exports2.DeleteInstanceProfileRequest$ = [
      3,
      n032,
      _DIPR,
      0,
      [_IPN],
      [0],
      1
    ];
    exports2.DeleteLoginProfileRequest$ = [
      3,
      n032,
      _DLPR,
      0,
      [_UN],
      [0]
    ];
    exports2.DeleteOpenIDConnectProviderRequest$ = [
      3,
      n032,
      _DOIDCPR,
      0,
      [_OIDCPA],
      [0],
      1
    ];
    exports2.DeletePolicyRequest$ = [
      3,
      n032,
      _DPR,
      0,
      [_PA10],
      [0],
      1
    ];
    exports2.DeletePolicyVersionRequest$ = [
      3,
      n032,
      _DPVR,
      0,
      [_PA10, _VI],
      [0, 0],
      2
    ];
    exports2.DeleteRolePermissionsBoundaryRequest$ = [
      3,
      n032,
      _DRPBR,
      0,
      [_RN],
      [0],
      1
    ];
    exports2.DeleteRolePolicyRequest$ = [
      3,
      n032,
      _DRPR,
      0,
      [_RN, _PN],
      [0, 0],
      2
    ];
    exports2.DeleteRoleRequest$ = [
      3,
      n032,
      _DRR,
      0,
      [_RN],
      [0],
      1
    ];
    exports2.DeleteSAMLProviderRequest$ = [
      3,
      n032,
      _DSAMLPR,
      0,
      [_SAMLPA],
      [0],
      1
    ];
    exports2.DeleteServerCertificateRequest$ = [
      3,
      n032,
      _DSCR,
      0,
      [_SCN],
      [0],
      1
    ];
    exports2.DeleteServiceLinkedRoleRequest$ = [
      3,
      n032,
      _DSLRR,
      0,
      [_RN],
      [0],
      1
    ];
    exports2.DeleteServiceLinkedRoleResponse$ = [
      3,
      n032,
      _DSLRRe,
      0,
      [_DTI],
      [0],
      1
    ];
    exports2.DeleteServiceSpecificCredentialRequest$ = [
      3,
      n032,
      _DSSCR,
      0,
      [_SSCI, _UN],
      [0, 0],
      1
    ];
    exports2.DeleteSigningCertificateRequest$ = [
      3,
      n032,
      _DSCRe,
      0,
      [_CI, _UN],
      [0, 0],
      1
    ];
    exports2.DeleteSSHPublicKeyRequest$ = [
      3,
      n032,
      _DSSHPKR,
      0,
      [_UN, _SSHPKI],
      [0, 0],
      2
    ];
    exports2.DeleteUserPermissionsBoundaryRequest$ = [
      3,
      n032,
      _DUPBR,
      0,
      [_UN],
      [0],
      1
    ];
    exports2.DeleteUserPolicyRequest$ = [
      3,
      n032,
      _DUPR,
      0,
      [_UN, _PN],
      [0, 0],
      2
    ];
    exports2.DeleteUserRequest$ = [
      3,
      n032,
      _DUR,
      0,
      [_UN],
      [0],
      1
    ];
    exports2.DeleteVirtualMFADeviceRequest$ = [
      3,
      n032,
      _DVMFADR,
      0,
      [_SNer],
      [0],
      1
    ];
    exports2.DeletionTaskFailureReasonType$ = [
      3,
      n032,
      _DTFRT,
      0,
      [_Re, _RUL],
      [0, () => RoleUsageListType]
    ];
    exports2.DetachGroupPolicyRequest$ = [
      3,
      n032,
      _DGPRe,
      0,
      [_GN, _PA10],
      [0, 0],
      2
    ];
    exports2.DetachRolePolicyRequest$ = [
      3,
      n032,
      _DRPRe,
      0,
      [_RN, _PA10],
      [0, 0],
      2
    ];
    exports2.DetachUserPolicyRequest$ = [
      3,
      n032,
      _DUPRe,
      0,
      [_UN, _PA10],
      [0, 0],
      2
    ];
    exports2.DisableOrganizationsRootCredentialsManagementRequest$ = [
      3,
      n032,
      _DORCMR,
      0,
      [],
      []
    ];
    exports2.DisableOrganizationsRootCredentialsManagementResponse$ = [
      3,
      n032,
      _DORCMRi,
      0,
      [_OIr, _EF],
      [0, 64 | 0]
    ];
    exports2.DisableOrganizationsRootSessionsRequest$ = [
      3,
      n032,
      _DORSR,
      0,
      [],
      []
    ];
    exports2.DisableOrganizationsRootSessionsResponse$ = [
      3,
      n032,
      _DORSRi,
      0,
      [_OIr, _EF],
      [0, 64 | 0]
    ];
    exports2.EnableMFADeviceRequest$ = [
      3,
      n032,
      _EMFADR,
      0,
      [_UN, _SNer, _AC, _ACu],
      [0, 0, 0, 0],
      4
    ];
    exports2.EnableOrganizationsRootCredentialsManagementRequest$ = [
      3,
      n032,
      _EORCMR,
      0,
      [],
      []
    ];
    exports2.EnableOrganizationsRootCredentialsManagementResponse$ = [
      3,
      n032,
      _EORCMRn,
      0,
      [_OIr, _EF],
      [0, 64 | 0]
    ];
    exports2.EnableOrganizationsRootSessionsRequest$ = [
      3,
      n032,
      _EORSR,
      0,
      [],
      []
    ];
    exports2.EnableOrganizationsRootSessionsResponse$ = [
      3,
      n032,
      _EORSRn,
      0,
      [_OIr, _EF],
      [0, 64 | 0]
    ];
    exports2.EnableOutboundWebIdentityFederationResponse$ = [
      3,
      n032,
      _EOWIFR,
      0,
      [_II2],
      [0]
    ];
    exports2.EntityDetails$ = [
      3,
      n032,
      _ED,
      0,
      [_EI10, _LA],
      [() => exports2.EntityInfo$, 4],
      1
    ];
    exports2.EntityInfo$ = [
      3,
      n032,
      _EI10,
      0,
      [_A10, _N, _Ty, _I, _Pa],
      [0, 0, 0, 0, 0],
      4
    ];
    exports2.ErrorDetails$ = [
      3,
      n032,
      _EDr,
      0,
      [_M, _C11],
      [0, 0],
      2
    ];
    exports2.EvaluationResult$ = [
      3,
      n032,
      _ER,
      0,
      [_EAN, _EDv, _ERN, _MS, _MCV, _ODD, _PBDD, _EDD, _RSR],
      [0, 0, 0, () => StatementListType, 64 | 0, () => exports2.OrganizationsDecisionDetail$, () => exports2.PermissionsBoundaryDecisionDetail$, 128 | 0, () => ResourceSpecificResultListType],
      2
    ];
    exports2.GenerateCredentialReportResponse$ = [
      3,
      n032,
      _GCRR,
      0,
      [_St, _D],
      [0, 0]
    ];
    exports2.GenerateOrganizationsAccessReportRequest$ = [
      3,
      n032,
      _GOARR,
      0,
      [_EP, _OPI],
      [0, 0],
      1
    ];
    exports2.GenerateOrganizationsAccessReportResponse$ = [
      3,
      n032,
      _GOARRe,
      0,
      [_JI],
      [0]
    ];
    exports2.GenerateServiceLastAccessedDetailsRequest$ = [
      3,
      n032,
      _GSLADR,
      0,
      [_A10, _Gr],
      [0, 0],
      1
    ];
    exports2.GenerateServiceLastAccessedDetailsResponse$ = [
      3,
      n032,
      _GSLADRe,
      0,
      [_JI],
      [0]
    ];
    exports2.GetAccessKeyLastUsedRequest$ = [
      3,
      n032,
      _GAKLUR,
      0,
      [_AKI11],
      [0],
      1
    ];
    exports2.GetAccessKeyLastUsedResponse$ = [
      3,
      n032,
      _GAKLURe,
      0,
      [_UN, _AKLU],
      [0, () => exports2.AccessKeyLastUsed$]
    ];
    exports2.GetAccountAuthorizationDetailsRequest$ = [
      3,
      n032,
      _GAADR,
      0,
      [_F, _MI, _Ma],
      [64 | 0, 1, 0]
    ];
    exports2.GetAccountAuthorizationDetailsResponse$ = [
      3,
      n032,
      _GAADRe,
      0,
      [_UDL, _GDL, _RDL, _Pol, _IT4, _Ma],
      [() => userDetailListType, () => groupDetailListType, () => roleDetailListType, () => ManagedPolicyDetailListType, 2, 0]
    ];
    exports2.GetAccountPasswordPolicyResponse$ = [
      3,
      n032,
      _GAPPR,
      0,
      [_PPa],
      [() => exports2.PasswordPolicy$],
      1
    ];
    exports2.GetAccountSummaryResponse$ = [
      3,
      n032,
      _GASR,
      0,
      [_SM],
      [128 | 1]
    ];
    exports2.GetContextKeysForCustomPolicyRequest$ = [
      3,
      n032,
      _GCKFCPR,
      0,
      [_PIL],
      [64 | 0],
      1
    ];
    exports2.GetContextKeysForPolicyResponse$ = [
      3,
      n032,
      _GCKFPR,
      0,
      [_CKNo],
      [64 | 0]
    ];
    exports2.GetContextKeysForPrincipalPolicyRequest$ = [
      3,
      n032,
      _GCKFPPR,
      0,
      [_PSA, _PIL],
      [0, 64 | 0],
      1
    ];
    exports2.GetCredentialReportResponse$ = [
      3,
      n032,
      _GCRRe,
      0,
      [_Co, _RF, _GT],
      [21, 0, 4]
    ];
    exports2.GetDelegationRequestRequest$ = [
      3,
      n032,
      _GDRR,
      0,
      [_DRI, _DPC],
      [0, 2],
      1
    ];
    exports2.GetDelegationRequestResponse$ = [
      3,
      n032,
      _GDRRe,
      0,
      [_DR, _PCS, _PCR],
      [() => exports2.DelegationRequest$, 0, 0]
    ];
    exports2.GetGroupPolicyRequest$ = [
      3,
      n032,
      _GGPR,
      0,
      [_GN, _PN],
      [0, 0],
      2
    ];
    exports2.GetGroupPolicyResponse$ = [
      3,
      n032,
      _GGPRe,
      0,
      [_GN, _PN, _PD],
      [0, 0, 0],
      3
    ];
    exports2.GetGroupRequest$ = [
      3,
      n032,
      _GGR,
      0,
      [_GN, _Ma, _MI],
      [0, 0, 1],
      1
    ];
    exports2.GetGroupResponse$ = [
      3,
      n032,
      _GGRe,
      0,
      [_G, _Use, _IT4, _Ma],
      [() => exports2.Group$, () => userListType, 2, 0],
      2
    ];
    exports2.GetHumanReadableSummaryRequest$ = [
      3,
      n032,
      _GHRSR,
      0,
      [_EA, _L2],
      [0, 0],
      1
    ];
    exports2.GetHumanReadableSummaryResponse$ = [
      3,
      n032,
      _GHRSRe,
      0,
      [_SC, _L2, _SS],
      [0, 0, 0]
    ];
    exports2.GetInstanceProfileRequest$ = [
      3,
      n032,
      _GIPR,
      0,
      [_IPN],
      [0],
      1
    ];
    exports2.GetInstanceProfileResponse$ = [
      3,
      n032,
      _GIPRe,
      0,
      [_IP],
      [() => exports2.InstanceProfile$],
      1
    ];
    exports2.GetLoginProfileRequest$ = [
      3,
      n032,
      _GLPR,
      0,
      [_UN],
      [0]
    ];
    exports2.GetLoginProfileResponse$ = [
      3,
      n032,
      _GLPRe,
      0,
      [_LP],
      [() => exports2.LoginProfile$],
      1
    ];
    exports2.GetMFADeviceRequest$ = [
      3,
      n032,
      _GMFADR,
      0,
      [_SNer, _UN],
      [0, 0],
      1
    ];
    exports2.GetMFADeviceResponse$ = [
      3,
      n032,
      _GMFADRe,
      0,
      [_SNer, _UN, _EDn, _Ce],
      [0, 0, 4, 128 | 0],
      1
    ];
    exports2.GetOpenIDConnectProviderRequest$ = [
      3,
      n032,
      _GOIDCPR,
      0,
      [_OIDCPA],
      [0],
      1
    ];
    exports2.GetOpenIDConnectProviderResponse$ = [
      3,
      n032,
      _GOIDCPRe,
      0,
      [_U, _CIDL, _TL, _CD, _T10],
      [0, 64 | 0, 64 | 0, 4, () => tagListType10]
    ];
    exports2.GetOrganizationsAccessReportRequest$ = [
      3,
      n032,
      _GOARRet,
      0,
      [_JI, _MI, _Ma, _SK2],
      [0, 1, 0, 0],
      1
    ];
    exports2.GetOrganizationsAccessReportResponse$ = [
      3,
      n032,
      _GOARRetr,
      0,
      [_JS, _JCD, _JCDo, _NOSA, _NOSNA, _ADc, _IT4, _Ma, _EDr],
      [0, 4, 4, 1, 1, () => AccessDetails, 2, 0, () => exports2.ErrorDetails$],
      2
    ];
    exports2.GetOutboundWebIdentityFederationInfoResponse$ = [
      3,
      n032,
      _GOWIFIR,
      0,
      [_II2, _JVE],
      [0, 2]
    ];
    exports2.GetPolicyRequest$ = [
      3,
      n032,
      _GPR,
      0,
      [_PA10],
      [0],
      1
    ];
    exports2.GetPolicyResponse$ = [
      3,
      n032,
      _GPRe,
      0,
      [_Po],
      [() => exports2.Policy$]
    ];
    exports2.GetPolicyVersionRequest$ = [
      3,
      n032,
      _GPVR,
      0,
      [_PA10, _VI],
      [0, 0],
      2
    ];
    exports2.GetPolicyVersionResponse$ = [
      3,
      n032,
      _GPVRe,
      0,
      [_PV],
      [() => exports2.PolicyVersion$]
    ];
    exports2.GetRolePolicyRequest$ = [
      3,
      n032,
      _GRPR,
      0,
      [_RN, _PN],
      [0, 0],
      2
    ];
    exports2.GetRolePolicyResponse$ = [
      3,
      n032,
      _GRPRe,
      0,
      [_RN, _PN, _PD],
      [0, 0, 0],
      3
    ];
    exports2.GetRoleRequest$ = [
      3,
      n032,
      _GRR,
      0,
      [_RN],
      [0],
      1
    ];
    exports2.GetRoleResponse$ = [
      3,
      n032,
      _GRRe,
      0,
      [_Ro],
      [() => exports2.Role$],
      1
    ];
    exports2.GetSAMLProviderRequest$ = [
      3,
      n032,
      _GSAMLPR,
      0,
      [_SAMLPA],
      [0],
      1
    ];
    exports2.GetSAMLProviderResponse$ = [
      3,
      n032,
      _GSAMLPRe,
      0,
      [_SAMLPUUID, _SAMLMD, _CD, _VU, _T10, _AEM, _PKL],
      [0, 0, 4, 4, () => tagListType10, 0, () => privateKeyList]
    ];
    exports2.GetServerCertificateRequest$ = [
      3,
      n032,
      _GSCR,
      0,
      [_SCN],
      [0],
      1
    ];
    exports2.GetServerCertificateResponse$ = [
      3,
      n032,
      _GSCRe,
      0,
      [_SCe],
      [() => exports2.ServerCertificate$],
      1
    ];
    exports2.GetServiceLastAccessedDetailsRequest$ = [
      3,
      n032,
      _GSLADRet,
      0,
      [_JI, _MI, _Ma],
      [0, 1, 0],
      1
    ];
    exports2.GetServiceLastAccessedDetailsResponse$ = [
      3,
      n032,
      _GSLADRete,
      0,
      [_JS, _JCD, _SLA, _JCDo, _JT, _IT4, _Ma, _E11],
      [0, 4, () => ServicesLastAccessed, 4, 0, 2, 0, () => exports2.ErrorDetails$],
      4
    ];
    exports2.GetServiceLastAccessedDetailsWithEntitiesRequest$ = [
      3,
      n032,
      _GSLADWER,
      0,
      [_JI, _SNe, _MI, _Ma],
      [0, 0, 1, 0],
      2
    ];
    exports2.GetServiceLastAccessedDetailsWithEntitiesResponse$ = [
      3,
      n032,
      _GSLADWERe,
      0,
      [_JS, _JCD, _JCDo, _EDL, _IT4, _Ma, _E11],
      [0, 4, 4, () => entityDetailsListType, 2, 0, () => exports2.ErrorDetails$],
      4
    ];
    exports2.GetServiceLinkedRoleDeletionStatusRequest$ = [
      3,
      n032,
      _GSLRDSR,
      0,
      [_DTI],
      [0],
      1
    ];
    exports2.GetServiceLinkedRoleDeletionStatusResponse$ = [
      3,
      n032,
      _GSLRDSRe,
      0,
      [_S, _Re],
      [0, () => exports2.DeletionTaskFailureReasonType$],
      1
    ];
    exports2.GetSSHPublicKeyRequest$ = [
      3,
      n032,
      _GSSHPKR,
      0,
      [_UN, _SSHPKI, _En],
      [0, 0, 0],
      3
    ];
    exports2.GetSSHPublicKeyResponse$ = [
      3,
      n032,
      _GSSHPKRe,
      0,
      [_SSHPK],
      [() => exports2.SSHPublicKey$]
    ];
    exports2.GetUserPolicyRequest$ = [
      3,
      n032,
      _GUPR,
      0,
      [_UN, _PN],
      [0, 0],
      2
    ];
    exports2.GetUserPolicyResponse$ = [
      3,
      n032,
      _GUPRe,
      0,
      [_UN, _PN, _PD],
      [0, 0, 0],
      3
    ];
    exports2.GetUserRequest$ = [
      3,
      n032,
      _GUR,
      0,
      [_UN],
      [0]
    ];
    exports2.GetUserResponse$ = [
      3,
      n032,
      _GURe,
      0,
      [_Us],
      [() => exports2.User$],
      1
    ];
    exports2.Group$ = [
      3,
      n032,
      _G,
      0,
      [_Pa, _GN, _GI2, _A10, _CD],
      [0, 0, 0, 0, 4],
      5
    ];
    exports2.GroupDetail$ = [
      3,
      n032,
      _GD,
      0,
      [_Pa, _GN, _GI2, _A10, _CD, _GPL, _AMP],
      [0, 0, 0, 0, 4, () => policyDetailListType, () => attachedPoliciesListType]
    ];
    exports2.InstanceProfile$ = [
      3,
      n032,
      _IP,
      0,
      [_Pa, _IPN, _IPI2, _A10, _CD, _Rol, _T10],
      [0, 0, 0, 0, 4, () => roleListType, () => tagListType10],
      6
    ];
    exports2.ListAccessKeysRequest$ = [
      3,
      n032,
      _LAKR,
      0,
      [_UN, _Ma, _MI],
      [0, 0, 1]
    ];
    exports2.ListAccessKeysResponse$ = [
      3,
      n032,
      _LAKRi,
      0,
      [_AKM, _IT4, _Ma],
      [() => accessKeyMetadataListType, 2, 0],
      1
    ];
    exports2.ListAccountAliasesRequest$ = [
      3,
      n032,
      _LAAR,
      0,
      [_Ma, _MI],
      [0, 1]
    ];
    exports2.ListAccountAliasesResponse$ = [
      3,
      n032,
      _LAARi,
      0,
      [_AAc, _IT4, _Ma],
      [64 | 0, 2, 0],
      1
    ];
    exports2.ListAttachedGroupPoliciesRequest$ = [
      3,
      n032,
      _LAGPR,
      0,
      [_GN, _PPat, _Ma, _MI],
      [0, 0, 0, 1],
      1
    ];
    exports2.ListAttachedGroupPoliciesResponse$ = [
      3,
      n032,
      _LAGPRi,
      0,
      [_APt, _IT4, _Ma],
      [() => attachedPoliciesListType, 2, 0]
    ];
    exports2.ListAttachedRolePoliciesRequest$ = [
      3,
      n032,
      _LARPR,
      0,
      [_RN, _PPat, _Ma, _MI],
      [0, 0, 0, 1],
      1
    ];
    exports2.ListAttachedRolePoliciesResponse$ = [
      3,
      n032,
      _LARPRi,
      0,
      [_APt, _IT4, _Ma],
      [() => attachedPoliciesListType, 2, 0]
    ];
    exports2.ListAttachedUserPoliciesRequest$ = [
      3,
      n032,
      _LAUPR,
      0,
      [_UN, _PPat, _Ma, _MI],
      [0, 0, 0, 1],
      1
    ];
    exports2.ListAttachedUserPoliciesResponse$ = [
      3,
      n032,
      _LAUPRi,
      0,
      [_APt, _IT4, _Ma],
      [() => attachedPoliciesListType, 2, 0]
    ];
    exports2.ListDelegationRequestsRequest$ = [
      3,
      n032,
      _LDRR,
      0,
      [_OI, _Ma, _MI],
      [0, 0, 1]
    ];
    exports2.ListDelegationRequestsResponse$ = [
      3,
      n032,
      _LDRRi,
      0,
      [_DRe, _Ma, _iT13],
      [() => delegationRequestsListType, 0, 2]
    ];
    exports2.ListEntitiesForPolicyRequest$ = [
      3,
      n032,
      _LEFPR,
      0,
      [_PA10, _EFn, _PPat, _PUF, _Ma, _MI],
      [0, 0, 0, 0, 0, 1],
      1
    ];
    exports2.ListEntitiesForPolicyResponse$ = [
      3,
      n032,
      _LEFPRi,
      0,
      [_PG, _PU, _PR, _IT4, _Ma],
      [() => PolicyGroupListType, () => PolicyUserListType, () => PolicyRoleListType, 2, 0]
    ];
    exports2.ListGroupPoliciesRequest$ = [
      3,
      n032,
      _LGPR,
      0,
      [_GN, _Ma, _MI],
      [0, 0, 1],
      1
    ];
    exports2.ListGroupPoliciesResponse$ = [
      3,
      n032,
      _LGPRi,
      0,
      [_PNo, _IT4, _Ma],
      [64 | 0, 2, 0],
      1
    ];
    exports2.ListGroupsForUserRequest$ = [
      3,
      n032,
      _LGFUR,
      0,
      [_UN, _Ma, _MI],
      [0, 0, 1],
      1
    ];
    exports2.ListGroupsForUserResponse$ = [
      3,
      n032,
      _LGFURi,
      0,
      [_Gro, _IT4, _Ma],
      [() => groupListType, 2, 0],
      1
    ];
    exports2.ListGroupsRequest$ = [
      3,
      n032,
      _LGR,
      0,
      [_PPat, _Ma, _MI],
      [0, 0, 1]
    ];
    exports2.ListGroupsResponse$ = [
      3,
      n032,
      _LGRi,
      0,
      [_Gro, _IT4, _Ma],
      [() => groupListType, 2, 0],
      1
    ];
    exports2.ListInstanceProfilesForRoleRequest$ = [
      3,
      n032,
      _LIPFRR,
      0,
      [_RN, _Ma, _MI],
      [0, 0, 1],
      1
    ];
    exports2.ListInstanceProfilesForRoleResponse$ = [
      3,
      n032,
      _LIPFRRi,
      0,
      [_IPn, _IT4, _Ma],
      [() => instanceProfileListType, 2, 0],
      1
    ];
    exports2.ListInstanceProfilesRequest$ = [
      3,
      n032,
      _LIPR,
      0,
      [_PPat, _Ma, _MI],
      [0, 0, 1]
    ];
    exports2.ListInstanceProfilesResponse$ = [
      3,
      n032,
      _LIPRi,
      0,
      [_IPn, _IT4, _Ma],
      [() => instanceProfileListType, 2, 0],
      1
    ];
    exports2.ListInstanceProfileTagsRequest$ = [
      3,
      n032,
      _LIPTR,
      0,
      [_IPN, _Ma, _MI],
      [0, 0, 1],
      1
    ];
    exports2.ListInstanceProfileTagsResponse$ = [
      3,
      n032,
      _LIPTRi,
      0,
      [_T10, _IT4, _Ma],
      [() => tagListType10, 2, 0],
      1
    ];
    exports2.ListMFADevicesRequest$ = [
      3,
      n032,
      _LMFADR,
      0,
      [_UN, _Ma, _MI],
      [0, 0, 1]
    ];
    exports2.ListMFADevicesResponse$ = [
      3,
      n032,
      _LMFADRi,
      0,
      [_MFAD, _IT4, _Ma],
      [() => mfaDeviceListType, 2, 0],
      1
    ];
    exports2.ListMFADeviceTagsRequest$ = [
      3,
      n032,
      _LMFADTR,
      0,
      [_SNer, _Ma, _MI],
      [0, 0, 1],
      1
    ];
    exports2.ListMFADeviceTagsResponse$ = [
      3,
      n032,
      _LMFADTRi,
      0,
      [_T10, _IT4, _Ma],
      [() => tagListType10, 2, 0],
      1
    ];
    exports2.ListOpenIDConnectProvidersRequest$ = [
      3,
      n032,
      _LOIDCPR,
      0,
      [],
      []
    ];
    exports2.ListOpenIDConnectProvidersResponse$ = [
      3,
      n032,
      _LOIDCPRi,
      0,
      [_OIDCPL],
      [() => OpenIDConnectProviderListType]
    ];
    exports2.ListOpenIDConnectProviderTagsRequest$ = [
      3,
      n032,
      _LOIDCPTR,
      0,
      [_OIDCPA, _Ma, _MI],
      [0, 0, 1],
      1
    ];
    exports2.ListOpenIDConnectProviderTagsResponse$ = [
      3,
      n032,
      _LOIDCPTRi,
      0,
      [_T10, _IT4, _Ma],
      [() => tagListType10, 2, 0],
      1
    ];
    exports2.ListOrganizationsFeaturesRequest$ = [
      3,
      n032,
      _LOFR,
      0,
      [],
      []
    ];
    exports2.ListOrganizationsFeaturesResponse$ = [
      3,
      n032,
      _LOFRi,
      0,
      [_OIr, _EF],
      [0, 64 | 0]
    ];
    exports2.ListPoliciesGrantingServiceAccessEntry$ = [
      3,
      n032,
      _LPGSAE,
      0,
      [_SNe, _Pol],
      [0, () => policyGrantingServiceAccessListType]
    ];
    exports2.ListPoliciesGrantingServiceAccessRequest$ = [
      3,
      n032,
      _LPGSAR,
      0,
      [_A10, _SNerv, _Ma],
      [0, 64 | 0, 0],
      2
    ];
    exports2.ListPoliciesGrantingServiceAccessResponse$ = [
      3,
      n032,
      _LPGSARi,
      0,
      [_PGSA, _IT4, _Ma],
      [() => listPolicyGrantingServiceAccessResponseListType, 2, 0],
      1
    ];
    exports2.ListPoliciesRequest$ = [
      3,
      n032,
      _LPR,
      0,
      [_Sc, _OA, _PPat, _PUF, _Ma, _MI],
      [0, 2, 0, 0, 0, 1]
    ];
    exports2.ListPoliciesResponse$ = [
      3,
      n032,
      _LPRi,
      0,
      [_Pol, _IT4, _Ma],
      [() => policyListType, 2, 0]
    ];
    exports2.ListPolicyTagsRequest$ = [
      3,
      n032,
      _LPTR,
      0,
      [_PA10, _Ma, _MI],
      [0, 0, 1],
      1
    ];
    exports2.ListPolicyTagsResponse$ = [
      3,
      n032,
      _LPTRi,
      0,
      [_T10, _IT4, _Ma],
      [() => tagListType10, 2, 0],
      1
    ];
    exports2.ListPolicyVersionsRequest$ = [
      3,
      n032,
      _LPVR,
      0,
      [_PA10, _Ma, _MI],
      [0, 0, 1],
      1
    ];
    exports2.ListPolicyVersionsResponse$ = [
      3,
      n032,
      _LPVRi,
      0,
      [_V10, _IT4, _Ma],
      [() => policyDocumentVersionListType, 2, 0]
    ];
    exports2.ListRolePoliciesRequest$ = [
      3,
      n032,
      _LRPR,
      0,
      [_RN, _Ma, _MI],
      [0, 0, 1],
      1
    ];
    exports2.ListRolePoliciesResponse$ = [
      3,
      n032,
      _LRPRi,
      0,
      [_PNo, _IT4, _Ma],
      [64 | 0, 2, 0],
      1
    ];
    exports2.ListRolesRequest$ = [
      3,
      n032,
      _LRR,
      0,
      [_PPat, _Ma, _MI],
      [0, 0, 1]
    ];
    exports2.ListRolesResponse$ = [
      3,
      n032,
      _LRRi,
      0,
      [_Rol, _IT4, _Ma],
      [() => roleListType, 2, 0],
      1
    ];
    exports2.ListRoleTagsRequest$ = [
      3,
      n032,
      _LRTR,
      0,
      [_RN, _Ma, _MI],
      [0, 0, 1],
      1
    ];
    exports2.ListRoleTagsResponse$ = [
      3,
      n032,
      _LRTRi,
      0,
      [_T10, _IT4, _Ma],
      [() => tagListType10, 2, 0],
      1
    ];
    exports2.ListSAMLProvidersRequest$ = [
      3,
      n032,
      _LSAMLPR,
      0,
      [],
      []
    ];
    exports2.ListSAMLProvidersResponse$ = [
      3,
      n032,
      _LSAMLPRi,
      0,
      [_SAMLPL],
      [() => SAMLProviderListType]
    ];
    exports2.ListSAMLProviderTagsRequest$ = [
      3,
      n032,
      _LSAMLPTR,
      0,
      [_SAMLPA, _Ma, _MI],
      [0, 0, 1],
      1
    ];
    exports2.ListSAMLProviderTagsResponse$ = [
      3,
      n032,
      _LSAMLPTRi,
      0,
      [_T10, _IT4, _Ma],
      [() => tagListType10, 2, 0],
      1
    ];
    exports2.ListServerCertificatesRequest$ = [
      3,
      n032,
      _LSCR,
      0,
      [_PPat, _Ma, _MI],
      [0, 0, 1]
    ];
    exports2.ListServerCertificatesResponse$ = [
      3,
      n032,
      _LSCRi,
      0,
      [_SCML, _IT4, _Ma],
      [() => serverCertificateMetadataListType, 2, 0],
      1
    ];
    exports2.ListServerCertificateTagsRequest$ = [
      3,
      n032,
      _LSCTR,
      0,
      [_SCN, _Ma, _MI],
      [0, 0, 1],
      1
    ];
    exports2.ListServerCertificateTagsResponse$ = [
      3,
      n032,
      _LSCTRi,
      0,
      [_T10, _IT4, _Ma],
      [() => tagListType10, 2, 0],
      1
    ];
    exports2.ListServiceSpecificCredentialsRequest$ = [
      3,
      n032,
      _LSSCR,
      0,
      [_UN, _SN10, _AU, _Ma, _MI],
      [0, 0, 2, 0, 1]
    ];
    exports2.ListServiceSpecificCredentialsResponse$ = [
      3,
      n032,
      _LSSCRi,
      0,
      [_SSCe, _Ma, _IT4],
      [() => ServiceSpecificCredentialsListType, 0, 2]
    ];
    exports2.ListSigningCertificatesRequest$ = [
      3,
      n032,
      _LSCRis,
      0,
      [_UN, _Ma, _MI],
      [0, 0, 1]
    ];
    exports2.ListSigningCertificatesResponse$ = [
      3,
      n032,
      _LSCRist,
      0,
      [_Cer, _IT4, _Ma],
      [() => certificateListType, 2, 0],
      1
    ];
    exports2.ListSSHPublicKeysRequest$ = [
      3,
      n032,
      _LSSHPKR,
      0,
      [_UN, _Ma, _MI],
      [0, 0, 1]
    ];
    exports2.ListSSHPublicKeysResponse$ = [
      3,
      n032,
      _LSSHPKRi,
      0,
      [_SSHPKu, _IT4, _Ma],
      [() => SSHPublicKeyListType, 2, 0]
    ];
    exports2.ListUserPoliciesRequest$ = [
      3,
      n032,
      _LUPR,
      0,
      [_UN, _Ma, _MI],
      [0, 0, 1],
      1
    ];
    exports2.ListUserPoliciesResponse$ = [
      3,
      n032,
      _LUPRi,
      0,
      [_PNo, _IT4, _Ma],
      [64 | 0, 2, 0],
      1
    ];
    exports2.ListUsersRequest$ = [
      3,
      n032,
      _LUR,
      0,
      [_PPat, _Ma, _MI],
      [0, 0, 1]
    ];
    exports2.ListUsersResponse$ = [
      3,
      n032,
      _LURi,
      0,
      [_Use, _IT4, _Ma],
      [() => userListType, 2, 0],
      1
    ];
    exports2.ListUserTagsRequest$ = [
      3,
      n032,
      _LUTR,
      0,
      [_UN, _Ma, _MI],
      [0, 0, 1],
      1
    ];
    exports2.ListUserTagsResponse$ = [
      3,
      n032,
      _LUTRi,
      0,
      [_T10, _IT4, _Ma],
      [() => tagListType10, 2, 0],
      1
    ];
    exports2.ListVirtualMFADevicesRequest$ = [
      3,
      n032,
      _LVMFADR,
      0,
      [_AS, _Ma, _MI],
      [0, 0, 1]
    ];
    exports2.ListVirtualMFADevicesResponse$ = [
      3,
      n032,
      _LVMFADRi,
      0,
      [_VMFADi, _IT4, _Ma],
      [[() => virtualMFADeviceListType, 0], 2, 0],
      1
    ];
    exports2.LoginProfile$ = [
      3,
      n032,
      _LP,
      0,
      [_UN, _CD, _PRR],
      [0, 4, 2],
      2
    ];
    exports2.ManagedPolicyDetail$ = [
      3,
      n032,
      _MPD,
      0,
      [_PN, _PI10, _A10, _Pa, _DVI, _ACt, _PBUC, _IA, _D, _CD, _UD, _PVL],
      [0, 0, 0, 0, 0, 1, 1, 2, 0, 4, 4, () => policyDocumentVersionListType]
    ];
    exports2.MFADevice$ = [
      3,
      n032,
      _MFADe,
      0,
      [_UN, _SNer, _EDn],
      [0, 0, 4],
      3
    ];
    exports2.OpenIDConnectProviderListEntry$ = [
      3,
      n032,
      _OIDCPLE,
      0,
      [_A10],
      [0]
    ];
    exports2.OrganizationsDecisionDetail$ = [
      3,
      n032,
      _ODD,
      0,
      [_ABO],
      [2]
    ];
    exports2.PasswordPolicy$ = [
      3,
      n032,
      _PPa,
      0,
      [_MPL, _RS, _RNeq, _RUC, _RLC, _AUTCP, _EPx, _MPA, _PRP, _HE],
      [1, 2, 2, 2, 2, 2, 2, 1, 1, 2]
    ];
    exports2.PermissionsBoundaryDecisionDetail$ = [
      3,
      n032,
      _PBDD,
      0,
      [_ABPB],
      [2]
    ];
    exports2.Policy$ = [
      3,
      n032,
      _Po,
      0,
      [_PN, _PI10, _A10, _Pa, _DVI, _ACt, _PBUC, _IA, _D, _CD, _UD, _T10],
      [0, 0, 0, 0, 0, 1, 1, 2, 0, 4, 4, () => tagListType10]
    ];
    exports2.PolicyDetail$ = [
      3,
      n032,
      _PDo,
      0,
      [_PN, _PD],
      [0, 0]
    ];
    exports2.PolicyGrantingServiceAccess$ = [
      3,
      n032,
      _PGSAo,
      0,
      [_PN, _PT, _PA10, _ETn, _EN],
      [0, 0, 0, 0, 0],
      2
    ];
    exports2.PolicyGroup$ = [
      3,
      n032,
      _PGo,
      0,
      [_GN, _GI2],
      [0, 0]
    ];
    exports2.PolicyParameter$ = [
      3,
      n032,
      _PPo,
      0,
      [_N, _Va, _Ty],
      [0, 64 | 0, 0]
    ];
    exports2.PolicyRole$ = [
      3,
      n032,
      _PRo,
      0,
      [_RN, _RIo],
      [0, 0]
    ];
    exports2.PolicyUser$ = [
      3,
      n032,
      _PUo,
      0,
      [_UN, _UI],
      [0, 0]
    ];
    exports2.PolicyVersion$ = [
      3,
      n032,
      _PV,
      0,
      [_Do, _VI, _IDV, _CD],
      [0, 0, 2, 4]
    ];
    exports2.Position$ = [
      3,
      n032,
      _Pos,
      0,
      [_Li, _Col],
      [1, 1]
    ];
    exports2.PutGroupPolicyRequest$ = [
      3,
      n032,
      _PGPR,
      0,
      [_GN, _PN, _PD],
      [0, 0, 0],
      3
    ];
    exports2.PutRolePermissionsBoundaryRequest$ = [
      3,
      n032,
      _PRPBR,
      0,
      [_RN, _PB],
      [0, 0],
      2
    ];
    exports2.PutRolePolicyRequest$ = [
      3,
      n032,
      _PRPR,
      0,
      [_RN, _PN, _PD],
      [0, 0, 0],
      3
    ];
    exports2.PutUserPermissionsBoundaryRequest$ = [
      3,
      n032,
      _PUPBR,
      0,
      [_UN, _PB],
      [0, 0],
      2
    ];
    exports2.PutUserPolicyRequest$ = [
      3,
      n032,
      _PUPR,
      0,
      [_UN, _PN, _PD],
      [0, 0, 0],
      3
    ];
    exports2.RejectDelegationRequestRequest$ = [
      3,
      n032,
      _RDRR,
      0,
      [_DRI, _No],
      [0, 0],
      1
    ];
    exports2.RemoveClientIDFromOpenIDConnectProviderRequest$ = [
      3,
      n032,
      _RCIDFOIDCPR,
      0,
      [_OIDCPA, _CID],
      [0, 0],
      2
    ];
    exports2.RemoveRoleFromInstanceProfileRequest$ = [
      3,
      n032,
      _RRFIPR,
      0,
      [_IPN, _RN],
      [0, 0],
      2
    ];
    exports2.RemoveUserFromGroupRequest$ = [
      3,
      n032,
      _RUFGR,
      0,
      [_GN, _UN],
      [0, 0],
      2
    ];
    exports2.ResetServiceSpecificCredentialRequest$ = [
      3,
      n032,
      _RSSCR,
      0,
      [_SSCI, _UN],
      [0, 0],
      1
    ];
    exports2.ResetServiceSpecificCredentialResponse$ = [
      3,
      n032,
      _RSSCRe,
      0,
      [_SSC],
      [[() => exports2.ServiceSpecificCredential$, 0]]
    ];
    exports2.ResourceSpecificResult$ = [
      3,
      n032,
      _RSRe,
      0,
      [_ERN, _ERD, _MS, _MCV, _EDD, _PBDD],
      [0, 0, () => StatementListType, 64 | 0, 128 | 0, () => exports2.PermissionsBoundaryDecisionDetail$],
      2
    ];
    exports2.ResyncMFADeviceRequest$ = [
      3,
      n032,
      _RMFADR,
      0,
      [_UN, _SNer, _AC, _ACu],
      [0, 0, 0, 0],
      4
    ];
    exports2.Role$ = [
      3,
      n032,
      _Ro,
      0,
      [_Pa, _RN, _RIo, _A10, _CD, _ARPD, _D, _MSD, _PB, _T10, _RLU],
      [0, 0, 0, 0, 4, 0, 0, 1, () => exports2.AttachedPermissionsBoundary$, () => tagListType10, () => exports2.RoleLastUsed$],
      5
    ];
    exports2.RoleDetail$ = [
      3,
      n032,
      _RD,
      0,
      [_Pa, _RN, _RIo, _A10, _CD, _ARPD, _IPL, _RPL, _AMP, _PB, _T10, _RLU],
      [0, 0, 0, 0, 4, 0, () => instanceProfileListType, () => policyDetailListType, () => attachedPoliciesListType, () => exports2.AttachedPermissionsBoundary$, () => tagListType10, () => exports2.RoleLastUsed$]
    ];
    exports2.RoleLastUsed$ = [
      3,
      n032,
      _RLU,
      0,
      [_LUD, _R],
      [4, 0]
    ];
    exports2.RoleUsageType$ = [
      3,
      n032,
      _RUT,
      0,
      [_R, _Res],
      [0, 64 | 0]
    ];
    exports2.SAMLPrivateKey$ = [
      3,
      n032,
      _SAMLPK,
      0,
      [_KI, _Ti],
      [0, 4]
    ];
    exports2.SAMLProviderListEntry$ = [
      3,
      n032,
      _SAMLPLE,
      0,
      [_A10, _VU, _CD],
      [0, 4, 4]
    ];
    exports2.SendDelegationTokenRequest$ = [
      3,
      n032,
      _SDTR,
      0,
      [_DRI],
      [0],
      1
    ];
    exports2.ServerCertificate$ = [
      3,
      n032,
      _SCe,
      0,
      [_SCM, _CB, _CC, _T10],
      [() => exports2.ServerCertificateMetadata$, 0, 0, () => tagListType10],
      2
    ];
    exports2.ServerCertificateMetadata$ = [
      3,
      n032,
      _SCM,
      0,
      [_Pa, _SCN, _SCI, _A10, _UDp, _Ex],
      [0, 0, 0, 0, 4, 4],
      4
    ];
    exports2.ServiceLastAccessed$ = [
      3,
      n032,
      _SLAe,
      0,
      [_SN10, _SNe, _LA, _LAE, _LAR, _TAE, _TALA],
      [0, 0, 4, 0, 0, 1, () => TrackedActionsLastAccessed],
      2
    ];
    exports2.ServiceSpecificCredential$ = [
      3,
      n032,
      _SSC,
      0,
      [_CD, _SN10, _SSCI, _UN, _S, _EDx, _SUN, _SP, _SCA, _SCS],
      [4, 0, 0, 0, 0, 4, 0, [() => servicePassword, 0], 0, [() => serviceCredentialSecret, 0]],
      5
    ];
    exports2.ServiceSpecificCredentialMetadata$ = [
      3,
      n032,
      _SSCM,
      0,
      [_UN, _S, _CD, _SSCI, _SN10, _SUN, _SCA, _EDx],
      [0, 0, 4, 0, 0, 0, 0, 4],
      5
    ];
    exports2.SetDefaultPolicyVersionRequest$ = [
      3,
      n032,
      _SDPVR,
      0,
      [_PA10, _VI],
      [0, 0],
      2
    ];
    exports2.SetSecurityTokenServicePreferencesRequest$ = [
      3,
      n032,
      _SSTSPR,
      0,
      [_GETV],
      [0],
      1
    ];
    exports2.SigningCertificate$ = [
      3,
      n032,
      _SCi,
      0,
      [_UN, _CI, _CB, _S, _UDp],
      [0, 0, 0, 0, 4],
      4
    ];
    exports2.SimulateCustomPolicyRequest$ = [
      3,
      n032,
      _SCPR,
      0,
      [_PIL, _AN, _PBPIL, _RA10, _RP, _RO, _CA10, _CEo, _RHO, _MI, _Ma],
      [64 | 0, 64 | 0, 64 | 0, 64 | 0, 0, 0, 0, () => ContextEntryListType, 0, 1, 0],
      2
    ];
    exports2.SimulatePolicyResponse$ = [
      3,
      n032,
      _SPR,
      0,
      [_ERv, _IT4, _Ma],
      [() => EvaluationResultsListType, 2, 0]
    ];
    exports2.SimulatePrincipalPolicyRequest$ = [
      3,
      n032,
      _SPPR,
      0,
      [_PSA, _AN, _PIL, _PBPIL, _RA10, _RP, _RO, _CA10, _CEo, _RHO, _MI, _Ma],
      [0, 64 | 0, 64 | 0, 64 | 0, 64 | 0, 0, 0, 0, () => ContextEntryListType, 0, 1, 0],
      2
    ];
    exports2.SSHPublicKey$ = [
      3,
      n032,
      _SSHPK,
      0,
      [_UN, _SSHPKI, _Fi, _SSHPKB, _S, _UDp],
      [0, 0, 0, 0, 0, 4],
      5
    ];
    exports2.SSHPublicKeyMetadata$ = [
      3,
      n032,
      _SSHPKM,
      0,
      [_UN, _SSHPKI, _S, _UDp],
      [0, 0, 0, 4],
      4
    ];
    exports2.Statement$ = [
      3,
      n032,
      _Sta,
      0,
      [_SPI, _SPT, _SPt, _EPn],
      [0, 0, () => exports2.Position$, () => exports2.Position$]
    ];
    exports2.Tag$ = [
      3,
      n032,
      _Ta10,
      0,
      [_K10, _Val],
      [0, 0],
      2
    ];
    exports2.TagInstanceProfileRequest$ = [
      3,
      n032,
      _TIPR,
      0,
      [_IPN, _T10],
      [0, () => tagListType10],
      2
    ];
    exports2.TagMFADeviceRequest$ = [
      3,
      n032,
      _TMFADR,
      0,
      [_SNer, _T10],
      [0, () => tagListType10],
      2
    ];
    exports2.TagOpenIDConnectProviderRequest$ = [
      3,
      n032,
      _TOIDCPR,
      0,
      [_OIDCPA, _T10],
      [0, () => tagListType10],
      2
    ];
    exports2.TagPolicyRequest$ = [
      3,
      n032,
      _TPR,
      0,
      [_PA10, _T10],
      [0, () => tagListType10],
      2
    ];
    exports2.TagRoleRequest$ = [
      3,
      n032,
      _TRR,
      0,
      [_RN, _T10],
      [0, () => tagListType10],
      2
    ];
    exports2.TagSAMLProviderRequest$ = [
      3,
      n032,
      _TSAMLPR,
      0,
      [_SAMLPA, _T10],
      [0, () => tagListType10],
      2
    ];
    exports2.TagServerCertificateRequest$ = [
      3,
      n032,
      _TSCR,
      0,
      [_SCN, _T10],
      [0, () => tagListType10],
      2
    ];
    exports2.TagUserRequest$ = [
      3,
      n032,
      _TUR,
      0,
      [_UN, _T10],
      [0, () => tagListType10],
      2
    ];
    exports2.TrackedActionLastAccessed$ = [
      3,
      n032,
      _TALAr,
      0,
      [_ANc, _LAEa, _LATa, _LARa],
      [0, 0, 4, 0]
    ];
    exports2.UntagInstanceProfileRequest$ = [
      3,
      n032,
      _UIPR,
      0,
      [_IPN, _TK],
      [0, 64 | 0],
      2
    ];
    exports2.UntagMFADeviceRequest$ = [
      3,
      n032,
      _UMFADR,
      0,
      [_SNer, _TK],
      [0, 64 | 0],
      2
    ];
    exports2.UntagOpenIDConnectProviderRequest$ = [
      3,
      n032,
      _UOIDCPR,
      0,
      [_OIDCPA, _TK],
      [0, 64 | 0],
      2
    ];
    exports2.UntagPolicyRequest$ = [
      3,
      n032,
      _UPR,
      0,
      [_PA10, _TK],
      [0, 64 | 0],
      2
    ];
    exports2.UntagRoleRequest$ = [
      3,
      n032,
      _URR,
      0,
      [_RN, _TK],
      [0, 64 | 0],
      2
    ];
    exports2.UntagSAMLProviderRequest$ = [
      3,
      n032,
      _USAMLPR,
      0,
      [_SAMLPA, _TK],
      [0, 64 | 0],
      2
    ];
    exports2.UntagServerCertificateRequest$ = [
      3,
      n032,
      _USCR,
      0,
      [_SCN, _TK],
      [0, 64 | 0],
      2
    ];
    exports2.UntagUserRequest$ = [
      3,
      n032,
      _UUR,
      0,
      [_UN, _TK],
      [0, 64 | 0],
      2
    ];
    exports2.UpdateAccessKeyRequest$ = [
      3,
      n032,
      _UAKR,
      0,
      [_AKI11, _S, _UN],
      [0, 0, 0],
      2
    ];
    exports2.UpdateAccountPasswordPolicyRequest$ = [
      3,
      n032,
      _UAPPR,
      0,
      [_MPL, _RS, _RNeq, _RUC, _RLC, _AUTCP, _MPA, _PRP, _HE],
      [1, 2, 2, 2, 2, 2, 1, 1, 2]
    ];
    exports2.UpdateAssumeRolePolicyRequest$ = [
      3,
      n032,
      _UARPR,
      0,
      [_RN, _PD],
      [0, 0],
      2
    ];
    exports2.UpdateDelegationRequestRequest$ = [
      3,
      n032,
      _UDRR,
      0,
      [_DRI, _No],
      [0, 0],
      1
    ];
    exports2.UpdateGroupRequest$ = [
      3,
      n032,
      _UGR,
      0,
      [_GN, _NPe, _NGN],
      [0, 0, 0],
      1
    ];
    exports2.UpdateLoginProfileRequest$ = [
      3,
      n032,
      _ULPR,
      0,
      [_UN, _Pas, _PRR],
      [0, [() => passwordType, 0], 2],
      1
    ];
    exports2.UpdateOpenIDConnectProviderThumbprintRequest$ = [
      3,
      n032,
      _UOIDCPTR,
      0,
      [_OIDCPA, _TL],
      [0, 64 | 0],
      2
    ];
    exports2.UpdateRoleDescriptionRequest$ = [
      3,
      n032,
      _URDR,
      0,
      [_RN, _D],
      [0, 0],
      2
    ];
    exports2.UpdateRoleDescriptionResponse$ = [
      3,
      n032,
      _URDRp,
      0,
      [_Ro],
      [() => exports2.Role$]
    ];
    exports2.UpdateRoleRequest$ = [
      3,
      n032,
      _URRp,
      0,
      [_RN, _D, _MSD],
      [0, 0, 1],
      1
    ];
    exports2.UpdateRoleResponse$ = [
      3,
      n032,
      _URRpd,
      0,
      [],
      []
    ];
    exports2.UpdateSAMLProviderRequest$ = [
      3,
      n032,
      _USAMLPRp,
      0,
      [_SAMLPA, _SAMLMD, _AEM, _APK, _RPK],
      [0, 0, 0, [() => privateKeyType, 0], 0],
      1
    ];
    exports2.UpdateSAMLProviderResponse$ = [
      3,
      n032,
      _USAMLPRpd,
      0,
      [_SAMLPA],
      [0]
    ];
    exports2.UpdateServerCertificateRequest$ = [
      3,
      n032,
      _USCRp,
      0,
      [_SCN, _NPe, _NSCN],
      [0, 0, 0],
      1
    ];
    exports2.UpdateServiceSpecificCredentialRequest$ = [
      3,
      n032,
      _USSCR,
      0,
      [_SSCI, _S, _UN],
      [0, 0, 0],
      2
    ];
    exports2.UpdateSigningCertificateRequest$ = [
      3,
      n032,
      _USCRpd,
      0,
      [_CI, _S, _UN],
      [0, 0, 0],
      2
    ];
    exports2.UpdateSSHPublicKeyRequest$ = [
      3,
      n032,
      _USSHPKR,
      0,
      [_UN, _SSHPKI, _S],
      [0, 0, 0],
      3
    ];
    exports2.UpdateUserRequest$ = [
      3,
      n032,
      _UURp,
      0,
      [_UN, _NPe, _NUN],
      [0, 0, 0],
      1
    ];
    exports2.UploadServerCertificateRequest$ = [
      3,
      n032,
      _USCRpl,
      0,
      [_SCN, _CB, _PK, _Pa, _CC, _T10],
      [0, 0, [() => privateKeyType, 0], 0, 0, () => tagListType10],
      3
    ];
    exports2.UploadServerCertificateResponse$ = [
      3,
      n032,
      _USCRplo,
      0,
      [_SCM, _T10],
      [() => exports2.ServerCertificateMetadata$, () => tagListType10]
    ];
    exports2.UploadSigningCertificateRequest$ = [
      3,
      n032,
      _USCRploa,
      0,
      [_CB, _UN],
      [0, 0],
      1
    ];
    exports2.UploadSigningCertificateResponse$ = [
      3,
      n032,
      _USCRpload,
      0,
      [_Cert],
      [() => exports2.SigningCertificate$],
      1
    ];
    exports2.UploadSSHPublicKeyRequest$ = [
      3,
      n032,
      _USSHPKRp,
      0,
      [_UN, _SSHPKB],
      [0, 0],
      2
    ];
    exports2.UploadSSHPublicKeyResponse$ = [
      3,
      n032,
      _USSHPKRpl,
      0,
      [_SSHPK],
      [() => exports2.SSHPublicKey$]
    ];
    exports2.User$ = [
      3,
      n032,
      _Us,
      0,
      [_Pa, _UN, _UI, _A10, _CD, _PLU, _PB, _T10],
      [0, 0, 0, 0, 4, 4, () => exports2.AttachedPermissionsBoundary$, () => tagListType10],
      5
    ];
    exports2.UserDetail$ = [
      3,
      n032,
      _UDs,
      0,
      [_Pa, _UN, _UI, _A10, _CD, _UPL, _GL, _AMP, _PB, _T10],
      [0, 0, 0, 0, 4, () => policyDetailListType, 64 | 0, () => attachedPoliciesListType, () => exports2.AttachedPermissionsBoundary$, () => tagListType10]
    ];
    exports2.VirtualMFADevice$ = [
      3,
      n032,
      _VMFAD,
      0,
      [_SNer, _BSS, _QRCPNG, _Us, _EDn, _T10],
      [0, [() => BootstrapDatum, 0], [() => BootstrapDatum, 0], () => exports2.User$, 4, () => tagListType10],
      1
    ];
    var __Unit = "unit";
    var AccessDetails = [
      1,
      n032,
      _ADc,
      0,
      () => exports2.AccessDetail$
    ];
    var accessKeyMetadataListType = [
      1,
      n032,
      _aKMLT,
      0,
      () => exports2.AccessKeyMetadata$
    ];
    var accountAliasListType = 64 | 0;
    var ActionNameListType = 64 | 0;
    var ArnListType = 64 | 0;
    var attachedPoliciesListType = [
      1,
      n032,
      _aPLT,
      0,
      () => exports2.AttachedPolicy$
    ];
    var certificateListType = [
      1,
      n032,
      _cLT,
      0,
      () => exports2.SigningCertificate$
    ];
    var clientIDListType = 64 | 0;
    var ContextEntryListType = [
      1,
      n032,
      _CELT,
      0,
      () => exports2.ContextEntry$
    ];
    var ContextKeyNamesResultListType = 64 | 0;
    var ContextKeyValueListType = 64 | 0;
    var delegationRequestsListType = [
      1,
      n032,
      _dRLT,
      0,
      () => exports2.DelegationRequest$
    ];
    var entityDetailsListType = [
      1,
      n032,
      _eDLT,
      0,
      () => exports2.EntityDetails$
    ];
    var entityListType = 64 | 0;
    var EvaluationResultsListType = [
      1,
      n032,
      _ERLT,
      0,
      () => exports2.EvaluationResult$
    ];
    var FeaturesListType = 64 | 0;
    var groupDetailListType = [
      1,
      n032,
      _gDLT,
      0,
      () => exports2.GroupDetail$
    ];
    var groupListType = [
      1,
      n032,
      _gLT,
      0,
      () => exports2.Group$
    ];
    var groupNameListType = 64 | 0;
    var instanceProfileListType = [
      1,
      n032,
      _iPLT,
      0,
      () => exports2.InstanceProfile$
    ];
    var listPolicyGrantingServiceAccessResponseListType = [
      1,
      n032,
      _lPGSARLT,
      0,
      () => exports2.ListPoliciesGrantingServiceAccessEntry$
    ];
    var ManagedPolicyDetailListType = [
      1,
      n032,
      _MPDLT,
      0,
      () => exports2.ManagedPolicyDetail$
    ];
    var mfaDeviceListType = [
      1,
      n032,
      _mDLT,
      0,
      () => exports2.MFADevice$
    ];
    var OpenIDConnectProviderListType = [
      1,
      n032,
      _OIDCPLT,
      0,
      () => exports2.OpenIDConnectProviderListEntry$
    ];
    var policyDetailListType = [
      1,
      n032,
      _pDLT10,
      0,
      () => exports2.PolicyDetail$
    ];
    var policyDocumentVersionListType = [
      1,
      n032,
      _pDVLT,
      0,
      () => exports2.PolicyVersion$
    ];
    var policyGrantingServiceAccessListType = [
      1,
      n032,
      _pGSALT,
      0,
      () => exports2.PolicyGrantingServiceAccess$
    ];
    var PolicyGroupListType = [
      1,
      n032,
      _PGLT,
      0,
      () => exports2.PolicyGroup$
    ];
    var policyListType = [
      1,
      n032,
      _pLT,
      0,
      () => exports2.Policy$
    ];
    var policyNameListType = 64 | 0;
    var policyParameterListType = [
      1,
      n032,
      _pPLT,
      0,
      () => exports2.PolicyParameter$
    ];
    var policyParameterValuesListType = 64 | 0;
    var PolicyRoleListType = [
      1,
      n032,
      _PRLT,
      0,
      () => exports2.PolicyRole$
    ];
    var PolicyUserListType = [
      1,
      n032,
      _PULT,
      0,
      () => exports2.PolicyUser$
    ];
    var privateKeyList = [
      1,
      n032,
      _pKL,
      0,
      () => exports2.SAMLPrivateKey$
    ];
    var ResourceNameListType = 64 | 0;
    var ResourceSpecificResultListType = [
      1,
      n032,
      _RSRLT,
      0,
      () => exports2.ResourceSpecificResult$
    ];
    var roleDetailListType = [
      1,
      n032,
      _rDLT,
      0,
      () => exports2.RoleDetail$
    ];
    var roleListType = [
      1,
      n032,
      _rLT,
      0,
      () => exports2.Role$
    ];
    var rolePermissionRestrictionArnListType = 64 | 0;
    var RoleUsageListType = [
      1,
      n032,
      _RULT,
      0,
      () => exports2.RoleUsageType$
    ];
    var SAMLProviderListType = [
      1,
      n032,
      _SAMLPLT,
      0,
      () => exports2.SAMLProviderListEntry$
    ];
    var serverCertificateMetadataListType = [
      1,
      n032,
      _sCMLT,
      0,
      () => exports2.ServerCertificateMetadata$
    ];
    var serviceNamespaceListType = 64 | 0;
    var ServicesLastAccessed = [
      1,
      n032,
      _SLA,
      0,
      () => exports2.ServiceLastAccessed$
    ];
    var ServiceSpecificCredentialsListType = [
      1,
      n032,
      _SSCLT,
      0,
      () => exports2.ServiceSpecificCredentialMetadata$
    ];
    var SimulationPolicyListType = 64 | 0;
    var SSHPublicKeyListType = [
      1,
      n032,
      _SSHPKLT,
      0,
      () => exports2.SSHPublicKeyMetadata$
    ];
    var StatementListType = [
      1,
      n032,
      _SLT,
      0,
      () => exports2.Statement$
    ];
    var tagKeyListType10 = 64 | 0;
    var tagListType10 = [
      1,
      n032,
      _tLT10,
      0,
      () => exports2.Tag$
    ];
    var thumbprintListType = 64 | 0;
    var TrackedActionsLastAccessed = [
      1,
      n032,
      _TALA,
      0,
      () => exports2.TrackedActionLastAccessed$
    ];
    var userDetailListType = [
      1,
      n032,
      _uDLT,
      0,
      () => exports2.UserDetail$
    ];
    var userListType = [
      1,
      n032,
      _uLT,
      0,
      () => exports2.User$
    ];
    var virtualMFADeviceListType = [
      1,
      n032,
      _vMFADLT,
      0,
      [
        () => exports2.VirtualMFADevice$,
        0
      ]
    ];
    var CertificationMapType = 128 | 0;
    var EvalDecisionDetailsType = 128 | 0;
    var summaryMapType = 128 | 1;
    exports2.AcceptDelegationRequest$ = [
      9,
      n032,
      _ADR,
      0,
      () => exports2.AcceptDelegationRequestRequest$,
      () => __Unit
    ];
    exports2.AddClientIDToOpenIDConnectProvider$ = [
      9,
      n032,
      _ACIDTOIDCP,
      0,
      () => exports2.AddClientIDToOpenIDConnectProviderRequest$,
      () => __Unit
    ];
    exports2.AddRoleToInstanceProfile$ = [
      9,
      n032,
      _ARTIP,
      0,
      () => exports2.AddRoleToInstanceProfileRequest$,
      () => __Unit
    ];
    exports2.AddUserToGroup$ = [
      9,
      n032,
      _AUTG,
      0,
      () => exports2.AddUserToGroupRequest$,
      () => __Unit
    ];
    exports2.AssociateDelegationRequest$ = [
      9,
      n032,
      _ADRs,
      0,
      () => exports2.AssociateDelegationRequestRequest$,
      () => __Unit
    ];
    exports2.AttachGroupPolicy$ = [
      9,
      n032,
      _AGP,
      0,
      () => exports2.AttachGroupPolicyRequest$,
      () => __Unit
    ];
    exports2.AttachRolePolicy$ = [
      9,
      n032,
      _ARP,
      0,
      () => exports2.AttachRolePolicyRequest$,
      () => __Unit
    ];
    exports2.AttachUserPolicy$ = [
      9,
      n032,
      _AUP,
      0,
      () => exports2.AttachUserPolicyRequest$,
      () => __Unit
    ];
    exports2.ChangePassword$ = [
      9,
      n032,
      _CP,
      0,
      () => exports2.ChangePasswordRequest$,
      () => __Unit
    ];
    exports2.CreateAccessKey$ = [
      9,
      n032,
      _CAK,
      0,
      () => exports2.CreateAccessKeyRequest$,
      () => exports2.CreateAccessKeyResponse$
    ];
    exports2.CreateAccountAlias$ = [
      9,
      n032,
      _CAA,
      0,
      () => exports2.CreateAccountAliasRequest$,
      () => __Unit
    ];
    exports2.CreateDelegationRequest$ = [
      9,
      n032,
      _CDR,
      0,
      () => exports2.CreateDelegationRequestRequest$,
      () => exports2.CreateDelegationRequestResponse$
    ];
    exports2.CreateGroup$ = [
      9,
      n032,
      _CG,
      0,
      () => exports2.CreateGroupRequest$,
      () => exports2.CreateGroupResponse$
    ];
    exports2.CreateInstanceProfile$ = [
      9,
      n032,
      _CIP,
      0,
      () => exports2.CreateInstanceProfileRequest$,
      () => exports2.CreateInstanceProfileResponse$
    ];
    exports2.CreateLoginProfile$ = [
      9,
      n032,
      _CLP,
      0,
      () => exports2.CreateLoginProfileRequest$,
      () => exports2.CreateLoginProfileResponse$
    ];
    exports2.CreateOpenIDConnectProvider$ = [
      9,
      n032,
      _COIDCP,
      0,
      () => exports2.CreateOpenIDConnectProviderRequest$,
      () => exports2.CreateOpenIDConnectProviderResponse$
    ];
    exports2.CreatePolicy$ = [
      9,
      n032,
      _CPr,
      0,
      () => exports2.CreatePolicyRequest$,
      () => exports2.CreatePolicyResponse$
    ];
    exports2.CreatePolicyVersion$ = [
      9,
      n032,
      _CPV,
      0,
      () => exports2.CreatePolicyVersionRequest$,
      () => exports2.CreatePolicyVersionResponse$
    ];
    exports2.CreateRole$ = [
      9,
      n032,
      _CR,
      0,
      () => exports2.CreateRoleRequest$,
      () => exports2.CreateRoleResponse$
    ];
    exports2.CreateSAMLProvider$ = [
      9,
      n032,
      _CSAMLP,
      0,
      () => exports2.CreateSAMLProviderRequest$,
      () => exports2.CreateSAMLProviderResponse$
    ];
    exports2.CreateServiceLinkedRole$ = [
      9,
      n032,
      _CSLR,
      0,
      () => exports2.CreateServiceLinkedRoleRequest$,
      () => exports2.CreateServiceLinkedRoleResponse$
    ];
    exports2.CreateServiceSpecificCredential$ = [
      9,
      n032,
      _CSSC,
      0,
      () => exports2.CreateServiceSpecificCredentialRequest$,
      () => exports2.CreateServiceSpecificCredentialResponse$
    ];
    exports2.CreateUser$ = [
      9,
      n032,
      _CU,
      0,
      () => exports2.CreateUserRequest$,
      () => exports2.CreateUserResponse$
    ];
    exports2.CreateVirtualMFADevice$ = [
      9,
      n032,
      _CVMFAD,
      0,
      () => exports2.CreateVirtualMFADeviceRequest$,
      () => exports2.CreateVirtualMFADeviceResponse$
    ];
    exports2.DeactivateMFADevice$ = [
      9,
      n032,
      _DMFAD,
      0,
      () => exports2.DeactivateMFADeviceRequest$,
      () => __Unit
    ];
    exports2.DeleteAccessKey$ = [
      9,
      n032,
      _DAK,
      0,
      () => exports2.DeleteAccessKeyRequest$,
      () => __Unit
    ];
    exports2.DeleteAccountAlias$ = [
      9,
      n032,
      _DAA,
      0,
      () => exports2.DeleteAccountAliasRequest$,
      () => __Unit
    ];
    exports2.DeleteAccountPasswordPolicy$ = [
      9,
      n032,
      _DAPP,
      0,
      () => __Unit,
      () => __Unit
    ];
    exports2.DeleteGroup$ = [
      9,
      n032,
      _DG,
      0,
      () => exports2.DeleteGroupRequest$,
      () => __Unit
    ];
    exports2.DeleteGroupPolicy$ = [
      9,
      n032,
      _DGP,
      0,
      () => exports2.DeleteGroupPolicyRequest$,
      () => __Unit
    ];
    exports2.DeleteInstanceProfile$ = [
      9,
      n032,
      _DIP,
      0,
      () => exports2.DeleteInstanceProfileRequest$,
      () => __Unit
    ];
    exports2.DeleteLoginProfile$ = [
      9,
      n032,
      _DLP,
      0,
      () => exports2.DeleteLoginProfileRequest$,
      () => __Unit
    ];
    exports2.DeleteOpenIDConnectProvider$ = [
      9,
      n032,
      _DOIDCP,
      0,
      () => exports2.DeleteOpenIDConnectProviderRequest$,
      () => __Unit
    ];
    exports2.DeletePolicy$ = [
      9,
      n032,
      _DPe,
      0,
      () => exports2.DeletePolicyRequest$,
      () => __Unit
    ];
    exports2.DeletePolicyVersion$ = [
      9,
      n032,
      _DPV,
      0,
      () => exports2.DeletePolicyVersionRequest$,
      () => __Unit
    ];
    exports2.DeleteRole$ = [
      9,
      n032,
      _DRel,
      0,
      () => exports2.DeleteRoleRequest$,
      () => __Unit
    ];
    exports2.DeleteRolePermissionsBoundary$ = [
      9,
      n032,
      _DRPB,
      0,
      () => exports2.DeleteRolePermissionsBoundaryRequest$,
      () => __Unit
    ];
    exports2.DeleteRolePolicy$ = [
      9,
      n032,
      _DRP,
      0,
      () => exports2.DeleteRolePolicyRequest$,
      () => __Unit
    ];
    exports2.DeleteSAMLProvider$ = [
      9,
      n032,
      _DSAMLP,
      0,
      () => exports2.DeleteSAMLProviderRequest$,
      () => __Unit
    ];
    exports2.DeleteServerCertificate$ = [
      9,
      n032,
      _DSC,
      0,
      () => exports2.DeleteServerCertificateRequest$,
      () => __Unit
    ];
    exports2.DeleteServiceLinkedRole$ = [
      9,
      n032,
      _DSLR,
      0,
      () => exports2.DeleteServiceLinkedRoleRequest$,
      () => exports2.DeleteServiceLinkedRoleResponse$
    ];
    exports2.DeleteServiceSpecificCredential$ = [
      9,
      n032,
      _DSSC,
      0,
      () => exports2.DeleteServiceSpecificCredentialRequest$,
      () => __Unit
    ];
    exports2.DeleteSigningCertificate$ = [
      9,
      n032,
      _DSCe,
      0,
      () => exports2.DeleteSigningCertificateRequest$,
      () => __Unit
    ];
    exports2.DeleteSSHPublicKey$ = [
      9,
      n032,
      _DSSHPK,
      0,
      () => exports2.DeleteSSHPublicKeyRequest$,
      () => __Unit
    ];
    exports2.DeleteUser$ = [
      9,
      n032,
      _DU,
      0,
      () => exports2.DeleteUserRequest$,
      () => __Unit
    ];
    exports2.DeleteUserPermissionsBoundary$ = [
      9,
      n032,
      _DUPB,
      0,
      () => exports2.DeleteUserPermissionsBoundaryRequest$,
      () => __Unit
    ];
    exports2.DeleteUserPolicy$ = [
      9,
      n032,
      _DUP,
      0,
      () => exports2.DeleteUserPolicyRequest$,
      () => __Unit
    ];
    exports2.DeleteVirtualMFADevice$ = [
      9,
      n032,
      _DVMFAD,
      0,
      () => exports2.DeleteVirtualMFADeviceRequest$,
      () => __Unit
    ];
    exports2.DetachGroupPolicy$ = [
      9,
      n032,
      _DGPe,
      0,
      () => exports2.DetachGroupPolicyRequest$,
      () => __Unit
    ];
    exports2.DetachRolePolicy$ = [
      9,
      n032,
      _DRPe,
      0,
      () => exports2.DetachRolePolicyRequest$,
      () => __Unit
    ];
    exports2.DetachUserPolicy$ = [
      9,
      n032,
      _DUPe,
      0,
      () => exports2.DetachUserPolicyRequest$,
      () => __Unit
    ];
    exports2.DisableOrganizationsRootCredentialsManagement$ = [
      9,
      n032,
      _DORCM,
      0,
      () => exports2.DisableOrganizationsRootCredentialsManagementRequest$,
      () => exports2.DisableOrganizationsRootCredentialsManagementResponse$
    ];
    exports2.DisableOrganizationsRootSessions$ = [
      9,
      n032,
      _DORS,
      0,
      () => exports2.DisableOrganizationsRootSessionsRequest$,
      () => exports2.DisableOrganizationsRootSessionsResponse$
    ];
    exports2.DisableOutboundWebIdentityFederation$ = [
      9,
      n032,
      _DOWIF,
      0,
      () => __Unit,
      () => __Unit
    ];
    exports2.EnableMFADevice$ = [
      9,
      n032,
      _EMFAD,
      0,
      () => exports2.EnableMFADeviceRequest$,
      () => __Unit
    ];
    exports2.EnableOrganizationsRootCredentialsManagement$ = [
      9,
      n032,
      _EORCM,
      0,
      () => exports2.EnableOrganizationsRootCredentialsManagementRequest$,
      () => exports2.EnableOrganizationsRootCredentialsManagementResponse$
    ];
    exports2.EnableOrganizationsRootSessions$ = [
      9,
      n032,
      _EORS,
      0,
      () => exports2.EnableOrganizationsRootSessionsRequest$,
      () => exports2.EnableOrganizationsRootSessionsResponse$
    ];
    exports2.EnableOutboundWebIdentityFederation$ = [
      9,
      n032,
      _EOWIF,
      0,
      () => __Unit,
      () => exports2.EnableOutboundWebIdentityFederationResponse$
    ];
    exports2.GenerateCredentialReport$ = [
      9,
      n032,
      _GCR,
      0,
      () => __Unit,
      () => exports2.GenerateCredentialReportResponse$
    ];
    exports2.GenerateOrganizationsAccessReport$ = [
      9,
      n032,
      _GOAR,
      0,
      () => exports2.GenerateOrganizationsAccessReportRequest$,
      () => exports2.GenerateOrganizationsAccessReportResponse$
    ];
    exports2.GenerateServiceLastAccessedDetails$ = [
      9,
      n032,
      _GSLAD,
      0,
      () => exports2.GenerateServiceLastAccessedDetailsRequest$,
      () => exports2.GenerateServiceLastAccessedDetailsResponse$
    ];
    exports2.GetAccessKeyLastUsed$ = [
      9,
      n032,
      _GAKLU,
      0,
      () => exports2.GetAccessKeyLastUsedRequest$,
      () => exports2.GetAccessKeyLastUsedResponse$
    ];
    exports2.GetAccountAuthorizationDetails$ = [
      9,
      n032,
      _GAAD,
      0,
      () => exports2.GetAccountAuthorizationDetailsRequest$,
      () => exports2.GetAccountAuthorizationDetailsResponse$
    ];
    exports2.GetAccountPasswordPolicy$ = [
      9,
      n032,
      _GAPP,
      0,
      () => __Unit,
      () => exports2.GetAccountPasswordPolicyResponse$
    ];
    exports2.GetAccountSummary$ = [
      9,
      n032,
      _GAS,
      0,
      () => __Unit,
      () => exports2.GetAccountSummaryResponse$
    ];
    exports2.GetContextKeysForCustomPolicy$ = [
      9,
      n032,
      _GCKFCP,
      0,
      () => exports2.GetContextKeysForCustomPolicyRequest$,
      () => exports2.GetContextKeysForPolicyResponse$
    ];
    exports2.GetContextKeysForPrincipalPolicy$ = [
      9,
      n032,
      _GCKFPP,
      0,
      () => exports2.GetContextKeysForPrincipalPolicyRequest$,
      () => exports2.GetContextKeysForPolicyResponse$
    ];
    exports2.GetCredentialReport$ = [
      9,
      n032,
      _GCRe,
      0,
      () => __Unit,
      () => exports2.GetCredentialReportResponse$
    ];
    exports2.GetDelegationRequest$ = [
      9,
      n032,
      _GDR,
      0,
      () => exports2.GetDelegationRequestRequest$,
      () => exports2.GetDelegationRequestResponse$
    ];
    exports2.GetGroup$ = [
      9,
      n032,
      _GG,
      0,
      () => exports2.GetGroupRequest$,
      () => exports2.GetGroupResponse$
    ];
    exports2.GetGroupPolicy$ = [
      9,
      n032,
      _GGP,
      0,
      () => exports2.GetGroupPolicyRequest$,
      () => exports2.GetGroupPolicyResponse$
    ];
    exports2.GetHumanReadableSummary$ = [
      9,
      n032,
      _GHRS,
      0,
      () => exports2.GetHumanReadableSummaryRequest$,
      () => exports2.GetHumanReadableSummaryResponse$
    ];
    exports2.GetInstanceProfile$ = [
      9,
      n032,
      _GIP,
      0,
      () => exports2.GetInstanceProfileRequest$,
      () => exports2.GetInstanceProfileResponse$
    ];
    exports2.GetLoginProfile$ = [
      9,
      n032,
      _GLP,
      0,
      () => exports2.GetLoginProfileRequest$,
      () => exports2.GetLoginProfileResponse$
    ];
    exports2.GetMFADevice$ = [
      9,
      n032,
      _GMFAD,
      0,
      () => exports2.GetMFADeviceRequest$,
      () => exports2.GetMFADeviceResponse$
    ];
    exports2.GetOpenIDConnectProvider$ = [
      9,
      n032,
      _GOIDCP,
      0,
      () => exports2.GetOpenIDConnectProviderRequest$,
      () => exports2.GetOpenIDConnectProviderResponse$
    ];
    exports2.GetOrganizationsAccessReport$ = [
      9,
      n032,
      _GOARe,
      0,
      () => exports2.GetOrganizationsAccessReportRequest$,
      () => exports2.GetOrganizationsAccessReportResponse$
    ];
    exports2.GetOutboundWebIdentityFederationInfo$ = [
      9,
      n032,
      _GOWIFI,
      0,
      () => __Unit,
      () => exports2.GetOutboundWebIdentityFederationInfoResponse$
    ];
    exports2.GetPolicy$ = [
      9,
      n032,
      _GP,
      0,
      () => exports2.GetPolicyRequest$,
      () => exports2.GetPolicyResponse$
    ];
    exports2.GetPolicyVersion$ = [
      9,
      n032,
      _GPV,
      0,
      () => exports2.GetPolicyVersionRequest$,
      () => exports2.GetPolicyVersionResponse$
    ];
    exports2.GetRole$ = [
      9,
      n032,
      _GR,
      0,
      () => exports2.GetRoleRequest$,
      () => exports2.GetRoleResponse$
    ];
    exports2.GetRolePolicy$ = [
      9,
      n032,
      _GRP,
      0,
      () => exports2.GetRolePolicyRequest$,
      () => exports2.GetRolePolicyResponse$
    ];
    exports2.GetSAMLProvider$ = [
      9,
      n032,
      _GSAMLP,
      0,
      () => exports2.GetSAMLProviderRequest$,
      () => exports2.GetSAMLProviderResponse$
    ];
    exports2.GetServerCertificate$ = [
      9,
      n032,
      _GSC,
      0,
      () => exports2.GetServerCertificateRequest$,
      () => exports2.GetServerCertificateResponse$
    ];
    exports2.GetServiceLastAccessedDetails$ = [
      9,
      n032,
      _GSLADe,
      0,
      () => exports2.GetServiceLastAccessedDetailsRequest$,
      () => exports2.GetServiceLastAccessedDetailsResponse$
    ];
    exports2.GetServiceLastAccessedDetailsWithEntities$ = [
      9,
      n032,
      _GSLADWE,
      0,
      () => exports2.GetServiceLastAccessedDetailsWithEntitiesRequest$,
      () => exports2.GetServiceLastAccessedDetailsWithEntitiesResponse$
    ];
    exports2.GetServiceLinkedRoleDeletionStatus$ = [
      9,
      n032,
      _GSLRDS,
      0,
      () => exports2.GetServiceLinkedRoleDeletionStatusRequest$,
      () => exports2.GetServiceLinkedRoleDeletionStatusResponse$
    ];
    exports2.GetSSHPublicKey$ = [
      9,
      n032,
      _GSSHPK,
      0,
      () => exports2.GetSSHPublicKeyRequest$,
      () => exports2.GetSSHPublicKeyResponse$
    ];
    exports2.GetUser$ = [
      9,
      n032,
      _GU,
      0,
      () => exports2.GetUserRequest$,
      () => exports2.GetUserResponse$
    ];
    exports2.GetUserPolicy$ = [
      9,
      n032,
      _GUP,
      0,
      () => exports2.GetUserPolicyRequest$,
      () => exports2.GetUserPolicyResponse$
    ];
    exports2.ListAccessKeys$ = [
      9,
      n032,
      _LAK,
      0,
      () => exports2.ListAccessKeysRequest$,
      () => exports2.ListAccessKeysResponse$
    ];
    exports2.ListAccountAliases$ = [
      9,
      n032,
      _LAA,
      0,
      () => exports2.ListAccountAliasesRequest$,
      () => exports2.ListAccountAliasesResponse$
    ];
    exports2.ListAttachedGroupPolicies$ = [
      9,
      n032,
      _LAGP,
      0,
      () => exports2.ListAttachedGroupPoliciesRequest$,
      () => exports2.ListAttachedGroupPoliciesResponse$
    ];
    exports2.ListAttachedRolePolicies$ = [
      9,
      n032,
      _LARP,
      0,
      () => exports2.ListAttachedRolePoliciesRequest$,
      () => exports2.ListAttachedRolePoliciesResponse$
    ];
    exports2.ListAttachedUserPolicies$ = [
      9,
      n032,
      _LAUP,
      0,
      () => exports2.ListAttachedUserPoliciesRequest$,
      () => exports2.ListAttachedUserPoliciesResponse$
    ];
    exports2.ListDelegationRequests$ = [
      9,
      n032,
      _LDR,
      0,
      () => exports2.ListDelegationRequestsRequest$,
      () => exports2.ListDelegationRequestsResponse$
    ];
    exports2.ListEntitiesForPolicy$ = [
      9,
      n032,
      _LEFP,
      0,
      () => exports2.ListEntitiesForPolicyRequest$,
      () => exports2.ListEntitiesForPolicyResponse$
    ];
    exports2.ListGroupPolicies$ = [
      9,
      n032,
      _LGP,
      0,
      () => exports2.ListGroupPoliciesRequest$,
      () => exports2.ListGroupPoliciesResponse$
    ];
    exports2.ListGroups$ = [
      9,
      n032,
      _LG,
      0,
      () => exports2.ListGroupsRequest$,
      () => exports2.ListGroupsResponse$
    ];
    exports2.ListGroupsForUser$ = [
      9,
      n032,
      _LGFU,
      0,
      () => exports2.ListGroupsForUserRequest$,
      () => exports2.ListGroupsForUserResponse$
    ];
    exports2.ListInstanceProfiles$ = [
      9,
      n032,
      _LIP,
      0,
      () => exports2.ListInstanceProfilesRequest$,
      () => exports2.ListInstanceProfilesResponse$
    ];
    exports2.ListInstanceProfilesForRole$ = [
      9,
      n032,
      _LIPFR,
      0,
      () => exports2.ListInstanceProfilesForRoleRequest$,
      () => exports2.ListInstanceProfilesForRoleResponse$
    ];
    exports2.ListInstanceProfileTags$ = [
      9,
      n032,
      _LIPT,
      0,
      () => exports2.ListInstanceProfileTagsRequest$,
      () => exports2.ListInstanceProfileTagsResponse$
    ];
    exports2.ListMFADevices$ = [
      9,
      n032,
      _LMFAD,
      0,
      () => exports2.ListMFADevicesRequest$,
      () => exports2.ListMFADevicesResponse$
    ];
    exports2.ListMFADeviceTags$ = [
      9,
      n032,
      _LMFADT,
      0,
      () => exports2.ListMFADeviceTagsRequest$,
      () => exports2.ListMFADeviceTagsResponse$
    ];
    exports2.ListOpenIDConnectProviders$ = [
      9,
      n032,
      _LOIDCP,
      0,
      () => exports2.ListOpenIDConnectProvidersRequest$,
      () => exports2.ListOpenIDConnectProvidersResponse$
    ];
    exports2.ListOpenIDConnectProviderTags$ = [
      9,
      n032,
      _LOIDCPT,
      0,
      () => exports2.ListOpenIDConnectProviderTagsRequest$,
      () => exports2.ListOpenIDConnectProviderTagsResponse$
    ];
    exports2.ListOrganizationsFeatures$ = [
      9,
      n032,
      _LOF,
      0,
      () => exports2.ListOrganizationsFeaturesRequest$,
      () => exports2.ListOrganizationsFeaturesResponse$
    ];
    exports2.ListPolicies$ = [
      9,
      n032,
      _LPi,
      0,
      () => exports2.ListPoliciesRequest$,
      () => exports2.ListPoliciesResponse$
    ];
    exports2.ListPoliciesGrantingServiceAccess$ = [
      9,
      n032,
      _LPGSA,
      0,
      () => exports2.ListPoliciesGrantingServiceAccessRequest$,
      () => exports2.ListPoliciesGrantingServiceAccessResponse$
    ];
    exports2.ListPolicyTags$ = [
      9,
      n032,
      _LPT,
      0,
      () => exports2.ListPolicyTagsRequest$,
      () => exports2.ListPolicyTagsResponse$
    ];
    exports2.ListPolicyVersions$ = [
      9,
      n032,
      _LPV,
      0,
      () => exports2.ListPolicyVersionsRequest$,
      () => exports2.ListPolicyVersionsResponse$
    ];
    exports2.ListRolePolicies$ = [
      9,
      n032,
      _LRP,
      0,
      () => exports2.ListRolePoliciesRequest$,
      () => exports2.ListRolePoliciesResponse$
    ];
    exports2.ListRoles$ = [
      9,
      n032,
      _LR,
      0,
      () => exports2.ListRolesRequest$,
      () => exports2.ListRolesResponse$
    ];
    exports2.ListRoleTags$ = [
      9,
      n032,
      _LRT,
      0,
      () => exports2.ListRoleTagsRequest$,
      () => exports2.ListRoleTagsResponse$
    ];
    exports2.ListSAMLProviders$ = [
      9,
      n032,
      _LSAMLP,
      0,
      () => exports2.ListSAMLProvidersRequest$,
      () => exports2.ListSAMLProvidersResponse$
    ];
    exports2.ListSAMLProviderTags$ = [
      9,
      n032,
      _LSAMLPT,
      0,
      () => exports2.ListSAMLProviderTagsRequest$,
      () => exports2.ListSAMLProviderTagsResponse$
    ];
    exports2.ListServerCertificates$ = [
      9,
      n032,
      _LSC,
      0,
      () => exports2.ListServerCertificatesRequest$,
      () => exports2.ListServerCertificatesResponse$
    ];
    exports2.ListServerCertificateTags$ = [
      9,
      n032,
      _LSCT,
      0,
      () => exports2.ListServerCertificateTagsRequest$,
      () => exports2.ListServerCertificateTagsResponse$
    ];
    exports2.ListServiceSpecificCredentials$ = [
      9,
      n032,
      _LSSC,
      0,
      () => exports2.ListServiceSpecificCredentialsRequest$,
      () => exports2.ListServiceSpecificCredentialsResponse$
    ];
    exports2.ListSigningCertificates$ = [
      9,
      n032,
      _LSCi,
      0,
      () => exports2.ListSigningCertificatesRequest$,
      () => exports2.ListSigningCertificatesResponse$
    ];
    exports2.ListSSHPublicKeys$ = [
      9,
      n032,
      _LSSHPK,
      0,
      () => exports2.ListSSHPublicKeysRequest$,
      () => exports2.ListSSHPublicKeysResponse$
    ];
    exports2.ListUserPolicies$ = [
      9,
      n032,
      _LUP,
      0,
      () => exports2.ListUserPoliciesRequest$,
      () => exports2.ListUserPoliciesResponse$
    ];
    exports2.ListUsers$ = [
      9,
      n032,
      _LU,
      0,
      () => exports2.ListUsersRequest$,
      () => exports2.ListUsersResponse$
    ];
    exports2.ListUserTags$ = [
      9,
      n032,
      _LUT,
      0,
      () => exports2.ListUserTagsRequest$,
      () => exports2.ListUserTagsResponse$
    ];
    exports2.ListVirtualMFADevices$ = [
      9,
      n032,
      _LVMFAD,
      0,
      () => exports2.ListVirtualMFADevicesRequest$,
      () => exports2.ListVirtualMFADevicesResponse$
    ];
    exports2.PutGroupPolicy$ = [
      9,
      n032,
      _PGP,
      0,
      () => exports2.PutGroupPolicyRequest$,
      () => __Unit
    ];
    exports2.PutRolePermissionsBoundary$ = [
      9,
      n032,
      _PRPB,
      0,
      () => exports2.PutRolePermissionsBoundaryRequest$,
      () => __Unit
    ];
    exports2.PutRolePolicy$ = [
      9,
      n032,
      _PRPu,
      0,
      () => exports2.PutRolePolicyRequest$,
      () => __Unit
    ];
    exports2.PutUserPermissionsBoundary$ = [
      9,
      n032,
      _PUPB,
      0,
      () => exports2.PutUserPermissionsBoundaryRequest$,
      () => __Unit
    ];
    exports2.PutUserPolicy$ = [
      9,
      n032,
      _PUP,
      0,
      () => exports2.PutUserPolicyRequest$,
      () => __Unit
    ];
    exports2.RejectDelegationRequest$ = [
      9,
      n032,
      _RDR,
      0,
      () => exports2.RejectDelegationRequestRequest$,
      () => __Unit
    ];
    exports2.RemoveClientIDFromOpenIDConnectProvider$ = [
      9,
      n032,
      _RCIDFOIDCP,
      0,
      () => exports2.RemoveClientIDFromOpenIDConnectProviderRequest$,
      () => __Unit
    ];
    exports2.RemoveRoleFromInstanceProfile$ = [
      9,
      n032,
      _RRFIP,
      0,
      () => exports2.RemoveRoleFromInstanceProfileRequest$,
      () => __Unit
    ];
    exports2.RemoveUserFromGroup$ = [
      9,
      n032,
      _RUFG,
      0,
      () => exports2.RemoveUserFromGroupRequest$,
      () => __Unit
    ];
    exports2.ResetServiceSpecificCredential$ = [
      9,
      n032,
      _RSSC,
      0,
      () => exports2.ResetServiceSpecificCredentialRequest$,
      () => exports2.ResetServiceSpecificCredentialResponse$
    ];
    exports2.ResyncMFADevice$ = [
      9,
      n032,
      _RMFAD,
      0,
      () => exports2.ResyncMFADeviceRequest$,
      () => __Unit
    ];
    exports2.SendDelegationToken$ = [
      9,
      n032,
      _SDT,
      0,
      () => exports2.SendDelegationTokenRequest$,
      () => __Unit
    ];
    exports2.SetDefaultPolicyVersion$ = [
      9,
      n032,
      _SDPV,
      0,
      () => exports2.SetDefaultPolicyVersionRequest$,
      () => __Unit
    ];
    exports2.SetSecurityTokenServicePreferences$ = [
      9,
      n032,
      _SSTSP,
      0,
      () => exports2.SetSecurityTokenServicePreferencesRequest$,
      () => __Unit
    ];
    exports2.SimulateCustomPolicy$ = [
      9,
      n032,
      _SCP,
      0,
      () => exports2.SimulateCustomPolicyRequest$,
      () => exports2.SimulatePolicyResponse$
    ];
    exports2.SimulatePrincipalPolicy$ = [
      9,
      n032,
      _SPP,
      0,
      () => exports2.SimulatePrincipalPolicyRequest$,
      () => exports2.SimulatePolicyResponse$
    ];
    exports2.TagInstanceProfile$ = [
      9,
      n032,
      _TIP,
      0,
      () => exports2.TagInstanceProfileRequest$,
      () => __Unit
    ];
    exports2.TagMFADevice$ = [
      9,
      n032,
      _TMFAD,
      0,
      () => exports2.TagMFADeviceRequest$,
      () => __Unit
    ];
    exports2.TagOpenIDConnectProvider$ = [
      9,
      n032,
      _TOIDCP,
      0,
      () => exports2.TagOpenIDConnectProviderRequest$,
      () => __Unit
    ];
    exports2.TagPolicy$ = [
      9,
      n032,
      _TP,
      0,
      () => exports2.TagPolicyRequest$,
      () => __Unit
    ];
    exports2.TagRole$ = [
      9,
      n032,
      _TR,
      0,
      () => exports2.TagRoleRequest$,
      () => __Unit
    ];
    exports2.TagSAMLProvider$ = [
      9,
      n032,
      _TSAMLP,
      0,
      () => exports2.TagSAMLProviderRequest$,
      () => __Unit
    ];
    exports2.TagServerCertificate$ = [
      9,
      n032,
      _TSC,
      0,
      () => exports2.TagServerCertificateRequest$,
      () => __Unit
    ];
    exports2.TagUser$ = [
      9,
      n032,
      _TU,
      0,
      () => exports2.TagUserRequest$,
      () => __Unit
    ];
    exports2.UntagInstanceProfile$ = [
      9,
      n032,
      _UIP,
      0,
      () => exports2.UntagInstanceProfileRequest$,
      () => __Unit
    ];
    exports2.UntagMFADevice$ = [
      9,
      n032,
      _UMFAD,
      0,
      () => exports2.UntagMFADeviceRequest$,
      () => __Unit
    ];
    exports2.UntagOpenIDConnectProvider$ = [
      9,
      n032,
      _UOIDCP,
      0,
      () => exports2.UntagOpenIDConnectProviderRequest$,
      () => __Unit
    ];
    exports2.UntagPolicy$ = [
      9,
      n032,
      _UP,
      0,
      () => exports2.UntagPolicyRequest$,
      () => __Unit
    ];
    exports2.UntagRole$ = [
      9,
      n032,
      _UR,
      0,
      () => exports2.UntagRoleRequest$,
      () => __Unit
    ];
    exports2.UntagSAMLProvider$ = [
      9,
      n032,
      _USAMLP,
      0,
      () => exports2.UntagSAMLProviderRequest$,
      () => __Unit
    ];
    exports2.UntagServerCertificate$ = [
      9,
      n032,
      _USC,
      0,
      () => exports2.UntagServerCertificateRequest$,
      () => __Unit
    ];
    exports2.UntagUser$ = [
      9,
      n032,
      _UU,
      0,
      () => exports2.UntagUserRequest$,
      () => __Unit
    ];
    exports2.UpdateAccessKey$ = [
      9,
      n032,
      _UAK,
      0,
      () => exports2.UpdateAccessKeyRequest$,
      () => __Unit
    ];
    exports2.UpdateAccountPasswordPolicy$ = [
      9,
      n032,
      _UAPP,
      0,
      () => exports2.UpdateAccountPasswordPolicyRequest$,
      () => __Unit
    ];
    exports2.UpdateAssumeRolePolicy$ = [
      9,
      n032,
      _UARP,
      0,
      () => exports2.UpdateAssumeRolePolicyRequest$,
      () => __Unit
    ];
    exports2.UpdateDelegationRequest$ = [
      9,
      n032,
      _UDR,
      0,
      () => exports2.UpdateDelegationRequestRequest$,
      () => __Unit
    ];
    exports2.UpdateGroup$ = [
      9,
      n032,
      _UG,
      0,
      () => exports2.UpdateGroupRequest$,
      () => __Unit
    ];
    exports2.UpdateLoginProfile$ = [
      9,
      n032,
      _ULP,
      0,
      () => exports2.UpdateLoginProfileRequest$,
      () => __Unit
    ];
    exports2.UpdateOpenIDConnectProviderThumbprint$ = [
      9,
      n032,
      _UOIDCPT,
      0,
      () => exports2.UpdateOpenIDConnectProviderThumbprintRequest$,
      () => __Unit
    ];
    exports2.UpdateRole$ = [
      9,
      n032,
      _URp,
      0,
      () => exports2.UpdateRoleRequest$,
      () => exports2.UpdateRoleResponse$
    ];
    exports2.UpdateRoleDescription$ = [
      9,
      n032,
      _URD,
      0,
      () => exports2.UpdateRoleDescriptionRequest$,
      () => exports2.UpdateRoleDescriptionResponse$
    ];
    exports2.UpdateSAMLProvider$ = [
      9,
      n032,
      _USAMLPp,
      0,
      () => exports2.UpdateSAMLProviderRequest$,
      () => exports2.UpdateSAMLProviderResponse$
    ];
    exports2.UpdateServerCertificate$ = [
      9,
      n032,
      _USCp,
      0,
      () => exports2.UpdateServerCertificateRequest$,
      () => __Unit
    ];
    exports2.UpdateServiceSpecificCredential$ = [
      9,
      n032,
      _USSC,
      0,
      () => exports2.UpdateServiceSpecificCredentialRequest$,
      () => __Unit
    ];
    exports2.UpdateSigningCertificate$ = [
      9,
      n032,
      _USCpd,
      0,
      () => exports2.UpdateSigningCertificateRequest$,
      () => __Unit
    ];
    exports2.UpdateSSHPublicKey$ = [
      9,
      n032,
      _USSHPK,
      0,
      () => exports2.UpdateSSHPublicKeyRequest$,
      () => __Unit
    ];
    exports2.UpdateUser$ = [
      9,
      n032,
      _UUp,
      0,
      () => exports2.UpdateUserRequest$,
      () => __Unit
    ];
    exports2.UploadServerCertificate$ = [
      9,
      n032,
      _USCpl,
      0,
      () => exports2.UploadServerCertificateRequest$,
      () => exports2.UploadServerCertificateResponse$
    ];
    exports2.UploadSigningCertificate$ = [
      9,
      n032,
      _USCplo,
      0,
      () => exports2.UploadSigningCertificateRequest$,
      () => exports2.UploadSigningCertificateResponse$
    ];
    exports2.UploadSSHPublicKey$ = [
      9,
      n032,
      _USSHPKp,
      0,
      () => exports2.UploadSSHPublicKeyRequest$,
      () => exports2.UploadSSHPublicKeyResponse$
    ];
  }
});

// ../../node_modules/@aws-sdk/client-iam/dist-cjs/runtimeConfig.shared.js
var require_runtimeConfig_shared15 = __commonJS({
  "../../node_modules/@aws-sdk/client-iam/dist-cjs/runtimeConfig.shared.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var protocols_1 = (init_protocols8(), __toCommonJS(protocols_exports5));
    var smithy_client_1 = require_dist_cjs34();
    var url_parser_1 = require_dist_cjs18();
    var util_base64_1 = require_dist_cjs10();
    var util_utf8_1 = require_dist_cjs9();
    var httpAuthSchemeProvider_1 = require_httpAuthSchemeProvider14();
    var endpointResolver_1 = require_endpointResolver14();
    var schemas_0_1 = require_schemas_014();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2010-05-08",
        base64Decoder: config2?.base64Decoder ?? util_base64_1.fromBase64,
        base64Encoder: config2?.base64Encoder ?? util_base64_1.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? endpointResolver_1.defaultEndpointResolver,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? httpAuthSchemeProvider_1.defaultIAMHttpAuthSchemeProvider,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new httpAuthSchemes_1.AwsSdkSigV4Signer()
          }
        ],
        logger: config2?.logger ?? new smithy_client_1.NoOpLogger(),
        protocol: config2?.protocol ?? protocols_1.AwsQueryProtocol,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.iam",
          errorTypeRegistries: schemas_0_1.errorTypeRegistries,
          xmlNamespace: "https://iam.amazonaws.com/doc/2010-05-08/",
          version: "2010-05-08",
          serviceTarget: "AWSIdentityManagementV20100508"
        },
        serviceId: config2?.serviceId ?? "IAM",
        urlParser: config2?.urlParser ?? url_parser_1.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? util_utf8_1.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? util_utf8_1.toUtf8
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-iam/dist-cjs/runtimeConfig.js
var require_runtimeConfig15 = __commonJS({
  "../../node_modules/@aws-sdk/client-iam/dist-cjs/runtimeConfig.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var package_json_1 = tslib_1.__importDefault(require_package14());
    var client_1 = (init_client8(), __toCommonJS(client_exports7));
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var credential_provider_node_1 = require_dist_cjs122();
    var util_user_agent_node_1 = require_dist_cjs113();
    var config_resolver_1 = require_dist_cjs25();
    var hash_node_1 = require_dist_cjs44();
    var middleware_retry_1 = require_dist_cjs106();
    var node_config_provider_1 = require_dist_cjs29();
    var node_http_handler_1 = require_dist_cjs13();
    var smithy_client_1 = require_dist_cjs34();
    var util_body_length_node_1 = require_dist_cjs45();
    var util_defaults_mode_node_1 = require_dist_cjs46();
    var util_retry_1 = require_dist_cjs22();
    var runtimeConfig_shared_1 = require_runtimeConfig_shared15();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      (0, smithy_client_1.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, util_defaults_mode_node_1.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(smithy_client_1.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = (0, runtimeConfig_shared_1.getRuntimeConfig)(config2);
      (0, client_1.emitWarningIfUnsupportedVersion)(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, node_config_provider_1.loadConfig)(httpAuthSchemes_1.NODE_AUTH_SCHEME_PREFERENCE_OPTIONS, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? util_body_length_node_1.calculateBodyLength,
        credentialDefaultProvider: config2?.credentialDefaultProvider ?? credential_provider_node_1.defaultProvider,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, util_user_agent_node_1.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_json_1.default.version }),
        maxAttempts: config2?.maxAttempts ?? (0, node_config_provider_1.loadConfig)(middleware_retry_1.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_REGION_CONFIG_OPTIONS, { ...config_resolver_1.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: node_http_handler_1.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, node_config_provider_1.loadConfig)({
          ...middleware_retry_1.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || util_retry_1.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? hash_node_1.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? node_http_handler_1.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, node_config_provider_1.loadConfig)(util_user_agent_node_1.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-iam/dist-cjs/index.js
var require_dist_cjs166 = __commonJS({
  "../../node_modules/@aws-sdk/client-iam/dist-cjs/index.js"(exports2) {
    "use strict";
    var middlewareHostHeader = require_dist_cjs3();
    var middlewareLogger = require_dist_cjs4();
    var middlewareRecursionDetection = require_dist_cjs5();
    var middlewareUserAgent = require_dist_cjs104();
    var configResolver = require_dist_cjs25();
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var schema = (init_schema4(), __toCommonJS(schema_exports));
    var middlewareContentLength = require_dist_cjs26();
    var middlewareEndpoint = require_dist_cjs31();
    var middlewareRetry = require_dist_cjs106();
    var smithyClient = require_dist_cjs34();
    var httpAuthSchemeProvider = require_httpAuthSchemeProvider14();
    var runtimeConfig = require_runtimeConfig15();
    var regionConfigResolver = require_dist_cjs48();
    var protocolHttp = require_dist_cjs2();
    var schemas_0 = require_schemas_014();
    var utilWaiter = require_dist_cjs156();
    var errors = require_errors13();
    var IAMServiceException = require_IAMServiceException();
    var resolveClientEndpointParameters32 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "iam"
      });
    }, "resolveClientEndpointParameters");
    var commonParams32 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
    var getHttpAuthExtensionConfiguration32 = /* @__PURE__ */ __name((runtimeConfig2) => {
      const _httpAuthSchemes = runtimeConfig2.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig2.httpAuthSchemeProvider;
      let _credentials = runtimeConfig2.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider2) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider2;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    var resolveHttpAuthRuntimeConfig32 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
    var resolveRuntimeExtensions32 = /* @__PURE__ */ __name((runtimeConfig2, extensions) => {
      const extensionConfiguration = Object.assign(regionConfigResolver.getAwsRegionExtensionConfiguration(runtimeConfig2), smithyClient.getDefaultExtensionConfiguration(runtimeConfig2), protocolHttp.getHttpHandlerExtensionConfiguration(runtimeConfig2), getHttpAuthExtensionConfiguration32(runtimeConfig2));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig2, regionConfigResolver.resolveAwsRegionExtensionConfiguration(extensionConfiguration), smithyClient.resolveDefaultRuntimeConfig(extensionConfiguration), protocolHttp.resolveHttpHandlerRuntimeConfig(extensionConfiguration), resolveHttpAuthRuntimeConfig32(extensionConfiguration));
    }, "resolveRuntimeExtensions");
    var IAMClient2 = class extends smithyClient.Client {
      static {
        __name(this, "IAMClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = runtimeConfig.getRuntimeConfig(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters32(_config_0);
        const _config_2 = middlewareUserAgent.resolveUserAgentConfig(_config_1);
        const _config_3 = middlewareRetry.resolveRetryConfig(_config_2);
        const _config_4 = configResolver.resolveRegionConfig(_config_3);
        const _config_5 = middlewareHostHeader.resolveHostHeaderConfig(_config_4);
        const _config_6 = middlewareEndpoint.resolveEndpointConfig(_config_5);
        const _config_7 = httpAuthSchemeProvider.resolveHttpAuthSchemeConfig(_config_6);
        const _config_8 = resolveRuntimeExtensions32(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(schema.getSchemaSerdePlugin(this.config));
        this.middlewareStack.use(middlewareUserAgent.getUserAgentPlugin(this.config));
        this.middlewareStack.use(middlewareRetry.getRetryPlugin(this.config));
        this.middlewareStack.use(middlewareContentLength.getContentLengthPlugin(this.config));
        this.middlewareStack.use(middlewareHostHeader.getHostHeaderPlugin(this.config));
        this.middlewareStack.use(middlewareLogger.getLoggerPlugin(this.config));
        this.middlewareStack.use(middlewareRecursionDetection.getRecursionDetectionPlugin(this.config));
        this.middlewareStack.use(core.getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: httpAuthSchemeProvider.defaultIAMHttpAuthSchemeParametersProvider,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new core.DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(core.getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
    var AcceptDelegationRequestCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "AcceptDelegationRequest", {}).n("IAMClient", "AcceptDelegationRequestCommand").sc(schemas_0.AcceptDelegationRequest$).build() {
      static {
        __name(this, "AcceptDelegationRequestCommand");
      }
    };
    var AddClientIDToOpenIDConnectProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "AddClientIDToOpenIDConnectProvider", {}).n("IAMClient", "AddClientIDToOpenIDConnectProviderCommand").sc(schemas_0.AddClientIDToOpenIDConnectProvider$).build() {
      static {
        __name(this, "AddClientIDToOpenIDConnectProviderCommand");
      }
    };
    var AddRoleToInstanceProfileCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "AddRoleToInstanceProfile", {}).n("IAMClient", "AddRoleToInstanceProfileCommand").sc(schemas_0.AddRoleToInstanceProfile$).build() {
      static {
        __name(this, "AddRoleToInstanceProfileCommand");
      }
    };
    var AddUserToGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "AddUserToGroup", {}).n("IAMClient", "AddUserToGroupCommand").sc(schemas_0.AddUserToGroup$).build() {
      static {
        __name(this, "AddUserToGroupCommand");
      }
    };
    var AssociateDelegationRequestCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "AssociateDelegationRequest", {}).n("IAMClient", "AssociateDelegationRequestCommand").sc(schemas_0.AssociateDelegationRequest$).build() {
      static {
        __name(this, "AssociateDelegationRequestCommand");
      }
    };
    var AttachGroupPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "AttachGroupPolicy", {}).n("IAMClient", "AttachGroupPolicyCommand").sc(schemas_0.AttachGroupPolicy$).build() {
      static {
        __name(this, "AttachGroupPolicyCommand");
      }
    };
    var AttachRolePolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "AttachRolePolicy", {}).n("IAMClient", "AttachRolePolicyCommand").sc(schemas_0.AttachRolePolicy$).build() {
      static {
        __name(this, "AttachRolePolicyCommand");
      }
    };
    var AttachUserPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "AttachUserPolicy", {}).n("IAMClient", "AttachUserPolicyCommand").sc(schemas_0.AttachUserPolicy$).build() {
      static {
        __name(this, "AttachUserPolicyCommand");
      }
    };
    var ChangePasswordCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ChangePassword", {}).n("IAMClient", "ChangePasswordCommand").sc(schemas_0.ChangePassword$).build() {
      static {
        __name(this, "ChangePasswordCommand");
      }
    };
    var CreateAccessKeyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "CreateAccessKey", {}).n("IAMClient", "CreateAccessKeyCommand").sc(schemas_0.CreateAccessKey$).build() {
      static {
        __name(this, "CreateAccessKeyCommand");
      }
    };
    var CreateAccountAliasCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "CreateAccountAlias", {}).n("IAMClient", "CreateAccountAliasCommand").sc(schemas_0.CreateAccountAlias$).build() {
      static {
        __name(this, "CreateAccountAliasCommand");
      }
    };
    var CreateDelegationRequestCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "CreateDelegationRequest", {}).n("IAMClient", "CreateDelegationRequestCommand").sc(schemas_0.CreateDelegationRequest$).build() {
      static {
        __name(this, "CreateDelegationRequestCommand");
      }
    };
    var CreateGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "CreateGroup", {}).n("IAMClient", "CreateGroupCommand").sc(schemas_0.CreateGroup$).build() {
      static {
        __name(this, "CreateGroupCommand");
      }
    };
    var CreateInstanceProfileCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "CreateInstanceProfile", {}).n("IAMClient", "CreateInstanceProfileCommand").sc(schemas_0.CreateInstanceProfile$).build() {
      static {
        __name(this, "CreateInstanceProfileCommand");
      }
    };
    var CreateLoginProfileCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "CreateLoginProfile", {}).n("IAMClient", "CreateLoginProfileCommand").sc(schemas_0.CreateLoginProfile$).build() {
      static {
        __name(this, "CreateLoginProfileCommand");
      }
    };
    var CreateOpenIDConnectProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "CreateOpenIDConnectProvider", {}).n("IAMClient", "CreateOpenIDConnectProviderCommand").sc(schemas_0.CreateOpenIDConnectProvider$).build() {
      static {
        __name(this, "CreateOpenIDConnectProviderCommand");
      }
    };
    var CreatePolicyCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "CreatePolicy", {}).n("IAMClient", "CreatePolicyCommand").sc(schemas_0.CreatePolicy$).build() {
      static {
        __name(this, "CreatePolicyCommand");
      }
    };
    var CreatePolicyVersionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "CreatePolicyVersion", {}).n("IAMClient", "CreatePolicyVersionCommand").sc(schemas_0.CreatePolicyVersion$).build() {
      static {
        __name(this, "CreatePolicyVersionCommand");
      }
    };
    var CreateRoleCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "CreateRole", {}).n("IAMClient", "CreateRoleCommand").sc(schemas_0.CreateRole$).build() {
      static {
        __name(this, "CreateRoleCommand");
      }
    };
    var CreateSAMLProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "CreateSAMLProvider", {}).n("IAMClient", "CreateSAMLProviderCommand").sc(schemas_0.CreateSAMLProvider$).build() {
      static {
        __name(this, "CreateSAMLProviderCommand");
      }
    };
    var CreateServiceLinkedRoleCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "CreateServiceLinkedRole", {}).n("IAMClient", "CreateServiceLinkedRoleCommand").sc(schemas_0.CreateServiceLinkedRole$).build() {
      static {
        __name(this, "CreateServiceLinkedRoleCommand");
      }
    };
    var CreateServiceSpecificCredentialCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "CreateServiceSpecificCredential", {}).n("IAMClient", "CreateServiceSpecificCredentialCommand").sc(schemas_0.CreateServiceSpecificCredential$).build() {
      static {
        __name(this, "CreateServiceSpecificCredentialCommand");
      }
    };
    var CreateUserCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "CreateUser", {}).n("IAMClient", "CreateUserCommand").sc(schemas_0.CreateUser$).build() {
      static {
        __name(this, "CreateUserCommand");
      }
    };
    var CreateVirtualMFADeviceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "CreateVirtualMFADevice", {}).n("IAMClient", "CreateVirtualMFADeviceCommand").sc(schemas_0.CreateVirtualMFADevice$).build() {
      static {
        __name(this, "CreateVirtualMFADeviceCommand");
      }
    };
    var DeactivateMFADeviceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DeactivateMFADevice", {}).n("IAMClient", "DeactivateMFADeviceCommand").sc(schemas_0.DeactivateMFADevice$).build() {
      static {
        __name(this, "DeactivateMFADeviceCommand");
      }
    };
    var DeleteAccessKeyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DeleteAccessKey", {}).n("IAMClient", "DeleteAccessKeyCommand").sc(schemas_0.DeleteAccessKey$).build() {
      static {
        __name(this, "DeleteAccessKeyCommand");
      }
    };
    var DeleteAccountAliasCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DeleteAccountAlias", {}).n("IAMClient", "DeleteAccountAliasCommand").sc(schemas_0.DeleteAccountAlias$).build() {
      static {
        __name(this, "DeleteAccountAliasCommand");
      }
    };
    var DeleteAccountPasswordPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DeleteAccountPasswordPolicy", {}).n("IAMClient", "DeleteAccountPasswordPolicyCommand").sc(schemas_0.DeleteAccountPasswordPolicy$).build() {
      static {
        __name(this, "DeleteAccountPasswordPolicyCommand");
      }
    };
    var DeleteGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DeleteGroup", {}).n("IAMClient", "DeleteGroupCommand").sc(schemas_0.DeleteGroup$).build() {
      static {
        __name(this, "DeleteGroupCommand");
      }
    };
    var DeleteGroupPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DeleteGroupPolicy", {}).n("IAMClient", "DeleteGroupPolicyCommand").sc(schemas_0.DeleteGroupPolicy$).build() {
      static {
        __name(this, "DeleteGroupPolicyCommand");
      }
    };
    var DeleteInstanceProfileCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DeleteInstanceProfile", {}).n("IAMClient", "DeleteInstanceProfileCommand").sc(schemas_0.DeleteInstanceProfile$).build() {
      static {
        __name(this, "DeleteInstanceProfileCommand");
      }
    };
    var DeleteLoginProfileCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DeleteLoginProfile", {}).n("IAMClient", "DeleteLoginProfileCommand").sc(schemas_0.DeleteLoginProfile$).build() {
      static {
        __name(this, "DeleteLoginProfileCommand");
      }
    };
    var DeleteOpenIDConnectProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DeleteOpenIDConnectProvider", {}).n("IAMClient", "DeleteOpenIDConnectProviderCommand").sc(schemas_0.DeleteOpenIDConnectProvider$).build() {
      static {
        __name(this, "DeleteOpenIDConnectProviderCommand");
      }
    };
    var DeletePolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DeletePolicy", {}).n("IAMClient", "DeletePolicyCommand").sc(schemas_0.DeletePolicy$).build() {
      static {
        __name(this, "DeletePolicyCommand");
      }
    };
    var DeletePolicyVersionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DeletePolicyVersion", {}).n("IAMClient", "DeletePolicyVersionCommand").sc(schemas_0.DeletePolicyVersion$).build() {
      static {
        __name(this, "DeletePolicyVersionCommand");
      }
    };
    var DeleteRoleCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DeleteRole", {}).n("IAMClient", "DeleteRoleCommand").sc(schemas_0.DeleteRole$).build() {
      static {
        __name(this, "DeleteRoleCommand");
      }
    };
    var DeleteRolePermissionsBoundaryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DeleteRolePermissionsBoundary", {}).n("IAMClient", "DeleteRolePermissionsBoundaryCommand").sc(schemas_0.DeleteRolePermissionsBoundary$).build() {
      static {
        __name(this, "DeleteRolePermissionsBoundaryCommand");
      }
    };
    var DeleteRolePolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DeleteRolePolicy", {}).n("IAMClient", "DeleteRolePolicyCommand").sc(schemas_0.DeleteRolePolicy$).build() {
      static {
        __name(this, "DeleteRolePolicyCommand");
      }
    };
    var DeleteSAMLProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DeleteSAMLProvider", {}).n("IAMClient", "DeleteSAMLProviderCommand").sc(schemas_0.DeleteSAMLProvider$).build() {
      static {
        __name(this, "DeleteSAMLProviderCommand");
      }
    };
    var DeleteServerCertificateCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DeleteServerCertificate", {}).n("IAMClient", "DeleteServerCertificateCommand").sc(schemas_0.DeleteServerCertificate$).build() {
      static {
        __name(this, "DeleteServerCertificateCommand");
      }
    };
    var DeleteServiceLinkedRoleCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DeleteServiceLinkedRole", {}).n("IAMClient", "DeleteServiceLinkedRoleCommand").sc(schemas_0.DeleteServiceLinkedRole$).build() {
      static {
        __name(this, "DeleteServiceLinkedRoleCommand");
      }
    };
    var DeleteServiceSpecificCredentialCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DeleteServiceSpecificCredential", {}).n("IAMClient", "DeleteServiceSpecificCredentialCommand").sc(schemas_0.DeleteServiceSpecificCredential$).build() {
      static {
        __name(this, "DeleteServiceSpecificCredentialCommand");
      }
    };
    var DeleteSigningCertificateCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DeleteSigningCertificate", {}).n("IAMClient", "DeleteSigningCertificateCommand").sc(schemas_0.DeleteSigningCertificate$).build() {
      static {
        __name(this, "DeleteSigningCertificateCommand");
      }
    };
    var DeleteSSHPublicKeyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DeleteSSHPublicKey", {}).n("IAMClient", "DeleteSSHPublicKeyCommand").sc(schemas_0.DeleteSSHPublicKey$).build() {
      static {
        __name(this, "DeleteSSHPublicKeyCommand");
      }
    };
    var DeleteUserCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DeleteUser", {}).n("IAMClient", "DeleteUserCommand").sc(schemas_0.DeleteUser$).build() {
      static {
        __name(this, "DeleteUserCommand");
      }
    };
    var DeleteUserPermissionsBoundaryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DeleteUserPermissionsBoundary", {}).n("IAMClient", "DeleteUserPermissionsBoundaryCommand").sc(schemas_0.DeleteUserPermissionsBoundary$).build() {
      static {
        __name(this, "DeleteUserPermissionsBoundaryCommand");
      }
    };
    var DeleteUserPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DeleteUserPolicy", {}).n("IAMClient", "DeleteUserPolicyCommand").sc(schemas_0.DeleteUserPolicy$).build() {
      static {
        __name(this, "DeleteUserPolicyCommand");
      }
    };
    var DeleteVirtualMFADeviceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DeleteVirtualMFADevice", {}).n("IAMClient", "DeleteVirtualMFADeviceCommand").sc(schemas_0.DeleteVirtualMFADevice$).build() {
      static {
        __name(this, "DeleteVirtualMFADeviceCommand");
      }
    };
    var DetachGroupPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DetachGroupPolicy", {}).n("IAMClient", "DetachGroupPolicyCommand").sc(schemas_0.DetachGroupPolicy$).build() {
      static {
        __name(this, "DetachGroupPolicyCommand");
      }
    };
    var DetachRolePolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DetachRolePolicy", {}).n("IAMClient", "DetachRolePolicyCommand").sc(schemas_0.DetachRolePolicy$).build() {
      static {
        __name(this, "DetachRolePolicyCommand");
      }
    };
    var DetachUserPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DetachUserPolicy", {}).n("IAMClient", "DetachUserPolicyCommand").sc(schemas_0.DetachUserPolicy$).build() {
      static {
        __name(this, "DetachUserPolicyCommand");
      }
    };
    var DisableOrganizationsRootCredentialsManagementCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DisableOrganizationsRootCredentialsManagement", {}).n("IAMClient", "DisableOrganizationsRootCredentialsManagementCommand").sc(schemas_0.DisableOrganizationsRootCredentialsManagement$).build() {
      static {
        __name(this, "DisableOrganizationsRootCredentialsManagementCommand");
      }
    };
    var DisableOrganizationsRootSessionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DisableOrganizationsRootSessions", {}).n("IAMClient", "DisableOrganizationsRootSessionsCommand").sc(schemas_0.DisableOrganizationsRootSessions$).build() {
      static {
        __name(this, "DisableOrganizationsRootSessionsCommand");
      }
    };
    var DisableOutboundWebIdentityFederationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "DisableOutboundWebIdentityFederation", {}).n("IAMClient", "DisableOutboundWebIdentityFederationCommand").sc(schemas_0.DisableOutboundWebIdentityFederation$).build() {
      static {
        __name(this, "DisableOutboundWebIdentityFederationCommand");
      }
    };
    var EnableMFADeviceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "EnableMFADevice", {}).n("IAMClient", "EnableMFADeviceCommand").sc(schemas_0.EnableMFADevice$).build() {
      static {
        __name(this, "EnableMFADeviceCommand");
      }
    };
    var EnableOrganizationsRootCredentialsManagementCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "EnableOrganizationsRootCredentialsManagement", {}).n("IAMClient", "EnableOrganizationsRootCredentialsManagementCommand").sc(schemas_0.EnableOrganizationsRootCredentialsManagement$).build() {
      static {
        __name(this, "EnableOrganizationsRootCredentialsManagementCommand");
      }
    };
    var EnableOrganizationsRootSessionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "EnableOrganizationsRootSessions", {}).n("IAMClient", "EnableOrganizationsRootSessionsCommand").sc(schemas_0.EnableOrganizationsRootSessions$).build() {
      static {
        __name(this, "EnableOrganizationsRootSessionsCommand");
      }
    };
    var EnableOutboundWebIdentityFederationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "EnableOutboundWebIdentityFederation", {}).n("IAMClient", "EnableOutboundWebIdentityFederationCommand").sc(schemas_0.EnableOutboundWebIdentityFederation$).build() {
      static {
        __name(this, "EnableOutboundWebIdentityFederationCommand");
      }
    };
    var GenerateCredentialReportCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GenerateCredentialReport", {}).n("IAMClient", "GenerateCredentialReportCommand").sc(schemas_0.GenerateCredentialReport$).build() {
      static {
        __name(this, "GenerateCredentialReportCommand");
      }
    };
    var GenerateOrganizationsAccessReportCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GenerateOrganizationsAccessReport", {}).n("IAMClient", "GenerateOrganizationsAccessReportCommand").sc(schemas_0.GenerateOrganizationsAccessReport$).build() {
      static {
        __name(this, "GenerateOrganizationsAccessReportCommand");
      }
    };
    var GenerateServiceLastAccessedDetailsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GenerateServiceLastAccessedDetails", {}).n("IAMClient", "GenerateServiceLastAccessedDetailsCommand").sc(schemas_0.GenerateServiceLastAccessedDetails$).build() {
      static {
        __name(this, "GenerateServiceLastAccessedDetailsCommand");
      }
    };
    var GetAccessKeyLastUsedCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetAccessKeyLastUsed", {}).n("IAMClient", "GetAccessKeyLastUsedCommand").sc(schemas_0.GetAccessKeyLastUsed$).build() {
      static {
        __name(this, "GetAccessKeyLastUsedCommand");
      }
    };
    var GetAccountAuthorizationDetailsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetAccountAuthorizationDetails", {}).n("IAMClient", "GetAccountAuthorizationDetailsCommand").sc(schemas_0.GetAccountAuthorizationDetails$).build() {
      static {
        __name(this, "GetAccountAuthorizationDetailsCommand");
      }
    };
    var GetAccountPasswordPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetAccountPasswordPolicy", {}).n("IAMClient", "GetAccountPasswordPolicyCommand").sc(schemas_0.GetAccountPasswordPolicy$).build() {
      static {
        __name(this, "GetAccountPasswordPolicyCommand");
      }
    };
    var GetAccountSummaryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetAccountSummary", {}).n("IAMClient", "GetAccountSummaryCommand").sc(schemas_0.GetAccountSummary$).build() {
      static {
        __name(this, "GetAccountSummaryCommand");
      }
    };
    var GetContextKeysForCustomPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetContextKeysForCustomPolicy", {}).n("IAMClient", "GetContextKeysForCustomPolicyCommand").sc(schemas_0.GetContextKeysForCustomPolicy$).build() {
      static {
        __name(this, "GetContextKeysForCustomPolicyCommand");
      }
    };
    var GetContextKeysForPrincipalPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetContextKeysForPrincipalPolicy", {}).n("IAMClient", "GetContextKeysForPrincipalPolicyCommand").sc(schemas_0.GetContextKeysForPrincipalPolicy$).build() {
      static {
        __name(this, "GetContextKeysForPrincipalPolicyCommand");
      }
    };
    var GetCredentialReportCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetCredentialReport", {}).n("IAMClient", "GetCredentialReportCommand").sc(schemas_0.GetCredentialReport$).build() {
      static {
        __name(this, "GetCredentialReportCommand");
      }
    };
    var GetDelegationRequestCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetDelegationRequest", {}).n("IAMClient", "GetDelegationRequestCommand").sc(schemas_0.GetDelegationRequest$).build() {
      static {
        __name(this, "GetDelegationRequestCommand");
      }
    };
    var GetGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetGroup", {}).n("IAMClient", "GetGroupCommand").sc(schemas_0.GetGroup$).build() {
      static {
        __name(this, "GetGroupCommand");
      }
    };
    var GetGroupPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetGroupPolicy", {}).n("IAMClient", "GetGroupPolicyCommand").sc(schemas_0.GetGroupPolicy$).build() {
      static {
        __name(this, "GetGroupPolicyCommand");
      }
    };
    var GetHumanReadableSummaryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetHumanReadableSummary", {}).n("IAMClient", "GetHumanReadableSummaryCommand").sc(schemas_0.GetHumanReadableSummary$).build() {
      static {
        __name(this, "GetHumanReadableSummaryCommand");
      }
    };
    var GetInstanceProfileCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetInstanceProfile", {}).n("IAMClient", "GetInstanceProfileCommand").sc(schemas_0.GetInstanceProfile$).build() {
      static {
        __name(this, "GetInstanceProfileCommand");
      }
    };
    var GetLoginProfileCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetLoginProfile", {}).n("IAMClient", "GetLoginProfileCommand").sc(schemas_0.GetLoginProfile$).build() {
      static {
        __name(this, "GetLoginProfileCommand");
      }
    };
    var GetMFADeviceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetMFADevice", {}).n("IAMClient", "GetMFADeviceCommand").sc(schemas_0.GetMFADevice$).build() {
      static {
        __name(this, "GetMFADeviceCommand");
      }
    };
    var GetOpenIDConnectProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetOpenIDConnectProvider", {}).n("IAMClient", "GetOpenIDConnectProviderCommand").sc(schemas_0.GetOpenIDConnectProvider$).build() {
      static {
        __name(this, "GetOpenIDConnectProviderCommand");
      }
    };
    var GetOrganizationsAccessReportCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetOrganizationsAccessReport", {}).n("IAMClient", "GetOrganizationsAccessReportCommand").sc(schemas_0.GetOrganizationsAccessReport$).build() {
      static {
        __name(this, "GetOrganizationsAccessReportCommand");
      }
    };
    var GetOutboundWebIdentityFederationInfoCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetOutboundWebIdentityFederationInfo", {}).n("IAMClient", "GetOutboundWebIdentityFederationInfoCommand").sc(schemas_0.GetOutboundWebIdentityFederationInfo$).build() {
      static {
        __name(this, "GetOutboundWebIdentityFederationInfoCommand");
      }
    };
    var GetPolicyCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetPolicy", {}).n("IAMClient", "GetPolicyCommand").sc(schemas_0.GetPolicy$).build() {
      static {
        __name(this, "GetPolicyCommand");
      }
    };
    var GetPolicyVersionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetPolicyVersion", {}).n("IAMClient", "GetPolicyVersionCommand").sc(schemas_0.GetPolicyVersion$).build() {
      static {
        __name(this, "GetPolicyVersionCommand");
      }
    };
    var GetRoleCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetRole", {}).n("IAMClient", "GetRoleCommand").sc(schemas_0.GetRole$).build() {
      static {
        __name(this, "GetRoleCommand");
      }
    };
    var GetRolePolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetRolePolicy", {}).n("IAMClient", "GetRolePolicyCommand").sc(schemas_0.GetRolePolicy$).build() {
      static {
        __name(this, "GetRolePolicyCommand");
      }
    };
    var GetSAMLProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetSAMLProvider", {}).n("IAMClient", "GetSAMLProviderCommand").sc(schemas_0.GetSAMLProvider$).build() {
      static {
        __name(this, "GetSAMLProviderCommand");
      }
    };
    var GetServerCertificateCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetServerCertificate", {}).n("IAMClient", "GetServerCertificateCommand").sc(schemas_0.GetServerCertificate$).build() {
      static {
        __name(this, "GetServerCertificateCommand");
      }
    };
    var GetServiceLastAccessedDetailsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetServiceLastAccessedDetails", {}).n("IAMClient", "GetServiceLastAccessedDetailsCommand").sc(schemas_0.GetServiceLastAccessedDetails$).build() {
      static {
        __name(this, "GetServiceLastAccessedDetailsCommand");
      }
    };
    var GetServiceLastAccessedDetailsWithEntitiesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetServiceLastAccessedDetailsWithEntities", {}).n("IAMClient", "GetServiceLastAccessedDetailsWithEntitiesCommand").sc(schemas_0.GetServiceLastAccessedDetailsWithEntities$).build() {
      static {
        __name(this, "GetServiceLastAccessedDetailsWithEntitiesCommand");
      }
    };
    var GetServiceLinkedRoleDeletionStatusCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetServiceLinkedRoleDeletionStatus", {}).n("IAMClient", "GetServiceLinkedRoleDeletionStatusCommand").sc(schemas_0.GetServiceLinkedRoleDeletionStatus$).build() {
      static {
        __name(this, "GetServiceLinkedRoleDeletionStatusCommand");
      }
    };
    var GetSSHPublicKeyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetSSHPublicKey", {}).n("IAMClient", "GetSSHPublicKeyCommand").sc(schemas_0.GetSSHPublicKey$).build() {
      static {
        __name(this, "GetSSHPublicKeyCommand");
      }
    };
    var GetUserCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetUser", {}).n("IAMClient", "GetUserCommand").sc(schemas_0.GetUser$).build() {
      static {
        __name(this, "GetUserCommand");
      }
    };
    var GetUserPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "GetUserPolicy", {}).n("IAMClient", "GetUserPolicyCommand").sc(schemas_0.GetUserPolicy$).build() {
      static {
        __name(this, "GetUserPolicyCommand");
      }
    };
    var ListAccessKeysCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListAccessKeys", {}).n("IAMClient", "ListAccessKeysCommand").sc(schemas_0.ListAccessKeys$).build() {
      static {
        __name(this, "ListAccessKeysCommand");
      }
    };
    var ListAccountAliasesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListAccountAliases", {}).n("IAMClient", "ListAccountAliasesCommand").sc(schemas_0.ListAccountAliases$).build() {
      static {
        __name(this, "ListAccountAliasesCommand");
      }
    };
    var ListAttachedGroupPoliciesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListAttachedGroupPolicies", {}).n("IAMClient", "ListAttachedGroupPoliciesCommand").sc(schemas_0.ListAttachedGroupPolicies$).build() {
      static {
        __name(this, "ListAttachedGroupPoliciesCommand");
      }
    };
    var ListAttachedRolePoliciesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListAttachedRolePolicies", {}).n("IAMClient", "ListAttachedRolePoliciesCommand").sc(schemas_0.ListAttachedRolePolicies$).build() {
      static {
        __name(this, "ListAttachedRolePoliciesCommand");
      }
    };
    var ListAttachedUserPoliciesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListAttachedUserPolicies", {}).n("IAMClient", "ListAttachedUserPoliciesCommand").sc(schemas_0.ListAttachedUserPolicies$).build() {
      static {
        __name(this, "ListAttachedUserPoliciesCommand");
      }
    };
    var ListDelegationRequestsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListDelegationRequests", {}).n("IAMClient", "ListDelegationRequestsCommand").sc(schemas_0.ListDelegationRequests$).build() {
      static {
        __name(this, "ListDelegationRequestsCommand");
      }
    };
    var ListEntitiesForPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListEntitiesForPolicy", {}).n("IAMClient", "ListEntitiesForPolicyCommand").sc(schemas_0.ListEntitiesForPolicy$).build() {
      static {
        __name(this, "ListEntitiesForPolicyCommand");
      }
    };
    var ListGroupPoliciesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListGroupPolicies", {}).n("IAMClient", "ListGroupPoliciesCommand").sc(schemas_0.ListGroupPolicies$).build() {
      static {
        __name(this, "ListGroupPoliciesCommand");
      }
    };
    var ListGroupsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListGroups", {}).n("IAMClient", "ListGroupsCommand").sc(schemas_0.ListGroups$).build() {
      static {
        __name(this, "ListGroupsCommand");
      }
    };
    var ListGroupsForUserCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListGroupsForUser", {}).n("IAMClient", "ListGroupsForUserCommand").sc(schemas_0.ListGroupsForUser$).build() {
      static {
        __name(this, "ListGroupsForUserCommand");
      }
    };
    var ListInstanceProfilesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListInstanceProfiles", {}).n("IAMClient", "ListInstanceProfilesCommand").sc(schemas_0.ListInstanceProfiles$).build() {
      static {
        __name(this, "ListInstanceProfilesCommand");
      }
    };
    var ListInstanceProfilesForRoleCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListInstanceProfilesForRole", {}).n("IAMClient", "ListInstanceProfilesForRoleCommand").sc(schemas_0.ListInstanceProfilesForRole$).build() {
      static {
        __name(this, "ListInstanceProfilesForRoleCommand");
      }
    };
    var ListInstanceProfileTagsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListInstanceProfileTags", {}).n("IAMClient", "ListInstanceProfileTagsCommand").sc(schemas_0.ListInstanceProfileTags$).build() {
      static {
        __name(this, "ListInstanceProfileTagsCommand");
      }
    };
    var ListMFADevicesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListMFADevices", {}).n("IAMClient", "ListMFADevicesCommand").sc(schemas_0.ListMFADevices$).build() {
      static {
        __name(this, "ListMFADevicesCommand");
      }
    };
    var ListMFADeviceTagsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListMFADeviceTags", {}).n("IAMClient", "ListMFADeviceTagsCommand").sc(schemas_0.ListMFADeviceTags$).build() {
      static {
        __name(this, "ListMFADeviceTagsCommand");
      }
    };
    var ListOpenIDConnectProvidersCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListOpenIDConnectProviders", {}).n("IAMClient", "ListOpenIDConnectProvidersCommand").sc(schemas_0.ListOpenIDConnectProviders$).build() {
      static {
        __name(this, "ListOpenIDConnectProvidersCommand");
      }
    };
    var ListOpenIDConnectProviderTagsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListOpenIDConnectProviderTags", {}).n("IAMClient", "ListOpenIDConnectProviderTagsCommand").sc(schemas_0.ListOpenIDConnectProviderTags$).build() {
      static {
        __name(this, "ListOpenIDConnectProviderTagsCommand");
      }
    };
    var ListOrganizationsFeaturesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListOrganizationsFeatures", {}).n("IAMClient", "ListOrganizationsFeaturesCommand").sc(schemas_0.ListOrganizationsFeatures$).build() {
      static {
        __name(this, "ListOrganizationsFeaturesCommand");
      }
    };
    var ListPoliciesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListPolicies", {}).n("IAMClient", "ListPoliciesCommand").sc(schemas_0.ListPolicies$).build() {
      static {
        __name(this, "ListPoliciesCommand");
      }
    };
    var ListPoliciesGrantingServiceAccessCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListPoliciesGrantingServiceAccess", {}).n("IAMClient", "ListPoliciesGrantingServiceAccessCommand").sc(schemas_0.ListPoliciesGrantingServiceAccess$).build() {
      static {
        __name(this, "ListPoliciesGrantingServiceAccessCommand");
      }
    };
    var ListPolicyTagsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListPolicyTags", {}).n("IAMClient", "ListPolicyTagsCommand").sc(schemas_0.ListPolicyTags$).build() {
      static {
        __name(this, "ListPolicyTagsCommand");
      }
    };
    var ListPolicyVersionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListPolicyVersions", {}).n("IAMClient", "ListPolicyVersionsCommand").sc(schemas_0.ListPolicyVersions$).build() {
      static {
        __name(this, "ListPolicyVersionsCommand");
      }
    };
    var ListRolePoliciesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListRolePolicies", {}).n("IAMClient", "ListRolePoliciesCommand").sc(schemas_0.ListRolePolicies$).build() {
      static {
        __name(this, "ListRolePoliciesCommand");
      }
    };
    var ListRolesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListRoles", {}).n("IAMClient", "ListRolesCommand").sc(schemas_0.ListRoles$).build() {
      static {
        __name(this, "ListRolesCommand");
      }
    };
    var ListRoleTagsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListRoleTags", {}).n("IAMClient", "ListRoleTagsCommand").sc(schemas_0.ListRoleTags$).build() {
      static {
        __name(this, "ListRoleTagsCommand");
      }
    };
    var ListSAMLProvidersCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListSAMLProviders", {}).n("IAMClient", "ListSAMLProvidersCommand").sc(schemas_0.ListSAMLProviders$).build() {
      static {
        __name(this, "ListSAMLProvidersCommand");
      }
    };
    var ListSAMLProviderTagsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListSAMLProviderTags", {}).n("IAMClient", "ListSAMLProviderTagsCommand").sc(schemas_0.ListSAMLProviderTags$).build() {
      static {
        __name(this, "ListSAMLProviderTagsCommand");
      }
    };
    var ListServerCertificatesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListServerCertificates", {}).n("IAMClient", "ListServerCertificatesCommand").sc(schemas_0.ListServerCertificates$).build() {
      static {
        __name(this, "ListServerCertificatesCommand");
      }
    };
    var ListServerCertificateTagsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListServerCertificateTags", {}).n("IAMClient", "ListServerCertificateTagsCommand").sc(schemas_0.ListServerCertificateTags$).build() {
      static {
        __name(this, "ListServerCertificateTagsCommand");
      }
    };
    var ListServiceSpecificCredentialsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListServiceSpecificCredentials", {}).n("IAMClient", "ListServiceSpecificCredentialsCommand").sc(schemas_0.ListServiceSpecificCredentials$).build() {
      static {
        __name(this, "ListServiceSpecificCredentialsCommand");
      }
    };
    var ListSigningCertificatesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListSigningCertificates", {}).n("IAMClient", "ListSigningCertificatesCommand").sc(schemas_0.ListSigningCertificates$).build() {
      static {
        __name(this, "ListSigningCertificatesCommand");
      }
    };
    var ListSSHPublicKeysCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListSSHPublicKeys", {}).n("IAMClient", "ListSSHPublicKeysCommand").sc(schemas_0.ListSSHPublicKeys$).build() {
      static {
        __name(this, "ListSSHPublicKeysCommand");
      }
    };
    var ListUserPoliciesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListUserPolicies", {}).n("IAMClient", "ListUserPoliciesCommand").sc(schemas_0.ListUserPolicies$).build() {
      static {
        __name(this, "ListUserPoliciesCommand");
      }
    };
    var ListUsersCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListUsers", {}).n("IAMClient", "ListUsersCommand").sc(schemas_0.ListUsers$).build() {
      static {
        __name(this, "ListUsersCommand");
      }
    };
    var ListUserTagsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListUserTags", {}).n("IAMClient", "ListUserTagsCommand").sc(schemas_0.ListUserTags$).build() {
      static {
        __name(this, "ListUserTagsCommand");
      }
    };
    var ListVirtualMFADevicesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ListVirtualMFADevices", {}).n("IAMClient", "ListVirtualMFADevicesCommand").sc(schemas_0.ListVirtualMFADevices$).build() {
      static {
        __name(this, "ListVirtualMFADevicesCommand");
      }
    };
    var PutGroupPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "PutGroupPolicy", {}).n("IAMClient", "PutGroupPolicyCommand").sc(schemas_0.PutGroupPolicy$).build() {
      static {
        __name(this, "PutGroupPolicyCommand");
      }
    };
    var PutRolePermissionsBoundaryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "PutRolePermissionsBoundary", {}).n("IAMClient", "PutRolePermissionsBoundaryCommand").sc(schemas_0.PutRolePermissionsBoundary$).build() {
      static {
        __name(this, "PutRolePermissionsBoundaryCommand");
      }
    };
    var PutRolePolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "PutRolePolicy", {}).n("IAMClient", "PutRolePolicyCommand").sc(schemas_0.PutRolePolicy$).build() {
      static {
        __name(this, "PutRolePolicyCommand");
      }
    };
    var PutUserPermissionsBoundaryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "PutUserPermissionsBoundary", {}).n("IAMClient", "PutUserPermissionsBoundaryCommand").sc(schemas_0.PutUserPermissionsBoundary$).build() {
      static {
        __name(this, "PutUserPermissionsBoundaryCommand");
      }
    };
    var PutUserPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "PutUserPolicy", {}).n("IAMClient", "PutUserPolicyCommand").sc(schemas_0.PutUserPolicy$).build() {
      static {
        __name(this, "PutUserPolicyCommand");
      }
    };
    var RejectDelegationRequestCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "RejectDelegationRequest", {}).n("IAMClient", "RejectDelegationRequestCommand").sc(schemas_0.RejectDelegationRequest$).build() {
      static {
        __name(this, "RejectDelegationRequestCommand");
      }
    };
    var RemoveClientIDFromOpenIDConnectProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "RemoveClientIDFromOpenIDConnectProvider", {}).n("IAMClient", "RemoveClientIDFromOpenIDConnectProviderCommand").sc(schemas_0.RemoveClientIDFromOpenIDConnectProvider$).build() {
      static {
        __name(this, "RemoveClientIDFromOpenIDConnectProviderCommand");
      }
    };
    var RemoveRoleFromInstanceProfileCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "RemoveRoleFromInstanceProfile", {}).n("IAMClient", "RemoveRoleFromInstanceProfileCommand").sc(schemas_0.RemoveRoleFromInstanceProfile$).build() {
      static {
        __name(this, "RemoveRoleFromInstanceProfileCommand");
      }
    };
    var RemoveUserFromGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "RemoveUserFromGroup", {}).n("IAMClient", "RemoveUserFromGroupCommand").sc(schemas_0.RemoveUserFromGroup$).build() {
      static {
        __name(this, "RemoveUserFromGroupCommand");
      }
    };
    var ResetServiceSpecificCredentialCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ResetServiceSpecificCredential", {}).n("IAMClient", "ResetServiceSpecificCredentialCommand").sc(schemas_0.ResetServiceSpecificCredential$).build() {
      static {
        __name(this, "ResetServiceSpecificCredentialCommand");
      }
    };
    var ResyncMFADeviceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "ResyncMFADevice", {}).n("IAMClient", "ResyncMFADeviceCommand").sc(schemas_0.ResyncMFADevice$).build() {
      static {
        __name(this, "ResyncMFADeviceCommand");
      }
    };
    var SendDelegationTokenCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "SendDelegationToken", {}).n("IAMClient", "SendDelegationTokenCommand").sc(schemas_0.SendDelegationToken$).build() {
      static {
        __name(this, "SendDelegationTokenCommand");
      }
    };
    var SetDefaultPolicyVersionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "SetDefaultPolicyVersion", {}).n("IAMClient", "SetDefaultPolicyVersionCommand").sc(schemas_0.SetDefaultPolicyVersion$).build() {
      static {
        __name(this, "SetDefaultPolicyVersionCommand");
      }
    };
    var SetSecurityTokenServicePreferencesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "SetSecurityTokenServicePreferences", {}).n("IAMClient", "SetSecurityTokenServicePreferencesCommand").sc(schemas_0.SetSecurityTokenServicePreferences$).build() {
      static {
        __name(this, "SetSecurityTokenServicePreferencesCommand");
      }
    };
    var SimulateCustomPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "SimulateCustomPolicy", {}).n("IAMClient", "SimulateCustomPolicyCommand").sc(schemas_0.SimulateCustomPolicy$).build() {
      static {
        __name(this, "SimulateCustomPolicyCommand");
      }
    };
    var SimulatePrincipalPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "SimulatePrincipalPolicy", {}).n("IAMClient", "SimulatePrincipalPolicyCommand").sc(schemas_0.SimulatePrincipalPolicy$).build() {
      static {
        __name(this, "SimulatePrincipalPolicyCommand");
      }
    };
    var TagInstanceProfileCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "TagInstanceProfile", {}).n("IAMClient", "TagInstanceProfileCommand").sc(schemas_0.TagInstanceProfile$).build() {
      static {
        __name(this, "TagInstanceProfileCommand");
      }
    };
    var TagMFADeviceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "TagMFADevice", {}).n("IAMClient", "TagMFADeviceCommand").sc(schemas_0.TagMFADevice$).build() {
      static {
        __name(this, "TagMFADeviceCommand");
      }
    };
    var TagOpenIDConnectProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "TagOpenIDConnectProvider", {}).n("IAMClient", "TagOpenIDConnectProviderCommand").sc(schemas_0.TagOpenIDConnectProvider$).build() {
      static {
        __name(this, "TagOpenIDConnectProviderCommand");
      }
    };
    var TagPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "TagPolicy", {}).n("IAMClient", "TagPolicyCommand").sc(schemas_0.TagPolicy$).build() {
      static {
        __name(this, "TagPolicyCommand");
      }
    };
    var TagRoleCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "TagRole", {}).n("IAMClient", "TagRoleCommand").sc(schemas_0.TagRole$).build() {
      static {
        __name(this, "TagRoleCommand");
      }
    };
    var TagSAMLProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "TagSAMLProvider", {}).n("IAMClient", "TagSAMLProviderCommand").sc(schemas_0.TagSAMLProvider$).build() {
      static {
        __name(this, "TagSAMLProviderCommand");
      }
    };
    var TagServerCertificateCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "TagServerCertificate", {}).n("IAMClient", "TagServerCertificateCommand").sc(schemas_0.TagServerCertificate$).build() {
      static {
        __name(this, "TagServerCertificateCommand");
      }
    };
    var TagUserCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "TagUser", {}).n("IAMClient", "TagUserCommand").sc(schemas_0.TagUser$).build() {
      static {
        __name(this, "TagUserCommand");
      }
    };
    var UntagInstanceProfileCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "UntagInstanceProfile", {}).n("IAMClient", "UntagInstanceProfileCommand").sc(schemas_0.UntagInstanceProfile$).build() {
      static {
        __name(this, "UntagInstanceProfileCommand");
      }
    };
    var UntagMFADeviceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "UntagMFADevice", {}).n("IAMClient", "UntagMFADeviceCommand").sc(schemas_0.UntagMFADevice$).build() {
      static {
        __name(this, "UntagMFADeviceCommand");
      }
    };
    var UntagOpenIDConnectProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "UntagOpenIDConnectProvider", {}).n("IAMClient", "UntagOpenIDConnectProviderCommand").sc(schemas_0.UntagOpenIDConnectProvider$).build() {
      static {
        __name(this, "UntagOpenIDConnectProviderCommand");
      }
    };
    var UntagPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "UntagPolicy", {}).n("IAMClient", "UntagPolicyCommand").sc(schemas_0.UntagPolicy$).build() {
      static {
        __name(this, "UntagPolicyCommand");
      }
    };
    var UntagRoleCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "UntagRole", {}).n("IAMClient", "UntagRoleCommand").sc(schemas_0.UntagRole$).build() {
      static {
        __name(this, "UntagRoleCommand");
      }
    };
    var UntagSAMLProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "UntagSAMLProvider", {}).n("IAMClient", "UntagSAMLProviderCommand").sc(schemas_0.UntagSAMLProvider$).build() {
      static {
        __name(this, "UntagSAMLProviderCommand");
      }
    };
    var UntagServerCertificateCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "UntagServerCertificate", {}).n("IAMClient", "UntagServerCertificateCommand").sc(schemas_0.UntagServerCertificate$).build() {
      static {
        __name(this, "UntagServerCertificateCommand");
      }
    };
    var UntagUserCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "UntagUser", {}).n("IAMClient", "UntagUserCommand").sc(schemas_0.UntagUser$).build() {
      static {
        __name(this, "UntagUserCommand");
      }
    };
    var UpdateAccessKeyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "UpdateAccessKey", {}).n("IAMClient", "UpdateAccessKeyCommand").sc(schemas_0.UpdateAccessKey$).build() {
      static {
        __name(this, "UpdateAccessKeyCommand");
      }
    };
    var UpdateAccountPasswordPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "UpdateAccountPasswordPolicy", {}).n("IAMClient", "UpdateAccountPasswordPolicyCommand").sc(schemas_0.UpdateAccountPasswordPolicy$).build() {
      static {
        __name(this, "UpdateAccountPasswordPolicyCommand");
      }
    };
    var UpdateAssumeRolePolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "UpdateAssumeRolePolicy", {}).n("IAMClient", "UpdateAssumeRolePolicyCommand").sc(schemas_0.UpdateAssumeRolePolicy$).build() {
      static {
        __name(this, "UpdateAssumeRolePolicyCommand");
      }
    };
    var UpdateDelegationRequestCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "UpdateDelegationRequest", {}).n("IAMClient", "UpdateDelegationRequestCommand").sc(schemas_0.UpdateDelegationRequest$).build() {
      static {
        __name(this, "UpdateDelegationRequestCommand");
      }
    };
    var UpdateGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "UpdateGroup", {}).n("IAMClient", "UpdateGroupCommand").sc(schemas_0.UpdateGroup$).build() {
      static {
        __name(this, "UpdateGroupCommand");
      }
    };
    var UpdateLoginProfileCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "UpdateLoginProfile", {}).n("IAMClient", "UpdateLoginProfileCommand").sc(schemas_0.UpdateLoginProfile$).build() {
      static {
        __name(this, "UpdateLoginProfileCommand");
      }
    };
    var UpdateOpenIDConnectProviderThumbprintCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "UpdateOpenIDConnectProviderThumbprint", {}).n("IAMClient", "UpdateOpenIDConnectProviderThumbprintCommand").sc(schemas_0.UpdateOpenIDConnectProviderThumbprint$).build() {
      static {
        __name(this, "UpdateOpenIDConnectProviderThumbprintCommand");
      }
    };
    var UpdateRoleCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "UpdateRole", {}).n("IAMClient", "UpdateRoleCommand").sc(schemas_0.UpdateRole$).build() {
      static {
        __name(this, "UpdateRoleCommand");
      }
    };
    var UpdateRoleDescriptionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "UpdateRoleDescription", {}).n("IAMClient", "UpdateRoleDescriptionCommand").sc(schemas_0.UpdateRoleDescription$).build() {
      static {
        __name(this, "UpdateRoleDescriptionCommand");
      }
    };
    var UpdateSAMLProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "UpdateSAMLProvider", {}).n("IAMClient", "UpdateSAMLProviderCommand").sc(schemas_0.UpdateSAMLProvider$).build() {
      static {
        __name(this, "UpdateSAMLProviderCommand");
      }
    };
    var UpdateServerCertificateCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "UpdateServerCertificate", {}).n("IAMClient", "UpdateServerCertificateCommand").sc(schemas_0.UpdateServerCertificate$).build() {
      static {
        __name(this, "UpdateServerCertificateCommand");
      }
    };
    var UpdateServiceSpecificCredentialCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "UpdateServiceSpecificCredential", {}).n("IAMClient", "UpdateServiceSpecificCredentialCommand").sc(schemas_0.UpdateServiceSpecificCredential$).build() {
      static {
        __name(this, "UpdateServiceSpecificCredentialCommand");
      }
    };
    var UpdateSigningCertificateCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "UpdateSigningCertificate", {}).n("IAMClient", "UpdateSigningCertificateCommand").sc(schemas_0.UpdateSigningCertificate$).build() {
      static {
        __name(this, "UpdateSigningCertificateCommand");
      }
    };
    var UpdateSSHPublicKeyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "UpdateSSHPublicKey", {}).n("IAMClient", "UpdateSSHPublicKeyCommand").sc(schemas_0.UpdateSSHPublicKey$).build() {
      static {
        __name(this, "UpdateSSHPublicKeyCommand");
      }
    };
    var UpdateUserCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "UpdateUser", {}).n("IAMClient", "UpdateUserCommand").sc(schemas_0.UpdateUser$).build() {
      static {
        __name(this, "UpdateUserCommand");
      }
    };
    var UploadServerCertificateCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "UploadServerCertificate", {}).n("IAMClient", "UploadServerCertificateCommand").sc(schemas_0.UploadServerCertificate$).build() {
      static {
        __name(this, "UploadServerCertificateCommand");
      }
    };
    var UploadSigningCertificateCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "UploadSigningCertificate", {}).n("IAMClient", "UploadSigningCertificateCommand").sc(schemas_0.UploadSigningCertificate$).build() {
      static {
        __name(this, "UploadSigningCertificateCommand");
      }
    };
    var UploadSSHPublicKeyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSIdentityManagementV20100508", "UploadSSHPublicKey", {}).n("IAMClient", "UploadSSHPublicKeyCommand").sc(schemas_0.UploadSSHPublicKey$).build() {
      static {
        __name(this, "UploadSSHPublicKeyCommand");
      }
    };
    var paginateGetAccountAuthorizationDetails = core.createPaginator(IAMClient2, GetAccountAuthorizationDetailsCommand, "Marker", "Marker", "MaxItems");
    var paginateGetGroup = core.createPaginator(IAMClient2, GetGroupCommand, "Marker", "Marker", "MaxItems");
    var paginateListAccessKeys = core.createPaginator(IAMClient2, ListAccessKeysCommand, "Marker", "Marker", "MaxItems");
    var paginateListAccountAliases = core.createPaginator(IAMClient2, ListAccountAliasesCommand, "Marker", "Marker", "MaxItems");
    var paginateListAttachedGroupPolicies = core.createPaginator(IAMClient2, ListAttachedGroupPoliciesCommand, "Marker", "Marker", "MaxItems");
    var paginateListAttachedRolePolicies = core.createPaginator(IAMClient2, ListAttachedRolePoliciesCommand, "Marker", "Marker", "MaxItems");
    var paginateListAttachedUserPolicies = core.createPaginator(IAMClient2, ListAttachedUserPoliciesCommand, "Marker", "Marker", "MaxItems");
    var paginateListEntitiesForPolicy = core.createPaginator(IAMClient2, ListEntitiesForPolicyCommand, "Marker", "Marker", "MaxItems");
    var paginateListGroupPolicies = core.createPaginator(IAMClient2, ListGroupPoliciesCommand, "Marker", "Marker", "MaxItems");
    var paginateListGroupsForUser = core.createPaginator(IAMClient2, ListGroupsForUserCommand, "Marker", "Marker", "MaxItems");
    var paginateListGroups = core.createPaginator(IAMClient2, ListGroupsCommand, "Marker", "Marker", "MaxItems");
    var paginateListInstanceProfilesForRole = core.createPaginator(IAMClient2, ListInstanceProfilesForRoleCommand, "Marker", "Marker", "MaxItems");
    var paginateListInstanceProfiles = core.createPaginator(IAMClient2, ListInstanceProfilesCommand, "Marker", "Marker", "MaxItems");
    var paginateListInstanceProfileTags = core.createPaginator(IAMClient2, ListInstanceProfileTagsCommand, "Marker", "Marker", "MaxItems");
    var paginateListMFADevices = core.createPaginator(IAMClient2, ListMFADevicesCommand, "Marker", "Marker", "MaxItems");
    var paginateListMFADeviceTags = core.createPaginator(IAMClient2, ListMFADeviceTagsCommand, "Marker", "Marker", "MaxItems");
    var paginateListOpenIDConnectProviderTags = core.createPaginator(IAMClient2, ListOpenIDConnectProviderTagsCommand, "Marker", "Marker", "MaxItems");
    var paginateListPolicies = core.createPaginator(IAMClient2, ListPoliciesCommand, "Marker", "Marker", "MaxItems");
    var paginateListPolicyTags = core.createPaginator(IAMClient2, ListPolicyTagsCommand, "Marker", "Marker", "MaxItems");
    var paginateListPolicyVersions = core.createPaginator(IAMClient2, ListPolicyVersionsCommand, "Marker", "Marker", "MaxItems");
    var paginateListRolePolicies = core.createPaginator(IAMClient2, ListRolePoliciesCommand, "Marker", "Marker", "MaxItems");
    var paginateListRoles = core.createPaginator(IAMClient2, ListRolesCommand, "Marker", "Marker", "MaxItems");
    var paginateListRoleTags = core.createPaginator(IAMClient2, ListRoleTagsCommand, "Marker", "Marker", "MaxItems");
    var paginateListSAMLProviderTags = core.createPaginator(IAMClient2, ListSAMLProviderTagsCommand, "Marker", "Marker", "MaxItems");
    var paginateListServerCertificates = core.createPaginator(IAMClient2, ListServerCertificatesCommand, "Marker", "Marker", "MaxItems");
    var paginateListServerCertificateTags = core.createPaginator(IAMClient2, ListServerCertificateTagsCommand, "Marker", "Marker", "MaxItems");
    var paginateListSigningCertificates = core.createPaginator(IAMClient2, ListSigningCertificatesCommand, "Marker", "Marker", "MaxItems");
    var paginateListSSHPublicKeys = core.createPaginator(IAMClient2, ListSSHPublicKeysCommand, "Marker", "Marker", "MaxItems");
    var paginateListUserPolicies = core.createPaginator(IAMClient2, ListUserPoliciesCommand, "Marker", "Marker", "MaxItems");
    var paginateListUsers = core.createPaginator(IAMClient2, ListUsersCommand, "Marker", "Marker", "MaxItems");
    var paginateListUserTags = core.createPaginator(IAMClient2, ListUserTagsCommand, "Marker", "Marker", "MaxItems");
    var paginateListVirtualMFADevices = core.createPaginator(IAMClient2, ListVirtualMFADevicesCommand, "Marker", "Marker", "MaxItems");
    var paginateSimulateCustomPolicy = core.createPaginator(IAMClient2, SimulateCustomPolicyCommand, "Marker", "Marker", "MaxItems");
    var paginateSimulatePrincipalPolicy = core.createPaginator(IAMClient2, SimulatePrincipalPolicyCommand, "Marker", "Marker", "MaxItems");
    var checkState$3 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new GetInstanceProfileCommand(input));
        reason = result2;
        return { state: utilWaiter.WaiterState.SUCCESS, reason };
      } catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "NoSuchEntityException") {
          return { state: utilWaiter.WaiterState.RETRY, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$3");
    var waitForInstanceProfileExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 1, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$3);
    }, "waitForInstanceProfileExists");
    var waitUntilInstanceProfileExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 1, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$3);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilInstanceProfileExists");
    var checkState$2 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new GetPolicyCommand2(input));
        reason = result2;
        return { state: utilWaiter.WaiterState.SUCCESS, reason };
      } catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "NoSuchEntityException") {
          return { state: utilWaiter.WaiterState.RETRY, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$2");
    var waitForPolicyExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 1, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$2);
    }, "waitForPolicyExists");
    var waitUntilPolicyExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 1, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$2);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilPolicyExists");
    var checkState$1 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new GetRoleCommand2(input));
        reason = result2;
        return { state: utilWaiter.WaiterState.SUCCESS, reason };
      } catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "NoSuchEntityException") {
          return { state: utilWaiter.WaiterState.RETRY, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$1");
    var waitForRoleExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 1, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$1);
    }, "waitForRoleExists");
    var waitUntilRoleExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 1, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$1);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilRoleExists");
    var checkState = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new GetUserCommand(input));
        reason = result2;
        return { state: utilWaiter.WaiterState.SUCCESS, reason };
      } catch (exception) {
        reason = exception;
        if (exception.name && exception.name == "NoSuchEntityException") {
          return { state: utilWaiter.WaiterState.RETRY, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState");
    var waitForUserExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 1, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState);
    }, "waitForUserExists");
    var waitUntilUserExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 1, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilUserExists");
    var commands32 = {
      AcceptDelegationRequestCommand,
      AddClientIDToOpenIDConnectProviderCommand,
      AddRoleToInstanceProfileCommand,
      AddUserToGroupCommand,
      AssociateDelegationRequestCommand,
      AttachGroupPolicyCommand,
      AttachRolePolicyCommand,
      AttachUserPolicyCommand,
      ChangePasswordCommand,
      CreateAccessKeyCommand,
      CreateAccountAliasCommand,
      CreateDelegationRequestCommand,
      CreateGroupCommand,
      CreateInstanceProfileCommand,
      CreateLoginProfileCommand,
      CreateOpenIDConnectProviderCommand,
      CreatePolicyCommand: CreatePolicyCommand2,
      CreatePolicyVersionCommand,
      CreateRoleCommand,
      CreateSAMLProviderCommand,
      CreateServiceLinkedRoleCommand,
      CreateServiceSpecificCredentialCommand,
      CreateUserCommand,
      CreateVirtualMFADeviceCommand,
      DeactivateMFADeviceCommand,
      DeleteAccessKeyCommand,
      DeleteAccountAliasCommand,
      DeleteAccountPasswordPolicyCommand,
      DeleteGroupCommand,
      DeleteGroupPolicyCommand,
      DeleteInstanceProfileCommand,
      DeleteLoginProfileCommand,
      DeleteOpenIDConnectProviderCommand,
      DeletePolicyCommand,
      DeletePolicyVersionCommand,
      DeleteRoleCommand,
      DeleteRolePermissionsBoundaryCommand,
      DeleteRolePolicyCommand,
      DeleteSAMLProviderCommand,
      DeleteServerCertificateCommand,
      DeleteServiceLinkedRoleCommand,
      DeleteServiceSpecificCredentialCommand,
      DeleteSigningCertificateCommand,
      DeleteSSHPublicKeyCommand,
      DeleteUserCommand,
      DeleteUserPermissionsBoundaryCommand,
      DeleteUserPolicyCommand,
      DeleteVirtualMFADeviceCommand,
      DetachGroupPolicyCommand,
      DetachRolePolicyCommand,
      DetachUserPolicyCommand,
      DisableOrganizationsRootCredentialsManagementCommand,
      DisableOrganizationsRootSessionsCommand,
      DisableOutboundWebIdentityFederationCommand,
      EnableMFADeviceCommand,
      EnableOrganizationsRootCredentialsManagementCommand,
      EnableOrganizationsRootSessionsCommand,
      EnableOutboundWebIdentityFederationCommand,
      GenerateCredentialReportCommand,
      GenerateOrganizationsAccessReportCommand,
      GenerateServiceLastAccessedDetailsCommand,
      GetAccessKeyLastUsedCommand,
      GetAccountAuthorizationDetailsCommand,
      GetAccountPasswordPolicyCommand,
      GetAccountSummaryCommand,
      GetContextKeysForCustomPolicyCommand,
      GetContextKeysForPrincipalPolicyCommand,
      GetCredentialReportCommand,
      GetDelegationRequestCommand,
      GetGroupCommand,
      GetGroupPolicyCommand,
      GetHumanReadableSummaryCommand,
      GetInstanceProfileCommand,
      GetLoginProfileCommand,
      GetMFADeviceCommand,
      GetOpenIDConnectProviderCommand,
      GetOrganizationsAccessReportCommand,
      GetOutboundWebIdentityFederationInfoCommand,
      GetPolicyCommand: GetPolicyCommand2,
      GetPolicyVersionCommand,
      GetRoleCommand: GetRoleCommand2,
      GetRolePolicyCommand,
      GetSAMLProviderCommand,
      GetServerCertificateCommand,
      GetServiceLastAccessedDetailsCommand,
      GetServiceLastAccessedDetailsWithEntitiesCommand,
      GetServiceLinkedRoleDeletionStatusCommand,
      GetSSHPublicKeyCommand,
      GetUserCommand,
      GetUserPolicyCommand,
      ListAccessKeysCommand,
      ListAccountAliasesCommand,
      ListAttachedGroupPoliciesCommand,
      ListAttachedRolePoliciesCommand,
      ListAttachedUserPoliciesCommand,
      ListDelegationRequestsCommand,
      ListEntitiesForPolicyCommand,
      ListGroupPoliciesCommand,
      ListGroupsCommand,
      ListGroupsForUserCommand,
      ListInstanceProfilesCommand,
      ListInstanceProfilesForRoleCommand,
      ListInstanceProfileTagsCommand,
      ListMFADevicesCommand,
      ListMFADeviceTagsCommand,
      ListOpenIDConnectProvidersCommand,
      ListOpenIDConnectProviderTagsCommand,
      ListOrganizationsFeaturesCommand,
      ListPoliciesCommand,
      ListPoliciesGrantingServiceAccessCommand,
      ListPolicyTagsCommand,
      ListPolicyVersionsCommand,
      ListRolePoliciesCommand,
      ListRolesCommand,
      ListRoleTagsCommand,
      ListSAMLProvidersCommand,
      ListSAMLProviderTagsCommand,
      ListServerCertificatesCommand,
      ListServerCertificateTagsCommand,
      ListServiceSpecificCredentialsCommand,
      ListSigningCertificatesCommand,
      ListSSHPublicKeysCommand,
      ListUserPoliciesCommand,
      ListUsersCommand,
      ListUserTagsCommand,
      ListVirtualMFADevicesCommand,
      PutGroupPolicyCommand,
      PutRolePermissionsBoundaryCommand,
      PutRolePolicyCommand,
      PutUserPermissionsBoundaryCommand,
      PutUserPolicyCommand,
      RejectDelegationRequestCommand,
      RemoveClientIDFromOpenIDConnectProviderCommand,
      RemoveRoleFromInstanceProfileCommand,
      RemoveUserFromGroupCommand,
      ResetServiceSpecificCredentialCommand,
      ResyncMFADeviceCommand,
      SendDelegationTokenCommand,
      SetDefaultPolicyVersionCommand,
      SetSecurityTokenServicePreferencesCommand,
      SimulateCustomPolicyCommand,
      SimulatePrincipalPolicyCommand,
      TagInstanceProfileCommand,
      TagMFADeviceCommand,
      TagOpenIDConnectProviderCommand,
      TagPolicyCommand,
      TagRoleCommand,
      TagSAMLProviderCommand,
      TagServerCertificateCommand,
      TagUserCommand,
      UntagInstanceProfileCommand,
      UntagMFADeviceCommand,
      UntagOpenIDConnectProviderCommand,
      UntagPolicyCommand,
      UntagRoleCommand,
      UntagSAMLProviderCommand,
      UntagServerCertificateCommand,
      UntagUserCommand,
      UpdateAccessKeyCommand,
      UpdateAccountPasswordPolicyCommand,
      UpdateAssumeRolePolicyCommand,
      UpdateDelegationRequestCommand,
      UpdateGroupCommand,
      UpdateLoginProfileCommand,
      UpdateOpenIDConnectProviderThumbprintCommand,
      UpdateRoleCommand,
      UpdateRoleDescriptionCommand,
      UpdateSAMLProviderCommand,
      UpdateServerCertificateCommand,
      UpdateServiceSpecificCredentialCommand,
      UpdateSigningCertificateCommand,
      UpdateSSHPublicKeyCommand,
      UpdateUserCommand,
      UploadServerCertificateCommand,
      UploadSigningCertificateCommand,
      UploadSSHPublicKeyCommand
    };
    var paginators = {
      paginateGetAccountAuthorizationDetails,
      paginateGetGroup,
      paginateListAccessKeys,
      paginateListAccountAliases,
      paginateListAttachedGroupPolicies,
      paginateListAttachedRolePolicies,
      paginateListAttachedUserPolicies,
      paginateListEntitiesForPolicy,
      paginateListGroupPolicies,
      paginateListGroups,
      paginateListGroupsForUser,
      paginateListInstanceProfiles,
      paginateListInstanceProfilesForRole,
      paginateListInstanceProfileTags,
      paginateListMFADevices,
      paginateListMFADeviceTags,
      paginateListOpenIDConnectProviderTags,
      paginateListPolicies,
      paginateListPolicyTags,
      paginateListPolicyVersions,
      paginateListRolePolicies,
      paginateListRoles,
      paginateListRoleTags,
      paginateListSAMLProviderTags,
      paginateListServerCertificates,
      paginateListServerCertificateTags,
      paginateListSigningCertificates,
      paginateListSSHPublicKeys,
      paginateListUserPolicies,
      paginateListUsers,
      paginateListUserTags,
      paginateListVirtualMFADevices,
      paginateSimulateCustomPolicy,
      paginateSimulatePrincipalPolicy
    };
    var waiters = {
      waitUntilInstanceProfileExists,
      waitUntilPolicyExists,
      waitUntilRoleExists,
      waitUntilUserExists
    };
    var IAM = class extends IAMClient2 {
      static {
        __name(this, "IAM");
      }
    };
    smithyClient.createAggregatedClient(commands32, IAM, { paginators, waiters });
    var AccessAdvisorUsageGranularityType = {
      ACTION_LEVEL: "ACTION_LEVEL",
      SERVICE_LEVEL: "SERVICE_LEVEL"
    };
    var StatusType = {
      Active: "Active",
      Expired: "Expired",
      Inactive: "Inactive"
    };
    var AssertionEncryptionModeType = {
      Allowed: "Allowed",
      Required: "Required"
    };
    var AssignmentStatusType = {
      Any: "Any",
      Assigned: "Assigned",
      Unassigned: "Unassigned"
    };
    var PermissionsBoundaryAttachmentType = {
      Policy: "PermissionsBoundaryPolicy"
    };
    var PolicyParameterTypeEnum = {
      STRING: "string",
      STRING_LIST: "stringList"
    };
    var FeatureType = {
      ROOT_CREDENTIALS_MANAGEMENT: "RootCredentialsManagement",
      ROOT_SESSIONS: "RootSessions"
    };
    var ReportStateType = {
      COMPLETE: "COMPLETE",
      INPROGRESS: "INPROGRESS",
      STARTED: "STARTED"
    };
    var EntityType = {
      AWSManagedPolicy: "AWSManagedPolicy",
      Group: "Group",
      LocalManagedPolicy: "LocalManagedPolicy",
      Role: "Role",
      User: "User"
    };
    var SummaryKeyType = {
      AccessKeysPerUserQuota: "AccessKeysPerUserQuota",
      AccountAccessKeysPresent: "AccountAccessKeysPresent",
      AccountMFAEnabled: "AccountMFAEnabled",
      AccountPasswordPresent: "AccountPasswordPresent",
      AccountSigningCertificatesPresent: "AccountSigningCertificatesPresent",
      AssumeRolePolicySizeQuota: "AssumeRolePolicySizeQuota",
      AttachedPoliciesPerGroupQuota: "AttachedPoliciesPerGroupQuota",
      AttachedPoliciesPerRoleQuota: "AttachedPoliciesPerRoleQuota",
      AttachedPoliciesPerUserQuota: "AttachedPoliciesPerUserQuota",
      GlobalEndpointTokenVersion: "GlobalEndpointTokenVersion",
      GroupPolicySizeQuota: "GroupPolicySizeQuota",
      Groups: "Groups",
      GroupsPerUserQuota: "GroupsPerUserQuota",
      GroupsQuota: "GroupsQuota",
      InstanceProfiles: "InstanceProfiles",
      InstanceProfilesQuota: "InstanceProfilesQuota",
      MFADevices: "MFADevices",
      MFADevicesInUse: "MFADevicesInUse",
      Policies: "Policies",
      PoliciesQuota: "PoliciesQuota",
      PolicySizeQuota: "PolicySizeQuota",
      PolicyVersionsInUse: "PolicyVersionsInUse",
      PolicyVersionsInUseQuota: "PolicyVersionsInUseQuota",
      Providers: "Providers",
      RolePolicySizeQuota: "RolePolicySizeQuota",
      Roles: "Roles",
      RolesQuota: "RolesQuota",
      ServerCertificates: "ServerCertificates",
      ServerCertificatesQuota: "ServerCertificatesQuota",
      SigningCertificatesPerUserQuota: "SigningCertificatesPerUserQuota",
      UserPolicySizeQuota: "UserPolicySizeQuota",
      Users: "Users",
      UsersQuota: "UsersQuota",
      VersionsPerPolicyQuota: "VersionsPerPolicyQuota"
    };
    var ReportFormatType = {
      text_csv: "text/csv"
    };
    var StateType = {
      ACCEPTED: "ACCEPTED",
      ASSIGNED: "ASSIGNED",
      EXPIRED: "EXPIRED",
      FINALIZED: "FINALIZED",
      PENDING_APPROVAL: "PENDING_APPROVAL",
      REJECTED: "REJECTED",
      UNASSIGNED: "UNASSIGNED"
    };
    var PermissionCheckResultType = {
      ALLOWED: "ALLOWED",
      DENIED: "DENIED",
      UNSURE: "UNSURE"
    };
    var PermissionCheckStatusType = {
      COMPLETE: "COMPLETE",
      FAILED: "FAILED",
      IN_PROGRESS: "IN_PROGRESS"
    };
    var SummaryStateType = {
      AVAILABLE: "AVAILABLE",
      FAILED: "FAILED",
      NOT_AVAILABLE: "NOT_AVAILABLE",
      NOT_SUPPORTED: "NOT_SUPPORTED"
    };
    var SortKeyType = {
      LAST_AUTHENTICATED_TIME_ASCENDING: "LAST_AUTHENTICATED_TIME_ASCENDING",
      LAST_AUTHENTICATED_TIME_DESCENDING: "LAST_AUTHENTICATED_TIME_DESCENDING",
      SERVICE_NAMESPACE_ASCENDING: "SERVICE_NAMESPACE_ASCENDING",
      SERVICE_NAMESPACE_DESCENDING: "SERVICE_NAMESPACE_DESCENDING"
    };
    var JobStatusType = {
      COMPLETED: "COMPLETED",
      FAILED: "FAILED",
      IN_PROGRESS: "IN_PROGRESS"
    };
    var PolicyOwnerEntityType = {
      GROUP: "GROUP",
      ROLE: "ROLE",
      USER: "USER"
    };
    var DeletionTaskStatusType = {
      FAILED: "FAILED",
      IN_PROGRESS: "IN_PROGRESS",
      NOT_STARTED: "NOT_STARTED",
      SUCCEEDED: "SUCCEEDED"
    };
    var EncodingType = {
      PEM: "PEM",
      SSH: "SSH"
    };
    var PolicyUsageType = {
      PermissionsBoundary: "PermissionsBoundary",
      PermissionsPolicy: "PermissionsPolicy"
    };
    var PolicyScopeType = {
      AWS: "AWS",
      All: "All",
      Local: "Local"
    };
    var PolicyType = {
      INLINE: "INLINE",
      MANAGED: "MANAGED"
    };
    var GlobalEndpointTokenVersion = {
      v1Token: "v1Token",
      v2Token: "v2Token"
    };
    var ContextKeyTypeEnum = {
      BINARY: "binary",
      BINARY_LIST: "binaryList",
      BOOLEAN: "boolean",
      BOOLEAN_LIST: "booleanList",
      DATE: "date",
      DATE_LIST: "dateList",
      IP: "ip",
      IP_LIST: "ipList",
      NUMERIC: "numeric",
      NUMERIC_LIST: "numericList",
      STRING: "string",
      STRING_LIST: "stringList"
    };
    var PolicyEvaluationDecisionType = {
      ALLOWED: "allowed",
      EXPLICIT_DENY: "explicitDeny",
      IMPLICIT_DENY: "implicitDeny"
    };
    var PolicySourceType = {
      AWS_MANAGED: "aws-managed",
      GROUP: "group",
      NONE: "none",
      RESOURCE: "resource",
      ROLE: "role",
      USER: "user",
      USER_MANAGED: "user-managed"
    };
    exports2.$Command = smithyClient.Command;
    exports2.__Client = smithyClient.Client;
    exports2.IAMServiceException = IAMServiceException.IAMServiceException;
    exports2.AcceptDelegationRequestCommand = AcceptDelegationRequestCommand;
    exports2.AccessAdvisorUsageGranularityType = AccessAdvisorUsageGranularityType;
    exports2.AddClientIDToOpenIDConnectProviderCommand = AddClientIDToOpenIDConnectProviderCommand;
    exports2.AddRoleToInstanceProfileCommand = AddRoleToInstanceProfileCommand;
    exports2.AddUserToGroupCommand = AddUserToGroupCommand;
    exports2.AssertionEncryptionModeType = AssertionEncryptionModeType;
    exports2.AssignmentStatusType = AssignmentStatusType;
    exports2.AssociateDelegationRequestCommand = AssociateDelegationRequestCommand;
    exports2.AttachGroupPolicyCommand = AttachGroupPolicyCommand;
    exports2.AttachRolePolicyCommand = AttachRolePolicyCommand;
    exports2.AttachUserPolicyCommand = AttachUserPolicyCommand;
    exports2.ChangePasswordCommand = ChangePasswordCommand;
    exports2.ContextKeyTypeEnum = ContextKeyTypeEnum;
    exports2.CreateAccessKeyCommand = CreateAccessKeyCommand;
    exports2.CreateAccountAliasCommand = CreateAccountAliasCommand;
    exports2.CreateDelegationRequestCommand = CreateDelegationRequestCommand;
    exports2.CreateGroupCommand = CreateGroupCommand;
    exports2.CreateInstanceProfileCommand = CreateInstanceProfileCommand;
    exports2.CreateLoginProfileCommand = CreateLoginProfileCommand;
    exports2.CreateOpenIDConnectProviderCommand = CreateOpenIDConnectProviderCommand;
    exports2.CreatePolicyCommand = CreatePolicyCommand2;
    exports2.CreatePolicyVersionCommand = CreatePolicyVersionCommand;
    exports2.CreateRoleCommand = CreateRoleCommand;
    exports2.CreateSAMLProviderCommand = CreateSAMLProviderCommand;
    exports2.CreateServiceLinkedRoleCommand = CreateServiceLinkedRoleCommand;
    exports2.CreateServiceSpecificCredentialCommand = CreateServiceSpecificCredentialCommand;
    exports2.CreateUserCommand = CreateUserCommand;
    exports2.CreateVirtualMFADeviceCommand = CreateVirtualMFADeviceCommand;
    exports2.DeactivateMFADeviceCommand = DeactivateMFADeviceCommand;
    exports2.DeleteAccessKeyCommand = DeleteAccessKeyCommand;
    exports2.DeleteAccountAliasCommand = DeleteAccountAliasCommand;
    exports2.DeleteAccountPasswordPolicyCommand = DeleteAccountPasswordPolicyCommand;
    exports2.DeleteGroupCommand = DeleteGroupCommand;
    exports2.DeleteGroupPolicyCommand = DeleteGroupPolicyCommand;
    exports2.DeleteInstanceProfileCommand = DeleteInstanceProfileCommand;
    exports2.DeleteLoginProfileCommand = DeleteLoginProfileCommand;
    exports2.DeleteOpenIDConnectProviderCommand = DeleteOpenIDConnectProviderCommand;
    exports2.DeletePolicyCommand = DeletePolicyCommand;
    exports2.DeletePolicyVersionCommand = DeletePolicyVersionCommand;
    exports2.DeleteRoleCommand = DeleteRoleCommand;
    exports2.DeleteRolePermissionsBoundaryCommand = DeleteRolePermissionsBoundaryCommand;
    exports2.DeleteRolePolicyCommand = DeleteRolePolicyCommand;
    exports2.DeleteSAMLProviderCommand = DeleteSAMLProviderCommand;
    exports2.DeleteSSHPublicKeyCommand = DeleteSSHPublicKeyCommand;
    exports2.DeleteServerCertificateCommand = DeleteServerCertificateCommand;
    exports2.DeleteServiceLinkedRoleCommand = DeleteServiceLinkedRoleCommand;
    exports2.DeleteServiceSpecificCredentialCommand = DeleteServiceSpecificCredentialCommand;
    exports2.DeleteSigningCertificateCommand = DeleteSigningCertificateCommand;
    exports2.DeleteUserCommand = DeleteUserCommand;
    exports2.DeleteUserPermissionsBoundaryCommand = DeleteUserPermissionsBoundaryCommand;
    exports2.DeleteUserPolicyCommand = DeleteUserPolicyCommand;
    exports2.DeleteVirtualMFADeviceCommand = DeleteVirtualMFADeviceCommand;
    exports2.DeletionTaskStatusType = DeletionTaskStatusType;
    exports2.DetachGroupPolicyCommand = DetachGroupPolicyCommand;
    exports2.DetachRolePolicyCommand = DetachRolePolicyCommand;
    exports2.DetachUserPolicyCommand = DetachUserPolicyCommand;
    exports2.DisableOrganizationsRootCredentialsManagementCommand = DisableOrganizationsRootCredentialsManagementCommand;
    exports2.DisableOrganizationsRootSessionsCommand = DisableOrganizationsRootSessionsCommand;
    exports2.DisableOutboundWebIdentityFederationCommand = DisableOutboundWebIdentityFederationCommand;
    exports2.EnableMFADeviceCommand = EnableMFADeviceCommand;
    exports2.EnableOrganizationsRootCredentialsManagementCommand = EnableOrganizationsRootCredentialsManagementCommand;
    exports2.EnableOrganizationsRootSessionsCommand = EnableOrganizationsRootSessionsCommand;
    exports2.EnableOutboundWebIdentityFederationCommand = EnableOutboundWebIdentityFederationCommand;
    exports2.EncodingType = EncodingType;
    exports2.EntityType = EntityType;
    exports2.FeatureType = FeatureType;
    exports2.GenerateCredentialReportCommand = GenerateCredentialReportCommand;
    exports2.GenerateOrganizationsAccessReportCommand = GenerateOrganizationsAccessReportCommand;
    exports2.GenerateServiceLastAccessedDetailsCommand = GenerateServiceLastAccessedDetailsCommand;
    exports2.GetAccessKeyLastUsedCommand = GetAccessKeyLastUsedCommand;
    exports2.GetAccountAuthorizationDetailsCommand = GetAccountAuthorizationDetailsCommand;
    exports2.GetAccountPasswordPolicyCommand = GetAccountPasswordPolicyCommand;
    exports2.GetAccountSummaryCommand = GetAccountSummaryCommand;
    exports2.GetContextKeysForCustomPolicyCommand = GetContextKeysForCustomPolicyCommand;
    exports2.GetContextKeysForPrincipalPolicyCommand = GetContextKeysForPrincipalPolicyCommand;
    exports2.GetCredentialReportCommand = GetCredentialReportCommand;
    exports2.GetDelegationRequestCommand = GetDelegationRequestCommand;
    exports2.GetGroupCommand = GetGroupCommand;
    exports2.GetGroupPolicyCommand = GetGroupPolicyCommand;
    exports2.GetHumanReadableSummaryCommand = GetHumanReadableSummaryCommand;
    exports2.GetInstanceProfileCommand = GetInstanceProfileCommand;
    exports2.GetLoginProfileCommand = GetLoginProfileCommand;
    exports2.GetMFADeviceCommand = GetMFADeviceCommand;
    exports2.GetOpenIDConnectProviderCommand = GetOpenIDConnectProviderCommand;
    exports2.GetOrganizationsAccessReportCommand = GetOrganizationsAccessReportCommand;
    exports2.GetOutboundWebIdentityFederationInfoCommand = GetOutboundWebIdentityFederationInfoCommand;
    exports2.GetPolicyCommand = GetPolicyCommand2;
    exports2.GetPolicyVersionCommand = GetPolicyVersionCommand;
    exports2.GetRoleCommand = GetRoleCommand2;
    exports2.GetRolePolicyCommand = GetRolePolicyCommand;
    exports2.GetSAMLProviderCommand = GetSAMLProviderCommand;
    exports2.GetSSHPublicKeyCommand = GetSSHPublicKeyCommand;
    exports2.GetServerCertificateCommand = GetServerCertificateCommand;
    exports2.GetServiceLastAccessedDetailsCommand = GetServiceLastAccessedDetailsCommand;
    exports2.GetServiceLastAccessedDetailsWithEntitiesCommand = GetServiceLastAccessedDetailsWithEntitiesCommand;
    exports2.GetServiceLinkedRoleDeletionStatusCommand = GetServiceLinkedRoleDeletionStatusCommand;
    exports2.GetUserCommand = GetUserCommand;
    exports2.GetUserPolicyCommand = GetUserPolicyCommand;
    exports2.GlobalEndpointTokenVersion = GlobalEndpointTokenVersion;
    exports2.IAM = IAM;
    exports2.IAMClient = IAMClient2;
    exports2.JobStatusType = JobStatusType;
    exports2.ListAccessKeysCommand = ListAccessKeysCommand;
    exports2.ListAccountAliasesCommand = ListAccountAliasesCommand;
    exports2.ListAttachedGroupPoliciesCommand = ListAttachedGroupPoliciesCommand;
    exports2.ListAttachedRolePoliciesCommand = ListAttachedRolePoliciesCommand;
    exports2.ListAttachedUserPoliciesCommand = ListAttachedUserPoliciesCommand;
    exports2.ListDelegationRequestsCommand = ListDelegationRequestsCommand;
    exports2.ListEntitiesForPolicyCommand = ListEntitiesForPolicyCommand;
    exports2.ListGroupPoliciesCommand = ListGroupPoliciesCommand;
    exports2.ListGroupsCommand = ListGroupsCommand;
    exports2.ListGroupsForUserCommand = ListGroupsForUserCommand;
    exports2.ListInstanceProfileTagsCommand = ListInstanceProfileTagsCommand;
    exports2.ListInstanceProfilesCommand = ListInstanceProfilesCommand;
    exports2.ListInstanceProfilesForRoleCommand = ListInstanceProfilesForRoleCommand;
    exports2.ListMFADeviceTagsCommand = ListMFADeviceTagsCommand;
    exports2.ListMFADevicesCommand = ListMFADevicesCommand;
    exports2.ListOpenIDConnectProviderTagsCommand = ListOpenIDConnectProviderTagsCommand;
    exports2.ListOpenIDConnectProvidersCommand = ListOpenIDConnectProvidersCommand;
    exports2.ListOrganizationsFeaturesCommand = ListOrganizationsFeaturesCommand;
    exports2.ListPoliciesCommand = ListPoliciesCommand;
    exports2.ListPoliciesGrantingServiceAccessCommand = ListPoliciesGrantingServiceAccessCommand;
    exports2.ListPolicyTagsCommand = ListPolicyTagsCommand;
    exports2.ListPolicyVersionsCommand = ListPolicyVersionsCommand;
    exports2.ListRolePoliciesCommand = ListRolePoliciesCommand;
    exports2.ListRoleTagsCommand = ListRoleTagsCommand;
    exports2.ListRolesCommand = ListRolesCommand;
    exports2.ListSAMLProviderTagsCommand = ListSAMLProviderTagsCommand;
    exports2.ListSAMLProvidersCommand = ListSAMLProvidersCommand;
    exports2.ListSSHPublicKeysCommand = ListSSHPublicKeysCommand;
    exports2.ListServerCertificateTagsCommand = ListServerCertificateTagsCommand;
    exports2.ListServerCertificatesCommand = ListServerCertificatesCommand;
    exports2.ListServiceSpecificCredentialsCommand = ListServiceSpecificCredentialsCommand;
    exports2.ListSigningCertificatesCommand = ListSigningCertificatesCommand;
    exports2.ListUserPoliciesCommand = ListUserPoliciesCommand;
    exports2.ListUserTagsCommand = ListUserTagsCommand;
    exports2.ListUsersCommand = ListUsersCommand;
    exports2.ListVirtualMFADevicesCommand = ListVirtualMFADevicesCommand;
    exports2.PermissionCheckResultType = PermissionCheckResultType;
    exports2.PermissionCheckStatusType = PermissionCheckStatusType;
    exports2.PermissionsBoundaryAttachmentType = PermissionsBoundaryAttachmentType;
    exports2.PolicyEvaluationDecisionType = PolicyEvaluationDecisionType;
    exports2.PolicyOwnerEntityType = PolicyOwnerEntityType;
    exports2.PolicyParameterTypeEnum = PolicyParameterTypeEnum;
    exports2.PolicyScopeType = PolicyScopeType;
    exports2.PolicySourceType = PolicySourceType;
    exports2.PolicyType = PolicyType;
    exports2.PolicyUsageType = PolicyUsageType;
    exports2.PutGroupPolicyCommand = PutGroupPolicyCommand;
    exports2.PutRolePermissionsBoundaryCommand = PutRolePermissionsBoundaryCommand;
    exports2.PutRolePolicyCommand = PutRolePolicyCommand;
    exports2.PutUserPermissionsBoundaryCommand = PutUserPermissionsBoundaryCommand;
    exports2.PutUserPolicyCommand = PutUserPolicyCommand;
    exports2.RejectDelegationRequestCommand = RejectDelegationRequestCommand;
    exports2.RemoveClientIDFromOpenIDConnectProviderCommand = RemoveClientIDFromOpenIDConnectProviderCommand;
    exports2.RemoveRoleFromInstanceProfileCommand = RemoveRoleFromInstanceProfileCommand;
    exports2.RemoveUserFromGroupCommand = RemoveUserFromGroupCommand;
    exports2.ReportFormatType = ReportFormatType;
    exports2.ReportStateType = ReportStateType;
    exports2.ResetServiceSpecificCredentialCommand = ResetServiceSpecificCredentialCommand;
    exports2.ResyncMFADeviceCommand = ResyncMFADeviceCommand;
    exports2.SendDelegationTokenCommand = SendDelegationTokenCommand;
    exports2.SetDefaultPolicyVersionCommand = SetDefaultPolicyVersionCommand;
    exports2.SetSecurityTokenServicePreferencesCommand = SetSecurityTokenServicePreferencesCommand;
    exports2.SimulateCustomPolicyCommand = SimulateCustomPolicyCommand;
    exports2.SimulatePrincipalPolicyCommand = SimulatePrincipalPolicyCommand;
    exports2.SortKeyType = SortKeyType;
    exports2.StateType = StateType;
    exports2.StatusType = StatusType;
    exports2.SummaryKeyType = SummaryKeyType;
    exports2.SummaryStateType = SummaryStateType;
    exports2.TagInstanceProfileCommand = TagInstanceProfileCommand;
    exports2.TagMFADeviceCommand = TagMFADeviceCommand;
    exports2.TagOpenIDConnectProviderCommand = TagOpenIDConnectProviderCommand;
    exports2.TagPolicyCommand = TagPolicyCommand;
    exports2.TagRoleCommand = TagRoleCommand;
    exports2.TagSAMLProviderCommand = TagSAMLProviderCommand;
    exports2.TagServerCertificateCommand = TagServerCertificateCommand;
    exports2.TagUserCommand = TagUserCommand;
    exports2.UntagInstanceProfileCommand = UntagInstanceProfileCommand;
    exports2.UntagMFADeviceCommand = UntagMFADeviceCommand;
    exports2.UntagOpenIDConnectProviderCommand = UntagOpenIDConnectProviderCommand;
    exports2.UntagPolicyCommand = UntagPolicyCommand;
    exports2.UntagRoleCommand = UntagRoleCommand;
    exports2.UntagSAMLProviderCommand = UntagSAMLProviderCommand;
    exports2.UntagServerCertificateCommand = UntagServerCertificateCommand;
    exports2.UntagUserCommand = UntagUserCommand;
    exports2.UpdateAccessKeyCommand = UpdateAccessKeyCommand;
    exports2.UpdateAccountPasswordPolicyCommand = UpdateAccountPasswordPolicyCommand;
    exports2.UpdateAssumeRolePolicyCommand = UpdateAssumeRolePolicyCommand;
    exports2.UpdateDelegationRequestCommand = UpdateDelegationRequestCommand;
    exports2.UpdateGroupCommand = UpdateGroupCommand;
    exports2.UpdateLoginProfileCommand = UpdateLoginProfileCommand;
    exports2.UpdateOpenIDConnectProviderThumbprintCommand = UpdateOpenIDConnectProviderThumbprintCommand;
    exports2.UpdateRoleCommand = UpdateRoleCommand;
    exports2.UpdateRoleDescriptionCommand = UpdateRoleDescriptionCommand;
    exports2.UpdateSAMLProviderCommand = UpdateSAMLProviderCommand;
    exports2.UpdateSSHPublicKeyCommand = UpdateSSHPublicKeyCommand;
    exports2.UpdateServerCertificateCommand = UpdateServerCertificateCommand;
    exports2.UpdateServiceSpecificCredentialCommand = UpdateServiceSpecificCredentialCommand;
    exports2.UpdateSigningCertificateCommand = UpdateSigningCertificateCommand;
    exports2.UpdateUserCommand = UpdateUserCommand;
    exports2.UploadSSHPublicKeyCommand = UploadSSHPublicKeyCommand;
    exports2.UploadServerCertificateCommand = UploadServerCertificateCommand;
    exports2.UploadSigningCertificateCommand = UploadSigningCertificateCommand;
    exports2.paginateGetAccountAuthorizationDetails = paginateGetAccountAuthorizationDetails;
    exports2.paginateGetGroup = paginateGetGroup;
    exports2.paginateListAccessKeys = paginateListAccessKeys;
    exports2.paginateListAccountAliases = paginateListAccountAliases;
    exports2.paginateListAttachedGroupPolicies = paginateListAttachedGroupPolicies;
    exports2.paginateListAttachedRolePolicies = paginateListAttachedRolePolicies;
    exports2.paginateListAttachedUserPolicies = paginateListAttachedUserPolicies;
    exports2.paginateListEntitiesForPolicy = paginateListEntitiesForPolicy;
    exports2.paginateListGroupPolicies = paginateListGroupPolicies;
    exports2.paginateListGroups = paginateListGroups;
    exports2.paginateListGroupsForUser = paginateListGroupsForUser;
    exports2.paginateListInstanceProfileTags = paginateListInstanceProfileTags;
    exports2.paginateListInstanceProfiles = paginateListInstanceProfiles;
    exports2.paginateListInstanceProfilesForRole = paginateListInstanceProfilesForRole;
    exports2.paginateListMFADeviceTags = paginateListMFADeviceTags;
    exports2.paginateListMFADevices = paginateListMFADevices;
    exports2.paginateListOpenIDConnectProviderTags = paginateListOpenIDConnectProviderTags;
    exports2.paginateListPolicies = paginateListPolicies;
    exports2.paginateListPolicyTags = paginateListPolicyTags;
    exports2.paginateListPolicyVersions = paginateListPolicyVersions;
    exports2.paginateListRolePolicies = paginateListRolePolicies;
    exports2.paginateListRoleTags = paginateListRoleTags;
    exports2.paginateListRoles = paginateListRoles;
    exports2.paginateListSAMLProviderTags = paginateListSAMLProviderTags;
    exports2.paginateListSSHPublicKeys = paginateListSSHPublicKeys;
    exports2.paginateListServerCertificateTags = paginateListServerCertificateTags;
    exports2.paginateListServerCertificates = paginateListServerCertificates;
    exports2.paginateListSigningCertificates = paginateListSigningCertificates;
    exports2.paginateListUserPolicies = paginateListUserPolicies;
    exports2.paginateListUserTags = paginateListUserTags;
    exports2.paginateListUsers = paginateListUsers;
    exports2.paginateListVirtualMFADevices = paginateListVirtualMFADevices;
    exports2.paginateSimulateCustomPolicy = paginateSimulateCustomPolicy;
    exports2.paginateSimulatePrincipalPolicy = paginateSimulatePrincipalPolicy;
    exports2.waitForInstanceProfileExists = waitForInstanceProfileExists;
    exports2.waitForPolicyExists = waitForPolicyExists;
    exports2.waitForRoleExists = waitForRoleExists;
    exports2.waitForUserExists = waitForUserExists;
    exports2.waitUntilInstanceProfileExists = waitUntilInstanceProfileExists;
    exports2.waitUntilPolicyExists = waitUntilPolicyExists;
    exports2.waitUntilRoleExists = waitUntilRoleExists;
    exports2.waitUntilUserExists = waitUntilUserExists;
    Object.prototype.hasOwnProperty.call(schemas_0, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: schemas_0["__proto__"]
    });
    Object.keys(schemas_0).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = schemas_0[k32];
    });
    Object.prototype.hasOwnProperty.call(errors, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: errors["__proto__"]
    });
    Object.keys(errors).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = errors[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/client/emitWarningIfUnsupportedVersion.js
var state10, emitWarningIfUnsupportedVersion30;
var init_emitWarningIfUnsupportedVersion12 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/client/emitWarningIfUnsupportedVersion.js"() {
    state10 = {
      warningEmitted: false
    };
    emitWarningIfUnsupportedVersion30 = /* @__PURE__ */ __name((version) => {
      if (version && !state10.warningEmitted) {
        if (process.env.AWS_SDK_JS_NODE_VERSION_SUPPORT_WARNING_DISABLED === "true") {
          state10.warningEmitted = true;
          return;
        }
        const userMajorVersion = parseInt(version.substring(1, version.indexOf(".")));
        const vv = 22;
        if (userMajorVersion < vv) {
          state10.warningEmitted = true;
          process.emitWarning(`NodeVersionSupportWarning: The AWS SDK for JavaScript (v3)
versions published after the first week of January 2027
will require node >=${vv}. You are running node ${version}.

To continue receiving updates to AWS services, bug fixes,
and security updates please upgrade to node >=${vv}.

More information can be found at: https://a.co/c895JFp`);
        }
      }
    }, "emitWarningIfUnsupportedVersion");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/client/longPollMiddleware.js
var longPollMiddleware10, longPollMiddlewareOptions10, getLongPollPlugin10;
var init_longPollMiddleware10 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/client/longPollMiddleware.js"() {
    longPollMiddleware10 = /* @__PURE__ */ __name(() => (next, context) => async (args) => {
      context.__retryLongPoll = true;
      return next(args);
    }, "longPollMiddleware");
    longPollMiddlewareOptions10 = {
      name: "longPollMiddleware",
      tags: ["RETRY"],
      step: "initialize",
      override: true
    };
    getLongPollPlugin10 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(longPollMiddleware10(), longPollMiddlewareOptions10);
      }, "applyToStack")
    }), "getLongPollPlugin");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/client/setCredentialFeature.js
function setCredentialFeature10(credentials, feature, value) {
  if (!credentials.$source) {
    credentials.$source = {};
  }
  credentials.$source[feature] = value;
  return credentials;
}
var init_setCredentialFeature10 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/client/setCredentialFeature.js"() {
    __name(setCredentialFeature10, "setCredentialFeature");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/client/setFeature.js
function setFeature16(context, feature, value) {
  if (!context.__aws_sdk_context) {
    context.__aws_sdk_context = {
      features: {}
    };
  } else if (!context.__aws_sdk_context.features) {
    context.__aws_sdk_context.features = {};
  }
  context.__aws_sdk_context.features[feature] = value;
}
var import_util_retry27;
var init_setFeature12 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/client/setFeature.js"() {
    import_util_retry27 = __toESM(require_dist_cjs22());
    import_util_retry27.Retry.v2026 ||= typeof process === "object" && process.env?.AWS_NEW_RETRIES_2026 === "true";
    __name(setFeature16, "setFeature");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/client/setTokenFeature.js
function setTokenFeature10(token, feature, value) {
  if (!token.$source) {
    token.$source = {};
  }
  token.$source[feature] = value;
  return token;
}
var init_setTokenFeature10 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/client/setTokenFeature.js"() {
    __name(setTokenFeature10, "setTokenFeature");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/client/index.js
var client_exports12 = {};
__export(client_exports12, {
  emitWarningIfUnsupportedVersion: () => emitWarningIfUnsupportedVersion30,
  getLongPollPlugin: () => getLongPollPlugin10,
  setCredentialFeature: () => setCredentialFeature10,
  setFeature: () => setFeature16,
  setTokenFeature: () => setTokenFeature10,
  state: () => state10
});
var init_client17 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/client/index.js"() {
    init_emitWarningIfUnsupportedVersion12();
    init_longPollMiddleware10();
    init_setCredentialFeature10();
    init_setFeature12();
    init_setTokenFeature10();
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/middleware-user-agent/dist-cjs/index.js
var require_dist_cjs167 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/middleware-user-agent/dist-cjs/index.js"(exports2) {
    "use strict";
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var utilEndpoints = require_dist_cjs21();
    var protocolHttp = require_dist_cjs2();
    var client = (init_client17(), __toCommonJS(client_exports12));
    var utilRetry = require_dist_cjs22();
    var DEFAULT_UA_APP_ID2 = void 0;
    function isValidUserAgentAppId2(appId) {
      if (appId === void 0) {
        return true;
      }
      return typeof appId === "string" && appId.length <= 50;
    }
    __name(isValidUserAgentAppId2, "isValidUserAgentAppId");
    function resolveUserAgentConfig29(input) {
      const normalizedAppIdProvider = core.normalizeProvider(input.userAgentAppId ?? DEFAULT_UA_APP_ID2);
      const { customUserAgent } = input;
      return Object.assign(input, {
        customUserAgent: typeof customUserAgent === "string" ? [[customUserAgent]] : customUserAgent,
        userAgentAppId: /* @__PURE__ */ __name(async () => {
          const appId = await normalizedAppIdProvider();
          if (!isValidUserAgentAppId2(appId)) {
            const logger5 = input.logger?.constructor?.name === "NoOpLogger" || !input.logger ? console : input.logger;
            if (typeof appId !== "string") {
              logger5?.warn("userAgentAppId must be a string or undefined.");
            } else if (appId.length > 50) {
              logger5?.warn("The provided userAgentAppId exceeds the maximum length of 50 characters.");
            }
          }
          return appId;
        }, "userAgentAppId")
      });
    }
    __name(resolveUserAgentConfig29, "resolveUserAgentConfig");
    var ACCOUNT_ID_ENDPOINT_REGEX2 = /\d{12}\.ddb/;
    async function checkFeatures2(context, config2, args) {
      const request4 = args.request;
      if (request4?.headers?.["smithy-protocol"] === "rpc-v2-cbor") {
        client.setFeature(context, "PROTOCOL_RPC_V2_CBOR", "M");
      }
      if (typeof config2.retryStrategy === "function") {
        const retryStrategy = await config2.retryStrategy();
        if (typeof retryStrategy.mode === "string") {
          switch (retryStrategy.mode) {
            case utilRetry.RETRY_MODES.ADAPTIVE:
              client.setFeature(context, "RETRY_MODE_ADAPTIVE", "F");
              break;
            case utilRetry.RETRY_MODES.STANDARD:
              client.setFeature(context, "RETRY_MODE_STANDARD", "E");
              break;
          }
        }
      }
      if (typeof config2.accountIdEndpointMode === "function") {
        const endpointV2 = context.endpointV2;
        if (String(endpointV2?.url?.hostname).match(ACCOUNT_ID_ENDPOINT_REGEX2)) {
          client.setFeature(context, "ACCOUNT_ID_ENDPOINT", "O");
        }
        switch (await config2.accountIdEndpointMode?.()) {
          case "disabled":
            client.setFeature(context, "ACCOUNT_ID_MODE_DISABLED", "Q");
            break;
          case "preferred":
            client.setFeature(context, "ACCOUNT_ID_MODE_PREFERRED", "P");
            break;
          case "required":
            client.setFeature(context, "ACCOUNT_ID_MODE_REQUIRED", "R");
            break;
        }
      }
      const identity = context.__smithy_context?.selectedHttpAuthScheme?.identity;
      if (identity?.$source) {
        const credentials = identity;
        if (credentials.accountId) {
          client.setFeature(context, "RESOLVED_ACCOUNT_ID", "T");
        }
        for (const [key, value] of Object.entries(credentials.$source ?? {})) {
          client.setFeature(context, key, value);
        }
      }
    }
    __name(checkFeatures2, "checkFeatures");
    var USER_AGENT3 = "user-agent";
    var X_AMZ_USER_AGENT2 = "x-amz-user-agent";
    var SPACE2 = " ";
    var UA_NAME_SEPARATOR2 = "/";
    var UA_NAME_ESCAPE_REGEX2 = /[^!$%&'*+\-.^_`|~\w]/g;
    var UA_VALUE_ESCAPE_REGEX2 = /[^!$%&'*+\-.^_`|~\w#]/g;
    var UA_ESCAPE_CHAR2 = "-";
    var BYTE_LIMIT2 = 1024;
    function encodeFeatures2(features) {
      let buffer = "";
      for (const key in features) {
        const val = features[key];
        if (buffer.length + val.length + 1 <= BYTE_LIMIT2) {
          if (buffer.length) {
            buffer += "," + val;
          } else {
            buffer += val;
          }
          continue;
        }
        break;
      }
      return buffer;
    }
    __name(encodeFeatures2, "encodeFeatures");
    var userAgentMiddleware2 = /* @__PURE__ */ __name((options) => (next, context) => async (args) => {
      const { request: request4 } = args;
      if (!protocolHttp.HttpRequest.isInstance(request4)) {
        return next(args);
      }
      const { headers } = request4;
      const userAgent = context?.userAgent?.map(escapeUserAgent2) || [];
      const defaultUserAgent2 = (await options.defaultUserAgentProvider()).map(escapeUserAgent2);
      await checkFeatures2(context, options, args);
      const awsContext = context;
      defaultUserAgent2.push(`m/${encodeFeatures2(Object.assign({}, context.__smithy_context?.features, awsContext.__aws_sdk_context?.features))}`);
      const customUserAgent = options?.customUserAgent?.map(escapeUserAgent2) || [];
      const appId = await options.userAgentAppId();
      if (appId) {
        defaultUserAgent2.push(escapeUserAgent2([`app`, `${appId}`]));
      }
      const prefix = utilEndpoints.getUserAgentPrefix();
      const sdkUserAgentValue = (prefix ? [prefix] : []).concat([...defaultUserAgent2, ...userAgent, ...customUserAgent]).join(SPACE2);
      const normalUAValue = [
        ...defaultUserAgent2.filter((section) => section.startsWith("aws-sdk-")),
        ...customUserAgent
      ].join(SPACE2);
      if (options.runtime !== "browser") {
        if (normalUAValue) {
          headers[X_AMZ_USER_AGENT2] = headers[X_AMZ_USER_AGENT2] ? `${headers[USER_AGENT3]} ${normalUAValue}` : normalUAValue;
        }
        headers[USER_AGENT3] = sdkUserAgentValue;
      } else {
        headers[X_AMZ_USER_AGENT2] = sdkUserAgentValue;
      }
      return next({
        ...args,
        request: request4
      });
    }, "userAgentMiddleware");
    var escapeUserAgent2 = /* @__PURE__ */ __name((userAgentPair) => {
      const name = userAgentPair[0].split(UA_NAME_SEPARATOR2).map((part) => part.replace(UA_NAME_ESCAPE_REGEX2, UA_ESCAPE_CHAR2)).join(UA_NAME_SEPARATOR2);
      const version = userAgentPair[1]?.replace(UA_VALUE_ESCAPE_REGEX2, UA_ESCAPE_CHAR2);
      const prefixSeparatorIndex = name.indexOf(UA_NAME_SEPARATOR2);
      const prefix = name.substring(0, prefixSeparatorIndex);
      let uaName = name.substring(prefixSeparatorIndex + 1);
      if (prefix === "api") {
        uaName = uaName.toLowerCase();
      }
      return [prefix, uaName, version].filter((item) => item && item.length > 0).reduce((acc, item, index) => {
        switch (index) {
          case 0:
            return item;
          case 1:
            return `${acc}/${item}`;
          default:
            return `${acc}#${item}`;
        }
      }, "");
    }, "escapeUserAgent");
    var getUserAgentMiddlewareOptions2 = {
      name: "getUserAgentMiddleware",
      step: "build",
      priority: "low",
      tags: ["SET_USER_AGENT", "USER_AGENT"],
      override: true
    };
    var getUserAgentPlugin29 = /* @__PURE__ */ __name((config2) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(userAgentMiddleware2(config2), getUserAgentMiddlewareOptions2);
      }, "applyToStack")
    }), "getUserAgentPlugin");
    exports2.DEFAULT_UA_APP_ID = DEFAULT_UA_APP_ID2;
    exports2.getUserAgentMiddlewareOptions = getUserAgentMiddlewareOptions2;
    exports2.getUserAgentPlugin = getUserAgentPlugin29;
    exports2.resolveUserAgentConfig = resolveUserAgentConfig29;
    exports2.userAgentMiddleware = userAgentMiddleware2;
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/middleware-retry/dist-cjs/isStreamingPayload/isStreamingPayload.js
var require_isStreamingPayload7 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/middleware-retry/dist-cjs/isStreamingPayload/isStreamingPayload.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isStreamingPayload = void 0;
    var stream_1 = require("stream");
    var isStreamingPayload3 = /* @__PURE__ */ __name((request4) => request4?.body instanceof stream_1.Readable || typeof ReadableStream !== "undefined" && request4?.body instanceof ReadableStream, "isStreamingPayload");
    exports2.isStreamingPayload = isStreamingPayload3;
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/middleware-retry/dist-cjs/index.js
var require_dist_cjs168 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/middleware-retry/dist-cjs/index.js"(exports2) {
    "use strict";
    var utilRetry = require_dist_cjs22();
    var protocolHttp = require_dist_cjs2();
    var serviceErrorClassification = require_dist_cjs32();
    var uuid = require_dist_cjs19();
    var utilMiddleware = require_dist_cjs6();
    var smithyClient = require_dist_cjs34();
    var isStreamingPayload3 = require_isStreamingPayload7();
    var serde = (init_serde(), __toCommonJS(serde_exports));
    var asSdkError3 = /* @__PURE__ */ __name((error4) => {
      if (error4 instanceof Error)
        return error4;
      if (error4 instanceof Object)
        return Object.assign(new Error(), error4);
      if (typeof error4 === "string")
        return new Error(error4);
      return new Error(`AWS SDK error wrapper for ${error4}`);
    }, "asSdkError");
    var getDefaultRetryQuota3 = /* @__PURE__ */ __name((initialRetryTokens, options) => {
      const MAX_CAPACITY = initialRetryTokens;
      const noRetryIncrement = utilRetry.NO_RETRY_INCREMENT;
      const retryCost = utilRetry.RETRY_COST;
      const timeoutRetryCost = utilRetry.TIMEOUT_RETRY_COST;
      let availableCapacity = initialRetryTokens;
      const getCapacityAmount = /* @__PURE__ */ __name((error4) => error4.name === "TimeoutError" ? timeoutRetryCost : retryCost, "getCapacityAmount");
      const hasRetryTokens = /* @__PURE__ */ __name((error4) => getCapacityAmount(error4) <= availableCapacity, "hasRetryTokens");
      const retrieveRetryTokens = /* @__PURE__ */ __name((error4) => {
        if (!hasRetryTokens(error4)) {
          throw new Error("No retry token available");
        }
        const capacityAmount = getCapacityAmount(error4);
        availableCapacity -= capacityAmount;
        return capacityAmount;
      }, "retrieveRetryTokens");
      const releaseRetryTokens = /* @__PURE__ */ __name((capacityReleaseAmount) => {
        availableCapacity += capacityReleaseAmount ?? noRetryIncrement;
        availableCapacity = Math.min(availableCapacity, MAX_CAPACITY);
      }, "releaseRetryTokens");
      return Object.freeze({
        hasRetryTokens,
        retrieveRetryTokens,
        releaseRetryTokens
      });
    }, "getDefaultRetryQuota");
    var defaultDelayDecider3 = /* @__PURE__ */ __name((delayBase, attempts) => Math.floor(Math.min(utilRetry.MAXIMUM_RETRY_DELAY, Math.random() * 2 ** attempts * delayBase)), "defaultDelayDecider");
    var defaultRetryDecider3 = /* @__PURE__ */ __name((error4) => {
      if (!error4) {
        return false;
      }
      return serviceErrorClassification.isRetryableByTrait(error4) || serviceErrorClassification.isClockSkewError(error4) || serviceErrorClassification.isThrottlingError(error4) || serviceErrorClassification.isTransientError(error4);
    }, "defaultRetryDecider");
    var StandardRetryStrategy5 = class {
      static {
        __name(this, "StandardRetryStrategy");
      }
      maxAttemptsProvider;
      retryDecider;
      delayDecider;
      retryQuota;
      mode = utilRetry.RETRY_MODES.STANDARD;
      constructor(maxAttemptsProvider, options) {
        this.maxAttemptsProvider = maxAttemptsProvider;
        this.retryDecider = options?.retryDecider ?? defaultRetryDecider3;
        this.delayDecider = options?.delayDecider ?? defaultDelayDecider3;
        this.retryQuota = options?.retryQuota ?? getDefaultRetryQuota3(utilRetry.INITIAL_RETRY_TOKENS);
      }
      shouldRetry(error4, attempts, maxAttempts) {
        return attempts < maxAttempts && this.retryDecider(error4) && this.retryQuota.hasRetryTokens(error4);
      }
      async getMaxAttempts() {
        let maxAttempts;
        try {
          maxAttempts = await this.maxAttemptsProvider();
        } catch (error4) {
          maxAttempts = utilRetry.DEFAULT_MAX_ATTEMPTS;
        }
        return maxAttempts;
      }
      async retry(next, args, options) {
        let retryTokenAmount;
        let attempts = 0;
        let totalDelay = 0;
        const maxAttempts = await this.getMaxAttempts();
        const { request: request4 } = args;
        if (protocolHttp.HttpRequest.isInstance(request4)) {
          request4.headers[utilRetry.INVOCATION_ID_HEADER] = uuid.v4();
        }
        while (true) {
          try {
            if (protocolHttp.HttpRequest.isInstance(request4)) {
              request4.headers[utilRetry.REQUEST_HEADER] = `attempt=${attempts + 1}; max=${maxAttempts}`;
            }
            if (options?.beforeRequest) {
              await options.beforeRequest();
            }
            const { response, output } = await next(args);
            if (options?.afterRequest) {
              options.afterRequest(response);
            }
            this.retryQuota.releaseRetryTokens(retryTokenAmount);
            output.$metadata.attempts = attempts + 1;
            output.$metadata.totalRetryDelay = totalDelay;
            return { response, output };
          } catch (e32) {
            const err = asSdkError3(e32);
            attempts++;
            if (this.shouldRetry(err, attempts, maxAttempts)) {
              retryTokenAmount = this.retryQuota.retrieveRetryTokens(err);
              const delayFromDecider = this.delayDecider(serviceErrorClassification.isThrottlingError(err) ? utilRetry.THROTTLING_RETRY_DELAY_BASE : utilRetry.DEFAULT_RETRY_DELAY_BASE, attempts);
              const delayFromResponse = getDelayFromRetryAfterHeader3(err.$response);
              const delay = Math.max(delayFromResponse || 0, delayFromDecider);
              totalDelay += delay;
              await new Promise((resolve13) => setTimeout(resolve13, delay));
              continue;
            }
            if (!err.$metadata) {
              err.$metadata = {};
            }
            err.$metadata.attempts = attempts;
            err.$metadata.totalRetryDelay = totalDelay;
            throw err;
          }
        }
      }
    };
    var getDelayFromRetryAfterHeader3 = /* @__PURE__ */ __name((response) => {
      if (!protocolHttp.HttpResponse.isInstance(response))
        return;
      const retryAfterHeaderName = Object.keys(response.headers).find((key) => key.toLowerCase() === "retry-after");
      if (!retryAfterHeaderName)
        return;
      const retryAfter = response.headers[retryAfterHeaderName];
      const retryAfterSeconds = Number(retryAfter);
      if (!Number.isNaN(retryAfterSeconds))
        return retryAfterSeconds * 1e3;
      const retryAfterDate = new Date(retryAfter);
      return retryAfterDate.getTime() - Date.now();
    }, "getDelayFromRetryAfterHeader");
    var AdaptiveRetryStrategy5 = class extends StandardRetryStrategy5 {
      static {
        __name(this, "AdaptiveRetryStrategy");
      }
      rateLimiter;
      constructor(maxAttemptsProvider, options) {
        const { rateLimiter, ...superOptions } = options ?? {};
        super(maxAttemptsProvider, superOptions);
        this.rateLimiter = rateLimiter ?? new utilRetry.DefaultRateLimiter();
        this.mode = utilRetry.RETRY_MODES.ADAPTIVE;
      }
      async retry(next, args) {
        return super.retry(next, args, {
          beforeRequest: /* @__PURE__ */ __name(async () => {
            return this.rateLimiter.getSendToken();
          }, "beforeRequest"),
          afterRequest: /* @__PURE__ */ __name((response) => {
            this.rateLimiter.updateClientSendingRate(response);
          }, "afterRequest")
        });
      }
    };
    var ENV_MAX_ATTEMPTS3 = "AWS_MAX_ATTEMPTS";
    var CONFIG_MAX_ATTEMPTS3 = "max_attempts";
    var NODE_MAX_ATTEMPT_CONFIG_OPTIONS30 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => {
        const value = env3[ENV_MAX_ATTEMPTS3];
        if (!value)
          return void 0;
        const maxAttempt = parseInt(value);
        if (Number.isNaN(maxAttempt)) {
          throw new Error(`Environment variable ${ENV_MAX_ATTEMPTS3} mast be a number, got "${value}"`);
        }
        return maxAttempt;
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => {
        const value = profile[CONFIG_MAX_ATTEMPTS3];
        if (!value)
          return void 0;
        const maxAttempt = parseInt(value);
        if (Number.isNaN(maxAttempt)) {
          throw new Error(`Shared config file entry ${CONFIG_MAX_ATTEMPTS3} mast be a number, got "${value}"`);
        }
        return maxAttempt;
      }, "configFileSelector"),
      default: utilRetry.DEFAULT_MAX_ATTEMPTS
    };
    var resolveRetryConfig30 = /* @__PURE__ */ __name((input) => {
      const { retryStrategy, retryMode } = input;
      const maxAttempts = utilMiddleware.normalizeProvider(input.maxAttempts ?? utilRetry.DEFAULT_MAX_ATTEMPTS);
      let controller = retryStrategy ? Promise.resolve(retryStrategy) : void 0;
      const getDefault = /* @__PURE__ */ __name(async () => await utilMiddleware.normalizeProvider(retryMode)() === utilRetry.RETRY_MODES.ADAPTIVE ? new utilRetry.AdaptiveRetryStrategy(maxAttempts) : new utilRetry.StandardRetryStrategy(maxAttempts), "getDefault");
      return Object.assign(input, {
        maxAttempts,
        retryStrategy: /* @__PURE__ */ __name(() => controller ??= getDefault(), "retryStrategy")
      });
    }, "resolveRetryConfig");
    var ENV_RETRY_MODE3 = "AWS_RETRY_MODE";
    var CONFIG_RETRY_MODE3 = "retry_mode";
    var NODE_RETRY_MODE_CONFIG_OPTIONS30 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[ENV_RETRY_MODE3], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[CONFIG_RETRY_MODE3], "configFileSelector"),
      default: utilRetry.DEFAULT_RETRY_MODE
    };
    var omitRetryHeadersMiddleware3 = /* @__PURE__ */ __name(() => (next) => async (args) => {
      const { request: request4 } = args;
      if (protocolHttp.HttpRequest.isInstance(request4)) {
        delete request4.headers[utilRetry.INVOCATION_ID_HEADER];
        delete request4.headers[utilRetry.REQUEST_HEADER];
      }
      return next(args);
    }, "omitRetryHeadersMiddleware");
    var omitRetryHeadersMiddlewareOptions3 = {
      name: "omitRetryHeadersMiddleware",
      tags: ["RETRY", "HEADERS", "OMIT_RETRY_HEADERS"],
      relation: "before",
      toMiddleware: "awsAuthMiddleware",
      override: true
    };
    var getOmitRetryHeadersPlugin3 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.addRelativeTo(omitRetryHeadersMiddleware3(), omitRetryHeadersMiddlewareOptions3);
      }, "applyToStack")
    }), "getOmitRetryHeadersPlugin");
    function parseRetryAfterHeader3(response, logger5) {
      if (!protocolHttp.HttpResponse.isInstance(response)) {
        return;
      }
      for (const header of Object.keys(response.headers)) {
        const h32 = header.toLowerCase();
        if (h32 === "retry-after") {
          const retryAfter = response.headers[header];
          let retryAfterSeconds = NaN;
          if (retryAfter.endsWith("GMT")) {
            try {
              const date7 = serde.parseRfc7231DateTime(retryAfter);
              retryAfterSeconds = (date7.getTime() - Date.now()) / 1e3;
            } catch (e32) {
              logger5?.trace?.("Failed to parse retry-after header");
              logger5?.trace?.(e32);
            }
          } else if (retryAfter.match(/ GMT, ((\d+)|(\d+\.\d+))$/)) {
            retryAfterSeconds = Number(retryAfter.match(/ GMT, ([\d.]+)$/)?.[1]);
          } else if (retryAfter.match(/^((\d+)|(\d+\.\d+))$/)) {
            retryAfterSeconds = Number(retryAfter);
          } else if (Date.parse(retryAfter) >= Date.now()) {
            retryAfterSeconds = (Date.parse(retryAfter) - Date.now()) / 1e3;
          }
          if (isNaN(retryAfterSeconds)) {
            return;
          }
          return new Date(Date.now() + retryAfterSeconds * 1e3);
        } else if (h32 === "x-amz-retry-after") {
          const v = response.headers[header];
          const backoffMilliseconds = Number(v);
          if (isNaN(backoffMilliseconds)) {
            logger5?.trace?.(`Failed to parse x-amz-retry-after=${v}`);
            return;
          }
          return new Date(Date.now() + backoffMilliseconds);
        }
      }
    }
    __name(parseRetryAfterHeader3, "parseRetryAfterHeader");
    function getRetryAfterHint3(response, logger5) {
      return parseRetryAfterHeader3(response, logger5);
    }
    __name(getRetryAfterHint3, "getRetryAfterHint");
    var retryMiddleware3 = /* @__PURE__ */ __name((options) => (next, context) => async (args) => {
      let retryStrategy = await options.retryStrategy();
      const maxAttempts = await options.maxAttempts();
      if (isRetryStrategyV23(retryStrategy)) {
        retryStrategy = retryStrategy;
        let retryToken = await retryStrategy.acquireInitialRetryToken((context["partition_id"] ?? "") + (context.__retryLongPoll ? ":longpoll" : ""));
        let lastError = new Error();
        let attempts = 0;
        let totalRetryDelay = 0;
        const { request: request4 } = args;
        const isRequest = protocolHttp.HttpRequest.isInstance(request4);
        if (isRequest) {
          request4.headers[utilRetry.INVOCATION_ID_HEADER] = uuid.v4();
        }
        while (true) {
          try {
            if (isRequest) {
              request4.headers[utilRetry.REQUEST_HEADER] = `attempt=${attempts + 1}; max=${maxAttempts}`;
            }
            const { response, output } = await next(args);
            retryStrategy.recordSuccess(retryToken);
            output.$metadata.attempts = attempts + 1;
            output.$metadata.totalRetryDelay = totalRetryDelay;
            return { response, output };
          } catch (e32) {
            const retryErrorInfo = getRetryErrorInfo3(e32, options.logger);
            lastError = asSdkError3(e32);
            if (isRequest && isStreamingPayload3.isStreamingPayload(request4)) {
              (context.logger instanceof smithyClient.NoOpLogger ? console : context.logger)?.warn("An error was encountered in a non-retryable streaming request.");
              throw lastError;
            }
            try {
              retryToken = await retryStrategy.refreshRetryTokenForRetry(retryToken, retryErrorInfo);
            } catch (refreshError) {
              if (typeof refreshError.$backoff === "number") {
                await cooldown3(refreshError.$backoff);
              }
              if (!lastError.$metadata) {
                lastError.$metadata = {};
              }
              lastError.$metadata.attempts = attempts + 1;
              lastError.$metadata.totalRetryDelay = totalRetryDelay;
              throw lastError;
            }
            attempts = retryToken.getRetryCount();
            const delay = retryToken.getRetryDelay();
            totalRetryDelay += delay;
            await cooldown3(delay);
          }
        }
      } else {
        retryStrategy = retryStrategy;
        if (retryStrategy?.mode) {
          context.userAgent = [...context.userAgent || [], ["cfg/retry-mode", retryStrategy.mode]];
        }
        return retryStrategy.retry(next, args);
      }
    }, "retryMiddleware");
    var cooldown3 = /* @__PURE__ */ __name((ms) => new Promise((resolve13) => setTimeout(resolve13, ms)), "cooldown");
    var isRetryStrategyV23 = /* @__PURE__ */ __name((retryStrategy) => typeof retryStrategy.acquireInitialRetryToken !== "undefined" && typeof retryStrategy.refreshRetryTokenForRetry !== "undefined" && typeof retryStrategy.recordSuccess !== "undefined", "isRetryStrategyV2");
    var getRetryErrorInfo3 = /* @__PURE__ */ __name((error4, logger5) => {
      const errorInfo = {
        error: error4,
        errorType: getRetryErrorType3(error4)
      };
      const retryAfterHint = parseRetryAfterHeader3(error4.$response, logger5);
      if (retryAfterHint) {
        errorInfo.retryAfterHint = retryAfterHint;
      }
      return errorInfo;
    }, "getRetryErrorInfo");
    var getRetryErrorType3 = /* @__PURE__ */ __name((error4) => {
      if (serviceErrorClassification.isThrottlingError(error4))
        return "THROTTLING";
      if (serviceErrorClassification.isTransientError(error4))
        return "TRANSIENT";
      if (serviceErrorClassification.isServerError(error4))
        return "SERVER_ERROR";
      return "CLIENT_ERROR";
    }, "getRetryErrorType");
    var retryMiddlewareOptions3 = {
      name: "retryMiddleware",
      tags: ["RETRY"],
      step: "finalizeRequest",
      priority: "high",
      override: true
    };
    var getRetryPlugin30 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(retryMiddleware3(options), retryMiddlewareOptions3);
      }, "applyToStack")
    }), "getRetryPlugin");
    exports2.AdaptiveRetryStrategy = AdaptiveRetryStrategy5;
    exports2.CONFIG_MAX_ATTEMPTS = CONFIG_MAX_ATTEMPTS3;
    exports2.CONFIG_RETRY_MODE = CONFIG_RETRY_MODE3;
    exports2.ENV_MAX_ATTEMPTS = ENV_MAX_ATTEMPTS3;
    exports2.ENV_RETRY_MODE = ENV_RETRY_MODE3;
    exports2.NODE_MAX_ATTEMPT_CONFIG_OPTIONS = NODE_MAX_ATTEMPT_CONFIG_OPTIONS30;
    exports2.NODE_RETRY_MODE_CONFIG_OPTIONS = NODE_RETRY_MODE_CONFIG_OPTIONS30;
    exports2.StandardRetryStrategy = StandardRetryStrategy5;
    exports2.defaultDelayDecider = defaultDelayDecider3;
    exports2.defaultRetryDecider = defaultRetryDecider3;
    exports2.getOmitRetryHeadersPlugin = getOmitRetryHeadersPlugin3;
    exports2.getRetryAfterHint = getRetryAfterHint3;
    exports2.getRetryPlugin = getRetryPlugin30;
    exports2.omitRetryHeadersMiddleware = omitRetryHeadersMiddleware3;
    exports2.omitRetryHeadersMiddlewareOptions = omitRetryHeadersMiddlewareOptions3;
    exports2.resolveRetryConfig = resolveRetryConfig30;
    exports2.retryMiddleware = retryMiddleware3;
    exports2.retryMiddlewareOptions = retryMiddlewareOptions3;
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getDateHeader.js
var import_protocol_http45, getDateHeader8;
var init_getDateHeader8 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getDateHeader.js"() {
    import_protocol_http45 = __toESM(require_dist_cjs2());
    getDateHeader8 = /* @__PURE__ */ __name((response) => import_protocol_http45.HttpResponse.isInstance(response) ? response.headers?.date ?? response.headers?.Date : void 0, "getDateHeader");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getSkewCorrectedDate.js
var getSkewCorrectedDate8;
var init_getSkewCorrectedDate8 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getSkewCorrectedDate.js"() {
    getSkewCorrectedDate8 = /* @__PURE__ */ __name((systemClockOffset) => new Date(Date.now() + systemClockOffset), "getSkewCorrectedDate");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/isClockSkewed.js
var isClockSkewed8;
var init_isClockSkewed8 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/isClockSkewed.js"() {
    init_getSkewCorrectedDate8();
    isClockSkewed8 = /* @__PURE__ */ __name((clockTime, systemClockOffset) => Math.abs(getSkewCorrectedDate8(systemClockOffset).getTime() - clockTime) >= 3e5, "isClockSkewed");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getUpdatedSystemClockOffset.js
var getUpdatedSystemClockOffset8;
var init_getUpdatedSystemClockOffset8 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getUpdatedSystemClockOffset.js"() {
    init_isClockSkewed8();
    getUpdatedSystemClockOffset8 = /* @__PURE__ */ __name((clockTime, currentSystemClockOffset) => {
      const clockTimeInMs = Date.parse(clockTime);
      if (isClockSkewed8(clockTimeInMs, currentSystemClockOffset)) {
        return clockTimeInMs - Date.now();
      }
      return currentSystemClockOffset;
    }, "getUpdatedSystemClockOffset");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/index.js
var init_utils15 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/index.js"() {
    init_getDateHeader8();
    init_getSkewCorrectedDate8();
    init_getUpdatedSystemClockOffset8();
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4Signer.js
var import_protocol_http46, throwSigningPropertyError8, validateSigningProperties8, AwsSdkSigV4Signer8, AWSSDKSigV4Signer8;
var init_AwsSdkSigV4Signer8 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4Signer.js"() {
    import_protocol_http46 = __toESM(require_dist_cjs2());
    init_utils15();
    throwSigningPropertyError8 = /* @__PURE__ */ __name((name, property) => {
      if (!property) {
        throw new Error(`Property \`${name}\` is not resolved for AWS SDK SigV4Auth`);
      }
      return property;
    }, "throwSigningPropertyError");
    validateSigningProperties8 = /* @__PURE__ */ __name(async (signingProperties) => {
      const context = throwSigningPropertyError8("context", signingProperties.context);
      const config2 = throwSigningPropertyError8("config", signingProperties.config);
      const authScheme = context.endpointV2?.properties?.authSchemes?.[0];
      const signerFunction = throwSigningPropertyError8("signer", config2.signer);
      const signer = await signerFunction(authScheme);
      const signingRegion = signingProperties?.signingRegion;
      const signingRegionSet = signingProperties?.signingRegionSet;
      const signingName = signingProperties?.signingName;
      return {
        config: config2,
        signer,
        signingRegion,
        signingRegionSet,
        signingName
      };
    }, "validateSigningProperties");
    AwsSdkSigV4Signer8 = class {
      static {
        __name(this, "AwsSdkSigV4Signer");
      }
      async sign(httpRequest, identity, signingProperties) {
        if (!import_protocol_http46.HttpRequest.isInstance(httpRequest)) {
          throw new Error("The request is not an instance of `HttpRequest` and cannot be signed");
        }
        const validatedProps = await validateSigningProperties8(signingProperties);
        const { config: config2, signer } = validatedProps;
        let { signingRegion, signingName } = validatedProps;
        const handlerExecutionContext = signingProperties.context;
        if (handlerExecutionContext?.authSchemes?.length ?? 0 > 1) {
          const [first, second] = handlerExecutionContext.authSchemes;
          if (first?.name === "sigv4a" && second?.name === "sigv4") {
            signingRegion = second?.signingRegion ?? signingRegion;
            signingName = second?.signingName ?? signingName;
          }
        }
        const signedRequest = await signer.sign(httpRequest, {
          signingDate: getSkewCorrectedDate8(config2.systemClockOffset),
          signingRegion,
          signingService: signingName
        });
        return signedRequest;
      }
      errorHandler(signingProperties) {
        return (error4) => {
          const serverTime = error4.ServerTime ?? getDateHeader8(error4.$response);
          if (serverTime) {
            const config2 = throwSigningPropertyError8("config", signingProperties.config);
            const initialSystemClockOffset = config2.systemClockOffset;
            config2.systemClockOffset = getUpdatedSystemClockOffset8(serverTime, config2.systemClockOffset);
            const clockSkewCorrected = config2.systemClockOffset !== initialSystemClockOffset;
            if (clockSkewCorrected && error4.$metadata) {
              error4.$metadata.clockSkewCorrected = true;
            }
          }
          throw error4;
        };
      }
      successHandler(httpResponse, signingProperties) {
        const dateHeader = getDateHeader8(httpResponse);
        if (dateHeader) {
          const config2 = throwSigningPropertyError8("config", signingProperties.config);
          config2.systemClockOffset = getUpdatedSystemClockOffset8(dateHeader, config2.systemClockOffset);
        }
      }
    };
    AWSSDKSigV4Signer8 = AwsSdkSigV4Signer8;
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4ASigner.js
var import_protocol_http47, AwsSdkSigV4ASigner8;
var init_AwsSdkSigV4ASigner8 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4ASigner.js"() {
    import_protocol_http47 = __toESM(require_dist_cjs2());
    init_utils15();
    init_AwsSdkSigV4Signer8();
    AwsSdkSigV4ASigner8 = class extends AwsSdkSigV4Signer8 {
      static {
        __name(this, "AwsSdkSigV4ASigner");
      }
      async sign(httpRequest, identity, signingProperties) {
        if (!import_protocol_http47.HttpRequest.isInstance(httpRequest)) {
          throw new Error("The request is not an instance of `HttpRequest` and cannot be signed");
        }
        const { config: config2, signer, signingRegion, signingRegionSet, signingName } = await validateSigningProperties8(signingProperties);
        const configResolvedSigningRegionSet = await config2.sigv4aSigningRegionSet?.();
        const multiRegionOverride = (configResolvedSigningRegionSet ?? signingRegionSet ?? [signingRegion]).join(",");
        const signedRequest = await signer.sign(httpRequest, {
          signingDate: getSkewCorrectedDate8(config2.systemClockOffset),
          signingRegion: multiRegionOverride,
          signingService: signingName
        });
        return signedRequest;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getArrayForCommaSeparatedString.js
var getArrayForCommaSeparatedString8;
var init_getArrayForCommaSeparatedString8 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getArrayForCommaSeparatedString.js"() {
    getArrayForCommaSeparatedString8 = /* @__PURE__ */ __name((str) => typeof str === "string" && str.length > 0 ? str.split(",").map((item) => item.trim()) : [], "getArrayForCommaSeparatedString");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getBearerTokenEnvKey.js
var getBearerTokenEnvKey8;
var init_getBearerTokenEnvKey8 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getBearerTokenEnvKey.js"() {
    getBearerTokenEnvKey8 = /* @__PURE__ */ __name((signingName) => `AWS_BEARER_TOKEN_${signingName.replace(/[\s-]/g, "_").toUpperCase()}`, "getBearerTokenEnvKey");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/NODE_AUTH_SCHEME_PREFERENCE_OPTIONS.js
var NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY8, NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY8, NODE_AUTH_SCHEME_PREFERENCE_OPTIONS8;
var init_NODE_AUTH_SCHEME_PREFERENCE_OPTIONS8 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/NODE_AUTH_SCHEME_PREFERENCE_OPTIONS.js"() {
    init_getArrayForCommaSeparatedString8();
    init_getBearerTokenEnvKey8();
    NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY8 = "AWS_AUTH_SCHEME_PREFERENCE";
    NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY8 = "auth_scheme_preference";
    NODE_AUTH_SCHEME_PREFERENCE_OPTIONS8 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3, options) => {
        if (options?.signingName) {
          const bearerTokenKey = getBearerTokenEnvKey8(options.signingName);
          if (bearerTokenKey in env3)
            return ["httpBearerAuth"];
        }
        if (!(NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY8 in env3))
          return void 0;
        return getArrayForCommaSeparatedString8(env3[NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY8]);
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => {
        if (!(NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY8 in profile))
          return void 0;
        return getArrayForCommaSeparatedString8(profile[NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY8]);
      }, "configFileSelector"),
      default: []
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4AConfig.js
var import_property_provider7, resolveAwsSdkSigV4AConfig8, NODE_SIGV4A_CONFIG_OPTIONS8;
var init_resolveAwsSdkSigV4AConfig8 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4AConfig.js"() {
    init_dist_es();
    import_property_provider7 = __toESM(require_dist_cjs27());
    resolveAwsSdkSigV4AConfig8 = /* @__PURE__ */ __name((config2) => {
      config2.sigv4aSigningRegionSet = normalizeProvider(config2.sigv4aSigningRegionSet);
      return config2;
    }, "resolveAwsSdkSigV4AConfig");
    NODE_SIGV4A_CONFIG_OPTIONS8 = {
      environmentVariableSelector(env3) {
        if (env3.AWS_SIGV4A_SIGNING_REGION_SET) {
          return env3.AWS_SIGV4A_SIGNING_REGION_SET.split(",").map((_) => _.trim());
        }
        throw new import_property_provider7.ProviderError("AWS_SIGV4A_SIGNING_REGION_SET not set in env.", {
          tryNextLink: true
        });
      },
      configFileSelector(profile) {
        if (profile.sigv4a_signing_region_set) {
          return (profile.sigv4a_signing_region_set ?? "").split(",").map((_) => _.trim());
        }
        throw new import_property_provider7.ProviderError("sigv4a_signing_region_set not set in profile.", {
          tryNextLink: true
        });
      },
      default: void 0
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4Config.js
function normalizeCredentialProvider8(config2, { credentials, credentialDefaultProvider }) {
  let credentialsProvider;
  if (credentials) {
    if (!credentials?.memoized) {
      credentialsProvider = memoizeIdentityProvider(credentials, isIdentityExpired, doesIdentityRequireRefresh);
    } else {
      credentialsProvider = credentials;
    }
  } else {
    if (credentialDefaultProvider) {
      credentialsProvider = normalizeProvider(credentialDefaultProvider(Object.assign({}, config2, {
        parentClientConfig: config2
      })));
    } else {
      credentialsProvider = /* @__PURE__ */ __name(async () => {
        throw new Error("@aws-sdk/core::resolveAwsSdkSigV4Config - `credentials` not provided and no credentialDefaultProvider was configured.");
      }, "credentialsProvider");
    }
  }
  credentialsProvider.memoized = true;
  return credentialsProvider;
}
function bindCallerConfig8(config2, credentialsProvider) {
  if (credentialsProvider.configBound) {
    return credentialsProvider;
  }
  const fn = /* @__PURE__ */ __name(async (options) => credentialsProvider({ ...options, callerClientConfig: config2 }), "fn");
  fn.memoized = credentialsProvider.memoized;
  fn.configBound = true;
  return fn;
}
var import_signature_v48, resolveAwsSdkSigV4Config8, resolveAWSSDKSigV4Config8;
var init_resolveAwsSdkSigV4Config8 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4Config.js"() {
    init_client17();
    init_dist_es();
    import_signature_v48 = __toESM(require_dist_cjs36());
    resolveAwsSdkSigV4Config8 = /* @__PURE__ */ __name((config2) => {
      let inputCredentials = config2.credentials;
      let isUserSupplied = !!config2.credentials;
      let resolvedCredentials = void 0;
      Object.defineProperty(config2, "credentials", {
        set(credentials) {
          if (credentials && credentials !== inputCredentials && credentials !== resolvedCredentials) {
            isUserSupplied = true;
          }
          inputCredentials = credentials;
          const memoizedProvider = normalizeCredentialProvider8(config2, {
            credentials: inputCredentials,
            credentialDefaultProvider: config2.credentialDefaultProvider
          });
          const boundProvider = bindCallerConfig8(config2, memoizedProvider);
          if (isUserSupplied && !boundProvider.attributed) {
            const isCredentialObject = typeof inputCredentials === "object" && inputCredentials !== null;
            resolvedCredentials = /* @__PURE__ */ __name(async (options) => {
              const creds = await boundProvider(options);
              const attributedCreds = creds;
              if (isCredentialObject && (!attributedCreds.$source || Object.keys(attributedCreds.$source).length === 0)) {
                return setCredentialFeature10(attributedCreds, "CREDENTIALS_CODE", "e");
              }
              return attributedCreds;
            }, "resolvedCredentials");
            resolvedCredentials.memoized = boundProvider.memoized;
            resolvedCredentials.configBound = boundProvider.configBound;
            resolvedCredentials.attributed = true;
          } else {
            resolvedCredentials = boundProvider;
          }
        },
        get() {
          return resolvedCredentials;
        },
        enumerable: true,
        configurable: true
      });
      config2.credentials = inputCredentials;
      const { signingEscapePath = true, systemClockOffset = config2.systemClockOffset || 0, sha256 } = config2;
      let signer;
      if (config2.signer) {
        signer = normalizeProvider(config2.signer);
      } else if (config2.regionInfoProvider) {
        signer = /* @__PURE__ */ __name(() => normalizeProvider(config2.region)().then(async (region) => [
          await config2.regionInfoProvider(region, {
            useFipsEndpoint: await config2.useFipsEndpoint(),
            useDualstackEndpoint: await config2.useDualstackEndpoint()
          }) || {},
          region
        ]).then(([regionInfo, region]) => {
          const { signingRegion, signingService } = regionInfo;
          config2.signingRegion = config2.signingRegion || signingRegion || region;
          config2.signingName = config2.signingName || signingService || config2.serviceId;
          const params = {
            ...config2,
            credentials: config2.credentials,
            region: config2.signingRegion,
            service: config2.signingName,
            sha256,
            uriEscapePath: signingEscapePath
          };
          const SignerCtor = config2.signerConstructor || import_signature_v48.SignatureV4;
          return new SignerCtor(params);
        }), "signer");
      } else {
        signer = /* @__PURE__ */ __name(async (authScheme) => {
          authScheme = Object.assign({}, {
            name: "sigv4",
            signingName: config2.signingName || config2.defaultSigningName,
            signingRegion: await normalizeProvider(config2.region)(),
            properties: {}
          }, authScheme);
          const signingRegion = authScheme.signingRegion;
          const signingService = authScheme.signingName;
          config2.signingRegion = config2.signingRegion || signingRegion;
          config2.signingName = config2.signingName || signingService || config2.serviceId;
          const params = {
            ...config2,
            credentials: config2.credentials,
            region: config2.signingRegion,
            service: config2.signingName,
            sha256,
            uriEscapePath: signingEscapePath
          };
          const SignerCtor = config2.signerConstructor || import_signature_v48.SignatureV4;
          return new SignerCtor(params);
        }, "signer");
      }
      const resolvedConfig = Object.assign(config2, {
        systemClockOffset,
        signingEscapePath,
        signer
      });
      return resolvedConfig;
    }, "resolveAwsSdkSigV4Config");
    resolveAWSSDKSigV4Config8 = resolveAwsSdkSigV4Config8;
    __name(normalizeCredentialProvider8, "normalizeCredentialProvider");
    __name(bindCallerConfig8, "bindCallerConfig");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/index.js
var init_aws_sdk8 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/index.js"() {
    init_AwsSdkSigV4Signer8();
    init_AwsSdkSigV4ASigner8();
    init_NODE_AUTH_SCHEME_PREFERENCE_OPTIONS8();
    init_resolveAwsSdkSigV4AConfig8();
    init_resolveAwsSdkSigV4Config8();
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/index.js
var httpAuthSchemes_exports8 = {};
__export(httpAuthSchemes_exports8, {
  AWSSDKSigV4Signer: () => AWSSDKSigV4Signer8,
  AwsSdkSigV4ASigner: () => AwsSdkSigV4ASigner8,
  AwsSdkSigV4Signer: () => AwsSdkSigV4Signer8,
  NODE_AUTH_SCHEME_PREFERENCE_OPTIONS: () => NODE_AUTH_SCHEME_PREFERENCE_OPTIONS8,
  NODE_SIGV4A_CONFIG_OPTIONS: () => NODE_SIGV4A_CONFIG_OPTIONS8,
  getBearerTokenEnvKey: () => getBearerTokenEnvKey8,
  resolveAWSSDKSigV4Config: () => resolveAWSSDKSigV4Config8,
  resolveAwsSdkSigV4AConfig: () => resolveAwsSdkSigV4AConfig8,
  resolveAwsSdkSigV4Config: () => resolveAwsSdkSigV4Config8,
  validateSigningProperties: () => validateSigningProperties8
});
var init_httpAuthSchemes10 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/index.js"() {
    init_aws_sdk8();
    init_getBearerTokenEnvKey8();
  }
});

// ../../node_modules/@aws-sdk/client-kms/dist-cjs/auth/httpAuthSchemeProvider.js
var require_httpAuthSchemeProvider15 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/dist-cjs/auth/httpAuthSchemeProvider.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.resolveHttpAuthSchemeConfig = exports2.defaultKMSHttpAuthSchemeProvider = exports2.defaultKMSHttpAuthSchemeParametersProvider = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes10(), __toCommonJS(httpAuthSchemes_exports8));
    var util_middleware_1 = require_dist_cjs6();
    var defaultKMSHttpAuthSchemeParametersProvider = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, util_middleware_1.getSmithyContext)(context).operation,
        region: await (0, util_middleware_1.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultKMSHttpAuthSchemeParametersProvider");
    exports2.defaultKMSHttpAuthSchemeParametersProvider = defaultKMSHttpAuthSchemeParametersProvider;
    function createAwsAuthSigv4HttpAuthOption32(authParameters) {
      return {
        schemeId: "aws.auth#sigv4",
        signingProperties: {
          name: "kms",
          region: authParameters.region
        },
        propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
          signingProperties: {
            config: config2,
            context
          }
        }), "propertiesExtractor")
      };
    }
    __name(createAwsAuthSigv4HttpAuthOption32, "createAwsAuthSigv4HttpAuthOption");
    var defaultKMSHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption32(authParameters));
        }
      }
      return options;
    }, "defaultKMSHttpAuthSchemeProvider");
    exports2.defaultKMSHttpAuthSchemeProvider = defaultKMSHttpAuthSchemeProvider;
    var resolveHttpAuthSchemeConfig32 = /* @__PURE__ */ __name((config2) => {
      const config_0 = (0, httpAuthSchemes_1.resolveAwsSdkSigV4Config)(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, util_middleware_1.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
    exports2.resolveHttpAuthSchemeConfig = resolveHttpAuthSchemeConfig32;
  }
});

// ../../node_modules/@aws-sdk/client-kms/package.json
var require_package15 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/package.json"(exports2, module2) {
    module2.exports = {
      name: "@aws-sdk/client-kms",
      description: "AWS SDK for JavaScript Kms Client for Node.js, Browser and React Native",
      version: "3.1041.0",
      scripts: {
        build: "concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline client-kms",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        "extract:docs": "api-extractor run --local",
        "generate:client": "node ../../scripts/generate-clients/single-service --solo kms",
        "test:e2e": "yarn g:vitest run -c vitest.config.e2e.mts --mode development",
        "test:e2e:watch": "yarn g:vitest watch -c vitest.config.e2e.mts",
        "test:index": "tsc --noEmit ./test/index-types.ts && node ./test/index-objects.spec.mjs"
      },
      main: "./dist-cjs/index.js",
      types: "./dist-types/index.d.ts",
      module: "./dist-es/index.js",
      sideEffects: false,
      dependencies: {
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.8",
        "@aws-sdk/credential-provider-node": "^3.972.39",
        "@aws-sdk/middleware-host-header": "^3.972.10",
        "@aws-sdk/middleware-logger": "^3.972.10",
        "@aws-sdk/middleware-recursion-detection": "^3.972.11",
        "@aws-sdk/middleware-user-agent": "^3.972.38",
        "@aws-sdk/region-config-resolver": "^3.972.13",
        "@aws-sdk/types": "^3.973.8",
        "@aws-sdk/util-endpoints": "^3.996.8",
        "@aws-sdk/util-user-agent-browser": "^3.972.10",
        "@aws-sdk/util-user-agent-node": "^3.973.24",
        "@smithy/config-resolver": "^4.4.17",
        "@smithy/core": "^3.23.17",
        "@smithy/fetch-http-handler": "^5.3.17",
        "@smithy/hash-node": "^4.2.14",
        "@smithy/invalid-dependency": "^4.2.14",
        "@smithy/middleware-content-length": "^4.2.14",
        "@smithy/middleware-endpoint": "^4.4.32",
        "@smithy/middleware-retry": "^4.5.7",
        "@smithy/middleware-serde": "^4.2.20",
        "@smithy/middleware-stack": "^4.2.14",
        "@smithy/node-config-provider": "^4.3.14",
        "@smithy/node-http-handler": "^4.6.1",
        "@smithy/protocol-http": "^5.3.14",
        "@smithy/smithy-client": "^4.12.13",
        "@smithy/types": "^4.14.1",
        "@smithy/url-parser": "^4.2.14",
        "@smithy/util-base64": "^4.3.2",
        "@smithy/util-body-length-browser": "^4.2.2",
        "@smithy/util-body-length-node": "^4.2.3",
        "@smithy/util-defaults-mode-browser": "^4.3.49",
        "@smithy/util-defaults-mode-node": "^4.2.54",
        "@smithy/util-endpoints": "^3.4.2",
        "@smithy/util-middleware": "^4.2.14",
        "@smithy/util-retry": "^4.3.6",
        "@smithy/util-utf8": "^4.2.2",
        tslib: "^2.6.2"
      },
      devDependencies: {
        "@tsconfig/node20": "20.1.8",
        "@types/node": "^20.14.8",
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3"
      },
      engines: {
        node: ">=20.0.0"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "dist-*/**"
      ],
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      browser: {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.browser"
      },
      "react-native": {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.native"
      },
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/clients/client-kms",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "clients/client-kms"
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-env/dist-cjs/index.js
var require_dist_cjs169 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-env/dist-cjs/index.js"(exports2) {
    "use strict";
    var client = (init_client17(), __toCommonJS(client_exports12));
    var propertyProvider = require_dist_cjs27();
    var ENV_KEY = "AWS_ACCESS_KEY_ID";
    var ENV_SECRET = "AWS_SECRET_ACCESS_KEY";
    var ENV_SESSION = "AWS_SESSION_TOKEN";
    var ENV_EXPIRATION = "AWS_CREDENTIAL_EXPIRATION";
    var ENV_CREDENTIAL_SCOPE = "AWS_CREDENTIAL_SCOPE";
    var ENV_ACCOUNT_ID = "AWS_ACCOUNT_ID";
    var fromEnv6 = /* @__PURE__ */ __name((init) => async () => {
      init?.logger?.debug("@aws-sdk/credential-provider-env - fromEnv");
      const accessKeyId = process.env[ENV_KEY];
      const secretAccessKey = process.env[ENV_SECRET];
      const sessionToken = process.env[ENV_SESSION];
      const expiry = process.env[ENV_EXPIRATION];
      const credentialScope = process.env[ENV_CREDENTIAL_SCOPE];
      const accountId = process.env[ENV_ACCOUNT_ID];
      if (accessKeyId && secretAccessKey) {
        const credentials = {
          accessKeyId,
          secretAccessKey,
          ...sessionToken && { sessionToken },
          ...expiry && { expiration: new Date(expiry) },
          ...credentialScope && { credentialScope },
          ...accountId && { accountId }
        };
        client.setCredentialFeature(credentials, "CREDENTIALS_ENV_VARS", "g");
        return credentials;
      }
      throw new propertyProvider.CredentialsProviderError("Unable to find environment variable credentials.", { logger: init?.logger });
    }, "fromEnv");
    exports2.ENV_ACCOUNT_ID = ENV_ACCOUNT_ID;
    exports2.ENV_CREDENTIAL_SCOPE = ENV_CREDENTIAL_SCOPE;
    exports2.ENV_EXPIRATION = ENV_EXPIRATION;
    exports2.ENV_KEY = ENV_KEY;
    exports2.ENV_SECRET = ENV_SECRET;
    exports2.ENV_SESSION = ENV_SESSION;
    exports2.fromEnv = fromEnv6;
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/checkUrl.js
var require_checkUrl7 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/checkUrl.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.checkUrl = void 0;
    var property_provider_1 = require_dist_cjs27();
    var ECS_CONTAINER_HOST = "169.254.170.2";
    var EKS_CONTAINER_HOST_IPv4 = "169.254.170.23";
    var EKS_CONTAINER_HOST_IPv6 = "[fd00:ec2::23]";
    var checkUrl = /* @__PURE__ */ __name((url, logger5) => {
      if (url.protocol === "https:") {
        return;
      }
      if (url.hostname === ECS_CONTAINER_HOST || url.hostname === EKS_CONTAINER_HOST_IPv4 || url.hostname === EKS_CONTAINER_HOST_IPv6) {
        return;
      }
      if (url.hostname.includes("[")) {
        if (url.hostname === "[::1]" || url.hostname === "[0000:0000:0000:0000:0000:0000:0000:0001]") {
          return;
        }
      } else {
        if (url.hostname === "localhost") {
          return;
        }
        const ipComponents = url.hostname.split(".");
        const inRange = /* @__PURE__ */ __name((component) => {
          const num = parseInt(component, 10);
          return 0 <= num && num <= 255;
        }, "inRange");
        if (ipComponents[0] === "127" && inRange(ipComponents[1]) && inRange(ipComponents[2]) && inRange(ipComponents[3]) && ipComponents.length === 4) {
          return;
        }
      }
      throw new property_provider_1.CredentialsProviderError(`URL not accepted. It must either be HTTPS or match one of the following:
  - loopback CIDR 127.0.0.0/8 or [::1/128]
  - ECS container host 169.254.170.2
  - EKS container host 169.254.170.23 or [fd00:ec2::23]`, { logger: logger5 });
    }, "checkUrl");
    exports2.checkUrl = checkUrl;
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.js
var require_ChecksumStream8 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ChecksumStream = void 0;
    var util_base64_1 = require_dist_cjs10();
    var stream_1 = require("stream");
    var ChecksumStream5 = class extends stream_1.Duplex {
      static {
        __name(this, "ChecksumStream");
      }
      expectedChecksum;
      checksumSourceLocation;
      checksum;
      source;
      base64Encoder;
      pendingCallback = null;
      constructor({ expectedChecksum, checksum, source, checksumSourceLocation, base64Encoder }) {
        super();
        if (typeof source.pipe === "function") {
          this.source = source;
        } else {
          throw new Error(`@smithy/util-stream: unsupported source type ${source?.constructor?.name ?? source} in ChecksumStream.`);
        }
        this.base64Encoder = base64Encoder ?? util_base64_1.toBase64;
        this.expectedChecksum = expectedChecksum;
        this.checksum = checksum;
        this.checksumSourceLocation = checksumSourceLocation;
        this.source.pipe(this);
      }
      _read(size) {
        if (this.pendingCallback) {
          const callback = this.pendingCallback;
          this.pendingCallback = null;
          callback();
        }
      }
      _write(chunk, encoding, callback) {
        try {
          this.checksum.update(chunk);
          const canPushMore = this.push(chunk);
          if (!canPushMore) {
            this.pendingCallback = callback;
            return;
          }
        } catch (e32) {
          return callback(e32);
        }
        return callback();
      }
      async _final(callback) {
        try {
          const digest = await this.checksum.digest();
          const received = this.base64Encoder(digest);
          if (this.expectedChecksum !== received) {
            return callback(new Error(`Checksum mismatch: expected "${this.expectedChecksum}" but received "${received}" in response header "${this.checksumSourceLocation}".`));
          }
        } catch (e32) {
          return callback(e32);
        }
        this.push(null);
        return callback();
      }
    };
    exports2.ChecksumStream = ChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/stream-type-check.js
var require_stream_type_check8 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/stream-type-check.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isBlob = exports2.isReadableStream = void 0;
    var isReadableStream6 = /* @__PURE__ */ __name((stream) => typeof ReadableStream === "function" && (stream?.constructor?.name === ReadableStream.name || stream instanceof ReadableStream), "isReadableStream");
    exports2.isReadableStream = isReadableStream6;
    var isBlob3 = /* @__PURE__ */ __name((blob) => {
      return typeof Blob === "function" && (blob?.constructor?.name === Blob.name || blob instanceof Blob);
    }, "isBlob");
    exports2.isBlob = isBlob3;
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.browser.js
var require_ChecksumStream_browser8 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ChecksumStream = void 0;
    var ReadableStreamRef3 = typeof ReadableStream === "function" ? ReadableStream : function() {
    };
    var ChecksumStream5 = class extends ReadableStreamRef3 {
      static {
        __name(this, "ChecksumStream");
      }
    };
    exports2.ChecksumStream = ChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.browser.js
var require_createChecksumStream_browser8 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createChecksumStream = void 0;
    var util_base64_1 = require_dist_cjs10();
    var stream_type_check_1 = require_stream_type_check8();
    var ChecksumStream_browser_1 = require_ChecksumStream_browser8();
    var createChecksumStream5 = /* @__PURE__ */ __name(({ expectedChecksum, checksum, source, checksumSourceLocation, base64Encoder }) => {
      if (!(0, stream_type_check_1.isReadableStream)(source)) {
        throw new Error(`@smithy/util-stream: unsupported source type ${source?.constructor?.name ?? source} in ChecksumStream.`);
      }
      const encoder = base64Encoder ?? util_base64_1.toBase64;
      if (typeof TransformStream !== "function") {
        throw new Error("@smithy/util-stream: unable to instantiate ChecksumStream because API unavailable: ReadableStream/TransformStream.");
      }
      const transform = new TransformStream({
        start() {
        },
        async transform(chunk, controller) {
          checksum.update(chunk);
          controller.enqueue(chunk);
        },
        async flush(controller) {
          const digest = await checksum.digest();
          const received = encoder(digest);
          if (expectedChecksum !== received) {
            const error4 = new Error(`Checksum mismatch: expected "${expectedChecksum}" but received "${received}" in response header "${checksumSourceLocation}".`);
            controller.error(error4);
          } else {
            controller.terminate();
          }
        }
      });
      source.pipeThrough(transform);
      const readable = transform.readable;
      Object.setPrototypeOf(readable, ChecksumStream_browser_1.ChecksumStream.prototype);
      return readable;
    }, "createChecksumStream");
    exports2.createChecksumStream = createChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.js
var require_createChecksumStream8 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createChecksumStream = createChecksumStream5;
    var stream_type_check_1 = require_stream_type_check8();
    var ChecksumStream_1 = require_ChecksumStream8();
    var createChecksumStream_browser_1 = require_createChecksumStream_browser8();
    function createChecksumStream5(init) {
      if (typeof ReadableStream === "function" && (0, stream_type_check_1.isReadableStream)(init.source)) {
        return (0, createChecksumStream_browser_1.createChecksumStream)(init);
      }
      return new ChecksumStream_1.ChecksumStream(init);
    }
    __name(createChecksumStream5, "createChecksumStream");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/ByteArrayCollector.js
var require_ByteArrayCollector8 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/ByteArrayCollector.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ByteArrayCollector = void 0;
    var ByteArrayCollector3 = class {
      static {
        __name(this, "ByteArrayCollector");
      }
      allocByteArray;
      byteLength = 0;
      byteArrays = [];
      constructor(allocByteArray) {
        this.allocByteArray = allocByteArray;
      }
      push(byteArray) {
        this.byteArrays.push(byteArray);
        this.byteLength += byteArray.byteLength;
      }
      flush() {
        if (this.byteArrays.length === 1) {
          const bytes = this.byteArrays[0];
          this.reset();
          return bytes;
        }
        const aggregation = this.allocByteArray(this.byteLength);
        let cursor3 = 0;
        for (let i32 = 0; i32 < this.byteArrays.length; ++i32) {
          const bytes = this.byteArrays[i32];
          aggregation.set(bytes, cursor3);
          cursor3 += bytes.byteLength;
        }
        this.reset();
        return aggregation;
      }
      reset() {
        this.byteArrays = [];
        this.byteLength = 0;
      }
    };
    exports2.ByteArrayCollector = ByteArrayCollector3;
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadableStream.js
var require_createBufferedReadableStream8 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadableStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createBufferedReadable = void 0;
    exports2.createBufferedReadableStream = createBufferedReadableStream3;
    exports2.merge = merge3;
    exports2.flush = flush3;
    exports2.sizeOf = sizeOf3;
    exports2.modeOf = modeOf3;
    var ByteArrayCollector_1 = require_ByteArrayCollector8();
    function createBufferedReadableStream3(upstream, size, logger5) {
      const reader = upstream.getReader();
      let streamBufferingLoggedWarning = false;
      let bytesSeen = 0;
      const buffers = ["", new ByteArrayCollector_1.ByteArrayCollector((size2) => new Uint8Array(size2))];
      let mode = -1;
      const pull = /* @__PURE__ */ __name(async (controller) => {
        const { value, done } = await reader.read();
        const chunk = value;
        if (done) {
          if (mode !== -1) {
            const remainder = flush3(buffers, mode);
            if (sizeOf3(remainder) > 0) {
              controller.enqueue(remainder);
            }
          }
          controller.close();
        } else {
          const chunkMode = modeOf3(chunk, false);
          if (mode !== chunkMode) {
            if (mode >= 0) {
              controller.enqueue(flush3(buffers, mode));
            }
            mode = chunkMode;
          }
          if (mode === -1) {
            controller.enqueue(chunk);
            return;
          }
          const chunkSize = sizeOf3(chunk);
          bytesSeen += chunkSize;
          const bufferSize = sizeOf3(buffers[mode]);
          if (chunkSize >= size && bufferSize === 0) {
            controller.enqueue(chunk);
          } else {
            const newSize = merge3(buffers, mode, chunk);
            if (!streamBufferingLoggedWarning && bytesSeen > size * 2) {
              streamBufferingLoggedWarning = true;
              logger5?.warn(`@smithy/util-stream - stream chunk size ${chunkSize} is below threshold of ${size}, automatically buffering.`);
            }
            if (newSize >= size) {
              controller.enqueue(flush3(buffers, mode));
            } else {
              await pull(controller);
            }
          }
        }
      }, "pull");
      return new ReadableStream({
        pull
      });
    }
    __name(createBufferedReadableStream3, "createBufferedReadableStream");
    exports2.createBufferedReadable = createBufferedReadableStream3;
    function merge3(buffers, mode, chunk) {
      switch (mode) {
        case 0:
          buffers[0] += chunk;
          return sizeOf3(buffers[0]);
        case 1:
        case 2:
          buffers[mode].push(chunk);
          return sizeOf3(buffers[mode]);
      }
    }
    __name(merge3, "merge");
    function flush3(buffers, mode) {
      switch (mode) {
        case 0:
          const s = buffers[0];
          buffers[0] = "";
          return s;
        case 1:
        case 2:
          return buffers[mode].flush();
      }
      throw new Error(`@smithy/util-stream - invalid index ${mode} given to flush()`);
    }
    __name(flush3, "flush");
    function sizeOf3(chunk) {
      return chunk?.byteLength ?? chunk?.length ?? 0;
    }
    __name(sizeOf3, "sizeOf");
    function modeOf3(chunk, allowBuffer = true) {
      if (allowBuffer && typeof Buffer !== "undefined" && chunk instanceof Buffer) {
        return 2;
      }
      if (chunk instanceof Uint8Array) {
        return 1;
      }
      if (typeof chunk === "string") {
        return 0;
      }
      return -1;
    }
    __name(modeOf3, "modeOf");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadable.js
var require_createBufferedReadable8 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadable.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createBufferedReadable = createBufferedReadable3;
    var node_stream_1 = require("node:stream");
    var ByteArrayCollector_1 = require_ByteArrayCollector8();
    var createBufferedReadableStream_1 = require_createBufferedReadableStream8();
    var stream_type_check_1 = require_stream_type_check8();
    function createBufferedReadable3(upstream, size, logger5) {
      if ((0, stream_type_check_1.isReadableStream)(upstream)) {
        return (0, createBufferedReadableStream_1.createBufferedReadableStream)(upstream, size, logger5);
      }
      const downstream = new node_stream_1.Readable({ read() {
      } });
      let streamBufferingLoggedWarning = false;
      let bytesSeen = 0;
      const buffers = [
        "",
        new ByteArrayCollector_1.ByteArrayCollector((size2) => new Uint8Array(size2)),
        new ByteArrayCollector_1.ByteArrayCollector((size2) => Buffer.from(new Uint8Array(size2)))
      ];
      let mode = -1;
      upstream.on("data", (chunk) => {
        const chunkMode = (0, createBufferedReadableStream_1.modeOf)(chunk, true);
        if (mode !== chunkMode) {
          if (mode >= 0) {
            downstream.push((0, createBufferedReadableStream_1.flush)(buffers, mode));
          }
          mode = chunkMode;
        }
        if (mode === -1) {
          downstream.push(chunk);
          return;
        }
        const chunkSize = (0, createBufferedReadableStream_1.sizeOf)(chunk);
        bytesSeen += chunkSize;
        const bufferSize = (0, createBufferedReadableStream_1.sizeOf)(buffers[mode]);
        if (chunkSize >= size && bufferSize === 0) {
          downstream.push(chunk);
        } else {
          const newSize = (0, createBufferedReadableStream_1.merge)(buffers, mode, chunk);
          if (!streamBufferingLoggedWarning && bytesSeen > size * 2) {
            streamBufferingLoggedWarning = true;
            logger5?.warn(`@smithy/util-stream - stream chunk size ${chunkSize} is below threshold of ${size}, automatically buffering.`);
          }
          if (newSize >= size) {
            downstream.push((0, createBufferedReadableStream_1.flush)(buffers, mode));
          }
        }
      });
      upstream.on("end", () => {
        if (mode !== -1) {
          const remainder = (0, createBufferedReadableStream_1.flush)(buffers, mode);
          if ((0, createBufferedReadableStream_1.sizeOf)(remainder) > 0) {
            downstream.push(remainder);
          }
        }
        downstream.push(null);
      });
      return downstream;
    }
    __name(createBufferedReadable3, "createBufferedReadable");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.browser.js
var require_getAwsChunkedEncodingStream_browser8 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getAwsChunkedEncodingStream = void 0;
    var getAwsChunkedEncodingStream5 = /* @__PURE__ */ __name((readableStream, options) => {
      const { base64Encoder, bodyLengthChecker, checksumAlgorithmFn, checksumLocationName, streamHasher } = options;
      const checksumRequired = base64Encoder !== void 0 && bodyLengthChecker !== void 0 && checksumAlgorithmFn !== void 0 && checksumLocationName !== void 0 && streamHasher !== void 0;
      const digest = checksumRequired ? streamHasher(checksumAlgorithmFn, readableStream) : void 0;
      const reader = readableStream.getReader();
      return new ReadableStream({
        async pull(controller) {
          const { value, done } = await reader.read();
          if (done) {
            controller.enqueue(`0\r
`);
            if (checksumRequired) {
              const checksum = base64Encoder(await digest);
              controller.enqueue(`${checksumLocationName}:${checksum}\r
`);
              controller.enqueue(`\r
`);
            }
            controller.close();
          } else {
            controller.enqueue(`${(bodyLengthChecker(value) || 0).toString(16)}\r
${value}\r
`);
          }
        }
      });
    }, "getAwsChunkedEncodingStream");
    exports2.getAwsChunkedEncodingStream = getAwsChunkedEncodingStream5;
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.js
var require_getAwsChunkedEncodingStream8 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getAwsChunkedEncodingStream = getAwsChunkedEncodingStream5;
    var node_stream_1 = require("node:stream");
    var getAwsChunkedEncodingStream_browser_1 = require_getAwsChunkedEncodingStream_browser8();
    var stream_type_check_1 = require_stream_type_check8();
    function getAwsChunkedEncodingStream5(stream, options) {
      const readable = stream;
      const readableStream = stream;
      if ((0, stream_type_check_1.isReadableStream)(readableStream)) {
        return (0, getAwsChunkedEncodingStream_browser_1.getAwsChunkedEncodingStream)(readableStream, options);
      }
      const { base64Encoder, bodyLengthChecker, checksumAlgorithmFn, checksumLocationName, streamHasher } = options;
      const checksumRequired = base64Encoder !== void 0 && checksumAlgorithmFn !== void 0 && checksumLocationName !== void 0 && streamHasher !== void 0;
      const digest = checksumRequired ? streamHasher(checksumAlgorithmFn, readable) : void 0;
      const awsChunkedEncodingStream = new node_stream_1.Readable({
        read: /* @__PURE__ */ __name(() => {
        }, "read")
      });
      readable.on("data", (data3) => {
        const length = bodyLengthChecker(data3) || 0;
        if (length === 0) {
          return;
        }
        awsChunkedEncodingStream.push(`${length.toString(16)}\r
`);
        awsChunkedEncodingStream.push(data3);
        awsChunkedEncodingStream.push("\r\n");
      });
      readable.on("end", async () => {
        awsChunkedEncodingStream.push(`0\r
`);
        if (checksumRequired) {
          const checksum = base64Encoder(await digest);
          awsChunkedEncodingStream.push(`${checksumLocationName}:${checksum}\r
`);
          awsChunkedEncodingStream.push(`\r
`);
        }
        awsChunkedEncodingStream.push(null);
      });
      return awsChunkedEncodingStream;
    }
    __name(getAwsChunkedEncodingStream5, "getAwsChunkedEncodingStream");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/headStream.browser.js
var require_headStream_browser8 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/headStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.headStream = headStream5;
    async function headStream5(stream, bytes) {
      let byteLengthCounter = 0;
      const chunks2 = [];
      const reader = stream.getReader();
      let isDone = false;
      while (!isDone) {
        const { done, value } = await reader.read();
        if (value) {
          chunks2.push(value);
          byteLengthCounter += value?.byteLength ?? 0;
        }
        if (byteLengthCounter >= bytes) {
          break;
        }
        isDone = done;
      }
      reader.releaseLock();
      const collected = new Uint8Array(Math.min(bytes, byteLengthCounter));
      let offset = 0;
      for (const chunk of chunks2) {
        if (chunk.byteLength > collected.byteLength - offset) {
          collected.set(chunk.subarray(0, collected.byteLength - offset), offset);
          break;
        } else {
          collected.set(chunk, offset);
        }
        offset += chunk.length;
      }
      return collected;
    }
    __name(headStream5, "headStream");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/headStream.js
var require_headStream8 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/headStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.headStream = void 0;
    var stream_1 = require("stream");
    var headStream_browser_1 = require_headStream_browser8();
    var stream_type_check_1 = require_stream_type_check8();
    var headStream5 = /* @__PURE__ */ __name((stream, bytes) => {
      if ((0, stream_type_check_1.isReadableStream)(stream)) {
        return (0, headStream_browser_1.headStream)(stream, bytes);
      }
      return new Promise((resolve13, reject) => {
        const collector = new Collector8();
        collector.limit = bytes;
        stream.pipe(collector);
        stream.on("error", (err) => {
          collector.end();
          reject(err);
        });
        collector.on("error", reject);
        collector.on("finish", function() {
          const bytes2 = new Uint8Array(Buffer.concat(this.buffers));
          resolve13(bytes2);
        });
      });
    }, "headStream");
    exports2.headStream = headStream5;
    var Collector8 = class extends stream_1.Writable {
      static {
        __name(this, "Collector");
      }
      buffers = [];
      limit = Infinity;
      bytesBuffered = 0;
      _write(chunk, encoding, callback) {
        this.buffers.push(chunk);
        this.bytesBuffered += chunk.byteLength ?? 0;
        if (this.bytesBuffered >= this.limit) {
          const excess = this.bytesBuffered - this.limit;
          const tailBuffer = this.buffers[this.buffers.length - 1];
          this.buffers[this.buffers.length - 1] = tailBuffer.subarray(0, tailBuffer.byteLength - excess);
          this.emit("finish");
        }
        callback();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.browser.js
var require_sdk_stream_mixin_browser8 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.sdkStreamMixin = void 0;
    var fetch_http_handler_1 = require_dist_cjs14();
    var util_base64_1 = require_dist_cjs10();
    var util_hex_encoding_1 = require_dist_cjs15();
    var util_utf8_1 = require_dist_cjs9();
    var stream_type_check_1 = require_stream_type_check8();
    var ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11 = "The stream has already been transformed.";
    var sdkStreamMixin12 = /* @__PURE__ */ __name((stream) => {
      if (!isBlobInstance6(stream) && !(0, stream_type_check_1.isReadableStream)(stream)) {
        const name = stream?.__proto__?.constructor?.name || stream;
        throw new Error(`Unexpected stream implementation, expect Blob or ReadableStream, got ${name}`);
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
        }
        transformed = true;
        return await (0, fetch_http_handler_1.streamCollector)(stream);
      }, "transformToByteArray");
      const blobToWebStream = /* @__PURE__ */ __name((blob) => {
        if (typeof blob.stream !== "function") {
          throw new Error("Cannot transform payload Blob to web stream. Please make sure the Blob.stream() is polyfilled.\nIf you are using React Native, this API is not yet supported, see: https://react-native.canny.io/feature-requests/p/fetch-streaming-body");
        }
        return blob.stream();
      }, "blobToWebStream");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === "base64") {
            return (0, util_base64_1.toBase64)(buf);
          } else if (encoding === "hex") {
            return (0, util_hex_encoding_1.toHex)(buf);
          } else if (encoding === void 0 || encoding === "utf8" || encoding === "utf-8") {
            return (0, util_utf8_1.toUtf8)(buf);
          } else if (typeof TextDecoder === "function") {
            return new TextDecoder(encoding).decode(buf);
          } else {
            throw new Error("TextDecoder is not available, please make sure polyfill is provided.");
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
          }
          transformed = true;
          if (isBlobInstance6(stream)) {
            return blobToWebStream(stream);
          } else if ((0, stream_type_check_1.isReadableStream)(stream)) {
            return stream;
          } else {
            throw new Error(`Cannot transform payload to web stream, got ${stream}`);
          }
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
    exports2.sdkStreamMixin = sdkStreamMixin12;
    var isBlobInstance6 = /* @__PURE__ */ __name((stream) => typeof Blob === "function" && stream instanceof Blob, "isBlobInstance");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.js
var require_sdk_stream_mixin8 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.sdkStreamMixin = void 0;
    var node_http_handler_1 = require_dist_cjs13();
    var util_buffer_from_1 = require_dist_cjs8();
    var stream_1 = require("stream");
    var sdk_stream_mixin_browser_1 = require_sdk_stream_mixin_browser8();
    var ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11 = "The stream has already been transformed.";
    var sdkStreamMixin12 = /* @__PURE__ */ __name((stream) => {
      if (!(stream instanceof stream_1.Readable)) {
        try {
          return (0, sdk_stream_mixin_browser_1.sdkStreamMixin)(stream);
        } catch (e32) {
          const name = stream?.__proto__?.constructor?.name || stream;
          throw new Error(`Unexpected stream implementation, expect Stream.Readable instance, got ${name}`);
        }
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
        }
        transformed = true;
        return await (0, node_http_handler_1.streamCollector)(stream);
      }, "transformToByteArray");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === void 0 || Buffer.isEncoding(encoding)) {
            return (0, util_buffer_from_1.fromArrayBuffer)(buf.buffer, buf.byteOffset, buf.byteLength).toString(encoding);
          } else {
            const decoder = new TextDecoder(encoding);
            return decoder.decode(buf);
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
          }
          if (stream.readableFlowing !== null) {
            throw new Error("The stream has been consumed by other callbacks.");
          }
          if (typeof stream_1.Readable.toWeb !== "function") {
            throw new Error("Readable.toWeb() is not supported. Please ensure a polyfill is available.");
          }
          transformed = true;
          return stream_1.Readable.toWeb(stream);
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
    exports2.sdkStreamMixin = sdkStreamMixin12;
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/splitStream.browser.js
var require_splitStream_browser8 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/splitStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.splitStream = splitStream5;
    async function splitStream5(stream) {
      if (typeof stream.stream === "function") {
        stream = stream.stream();
      }
      const readableStream = stream;
      return readableStream.tee();
    }
    __name(splitStream5, "splitStream");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/splitStream.js
var require_splitStream8 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/splitStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.splitStream = splitStream5;
    var stream_1 = require("stream");
    var splitStream_browser_1 = require_splitStream_browser8();
    var stream_type_check_1 = require_stream_type_check8();
    async function splitStream5(stream) {
      if ((0, stream_type_check_1.isReadableStream)(stream) || (0, stream_type_check_1.isBlob)(stream)) {
        return (0, splitStream_browser_1.splitStream)(stream);
      }
      const stream1 = new stream_1.PassThrough();
      const stream2 = new stream_1.PassThrough();
      stream.pipe(stream1);
      stream.pipe(stream2);
      return [stream1, stream2];
    }
    __name(splitStream5, "splitStream");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/index.js
var require_dist_cjs170 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@smithy/util-stream/dist-cjs/index.js"(exports2) {
    "use strict";
    var utilBase64 = require_dist_cjs10();
    var utilUtf8 = require_dist_cjs9();
    var ChecksumStream5 = require_ChecksumStream8();
    var createChecksumStream5 = require_createChecksumStream8();
    var createBufferedReadable3 = require_createBufferedReadable8();
    var getAwsChunkedEncodingStream5 = require_getAwsChunkedEncodingStream8();
    var headStream5 = require_headStream8();
    var sdkStreamMixin12 = require_sdk_stream_mixin8();
    var splitStream5 = require_splitStream8();
    var streamTypeCheck = require_stream_type_check8();
    var Uint8ArrayBlobAdapter8 = class _Uint8ArrayBlobAdapter extends Uint8Array {
      static {
        __name(this, "Uint8ArrayBlobAdapter");
      }
      static fromString(source, encoding = "utf-8") {
        if (typeof source === "string") {
          if (encoding === "base64") {
            return _Uint8ArrayBlobAdapter.mutate(utilBase64.fromBase64(source));
          }
          return _Uint8ArrayBlobAdapter.mutate(utilUtf8.fromUtf8(source));
        }
        throw new Error(`Unsupported conversion from ${typeof source} to Uint8ArrayBlobAdapter.`);
      }
      static mutate(source) {
        Object.setPrototypeOf(source, _Uint8ArrayBlobAdapter.prototype);
        return source;
      }
      transformToString(encoding = "utf-8") {
        if (encoding === "base64") {
          return utilBase64.toBase64(this);
        }
        return utilUtf8.toUtf8(this);
      }
    };
    exports2.isBlob = streamTypeCheck.isBlob;
    exports2.isReadableStream = streamTypeCheck.isReadableStream;
    exports2.Uint8ArrayBlobAdapter = Uint8ArrayBlobAdapter8;
    Object.prototype.hasOwnProperty.call(ChecksumStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: ChecksumStream5["__proto__"]
    });
    Object.keys(ChecksumStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = ChecksumStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(createChecksumStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: createChecksumStream5["__proto__"]
    });
    Object.keys(createChecksumStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = createChecksumStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(createBufferedReadable3, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: createBufferedReadable3["__proto__"]
    });
    Object.keys(createBufferedReadable3).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = createBufferedReadable3[k32];
    });
    Object.prototype.hasOwnProperty.call(getAwsChunkedEncodingStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: getAwsChunkedEncodingStream5["__proto__"]
    });
    Object.keys(getAwsChunkedEncodingStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = getAwsChunkedEncodingStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(headStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: headStream5["__proto__"]
    });
    Object.keys(headStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = headStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(sdkStreamMixin12, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: sdkStreamMixin12["__proto__"]
    });
    Object.keys(sdkStreamMixin12).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = sdkStreamMixin12[k32];
    });
    Object.prototype.hasOwnProperty.call(splitStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: splitStream5["__proto__"]
    });
    Object.keys(splitStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = splitStream5[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/requestHelpers.js
var require_requestHelpers7 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/requestHelpers.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createGetRequest = createGetRequest;
    exports2.getCredentials = getCredentials;
    var property_provider_1 = require_dist_cjs27();
    var protocol_http_1 = require_dist_cjs2();
    var smithy_client_1 = require_dist_cjs34();
    var util_stream_1 = require_dist_cjs170();
    function createGetRequest(url) {
      return new protocol_http_1.HttpRequest({
        protocol: url.protocol,
        hostname: url.hostname,
        port: Number(url.port),
        path: url.pathname,
        query: Array.from(url.searchParams.entries()).reduce((acc, [k32, v]) => {
          acc[k32] = v;
          return acc;
        }, {}),
        fragment: url.hash
      });
    }
    __name(createGetRequest, "createGetRequest");
    async function getCredentials(response, logger5) {
      const stream = (0, util_stream_1.sdkStreamMixin)(response.body);
      const str = await stream.transformToString();
      if (response.statusCode === 200) {
        const parsed = JSON.parse(str);
        if (typeof parsed.AccessKeyId !== "string" || typeof parsed.SecretAccessKey !== "string" || typeof parsed.Token !== "string" || typeof parsed.Expiration !== "string") {
          throw new property_provider_1.CredentialsProviderError("HTTP credential provider response not of the required format, an object matching: { AccessKeyId: string, SecretAccessKey: string, Token: string, Expiration: string(rfc3339) }", { logger: logger5 });
        }
        return {
          accessKeyId: parsed.AccessKeyId,
          secretAccessKey: parsed.SecretAccessKey,
          sessionToken: parsed.Token,
          expiration: (0, smithy_client_1.parseRfc3339DateTime)(parsed.Expiration)
        };
      }
      if (response.statusCode >= 400 && response.statusCode < 500) {
        let parsedBody = {};
        try {
          parsedBody = JSON.parse(str);
        } catch (e32) {
        }
        throw Object.assign(new property_provider_1.CredentialsProviderError(`Server responded with status: ${response.statusCode}`, { logger: logger5 }), {
          Code: parsedBody.Code,
          Message: parsedBody.Message
        });
      }
      throw new property_provider_1.CredentialsProviderError(`Server responded with status: ${response.statusCode}`, { logger: logger5 });
    }
    __name(getCredentials, "getCredentials");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/retry-wrapper.js
var require_retry_wrapper7 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/retry-wrapper.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.retryWrapper = void 0;
    var retryWrapper = /* @__PURE__ */ __name((toRetry, maxRetries, delayMs) => {
      return async () => {
        for (let i32 = 0; i32 < maxRetries; ++i32) {
          try {
            return await toRetry();
          } catch (e32) {
            await new Promise((resolve13) => setTimeout(resolve13, delayMs));
          }
        }
        return await toRetry();
      };
    }, "retryWrapper");
    exports2.retryWrapper = retryWrapper;
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/fromHttp.js
var require_fromHttp7 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/fromHttp.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromHttp = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var client_1 = (init_client17(), __toCommonJS(client_exports12));
    var node_http_handler_1 = require_dist_cjs13();
    var property_provider_1 = require_dist_cjs27();
    var promises_1 = tslib_1.__importDefault(require("node:fs/promises"));
    var checkUrl_1 = require_checkUrl7();
    var requestHelpers_1 = require_requestHelpers7();
    var retry_wrapper_1 = require_retry_wrapper7();
    var AWS_CONTAINER_CREDENTIALS_RELATIVE_URI = "AWS_CONTAINER_CREDENTIALS_RELATIVE_URI";
    var DEFAULT_LINK_LOCAL_HOST = "http://169.254.170.2";
    var AWS_CONTAINER_CREDENTIALS_FULL_URI = "AWS_CONTAINER_CREDENTIALS_FULL_URI";
    var AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE = "AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE";
    var AWS_CONTAINER_AUTHORIZATION_TOKEN = "AWS_CONTAINER_AUTHORIZATION_TOKEN";
    var fromHttp = /* @__PURE__ */ __name((options = {}) => {
      options.logger?.debug("@aws-sdk/credential-provider-http - fromHttp");
      let host;
      const relative5 = options.awsContainerCredentialsRelativeUri ?? process.env[AWS_CONTAINER_CREDENTIALS_RELATIVE_URI];
      const full = options.awsContainerCredentialsFullUri ?? process.env[AWS_CONTAINER_CREDENTIALS_FULL_URI];
      const token = options.awsContainerAuthorizationToken ?? process.env[AWS_CONTAINER_AUTHORIZATION_TOKEN];
      const tokenFile = options.awsContainerAuthorizationTokenFile ?? process.env[AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE];
      const warn2 = options.logger?.constructor?.name === "NoOpLogger" || !options.logger?.warn ? console.warn : options.logger.warn.bind(options.logger);
      if (relative5 && full) {
        warn2("@aws-sdk/credential-provider-http: you have set both awsContainerCredentialsRelativeUri and awsContainerCredentialsFullUri.");
        warn2("awsContainerCredentialsFullUri will take precedence.");
      }
      if (token && tokenFile) {
        warn2("@aws-sdk/credential-provider-http: you have set both awsContainerAuthorizationToken and awsContainerAuthorizationTokenFile.");
        warn2("awsContainerAuthorizationToken will take precedence.");
      }
      if (full) {
        host = full;
      } else if (relative5) {
        host = `${DEFAULT_LINK_LOCAL_HOST}${relative5}`;
      } else {
        throw new property_provider_1.CredentialsProviderError(`No HTTP credential provider host provided.
Set AWS_CONTAINER_CREDENTIALS_FULL_URI or AWS_CONTAINER_CREDENTIALS_RELATIVE_URI.`, { logger: options.logger });
      }
      const url = new URL(host);
      (0, checkUrl_1.checkUrl)(url, options.logger);
      const requestHandler = node_http_handler_1.NodeHttpHandler.create({
        requestTimeout: options.timeout ?? 1e3,
        connectionTimeout: options.timeout ?? 1e3
      });
      return (0, retry_wrapper_1.retryWrapper)(async () => {
        const request4 = (0, requestHelpers_1.createGetRequest)(url);
        if (token) {
          request4.headers.Authorization = token;
        } else if (tokenFile) {
          request4.headers.Authorization = (await promises_1.default.readFile(tokenFile)).toString();
        }
        try {
          const result2 = await requestHandler.handle(request4);
          return (0, requestHelpers_1.getCredentials)(result2.response).then((creds) => (0, client_1.setCredentialFeature)(creds, "CREDENTIALS_HTTP", "z"));
        } catch (e32) {
          throw new property_provider_1.CredentialsProviderError(String(e32), { logger: options.logger });
        }
      }, options.maxRetries ?? 3, options.timeout ?? 1e3);
    }, "fromHttp");
    exports2.fromHttp = fromHttp;
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-http/dist-cjs/index.js
var require_dist_cjs171 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-http/dist-cjs/index.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromHttp = void 0;
    var fromHttp_1 = require_fromHttp7();
    Object.defineProperty(exports2, "fromHttp", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return fromHttp_1.fromHttp;
    }, "get") });
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption23(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "awsssoportal",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption23(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var import_util_middleware24, defaultSSOHttpAuthSchemeParametersProvider7, defaultSSOHttpAuthSchemeProvider7, resolveHttpAuthSchemeConfig23;
var init_httpAuthSchemeProvider23 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes10();
    import_util_middleware24 = __toESM(require_dist_cjs6());
    defaultSSOHttpAuthSchemeParametersProvider7 = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, import_util_middleware24.getSmithyContext)(context).operation,
        region: await (0, import_util_middleware24.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultSSOHttpAuthSchemeParametersProvider");
    __name(createAwsAuthSigv4HttpAuthOption23, "createAwsAuthSigv4HttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption23, "createSmithyApiNoAuthHttpAuthOption");
    defaultSSOHttpAuthSchemeProvider7 = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "GetRoleCredentials": {
          options.push(createSmithyApiNoAuthHttpAuthOption23(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption23(authParameters));
        }
      }
      return options;
    }, "defaultSSOHttpAuthSchemeProvider");
    resolveHttpAuthSchemeConfig23 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveAwsSdkSigV4Config8(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, import_util_middleware24.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/EndpointParameters.js
var resolveClientEndpointParameters23, commonParams23;
var init_EndpointParameters23 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters23 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "awsssoportal"
      });
    }, "resolveClientEndpointParameters");
    commonParams23 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/package.json
var package_default8;
var init_package8 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/package.json"() {
    package_default8 = {
      name: "@aws-sdk/nested-clients",
      version: "3.997.6",
      description: "Nested clients for AWS SDK packages.",
      main: "./dist-cjs/index.js",
      module: "./dist-es/index.js",
      types: "./dist-types/index.d.ts",
      scripts: {
        build: "yarn lint && concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline nested-clients",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        lint: "node ../../scripts/validation/submodules-linter.js --pkg nested-clients",
        test: "yarn g:vitest run",
        "test:watch": "yarn g:vitest watch"
      },
      engines: {
        node: ">=20.0.0"
      },
      sideEffects: false,
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      dependencies: {
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.8",
        "@aws-sdk/middleware-host-header": "^3.972.10",
        "@aws-sdk/middleware-logger": "^3.972.10",
        "@aws-sdk/middleware-recursion-detection": "^3.972.11",
        "@aws-sdk/middleware-user-agent": "^3.972.38",
        "@aws-sdk/region-config-resolver": "^3.972.13",
        "@aws-sdk/signature-v4-multi-region": "^3.996.25",
        "@aws-sdk/types": "^3.973.8",
        "@aws-sdk/util-endpoints": "^3.996.8",
        "@aws-sdk/util-user-agent-browser": "^3.972.10",
        "@aws-sdk/util-user-agent-node": "^3.973.24",
        "@smithy/config-resolver": "^4.4.17",
        "@smithy/core": "^3.23.17",
        "@smithy/fetch-http-handler": "^5.3.17",
        "@smithy/hash-node": "^4.2.14",
        "@smithy/invalid-dependency": "^4.2.14",
        "@smithy/middleware-content-length": "^4.2.14",
        "@smithy/middleware-endpoint": "^4.4.32",
        "@smithy/middleware-retry": "^4.5.7",
        "@smithy/middleware-serde": "^4.2.20",
        "@smithy/middleware-stack": "^4.2.14",
        "@smithy/node-config-provider": "^4.3.14",
        "@smithy/node-http-handler": "^4.6.1",
        "@smithy/protocol-http": "^5.3.14",
        "@smithy/smithy-client": "^4.12.13",
        "@smithy/types": "^4.14.1",
        "@smithy/url-parser": "^4.2.14",
        "@smithy/util-base64": "^4.3.2",
        "@smithy/util-body-length-browser": "^4.2.2",
        "@smithy/util-body-length-node": "^4.2.3",
        "@smithy/util-defaults-mode-browser": "^4.3.49",
        "@smithy/util-defaults-mode-node": "^4.2.54",
        "@smithy/util-endpoints": "^3.4.2",
        "@smithy/util-middleware": "^4.2.14",
        "@smithy/util-retry": "^4.3.6",
        "@smithy/util-utf8": "^4.2.2",
        tslib: "^2.6.2"
      },
      devDependencies: {
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "./cognito-identity.d.ts",
        "./cognito-identity.js",
        "./signin.d.ts",
        "./signin.js",
        "./sso-oidc.d.ts",
        "./sso-oidc.js",
        "./sso.d.ts",
        "./sso.js",
        "./sts.d.ts",
        "./sts.js",
        "dist-*/**"
      ],
      browser: {
        "./dist-es/submodules/cognito-identity/runtimeConfig": "./dist-es/submodules/cognito-identity/runtimeConfig.browser",
        "./dist-es/submodules/signin/runtimeConfig": "./dist-es/submodules/signin/runtimeConfig.browser",
        "./dist-es/submodules/sso-oidc/runtimeConfig": "./dist-es/submodules/sso-oidc/runtimeConfig.browser",
        "./dist-es/submodules/sso/runtimeConfig": "./dist-es/submodules/sso/runtimeConfig.browser",
        "./dist-es/submodules/sts/runtimeConfig": "./dist-es/submodules/sts/runtimeConfig.browser"
      },
      "react-native": {},
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/packages/nested-clients",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "packages/nested-clients"
      },
      exports: {
        "./package.json": "./package.json",
        "./sso-oidc": {
          types: "./dist-types/submodules/sso-oidc/index.d.ts",
          module: "./dist-es/submodules/sso-oidc/index.js",
          node: "./dist-cjs/submodules/sso-oidc/index.js",
          import: "./dist-es/submodules/sso-oidc/index.js",
          require: "./dist-cjs/submodules/sso-oidc/index.js"
        },
        "./sts": {
          types: "./dist-types/submodules/sts/index.d.ts",
          module: "./dist-es/submodules/sts/index.js",
          node: "./dist-cjs/submodules/sts/index.js",
          import: "./dist-es/submodules/sts/index.js",
          require: "./dist-cjs/submodules/sts/index.js"
        },
        "./signin": {
          types: "./dist-types/submodules/signin/index.d.ts",
          module: "./dist-es/submodules/signin/index.js",
          node: "./dist-cjs/submodules/signin/index.js",
          import: "./dist-es/submodules/signin/index.js",
          require: "./dist-cjs/submodules/signin/index.js"
        },
        "./cognito-identity": {
          types: "./dist-types/submodules/cognito-identity/index.d.ts",
          module: "./dist-es/submodules/cognito-identity/index.js",
          node: "./dist-cjs/submodules/cognito-identity/index.js",
          import: "./dist-es/submodules/cognito-identity/index.js",
          require: "./dist-cjs/submodules/cognito-identity/index.js"
        },
        "./sso": {
          types: "./dist-types/submodules/sso/index.d.ts",
          module: "./dist-es/submodules/sso/index.js",
          node: "./dist-cjs/submodules/sso/index.js",
          import: "./dist-es/submodules/sso/index.js",
          require: "./dist-cjs/submodules/sso/index.js"
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/util-user-agent-node/dist-cjs/index.js
var require_dist_cjs172 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/util-user-agent-node/dist-cjs/index.js"(exports2) {
    "use strict";
    var node_os = require("node:os");
    var node_process = require("node:process");
    var utilConfigProvider = require_dist_cjs24();
    var promises5 = require("node:fs/promises");
    var node_path = require("node:path");
    var middlewareUserAgent = require_dist_cjs167();
    var getRuntimeUserAgentPair2 = /* @__PURE__ */ __name(() => {
      const runtimesToCheck = ["deno", "bun", "llrt"];
      for (const runtime of runtimesToCheck) {
        if (node_process.versions[runtime]) {
          return [`md/${runtime}`, node_process.versions[runtime]];
        }
      }
      return ["md/nodejs", node_process.versions.node];
    }, "getRuntimeUserAgentPair");
    var getNodeModulesParentDirs2 = /* @__PURE__ */ __name((dirname14) => {
      const cwd = process.cwd();
      if (!dirname14) {
        return [cwd];
      }
      const normalizedPath = node_path.normalize(dirname14);
      const parts = normalizedPath.split(node_path.sep);
      const nodeModulesIndex = parts.indexOf("node_modules");
      const parentDir = nodeModulesIndex !== -1 ? parts.slice(0, nodeModulesIndex).join(node_path.sep) : normalizedPath;
      if (cwd === parentDir) {
        return [cwd];
      }
      return [parentDir, cwd];
    }, "getNodeModulesParentDirs");
    var SEMVER_REGEX2 = /^(0|[1-9]\d*)\.(0|[1-9]\d*)\.(0|[1-9]\d*)(?:-((?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*)(?:\.(?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*))*))?(?:\+[0-9a-zA-Z-]+(?:\.[0-9a-zA-Z-]+)*)?$/;
    var getSanitizedTypeScriptVersion2 = /* @__PURE__ */ __name((version = "") => {
      const match = version.match(SEMVER_REGEX2);
      if (!match) {
        return void 0;
      }
      const [major6, minor, patch, prerelease] = [match[1], match[2], match[3], match[4]];
      return prerelease ? `${major6}.${minor}.${patch}-${prerelease}` : `${major6}.${minor}.${patch}`;
    }, "getSanitizedTypeScriptVersion");
    var ALLOWED_PREFIXES2 = ["^", "~", ">=", "<=", ">", "<"];
    var ALLOWED_DIST_TAGS2 = ["latest", "beta", "dev", "rc", "insiders", "next"];
    var getSanitizedDevTypeScriptVersion2 = /* @__PURE__ */ __name((version = "") => {
      if (ALLOWED_DIST_TAGS2.includes(version)) {
        return version;
      }
      const prefix = ALLOWED_PREFIXES2.find((p10) => version.startsWith(p10)) ?? "";
      const sanitizedTypeScriptVersion = getSanitizedTypeScriptVersion2(version.slice(prefix.length));
      if (!sanitizedTypeScriptVersion) {
        return void 0;
      }
      return `${prefix}${sanitizedTypeScriptVersion}`;
    }, "getSanitizedDevTypeScriptVersion");
    var tscVersion2;
    var TS_PACKAGE_JSON2 = node_path.join("node_modules", "typescript", "package.json");
    var getTypeScriptUserAgentPair2 = /* @__PURE__ */ __name(async () => {
      if (tscVersion2 === null) {
        return void 0;
      } else if (typeof tscVersion2 === "string") {
        return ["md/tsc", tscVersion2];
      }
      let isTypeScriptDetectionDisabled = false;
      try {
        isTypeScriptDetectionDisabled = utilConfigProvider.booleanSelector(process.env, "AWS_SDK_JS_TYPESCRIPT_DETECTION_DISABLED", utilConfigProvider.SelectorType.ENV) || false;
      } catch {
      }
      if (isTypeScriptDetectionDisabled) {
        tscVersion2 = null;
        return void 0;
      }
      const dirname14 = typeof __dirname !== "undefined" ? __dirname : void 0;
      const nodeModulesParentDirs = getNodeModulesParentDirs2(dirname14);
      let versionFromApp;
      for (const nodeModulesParentDir of nodeModulesParentDirs) {
        try {
          const appPackageJsonPath = node_path.join(nodeModulesParentDir, "package.json");
          const packageJson = await promises5.readFile(appPackageJsonPath, "utf-8");
          const { dependencies, devDependencies } = JSON.parse(packageJson);
          const version = devDependencies?.typescript ?? dependencies?.typescript;
          if (typeof version !== "string") {
            continue;
          }
          versionFromApp = version;
          break;
        } catch {
        }
      }
      if (!versionFromApp) {
        tscVersion2 = null;
        return void 0;
      }
      let versionFromNodeModules;
      for (const nodeModulesParentDir of nodeModulesParentDirs) {
        try {
          const tsPackageJsonPath = node_path.join(nodeModulesParentDir, TS_PACKAGE_JSON2);
          const packageJson = await promises5.readFile(tsPackageJsonPath, "utf-8");
          const { version } = JSON.parse(packageJson);
          const sanitizedVersion2 = getSanitizedTypeScriptVersion2(version);
          if (typeof sanitizedVersion2 !== "string") {
            continue;
          }
          versionFromNodeModules = sanitizedVersion2;
          break;
        } catch {
        }
      }
      if (versionFromNodeModules) {
        tscVersion2 = versionFromNodeModules;
        return ["md/tsc", tscVersion2];
      }
      const sanitizedVersion = getSanitizedDevTypeScriptVersion2(versionFromApp);
      if (typeof sanitizedVersion !== "string") {
        tscVersion2 = null;
        return void 0;
      }
      tscVersion2 = `dev_${sanitizedVersion}`;
      return ["md/tsc", tscVersion2];
    }, "getTypeScriptUserAgentPair");
    var crtAvailability2 = {
      isCrtAvailable: false
    };
    var isCrtAvailable2 = /* @__PURE__ */ __name(() => {
      if (crtAvailability2.isCrtAvailable) {
        return ["md/crt-avail"];
      }
      return null;
    }, "isCrtAvailable");
    var createDefaultUserAgentProvider29 = /* @__PURE__ */ __name(({ serviceId, clientVersion }) => {
      const runtimeUserAgentPair = getRuntimeUserAgentPair2();
      return async (config2) => {
        const sections = [
          ["aws-sdk-js", clientVersion],
          ["ua", "2.1"],
          [`os/${node_os.platform()}`, node_os.release()],
          ["lang/js"],
          runtimeUserAgentPair
        ];
        const typescriptUserAgentPair = await getTypeScriptUserAgentPair2();
        if (typescriptUserAgentPair) {
          sections.push(typescriptUserAgentPair);
        }
        const crtAvailable = isCrtAvailable2();
        if (crtAvailable) {
          sections.push(crtAvailable);
        }
        if (serviceId) {
          sections.push([`api/${serviceId}`, clientVersion]);
        }
        if (node_process.env.AWS_EXECUTION_ENV) {
          sections.push([`exec-env/${node_process.env.AWS_EXECUTION_ENV}`]);
        }
        const appId = await config2?.userAgentAppId?.();
        const resolvedUserAgent = appId ? [...sections, [`app/${appId}`]] : [...sections];
        return resolvedUserAgent;
      };
    }, "createDefaultUserAgentProvider");
    var defaultUserAgent2 = createDefaultUserAgentProvider29;
    var UA_APP_ID_ENV_NAME2 = "AWS_SDK_UA_APP_ID";
    var UA_APP_ID_INI_NAME2 = "sdk_ua_app_id";
    var UA_APP_ID_INI_NAME_DEPRECATED2 = "sdk-ua-app-id";
    var NODE_APP_ID_CONFIG_OPTIONS29 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[UA_APP_ID_ENV_NAME2], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[UA_APP_ID_INI_NAME2] ?? profile[UA_APP_ID_INI_NAME_DEPRECATED2], "configFileSelector"),
      default: middlewareUserAgent.DEFAULT_UA_APP_ID
    };
    exports2.NODE_APP_ID_CONFIG_OPTIONS = NODE_APP_ID_CONFIG_OPTIONS29;
    exports2.UA_APP_ID_ENV_NAME = UA_APP_ID_ENV_NAME2;
    exports2.UA_APP_ID_INI_NAME = UA_APP_ID_INI_NAME2;
    exports2.createDefaultUserAgentProvider = createDefaultUserAgentProvider29;
    exports2.crtAvailability = crtAvailability2;
    exports2.defaultUserAgent = defaultUserAgent2;
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ProtocolLib.js
var import_smithy_client174, ProtocolLib9;
var init_ProtocolLib9 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ProtocolLib.js"() {
    init_schema4();
    import_smithy_client174 = __toESM(require_dist_cjs34());
    ProtocolLib9 = class {
      static {
        __name(this, "ProtocolLib");
      }
      queryCompat;
      errorRegistry;
      constructor(queryCompat = false) {
        this.queryCompat = queryCompat;
      }
      resolveRestContentType(defaultContentType, inputSchema) {
        const members = inputSchema.getMemberSchemas();
        const httpPayloadMember = Object.values(members).find((m20) => {
          return !!m20.getMergedTraits().httpPayload;
        });
        if (httpPayloadMember) {
          const mediaType = httpPayloadMember.getMergedTraits().mediaType;
          if (mediaType) {
            return mediaType;
          } else if (httpPayloadMember.isStringSchema()) {
            return "text/plain";
          } else if (httpPayloadMember.isBlobSchema()) {
            return "application/octet-stream";
          } else {
            return defaultContentType;
          }
        } else if (!inputSchema.isUnitSchema()) {
          const hasBody = Object.values(members).find((m20) => {
            const { httpQuery, httpQueryParams, httpHeader, httpLabel, httpPrefixHeaders } = m20.getMergedTraits();
            const noPrefixHeaders = httpPrefixHeaders === void 0;
            return !httpQuery && !httpQueryParams && !httpHeader && !httpLabel && noPrefixHeaders;
          });
          if (hasBody) {
            return defaultContentType;
          }
        }
      }
      async getErrorSchemaOrThrowBaseException(errorIdentifier, defaultNamespace, response, dataObject, metadata, getErrorSchema) {
        let errorName = errorIdentifier;
        if (errorIdentifier.includes("#")) {
          [, errorName] = errorIdentifier.split("#");
        }
        const errorMetadata = {
          $metadata: metadata,
          $fault: response.statusCode < 500 ? "client" : "server"
        };
        if (!this.errorRegistry) {
          throw new Error("@aws-sdk/core/protocols - error handler not initialized.");
        }
        try {
          const errorSchema = getErrorSchema?.(this.errorRegistry, errorName) ?? this.errorRegistry.getSchema(errorIdentifier);
          return { errorSchema, errorMetadata };
        } catch (e32) {
          dataObject.message = dataObject.message ?? dataObject.Message ?? "UnknownError";
          const synthetic = this.errorRegistry;
          const baseExceptionSchema = synthetic.getBaseException();
          if (baseExceptionSchema) {
            const ErrorCtor = synthetic.getErrorCtor(baseExceptionSchema) ?? Error;
            throw this.decorateServiceException(Object.assign(new ErrorCtor({ name: errorName }), errorMetadata), dataObject);
          }
          const d32 = dataObject;
          const message2 = d32?.message ?? d32?.Message ?? d32?.Error?.Message ?? d32?.Error?.message;
          throw this.decorateServiceException(Object.assign(new Error(message2), {
            name: errorName
          }, errorMetadata), dataObject);
        }
      }
      compose(composite, errorIdentifier, defaultNamespace) {
        let namespace = defaultNamespace;
        if (errorIdentifier.includes("#")) {
          [namespace] = errorIdentifier.split("#");
        }
        const staticRegistry = TypeRegistry.for(namespace);
        const defaultSyntheticRegistry = TypeRegistry.for("smithy.ts.sdk.synthetic." + defaultNamespace);
        composite.copyFrom(staticRegistry);
        composite.copyFrom(defaultSyntheticRegistry);
        this.errorRegistry = composite;
      }
      decorateServiceException(exception, additions = {}) {
        if (this.queryCompat) {
          const msg = exception.Message ?? additions.Message;
          const error4 = (0, import_smithy_client174.decorateServiceException)(exception, additions);
          if (msg) {
            error4.message = msg;
          }
          const errorObj = error4.Error ?? {};
          errorObj.Type = error4.Error?.Type;
          errorObj.Code = error4.Error?.Code;
          errorObj.Message = error4.Error?.message ?? error4.Error?.Message ?? msg;
          error4.Error = errorObj;
          const reqId = error4.$metadata.requestId;
          if (reqId) {
            error4.RequestId = reqId;
          }
          return error4;
        }
        return (0, import_smithy_client174.decorateServiceException)(exception, additions);
      }
      setQueryCompatError(output, response) {
        const queryErrorHeader = response.headers?.["x-amzn-query-error"];
        if (output !== void 0 && queryErrorHeader != null) {
          const [Code, Type] = queryErrorHeader.split(";");
          const keys = Object.keys(output);
          const Error2 = {
            Code,
            Type
          };
          output.Code = Code;
          output.Type = Type;
          for (let i32 = 0; i32 < keys.length; i32++) {
            const k32 = keys[i32];
            Error2[k32 === "message" ? "Message" : k32] = output[k32];
          }
          delete Error2.__type;
          output.Error = Error2;
        }
      }
      queryCompatOutput(queryCompatErrorData, errorData) {
        if (queryCompatErrorData.Error) {
          errorData.Error = queryCompatErrorData.Error;
        }
        if (queryCompatErrorData.Type) {
          errorData.Type = queryCompatErrorData.Type;
        }
        if (queryCompatErrorData.Code) {
          errorData.Code = queryCompatErrorData.Code;
        }
      }
      findQueryCompatibleError(registry, errorName) {
        try {
          return registry.getSchema(errorName);
        } catch (e32) {
          return registry.find((schema) => NormalizedSchema.of(schema).getMergedTraits().awsQueryError?.[0] === errorName);
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/cbor/AwsSmithyRpcV2CborProtocol.js
var AwsSmithyRpcV2CborProtocol7;
var init_AwsSmithyRpcV2CborProtocol9 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/cbor/AwsSmithyRpcV2CborProtocol.js"() {
    init_cbor2();
    init_schema4();
    init_ProtocolLib9();
    AwsSmithyRpcV2CborProtocol7 = class extends SmithyRpcV2CborProtocol {
      static {
        __name(this, "AwsSmithyRpcV2CborProtocol");
      }
      awsQueryCompatible;
      mixin;
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, awsQueryCompatible }) {
        super({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32 });
        this.awsQueryCompatible = !!awsQueryCompatible;
        this.mixin = new ProtocolLib9(this.awsQueryCompatible);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        if (this.awsQueryCompatible) {
          request4.headers["x-amzn-query-mode"] = "true";
        }
        return request4;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        if (this.awsQueryCompatible) {
          this.mixin.setQueryCompatError(dataObject, response);
        }
        const errorName = (() => {
          const compatHeader = response.headers["x-amzn-query-error"];
          if (compatHeader && this.awsQueryCompatible) {
            return compatHeader.split(";")[0];
          }
          return loadSmithyRpcV2CborErrorCode(response, dataObject) ?? "Unknown";
        })();
        this.mixin.compose(this.compositeErrorRegistry, errorName, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorName, this.options.defaultNamespace, response, dataObject, metadata, this.awsQueryCompatible ? this.mixin.findQueryCompatibleError : void 0);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        const output = {};
        for (const [name, member7] of ns.structIterator()) {
          if (dataObject[name] != null) {
            output[name] = this.deserializer.readValue(member7, dataObject[name]);
          }
        }
        if (this.awsQueryCompatible) {
          this.mixin.queryCompatOutput(dataObject, output);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/coercing-serializers.js
var _toStr7, _toBool7, _toNum7;
var init_coercing_serializers9 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/coercing-serializers.js"() {
    _toStr7 = /* @__PURE__ */ __name((val) => {
      if (val == null) {
        return val;
      }
      if (typeof val === "number" || typeof val === "bigint") {
        const warning2 = new Error(`Received number ${val} where a string was expected.`);
        warning2.name = "Warning";
        console.warn(warning2);
        return String(val);
      }
      if (typeof val === "boolean") {
        const warning2 = new Error(`Received boolean ${val} where a string was expected.`);
        warning2.name = "Warning";
        console.warn(warning2);
        return String(val);
      }
      return val;
    }, "_toStr");
    _toBool7 = /* @__PURE__ */ __name((val) => {
      if (val == null) {
        return val;
      }
      if (typeof val === "number") {
      }
      if (typeof val === "string") {
        const lowercase = val.toLowerCase();
        if (val !== "" && lowercase !== "false" && lowercase !== "true") {
          const warning2 = new Error(`Received string "${val}" where a boolean was expected.`);
          warning2.name = "Warning";
          console.warn(warning2);
        }
        return val !== "" && lowercase !== "false";
      }
      return val;
    }, "_toBool");
    _toNum7 = /* @__PURE__ */ __name((val) => {
      if (val == null) {
        return val;
      }
      if (typeof val === "boolean") {
      }
      if (typeof val === "string") {
        const num = Number(val);
        if (num.toString() !== val) {
          const warning2 = new Error(`Received string "${val}" where a number was expected.`);
          warning2.name = "Warning";
          console.warn(warning2);
          return val;
        }
        return num;
      }
      return val;
    }, "_toNum");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ConfigurableSerdeContext.js
var SerdeContextConfig9;
var init_ConfigurableSerdeContext9 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ConfigurableSerdeContext.js"() {
    SerdeContextConfig9 = class {
      static {
        __name(this, "SerdeContextConfig");
      }
      serdeContext;
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/UnionSerde.js
var UnionSerde9;
var init_UnionSerde9 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/UnionSerde.js"() {
    UnionSerde9 = class {
      static {
        __name(this, "UnionSerde");
      }
      from;
      to;
      keys;
      constructor(from, to) {
        this.from = from;
        this.to = to;
        const keys = Object.keys(this.from);
        const set = new Set(keys);
        set.delete("__type");
        this.keys = set;
      }
      mark(key) {
        this.keys.delete(key);
      }
      hasUnknown() {
        return this.keys.size === 1 && Object.keys(this.to).length === 0;
      }
      writeUnknown() {
        if (this.hasUnknown()) {
          const k32 = this.keys.values().next().value;
          const v = this.from[k32];
          this.to.$unknown = [k32, v];
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReviver.js
function jsonReviver9(key, value, context) {
  if (context?.source) {
    const numericString = context.source;
    if (typeof value === "number") {
      if (value > Number.MAX_SAFE_INTEGER || value < Number.MIN_SAFE_INTEGER || numericString !== String(value)) {
        const isFractional = numericString.includes(".");
        if (isFractional) {
          return new NumericValue(numericString, "bigDecimal");
        } else {
          return BigInt(numericString);
        }
      }
    }
  }
  return value;
}
var init_jsonReviver9 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReviver.js"() {
    init_serde();
    __name(jsonReviver9, "jsonReviver");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/common.js
var import_smithy_client175, import_util_utf837, collectBodyString9;
var init_common11 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/common.js"() {
    import_smithy_client175 = __toESM(require_dist_cjs34());
    import_util_utf837 = __toESM(require_dist_cjs9());
    collectBodyString9 = /* @__PURE__ */ __name((streamBody, context) => (0, import_smithy_client175.collectBody)(streamBody, context).then((body) => (context?.utf8Encoder ?? import_util_utf837.toUtf8)(body)), "collectBodyString");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/parseJsonBody.js
var parseJsonBody9, parseJsonErrorBody7, findKey9, sanitizeErrorCode9, loadRestJsonErrorCode9;
var init_parseJsonBody9 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/parseJsonBody.js"() {
    init_common11();
    parseJsonBody9 = /* @__PURE__ */ __name((streamBody, context) => collectBodyString9(streamBody, context).then((encoded) => {
      if (encoded.length) {
        try {
          return JSON.parse(encoded);
        } catch (e32) {
          if (e32?.name === "SyntaxError") {
            Object.defineProperty(e32, "$responseBodyText", {
              value: encoded
            });
          }
          throw e32;
        }
      }
      return {};
    }), "parseJsonBody");
    parseJsonErrorBody7 = /* @__PURE__ */ __name(async (errorBody, context) => {
      const value = await parseJsonBody9(errorBody, context);
      value.message = value.message ?? value.Message;
      return value;
    }, "parseJsonErrorBody");
    findKey9 = /* @__PURE__ */ __name((object, key) => Object.keys(object).find((k32) => k32.toLowerCase() === key.toLowerCase()), "findKey");
    sanitizeErrorCode9 = /* @__PURE__ */ __name((rawValue) => {
      let cleanValue = rawValue;
      if (typeof cleanValue === "number") {
        cleanValue = cleanValue.toString();
      }
      if (cleanValue.indexOf(",") >= 0) {
        cleanValue = cleanValue.split(",")[0];
      }
      if (cleanValue.indexOf(":") >= 0) {
        cleanValue = cleanValue.split(":")[0];
      }
      if (cleanValue.indexOf("#") >= 0) {
        cleanValue = cleanValue.split("#")[1];
      }
      return cleanValue;
    }, "sanitizeErrorCode");
    loadRestJsonErrorCode9 = /* @__PURE__ */ __name((output, data3) => {
      const headerKey = findKey9(output.headers, "x-amzn-errortype");
      if (headerKey !== void 0) {
        return sanitizeErrorCode9(output.headers[headerKey]);
      }
      if (data3 && typeof data3 === "object") {
        const codeKey = findKey9(data3, "code");
        if (codeKey && data3[codeKey] !== void 0) {
          return sanitizeErrorCode9(data3[codeKey]);
        }
        if (data3["__type"] !== void 0) {
          return sanitizeErrorCode9(data3["__type"]);
        }
      }
    }, "loadRestJsonErrorCode");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeDeserializer.js
var import_util_base6447, JsonShapeDeserializer9;
var init_JsonShapeDeserializer9 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeDeserializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_util_base6447 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext9();
    init_UnionSerde9();
    init_jsonReviver9();
    init_parseJsonBody9();
    JsonShapeDeserializer9 = class extends SerdeContextConfig9 {
      static {
        __name(this, "JsonShapeDeserializer");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      async read(schema, data3) {
        return this._read(schema, typeof data3 === "string" ? JSON.parse(data3, jsonReviver9) : await parseJsonBody9(data3, this.serdeContext));
      }
      readObject(schema, data3) {
        return this._read(schema, data3);
      }
      _read(schema, value) {
        const isObject3 = value !== null && typeof value === "object";
        const ns = NormalizedSchema.of(schema);
        if (isObject3) {
          if (ns.isStructSchema()) {
            const record = value;
            const union = ns.isUnionSchema();
            const out = {};
            let nameMap = void 0;
            const { jsonName } = this.settings;
            if (jsonName) {
              nameMap = {};
            }
            let unionSerde;
            if (union) {
              unionSerde = new UnionSerde9(record, out);
            }
            for (const [memberName, memberSchema] of ns.structIterator()) {
              let fromKey = memberName;
              if (jsonName) {
                fromKey = memberSchema.getMergedTraits().jsonName ?? fromKey;
                nameMap[fromKey] = memberName;
              }
              if (union) {
                unionSerde.mark(fromKey);
              }
              if (record[fromKey] != null) {
                out[memberName] = this._read(memberSchema, record[fromKey]);
              }
            }
            if (union) {
              unionSerde.writeUnknown();
            } else if (typeof record.__type === "string") {
              for (const k32 in record) {
                const v = record[k32];
                const t = jsonName ? nameMap[k32] ?? k32 : k32;
                if (!(t in out)) {
                  out[t] = v;
                }
              }
            }
            return out;
          }
          if (Array.isArray(value) && ns.isListSchema()) {
            const listMember = ns.getValueSchema();
            const out = [];
            for (const item of value) {
              out.push(this._read(listMember, item));
            }
            return out;
          }
          if (ns.isMapSchema()) {
            const mapMember = ns.getValueSchema();
            const out = {};
            for (const _k in value) {
              out[_k] = this._read(mapMember, value[_k]);
            }
            return out;
          }
        }
        if (ns.isBlobSchema() && typeof value === "string") {
          return (0, import_util_base6447.fromBase64)(value);
        }
        const mediaType = ns.getMergedTraits().mediaType;
        if (ns.isStringSchema() && typeof value === "string" && mediaType) {
          const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
          if (isJson) {
            return LazyJsonString.from(value);
          }
          return value;
        }
        if (ns.isTimestampSchema() && value != null) {
          const format32 = determineTimestampFormat(ns, this.settings);
          switch (format32) {
            case 5:
              return parseRfc3339DateTimeWithOffset(value);
            case 6:
              return parseRfc7231DateTime(value);
            case 7:
              return parseEpochTimestamp(value);
            default:
              console.warn("Missing timestamp format, parsing value with Date constructor:", value);
              return new Date(value);
          }
        }
        if (ns.isBigIntegerSchema() && (typeof value === "number" || typeof value === "string")) {
          return BigInt(value);
        }
        if (ns.isBigDecimalSchema() && value != void 0) {
          if (value instanceof NumericValue) {
            return value;
          }
          const untyped = value;
          if (untyped.type === "bigDecimal" && "string" in untyped) {
            return new NumericValue(untyped.string, untyped.type);
          }
          return new NumericValue(String(value), "bigDecimal");
        }
        if (ns.isNumericSchema() && typeof value === "string") {
          switch (value) {
            case "Infinity":
              return Infinity;
            case "-Infinity":
              return -Infinity;
            case "NaN":
              return NaN;
          }
          return value;
        }
        if (ns.isDocumentSchema()) {
          if (isObject3) {
            const out = Array.isArray(value) ? [] : {};
            for (const k32 in value) {
              const v = value[k32];
              if (v instanceof NumericValue) {
                out[k32] = v;
              } else {
                out[k32] = this._read(ns, v);
              }
            }
            return out;
          } else {
            return structuredClone(value);
          }
        }
        return value;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReplacer.js
var NUMERIC_CONTROL_CHAR9, JsonReplacer9;
var init_jsonReplacer9 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReplacer.js"() {
    init_serde();
    NUMERIC_CONTROL_CHAR9 = String.fromCharCode(925);
    JsonReplacer9 = class {
      static {
        __name(this, "JsonReplacer");
      }
      values = /* @__PURE__ */ new Map();
      counter = 0;
      stage = 0;
      createReplacer() {
        if (this.stage === 1) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer already created.");
        }
        if (this.stage === 2) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer exhausted.");
        }
        this.stage = 1;
        return (key, value) => {
          if (value instanceof NumericValue) {
            const v = `${NUMERIC_CONTROL_CHAR9 + "nv" + this.counter++}_` + value.string;
            this.values.set(`"${v}"`, value.string);
            return v;
          }
          if (typeof value === "bigint") {
            const s = value.toString();
            const v = `${NUMERIC_CONTROL_CHAR9 + "b" + this.counter++}_` + s;
            this.values.set(`"${v}"`, s);
            return v;
          }
          return value;
        };
      }
      replaceInJson(json) {
        if (this.stage === 0) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer not created yet.");
        }
        if (this.stage === 2) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer exhausted.");
        }
        this.stage = 2;
        if (this.counter === 0) {
          return json;
        }
        for (const [key, value] of this.values) {
          json = json.replace(key, value);
        }
        return json;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeSerializer.js
var import_util_base6448, JsonShapeSerializer9;
var init_JsonShapeSerializer9 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeSerializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_util_base6448 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext9();
    init_jsonReplacer9();
    JsonShapeSerializer9 = class extends SerdeContextConfig9 {
      static {
        __name(this, "JsonShapeSerializer");
      }
      settings;
      buffer;
      useReplacer = false;
      rootSchema;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value) {
        this.rootSchema = NormalizedSchema.of(schema);
        this.buffer = this._write(this.rootSchema, value);
      }
      flush() {
        const { rootSchema, useReplacer } = this;
        this.rootSchema = void 0;
        this.useReplacer = false;
        if (rootSchema?.isStructSchema() || rootSchema?.isDocumentSchema()) {
          if (!useReplacer) {
            return JSON.stringify(this.buffer);
          }
          const replacer = new JsonReplacer9();
          return replacer.replaceInJson(JSON.stringify(this.buffer, replacer.createReplacer(), 0));
        }
        return this.buffer;
      }
      writeDiscriminatedDocument(schema, value) {
        this.write(schema, value);
        if (typeof this.buffer === "object") {
          this.buffer.__type = NormalizedSchema.of(schema).getName(true);
        }
      }
      _write(schema, value, container) {
        const isObject3 = value !== null && typeof value === "object";
        const ns = NormalizedSchema.of(schema);
        if (isObject3) {
          if (ns.isStructSchema()) {
            const record = value;
            const out = {};
            const { jsonName } = this.settings;
            let nameMap = void 0;
            if (jsonName) {
              nameMap = {};
            }
            let outCount = 0;
            for (const [memberName, memberSchema] of ns.structIterator()) {
              const serializableValue = this._write(memberSchema, record[memberName], ns);
              if (serializableValue !== void 0) {
                let targetKey = memberName;
                if (jsonName) {
                  targetKey = memberSchema.getMergedTraits().jsonName ?? memberName;
                  nameMap[memberName] = targetKey;
                }
                out[targetKey] = serializableValue;
                outCount++;
              }
            }
            if (ns.isUnionSchema() && outCount === 0) {
              const { $unknown } = record;
              if (Array.isArray($unknown)) {
                const [k32, v] = $unknown;
                out[k32] = this._write(15, v);
              }
            } else if (typeof record.__type === "string") {
              for (const k32 in record) {
                const v = record[k32];
                const targetKey = jsonName ? nameMap[k32] ?? k32 : k32;
                if (!(targetKey in out)) {
                  out[targetKey] = this._write(15, v);
                }
              }
            }
            return out;
          }
          if (Array.isArray(value) && ns.isListSchema()) {
            const listMember = ns.getValueSchema();
            const out = [];
            const sparse = !!ns.getMergedTraits().sparse;
            for (const item of value) {
              if (sparse || item != null) {
                out.push(this._write(listMember, item));
              }
            }
            return out;
          }
          if (ns.isMapSchema()) {
            const mapMember = ns.getValueSchema();
            const out = {};
            const sparse = !!ns.getMergedTraits().sparse;
            for (const _k in value) {
              const _v = value[_k];
              if (sparse || _v != null) {
                out[_k] = this._write(mapMember, _v);
              }
            }
            return out;
          }
          if (value instanceof Uint8Array && (ns.isBlobSchema() || ns.isDocumentSchema())) {
            if (ns === this.rootSchema) {
              return value;
            }
            return (this.serdeContext?.base64Encoder ?? import_util_base6448.toBase64)(value);
          }
          if (value instanceof Date && (ns.isTimestampSchema() || ns.isDocumentSchema())) {
            const format32 = determineTimestampFormat(ns, this.settings);
            switch (format32) {
              case 5:
                return value.toISOString().replace(".000Z", "Z");
              case 6:
                return dateToUtcString(value);
              case 7:
                return value.getTime() / 1e3;
              default:
                console.warn("Missing timestamp format, using epoch seconds", value);
                return value.getTime() / 1e3;
            }
          }
          if (value instanceof NumericValue) {
            this.useReplacer = true;
          }
        }
        if (value === null && container?.isStructSchema()) {
          return void 0;
        }
        if (ns.isStringSchema()) {
          if (typeof value === "undefined" && ns.isIdempotencyToken()) {
            return (0, import_uuid.v4)();
          }
          const mediaType = ns.getMergedTraits().mediaType;
          if (value != null && mediaType) {
            const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
            if (isJson) {
              return LazyJsonString.from(value);
            }
          }
          return value;
        }
        if (typeof value === "number" && ns.isNumericSchema()) {
          if (Math.abs(value) === Infinity || isNaN(value)) {
            return String(value);
          }
          return value;
        }
        if (typeof value === "string" && ns.isBlobSchema()) {
          if (ns === this.rootSchema) {
            return value;
          }
          return (this.serdeContext?.base64Encoder ?? import_util_base6448.toBase64)(value);
        }
        if (typeof value === "bigint") {
          this.useReplacer = true;
        }
        if (ns.isDocumentSchema()) {
          if (isObject3) {
            const out = Array.isArray(value) ? [] : {};
            for (const k32 in value) {
              const v = value[k32];
              if (v instanceof NumericValue) {
                this.useReplacer = true;
                out[k32] = v;
              } else {
                out[k32] = this._write(ns, v);
              }
            }
            return out;
          } else {
            return structuredClone(value);
          }
        }
        return value;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonCodec.js
var JsonCodec9;
var init_JsonCodec9 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonCodec.js"() {
    init_ConfigurableSerdeContext9();
    init_JsonShapeDeserializer9();
    init_JsonShapeSerializer9();
    JsonCodec9 = class extends SerdeContextConfig9 {
      static {
        __name(this, "JsonCodec");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      createSerializer() {
        const serializer = new JsonShapeSerializer9(this.settings);
        serializer.setSerdeContext(this.serdeContext);
        return serializer;
      }
      createDeserializer() {
        const deserializer = new JsonShapeDeserializer9(this.settings);
        deserializer.setSerdeContext(this.serdeContext);
        return deserializer;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJsonRpcProtocol.js
var AwsJsonRpcProtocol7;
var init_AwsJsonRpcProtocol9 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJsonRpcProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib9();
    init_JsonCodec9();
    init_parseJsonBody9();
    AwsJsonRpcProtocol7 = class extends RpcProtocol {
      static {
        __name(this, "AwsJsonRpcProtocol");
      }
      serializer;
      deserializer;
      serviceTarget;
      codec;
      mixin;
      awsQueryCompatible;
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, serviceTarget, awsQueryCompatible, jsonCodec }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32
        });
        this.serviceTarget = serviceTarget;
        this.codec = jsonCodec ?? new JsonCodec9({
          timestampFormat: {
            useTrait: true,
            default: 7
          },
          jsonName: false
        });
        this.serializer = this.codec.createSerializer();
        this.deserializer = this.codec.createDeserializer();
        this.awsQueryCompatible = !!awsQueryCompatible;
        this.mixin = new ProtocolLib9(this.awsQueryCompatible);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        if (!request4.path.endsWith("/")) {
          request4.path += "/";
        }
        request4.headers["content-type"] = `application/x-amz-json-${this.getJsonRpcVersion()}`;
        request4.headers["x-amz-target"] = `${this.serviceTarget}.${operationSchema.name}`;
        if (this.awsQueryCompatible) {
          request4.headers["x-amzn-query-mode"] = "true";
        }
        if (deref(operationSchema.input) === "unit" || !request4.body) {
          request4.body = "{}";
        }
        return request4;
      }
      getPayloadCodec() {
        return this.codec;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        if (this.awsQueryCompatible) {
          this.mixin.setQueryCompatError(dataObject, response);
        }
        const errorIdentifier = loadRestJsonErrorCode9(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata, this.awsQueryCompatible ? this.mixin.findQueryCompatibleError : void 0);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          if (dataObject[name] != null) {
            output[name] = errorDeserializer.readObject(member7, dataObject[name]);
          }
        }
        if (this.awsQueryCompatible) {
          this.mixin.queryCompatOutput(dataObject, output);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_0Protocol.js
var AwsJson1_0Protocol7;
var init_AwsJson1_0Protocol9 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_0Protocol.js"() {
    init_AwsJsonRpcProtocol9();
    AwsJson1_0Protocol7 = class extends AwsJsonRpcProtocol7 {
      static {
        __name(this, "AwsJson1_0Protocol");
      }
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, serviceTarget, awsQueryCompatible, jsonCodec }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32,
          serviceTarget,
          awsQueryCompatible,
          jsonCodec
        });
      }
      getShapeId() {
        return "aws.protocols#awsJson1_0";
      }
      getJsonRpcVersion() {
        return "1.0";
      }
      getDefaultContentType() {
        return "application/x-amz-json-1.0";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_1Protocol.js
var AwsJson1_1Protocol7;
var init_AwsJson1_1Protocol9 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_1Protocol.js"() {
    init_AwsJsonRpcProtocol9();
    AwsJson1_1Protocol7 = class extends AwsJsonRpcProtocol7 {
      static {
        __name(this, "AwsJson1_1Protocol");
      }
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, serviceTarget, awsQueryCompatible, jsonCodec }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32,
          serviceTarget,
          awsQueryCompatible,
          jsonCodec
        });
      }
      getShapeId() {
        return "aws.protocols#awsJson1_1";
      }
      getJsonRpcVersion() {
        return "1.1";
      }
      getDefaultContentType() {
        return "application/x-amz-json-1.1";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsRestJsonProtocol.js
var AwsRestJsonProtocol9;
var init_AwsRestJsonProtocol9 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsRestJsonProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib9();
    init_JsonCodec9();
    init_parseJsonBody9();
    AwsRestJsonProtocol9 = class extends HttpBindingProtocol {
      static {
        __name(this, "AwsRestJsonProtocol");
      }
      serializer;
      deserializer;
      codec;
      mixin = new ProtocolLib9();
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32 }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32
        });
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 7
          },
          httpBindings: true,
          jsonName: true
        };
        this.codec = new JsonCodec9(settings);
        this.serializer = new HttpInterceptingShapeSerializer(this.codec.createSerializer(), settings);
        this.deserializer = new HttpInterceptingShapeDeserializer(this.codec.createDeserializer(), settings);
      }
      getShapeId() {
        return "aws.protocols#restJson1";
      }
      getPayloadCodec() {
        return this.codec;
      }
      setSerdeContext(serdeContext) {
        this.codec.setSerdeContext(serdeContext);
        super.setSerdeContext(serdeContext);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        const inputSchema = NormalizedSchema.of(operationSchema.input);
        if (!request4.headers["content-type"]) {
          const contentType = this.mixin.resolveRestContentType(this.getDefaultContentType(), inputSchema);
          if (contentType) {
            request4.headers["content-type"] = contentType;
          }
        }
        if (request4.body == null && request4.headers["content-type"] === this.getDefaultContentType()) {
          request4.body = "{}";
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        const output = await super.deserializeResponse(operationSchema, context, response);
        const outputSchema = NormalizedSchema.of(operationSchema.output);
        for (const [name, member7] of outputSchema.structIterator()) {
          if (member7.getMemberTraits().httpPayload && !(name in output)) {
            output[name] = null;
          }
        }
        return output;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = loadRestJsonErrorCode9(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        await this.deserializeHttpMessage(errorSchema, context, response, dataObject);
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().jsonName ?? name;
          output[name] = errorDeserializer.readObject(member7, dataObject[target]);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      getDefaultContentType() {
        return "application/json";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/awsExpectUnion.js
var import_smithy_client176, awsExpectUnion7;
var init_awsExpectUnion9 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/awsExpectUnion.js"() {
    import_smithy_client176 = __toESM(require_dist_cjs34());
    awsExpectUnion7 = /* @__PURE__ */ __name((value) => {
      if (value == null) {
        return void 0;
      }
      if (typeof value === "object" && "__type" in value) {
        delete value.__type;
      }
      return (0, import_smithy_client176.expectUnion)(value);
    }, "awsExpectUnion");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeDeserializer.js
var import_xml_builder20, import_smithy_client177, import_util_utf838, XmlShapeDeserializer8;
var init_XmlShapeDeserializer9 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeDeserializer.js"() {
    import_xml_builder20 = __toESM(require_dist_cjs47());
    init_protocols();
    init_schema4();
    import_smithy_client177 = __toESM(require_dist_cjs34());
    import_util_utf838 = __toESM(require_dist_cjs9());
    init_ConfigurableSerdeContext9();
    init_UnionSerde9();
    XmlShapeDeserializer8 = class extends SerdeContextConfig9 {
      static {
        __name(this, "XmlShapeDeserializer");
      }
      settings;
      stringDeserializer;
      constructor(settings) {
        super();
        this.settings = settings;
        this.stringDeserializer = new FromStringShapeDeserializer(settings);
      }
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
        this.stringDeserializer.setSerdeContext(serdeContext);
      }
      read(schema, bytes, key) {
        const ns = NormalizedSchema.of(schema);
        const memberSchemas = ns.getMemberSchemas();
        const isEventPayload = ns.isStructSchema() && ns.isMemberSchema() && !!Object.values(memberSchemas).find((memberNs) => {
          return !!memberNs.getMemberTraits().eventPayload;
        });
        if (isEventPayload) {
          const output = {};
          const memberName = Object.keys(memberSchemas)[0];
          const eventMemberSchema = memberSchemas[memberName];
          if (eventMemberSchema.isBlobSchema()) {
            output[memberName] = bytes;
          } else {
            output[memberName] = this.read(memberSchemas[memberName], bytes);
          }
          return output;
        }
        const xmlString = (this.serdeContext?.utf8Encoder ?? import_util_utf838.toUtf8)(bytes);
        const parsedObject = this.parseXml(xmlString);
        return this.readSchema(schema, key ? parsedObject[key] : parsedObject);
      }
      readSchema(_schema, value) {
        const ns = NormalizedSchema.of(_schema);
        if (ns.isUnitSchema()) {
          return;
        }
        const traits = ns.getMergedTraits();
        if (ns.isListSchema() && !Array.isArray(value)) {
          return this.readSchema(ns, [value]);
        }
        if (value == null) {
          return value;
        }
        if (typeof value === "object") {
          const flat = !!traits.xmlFlattened;
          if (ns.isListSchema()) {
            const listValue = ns.getValueSchema();
            const buffer2 = [];
            const sourceKey = listValue.getMergedTraits().xmlName ?? "member";
            const source = flat ? value : (value[0] ?? value)[sourceKey];
            if (source == null) {
              return buffer2;
            }
            const sourceArray = Array.isArray(source) ? source : [source];
            for (const v of sourceArray) {
              buffer2.push(this.readSchema(listValue, v));
            }
            return buffer2;
          }
          const buffer = {};
          if (ns.isMapSchema()) {
            const keyNs = ns.getKeySchema();
            const memberNs = ns.getValueSchema();
            let entries;
            if (flat) {
              entries = Array.isArray(value) ? value : [value];
            } else {
              entries = Array.isArray(value.entry) ? value.entry : [value.entry];
            }
            const keyProperty = keyNs.getMergedTraits().xmlName ?? "key";
            const valueProperty = memberNs.getMergedTraits().xmlName ?? "value";
            for (const entry of entries) {
              const key = entry[keyProperty];
              const value2 = entry[valueProperty];
              buffer[key] = this.readSchema(memberNs, value2);
            }
            return buffer;
          }
          if (ns.isStructSchema()) {
            const union = ns.isUnionSchema();
            let unionSerde;
            if (union) {
              unionSerde = new UnionSerde9(value, buffer);
            }
            for (const [memberName, memberSchema] of ns.structIterator()) {
              const memberTraits = memberSchema.getMergedTraits();
              const xmlObjectKey = !memberTraits.httpPayload ? memberSchema.getMemberTraits().xmlName ?? memberName : memberTraits.xmlName ?? memberSchema.getName();
              if (union) {
                unionSerde.mark(xmlObjectKey);
              }
              if (value[xmlObjectKey] != null) {
                buffer[memberName] = this.readSchema(memberSchema, value[xmlObjectKey]);
              }
            }
            if (union) {
              unionSerde.writeUnknown();
            }
            return buffer;
          }
          if (ns.isDocumentSchema()) {
            return value;
          }
          throw new Error(`@aws-sdk/core/protocols - xml deserializer unhandled schema type for ${ns.getName(true)}`);
        }
        if (ns.isListSchema()) {
          return [];
        }
        if (ns.isMapSchema() || ns.isStructSchema()) {
          return {};
        }
        return this.stringDeserializer.read(ns, value);
      }
      parseXml(xml) {
        if (xml.length) {
          let parsedObj;
          try {
            parsedObj = (0, import_xml_builder20.parseXML)(xml);
          } catch (e32) {
            if (e32 && typeof e32 === "object") {
              Object.defineProperty(e32, "$responseBodyText", {
                value: xml
              });
            }
            throw e32;
          }
          const textNodeName = "#text";
          const key = Object.keys(parsedObj)[0];
          const parsedObjToReturn = parsedObj[key];
          if (parsedObjToReturn[textNodeName]) {
            parsedObjToReturn[key] = parsedObjToReturn[textNodeName];
            delete parsedObjToReturn[textNodeName];
          }
          return (0, import_smithy_client177.getValueFromTextNode)(parsedObjToReturn);
        }
        return {};
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QueryShapeSerializer.js
var import_smithy_client178, import_util_base6449, QueryShapeSerializer8;
var init_QueryShapeSerializer9 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QueryShapeSerializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_smithy_client178 = __toESM(require_dist_cjs34());
    import_util_base6449 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext9();
    QueryShapeSerializer8 = class extends SerdeContextConfig9 {
      static {
        __name(this, "QueryShapeSerializer");
      }
      settings;
      buffer;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value, prefix = "") {
        if (this.buffer === void 0) {
          this.buffer = "";
        }
        const ns = NormalizedSchema.of(schema);
        if (prefix && !prefix.endsWith(".")) {
          prefix += ".";
        }
        if (ns.isBlobSchema()) {
          if (typeof value === "string" || value instanceof Uint8Array) {
            this.writeKey(prefix);
            this.writeValue((this.serdeContext?.base64Encoder ?? import_util_base6449.toBase64)(value));
          }
        } else if (ns.isBooleanSchema() || ns.isNumericSchema() || ns.isStringSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(String(value));
          } else if (ns.isIdempotencyToken()) {
            this.writeKey(prefix);
            this.writeValue((0, import_uuid.v4)());
          }
        } else if (ns.isBigIntegerSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(String(value));
          }
        } else if (ns.isBigDecimalSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(value instanceof NumericValue ? value.string : String(value));
          }
        } else if (ns.isTimestampSchema()) {
          if (value instanceof Date) {
            this.writeKey(prefix);
            const format32 = determineTimestampFormat(ns, this.settings);
            switch (format32) {
              case 5:
                this.writeValue(value.toISOString().replace(".000Z", "Z"));
                break;
              case 6:
                this.writeValue((0, import_smithy_client178.dateToUtcString)(value));
                break;
              case 7:
                this.writeValue(String(value.getTime() / 1e3));
                break;
            }
          }
        } else if (ns.isDocumentSchema()) {
          if (Array.isArray(value)) {
            this.write(64 | 15, value, prefix);
          } else if (value instanceof Date) {
            this.write(4, value, prefix);
          } else if (value instanceof Uint8Array) {
            this.write(21, value, prefix);
          } else if (value && typeof value === "object") {
            this.write(128 | 15, value, prefix);
          } else {
            this.writeKey(prefix);
            this.writeValue(String(value));
          }
        } else if (ns.isListSchema()) {
          if (Array.isArray(value)) {
            if (value.length === 0) {
              if (this.settings.serializeEmptyLists) {
                this.writeKey(prefix);
                this.writeValue("");
              }
            } else {
              const member7 = ns.getValueSchema();
              const flat = this.settings.flattenLists || ns.getMergedTraits().xmlFlattened;
              let i32 = 1;
              for (const item of value) {
                if (item == null) {
                  continue;
                }
                const traits = member7.getMergedTraits();
                const suffix = this.getKey("member", traits.xmlName, traits.ec2QueryName);
                const key = flat ? `${prefix}${i32}` : `${prefix}${suffix}.${i32}`;
                this.write(member7, item, key);
                ++i32;
              }
            }
          }
        } else if (ns.isMapSchema()) {
          if (value && typeof value === "object") {
            const keySchema = ns.getKeySchema();
            const memberSchema = ns.getValueSchema();
            const flat = ns.getMergedTraits().xmlFlattened;
            let i32 = 1;
            for (const k32 in value) {
              const v = value[k32];
              if (v == null) {
                continue;
              }
              const keyTraits = keySchema.getMergedTraits();
              const keySuffix = this.getKey("key", keyTraits.xmlName, keyTraits.ec2QueryName);
              const key = flat ? `${prefix}${i32}.${keySuffix}` : `${prefix}entry.${i32}.${keySuffix}`;
              const valTraits = memberSchema.getMergedTraits();
              const valueSuffix = this.getKey("value", valTraits.xmlName, valTraits.ec2QueryName);
              const valueKey = flat ? `${prefix}${i32}.${valueSuffix}` : `${prefix}entry.${i32}.${valueSuffix}`;
              this.write(keySchema, k32, key);
              this.write(memberSchema, v, valueKey);
              ++i32;
            }
          }
        } else if (ns.isStructSchema()) {
          if (value && typeof value === "object") {
            let didWriteMember = false;
            for (const [memberName, member7] of ns.structIterator()) {
              if (value[memberName] == null && !member7.isIdempotencyToken()) {
                continue;
              }
              const traits = member7.getMergedTraits();
              const suffix = this.getKey(memberName, traits.xmlName, traits.ec2QueryName, "struct");
              const key = `${prefix}${suffix}`;
              this.write(member7, value[memberName], key);
              didWriteMember = true;
            }
            if (!didWriteMember && ns.isUnionSchema()) {
              const { $unknown } = value;
              if (Array.isArray($unknown)) {
                const [k32, v] = $unknown;
                const key = `${prefix}${k32}`;
                this.write(15, v, key);
              }
            }
          }
        } else if (ns.isUnitSchema()) {
        } else {
          throw new Error(`@aws-sdk/core/protocols - QuerySerializer unrecognized schema type ${ns.getName(true)}`);
        }
      }
      flush() {
        if (this.buffer === void 0) {
          throw new Error("@aws-sdk/core/protocols - QuerySerializer cannot flush with nothing written to buffer.");
        }
        const str = this.buffer;
        delete this.buffer;
        return str;
      }
      getKey(memberName, xmlName, ec2QueryName, keySource) {
        const { ec2, capitalizeKeys } = this.settings;
        if (ec2 && ec2QueryName) {
          return ec2QueryName;
        }
        const key = xmlName ?? memberName;
        if (capitalizeKeys && keySource === "struct") {
          return key[0].toUpperCase() + key.slice(1);
        }
        return key;
      }
      writeKey(key) {
        if (key.endsWith(".")) {
          key = key.slice(0, key.length - 1);
        }
        this.buffer += `&${extendedEncodeURIComponent(key)}=`;
      }
      writeValue(value) {
        this.buffer += extendedEncodeURIComponent(value);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsQueryProtocol.js
var AwsQueryProtocol8;
var init_AwsQueryProtocol9 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsQueryProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib9();
    init_XmlShapeDeserializer9();
    init_QueryShapeSerializer9();
    AwsQueryProtocol8 = class extends RpcProtocol {
      static {
        __name(this, "AwsQueryProtocol");
      }
      options;
      serializer;
      deserializer;
      mixin = new ProtocolLib9();
      constructor(options) {
        super({
          defaultNamespace: options.defaultNamespace,
          errorTypeRegistries: options.errorTypeRegistries
        });
        this.options = options;
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 5
          },
          httpBindings: false,
          xmlNamespace: options.xmlNamespace,
          serviceNamespace: options.defaultNamespace,
          serializeEmptyLists: true
        };
        this.serializer = new QueryShapeSerializer8(settings);
        this.deserializer = new XmlShapeDeserializer8(settings);
      }
      getShapeId() {
        return "aws.protocols#awsQuery";
      }
      setSerdeContext(serdeContext) {
        this.serializer.setSerdeContext(serdeContext);
        this.deserializer.setSerdeContext(serdeContext);
      }
      getPayloadCodec() {
        throw new Error("AWSQuery protocol has no payload codec.");
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        if (!request4.path.endsWith("/")) {
          request4.path += "/";
        }
        request4.headers["content-type"] = "application/x-www-form-urlencoded";
        if (deref(operationSchema.input) === "unit" || !request4.body) {
          request4.body = "";
        }
        const action = operationSchema.name.split("#")[1] ?? operationSchema.name;
        request4.body = `Action=${action}&Version=${this.options.version}` + request4.body;
        if (request4.body.endsWith("&")) {
          request4.body = request4.body.slice(-1);
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        const deserializer = this.deserializer;
        const ns = NormalizedSchema.of(operationSchema.output);
        const dataObject = {};
        if (response.statusCode >= 300) {
          const bytes2 = await collectBody(response.body, context);
          if (bytes2.byteLength > 0) {
            Object.assign(dataObject, await deserializer.read(15, bytes2));
          }
          await this.handleError(operationSchema, context, response, dataObject, this.deserializeMetadata(response));
        }
        for (const header in response.headers) {
          const value = response.headers[header];
          delete response.headers[header];
          response.headers[header.toLowerCase()] = value;
        }
        const shortName = operationSchema.name.split("#")[1] ?? operationSchema.name;
        const awsQueryResultKey = ns.isStructSchema() && this.useNestedResult() ? shortName + "Result" : void 0;
        const bytes = await collectBody(response.body, context);
        if (bytes.byteLength > 0) {
          Object.assign(dataObject, await deserializer.read(ns, bytes, awsQueryResultKey));
        }
        dataObject.$metadata = this.deserializeMetadata(response);
        return dataObject;
      }
      useNestedResult() {
        return true;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = this.loadQueryErrorCode(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const errorData = this.loadQueryError(dataObject) ?? {};
        const message2 = this.loadQueryErrorMessage(dataObject);
        errorData.message = message2;
        errorData.Error = {
          Type: errorData.Type,
          Code: errorData.Code,
          Message: message2
        };
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, errorData, metadata, this.mixin.findQueryCompatibleError);
        const ns = NormalizedSchema.of(errorSchema);
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        const output = {
          Type: errorData.Error.Type,
          Code: errorData.Error.Code,
          Error: errorData.Error
        };
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().xmlName ?? name;
          const value = errorData[target] ?? dataObject[target];
          output[name] = this.deserializer.readSchema(member7, value);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      loadQueryErrorCode(output, data3) {
        const code = (data3.Errors?.[0]?.Error ?? data3.Errors?.Error ?? data3.Error)?.Code;
        if (code !== void 0) {
          return code;
        }
        if (output.statusCode == 404) {
          return "NotFound";
        }
      }
      loadQueryError(data3) {
        return data3.Errors?.[0]?.Error ?? data3.Errors?.Error ?? data3.Error;
      }
      loadQueryErrorMessage(data3) {
        const errorData = this.loadQueryError(data3);
        return errorData?.message ?? errorData?.Message ?? data3.message ?? data3.Message ?? "Unknown";
      }
      getDefaultContentType() {
        return "application/x-www-form-urlencoded";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsEc2QueryProtocol.js
var AwsEc2QueryProtocol7;
var init_AwsEc2QueryProtocol9 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsEc2QueryProtocol.js"() {
    init_AwsQueryProtocol9();
    AwsEc2QueryProtocol7 = class extends AwsQueryProtocol8 {
      static {
        __name(this, "AwsEc2QueryProtocol");
      }
      options;
      constructor(options) {
        super(options);
        this.options = options;
        const ec2Settings = {
          capitalizeKeys: true,
          flattenLists: true,
          serializeEmptyLists: false,
          ec2: true
        };
        Object.assign(this.serializer.settings, ec2Settings);
      }
      getShapeId() {
        return "aws.protocols#ec2Query";
      }
      useNestedResult() {
        return false;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QuerySerializerSettings.js
var init_QuerySerializerSettings9 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QuerySerializerSettings.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/parseXmlBody.js
var import_xml_builder21, import_smithy_client179, parseXmlBody7, parseXmlErrorBody7, loadRestXmlErrorCode7;
var init_parseXmlBody9 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/parseXmlBody.js"() {
    import_xml_builder21 = __toESM(require_dist_cjs47());
    import_smithy_client179 = __toESM(require_dist_cjs34());
    init_common11();
    parseXmlBody7 = /* @__PURE__ */ __name((streamBody, context) => collectBodyString9(streamBody, context).then((encoded) => {
      if (encoded.length) {
        let parsedObj;
        try {
          parsedObj = (0, import_xml_builder21.parseXML)(encoded);
        } catch (e32) {
          if (e32 && typeof e32 === "object") {
            Object.defineProperty(e32, "$responseBodyText", {
              value: encoded
            });
          }
          throw e32;
        }
        const textNodeName = "#text";
        const key = Object.keys(parsedObj)[0];
        const parsedObjToReturn = parsedObj[key];
        if (parsedObjToReturn[textNodeName]) {
          parsedObjToReturn[key] = parsedObjToReturn[textNodeName];
          delete parsedObjToReturn[textNodeName];
        }
        return (0, import_smithy_client179.getValueFromTextNode)(parsedObjToReturn);
      }
      return {};
    }), "parseXmlBody");
    parseXmlErrorBody7 = /* @__PURE__ */ __name(async (errorBody, context) => {
      const value = await parseXmlBody7(errorBody, context);
      if (value.Error) {
        value.Error.message = value.Error.message ?? value.Error.Message;
      }
      return value;
    }, "parseXmlErrorBody");
    loadRestXmlErrorCode7 = /* @__PURE__ */ __name((output, data3) => {
      if (data3?.Error?.Code !== void 0) {
        return data3.Error.Code;
      }
      if (data3?.Code !== void 0) {
        return data3.Code;
      }
      if (output.statusCode == 404) {
        return "NotFound";
      }
    }, "loadRestXmlErrorCode");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeSerializer.js
var import_xml_builder22, import_smithy_client180, import_util_base6450, XmlShapeSerializer7;
var init_XmlShapeSerializer9 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeSerializer.js"() {
    import_xml_builder22 = __toESM(require_dist_cjs47());
    init_protocols();
    init_schema4();
    init_serde();
    import_smithy_client180 = __toESM(require_dist_cjs34());
    import_util_base6450 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext9();
    XmlShapeSerializer7 = class extends SerdeContextConfig9 {
      static {
        __name(this, "XmlShapeSerializer");
      }
      settings;
      stringBuffer;
      byteBuffer;
      buffer;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value) {
        const ns = NormalizedSchema.of(schema);
        if (ns.isStringSchema() && typeof value === "string") {
          this.stringBuffer = value;
        } else if (ns.isBlobSchema()) {
          this.byteBuffer = "byteLength" in value ? value : (this.serdeContext?.base64Decoder ?? import_util_base6450.fromBase64)(value);
        } else {
          this.buffer = this.writeStruct(ns, value, void 0);
          const traits = ns.getMergedTraits();
          if (traits.httpPayload && !traits.xmlName) {
            this.buffer.withName(ns.getName());
          }
        }
      }
      flush() {
        if (this.byteBuffer !== void 0) {
          const bytes = this.byteBuffer;
          delete this.byteBuffer;
          return bytes;
        }
        if (this.stringBuffer !== void 0) {
          const str = this.stringBuffer;
          delete this.stringBuffer;
          return str;
        }
        const buffer = this.buffer;
        if (this.settings.xmlNamespace) {
          if (!buffer?.attributes?.["xmlns"]) {
            buffer.addAttribute("xmlns", this.settings.xmlNamespace);
          }
        }
        delete this.buffer;
        return buffer.toString();
      }
      writeStruct(ns, value, parentXmlns) {
        const traits = ns.getMergedTraits();
        const name = ns.isMemberSchema() && !traits.httpPayload ? ns.getMemberTraits().xmlName ?? ns.getMemberName() : traits.xmlName ?? ns.getName();
        if (!name || !ns.isStructSchema()) {
          throw new Error(`@aws-sdk/core/protocols - xml serializer, cannot write struct with empty name or non-struct, schema=${ns.getName(true)}.`);
        }
        const structXmlNode = import_xml_builder22.XmlNode.of(name);
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(ns, parentXmlns);
        for (const [memberName, memberSchema] of ns.structIterator()) {
          const val = value[memberName];
          if (val != null || memberSchema.isIdempotencyToken()) {
            if (memberSchema.getMergedTraits().xmlAttribute) {
              structXmlNode.addAttribute(memberSchema.getMergedTraits().xmlName ?? memberName, this.writeSimple(memberSchema, val));
              continue;
            }
            if (memberSchema.isListSchema()) {
              this.writeList(memberSchema, val, structXmlNode, xmlns);
            } else if (memberSchema.isMapSchema()) {
              this.writeMap(memberSchema, val, structXmlNode, xmlns);
            } else if (memberSchema.isStructSchema()) {
              structXmlNode.addChildNode(this.writeStruct(memberSchema, val, xmlns));
            } else {
              const memberNode = import_xml_builder22.XmlNode.of(memberSchema.getMergedTraits().xmlName ?? memberSchema.getMemberName());
              this.writeSimpleInto(memberSchema, val, memberNode, xmlns);
              structXmlNode.addChildNode(memberNode);
            }
          }
        }
        const { $unknown } = value;
        if ($unknown && ns.isUnionSchema() && Array.isArray($unknown) && Object.keys(value).length === 1) {
          const [k32, v] = $unknown;
          const node = import_xml_builder22.XmlNode.of(k32);
          if (typeof v !== "string") {
            if (value instanceof import_xml_builder22.XmlNode || value instanceof import_xml_builder22.XmlText) {
              structXmlNode.addChildNode(value);
            } else {
              throw new Error(`@aws-sdk - $unknown union member in XML requires value of type string, @aws-sdk/xml-builder::XmlNode or XmlText.`);
            }
          }
          this.writeSimpleInto(0, v, node, xmlns);
          structXmlNode.addChildNode(node);
        }
        if (xmlns) {
          structXmlNode.addAttribute(xmlnsAttr, xmlns);
        }
        return structXmlNode;
      }
      writeList(listMember, array, container, parentXmlns) {
        if (!listMember.isMemberSchema()) {
          throw new Error(`@aws-sdk/core/protocols - xml serializer, cannot write non-member list: ${listMember.getName(true)}`);
        }
        const listTraits = listMember.getMergedTraits();
        const listValueSchema = listMember.getValueSchema();
        const listValueTraits = listValueSchema.getMergedTraits();
        const sparse = !!listValueTraits.sparse;
        const flat = !!listTraits.xmlFlattened;
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(listMember, parentXmlns);
        const writeItem = /* @__PURE__ */ __name((container2, value) => {
          if (listValueSchema.isListSchema()) {
            this.writeList(listValueSchema, Array.isArray(value) ? value : [value], container2, xmlns);
          } else if (listValueSchema.isMapSchema()) {
            this.writeMap(listValueSchema, value, container2, xmlns);
          } else if (listValueSchema.isStructSchema()) {
            const struct3 = this.writeStruct(listValueSchema, value, xmlns);
            container2.addChildNode(struct3.withName(flat ? listTraits.xmlName ?? listMember.getMemberName() : listValueTraits.xmlName ?? "member"));
          } else {
            const listItemNode = import_xml_builder22.XmlNode.of(flat ? listTraits.xmlName ?? listMember.getMemberName() : listValueTraits.xmlName ?? "member");
            this.writeSimpleInto(listValueSchema, value, listItemNode, xmlns);
            container2.addChildNode(listItemNode);
          }
        }, "writeItem");
        if (flat) {
          for (const value of array) {
            if (sparse || value != null) {
              writeItem(container, value);
            }
          }
        } else {
          const listNode = import_xml_builder22.XmlNode.of(listTraits.xmlName ?? listMember.getMemberName());
          if (xmlns) {
            listNode.addAttribute(xmlnsAttr, xmlns);
          }
          for (const value of array) {
            if (sparse || value != null) {
              writeItem(listNode, value);
            }
          }
          container.addChildNode(listNode);
        }
      }
      writeMap(mapMember, map5, container, parentXmlns, containerIsMap = false) {
        if (!mapMember.isMemberSchema()) {
          throw new Error(`@aws-sdk/core/protocols - xml serializer, cannot write non-member map: ${mapMember.getName(true)}`);
        }
        const mapTraits = mapMember.getMergedTraits();
        const mapKeySchema = mapMember.getKeySchema();
        const mapKeyTraits = mapKeySchema.getMergedTraits();
        const keyTag = mapKeyTraits.xmlName ?? "key";
        const mapValueSchema = mapMember.getValueSchema();
        const mapValueTraits = mapValueSchema.getMergedTraits();
        const valueTag = mapValueTraits.xmlName ?? "value";
        const sparse = !!mapValueTraits.sparse;
        const flat = !!mapTraits.xmlFlattened;
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(mapMember, parentXmlns);
        const addKeyValue = /* @__PURE__ */ __name((entry, key, val) => {
          const keyNode = import_xml_builder22.XmlNode.of(keyTag, key);
          const [keyXmlnsAttr, keyXmlns] = this.getXmlnsAttribute(mapKeySchema, xmlns);
          if (keyXmlns) {
            keyNode.addAttribute(keyXmlnsAttr, keyXmlns);
          }
          entry.addChildNode(keyNode);
          let valueNode = import_xml_builder22.XmlNode.of(valueTag);
          if (mapValueSchema.isListSchema()) {
            this.writeList(mapValueSchema, val, valueNode, xmlns);
          } else if (mapValueSchema.isMapSchema()) {
            this.writeMap(mapValueSchema, val, valueNode, xmlns, true);
          } else if (mapValueSchema.isStructSchema()) {
            valueNode = this.writeStruct(mapValueSchema, val, xmlns);
          } else {
            this.writeSimpleInto(mapValueSchema, val, valueNode, xmlns);
          }
          entry.addChildNode(valueNode);
        }, "addKeyValue");
        if (flat) {
          for (const key in map5) {
            const val = map5[key];
            if (sparse || val != null) {
              const entry = import_xml_builder22.XmlNode.of(mapTraits.xmlName ?? mapMember.getMemberName());
              addKeyValue(entry, key, val);
              container.addChildNode(entry);
            }
          }
        } else {
          let mapNode;
          if (!containerIsMap) {
            mapNode = import_xml_builder22.XmlNode.of(mapTraits.xmlName ?? mapMember.getMemberName());
            if (xmlns) {
              mapNode.addAttribute(xmlnsAttr, xmlns);
            }
            container.addChildNode(mapNode);
          }
          for (const key in map5) {
            const val = map5[key];
            if (sparse || val != null) {
              const entry = import_xml_builder22.XmlNode.of("entry");
              addKeyValue(entry, key, val);
              (containerIsMap ? container : mapNode).addChildNode(entry);
            }
          }
        }
      }
      writeSimple(_schema, value) {
        if (null === value) {
          throw new Error("@aws-sdk/core/protocols - (XML serializer) cannot write null value.");
        }
        const ns = NormalizedSchema.of(_schema);
        let nodeContents = null;
        if (value && typeof value === "object") {
          if (ns.isBlobSchema()) {
            nodeContents = (this.serdeContext?.base64Encoder ?? import_util_base6450.toBase64)(value);
          } else if (ns.isTimestampSchema() && value instanceof Date) {
            const format32 = determineTimestampFormat(ns, this.settings);
            switch (format32) {
              case 5:
                nodeContents = value.toISOString().replace(".000Z", "Z");
                break;
              case 6:
                nodeContents = (0, import_smithy_client180.dateToUtcString)(value);
                break;
              case 7:
                nodeContents = String(value.getTime() / 1e3);
                break;
              default:
                console.warn("Missing timestamp format, using http date", value);
                nodeContents = (0, import_smithy_client180.dateToUtcString)(value);
                break;
            }
          } else if (ns.isBigDecimalSchema() && value) {
            if (value instanceof NumericValue) {
              return value.string;
            }
            return String(value);
          } else if (ns.isMapSchema() || ns.isListSchema()) {
            throw new Error("@aws-sdk/core/protocols - xml serializer, cannot call _write() on List/Map schema, call writeList or writeMap() instead.");
          } else {
            throw new Error(`@aws-sdk/core/protocols - xml serializer, unhandled schema type for object value and schema: ${ns.getName(true)}`);
          }
        }
        if (ns.isBooleanSchema() || ns.isNumericSchema() || ns.isBigIntegerSchema() || ns.isBigDecimalSchema()) {
          nodeContents = String(value);
        }
        if (ns.isStringSchema()) {
          if (value === void 0 && ns.isIdempotencyToken()) {
            nodeContents = (0, import_uuid.v4)();
          } else {
            nodeContents = String(value);
          }
        }
        if (nodeContents === null) {
          throw new Error(`Unhandled schema-value pair ${ns.getName(true)}=${value}`);
        }
        return nodeContents;
      }
      writeSimpleInto(_schema, value, into, parentXmlns) {
        const nodeContents = this.writeSimple(_schema, value);
        const ns = NormalizedSchema.of(_schema);
        const content = new import_xml_builder22.XmlText(nodeContents);
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(ns, parentXmlns);
        if (xmlns) {
          into.addAttribute(xmlnsAttr, xmlns);
        }
        into.addChildNode(content);
      }
      getXmlnsAttribute(ns, parentXmlns) {
        const traits = ns.getMergedTraits();
        const [prefix, xmlns] = traits.xmlNamespace ?? [];
        if (xmlns && xmlns !== parentXmlns) {
          return [prefix ? `xmlns:${prefix}` : "xmlns", xmlns];
        }
        return [void 0, void 0];
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlCodec.js
var XmlCodec7;
var init_XmlCodec9 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlCodec.js"() {
    init_ConfigurableSerdeContext9();
    init_XmlShapeDeserializer9();
    init_XmlShapeSerializer9();
    XmlCodec7 = class extends SerdeContextConfig9 {
      static {
        __name(this, "XmlCodec");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      createSerializer() {
        const serializer = new XmlShapeSerializer7(this.settings);
        serializer.setSerdeContext(this.serdeContext);
        return serializer;
      }
      createDeserializer() {
        const deserializer = new XmlShapeDeserializer8(this.settings);
        deserializer.setSerdeContext(this.serdeContext);
        return deserializer;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/AwsRestXmlProtocol.js
var AwsRestXmlProtocol7;
var init_AwsRestXmlProtocol9 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/AwsRestXmlProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib9();
    init_parseXmlBody9();
    init_XmlCodec9();
    AwsRestXmlProtocol7 = class extends HttpBindingProtocol {
      static {
        __name(this, "AwsRestXmlProtocol");
      }
      codec;
      serializer;
      deserializer;
      mixin = new ProtocolLib9();
      constructor(options) {
        super(options);
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 5
          },
          httpBindings: true,
          xmlNamespace: options.xmlNamespace,
          serviceNamespace: options.defaultNamespace
        };
        this.codec = new XmlCodec7(settings);
        this.serializer = new HttpInterceptingShapeSerializer(this.codec.createSerializer(), settings);
        this.deserializer = new HttpInterceptingShapeDeserializer(this.codec.createDeserializer(), settings);
      }
      getPayloadCodec() {
        return this.codec;
      }
      getShapeId() {
        return "aws.protocols#restXml";
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        const inputSchema = NormalizedSchema.of(operationSchema.input);
        if (!request4.headers["content-type"]) {
          const contentType = this.mixin.resolveRestContentType(this.getDefaultContentType(), inputSchema);
          if (contentType) {
            request4.headers["content-type"] = contentType;
          }
        }
        if (typeof request4.body === "string" && request4.headers["content-type"] === this.getDefaultContentType() && !request4.body.startsWith("<?xml ") && !this.hasUnstructuredPayloadBinding(inputSchema)) {
          request4.body = '<?xml version="1.0" encoding="UTF-8"?>' + request4.body;
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        return super.deserializeResponse(operationSchema, context, response);
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = loadRestXmlErrorCode7(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        if (dataObject.Error && typeof dataObject.Error === "object") {
          for (const key of Object.keys(dataObject.Error)) {
            dataObject[key] = dataObject.Error[key];
            if (key.toLowerCase() === "message") {
              dataObject.message = dataObject.Error[key];
            }
          }
        }
        if (dataObject.RequestId && !metadata.requestId) {
          metadata.requestId = dataObject.RequestId;
        }
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.Error?.message ?? dataObject.Error?.Message ?? dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        await this.deserializeHttpMessage(errorSchema, context, response, dataObject);
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().xmlName ?? name;
          const value = dataObject.Error?.[target] ?? dataObject[target];
          output[name] = errorDeserializer.readSchema(member7, value);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      getDefaultContentType() {
        return "application/xml";
      }
      hasUnstructuredPayloadBinding(ns) {
        for (const [, member7] of ns.structIterator()) {
          if (member7.getMergedTraits().httpPayload) {
            return !(member7.isStructSchema() || member7.isMapSchema() || member7.isListSchema());
          }
        }
        return false;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/index.js
var protocols_exports13 = {};
__export(protocols_exports13, {
  AwsEc2QueryProtocol: () => AwsEc2QueryProtocol7,
  AwsJson1_0Protocol: () => AwsJson1_0Protocol7,
  AwsJson1_1Protocol: () => AwsJson1_1Protocol7,
  AwsJsonRpcProtocol: () => AwsJsonRpcProtocol7,
  AwsQueryProtocol: () => AwsQueryProtocol8,
  AwsRestJsonProtocol: () => AwsRestJsonProtocol9,
  AwsRestXmlProtocol: () => AwsRestXmlProtocol7,
  AwsSmithyRpcV2CborProtocol: () => AwsSmithyRpcV2CborProtocol7,
  JsonCodec: () => JsonCodec9,
  JsonShapeDeserializer: () => JsonShapeDeserializer9,
  JsonShapeSerializer: () => JsonShapeSerializer9,
  QueryShapeSerializer: () => QueryShapeSerializer8,
  XmlCodec: () => XmlCodec7,
  XmlShapeDeserializer: () => XmlShapeDeserializer8,
  XmlShapeSerializer: () => XmlShapeSerializer7,
  _toBool: () => _toBool7,
  _toNum: () => _toNum7,
  _toStr: () => _toStr7,
  awsExpectUnion: () => awsExpectUnion7,
  loadRestJsonErrorCode: () => loadRestJsonErrorCode9,
  loadRestXmlErrorCode: () => loadRestXmlErrorCode7,
  parseJsonBody: () => parseJsonBody9,
  parseJsonErrorBody: () => parseJsonErrorBody7,
  parseXmlBody: () => parseXmlBody7,
  parseXmlErrorBody: () => parseXmlErrorBody7
});
var init_protocols16 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/core/dist-es/submodules/protocols/index.js"() {
    init_AwsSmithyRpcV2CborProtocol9();
    init_coercing_serializers9();
    init_AwsJson1_0Protocol9();
    init_AwsJson1_1Protocol9();
    init_AwsJsonRpcProtocol9();
    init_AwsRestJsonProtocol9();
    init_JsonCodec9();
    init_JsonShapeDeserializer9();
    init_JsonShapeSerializer9();
    init_awsExpectUnion9();
    init_parseJsonBody9();
    init_AwsEc2QueryProtocol9();
    init_AwsQueryProtocol9();
    init_QuerySerializerSettings9();
    init_QueryShapeSerializer9();
    init_AwsRestXmlProtocol9();
    init_XmlCodec9();
    init_XmlShapeDeserializer9();
    init_XmlShapeSerializer9();
    init_parseXmlBody9();
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/bdd.js
var import_util_endpoints55, k23, a23, b23, c23, d23, e23, f23, g23, h23, i23, j23, _data23, root23, r23, nodes23, bdd23;
var init_bdd23 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/bdd.js"() {
    import_util_endpoints55 = __toESM(require_dist_cjs20());
    k23 = "ref";
    a23 = -1;
    b23 = true;
    c23 = "isSet";
    d23 = "PartitionResult";
    e23 = "booleanEquals";
    f23 = "getAttr";
    g23 = { [k23]: "Endpoint" };
    h23 = { [k23]: d23 };
    i23 = {};
    j23 = [{ [k23]: "Region" }];
    _data23 = {
      conditions: [
        [c23, [g23]],
        [c23, j23],
        ["aws.partition", j23, d23],
        [e23, [{ [k23]: "UseFIPS" }, b23]],
        [e23, [{ [k23]: "UseDualStack" }, b23]],
        [e23, [{ fn: f23, argv: [h23, "supportsDualStack"] }, b23]],
        [e23, [{ fn: f23, argv: [h23, "supportsFIPS"] }, b23]],
        ["stringEquals", [{ fn: f23, argv: [h23, "name"] }, "aws-us-gov"]]
      ],
      results: [
        [a23],
        [a23, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a23, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [g23, i23],
        ["https://portal.sso-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", i23],
        [a23, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://portal.sso.{Region}.amazonaws.com", i23],
        ["https://portal.sso-fips.{Region}.{PartitionResult#dnsSuffix}", i23],
        [a23, "FIPS is enabled but this partition does not support FIPS"],
        ["https://portal.sso.{Region}.{PartitionResult#dualStackDnsSuffix}", i23],
        [a23, "DualStack is enabled but this partition does not support DualStack"],
        ["https://portal.sso.{Region}.{PartitionResult#dnsSuffix}", i23],
        [a23, "Invalid Configuration: Missing Region"]
      ]
    };
    root23 = 2;
    r23 = 1e8;
    nodes23 = new Int32Array([
      -1,
      1,
      -1,
      0,
      13,
      3,
      1,
      4,
      r23 + 12,
      2,
      5,
      r23 + 12,
      3,
      8,
      6,
      4,
      7,
      r23 + 11,
      5,
      r23 + 9,
      r23 + 10,
      4,
      11,
      9,
      6,
      10,
      r23 + 8,
      7,
      r23 + 6,
      r23 + 7,
      5,
      12,
      r23 + 5,
      6,
      r23 + 4,
      r23 + 5,
      3,
      r23 + 1,
      14,
      4,
      r23 + 2,
      r23 + 3
    ]);
    bdd23 = import_util_endpoints55.BinaryDecisionDiagram.from(nodes23, root23, _data23.conditions, _data23.results);
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/endpointResolver.js
var import_util_endpoints56, import_util_endpoints57, cache23, defaultEndpointResolver23;
var init_endpointResolver23 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/endpointResolver.js"() {
    import_util_endpoints56 = __toESM(require_dist_cjs21());
    import_util_endpoints57 = __toESM(require_dist_cjs20());
    init_bdd23();
    cache23 = new import_util_endpoints57.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    defaultEndpointResolver23 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache23.get(endpointParams, () => (0, import_util_endpoints57.decideEndpoint)(bdd23, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    import_util_endpoints57.customEndpointFunctions.aws = import_util_endpoints56.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/SSOServiceException.js
var import_smithy_client181, SSOServiceException7;
var init_SSOServiceException7 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/SSOServiceException.js"() {
    import_smithy_client181 = __toESM(require_dist_cjs34());
    SSOServiceException7 = class _SSOServiceException extends import_smithy_client181.ServiceException {
      static {
        __name(this, "SSOServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _SSOServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/errors.js
var InvalidRequestException10, ResourceNotFoundException8, TooManyRequestsException8, UnauthorizedException7;
var init_errors23 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/errors.js"() {
    init_SSOServiceException7();
    InvalidRequestException10 = class _InvalidRequestException extends SSOServiceException7 {
      static {
        __name(this, "InvalidRequestException");
      }
      name = "InvalidRequestException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidRequestException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidRequestException.prototype);
      }
    };
    ResourceNotFoundException8 = class _ResourceNotFoundException extends SSOServiceException7 {
      static {
        __name(this, "ResourceNotFoundException");
      }
      name = "ResourceNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ResourceNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceNotFoundException.prototype);
      }
    };
    TooManyRequestsException8 = class _TooManyRequestsException extends SSOServiceException7 {
      static {
        __name(this, "TooManyRequestsException");
      }
      name = "TooManyRequestsException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TooManyRequestsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyRequestsException.prototype);
      }
    };
    UnauthorizedException7 = class _UnauthorizedException extends SSOServiceException7 {
      static {
        __name(this, "UnauthorizedException");
      }
      name = "UnauthorizedException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "UnauthorizedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnauthorizedException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/schemas/schemas_0.js
var _ATT7, _GRC7, _GRCR7, _GRCRe7, _IRE10, _RC7, _RNFE8, _SAKT7, _STT7, _TMRE14, _UE7, _aI7, _aKI13, _aT16, _ai7, _c23, _e23, _ex7, _h16, _hE23, _hH7, _hQ7, _m20, _rC7, _rN7, _rn7, _s23, _sAK13, _sT13, _xasbt7, n023, _s_registry23, SSOServiceException$7, n0_registry23, InvalidRequestException$10, ResourceNotFoundException$8, TooManyRequestsException$8, UnauthorizedException$7, errorTypeRegistries23, AccessTokenType7, SecretAccessKeyType7, SessionTokenType7, GetRoleCredentialsRequest$7, GetRoleCredentialsResponse$7, RoleCredentials$7, GetRoleCredentials$7;
var init_schemas_023 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/schemas/schemas_0.js"() {
    init_schema4();
    init_errors23();
    init_SSOServiceException7();
    _ATT7 = "AccessTokenType";
    _GRC7 = "GetRoleCredentials";
    _GRCR7 = "GetRoleCredentialsRequest";
    _GRCRe7 = "GetRoleCredentialsResponse";
    _IRE10 = "InvalidRequestException";
    _RC7 = "RoleCredentials";
    _RNFE8 = "ResourceNotFoundException";
    _SAKT7 = "SecretAccessKeyType";
    _STT7 = "SessionTokenType";
    _TMRE14 = "TooManyRequestsException";
    _UE7 = "UnauthorizedException";
    _aI7 = "accountId";
    _aKI13 = "accessKeyId";
    _aT16 = "accessToken";
    _ai7 = "account_id";
    _c23 = "client";
    _e23 = "error";
    _ex7 = "expiration";
    _h16 = "http";
    _hE23 = "httpError";
    _hH7 = "httpHeader";
    _hQ7 = "httpQuery";
    _m20 = "message";
    _rC7 = "roleCredentials";
    _rN7 = "roleName";
    _rn7 = "role_name";
    _s23 = "smithy.ts.sdk.synthetic.com.amazonaws.sso";
    _sAK13 = "secretAccessKey";
    _sT13 = "sessionToken";
    _xasbt7 = "x-amz-sso_bearer_token";
    n023 = "com.amazonaws.sso";
    _s_registry23 = TypeRegistry.for(_s23);
    SSOServiceException$7 = [-3, _s23, "SSOServiceException", 0, [], []];
    _s_registry23.registerError(SSOServiceException$7, SSOServiceException7);
    n0_registry23 = TypeRegistry.for(n023);
    InvalidRequestException$10 = [-3, n023, _IRE10, { [_e23]: _c23, [_hE23]: 400 }, [_m20], [0]];
    n0_registry23.registerError(InvalidRequestException$10, InvalidRequestException10);
    ResourceNotFoundException$8 = [-3, n023, _RNFE8, { [_e23]: _c23, [_hE23]: 404 }, [_m20], [0]];
    n0_registry23.registerError(ResourceNotFoundException$8, ResourceNotFoundException8);
    TooManyRequestsException$8 = [-3, n023, _TMRE14, { [_e23]: _c23, [_hE23]: 429 }, [_m20], [0]];
    n0_registry23.registerError(TooManyRequestsException$8, TooManyRequestsException8);
    UnauthorizedException$7 = [-3, n023, _UE7, { [_e23]: _c23, [_hE23]: 401 }, [_m20], [0]];
    n0_registry23.registerError(UnauthorizedException$7, UnauthorizedException7);
    errorTypeRegistries23 = [_s_registry23, n0_registry23];
    AccessTokenType7 = [0, n023, _ATT7, 8, 0];
    SecretAccessKeyType7 = [0, n023, _SAKT7, 8, 0];
    SessionTokenType7 = [0, n023, _STT7, 8, 0];
    GetRoleCredentialsRequest$7 = [
      3,
      n023,
      _GRCR7,
      0,
      [_rN7, _aI7, _aT16],
      [
        [0, { [_hQ7]: _rn7 }],
        [0, { [_hQ7]: _ai7 }],
        [() => AccessTokenType7, { [_hH7]: _xasbt7 }]
      ],
      3
    ];
    GetRoleCredentialsResponse$7 = [
      3,
      n023,
      _GRCRe7,
      0,
      [_rC7],
      [[() => RoleCredentials$7, 0]]
    ];
    RoleCredentials$7 = [
      3,
      n023,
      _RC7,
      0,
      [_aKI13, _sAK13, _sT13, _ex7],
      [0, [() => SecretAccessKeyType7, 0], [() => SessionTokenType7, 0], 1]
    ];
    GetRoleCredentials$7 = [
      9,
      n023,
      _GRC7,
      { [_h16]: ["GET", "/federation/credentials", 200] },
      () => GetRoleCredentialsRequest$7,
      () => GetRoleCredentialsResponse$7
    ];
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.shared.js
var import_smithy_client182, import_url_parser20, import_util_base6451, import_util_utf839, getRuntimeConfig45;
var init_runtimeConfig_shared23 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.shared.js"() {
    init_httpAuthSchemes10();
    init_protocols16();
    init_dist_es();
    import_smithy_client182 = __toESM(require_dist_cjs34());
    import_url_parser20 = __toESM(require_dist_cjs18());
    import_util_base6451 = __toESM(require_dist_cjs10());
    import_util_utf839 = __toESM(require_dist_cjs9());
    init_httpAuthSchemeProvider23();
    init_endpointResolver23();
    init_schemas_023();
    getRuntimeConfig45 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2019-06-10",
        base64Decoder: config2?.base64Decoder ?? import_util_base6451.fromBase64,
        base64Encoder: config2?.base64Encoder ?? import_util_base6451.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver23,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSSOHttpAuthSchemeProvider7,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer8()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        logger: config2?.logger ?? new import_smithy_client182.NoOpLogger(),
        protocol: config2?.protocol ?? AwsRestJsonProtocol9,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.sso",
          errorTypeRegistries: errorTypeRegistries23,
          version: "2019-06-10",
          serviceTarget: "SWBPortalService"
        },
        serviceId: config2?.serviceId ?? "SSO",
        urlParser: config2?.urlParser ?? import_url_parser20.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? import_util_utf839.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? import_util_utf839.toUtf8
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.js
var import_util_user_agent_node19, import_config_resolver38, import_hash_node21, import_middleware_retry37, import_node_config_provider20, import_node_http_handler23, import_smithy_client183, import_util_body_length_node19, import_util_defaults_mode_node19, import_util_retry28, getRuntimeConfig46;
var init_runtimeConfig23 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.js"() {
    init_package8();
    init_client17();
    init_httpAuthSchemes10();
    import_util_user_agent_node19 = __toESM(require_dist_cjs172());
    import_config_resolver38 = __toESM(require_dist_cjs25());
    import_hash_node21 = __toESM(require_dist_cjs44());
    import_middleware_retry37 = __toESM(require_dist_cjs168());
    import_node_config_provider20 = __toESM(require_dist_cjs29());
    import_node_http_handler23 = __toESM(require_dist_cjs13());
    import_smithy_client183 = __toESM(require_dist_cjs34());
    import_util_body_length_node19 = __toESM(require_dist_cjs45());
    import_util_defaults_mode_node19 = __toESM(require_dist_cjs46());
    import_util_retry28 = __toESM(require_dist_cjs22());
    init_runtimeConfig_shared23();
    getRuntimeConfig46 = /* @__PURE__ */ __name((config2) => {
      (0, import_smithy_client183.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, import_util_defaults_mode_node19.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(import_smithy_client183.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig45(config2);
      emitWarningIfUnsupportedVersion30(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, import_node_config_provider20.loadConfig)(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS8, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? import_util_body_length_node19.calculateBodyLength,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, import_util_user_agent_node19.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_default8.version }),
        maxAttempts: config2?.maxAttempts ?? (0, import_node_config_provider20.loadConfig)(import_middleware_retry37.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, import_node_config_provider20.loadConfig)(import_config_resolver38.NODE_REGION_CONFIG_OPTIONS, { ...import_config_resolver38.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: import_node_http_handler23.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, import_node_config_provider20.loadConfig)({
          ...import_middleware_retry37.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || import_util_retry28.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? import_hash_node21.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? import_node_http_handler23.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, import_node_config_provider20.loadConfig)(import_config_resolver38.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, import_node_config_provider20.loadConfig)(import_config_resolver38.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, import_node_config_provider20.loadConfig)(import_util_user_agent_node19.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration23, resolveHttpAuthRuntimeConfig23;
var init_httpAuthExtensionConfiguration23 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration23 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig23 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeExtensions.js
var import_region_config_resolver24, import_protocol_http48, import_smithy_client184, resolveRuntimeExtensions23;
var init_runtimeExtensions23 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeExtensions.js"() {
    import_region_config_resolver24 = __toESM(require_dist_cjs48());
    import_protocol_http48 = __toESM(require_dist_cjs2());
    import_smithy_client184 = __toESM(require_dist_cjs34());
    init_httpAuthExtensionConfiguration23();
    resolveRuntimeExtensions23 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign((0, import_region_config_resolver24.getAwsRegionExtensionConfiguration)(runtimeConfig), (0, import_smithy_client184.getDefaultExtensionConfiguration)(runtimeConfig), (0, import_protocol_http48.getHttpHandlerExtensionConfiguration)(runtimeConfig), getHttpAuthExtensionConfiguration23(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, (0, import_region_config_resolver24.resolveAwsRegionExtensionConfiguration)(extensionConfiguration), (0, import_smithy_client184.resolveDefaultRuntimeConfig)(extensionConfiguration), (0, import_protocol_http48.resolveHttpHandlerRuntimeConfig)(extensionConfiguration), resolveHttpAuthRuntimeConfig23(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSOClient.js
var import_middleware_host_header19, import_middleware_logger19, import_middleware_recursion_detection19, import_middleware_user_agent19, import_config_resolver39, import_middleware_content_length19, import_middleware_endpoint49, import_middleware_retry38, import_smithy_client185, SSOClient7;
var init_SSOClient7 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSOClient.js"() {
    import_middleware_host_header19 = __toESM(require_dist_cjs3());
    import_middleware_logger19 = __toESM(require_dist_cjs4());
    import_middleware_recursion_detection19 = __toESM(require_dist_cjs5());
    import_middleware_user_agent19 = __toESM(require_dist_cjs167());
    import_config_resolver39 = __toESM(require_dist_cjs25());
    init_dist_es();
    init_schema4();
    import_middleware_content_length19 = __toESM(require_dist_cjs26());
    import_middleware_endpoint49 = __toESM(require_dist_cjs31());
    import_middleware_retry38 = __toESM(require_dist_cjs168());
    import_smithy_client185 = __toESM(require_dist_cjs34());
    init_httpAuthSchemeProvider23();
    init_EndpointParameters23();
    init_runtimeConfig23();
    init_runtimeExtensions23();
    SSOClient7 = class extends import_smithy_client185.Client {
      static {
        __name(this, "SSOClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig46(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters23(_config_0);
        const _config_2 = (0, import_middleware_user_agent19.resolveUserAgentConfig)(_config_1);
        const _config_3 = (0, import_middleware_retry38.resolveRetryConfig)(_config_2);
        const _config_4 = (0, import_config_resolver39.resolveRegionConfig)(_config_3);
        const _config_5 = (0, import_middleware_host_header19.resolveHostHeaderConfig)(_config_4);
        const _config_6 = (0, import_middleware_endpoint49.resolveEndpointConfig)(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig23(_config_6);
        const _config_8 = resolveRuntimeExtensions23(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin(this.config));
        this.middlewareStack.use((0, import_middleware_user_agent19.getUserAgentPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_retry38.getRetryPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_content_length19.getContentLengthPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_host_header19.getHostHeaderPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_logger19.getLoggerPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_recursion_detection19.getRecursionDetectionPlugin)(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: defaultSSOHttpAuthSchemeParametersProvider7,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/GetRoleCredentialsCommand.js
var import_middleware_endpoint50, import_smithy_client186, GetRoleCredentialsCommand7;
var init_GetRoleCredentialsCommand7 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/GetRoleCredentialsCommand.js"() {
    import_middleware_endpoint50 = __toESM(require_dist_cjs31());
    import_smithy_client186 = __toESM(require_dist_cjs34());
    init_EndpointParameters23();
    init_schemas_023();
    GetRoleCredentialsCommand7 = class extends import_smithy_client186.Command.classBuilder().ep(commonParams23).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint50.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("SWBPortalService", "GetRoleCredentials", {}).n("SSOClient", "GetRoleCredentialsCommand").sc(GetRoleCredentials$7).build() {
      static {
        __name(this, "GetRoleCredentialsCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSO.js
var import_smithy_client187, commands23, SSO7;
var init_SSO7 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSO.js"() {
    import_smithy_client187 = __toESM(require_dist_cjs34());
    init_GetRoleCredentialsCommand7();
    init_SSOClient7();
    commands23 = {
      GetRoleCredentialsCommand: GetRoleCredentialsCommand7
    };
    SSO7 = class extends SSOClient7 {
      static {
        __name(this, "SSO");
      }
    };
    (0, import_smithy_client187.createAggregatedClient)(commands23, SSO7);
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/index.js
var init_commands24 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/index.js"() {
    init_GetRoleCredentialsCommand7();
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/models_0.js
var init_models_023 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/index.js
var sso_exports7 = {};
__export(sso_exports7, {
  $Command: () => import_smithy_client186.Command,
  GetRoleCredentials$: () => GetRoleCredentials$7,
  GetRoleCredentialsCommand: () => GetRoleCredentialsCommand7,
  GetRoleCredentialsRequest$: () => GetRoleCredentialsRequest$7,
  GetRoleCredentialsResponse$: () => GetRoleCredentialsResponse$7,
  InvalidRequestException: () => InvalidRequestException10,
  InvalidRequestException$: () => InvalidRequestException$10,
  ResourceNotFoundException: () => ResourceNotFoundException8,
  ResourceNotFoundException$: () => ResourceNotFoundException$8,
  RoleCredentials$: () => RoleCredentials$7,
  SSO: () => SSO7,
  SSOClient: () => SSOClient7,
  SSOServiceException: () => SSOServiceException7,
  SSOServiceException$: () => SSOServiceException$7,
  TooManyRequestsException: () => TooManyRequestsException8,
  TooManyRequestsException$: () => TooManyRequestsException$8,
  UnauthorizedException: () => UnauthorizedException7,
  UnauthorizedException$: () => UnauthorizedException$7,
  __Client: () => import_smithy_client185.Client,
  errorTypeRegistries: () => errorTypeRegistries23
});
var init_sso7 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/index.js"() {
    init_SSOClient7();
    init_SSO7();
    init_commands24();
    init_schemas_023();
    init_errors23();
    init_models_023();
    init_SSOServiceException7();
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/loadSso-BKDNrsal.js
var require_loadSso_BKDNrsal7 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/loadSso-BKDNrsal.js"(exports2) {
    "use strict";
    var sso = (init_sso7(), __toCommonJS(sso_exports7));
    exports2.GetRoleCredentialsCommand = sso.GetRoleCredentialsCommand;
    exports2.SSOClient = sso.SSOClient;
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/index.js
var require_dist_cjs173 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/index.js"(exports2) {
    "use strict";
    var propertyProvider = require_dist_cjs27();
    var sharedIniFileLoader = require_dist_cjs28();
    var client = (init_client17(), __toCommonJS(client_exports12));
    var tokenProviders = require_dist_cjs49();
    var isSsoProfile = /* @__PURE__ */ __name((arg) => arg && (typeof arg.sso_start_url === "string" || typeof arg.sso_account_id === "string" || typeof arg.sso_session === "string" || typeof arg.sso_region === "string" || typeof arg.sso_role_name === "string"), "isSsoProfile");
    var SHOULD_FAIL_CREDENTIAL_CHAIN = false;
    var resolveSSOCredentials = /* @__PURE__ */ __name(async ({ ssoStartUrl, ssoSession, ssoAccountId, ssoRegion, ssoRoleName, ssoClient, clientConfig, parentClientConfig, callerClientConfig, profile, filepath, configFilepath, ignoreCache, logger: logger5 }) => {
      let token;
      const refreshMessage = `To refresh this SSO session run aws sso login with the corresponding profile.`;
      if (ssoSession) {
        try {
          const _token = await tokenProviders.fromSso({
            profile,
            filepath,
            configFilepath,
            ignoreCache
          })();
          token = {
            accessToken: _token.token,
            expiresAt: new Date(_token.expiration).toISOString()
          };
        } catch (e32) {
          throw new propertyProvider.CredentialsProviderError(e32.message, {
            tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
            logger: logger5
          });
        }
      } else {
        try {
          token = await sharedIniFileLoader.getSSOTokenFromFile(ssoStartUrl);
        } catch (e32) {
          throw new propertyProvider.CredentialsProviderError(`The SSO session associated with this profile is invalid. ${refreshMessage}`, {
            tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
            logger: logger5
          });
        }
      }
      if (new Date(token.expiresAt).getTime() - Date.now() <= 0) {
        throw new propertyProvider.CredentialsProviderError(`The SSO session associated with this profile has expired. ${refreshMessage}`, {
          tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
          logger: logger5
        });
      }
      const { accessToken } = token;
      const { SSOClient: SSOClient10, GetRoleCredentialsCommand: GetRoleCredentialsCommand10 } = await Promise.resolve().then(function() {
        return require_loadSso_BKDNrsal7();
      });
      const sso = ssoClient || new SSOClient10(Object.assign({}, clientConfig ?? {}, {
        logger: clientConfig?.logger ?? callerClientConfig?.logger ?? parentClientConfig?.logger,
        region: clientConfig?.region ?? ssoRegion,
        userAgentAppId: clientConfig?.userAgentAppId ?? callerClientConfig?.userAgentAppId ?? parentClientConfig?.userAgentAppId
      }));
      let ssoResp;
      try {
        ssoResp = await sso.send(new GetRoleCredentialsCommand10({
          accountId: ssoAccountId,
          roleName: ssoRoleName,
          accessToken
        }));
      } catch (e32) {
        throw new propertyProvider.CredentialsProviderError(e32, {
          tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
          logger: logger5
        });
      }
      const { roleCredentials: { accessKeyId, secretAccessKey, sessionToken, expiration, credentialScope, accountId } = {} } = ssoResp;
      if (!accessKeyId || !secretAccessKey || !sessionToken || !expiration) {
        throw new propertyProvider.CredentialsProviderError("SSO returns an invalid temporary credential.", {
          tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
          logger: logger5
        });
      }
      const credentials = {
        accessKeyId,
        secretAccessKey,
        sessionToken,
        expiration: new Date(expiration),
        ...credentialScope && { credentialScope },
        ...accountId && { accountId }
      };
      if (ssoSession) {
        client.setCredentialFeature(credentials, "CREDENTIALS_SSO", "s");
      } else {
        client.setCredentialFeature(credentials, "CREDENTIALS_SSO_LEGACY", "u");
      }
      return credentials;
    }, "resolveSSOCredentials");
    var validateSsoProfile = /* @__PURE__ */ __name((profile, logger5) => {
      const { sso_start_url, sso_account_id, sso_region, sso_role_name } = profile;
      if (!sso_start_url || !sso_account_id || !sso_region || !sso_role_name) {
        throw new propertyProvider.CredentialsProviderError(`Profile is configured with invalid SSO credentials. Required parameters "sso_account_id", "sso_region", "sso_role_name", "sso_start_url". Got ${Object.keys(profile).join(", ")}
Reference: https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-sso.html`, { tryNextLink: false, logger: logger5 });
      }
      return profile;
    }, "validateSsoProfile");
    var fromSSO = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/credential-provider-sso - fromSSO");
      const { ssoStartUrl, ssoAccountId, ssoRegion, ssoRoleName, ssoSession } = init;
      const { ssoClient } = init;
      const profileName = sharedIniFileLoader.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      });
      if (!ssoStartUrl && !ssoAccountId && !ssoRegion && !ssoRoleName && !ssoSession) {
        const profiles = await sharedIniFileLoader.parseKnownFiles(init);
        const profile = profiles[profileName];
        if (!profile) {
          throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} was not found.`, { logger: init.logger });
        }
        if (!isSsoProfile(profile)) {
          throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} is not configured with SSO credentials.`, {
            logger: init.logger
          });
        }
        if (profile?.sso_session) {
          const ssoSessions = await sharedIniFileLoader.loadSsoSessionData(init);
          const session = ssoSessions[profile.sso_session];
          const conflictMsg = ` configurations in profile ${profileName} and sso-session ${profile.sso_session}`;
          if (ssoRegion && ssoRegion !== session.sso_region) {
            throw new propertyProvider.CredentialsProviderError(`Conflicting SSO region` + conflictMsg, {
              tryNextLink: false,
              logger: init.logger
            });
          }
          if (ssoStartUrl && ssoStartUrl !== session.sso_start_url) {
            throw new propertyProvider.CredentialsProviderError(`Conflicting SSO start_url` + conflictMsg, {
              tryNextLink: false,
              logger: init.logger
            });
          }
          profile.sso_region = session.sso_region;
          profile.sso_start_url = session.sso_start_url;
        }
        const { sso_start_url, sso_account_id, sso_region, sso_role_name, sso_session } = validateSsoProfile(profile, init.logger);
        return resolveSSOCredentials({
          ssoStartUrl: sso_start_url,
          ssoSession: sso_session,
          ssoAccountId: sso_account_id,
          ssoRegion: sso_region,
          ssoRoleName: sso_role_name,
          ssoClient,
          clientConfig: init.clientConfig,
          parentClientConfig: init.parentClientConfig,
          callerClientConfig: init.callerClientConfig,
          profile: profileName,
          filepath: init.filepath,
          configFilepath: init.configFilepath,
          ignoreCache: init.ignoreCache,
          logger: init.logger
        });
      } else if (!ssoStartUrl || !ssoAccountId || !ssoRegion || !ssoRoleName) {
        throw new propertyProvider.CredentialsProviderError('Incomplete configuration. The fromSSO() argument hash must include "ssoStartUrl", "ssoAccountId", "ssoRegion", "ssoRoleName"', { tryNextLink: false, logger: init.logger });
      } else {
        return resolveSSOCredentials({
          ssoStartUrl,
          ssoSession,
          ssoAccountId,
          ssoRegion,
          ssoRoleName,
          ssoClient,
          clientConfig: init.clientConfig,
          parentClientConfig: init.parentClientConfig,
          callerClientConfig: init.callerClientConfig,
          profile: profileName,
          filepath: init.filepath,
          configFilepath: init.configFilepath,
          ignoreCache: init.ignoreCache,
          logger: init.logger
        });
      }
    }, "fromSSO");
    exports2.fromSSO = fromSSO;
    exports2.isSsoProfile = isSsoProfile;
    exports2.validateSsoProfile = validateSsoProfile;
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption24(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "signin",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption24(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var import_util_middleware25, defaultSigninHttpAuthSchemeParametersProvider7, defaultSigninHttpAuthSchemeProvider7, resolveHttpAuthSchemeConfig24;
var init_httpAuthSchemeProvider24 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes10();
    import_util_middleware25 = __toESM(require_dist_cjs6());
    defaultSigninHttpAuthSchemeParametersProvider7 = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, import_util_middleware25.getSmithyContext)(context).operation,
        region: await (0, import_util_middleware25.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultSigninHttpAuthSchemeParametersProvider");
    __name(createAwsAuthSigv4HttpAuthOption24, "createAwsAuthSigv4HttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption24, "createSmithyApiNoAuthHttpAuthOption");
    defaultSigninHttpAuthSchemeProvider7 = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "CreateOAuth2Token": {
          options.push(createSmithyApiNoAuthHttpAuthOption24(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption24(authParameters));
        }
      }
      return options;
    }, "defaultSigninHttpAuthSchemeProvider");
    resolveHttpAuthSchemeConfig24 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveAwsSdkSigV4Config8(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, import_util_middleware25.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/EndpointParameters.js
var resolveClientEndpointParameters24, commonParams24;
var init_EndpointParameters24 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters24 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "signin"
      });
    }, "resolveClientEndpointParameters");
    commonParams24 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/bdd.js
var import_util_endpoints58, m14, a24, b24, c24, d24, e24, f24, g24, h24, i24, j24, k24, l14, _data24, root24, r24, nodes24, bdd24;
var init_bdd24 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/bdd.js"() {
    import_util_endpoints58 = __toESM(require_dist_cjs20());
    m14 = "ref";
    a24 = -1;
    b24 = true;
    c24 = "isSet";
    d24 = "PartitionResult";
    e24 = "booleanEquals";
    f24 = "getAttr";
    g24 = "stringEquals";
    h24 = { [m14]: "Endpoint" };
    i24 = { [m14]: d24 };
    j24 = { fn: f24, argv: [i24, "name"] };
    k24 = {};
    l14 = [{ [m14]: "Region" }];
    _data24 = {
      conditions: [
        [c24, [h24]],
        [c24, l14],
        ["aws.partition", l14, d24],
        [e24, [{ [m14]: "UseFIPS" }, b24]],
        [e24, [{ [m14]: "UseDualStack" }, b24]],
        [e24, [{ fn: f24, argv: [i24, "supportsDualStack"] }, b24]],
        [e24, [{ fn: f24, argv: [i24, "supportsFIPS"] }, b24]],
        [g24, [j24, "aws"]],
        [g24, [j24, "aws-cn"]],
        [g24, [j24, "aws-us-gov"]]
      ],
      results: [
        [a24],
        [a24, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a24, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [h24, k24],
        ["https://{Region}.signin.aws.amazon.com", k24],
        ["https://{Region}.signin.amazonaws.cn", k24],
        ["https://{Region}.signin.amazonaws-us-gov.com", k24],
        ["https://signin-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", k24],
        [a24, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://signin-fips.{Region}.{PartitionResult#dnsSuffix}", k24],
        [a24, "FIPS is enabled but this partition does not support FIPS"],
        ["https://signin.{Region}.{PartitionResult#dualStackDnsSuffix}", k24],
        [a24, "DualStack is enabled but this partition does not support DualStack"],
        ["https://signin.{Region}.{PartitionResult#dnsSuffix}", k24],
        [a24, "Invalid Configuration: Missing Region"]
      ]
    };
    root24 = 2;
    r24 = 1e8;
    nodes24 = new Int32Array([
      -1,
      1,
      -1,
      0,
      15,
      3,
      1,
      4,
      r24 + 14,
      2,
      5,
      r24 + 14,
      3,
      11,
      6,
      4,
      10,
      7,
      7,
      r24 + 4,
      8,
      8,
      r24 + 5,
      9,
      9,
      r24 + 6,
      r24 + 13,
      5,
      r24 + 11,
      r24 + 12,
      4,
      13,
      12,
      6,
      r24 + 9,
      r24 + 10,
      5,
      14,
      r24 + 8,
      6,
      r24 + 7,
      r24 + 8,
      3,
      r24 + 1,
      16,
      4,
      r24 + 2,
      r24 + 3
    ]);
    bdd24 = import_util_endpoints58.BinaryDecisionDiagram.from(nodes24, root24, _data24.conditions, _data24.results);
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/endpointResolver.js
var import_util_endpoints59, import_util_endpoints60, cache24, defaultEndpointResolver24;
var init_endpointResolver24 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/endpointResolver.js"() {
    import_util_endpoints59 = __toESM(require_dist_cjs21());
    import_util_endpoints60 = __toESM(require_dist_cjs20());
    init_bdd24();
    cache24 = new import_util_endpoints60.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    defaultEndpointResolver24 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache24.get(endpointParams, () => (0, import_util_endpoints60.decideEndpoint)(bdd24, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    import_util_endpoints60.customEndpointFunctions.aws = import_util_endpoints59.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/SigninServiceException.js
var import_smithy_client188, SigninServiceException7;
var init_SigninServiceException7 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/SigninServiceException.js"() {
    import_smithy_client188 = __toESM(require_dist_cjs34());
    SigninServiceException7 = class _SigninServiceException extends import_smithy_client188.ServiceException {
      static {
        __name(this, "SigninServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _SigninServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/errors.js
var AccessDeniedException10, InternalServerException10, TooManyRequestsError7, ValidationException7;
var init_errors24 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/errors.js"() {
    init_SigninServiceException7();
    AccessDeniedException10 = class _AccessDeniedException extends SigninServiceException7 {
      static {
        __name(this, "AccessDeniedException");
      }
      name = "AccessDeniedException";
      $fault = "client";
      error;
      constructor(opts) {
        super({
          name: "AccessDeniedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AccessDeniedException.prototype);
        this.error = opts.error;
      }
    };
    InternalServerException10 = class _InternalServerException extends SigninServiceException7 {
      static {
        __name(this, "InternalServerException");
      }
      name = "InternalServerException";
      $fault = "server";
      error;
      constructor(opts) {
        super({
          name: "InternalServerException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _InternalServerException.prototype);
        this.error = opts.error;
      }
    };
    TooManyRequestsError7 = class _TooManyRequestsError extends SigninServiceException7 {
      static {
        __name(this, "TooManyRequestsError");
      }
      name = "TooManyRequestsError";
      $fault = "client";
      error;
      constructor(opts) {
        super({
          name: "TooManyRequestsError",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyRequestsError.prototype);
        this.error = opts.error;
      }
    };
    ValidationException7 = class _ValidationException extends SigninServiceException7 {
      static {
        __name(this, "ValidationException");
      }
      name = "ValidationException";
      $fault = "client";
      error;
      constructor(opts) {
        super({
          name: "ValidationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ValidationException.prototype);
        this.error = opts.error;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/schemas/schemas_0.js
var _ADE10, _AT10, _COAT7, _COATR7, _COATRB7, _COATRBr7, _COATRr7, _ISE10, _RT10, _TMRE15, _VE7, _aKI14, _aT17, _c24, _cI10, _cV10, _co10, _e24, _eI10, _gT10, _h17, _hE24, _iT10, _jN7, _m21, _rT10, _rU10, _s24, _sAK14, _sT14, _se11, _tI7, _tO7, _tT10, n024, _s_registry24, SigninServiceException$7, n0_registry24, AccessDeniedException$10, InternalServerException$10, TooManyRequestsError$7, ValidationException$7, errorTypeRegistries24, RefreshToken10, AccessToken$7, CreateOAuth2TokenRequest$7, CreateOAuth2TokenRequestBody$7, CreateOAuth2TokenResponse$7, CreateOAuth2TokenResponseBody$7, CreateOAuth2Token$7;
var init_schemas_024 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/schemas/schemas_0.js"() {
    init_schema4();
    init_errors24();
    init_SigninServiceException7();
    _ADE10 = "AccessDeniedException";
    _AT10 = "AccessToken";
    _COAT7 = "CreateOAuth2Token";
    _COATR7 = "CreateOAuth2TokenRequest";
    _COATRB7 = "CreateOAuth2TokenRequestBody";
    _COATRBr7 = "CreateOAuth2TokenResponseBody";
    _COATRr7 = "CreateOAuth2TokenResponse";
    _ISE10 = "InternalServerException";
    _RT10 = "RefreshToken";
    _TMRE15 = "TooManyRequestsError";
    _VE7 = "ValidationException";
    _aKI14 = "accessKeyId";
    _aT17 = "accessToken";
    _c24 = "client";
    _cI10 = "clientId";
    _cV10 = "codeVerifier";
    _co10 = "code";
    _e24 = "error";
    _eI10 = "expiresIn";
    _gT10 = "grantType";
    _h17 = "http";
    _hE24 = "httpError";
    _iT10 = "idToken";
    _jN7 = "jsonName";
    _m21 = "message";
    _rT10 = "refreshToken";
    _rU10 = "redirectUri";
    _s24 = "smithy.ts.sdk.synthetic.com.amazonaws.signin";
    _sAK14 = "secretAccessKey";
    _sT14 = "sessionToken";
    _se11 = "server";
    _tI7 = "tokenInput";
    _tO7 = "tokenOutput";
    _tT10 = "tokenType";
    n024 = "com.amazonaws.signin";
    _s_registry24 = TypeRegistry.for(_s24);
    SigninServiceException$7 = [-3, _s24, "SigninServiceException", 0, [], []];
    _s_registry24.registerError(SigninServiceException$7, SigninServiceException7);
    n0_registry24 = TypeRegistry.for(n024);
    AccessDeniedException$10 = [-3, n024, _ADE10, { [_e24]: _c24 }, [_e24, _m21], [0, 0], 2];
    n0_registry24.registerError(AccessDeniedException$10, AccessDeniedException10);
    InternalServerException$10 = [-3, n024, _ISE10, { [_e24]: _se11, [_hE24]: 500 }, [_e24, _m21], [0, 0], 2];
    n0_registry24.registerError(InternalServerException$10, InternalServerException10);
    TooManyRequestsError$7 = [-3, n024, _TMRE15, { [_e24]: _c24, [_hE24]: 429 }, [_e24, _m21], [0, 0], 2];
    n0_registry24.registerError(TooManyRequestsError$7, TooManyRequestsError7);
    ValidationException$7 = [-3, n024, _VE7, { [_e24]: _c24, [_hE24]: 400 }, [_e24, _m21], [0, 0], 2];
    n0_registry24.registerError(ValidationException$7, ValidationException7);
    errorTypeRegistries24 = [_s_registry24, n0_registry24];
    RefreshToken10 = [0, n024, _RT10, 8, 0];
    AccessToken$7 = [
      3,
      n024,
      _AT10,
      8,
      [_aKI14, _sAK14, _sT14],
      [
        [0, { [_jN7]: _aKI14 }],
        [0, { [_jN7]: _sAK14 }],
        [0, { [_jN7]: _sT14 }]
      ],
      3
    ];
    CreateOAuth2TokenRequest$7 = [
      3,
      n024,
      _COATR7,
      0,
      [_tI7],
      [[() => CreateOAuth2TokenRequestBody$7, 16]],
      1
    ];
    CreateOAuth2TokenRequestBody$7 = [
      3,
      n024,
      _COATRB7,
      0,
      [_cI10, _gT10, _co10, _rU10, _cV10, _rT10],
      [
        [0, { [_jN7]: _cI10 }],
        [0, { [_jN7]: _gT10 }],
        0,
        [0, { [_jN7]: _rU10 }],
        [0, { [_jN7]: _cV10 }],
        [() => RefreshToken10, { [_jN7]: _rT10 }]
      ],
      2
    ];
    CreateOAuth2TokenResponse$7 = [
      3,
      n024,
      _COATRr7,
      0,
      [_tO7],
      [[() => CreateOAuth2TokenResponseBody$7, 16]],
      1
    ];
    CreateOAuth2TokenResponseBody$7 = [
      3,
      n024,
      _COATRBr7,
      0,
      [_aT17, _tT10, _eI10, _rT10, _iT10],
      [
        [() => AccessToken$7, { [_jN7]: _aT17 }],
        [0, { [_jN7]: _tT10 }],
        [1, { [_jN7]: _eI10 }],
        [() => RefreshToken10, { [_jN7]: _rT10 }],
        [0, { [_jN7]: _iT10 }]
      ],
      4
    ];
    CreateOAuth2Token$7 = [
      9,
      n024,
      _COAT7,
      { [_h17]: ["POST", "/v1/token", 200] },
      () => CreateOAuth2TokenRequest$7,
      () => CreateOAuth2TokenResponse$7
    ];
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.shared.js
var import_smithy_client189, import_url_parser21, import_util_base6452, import_util_utf840, getRuntimeConfig47;
var init_runtimeConfig_shared24 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.shared.js"() {
    init_httpAuthSchemes10();
    init_protocols16();
    init_dist_es();
    import_smithy_client189 = __toESM(require_dist_cjs34());
    import_url_parser21 = __toESM(require_dist_cjs18());
    import_util_base6452 = __toESM(require_dist_cjs10());
    import_util_utf840 = __toESM(require_dist_cjs9());
    init_httpAuthSchemeProvider24();
    init_endpointResolver24();
    init_schemas_024();
    getRuntimeConfig47 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2023-01-01",
        base64Decoder: config2?.base64Decoder ?? import_util_base6452.fromBase64,
        base64Encoder: config2?.base64Encoder ?? import_util_base6452.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver24,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSigninHttpAuthSchemeProvider7,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer8()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        logger: config2?.logger ?? new import_smithy_client189.NoOpLogger(),
        protocol: config2?.protocol ?? AwsRestJsonProtocol9,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.signin",
          errorTypeRegistries: errorTypeRegistries24,
          version: "2023-01-01",
          serviceTarget: "Signin"
        },
        serviceId: config2?.serviceId ?? "Signin",
        urlParser: config2?.urlParser ?? import_url_parser21.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? import_util_utf840.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? import_util_utf840.toUtf8
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.js
var import_util_user_agent_node20, import_config_resolver40, import_hash_node22, import_middleware_retry39, import_node_config_provider21, import_node_http_handler24, import_smithy_client190, import_util_body_length_node20, import_util_defaults_mode_node20, import_util_retry29, getRuntimeConfig48;
var init_runtimeConfig24 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.js"() {
    init_package8();
    init_client17();
    init_httpAuthSchemes10();
    import_util_user_agent_node20 = __toESM(require_dist_cjs172());
    import_config_resolver40 = __toESM(require_dist_cjs25());
    import_hash_node22 = __toESM(require_dist_cjs44());
    import_middleware_retry39 = __toESM(require_dist_cjs168());
    import_node_config_provider21 = __toESM(require_dist_cjs29());
    import_node_http_handler24 = __toESM(require_dist_cjs13());
    import_smithy_client190 = __toESM(require_dist_cjs34());
    import_util_body_length_node20 = __toESM(require_dist_cjs45());
    import_util_defaults_mode_node20 = __toESM(require_dist_cjs46());
    import_util_retry29 = __toESM(require_dist_cjs22());
    init_runtimeConfig_shared24();
    getRuntimeConfig48 = /* @__PURE__ */ __name((config2) => {
      (0, import_smithy_client190.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, import_util_defaults_mode_node20.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(import_smithy_client190.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig47(config2);
      emitWarningIfUnsupportedVersion30(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, import_node_config_provider21.loadConfig)(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS8, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? import_util_body_length_node20.calculateBodyLength,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, import_util_user_agent_node20.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_default8.version }),
        maxAttempts: config2?.maxAttempts ?? (0, import_node_config_provider21.loadConfig)(import_middleware_retry39.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, import_node_config_provider21.loadConfig)(import_config_resolver40.NODE_REGION_CONFIG_OPTIONS, { ...import_config_resolver40.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: import_node_http_handler24.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, import_node_config_provider21.loadConfig)({
          ...import_middleware_retry39.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || import_util_retry29.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? import_hash_node22.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? import_node_http_handler24.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, import_node_config_provider21.loadConfig)(import_config_resolver40.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, import_node_config_provider21.loadConfig)(import_config_resolver40.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, import_node_config_provider21.loadConfig)(import_util_user_agent_node20.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration24, resolveHttpAuthRuntimeConfig24;
var init_httpAuthExtensionConfiguration24 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration24 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig24 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeExtensions.js
var import_region_config_resolver25, import_protocol_http49, import_smithy_client191, resolveRuntimeExtensions24;
var init_runtimeExtensions24 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeExtensions.js"() {
    import_region_config_resolver25 = __toESM(require_dist_cjs48());
    import_protocol_http49 = __toESM(require_dist_cjs2());
    import_smithy_client191 = __toESM(require_dist_cjs34());
    init_httpAuthExtensionConfiguration24();
    resolveRuntimeExtensions24 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign((0, import_region_config_resolver25.getAwsRegionExtensionConfiguration)(runtimeConfig), (0, import_smithy_client191.getDefaultExtensionConfiguration)(runtimeConfig), (0, import_protocol_http49.getHttpHandlerExtensionConfiguration)(runtimeConfig), getHttpAuthExtensionConfiguration24(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, (0, import_region_config_resolver25.resolveAwsRegionExtensionConfiguration)(extensionConfiguration), (0, import_smithy_client191.resolveDefaultRuntimeConfig)(extensionConfiguration), (0, import_protocol_http49.resolveHttpHandlerRuntimeConfig)(extensionConfiguration), resolveHttpAuthRuntimeConfig24(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/SigninClient.js
var import_middleware_host_header20, import_middleware_logger20, import_middleware_recursion_detection20, import_middleware_user_agent20, import_config_resolver41, import_middleware_content_length20, import_middleware_endpoint51, import_middleware_retry40, import_smithy_client192, SigninClient7;
var init_SigninClient7 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/SigninClient.js"() {
    import_middleware_host_header20 = __toESM(require_dist_cjs3());
    import_middleware_logger20 = __toESM(require_dist_cjs4());
    import_middleware_recursion_detection20 = __toESM(require_dist_cjs5());
    import_middleware_user_agent20 = __toESM(require_dist_cjs167());
    import_config_resolver41 = __toESM(require_dist_cjs25());
    init_dist_es();
    init_schema4();
    import_middleware_content_length20 = __toESM(require_dist_cjs26());
    import_middleware_endpoint51 = __toESM(require_dist_cjs31());
    import_middleware_retry40 = __toESM(require_dist_cjs168());
    import_smithy_client192 = __toESM(require_dist_cjs34());
    init_httpAuthSchemeProvider24();
    init_EndpointParameters24();
    init_runtimeConfig24();
    init_runtimeExtensions24();
    SigninClient7 = class extends import_smithy_client192.Client {
      static {
        __name(this, "SigninClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig48(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters24(_config_0);
        const _config_2 = (0, import_middleware_user_agent20.resolveUserAgentConfig)(_config_1);
        const _config_3 = (0, import_middleware_retry40.resolveRetryConfig)(_config_2);
        const _config_4 = (0, import_config_resolver41.resolveRegionConfig)(_config_3);
        const _config_5 = (0, import_middleware_host_header20.resolveHostHeaderConfig)(_config_4);
        const _config_6 = (0, import_middleware_endpoint51.resolveEndpointConfig)(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig24(_config_6);
        const _config_8 = resolveRuntimeExtensions24(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin(this.config));
        this.middlewareStack.use((0, import_middleware_user_agent20.getUserAgentPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_retry40.getRetryPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_content_length20.getContentLengthPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_host_header20.getHostHeaderPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_logger20.getLoggerPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_recursion_detection20.getRecursionDetectionPlugin)(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: defaultSigninHttpAuthSchemeParametersProvider7,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/CreateOAuth2TokenCommand.js
var import_middleware_endpoint52, import_smithy_client193, CreateOAuth2TokenCommand7;
var init_CreateOAuth2TokenCommand7 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/CreateOAuth2TokenCommand.js"() {
    import_middleware_endpoint52 = __toESM(require_dist_cjs31());
    import_smithy_client193 = __toESM(require_dist_cjs34());
    init_EndpointParameters24();
    init_schemas_024();
    CreateOAuth2TokenCommand7 = class extends import_smithy_client193.Command.classBuilder().ep(commonParams24).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint52.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("Signin", "CreateOAuth2Token", {}).n("SigninClient", "CreateOAuth2TokenCommand").sc(CreateOAuth2Token$7).build() {
      static {
        __name(this, "CreateOAuth2TokenCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/Signin.js
var import_smithy_client194, commands24, Signin7;
var init_Signin7 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/Signin.js"() {
    import_smithy_client194 = __toESM(require_dist_cjs34());
    init_CreateOAuth2TokenCommand7();
    init_SigninClient7();
    commands24 = {
      CreateOAuth2TokenCommand: CreateOAuth2TokenCommand7
    };
    Signin7 = class extends SigninClient7 {
      static {
        __name(this, "Signin");
      }
    };
    (0, import_smithy_client194.createAggregatedClient)(commands24, Signin7);
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/index.js
var init_commands25 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/index.js"() {
    init_CreateOAuth2TokenCommand7();
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/enums.js
var OAuth2ErrorCode7;
var init_enums10 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/enums.js"() {
    OAuth2ErrorCode7 = {
      AUTHCODE_EXPIRED: "AUTHCODE_EXPIRED",
      INSUFFICIENT_PERMISSIONS: "INSUFFICIENT_PERMISSIONS",
      INVALID_REQUEST: "INVALID_REQUEST",
      SERVER_ERROR: "server_error",
      TOKEN_EXPIRED: "TOKEN_EXPIRED",
      USER_CREDENTIALS_CHANGED: "USER_CREDENTIALS_CHANGED"
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/models_0.js
var init_models_024 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/index.js
var signin_exports7 = {};
__export(signin_exports7, {
  $Command: () => import_smithy_client193.Command,
  AccessDeniedException: () => AccessDeniedException10,
  AccessDeniedException$: () => AccessDeniedException$10,
  AccessToken$: () => AccessToken$7,
  CreateOAuth2Token$: () => CreateOAuth2Token$7,
  CreateOAuth2TokenCommand: () => CreateOAuth2TokenCommand7,
  CreateOAuth2TokenRequest$: () => CreateOAuth2TokenRequest$7,
  CreateOAuth2TokenRequestBody$: () => CreateOAuth2TokenRequestBody$7,
  CreateOAuth2TokenResponse$: () => CreateOAuth2TokenResponse$7,
  CreateOAuth2TokenResponseBody$: () => CreateOAuth2TokenResponseBody$7,
  InternalServerException: () => InternalServerException10,
  InternalServerException$: () => InternalServerException$10,
  OAuth2ErrorCode: () => OAuth2ErrorCode7,
  Signin: () => Signin7,
  SigninClient: () => SigninClient7,
  SigninServiceException: () => SigninServiceException7,
  SigninServiceException$: () => SigninServiceException$7,
  TooManyRequestsError: () => TooManyRequestsError7,
  TooManyRequestsError$: () => TooManyRequestsError$7,
  ValidationException: () => ValidationException7,
  ValidationException$: () => ValidationException$7,
  __Client: () => import_smithy_client192.Client,
  errorTypeRegistries: () => errorTypeRegistries24
});
var init_signin7 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/index.js"() {
    init_SigninClient7();
    init_Signin7();
    init_commands25();
    init_schemas_024();
    init_enums10();
    init_errors24();
    init_models_024();
    init_SigninServiceException7();
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-login/dist-cjs/index.js
var require_dist_cjs174 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-login/dist-cjs/index.js"(exports2) {
    "use strict";
    var client = (init_client17(), __toCommonJS(client_exports12));
    var propertyProvider = require_dist_cjs27();
    var sharedIniFileLoader = require_dist_cjs28();
    var protocolHttp = require_dist_cjs2();
    var node_crypto = require("node:crypto");
    var node_fs = require("node:fs");
    var node_os = require("node:os");
    var node_path = require("node:path");
    var LoginCredentialsFetcher = class _LoginCredentialsFetcher {
      static {
        __name(this, "LoginCredentialsFetcher");
      }
      profileData;
      init;
      callerClientConfig;
      static REFRESH_THRESHOLD = 5 * 60 * 1e3;
      constructor(profileData, init, callerClientConfig) {
        this.profileData = profileData;
        this.init = init;
        this.callerClientConfig = callerClientConfig;
      }
      async loadCredentials() {
        const token = await this.loadToken();
        if (!token) {
          throw new propertyProvider.CredentialsProviderError(`Failed to load a token for session ${this.loginSession}, please re-authenticate using aws login`, { tryNextLink: false, logger: this.logger });
        }
        const accessToken = token.accessToken;
        const now = Date.now();
        const expiryTime = new Date(accessToken.expiresAt).getTime();
        const timeUntilExpiry = expiryTime - now;
        if (timeUntilExpiry <= _LoginCredentialsFetcher.REFRESH_THRESHOLD) {
          return this.refresh(token);
        }
        return {
          accessKeyId: accessToken.accessKeyId,
          secretAccessKey: accessToken.secretAccessKey,
          sessionToken: accessToken.sessionToken,
          accountId: accessToken.accountId,
          expiration: new Date(accessToken.expiresAt)
        };
      }
      get logger() {
        return this.init?.logger;
      }
      get loginSession() {
        return this.profileData.login_session;
      }
      async refresh(token) {
        const { SigninClient: SigninClient10, CreateOAuth2TokenCommand: CreateOAuth2TokenCommand10 } = await Promise.resolve().then(() => (init_signin7(), signin_exports7));
        const { logger: logger5, userAgentAppId } = this.callerClientConfig ?? {};
        const isH210 = /* @__PURE__ */ __name((requestHandler2) => {
          return requestHandler2?.metadata?.handlerProtocol === "h2";
        }, "isH2");
        const requestHandler = isH210(this.callerClientConfig?.requestHandler) ? void 0 : this.callerClientConfig?.requestHandler;
        const region = this.profileData.region ?? await this.callerClientConfig?.region?.() ?? process.env.AWS_REGION;
        const client2 = new SigninClient10({
          credentials: {
            accessKeyId: "",
            secretAccessKey: ""
          },
          region,
          requestHandler,
          logger: logger5,
          userAgentAppId,
          ...this.init?.clientConfig
        });
        this.createDPoPInterceptor(client2.middlewareStack);
        const commandInput = {
          tokenInput: {
            clientId: token.clientId,
            refreshToken: token.refreshToken,
            grantType: "refresh_token"
          }
        };
        try {
          const response = await client2.send(new CreateOAuth2TokenCommand10(commandInput));
          const { accessKeyId, secretAccessKey, sessionToken } = response.tokenOutput?.accessToken ?? {};
          const { refreshToken, expiresIn } = response.tokenOutput ?? {};
          if (!accessKeyId || !secretAccessKey || !sessionToken || !refreshToken) {
            throw new propertyProvider.CredentialsProviderError("Token refresh response missing required fields", {
              logger: this.logger,
              tryNextLink: false
            });
          }
          const expiresInMs = (expiresIn ?? 900) * 1e3;
          const expiration = new Date(Date.now() + expiresInMs);
          const updatedToken = {
            ...token,
            accessToken: {
              ...token.accessToken,
              accessKeyId,
              secretAccessKey,
              sessionToken,
              expiresAt: expiration.toISOString()
            },
            refreshToken
          };
          await this.saveToken(updatedToken);
          const newAccessToken = updatedToken.accessToken;
          return {
            accessKeyId: newAccessToken.accessKeyId,
            secretAccessKey: newAccessToken.secretAccessKey,
            sessionToken: newAccessToken.sessionToken,
            accountId: newAccessToken.accountId,
            expiration
          };
        } catch (error4) {
          if (error4.name === "AccessDeniedException") {
            const errorType = error4.error;
            let message2;
            switch (errorType) {
              case "TOKEN_EXPIRED":
                message2 = "Your session has expired. Please reauthenticate.";
                break;
              case "USER_CREDENTIALS_CHANGED":
                message2 = "Unable to refresh credentials because of a change in your password. Please reauthenticate with your new password.";
                break;
              case "INSUFFICIENT_PERMISSIONS":
                message2 = "Unable to refresh credentials due to insufficient permissions. You may be missing permission for the 'CreateOAuth2Token' action.";
                break;
              default:
                message2 = `Failed to refresh token: ${String(error4)}. Please re-authenticate using \`aws login\``;
            }
            throw new propertyProvider.CredentialsProviderError(message2, { logger: this.logger, tryNextLink: false });
          }
          throw new propertyProvider.CredentialsProviderError(`Failed to refresh token: ${String(error4)}. Please re-authenticate using aws login`, { logger: this.logger });
        }
      }
      async loadToken() {
        const tokenFilePath = this.getTokenFilePath();
        try {
          let tokenData;
          try {
            tokenData = await sharedIniFileLoader.readFile(tokenFilePath, { ignoreCache: this.init?.ignoreCache });
          } catch {
            tokenData = await node_fs.promises.readFile(tokenFilePath, "utf8");
          }
          const token = JSON.parse(tokenData);
          const missingFields = ["accessToken", "clientId", "refreshToken", "dpopKey"].filter((k32) => !token[k32]);
          if (!token.accessToken?.accountId) {
            missingFields.push("accountId");
          }
          if (missingFields.length > 0) {
            throw new propertyProvider.CredentialsProviderError(`Token validation failed, missing fields: ${missingFields.join(", ")}`, {
              logger: this.logger,
              tryNextLink: false
            });
          }
          return token;
        } catch (error4) {
          throw new propertyProvider.CredentialsProviderError(`Failed to load token from ${tokenFilePath}: ${String(error4)}`, {
            logger: this.logger,
            tryNextLink: false
          });
        }
      }
      async saveToken(token) {
        const tokenFilePath = this.getTokenFilePath();
        const directory = node_path.dirname(tokenFilePath);
        try {
          await node_fs.promises.mkdir(directory, { recursive: true });
        } catch (error4) {
        }
        await node_fs.promises.writeFile(tokenFilePath, JSON.stringify(token, null, 2), "utf8");
      }
      getTokenFilePath() {
        const directory = process.env.AWS_LOGIN_CACHE_DIRECTORY ?? node_path.join(node_os.homedir(), ".aws", "login", "cache");
        const loginSessionBytes = Buffer.from(this.loginSession, "utf8");
        const loginSessionSha256 = node_crypto.createHash("sha256").update(loginSessionBytes).digest("hex");
        return node_path.join(directory, `${loginSessionSha256}.json`);
      }
      derToRawSignature(derSignature) {
        let offset = 2;
        if (derSignature[offset] !== 2) {
          throw new Error("Invalid DER signature");
        }
        offset++;
        const rLength = derSignature[offset++];
        let r32 = derSignature.subarray(offset, offset + rLength);
        offset += rLength;
        if (derSignature[offset] !== 2) {
          throw new Error("Invalid DER signature");
        }
        offset++;
        const sLength = derSignature[offset++];
        let s = derSignature.subarray(offset, offset + sLength);
        r32 = r32[0] === 0 ? r32.subarray(1) : r32;
        s = s[0] === 0 ? s.subarray(1) : s;
        const rPadded = Buffer.concat([Buffer.alloc(32 - r32.length), r32]);
        const sPadded = Buffer.concat([Buffer.alloc(32 - s.length), s]);
        return Buffer.concat([rPadded, sPadded]);
      }
      createDPoPInterceptor(middlewareStack) {
        middlewareStack.add((next) => async (args) => {
          if (protocolHttp.HttpRequest.isInstance(args.request)) {
            const request4 = args.request;
            const actualEndpoint = `${request4.protocol}//${request4.hostname}${request4.port ? `:${request4.port}` : ""}${request4.path}`;
            const dpop = await this.generateDpop(request4.method, actualEndpoint);
            request4.headers = {
              ...request4.headers,
              DPoP: dpop
            };
          }
          return next(args);
        }, {
          step: "finalizeRequest",
          name: "dpopInterceptor",
          override: true
        });
      }
      async generateDpop(method = "POST", endpoint) {
        const token = await this.loadToken();
        try {
          const privateKey = node_crypto.createPrivateKey({
            key: token.dpopKey,
            format: "pem",
            type: "sec1"
          });
          const publicKey = node_crypto.createPublicKey(privateKey);
          const publicDer = publicKey.export({ format: "der", type: "spki" });
          let pointStart = -1;
          for (let i32 = 0; i32 < publicDer.length; i32++) {
            if (publicDer[i32] === 4) {
              pointStart = i32;
              break;
            }
          }
          const x = publicDer.slice(pointStart + 1, pointStart + 33);
          const y = publicDer.slice(pointStart + 33, pointStart + 65);
          const header = {
            alg: "ES256",
            typ: "dpop+jwt",
            jwk: {
              kty: "EC",
              crv: "P-256",
              x: x.toString("base64url"),
              y: y.toString("base64url")
            }
          };
          const payload3 = {
            jti: crypto.randomUUID(),
            htm: method,
            htu: endpoint,
            iat: Math.floor(Date.now() / 1e3)
          };
          const headerB64 = Buffer.from(JSON.stringify(header)).toString("base64url");
          const payloadB64 = Buffer.from(JSON.stringify(payload3)).toString("base64url");
          const message2 = `${headerB64}.${payloadB64}`;
          const asn1Signature = node_crypto.sign("sha256", Buffer.from(message2), privateKey);
          const rawSignature = this.derToRawSignature(asn1Signature);
          const signatureB64 = rawSignature.toString("base64url");
          return `${message2}.${signatureB64}`;
        } catch (error4) {
          throw new propertyProvider.CredentialsProviderError(`Failed to generate Dpop proof: ${error4 instanceof Error ? error4.message : String(error4)}`, { logger: this.logger, tryNextLink: false });
        }
      }
    };
    var fromLoginCredentials = /* @__PURE__ */ __name((init) => async ({ callerClientConfig } = {}) => {
      init?.logger?.debug?.("@aws-sdk/credential-providers - fromLoginCredentials");
      const profiles = await sharedIniFileLoader.parseKnownFiles(init || {});
      const profileName = sharedIniFileLoader.getProfileName({
        profile: init?.profile ?? callerClientConfig?.profile
      });
      const profile = profiles[profileName];
      if (!profile?.login_session) {
        throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} does not contain login_session.`, {
          tryNextLink: true,
          logger: init?.logger
        });
      }
      const fetcher = new LoginCredentialsFetcher(profile, init, callerClientConfig);
      const credentials = await fetcher.loadCredentials();
      return client.setCredentialFeature(credentials, "CREDENTIALS_LOGIN", "AD");
    }, "fromLoginCredentials");
    exports2.fromLoginCredentials = fromLoginCredentials;
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/bdd.js
var import_util_endpoints61, q7, a25, b25, c25, d25, e25, f25, g25, h25, i25, j25, k25, l15, m15, n7, o7, p7, _data25, root25, r25, nodes25, bdd25;
var init_bdd25 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/bdd.js"() {
    import_util_endpoints61 = __toESM(require_dist_cjs20());
    q7 = "ref";
    a25 = -1;
    b25 = true;
    c25 = "isSet";
    d25 = "PartitionResult";
    e25 = "booleanEquals";
    f25 = "stringEquals";
    g25 = "getAttr";
    h25 = "us-east-1";
    i25 = "sigv4";
    j25 = "sts";
    k25 = "https://sts.{Region}.{PartitionResult#dnsSuffix}";
    l15 = { [q7]: "Endpoint" };
    m15 = { [q7]: "Region" };
    n7 = { [q7]: d25 };
    o7 = {};
    p7 = [m15];
    _data25 = {
      conditions: [
        [c25, [l15]],
        [c25, p7],
        ["aws.partition", p7, d25],
        [e25, [{ [q7]: "UseFIPS" }, b25]],
        [e25, [{ [q7]: "UseDualStack" }, b25]],
        [f25, [m15, "aws-global"]],
        [e25, [{ [q7]: "UseGlobalEndpoint" }, b25]],
        [f25, [m15, "eu-central-1"]],
        [e25, [{ fn: g25, argv: [n7, "supportsDualStack"] }, b25]],
        [e25, [{ fn: g25, argv: [n7, "supportsFIPS"] }, b25]],
        [f25, [m15, "ap-south-1"]],
        [f25, [m15, "eu-north-1"]],
        [f25, [m15, "eu-west-1"]],
        [f25, [m15, "eu-west-2"]],
        [f25, [m15, "eu-west-3"]],
        [f25, [m15, "sa-east-1"]],
        [f25, [m15, h25]],
        [f25, [m15, "us-east-2"]],
        [f25, [m15, "us-west-2"]],
        [f25, [m15, "us-west-1"]],
        [f25, [m15, "ca-central-1"]],
        [f25, [m15, "ap-southeast-1"]],
        [f25, [m15, "ap-northeast-1"]],
        [f25, [m15, "ap-southeast-2"]],
        [f25, [{ fn: g25, argv: [n7, "name"] }, "aws-us-gov"]]
      ],
      results: [
        [a25],
        ["https://sts.amazonaws.com", { authSchemes: [{ name: i25, signingName: j25, signingRegion: h25 }] }],
        [k25, { authSchemes: [{ name: i25, signingName: j25, signingRegion: "{Region}" }] }],
        [a25, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a25, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [l15, o7],
        ["https://sts-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", o7],
        [a25, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://sts.{Region}.amazonaws.com", o7],
        ["https://sts-fips.{Region}.{PartitionResult#dnsSuffix}", o7],
        [a25, "FIPS is enabled but this partition does not support FIPS"],
        ["https://sts.{Region}.{PartitionResult#dualStackDnsSuffix}", o7],
        [a25, "DualStack is enabled but this partition does not support DualStack"],
        [k25, o7],
        [a25, "Invalid Configuration: Missing Region"]
      ]
    };
    root25 = 2;
    r25 = 1e8;
    nodes25 = new Int32Array([
      -1,
      1,
      -1,
      0,
      30,
      3,
      1,
      4,
      r25 + 14,
      2,
      5,
      r25 + 14,
      3,
      25,
      6,
      4,
      24,
      7,
      5,
      r25 + 1,
      8,
      6,
      9,
      r25 + 13,
      7,
      r25 + 1,
      10,
      10,
      r25 + 1,
      11,
      11,
      r25 + 1,
      12,
      12,
      r25 + 1,
      13,
      13,
      r25 + 1,
      14,
      14,
      r25 + 1,
      15,
      15,
      r25 + 1,
      16,
      16,
      r25 + 1,
      17,
      17,
      r25 + 1,
      18,
      18,
      r25 + 1,
      19,
      19,
      r25 + 1,
      20,
      20,
      r25 + 1,
      21,
      21,
      r25 + 1,
      22,
      22,
      r25 + 1,
      23,
      23,
      r25 + 1,
      r25 + 2,
      8,
      r25 + 11,
      r25 + 12,
      4,
      28,
      26,
      9,
      27,
      r25 + 10,
      24,
      r25 + 8,
      r25 + 9,
      8,
      29,
      r25 + 7,
      9,
      r25 + 6,
      r25 + 7,
      3,
      r25 + 3,
      31,
      4,
      r25 + 4,
      r25 + 5
    ]);
    bdd25 = import_util_endpoints61.BinaryDecisionDiagram.from(nodes25, root25, _data25.conditions, _data25.results);
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/endpointResolver.js
var import_util_endpoints62, import_util_endpoints63, cache25, defaultEndpointResolver25;
var init_endpointResolver25 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/endpointResolver.js"() {
    import_util_endpoints62 = __toESM(require_dist_cjs21());
    import_util_endpoints63 = __toESM(require_dist_cjs20());
    init_bdd25();
    cache25 = new import_util_endpoints63.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS", "UseGlobalEndpoint"]
    });
    defaultEndpointResolver25 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache25.get(endpointParams, () => (0, import_util_endpoints63.decideEndpoint)(bdd25, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    import_util_endpoints63.customEndpointFunctions.aws = import_util_endpoints62.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption25(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "sts",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createAwsAuthSigv4aHttpAuthOption7(authParameters) {
  return {
    schemeId: "aws.auth#sigv4a",
    signingProperties: {
      name: "sts",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption25(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var import_signature_v4_multi_region13, import_middleware_endpoint53, import_util_middleware26, createEndpointRuleSetHttpAuthSchemeParametersProvider7, _defaultSTSHttpAuthSchemeParametersProvider7, defaultSTSHttpAuthSchemeParametersProvider7, createEndpointRuleSetHttpAuthSchemeProvider7, _defaultSTSHttpAuthSchemeProvider7, defaultSTSHttpAuthSchemeProvider7, resolveStsAuthConfig6, resolveHttpAuthSchemeConfig25;
var init_httpAuthSchemeProvider25 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes10();
    import_signature_v4_multi_region13 = __toESM(require_dist_cjs55());
    import_middleware_endpoint53 = __toESM(require_dist_cjs31());
    import_util_middleware26 = __toESM(require_dist_cjs6());
    init_endpointResolver25();
    init_STSClient7();
    createEndpointRuleSetHttpAuthSchemeParametersProvider7 = /* @__PURE__ */ __name((defaultHttpAuthSchemeParametersProvider) => async (config2, context, input) => {
      if (!input) {
        throw new Error("Could not find `input` for `defaultEndpointRuleSetHttpAuthSchemeParametersProvider`");
      }
      const defaultParameters = await defaultHttpAuthSchemeParametersProvider(config2, context, input);
      const instructionsFn = (0, import_util_middleware26.getSmithyContext)(context)?.commandInstance?.constructor?.getEndpointParameterInstructions;
      if (!instructionsFn) {
        throw new Error(`getEndpointParameterInstructions() is not defined on '${context.commandName}'`);
      }
      const endpointParameters = await (0, import_middleware_endpoint53.resolveParams)(input, { getEndpointParameterInstructions: instructionsFn }, config2);
      return Object.assign(defaultParameters, endpointParameters);
    }, "createEndpointRuleSetHttpAuthSchemeParametersProvider");
    _defaultSTSHttpAuthSchemeParametersProvider7 = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, import_util_middleware26.getSmithyContext)(context).operation,
        region: await (0, import_util_middleware26.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "_defaultSTSHttpAuthSchemeParametersProvider");
    defaultSTSHttpAuthSchemeParametersProvider7 = createEndpointRuleSetHttpAuthSchemeParametersProvider7(_defaultSTSHttpAuthSchemeParametersProvider7);
    __name(createAwsAuthSigv4HttpAuthOption25, "createAwsAuthSigv4HttpAuthOption");
    __name(createAwsAuthSigv4aHttpAuthOption7, "createAwsAuthSigv4aHttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption25, "createSmithyApiNoAuthHttpAuthOption");
    createEndpointRuleSetHttpAuthSchemeProvider7 = /* @__PURE__ */ __name((defaultEndpointResolver32, defaultHttpAuthSchemeResolver, createHttpAuthOptionFunctions) => {
      const endpointRuleSetHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
        const endpoint = defaultEndpointResolver32(authParameters);
        const authSchemes = endpoint.properties?.authSchemes;
        if (!authSchemes) {
          return defaultHttpAuthSchemeResolver(authParameters);
        }
        const options = [];
        for (const scheme of authSchemes) {
          const { name: resolvedName, properties = {}, ...rest } = scheme;
          const name = resolvedName.toLowerCase();
          if (resolvedName !== name) {
            console.warn(`HttpAuthScheme has been normalized with lowercasing: '${resolvedName}' to '${name}'`);
          }
          let schemeId;
          if (name === "sigv4a") {
            schemeId = "aws.auth#sigv4a";
            const sigv4Present = authSchemes.find((s) => {
              const name2 = s.name.toLowerCase();
              return name2 !== "sigv4a" && name2.startsWith("sigv4");
            });
            if (import_signature_v4_multi_region13.SignatureV4MultiRegion.sigv4aDependency() === "none" && sigv4Present) {
              continue;
            }
          } else if (name.startsWith("sigv4")) {
            schemeId = "aws.auth#sigv4";
          } else {
            throw new Error(`Unknown HttpAuthScheme found in '@smithy.rules#endpointRuleSet': '${name}'`);
          }
          const createOption = createHttpAuthOptionFunctions[schemeId];
          if (!createOption) {
            throw new Error(`Could not find HttpAuthOption create function for '${schemeId}'`);
          }
          const option = createOption(authParameters);
          option.schemeId = schemeId;
          option.signingProperties = { ...option.signingProperties || {}, ...rest, ...properties };
          options.push(option);
        }
        return options;
      }, "endpointRuleSetHttpAuthSchemeProvider");
      return endpointRuleSetHttpAuthSchemeProvider;
    }, "createEndpointRuleSetHttpAuthSchemeProvider");
    _defaultSTSHttpAuthSchemeProvider7 = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "AssumeRoleWithWebIdentity": {
          options.push(createSmithyApiNoAuthHttpAuthOption25(authParameters));
          options.push(createAwsAuthSigv4aHttpAuthOption7(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption25(authParameters));
          options.push(createAwsAuthSigv4aHttpAuthOption7(authParameters));
        }
      }
      return options;
    }, "_defaultSTSHttpAuthSchemeProvider");
    defaultSTSHttpAuthSchemeProvider7 = createEndpointRuleSetHttpAuthSchemeProvider7(defaultEndpointResolver25, _defaultSTSHttpAuthSchemeProvider7, {
      "aws.auth#sigv4": createAwsAuthSigv4HttpAuthOption25,
      "aws.auth#sigv4a": createAwsAuthSigv4aHttpAuthOption7,
      "smithy.api#noAuth": createSmithyApiNoAuthHttpAuthOption25
    });
    resolveStsAuthConfig6 = /* @__PURE__ */ __name((input) => Object.assign(input, {
      stsClientCtor: STSClient8
    }), "resolveStsAuthConfig");
    resolveHttpAuthSchemeConfig25 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveStsAuthConfig6(config2);
      const config_1 = resolveAwsSdkSigV4Config8(config_0);
      const config_2 = resolveAwsSdkSigV4AConfig8(config_1);
      return Object.assign(config_2, {
        authSchemePreference: (0, import_util_middleware26.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/EndpointParameters.js
var resolveClientEndpointParameters25, commonParams25;
var init_EndpointParameters25 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters25 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        useGlobalEndpoint: options.useGlobalEndpoint ?? false,
        defaultSigningName: "sts"
      });
    }, "resolveClientEndpointParameters");
    commonParams25 = {
      UseGlobalEndpoint: { type: "builtInParams", name: "useGlobalEndpoint" },
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/STSServiceException.js
var import_smithy_client195, STSServiceException7;
var init_STSServiceException7 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/STSServiceException.js"() {
    import_smithy_client195 = __toESM(require_dist_cjs34());
    STSServiceException7 = class _STSServiceException extends import_smithy_client195.ServiceException {
      static {
        __name(this, "STSServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _STSServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/errors.js
var ExpiredTokenException10, MalformedPolicyDocumentException7, PackedPolicyTooLargeException7, RegionDisabledException7, IDPRejectedClaimException7, InvalidIdentityTokenException7, IDPCommunicationErrorException7;
var init_errors25 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/errors.js"() {
    init_STSServiceException7();
    ExpiredTokenException10 = class _ExpiredTokenException extends STSServiceException7 {
      static {
        __name(this, "ExpiredTokenException");
      }
      name = "ExpiredTokenException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ExpiredTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ExpiredTokenException.prototype);
      }
    };
    MalformedPolicyDocumentException7 = class _MalformedPolicyDocumentException extends STSServiceException7 {
      static {
        __name(this, "MalformedPolicyDocumentException");
      }
      name = "MalformedPolicyDocumentException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "MalformedPolicyDocumentException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _MalformedPolicyDocumentException.prototype);
      }
    };
    PackedPolicyTooLargeException7 = class _PackedPolicyTooLargeException extends STSServiceException7 {
      static {
        __name(this, "PackedPolicyTooLargeException");
      }
      name = "PackedPolicyTooLargeException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "PackedPolicyTooLargeException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _PackedPolicyTooLargeException.prototype);
      }
    };
    RegionDisabledException7 = class _RegionDisabledException extends STSServiceException7 {
      static {
        __name(this, "RegionDisabledException");
      }
      name = "RegionDisabledException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "RegionDisabledException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _RegionDisabledException.prototype);
      }
    };
    IDPRejectedClaimException7 = class _IDPRejectedClaimException extends STSServiceException7 {
      static {
        __name(this, "IDPRejectedClaimException");
      }
      name = "IDPRejectedClaimException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "IDPRejectedClaimException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _IDPRejectedClaimException.prototype);
      }
    };
    InvalidIdentityTokenException7 = class _InvalidIdentityTokenException extends STSServiceException7 {
      static {
        __name(this, "InvalidIdentityTokenException");
      }
      name = "InvalidIdentityTokenException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidIdentityTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidIdentityTokenException.prototype);
      }
    };
    IDPCommunicationErrorException7 = class _IDPCommunicationErrorException extends STSServiceException7 {
      static {
        __name(this, "IDPCommunicationErrorException");
      }
      name = "IDPCommunicationErrorException";
      $fault = "client";
      $retryable = {};
      constructor(opts) {
        super({
          name: "IDPCommunicationErrorException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _IDPCommunicationErrorException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/schemas/schemas_0.js
var _A7, _AKI8, _AR7, _ARI7, _ARR7, _ARRs7, _ARU7, _ARWWI7, _ARWWIR7, _ARWWIRs7, _Au7, _C8, _CA7, _DS7, _E8, _EI7, _ETE10, _IDPCEE7, _IDPRCE7, _IITE7, _K7, _MPDE7, _P7, _PA7, _PAr7, _PC7, _PCLT7, _PCr7, _PDT7, _PI7, _PPS7, _PPTLE7, _Pr7, _RA7, _RDE7, _RSN7, _SAK7, _SFWIT7, _SI7, _SN7, _ST8, _T7, _TC7, _TTK7, _Ta7, _V7, _WIT7, _a7, _aKST7, _aQE7, _c25, _cTT7, _e25, _hE25, _m22, _pDLT7, _s25, _tLT7, n025, _s_registry25, STSServiceException$7, n0_registry25, ExpiredTokenException$10, IDPCommunicationErrorException$7, IDPRejectedClaimException$7, InvalidIdentityTokenException$7, MalformedPolicyDocumentException$7, PackedPolicyTooLargeException$7, RegionDisabledException$7, errorTypeRegistries25, accessKeySecretType7, clientTokenType7, AssumedRoleUser$7, AssumeRoleRequest$7, AssumeRoleResponse$7, AssumeRoleWithWebIdentityRequest$7, AssumeRoleWithWebIdentityResponse$7, Credentials$8, PolicyDescriptorType$7, ProvidedContext$7, Tag$7, policyDescriptorListType7, ProvidedContextsListType7, tagKeyListType7, tagListType7, AssumeRole$7, AssumeRoleWithWebIdentity$7;
var init_schemas_025 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/schemas/schemas_0.js"() {
    init_schema4();
    init_errors25();
    init_STSServiceException7();
    _A7 = "Arn";
    _AKI8 = "AccessKeyId";
    _AR7 = "AssumeRole";
    _ARI7 = "AssumedRoleId";
    _ARR7 = "AssumeRoleRequest";
    _ARRs7 = "AssumeRoleResponse";
    _ARU7 = "AssumedRoleUser";
    _ARWWI7 = "AssumeRoleWithWebIdentity";
    _ARWWIR7 = "AssumeRoleWithWebIdentityRequest";
    _ARWWIRs7 = "AssumeRoleWithWebIdentityResponse";
    _Au7 = "Audience";
    _C8 = "Credentials";
    _CA7 = "ContextAssertion";
    _DS7 = "DurationSeconds";
    _E8 = "Expiration";
    _EI7 = "ExternalId";
    _ETE10 = "ExpiredTokenException";
    _IDPCEE7 = "IDPCommunicationErrorException";
    _IDPRCE7 = "IDPRejectedClaimException";
    _IITE7 = "InvalidIdentityTokenException";
    _K7 = "Key";
    _MPDE7 = "MalformedPolicyDocumentException";
    _P7 = "Policy";
    _PA7 = "PolicyArns";
    _PAr7 = "ProviderArn";
    _PC7 = "ProvidedContexts";
    _PCLT7 = "ProvidedContextsListType";
    _PCr7 = "ProvidedContext";
    _PDT7 = "PolicyDescriptorType";
    _PI7 = "ProviderId";
    _PPS7 = "PackedPolicySize";
    _PPTLE7 = "PackedPolicyTooLargeException";
    _Pr7 = "Provider";
    _RA7 = "RoleArn";
    _RDE7 = "RegionDisabledException";
    _RSN7 = "RoleSessionName";
    _SAK7 = "SecretAccessKey";
    _SFWIT7 = "SubjectFromWebIdentityToken";
    _SI7 = "SourceIdentity";
    _SN7 = "SerialNumber";
    _ST8 = "SessionToken";
    _T7 = "Tags";
    _TC7 = "TokenCode";
    _TTK7 = "TransitiveTagKeys";
    _Ta7 = "Tag";
    _V7 = "Value";
    _WIT7 = "WebIdentityToken";
    _a7 = "arn";
    _aKST7 = "accessKeySecretType";
    _aQE7 = "awsQueryError";
    _c25 = "client";
    _cTT7 = "clientTokenType";
    _e25 = "error";
    _hE25 = "httpError";
    _m22 = "message";
    _pDLT7 = "policyDescriptorListType";
    _s25 = "smithy.ts.sdk.synthetic.com.amazonaws.sts";
    _tLT7 = "tagListType";
    n025 = "com.amazonaws.sts";
    _s_registry25 = TypeRegistry.for(_s25);
    STSServiceException$7 = [-3, _s25, "STSServiceException", 0, [], []];
    _s_registry25.registerError(STSServiceException$7, STSServiceException7);
    n0_registry25 = TypeRegistry.for(n025);
    ExpiredTokenException$10 = [
      -3,
      n025,
      _ETE10,
      { [_aQE7]: [`ExpiredTokenException`, 400], [_e25]: _c25, [_hE25]: 400 },
      [_m22],
      [0]
    ];
    n0_registry25.registerError(ExpiredTokenException$10, ExpiredTokenException10);
    IDPCommunicationErrorException$7 = [
      -3,
      n025,
      _IDPCEE7,
      { [_aQE7]: [`IDPCommunicationError`, 400], [_e25]: _c25, [_hE25]: 400 },
      [_m22],
      [0]
    ];
    n0_registry25.registerError(IDPCommunicationErrorException$7, IDPCommunicationErrorException7);
    IDPRejectedClaimException$7 = [
      -3,
      n025,
      _IDPRCE7,
      { [_aQE7]: [`IDPRejectedClaim`, 403], [_e25]: _c25, [_hE25]: 403 },
      [_m22],
      [0]
    ];
    n0_registry25.registerError(IDPRejectedClaimException$7, IDPRejectedClaimException7);
    InvalidIdentityTokenException$7 = [
      -3,
      n025,
      _IITE7,
      { [_aQE7]: [`InvalidIdentityToken`, 400], [_e25]: _c25, [_hE25]: 400 },
      [_m22],
      [0]
    ];
    n0_registry25.registerError(InvalidIdentityTokenException$7, InvalidIdentityTokenException7);
    MalformedPolicyDocumentException$7 = [
      -3,
      n025,
      _MPDE7,
      { [_aQE7]: [`MalformedPolicyDocument`, 400], [_e25]: _c25, [_hE25]: 400 },
      [_m22],
      [0]
    ];
    n0_registry25.registerError(MalformedPolicyDocumentException$7, MalformedPolicyDocumentException7);
    PackedPolicyTooLargeException$7 = [
      -3,
      n025,
      _PPTLE7,
      { [_aQE7]: [`PackedPolicyTooLarge`, 400], [_e25]: _c25, [_hE25]: 400 },
      [_m22],
      [0]
    ];
    n0_registry25.registerError(PackedPolicyTooLargeException$7, PackedPolicyTooLargeException7);
    RegionDisabledException$7 = [
      -3,
      n025,
      _RDE7,
      { [_aQE7]: [`RegionDisabledException`, 403], [_e25]: _c25, [_hE25]: 403 },
      [_m22],
      [0]
    ];
    n0_registry25.registerError(RegionDisabledException$7, RegionDisabledException7);
    errorTypeRegistries25 = [_s_registry25, n0_registry25];
    accessKeySecretType7 = [0, n025, _aKST7, 8, 0];
    clientTokenType7 = [0, n025, _cTT7, 8, 0];
    AssumedRoleUser$7 = [3, n025, _ARU7, 0, [_ARI7, _A7], [0, 0], 2];
    AssumeRoleRequest$7 = [
      3,
      n025,
      _ARR7,
      0,
      [_RA7, _RSN7, _PA7, _P7, _DS7, _T7, _TTK7, _EI7, _SN7, _TC7, _SI7, _PC7],
      [0, 0, () => policyDescriptorListType7, 0, 1, () => tagListType7, 64 | 0, 0, 0, 0, 0, () => ProvidedContextsListType7],
      2
    ];
    AssumeRoleResponse$7 = [
      3,
      n025,
      _ARRs7,
      0,
      [_C8, _ARU7, _PPS7, _SI7],
      [[() => Credentials$8, 0], () => AssumedRoleUser$7, 1, 0]
    ];
    AssumeRoleWithWebIdentityRequest$7 = [
      3,
      n025,
      _ARWWIR7,
      0,
      [_RA7, _RSN7, _WIT7, _PI7, _PA7, _P7, _DS7],
      [0, 0, [() => clientTokenType7, 0], 0, () => policyDescriptorListType7, 0, 1],
      3
    ];
    AssumeRoleWithWebIdentityResponse$7 = [
      3,
      n025,
      _ARWWIRs7,
      0,
      [_C8, _SFWIT7, _ARU7, _PPS7, _Pr7, _Au7, _SI7],
      [[() => Credentials$8, 0], 0, () => AssumedRoleUser$7, 1, 0, 0, 0]
    ];
    Credentials$8 = [
      3,
      n025,
      _C8,
      0,
      [_AKI8, _SAK7, _ST8, _E8],
      [0, [() => accessKeySecretType7, 0], 0, 4],
      4
    ];
    PolicyDescriptorType$7 = [3, n025, _PDT7, 0, [_a7], [0]];
    ProvidedContext$7 = [3, n025, _PCr7, 0, [_PAr7, _CA7], [0, 0]];
    Tag$7 = [3, n025, _Ta7, 0, [_K7, _V7], [0, 0], 2];
    policyDescriptorListType7 = [1, n025, _pDLT7, 0, () => PolicyDescriptorType$7];
    ProvidedContextsListType7 = [1, n025, _PCLT7, 0, () => ProvidedContext$7];
    tagKeyListType7 = 64 | 0;
    tagListType7 = [1, n025, _tLT7, 0, () => Tag$7];
    AssumeRole$7 = [9, n025, _AR7, 0, () => AssumeRoleRequest$7, () => AssumeRoleResponse$7];
    AssumeRoleWithWebIdentity$7 = [
      9,
      n025,
      _ARWWI7,
      0,
      () => AssumeRoleWithWebIdentityRequest$7,
      () => AssumeRoleWithWebIdentityResponse$7
    ];
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.shared.js
var import_signature_v4_multi_region14, import_smithy_client196, import_url_parser22, import_util_base6453, import_util_utf841, getRuntimeConfig49;
var init_runtimeConfig_shared25 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.shared.js"() {
    init_httpAuthSchemes10();
    init_protocols16();
    import_signature_v4_multi_region14 = __toESM(require_dist_cjs55());
    init_dist_es();
    import_smithy_client196 = __toESM(require_dist_cjs34());
    import_url_parser22 = __toESM(require_dist_cjs18());
    import_util_base6453 = __toESM(require_dist_cjs10());
    import_util_utf841 = __toESM(require_dist_cjs9());
    init_httpAuthSchemeProvider25();
    init_endpointResolver25();
    init_schemas_025();
    getRuntimeConfig49 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2011-06-15",
        base64Decoder: config2?.base64Decoder ?? import_util_base6453.fromBase64,
        base64Encoder: config2?.base64Encoder ?? import_util_base6453.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver25,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSTSHttpAuthSchemeProvider7,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer8()
          },
          {
            schemeId: "aws.auth#sigv4a",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4a"), "identityProvider"),
            signer: new AwsSdkSigV4ASigner8()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        logger: config2?.logger ?? new import_smithy_client196.NoOpLogger(),
        protocol: config2?.protocol ?? AwsQueryProtocol8,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.sts",
          errorTypeRegistries: errorTypeRegistries25,
          xmlNamespace: "https://sts.amazonaws.com/doc/2011-06-15/",
          version: "2011-06-15",
          serviceTarget: "AWSSecurityTokenServiceV20110615"
        },
        serviceId: config2?.serviceId ?? "STS",
        signerConstructor: config2?.signerConstructor ?? import_signature_v4_multi_region14.SignatureV4MultiRegion,
        urlParser: config2?.urlParser ?? import_url_parser22.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? import_util_utf841.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? import_util_utf841.toUtf8
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.js
var import_util_user_agent_node21, import_config_resolver42, import_hash_node23, import_middleware_retry41, import_node_config_provider22, import_node_http_handler25, import_smithy_client197, import_util_body_length_node21, import_util_defaults_mode_node21, import_util_retry30, getRuntimeConfig50;
var init_runtimeConfig25 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.js"() {
    init_package8();
    init_client17();
    init_httpAuthSchemes10();
    import_util_user_agent_node21 = __toESM(require_dist_cjs172());
    import_config_resolver42 = __toESM(require_dist_cjs25());
    init_dist_es();
    import_hash_node23 = __toESM(require_dist_cjs44());
    import_middleware_retry41 = __toESM(require_dist_cjs168());
    import_node_config_provider22 = __toESM(require_dist_cjs29());
    import_node_http_handler25 = __toESM(require_dist_cjs13());
    import_smithy_client197 = __toESM(require_dist_cjs34());
    import_util_body_length_node21 = __toESM(require_dist_cjs45());
    import_util_defaults_mode_node21 = __toESM(require_dist_cjs46());
    import_util_retry30 = __toESM(require_dist_cjs22());
    init_runtimeConfig_shared25();
    getRuntimeConfig50 = /* @__PURE__ */ __name((config2) => {
      (0, import_smithy_client197.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, import_util_defaults_mode_node21.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(import_smithy_client197.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig49(config2);
      emitWarningIfUnsupportedVersion30(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, import_node_config_provider22.loadConfig)(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS8, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? import_util_body_length_node21.calculateBodyLength,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, import_util_user_agent_node21.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_default8.version }),
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4") || (async (idProps) => await config2.credentialDefaultProvider(idProps?.__config || {})()), "identityProvider"),
            signer: new AwsSdkSigV4Signer8()
          },
          {
            schemeId: "aws.auth#sigv4a",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4a"), "identityProvider"),
            signer: new AwsSdkSigV4ASigner8()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        maxAttempts: config2?.maxAttempts ?? (0, import_node_config_provider22.loadConfig)(import_middleware_retry41.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, import_node_config_provider22.loadConfig)(import_config_resolver42.NODE_REGION_CONFIG_OPTIONS, { ...import_config_resolver42.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: import_node_http_handler25.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, import_node_config_provider22.loadConfig)({
          ...import_middleware_retry41.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || import_util_retry30.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? import_hash_node23.Hash.bind(null, "sha256"),
        sigv4aSigningRegionSet: config2?.sigv4aSigningRegionSet ?? (0, import_node_config_provider22.loadConfig)(NODE_SIGV4A_CONFIG_OPTIONS8, loaderConfig),
        streamCollector: config2?.streamCollector ?? import_node_http_handler25.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, import_node_config_provider22.loadConfig)(import_config_resolver42.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, import_node_config_provider22.loadConfig)(import_config_resolver42.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, import_node_config_provider22.loadConfig)(import_util_user_agent_node21.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration25, resolveHttpAuthRuntimeConfig25;
var init_httpAuthExtensionConfiguration25 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration25 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig25 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeExtensions.js
var import_region_config_resolver26, import_protocol_http50, import_smithy_client198, resolveRuntimeExtensions25;
var init_runtimeExtensions25 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeExtensions.js"() {
    import_region_config_resolver26 = __toESM(require_dist_cjs48());
    import_protocol_http50 = __toESM(require_dist_cjs2());
    import_smithy_client198 = __toESM(require_dist_cjs34());
    init_httpAuthExtensionConfiguration25();
    resolveRuntimeExtensions25 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign((0, import_region_config_resolver26.getAwsRegionExtensionConfiguration)(runtimeConfig), (0, import_smithy_client198.getDefaultExtensionConfiguration)(runtimeConfig), (0, import_protocol_http50.getHttpHandlerExtensionConfiguration)(runtimeConfig), getHttpAuthExtensionConfiguration25(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, (0, import_region_config_resolver26.resolveAwsRegionExtensionConfiguration)(extensionConfiguration), (0, import_smithy_client198.resolveDefaultRuntimeConfig)(extensionConfiguration), (0, import_protocol_http50.resolveHttpHandlerRuntimeConfig)(extensionConfiguration), resolveHttpAuthRuntimeConfig25(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STSClient.js
var import_middleware_host_header21, import_middleware_logger21, import_middleware_recursion_detection21, import_middleware_user_agent21, import_config_resolver43, import_middleware_content_length21, import_middleware_endpoint54, import_middleware_retry42, import_smithy_client199, STSClient8;
var init_STSClient7 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STSClient.js"() {
    import_middleware_host_header21 = __toESM(require_dist_cjs3());
    import_middleware_logger21 = __toESM(require_dist_cjs4());
    import_middleware_recursion_detection21 = __toESM(require_dist_cjs5());
    import_middleware_user_agent21 = __toESM(require_dist_cjs167());
    import_config_resolver43 = __toESM(require_dist_cjs25());
    init_dist_es();
    init_schema4();
    import_middleware_content_length21 = __toESM(require_dist_cjs26());
    import_middleware_endpoint54 = __toESM(require_dist_cjs31());
    import_middleware_retry42 = __toESM(require_dist_cjs168());
    import_smithy_client199 = __toESM(require_dist_cjs34());
    init_httpAuthSchemeProvider25();
    init_EndpointParameters25();
    init_runtimeConfig25();
    init_runtimeExtensions25();
    STSClient8 = class extends import_smithy_client199.Client {
      static {
        __name(this, "STSClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig50(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters25(_config_0);
        const _config_2 = (0, import_middleware_user_agent21.resolveUserAgentConfig)(_config_1);
        const _config_3 = (0, import_middleware_retry42.resolveRetryConfig)(_config_2);
        const _config_4 = (0, import_config_resolver43.resolveRegionConfig)(_config_3);
        const _config_5 = (0, import_middleware_host_header21.resolveHostHeaderConfig)(_config_4);
        const _config_6 = (0, import_middleware_endpoint54.resolveEndpointConfig)(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig25(_config_6);
        const _config_8 = resolveRuntimeExtensions25(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin(this.config));
        this.middlewareStack.use((0, import_middleware_user_agent21.getUserAgentPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_retry42.getRetryPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_content_length21.getContentLengthPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_host_header21.getHostHeaderPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_logger21.getLoggerPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_recursion_detection21.getRecursionDetectionPlugin)(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: defaultSTSHttpAuthSchemeParametersProvider7,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials,
            "aws.auth#sigv4a": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleCommand.js
var import_middleware_endpoint55, import_smithy_client200, AssumeRoleCommand7;
var init_AssumeRoleCommand7 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleCommand.js"() {
    import_middleware_endpoint55 = __toESM(require_dist_cjs31());
    import_smithy_client200 = __toESM(require_dist_cjs34());
    init_EndpointParameters25();
    init_schemas_025();
    AssumeRoleCommand7 = class extends import_smithy_client200.Command.classBuilder().ep(commonParams25).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint55.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "AssumeRole", {}).n("STSClient", "AssumeRoleCommand").sc(AssumeRole$7).build() {
      static {
        __name(this, "AssumeRoleCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleWithWebIdentityCommand.js
var import_middleware_endpoint56, import_smithy_client201, AssumeRoleWithWebIdentityCommand7;
var init_AssumeRoleWithWebIdentityCommand7 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleWithWebIdentityCommand.js"() {
    import_middleware_endpoint56 = __toESM(require_dist_cjs31());
    import_smithy_client201 = __toESM(require_dist_cjs34());
    init_EndpointParameters25();
    init_schemas_025();
    AssumeRoleWithWebIdentityCommand7 = class extends import_smithy_client201.Command.classBuilder().ep(commonParams25).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint56.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "AssumeRoleWithWebIdentity", {}).n("STSClient", "AssumeRoleWithWebIdentityCommand").sc(AssumeRoleWithWebIdentity$7).build() {
      static {
        __name(this, "AssumeRoleWithWebIdentityCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STS.js
var import_smithy_client202, commands25, STS7;
var init_STS7 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STS.js"() {
    import_smithy_client202 = __toESM(require_dist_cjs34());
    init_AssumeRoleCommand7();
    init_AssumeRoleWithWebIdentityCommand7();
    init_STSClient7();
    commands25 = {
      AssumeRoleCommand: AssumeRoleCommand7,
      AssumeRoleWithWebIdentityCommand: AssumeRoleWithWebIdentityCommand7
    };
    STS7 = class extends STSClient8 {
      static {
        __name(this, "STS");
      }
    };
    (0, import_smithy_client202.createAggregatedClient)(commands25, STS7);
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/index.js
var init_commands26 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/index.js"() {
    init_AssumeRoleCommand7();
    init_AssumeRoleWithWebIdentityCommand7();
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/models_0.js
var init_models_025 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultStsRoleAssumers.js
var import_region_config_resolver27, getAccountIdFromAssumedRoleUser7, resolveRegion7, getDefaultRoleAssumer13, getDefaultRoleAssumerWithWebIdentity13, isH27;
var init_defaultStsRoleAssumers7 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultStsRoleAssumers.js"() {
    init_client17();
    import_region_config_resolver27 = __toESM(require_dist_cjs48());
    init_AssumeRoleCommand7();
    init_AssumeRoleWithWebIdentityCommand7();
    getAccountIdFromAssumedRoleUser7 = /* @__PURE__ */ __name((assumedRoleUser) => {
      if (typeof assumedRoleUser?.Arn === "string") {
        const arnComponents = assumedRoleUser.Arn.split(":");
        if (arnComponents.length > 4 && arnComponents[4] !== "") {
          return arnComponents[4];
        }
      }
      return void 0;
    }, "getAccountIdFromAssumedRoleUser");
    resolveRegion7 = /* @__PURE__ */ __name(async (_region, _parentRegion, credentialProviderLogger, loaderConfig = {}) => {
      const region = typeof _region === "function" ? await _region() : _region;
      const parentRegion = typeof _parentRegion === "function" ? await _parentRegion() : _parentRegion;
      let stsDefaultRegion = "";
      const resolvedRegion = region ?? parentRegion ?? (stsDefaultRegion = await (0, import_region_config_resolver27.stsRegionDefaultResolver)(loaderConfig)());
      credentialProviderLogger?.debug?.("@aws-sdk/client-sts::resolveRegion", "accepting first of:", `${region} (credential provider clientConfig)`, `${parentRegion} (contextual client)`, `${stsDefaultRegion} (STS default: AWS_REGION, profile region, or us-east-1)`);
      return resolvedRegion;
    }, "resolveRegion");
    getDefaultRoleAssumer13 = /* @__PURE__ */ __name((stsOptions, STSClient12) => {
      let stsClient;
      let closureSourceCreds;
      return async (sourceCreds, params) => {
        closureSourceCreds = sourceCreds;
        if (!stsClient) {
          const { logger: logger5 = stsOptions?.parentClientConfig?.logger, profile = stsOptions?.parentClientConfig?.profile, region, requestHandler = stsOptions?.parentClientConfig?.requestHandler, credentialProviderLogger, userAgentAppId = stsOptions?.parentClientConfig?.userAgentAppId } = stsOptions;
          const resolvedRegion = await resolveRegion7(region, stsOptions?.parentClientConfig?.region, credentialProviderLogger, {
            logger: logger5,
            profile
          });
          const isCompatibleRequestHandler = !isH27(requestHandler);
          stsClient = new STSClient12({
            ...stsOptions,
            userAgentAppId,
            profile,
            credentialDefaultProvider: /* @__PURE__ */ __name(() => async () => closureSourceCreds, "credentialDefaultProvider"),
            region: resolvedRegion,
            requestHandler: isCompatibleRequestHandler ? requestHandler : void 0,
            logger: logger5
          });
        }
        const { Credentials, AssumedRoleUser } = await stsClient.send(new AssumeRoleCommand7(params));
        if (!Credentials || !Credentials.AccessKeyId || !Credentials.SecretAccessKey) {
          throw new Error(`Invalid response from STS.assumeRole call with role ${params.RoleArn}`);
        }
        const accountId = getAccountIdFromAssumedRoleUser7(AssumedRoleUser);
        const credentials = {
          accessKeyId: Credentials.AccessKeyId,
          secretAccessKey: Credentials.SecretAccessKey,
          sessionToken: Credentials.SessionToken,
          expiration: Credentials.Expiration,
          ...Credentials.CredentialScope && { credentialScope: Credentials.CredentialScope },
          ...accountId && { accountId }
        };
        setCredentialFeature10(credentials, "CREDENTIALS_STS_ASSUME_ROLE", "i");
        return credentials;
      };
    }, "getDefaultRoleAssumer");
    getDefaultRoleAssumerWithWebIdentity13 = /* @__PURE__ */ __name((stsOptions, STSClient12) => {
      let stsClient;
      return async (params) => {
        if (!stsClient) {
          const { logger: logger5 = stsOptions?.parentClientConfig?.logger, profile = stsOptions?.parentClientConfig?.profile, region, requestHandler = stsOptions?.parentClientConfig?.requestHandler, credentialProviderLogger, userAgentAppId = stsOptions?.parentClientConfig?.userAgentAppId } = stsOptions;
          const resolvedRegion = await resolveRegion7(region, stsOptions?.parentClientConfig?.region, credentialProviderLogger, {
            logger: logger5,
            profile
          });
          const isCompatibleRequestHandler = !isH27(requestHandler);
          stsClient = new STSClient12({
            ...stsOptions,
            userAgentAppId,
            profile,
            region: resolvedRegion,
            requestHandler: isCompatibleRequestHandler ? requestHandler : void 0,
            logger: logger5
          });
        }
        const { Credentials, AssumedRoleUser } = await stsClient.send(new AssumeRoleWithWebIdentityCommand7(params));
        if (!Credentials || !Credentials.AccessKeyId || !Credentials.SecretAccessKey) {
          throw new Error(`Invalid response from STS.assumeRoleWithWebIdentity call with role ${params.RoleArn}`);
        }
        const accountId = getAccountIdFromAssumedRoleUser7(AssumedRoleUser);
        const credentials = {
          accessKeyId: Credentials.AccessKeyId,
          secretAccessKey: Credentials.SecretAccessKey,
          sessionToken: Credentials.SessionToken,
          expiration: Credentials.Expiration,
          ...Credentials.CredentialScope && { credentialScope: Credentials.CredentialScope },
          ...accountId && { accountId }
        };
        if (accountId) {
          setCredentialFeature10(credentials, "RESOLVED_ACCOUNT_ID", "T");
        }
        setCredentialFeature10(credentials, "CREDENTIALS_STS_ASSUME_ROLE_WEB_ID", "k");
        return credentials;
      };
    }, "getDefaultRoleAssumerWithWebIdentity");
    isH27 = /* @__PURE__ */ __name((requestHandler) => {
      return requestHandler?.metadata?.handlerProtocol === "h2";
    }, "isH2");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultRoleAssumers.js
var getCustomizableStsClientCtor7, getDefaultRoleAssumer14, getDefaultRoleAssumerWithWebIdentity14, decorateDefaultCredentialProvider7;
var init_defaultRoleAssumers7 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultRoleAssumers.js"() {
    init_defaultStsRoleAssumers7();
    init_STSClient7();
    getCustomizableStsClientCtor7 = /* @__PURE__ */ __name((baseCtor, customizations) => {
      if (!customizations)
        return baseCtor;
      else
        return class CustomizableSTSClient extends baseCtor {
          static {
            __name(this, "CustomizableSTSClient");
          }
          constructor(config2) {
            super(config2);
            for (const customization of customizations) {
              this.middlewareStack.use(customization);
            }
          }
        };
    }, "getCustomizableStsClientCtor");
    getDefaultRoleAssumer14 = /* @__PURE__ */ __name((stsOptions = {}, stsPlugins) => getDefaultRoleAssumer13(stsOptions, getCustomizableStsClientCtor7(STSClient8, stsPlugins)), "getDefaultRoleAssumer");
    getDefaultRoleAssumerWithWebIdentity14 = /* @__PURE__ */ __name((stsOptions = {}, stsPlugins) => getDefaultRoleAssumerWithWebIdentity13(stsOptions, getCustomizableStsClientCtor7(STSClient8, stsPlugins)), "getDefaultRoleAssumerWithWebIdentity");
    decorateDefaultCredentialProvider7 = /* @__PURE__ */ __name((provider) => (input) => provider({
      roleAssumer: getDefaultRoleAssumer14(input),
      roleAssumerWithWebIdentity: getDefaultRoleAssumerWithWebIdentity14(input),
      ...input
    }), "decorateDefaultCredentialProvider");
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/index.js
var sts_exports7 = {};
__export(sts_exports7, {
  AssumeRole$: () => AssumeRole$7,
  AssumeRoleCommand: () => AssumeRoleCommand7,
  AssumeRoleRequest$: () => AssumeRoleRequest$7,
  AssumeRoleResponse$: () => AssumeRoleResponse$7,
  AssumeRoleWithWebIdentity$: () => AssumeRoleWithWebIdentity$7,
  AssumeRoleWithWebIdentityCommand: () => AssumeRoleWithWebIdentityCommand7,
  AssumeRoleWithWebIdentityRequest$: () => AssumeRoleWithWebIdentityRequest$7,
  AssumeRoleWithWebIdentityResponse$: () => AssumeRoleWithWebIdentityResponse$7,
  AssumedRoleUser$: () => AssumedRoleUser$7,
  Credentials$: () => Credentials$8,
  ExpiredTokenException: () => ExpiredTokenException10,
  ExpiredTokenException$: () => ExpiredTokenException$10,
  IDPCommunicationErrorException: () => IDPCommunicationErrorException7,
  IDPCommunicationErrorException$: () => IDPCommunicationErrorException$7,
  IDPRejectedClaimException: () => IDPRejectedClaimException7,
  IDPRejectedClaimException$: () => IDPRejectedClaimException$7,
  InvalidIdentityTokenException: () => InvalidIdentityTokenException7,
  InvalidIdentityTokenException$: () => InvalidIdentityTokenException$7,
  MalformedPolicyDocumentException: () => MalformedPolicyDocumentException7,
  MalformedPolicyDocumentException$: () => MalformedPolicyDocumentException$7,
  PackedPolicyTooLargeException: () => PackedPolicyTooLargeException7,
  PackedPolicyTooLargeException$: () => PackedPolicyTooLargeException$7,
  PolicyDescriptorType$: () => PolicyDescriptorType$7,
  ProvidedContext$: () => ProvidedContext$7,
  RegionDisabledException: () => RegionDisabledException7,
  RegionDisabledException$: () => RegionDisabledException$7,
  STS: () => STS7,
  STSClient: () => STSClient8,
  STSServiceException: () => STSServiceException7,
  STSServiceException$: () => STSServiceException$7,
  Tag$: () => Tag$7,
  __Client: () => import_smithy_client199.Client,
  decorateDefaultCredentialProvider: () => decorateDefaultCredentialProvider7,
  errorTypeRegistries: () => errorTypeRegistries25,
  getDefaultRoleAssumer: () => getDefaultRoleAssumer14,
  getDefaultRoleAssumerWithWebIdentity: () => getDefaultRoleAssumerWithWebIdentity14
});
var init_sts7 = __esm({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/index.js"() {
    init_STSClient7();
    init_STS7();
    init_commands26();
    init_schemas_025();
    init_errors25();
    init_models_025();
    init_defaultRoleAssumers7();
    init_STSServiceException7();
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-process/dist-cjs/index.js
var require_dist_cjs175 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-process/dist-cjs/index.js"(exports2) {
    "use strict";
    var sharedIniFileLoader = require_dist_cjs28();
    var propertyProvider = require_dist_cjs27();
    var node_child_process = require("node:child_process");
    var node_util = require("node:util");
    var client = (init_client17(), __toCommonJS(client_exports12));
    var getValidatedProcessCredentials = /* @__PURE__ */ __name((profileName, data3, profiles) => {
      if (data3.Version !== 1) {
        throw Error(`Profile ${profileName} credential_process did not return Version 1.`);
      }
      if (data3.AccessKeyId === void 0 || data3.SecretAccessKey === void 0) {
        throw Error(`Profile ${profileName} credential_process returned invalid credentials.`);
      }
      if (data3.Expiration) {
        const currentTime = /* @__PURE__ */ new Date();
        const expireTime = new Date(data3.Expiration);
        if (expireTime < currentTime) {
          throw Error(`Profile ${profileName} credential_process returned expired credentials.`);
        }
      }
      let accountId = data3.AccountId;
      if (!accountId && profiles?.[profileName]?.aws_account_id) {
        accountId = profiles[profileName].aws_account_id;
      }
      const credentials = {
        accessKeyId: data3.AccessKeyId,
        secretAccessKey: data3.SecretAccessKey,
        ...data3.SessionToken && { sessionToken: data3.SessionToken },
        ...data3.Expiration && { expiration: new Date(data3.Expiration) },
        ...data3.CredentialScope && { credentialScope: data3.CredentialScope },
        ...accountId && { accountId }
      };
      client.setCredentialFeature(credentials, "CREDENTIALS_PROCESS", "w");
      return credentials;
    }, "getValidatedProcessCredentials");
    var resolveProcessCredentials = /* @__PURE__ */ __name(async (profileName, profiles, logger5) => {
      const profile = profiles[profileName];
      if (profiles[profileName]) {
        const credentialProcess = profile["credential_process"];
        if (credentialProcess !== void 0) {
          const execPromise = node_util.promisify(sharedIniFileLoader.externalDataInterceptor?.getTokenRecord?.().exec ?? node_child_process.exec);
          try {
            const { stdout } = await execPromise(credentialProcess);
            let data3;
            try {
              data3 = JSON.parse(stdout.trim());
            } catch {
              throw Error(`Profile ${profileName} credential_process returned invalid JSON.`);
            }
            return getValidatedProcessCredentials(profileName, data3, profiles);
          } catch (error4) {
            throw new propertyProvider.CredentialsProviderError(error4.message, { logger: logger5 });
          }
        } else {
          throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} did not contain credential_process.`, { logger: logger5 });
        }
      } else {
        throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} could not be found in shared credentials file.`, {
          logger: logger5
        });
      }
    }, "resolveProcessCredentials");
    var fromProcess = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/credential-provider-process - fromProcess");
      const profiles = await sharedIniFileLoader.parseKnownFiles(init);
      return resolveProcessCredentials(sharedIniFileLoader.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      }), profiles, init.logger);
    }, "fromProcess");
    exports2.fromProcess = fromProcess;
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromWebToken.js
var require_fromWebToken8 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromWebToken.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __setModuleDefault2 = exports2 && exports2.__setModuleDefault || (Object.create ? (function(o10, v) {
      Object.defineProperty(o10, "default", { enumerable: true, value: v });
    }) : function(o10, v) {
      o10["default"] = v;
    });
    var __importStar2 = exports2 && exports2.__importStar || /* @__PURE__ */ (function() {
      var ownKeys2 = /* @__PURE__ */ __name(function(o10) {
        ownKeys2 = Object.getOwnPropertyNames || function(o11) {
          var ar = [];
          for (var k32 in o11) if (Object.prototype.hasOwnProperty.call(o11, k32)) ar[ar.length] = k32;
          return ar;
        };
        return ownKeys2(o10);
      }, "ownKeys");
      return function(mod) {
        if (mod && mod.__esModule) return mod;
        var result2 = {};
        if (mod != null) {
          for (var k32 = ownKeys2(mod), i32 = 0; i32 < k32.length; i32++) if (k32[i32] !== "default") __createBinding3(result2, mod, k32[i32]);
        }
        __setModuleDefault2(result2, mod);
        return result2;
      };
    })();
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromWebToken = void 0;
    var fromWebToken = /* @__PURE__ */ __name((init) => async (awsIdentityProperties) => {
      init.logger?.debug("@aws-sdk/credential-provider-web-identity - fromWebToken");
      const { roleArn, roleSessionName, webIdentityToken, providerId, policyArns, policy, durationSeconds } = init;
      let { roleAssumerWithWebIdentity } = init;
      if (!roleAssumerWithWebIdentity) {
        const { getDefaultRoleAssumerWithWebIdentity: getDefaultRoleAssumerWithWebIdentity19 } = await Promise.resolve().then(() => __importStar2((init_sts7(), __toCommonJS(sts_exports7))));
        roleAssumerWithWebIdentity = getDefaultRoleAssumerWithWebIdentity19({
          ...init.clientConfig,
          credentialProviderLogger: init.logger,
          parentClientConfig: {
            ...awsIdentityProperties?.callerClientConfig,
            ...init.parentClientConfig
          }
        }, init.clientPlugins);
      }
      return roleAssumerWithWebIdentity({
        RoleArn: roleArn,
        RoleSessionName: roleSessionName ?? `aws-sdk-js-session-${Date.now()}`,
        WebIdentityToken: webIdentityToken,
        ProviderId: providerId,
        PolicyArns: policyArns,
        Policy: policy,
        DurationSeconds: durationSeconds
      });
    }, "fromWebToken");
    exports2.fromWebToken = fromWebToken;
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromTokenFile.js
var require_fromTokenFile8 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromTokenFile.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromTokenFile = void 0;
    var client_1 = (init_client17(), __toCommonJS(client_exports12));
    var property_provider_1 = require_dist_cjs27();
    var shared_ini_file_loader_1 = require_dist_cjs28();
    var node_fs_1 = require("node:fs");
    var fromWebToken_1 = require_fromWebToken8();
    var ENV_TOKEN_FILE = "AWS_WEB_IDENTITY_TOKEN_FILE";
    var ENV_ROLE_ARN = "AWS_ROLE_ARN";
    var ENV_ROLE_SESSION_NAME = "AWS_ROLE_SESSION_NAME";
    var fromTokenFile = /* @__PURE__ */ __name((init = {}) => async (awsIdentityProperties) => {
      init.logger?.debug("@aws-sdk/credential-provider-web-identity - fromTokenFile");
      const webIdentityTokenFile = init?.webIdentityTokenFile ?? process.env[ENV_TOKEN_FILE];
      const roleArn = init?.roleArn ?? process.env[ENV_ROLE_ARN];
      const roleSessionName = init?.roleSessionName ?? process.env[ENV_ROLE_SESSION_NAME];
      if (!webIdentityTokenFile || !roleArn) {
        throw new property_provider_1.CredentialsProviderError("Web identity configuration not specified", {
          logger: init.logger
        });
      }
      const credentials = await (0, fromWebToken_1.fromWebToken)({
        ...init,
        webIdentityToken: shared_ini_file_loader_1.externalDataInterceptor?.getTokenRecord?.()[webIdentityTokenFile] ?? (0, node_fs_1.readFileSync)(webIdentityTokenFile, { encoding: "ascii" }),
        roleArn,
        roleSessionName
      })(awsIdentityProperties);
      if (webIdentityTokenFile === process.env[ENV_TOKEN_FILE]) {
        (0, client_1.setCredentialFeature)(credentials, "CREDENTIALS_ENV_VARS_STS_WEB_ID_TOKEN", "h");
      }
      return credentials;
    }, "fromTokenFile");
    exports2.fromTokenFile = fromTokenFile;
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/index.js
var require_dist_cjs176 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/index.js"(exports2) {
    "use strict";
    var fromTokenFile = require_fromTokenFile8();
    var fromWebToken = require_fromWebToken8();
    Object.prototype.hasOwnProperty.call(fromTokenFile, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: fromTokenFile["__proto__"]
    });
    Object.keys(fromTokenFile).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = fromTokenFile[k32];
    });
    Object.prototype.hasOwnProperty.call(fromWebToken, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: fromWebToken["__proto__"]
    });
    Object.keys(fromWebToken).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = fromWebToken[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-ini/dist-cjs/index.js
var require_dist_cjs177 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-ini/dist-cjs/index.js"(exports2) {
    "use strict";
    var sharedIniFileLoader = require_dist_cjs28();
    var propertyProvider = require_dist_cjs27();
    var client = (init_client17(), __toCommonJS(client_exports12));
    var credentialProviderLogin = require_dist_cjs174();
    var resolveCredentialSource = /* @__PURE__ */ __name((credentialSource, profileName, logger5) => {
      const sourceProvidersMap = {
        EcsContainer: /* @__PURE__ */ __name(async (options) => {
          const { fromHttp } = await Promise.resolve().then(() => __toESM(require_dist_cjs171()));
          const { fromContainerMetadata } = await Promise.resolve().then(() => __toESM(require_dist_cjs38()));
          logger5?.debug("@aws-sdk/credential-provider-ini - credential_source is EcsContainer");
          return async () => propertyProvider.chain(fromHttp(options ?? {}), fromContainerMetadata(options))().then(setNamedProvider);
        }, "EcsContainer"),
        Ec2InstanceMetadata: /* @__PURE__ */ __name(async (options) => {
          logger5?.debug("@aws-sdk/credential-provider-ini - credential_source is Ec2InstanceMetadata");
          const { fromInstanceMetadata } = await Promise.resolve().then(() => __toESM(require_dist_cjs38()));
          return async () => fromInstanceMetadata(options)().then(setNamedProvider);
        }, "Ec2InstanceMetadata"),
        Environment: /* @__PURE__ */ __name(async (options) => {
          logger5?.debug("@aws-sdk/credential-provider-ini - credential_source is Environment");
          const { fromEnv: fromEnv6 } = await Promise.resolve().then(() => __toESM(require_dist_cjs169()));
          return async () => fromEnv6(options)().then(setNamedProvider);
        }, "Environment")
      };
      if (credentialSource in sourceProvidersMap) {
        return sourceProvidersMap[credentialSource];
      } else {
        throw new propertyProvider.CredentialsProviderError(`Unsupported credential source in profile ${profileName}. Got ${credentialSource}, expected EcsContainer or Ec2InstanceMetadata or Environment.`, { logger: logger5 });
      }
    }, "resolveCredentialSource");
    var setNamedProvider = /* @__PURE__ */ __name((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_NAMED_PROVIDER", "p"), "setNamedProvider");
    var isAssumeRoleProfile = /* @__PURE__ */ __name((arg, { profile = "default", logger: logger5 } = {}) => {
      return Boolean(arg) && typeof arg === "object" && typeof arg.role_arn === "string" && ["undefined", "string"].indexOf(typeof arg.role_session_name) > -1 && ["undefined", "string"].indexOf(typeof arg.external_id) > -1 && ["undefined", "string"].indexOf(typeof arg.mfa_serial) > -1 && (isAssumeRoleWithSourceProfile(arg, { profile, logger: logger5 }) || isCredentialSourceProfile(arg, { profile, logger: logger5 }));
    }, "isAssumeRoleProfile");
    var isAssumeRoleWithSourceProfile = /* @__PURE__ */ __name((arg, { profile, logger: logger5 }) => {
      const withSourceProfile = typeof arg.source_profile === "string" && typeof arg.credential_source === "undefined";
      if (withSourceProfile) {
        logger5?.debug?.(`    ${profile} isAssumeRoleWithSourceProfile source_profile=${arg.source_profile}`);
      }
      return withSourceProfile;
    }, "isAssumeRoleWithSourceProfile");
    var isCredentialSourceProfile = /* @__PURE__ */ __name((arg, { profile, logger: logger5 }) => {
      const withProviderProfile = typeof arg.credential_source === "string" && typeof arg.source_profile === "undefined";
      if (withProviderProfile) {
        logger5?.debug?.(`    ${profile} isCredentialSourceProfile credential_source=${arg.credential_source}`);
      }
      return withProviderProfile;
    }, "isCredentialSourceProfile");
    var resolveAssumeRoleCredentials = /* @__PURE__ */ __name(async (profileName, profiles, options, callerClientConfig, visitedProfiles = {}, resolveProfileData2) => {
      options.logger?.debug("@aws-sdk/credential-provider-ini - resolveAssumeRoleCredentials (STS)");
      const profileData = profiles[profileName];
      const { source_profile, region } = profileData;
      if (!options.roleAssumer) {
        const { getDefaultRoleAssumer: getDefaultRoleAssumer19 } = await Promise.resolve().then(() => (init_sts7(), sts_exports7));
        options.roleAssumer = getDefaultRoleAssumer19({
          ...options.clientConfig,
          credentialProviderLogger: options.logger,
          parentClientConfig: {
            ...callerClientConfig,
            ...options?.parentClientConfig,
            region: region ?? options?.parentClientConfig?.region ?? callerClientConfig?.region
          }
        }, options.clientPlugins);
      }
      if (source_profile && source_profile in visitedProfiles) {
        throw new propertyProvider.CredentialsProviderError(`Detected a cycle attempting to resolve credentials for profile ${sharedIniFileLoader.getProfileName(options)}. Profiles visited: ` + Object.keys(visitedProfiles).join(", "), { logger: options.logger });
      }
      options.logger?.debug(`@aws-sdk/credential-provider-ini - finding credential resolver using ${source_profile ? `source_profile=[${source_profile}]` : `profile=[${profileName}]`}`);
      const sourceCredsProvider = source_profile ? resolveProfileData2(source_profile, profiles, options, callerClientConfig, {
        ...visitedProfiles,
        [source_profile]: true
      }, isCredentialSourceWithoutRoleArn(profiles[source_profile] ?? {})) : (await resolveCredentialSource(profileData.credential_source, profileName, options.logger)(options))();
      if (isCredentialSourceWithoutRoleArn(profileData)) {
        return sourceCredsProvider.then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SOURCE_PROFILE", "o"));
      } else {
        const params = {
          RoleArn: profileData.role_arn,
          RoleSessionName: profileData.role_session_name || `aws-sdk-js-${Date.now()}`,
          ExternalId: profileData.external_id,
          DurationSeconds: parseInt(profileData.duration_seconds || "3600", 10)
        };
        const { mfa_serial } = profileData;
        if (mfa_serial) {
          if (!options.mfaCodeProvider) {
            throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} requires multi-factor authentication, but no MFA code callback was provided.`, { logger: options.logger, tryNextLink: false });
          }
          params.SerialNumber = mfa_serial;
          params.TokenCode = await options.mfaCodeProvider(mfa_serial);
        }
        const sourceCreds = await sourceCredsProvider;
        return options.roleAssumer(sourceCreds, params).then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SOURCE_PROFILE", "o"));
      }
    }, "resolveAssumeRoleCredentials");
    var isCredentialSourceWithoutRoleArn = /* @__PURE__ */ __name((section) => {
      return !section.role_arn && !!section.credential_source;
    }, "isCredentialSourceWithoutRoleArn");
    var isLoginProfile = /* @__PURE__ */ __name((data3) => {
      return Boolean(data3 && data3.login_session);
    }, "isLoginProfile");
    var resolveLoginCredentials = /* @__PURE__ */ __name(async (profileName, options, callerClientConfig) => {
      const credentials = await credentialProviderLogin.fromLoginCredentials({
        ...options,
        profile: profileName
      })({ callerClientConfig });
      return client.setCredentialFeature(credentials, "CREDENTIALS_PROFILE_LOGIN", "AC");
    }, "resolveLoginCredentials");
    var isProcessProfile = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.credential_process === "string", "isProcessProfile");
    var resolveProcessCredentials = /* @__PURE__ */ __name(async (options, profile) => Promise.resolve().then(() => __toESM(require_dist_cjs175())).then(({ fromProcess }) => fromProcess({
      ...options,
      profile
    })().then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_PROCESS", "v"))), "resolveProcessCredentials");
    var resolveSsoCredentials = /* @__PURE__ */ __name(async (profile, profileData, options = {}, callerClientConfig) => {
      const { fromSSO } = await Promise.resolve().then(() => __toESM(require_dist_cjs173()));
      return fromSSO({
        profile,
        logger: options.logger,
        parentClientConfig: options.parentClientConfig,
        clientConfig: options.clientConfig
      })({
        callerClientConfig
      }).then((creds) => {
        if (profileData.sso_session) {
          return client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SSO", "r");
        } else {
          return client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SSO_LEGACY", "t");
        }
      });
    }, "resolveSsoCredentials");
    var isSsoProfile = /* @__PURE__ */ __name((arg) => arg && (typeof arg.sso_start_url === "string" || typeof arg.sso_account_id === "string" || typeof arg.sso_session === "string" || typeof arg.sso_region === "string" || typeof arg.sso_role_name === "string"), "isSsoProfile");
    var isStaticCredsProfile = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.aws_access_key_id === "string" && typeof arg.aws_secret_access_key === "string" && ["undefined", "string"].indexOf(typeof arg.aws_session_token) > -1 && ["undefined", "string"].indexOf(typeof arg.aws_account_id) > -1, "isStaticCredsProfile");
    var resolveStaticCredentials = /* @__PURE__ */ __name(async (profile, options) => {
      options?.logger?.debug("@aws-sdk/credential-provider-ini - resolveStaticCredentials");
      const credentials = {
        accessKeyId: profile.aws_access_key_id,
        secretAccessKey: profile.aws_secret_access_key,
        sessionToken: profile.aws_session_token,
        ...profile.aws_credential_scope && { credentialScope: profile.aws_credential_scope },
        ...profile.aws_account_id && { accountId: profile.aws_account_id }
      };
      return client.setCredentialFeature(credentials, "CREDENTIALS_PROFILE", "n");
    }, "resolveStaticCredentials");
    var isWebIdentityProfile = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.web_identity_token_file === "string" && typeof arg.role_arn === "string" && ["undefined", "string"].indexOf(typeof arg.role_session_name) > -1, "isWebIdentityProfile");
    var resolveWebIdentityCredentials = /* @__PURE__ */ __name(async (profile, options, callerClientConfig) => Promise.resolve().then(() => __toESM(require_dist_cjs176())).then(({ fromTokenFile }) => fromTokenFile({
      webIdentityTokenFile: profile.web_identity_token_file,
      roleArn: profile.role_arn,
      roleSessionName: profile.role_session_name,
      roleAssumerWithWebIdentity: options.roleAssumerWithWebIdentity,
      logger: options.logger,
      parentClientConfig: options.parentClientConfig
    })({
      callerClientConfig
    }).then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_STS_WEB_ID_TOKEN", "q"))), "resolveWebIdentityCredentials");
    var resolveProfileData = /* @__PURE__ */ __name(async (profileName, profiles, options, callerClientConfig, visitedProfiles = {}, isAssumeRoleRecursiveCall = false) => {
      const data3 = profiles[profileName];
      if (Object.keys(visitedProfiles).length > 0 && isStaticCredsProfile(data3)) {
        return resolveStaticCredentials(data3, options);
      }
      if (isAssumeRoleRecursiveCall || isAssumeRoleProfile(data3, { profile: profileName, logger: options.logger })) {
        return resolveAssumeRoleCredentials(profileName, profiles, options, callerClientConfig, visitedProfiles, resolveProfileData);
      }
      if (isStaticCredsProfile(data3)) {
        return resolveStaticCredentials(data3, options);
      }
      if (isWebIdentityProfile(data3)) {
        return resolveWebIdentityCredentials(data3, options, callerClientConfig);
      }
      if (isProcessProfile(data3)) {
        return resolveProcessCredentials(options, profileName);
      }
      if (isSsoProfile(data3)) {
        return await resolveSsoCredentials(profileName, data3, options, callerClientConfig);
      }
      if (isLoginProfile(data3)) {
        return resolveLoginCredentials(profileName, options, callerClientConfig);
      }
      throw new propertyProvider.CredentialsProviderError(`Could not resolve credentials using profile: [${profileName}] in configuration/credentials file(s).`, { logger: options.logger });
    }, "resolveProfileData");
    var fromIni2 = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/credential-provider-ini - fromIni");
      const profiles = await sharedIniFileLoader.parseKnownFiles(init);
      return resolveProfileData(sharedIniFileLoader.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      }), profiles, init, callerClientConfig);
    }, "fromIni");
    exports2.fromIni = fromIni2;
  }
});

// ../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-node/dist-cjs/index.js
var require_dist_cjs178 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/node_modules/@aws-sdk/credential-provider-node/dist-cjs/index.js"(exports2) {
    "use strict";
    var credentialProviderEnv = require_dist_cjs169();
    var propertyProvider = require_dist_cjs27();
    var sharedIniFileLoader = require_dist_cjs28();
    var ENV_IMDS_DISABLED3 = "AWS_EC2_METADATA_DISABLED";
    var remoteProvider = /* @__PURE__ */ __name(async (init) => {
      const { ENV_CMDS_FULL_URI, ENV_CMDS_RELATIVE_URI, fromContainerMetadata, fromInstanceMetadata } = await Promise.resolve().then(() => __toESM(require_dist_cjs38()));
      if (process.env[ENV_CMDS_RELATIVE_URI] || process.env[ENV_CMDS_FULL_URI]) {
        init.logger?.debug("@aws-sdk/credential-provider-node - remoteProvider::fromHttp/fromContainerMetadata");
        const { fromHttp } = await Promise.resolve().then(() => __toESM(require_dist_cjs171()));
        return propertyProvider.chain(fromHttp(init), fromContainerMetadata(init));
      }
      if (process.env[ENV_IMDS_DISABLED3] && process.env[ENV_IMDS_DISABLED3] !== "false") {
        return async () => {
          throw new propertyProvider.CredentialsProviderError("EC2 Instance Metadata Service access disabled", { logger: init.logger });
        };
      }
      init.logger?.debug("@aws-sdk/credential-provider-node - remoteProvider::fromInstanceMetadata");
      return fromInstanceMetadata(init);
    }, "remoteProvider");
    function memoizeChain(providers, treatAsExpired) {
      const chain5 = internalCreateChain(providers);
      let activeLock;
      let passiveLock;
      let credentials;
      const provider = /* @__PURE__ */ __name(async (options) => {
        if (options?.forceRefresh) {
          return await chain5(options);
        }
        if (credentials?.expiration) {
          if (credentials?.expiration?.getTime() < Date.now()) {
            credentials = void 0;
          }
        }
        if (activeLock) {
          await activeLock;
        } else if (!credentials || treatAsExpired?.(credentials)) {
          if (credentials) {
            if (!passiveLock) {
              passiveLock = chain5(options).then((c32) => {
                credentials = c32;
              }).finally(() => {
                passiveLock = void 0;
              });
            }
          } else {
            activeLock = chain5(options).then((c32) => {
              credentials = c32;
            }).finally(() => {
              activeLock = void 0;
            });
            return provider(options);
          }
        }
        return credentials;
      }, "provider");
      return provider;
    }
    __name(memoizeChain, "memoizeChain");
    var internalCreateChain = /* @__PURE__ */ __name((providers) => async (awsIdentityProperties) => {
      let lastProviderError;
      for (const provider of providers) {
        try {
          return await provider(awsIdentityProperties);
        } catch (err) {
          lastProviderError = err;
          if (err?.tryNextLink) {
            continue;
          }
          throw err;
        }
      }
      throw lastProviderError;
    }, "internalCreateChain");
    var multipleCredentialSourceWarningEmitted = false;
    var defaultProvider = /* @__PURE__ */ __name((init = {}) => memoizeChain([
      async () => {
        const profile = init.profile ?? process.env[sharedIniFileLoader.ENV_PROFILE];
        if (profile) {
          const envStaticCredentialsAreSet = process.env[credentialProviderEnv.ENV_KEY] && process.env[credentialProviderEnv.ENV_SECRET];
          if (envStaticCredentialsAreSet) {
            if (!multipleCredentialSourceWarningEmitted) {
              const warnFn = init.logger?.warn && init.logger?.constructor?.name !== "NoOpLogger" ? init.logger.warn.bind(init.logger) : console.warn;
              warnFn(`@aws-sdk/credential-provider-node - defaultProvider::fromEnv WARNING:
    Multiple credential sources detected: 
    Both AWS_PROFILE and the pair AWS_ACCESS_KEY_ID/AWS_SECRET_ACCESS_KEY static credentials are set.
    This SDK will proceed with the AWS_PROFILE value.
    
    However, a future version may change this behavior to prefer the ENV static credentials.
    Please ensure that your environment only sets either the AWS_PROFILE or the
    AWS_ACCESS_KEY_ID/AWS_SECRET_ACCESS_KEY pair.
`);
              multipleCredentialSourceWarningEmitted = true;
            }
          }
          throw new propertyProvider.CredentialsProviderError("AWS_PROFILE is set, skipping fromEnv provider.", {
            logger: init.logger,
            tryNextLink: true
          });
        }
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromEnv");
        return credentialProviderEnv.fromEnv(init)();
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromSSO");
        const { ssoStartUrl, ssoAccountId, ssoRegion, ssoRoleName, ssoSession } = init;
        if (!ssoStartUrl && !ssoAccountId && !ssoRegion && !ssoRoleName && !ssoSession) {
          throw new propertyProvider.CredentialsProviderError("Skipping SSO provider in default chain (inputs do not include SSO fields).", { logger: init.logger });
        }
        const { fromSSO } = await Promise.resolve().then(() => __toESM(require_dist_cjs173()));
        return fromSSO(init)(awsIdentityProperties);
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromIni");
        const { fromIni: fromIni2 } = await Promise.resolve().then(() => __toESM(require_dist_cjs177()));
        return fromIni2(init)(awsIdentityProperties);
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromProcess");
        const { fromProcess } = await Promise.resolve().then(() => __toESM(require_dist_cjs175()));
        return fromProcess(init)(awsIdentityProperties);
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromTokenFile");
        const { fromTokenFile } = await Promise.resolve().then(() => __toESM(require_dist_cjs176()));
        return fromTokenFile(init)(awsIdentityProperties);
      },
      async () => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::remoteProvider");
        return (await remoteProvider(init))();
      },
      async () => {
        throw new propertyProvider.CredentialsProviderError("Could not load credentials from any providers", {
          tryNextLink: false,
          logger: init.logger
        });
      }
    ], credentialsTreatedAsExpired), "defaultProvider");
    var credentialsWillNeedRefresh = /* @__PURE__ */ __name((credentials) => credentials?.expiration !== void 0, "credentialsWillNeedRefresh");
    var credentialsTreatedAsExpired = /* @__PURE__ */ __name((credentials) => credentials?.expiration !== void 0 && credentials.expiration.getTime() - Date.now() < 3e5, "credentialsTreatedAsExpired");
    exports2.credentialsTreatedAsExpired = credentialsTreatedAsExpired;
    exports2.credentialsWillNeedRefresh = credentialsWillNeedRefresh;
    exports2.defaultProvider = defaultProvider;
  }
});

// ../../node_modules/@aws-sdk/client-kms/dist-cjs/endpoint/bdd.js
var require_bdd15 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/dist-cjs/endpoint/bdd.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.bdd = void 0;
    var util_endpoints_1 = require_dist_cjs20();
    var k32 = "ref";
    var a32 = -1;
    var b32 = true;
    var c32 = "isSet";
    var d32 = "PartitionResult";
    var e32 = "booleanEquals";
    var f32 = "getAttr";
    var g32 = { [k32]: "Endpoint" };
    var h32 = { [k32]: d32 };
    var i32 = {};
    var j32 = [{ [k32]: "Region" }];
    var _data32 = {
      conditions: [
        [c32, [g32]],
        [c32, j32],
        ["aws.partition", j32, d32],
        [e32, [{ [k32]: "UseFIPS" }, b32]],
        [e32, [{ [k32]: "UseDualStack" }, b32]],
        [e32, [{ fn: f32, argv: [h32, "supportsDualStack"] }, b32]],
        [e32, [{ fn: f32, argv: [h32, "supportsFIPS"] }, b32]]
      ],
      results: [
        [a32],
        [a32, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a32, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [g32, i32],
        ["https://kms-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", i32],
        [a32, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://kms-fips.{Region}.{PartitionResult#dnsSuffix}", i32],
        [a32, "FIPS is enabled but this partition does not support FIPS"],
        ["https://kms.{Region}.{PartitionResult#dualStackDnsSuffix}", i32],
        [a32, "DualStack is enabled but this partition does not support DualStack"],
        ["https://kms.{Region}.{PartitionResult#dnsSuffix}", i32],
        [a32, "Invalid Configuration: Missing Region"]
      ]
    };
    var root32 = 2;
    var r32 = 1e8;
    var nodes32 = new Int32Array([
      -1,
      1,
      -1,
      0,
      12,
      3,
      1,
      4,
      r32 + 11,
      2,
      5,
      r32 + 11,
      3,
      8,
      6,
      4,
      7,
      r32 + 10,
      5,
      r32 + 8,
      r32 + 9,
      4,
      10,
      9,
      6,
      r32 + 6,
      r32 + 7,
      5,
      11,
      r32 + 5,
      6,
      r32 + 4,
      r32 + 5,
      3,
      r32 + 1,
      13,
      4,
      r32 + 2,
      r32 + 3
    ]);
    exports2.bdd = util_endpoints_1.BinaryDecisionDiagram.from(nodes32, root32, _data32.conditions, _data32.results);
  }
});

// ../../node_modules/@aws-sdk/client-kms/dist-cjs/endpoint/endpointResolver.js
var require_endpointResolver15 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/dist-cjs/endpoint/endpointResolver.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.defaultEndpointResolver = void 0;
    var util_endpoints_1 = require_dist_cjs21();
    var util_endpoints_2 = require_dist_cjs20();
    var bdd_1 = require_bdd15();
    var cache32 = new util_endpoints_2.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    var defaultEndpointResolver32 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache32.get(endpointParams, () => (0, util_endpoints_2.decideEndpoint)(bdd_1.bdd, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    exports2.defaultEndpointResolver = defaultEndpointResolver32;
    util_endpoints_2.customEndpointFunctions.aws = util_endpoints_1.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-kms/dist-cjs/models/KMSServiceException.js
var require_KMSServiceException = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/dist-cjs/models/KMSServiceException.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.KMSServiceException = exports2.__ServiceException = void 0;
    var smithy_client_1 = require_dist_cjs34();
    Object.defineProperty(exports2, "__ServiceException", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return smithy_client_1.ServiceException;
    }, "get") });
    var KMSServiceException = class _KMSServiceException extends smithy_client_1.ServiceException {
      static {
        __name(this, "KMSServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _KMSServiceException.prototype);
      }
    };
    exports2.KMSServiceException = KMSServiceException;
  }
});

// ../../node_modules/@aws-sdk/client-kms/dist-cjs/models/errors.js
var require_errors14 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/dist-cjs/models/errors.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.KMSInvalidSignatureException = exports2.KMSInvalidMacException = exports2.InvalidGrantIdException = exports2.InvalidImportTokenException = exports2.IncorrectKeyMaterialException = exports2.ExpiredImportTokenException = exports2.InvalidMarkerException = exports2.KeyUnavailableException = exports2.InvalidKeyUsageException = exports2.InvalidCiphertextException = exports2.IncorrectKeyException = exports2.CustomKeyStoreHasCMKsException = exports2.XksKeyNotFoundException = exports2.XksKeyInvalidConfigurationException = exports2.XksKeyAlreadyInUseException = exports2.UnsupportedOperationException = exports2.TagException = exports2.MalformedPolicyDocumentException = exports2.InvalidGrantTokenException = exports2.DryRunOperationException = exports2.DisabledException = exports2.XksProxyVpcEndpointServiceNotFoundException = exports2.XksProxyVpcEndpointServiceInvalidConfigurationException = exports2.XksProxyVpcEndpointServiceInUseException = exports2.XksProxyUriUnreachableException = exports2.XksProxyUriInUseException = exports2.XksProxyUriEndpointInUseException = exports2.XksProxyInvalidResponseException = exports2.XksProxyInvalidConfigurationException = exports2.XksProxyIncorrectAuthenticationCredentialException = exports2.IncorrectTrustAnchorException = exports2.CustomKeyStoreNameInUseException = exports2.LimitExceededException = exports2.InvalidAliasNameException = exports2.CustomKeyStoreNotFoundException = exports2.CustomKeyStoreInvalidStateException = exports2.ConflictException = exports2.CloudHsmClusterNotRelatedException = exports2.CloudHsmClusterNotFoundException = exports2.CloudHsmClusterNotActiveException = exports2.CloudHsmClusterInvalidConfigurationException = exports2.CloudHsmClusterInUseException = exports2.NotFoundException = exports2.KMSInvalidStateException = exports2.KMSInternalException = exports2.InvalidArnException = exports2.DependencyTimeoutException = exports2.AlreadyExistsException = void 0;
    var KMSServiceException_1 = require_KMSServiceException();
    var AlreadyExistsException = class _AlreadyExistsException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "AlreadyExistsException");
      }
      name = "AlreadyExistsException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "AlreadyExistsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AlreadyExistsException.prototype);
      }
    };
    exports2.AlreadyExistsException = AlreadyExistsException;
    var DependencyTimeoutException = class _DependencyTimeoutException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "DependencyTimeoutException");
      }
      name = "DependencyTimeoutException";
      $fault = "server";
      constructor(opts) {
        super({
          name: "DependencyTimeoutException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _DependencyTimeoutException.prototype);
      }
    };
    exports2.DependencyTimeoutException = DependencyTimeoutException;
    var InvalidArnException = class _InvalidArnException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "InvalidArnException");
      }
      name = "InvalidArnException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidArnException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidArnException.prototype);
      }
    };
    exports2.InvalidArnException = InvalidArnException;
    var KMSInternalException = class _KMSInternalException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "KMSInternalException");
      }
      name = "KMSInternalException";
      $fault = "server";
      constructor(opts) {
        super({
          name: "KMSInternalException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _KMSInternalException.prototype);
      }
    };
    exports2.KMSInternalException = KMSInternalException;
    var KMSInvalidStateException = class _KMSInvalidStateException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "KMSInvalidStateException");
      }
      name = "KMSInvalidStateException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "KMSInvalidStateException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _KMSInvalidStateException.prototype);
      }
    };
    exports2.KMSInvalidStateException = KMSInvalidStateException;
    var NotFoundException = class _NotFoundException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "NotFoundException");
      }
      name = "NotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "NotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _NotFoundException.prototype);
      }
    };
    exports2.NotFoundException = NotFoundException;
    var CloudHsmClusterInUseException = class _CloudHsmClusterInUseException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "CloudHsmClusterInUseException");
      }
      name = "CloudHsmClusterInUseException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "CloudHsmClusterInUseException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CloudHsmClusterInUseException.prototype);
      }
    };
    exports2.CloudHsmClusterInUseException = CloudHsmClusterInUseException;
    var CloudHsmClusterInvalidConfigurationException = class _CloudHsmClusterInvalidConfigurationException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "CloudHsmClusterInvalidConfigurationException");
      }
      name = "CloudHsmClusterInvalidConfigurationException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "CloudHsmClusterInvalidConfigurationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CloudHsmClusterInvalidConfigurationException.prototype);
      }
    };
    exports2.CloudHsmClusterInvalidConfigurationException = CloudHsmClusterInvalidConfigurationException;
    var CloudHsmClusterNotActiveException = class _CloudHsmClusterNotActiveException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "CloudHsmClusterNotActiveException");
      }
      name = "CloudHsmClusterNotActiveException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "CloudHsmClusterNotActiveException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CloudHsmClusterNotActiveException.prototype);
      }
    };
    exports2.CloudHsmClusterNotActiveException = CloudHsmClusterNotActiveException;
    var CloudHsmClusterNotFoundException = class _CloudHsmClusterNotFoundException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "CloudHsmClusterNotFoundException");
      }
      name = "CloudHsmClusterNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "CloudHsmClusterNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CloudHsmClusterNotFoundException.prototype);
      }
    };
    exports2.CloudHsmClusterNotFoundException = CloudHsmClusterNotFoundException;
    var CloudHsmClusterNotRelatedException = class _CloudHsmClusterNotRelatedException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "CloudHsmClusterNotRelatedException");
      }
      name = "CloudHsmClusterNotRelatedException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "CloudHsmClusterNotRelatedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CloudHsmClusterNotRelatedException.prototype);
      }
    };
    exports2.CloudHsmClusterNotRelatedException = CloudHsmClusterNotRelatedException;
    var ConflictException = class _ConflictException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "ConflictException");
      }
      name = "ConflictException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ConflictException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ConflictException.prototype);
      }
    };
    exports2.ConflictException = ConflictException;
    var CustomKeyStoreInvalidStateException = class _CustomKeyStoreInvalidStateException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "CustomKeyStoreInvalidStateException");
      }
      name = "CustomKeyStoreInvalidStateException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "CustomKeyStoreInvalidStateException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CustomKeyStoreInvalidStateException.prototype);
      }
    };
    exports2.CustomKeyStoreInvalidStateException = CustomKeyStoreInvalidStateException;
    var CustomKeyStoreNotFoundException = class _CustomKeyStoreNotFoundException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "CustomKeyStoreNotFoundException");
      }
      name = "CustomKeyStoreNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "CustomKeyStoreNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CustomKeyStoreNotFoundException.prototype);
      }
    };
    exports2.CustomKeyStoreNotFoundException = CustomKeyStoreNotFoundException;
    var InvalidAliasNameException = class _InvalidAliasNameException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "InvalidAliasNameException");
      }
      name = "InvalidAliasNameException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidAliasNameException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidAliasNameException.prototype);
      }
    };
    exports2.InvalidAliasNameException = InvalidAliasNameException;
    var LimitExceededException2 = class _LimitExceededException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "LimitExceededException");
      }
      name = "LimitExceededException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "LimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _LimitExceededException.prototype);
      }
    };
    exports2.LimitExceededException = LimitExceededException2;
    var CustomKeyStoreNameInUseException = class _CustomKeyStoreNameInUseException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "CustomKeyStoreNameInUseException");
      }
      name = "CustomKeyStoreNameInUseException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "CustomKeyStoreNameInUseException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CustomKeyStoreNameInUseException.prototype);
      }
    };
    exports2.CustomKeyStoreNameInUseException = CustomKeyStoreNameInUseException;
    var IncorrectTrustAnchorException = class _IncorrectTrustAnchorException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "IncorrectTrustAnchorException");
      }
      name = "IncorrectTrustAnchorException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "IncorrectTrustAnchorException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _IncorrectTrustAnchorException.prototype);
      }
    };
    exports2.IncorrectTrustAnchorException = IncorrectTrustAnchorException;
    var XksProxyIncorrectAuthenticationCredentialException = class _XksProxyIncorrectAuthenticationCredentialException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "XksProxyIncorrectAuthenticationCredentialException");
      }
      name = "XksProxyIncorrectAuthenticationCredentialException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "XksProxyIncorrectAuthenticationCredentialException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _XksProxyIncorrectAuthenticationCredentialException.prototype);
      }
    };
    exports2.XksProxyIncorrectAuthenticationCredentialException = XksProxyIncorrectAuthenticationCredentialException;
    var XksProxyInvalidConfigurationException = class _XksProxyInvalidConfigurationException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "XksProxyInvalidConfigurationException");
      }
      name = "XksProxyInvalidConfigurationException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "XksProxyInvalidConfigurationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _XksProxyInvalidConfigurationException.prototype);
      }
    };
    exports2.XksProxyInvalidConfigurationException = XksProxyInvalidConfigurationException;
    var XksProxyInvalidResponseException = class _XksProxyInvalidResponseException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "XksProxyInvalidResponseException");
      }
      name = "XksProxyInvalidResponseException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "XksProxyInvalidResponseException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _XksProxyInvalidResponseException.prototype);
      }
    };
    exports2.XksProxyInvalidResponseException = XksProxyInvalidResponseException;
    var XksProxyUriEndpointInUseException = class _XksProxyUriEndpointInUseException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "XksProxyUriEndpointInUseException");
      }
      name = "XksProxyUriEndpointInUseException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "XksProxyUriEndpointInUseException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _XksProxyUriEndpointInUseException.prototype);
      }
    };
    exports2.XksProxyUriEndpointInUseException = XksProxyUriEndpointInUseException;
    var XksProxyUriInUseException = class _XksProxyUriInUseException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "XksProxyUriInUseException");
      }
      name = "XksProxyUriInUseException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "XksProxyUriInUseException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _XksProxyUriInUseException.prototype);
      }
    };
    exports2.XksProxyUriInUseException = XksProxyUriInUseException;
    var XksProxyUriUnreachableException = class _XksProxyUriUnreachableException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "XksProxyUriUnreachableException");
      }
      name = "XksProxyUriUnreachableException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "XksProxyUriUnreachableException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _XksProxyUriUnreachableException.prototype);
      }
    };
    exports2.XksProxyUriUnreachableException = XksProxyUriUnreachableException;
    var XksProxyVpcEndpointServiceInUseException = class _XksProxyVpcEndpointServiceInUseException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "XksProxyVpcEndpointServiceInUseException");
      }
      name = "XksProxyVpcEndpointServiceInUseException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "XksProxyVpcEndpointServiceInUseException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _XksProxyVpcEndpointServiceInUseException.prototype);
      }
    };
    exports2.XksProxyVpcEndpointServiceInUseException = XksProxyVpcEndpointServiceInUseException;
    var XksProxyVpcEndpointServiceInvalidConfigurationException = class _XksProxyVpcEndpointServiceInvalidConfigurationException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "XksProxyVpcEndpointServiceInvalidConfigurationException");
      }
      name = "XksProxyVpcEndpointServiceInvalidConfigurationException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "XksProxyVpcEndpointServiceInvalidConfigurationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _XksProxyVpcEndpointServiceInvalidConfigurationException.prototype);
      }
    };
    exports2.XksProxyVpcEndpointServiceInvalidConfigurationException = XksProxyVpcEndpointServiceInvalidConfigurationException;
    var XksProxyVpcEndpointServiceNotFoundException = class _XksProxyVpcEndpointServiceNotFoundException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "XksProxyVpcEndpointServiceNotFoundException");
      }
      name = "XksProxyVpcEndpointServiceNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "XksProxyVpcEndpointServiceNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _XksProxyVpcEndpointServiceNotFoundException.prototype);
      }
    };
    exports2.XksProxyVpcEndpointServiceNotFoundException = XksProxyVpcEndpointServiceNotFoundException;
    var DisabledException = class _DisabledException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "DisabledException");
      }
      name = "DisabledException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "DisabledException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DisabledException.prototype);
      }
    };
    exports2.DisabledException = DisabledException;
    var DryRunOperationException = class _DryRunOperationException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "DryRunOperationException");
      }
      name = "DryRunOperationException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "DryRunOperationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DryRunOperationException.prototype);
      }
    };
    exports2.DryRunOperationException = DryRunOperationException;
    var InvalidGrantTokenException = class _InvalidGrantTokenException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "InvalidGrantTokenException");
      }
      name = "InvalidGrantTokenException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidGrantTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidGrantTokenException.prototype);
      }
    };
    exports2.InvalidGrantTokenException = InvalidGrantTokenException;
    var MalformedPolicyDocumentException10 = class _MalformedPolicyDocumentException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "MalformedPolicyDocumentException");
      }
      name = "MalformedPolicyDocumentException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "MalformedPolicyDocumentException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _MalformedPolicyDocumentException.prototype);
      }
    };
    exports2.MalformedPolicyDocumentException = MalformedPolicyDocumentException10;
    var TagException = class _TagException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "TagException");
      }
      name = "TagException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TagException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TagException.prototype);
      }
    };
    exports2.TagException = TagException;
    var UnsupportedOperationException = class _UnsupportedOperationException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "UnsupportedOperationException");
      }
      name = "UnsupportedOperationException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "UnsupportedOperationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnsupportedOperationException.prototype);
      }
    };
    exports2.UnsupportedOperationException = UnsupportedOperationException;
    var XksKeyAlreadyInUseException = class _XksKeyAlreadyInUseException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "XksKeyAlreadyInUseException");
      }
      name = "XksKeyAlreadyInUseException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "XksKeyAlreadyInUseException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _XksKeyAlreadyInUseException.prototype);
      }
    };
    exports2.XksKeyAlreadyInUseException = XksKeyAlreadyInUseException;
    var XksKeyInvalidConfigurationException = class _XksKeyInvalidConfigurationException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "XksKeyInvalidConfigurationException");
      }
      name = "XksKeyInvalidConfigurationException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "XksKeyInvalidConfigurationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _XksKeyInvalidConfigurationException.prototype);
      }
    };
    exports2.XksKeyInvalidConfigurationException = XksKeyInvalidConfigurationException;
    var XksKeyNotFoundException = class _XksKeyNotFoundException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "XksKeyNotFoundException");
      }
      name = "XksKeyNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "XksKeyNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _XksKeyNotFoundException.prototype);
      }
    };
    exports2.XksKeyNotFoundException = XksKeyNotFoundException;
    var CustomKeyStoreHasCMKsException = class _CustomKeyStoreHasCMKsException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "CustomKeyStoreHasCMKsException");
      }
      name = "CustomKeyStoreHasCMKsException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "CustomKeyStoreHasCMKsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CustomKeyStoreHasCMKsException.prototype);
      }
    };
    exports2.CustomKeyStoreHasCMKsException = CustomKeyStoreHasCMKsException;
    var IncorrectKeyException = class _IncorrectKeyException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "IncorrectKeyException");
      }
      name = "IncorrectKeyException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "IncorrectKeyException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _IncorrectKeyException.prototype);
      }
    };
    exports2.IncorrectKeyException = IncorrectKeyException;
    var InvalidCiphertextException = class _InvalidCiphertextException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "InvalidCiphertextException");
      }
      name = "InvalidCiphertextException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidCiphertextException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidCiphertextException.prototype);
      }
    };
    exports2.InvalidCiphertextException = InvalidCiphertextException;
    var InvalidKeyUsageException = class _InvalidKeyUsageException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "InvalidKeyUsageException");
      }
      name = "InvalidKeyUsageException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidKeyUsageException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidKeyUsageException.prototype);
      }
    };
    exports2.InvalidKeyUsageException = InvalidKeyUsageException;
    var KeyUnavailableException = class _KeyUnavailableException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "KeyUnavailableException");
      }
      name = "KeyUnavailableException";
      $fault = "server";
      constructor(opts) {
        super({
          name: "KeyUnavailableException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _KeyUnavailableException.prototype);
      }
    };
    exports2.KeyUnavailableException = KeyUnavailableException;
    var InvalidMarkerException = class _InvalidMarkerException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "InvalidMarkerException");
      }
      name = "InvalidMarkerException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidMarkerException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidMarkerException.prototype);
      }
    };
    exports2.InvalidMarkerException = InvalidMarkerException;
    var ExpiredImportTokenException = class _ExpiredImportTokenException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "ExpiredImportTokenException");
      }
      name = "ExpiredImportTokenException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ExpiredImportTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ExpiredImportTokenException.prototype);
      }
    };
    exports2.ExpiredImportTokenException = ExpiredImportTokenException;
    var IncorrectKeyMaterialException = class _IncorrectKeyMaterialException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "IncorrectKeyMaterialException");
      }
      name = "IncorrectKeyMaterialException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "IncorrectKeyMaterialException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _IncorrectKeyMaterialException.prototype);
      }
    };
    exports2.IncorrectKeyMaterialException = IncorrectKeyMaterialException;
    var InvalidImportTokenException = class _InvalidImportTokenException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "InvalidImportTokenException");
      }
      name = "InvalidImportTokenException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidImportTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidImportTokenException.prototype);
      }
    };
    exports2.InvalidImportTokenException = InvalidImportTokenException;
    var InvalidGrantIdException = class _InvalidGrantIdException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "InvalidGrantIdException");
      }
      name = "InvalidGrantIdException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidGrantIdException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidGrantIdException.prototype);
      }
    };
    exports2.InvalidGrantIdException = InvalidGrantIdException;
    var KMSInvalidMacException = class _KMSInvalidMacException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "KMSInvalidMacException");
      }
      name = "KMSInvalidMacException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "KMSInvalidMacException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _KMSInvalidMacException.prototype);
      }
    };
    exports2.KMSInvalidMacException = KMSInvalidMacException;
    var KMSInvalidSignatureException = class _KMSInvalidSignatureException extends KMSServiceException_1.KMSServiceException {
      static {
        __name(this, "KMSInvalidSignatureException");
      }
      name = "KMSInvalidSignatureException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "KMSInvalidSignatureException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _KMSInvalidSignatureException.prototype);
      }
    };
    exports2.KMSInvalidSignatureException = KMSInvalidSignatureException;
  }
});

// ../../node_modules/@aws-sdk/client-kms/dist-cjs/schemas/schemas_0.js
var require_schemas_015 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/dist-cjs/schemas/schemas_0.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.errorTypeRegistries = exports2.XksProxyVpcEndpointServiceNotFoundException$ = exports2.XksProxyVpcEndpointServiceInvalidConfigurationException$ = exports2.XksProxyVpcEndpointServiceInUseException$ = exports2.XksProxyUriUnreachableException$ = exports2.XksProxyUriInUseException$ = exports2.XksProxyUriEndpointInUseException$ = exports2.XksProxyInvalidResponseException$ = exports2.XksProxyInvalidConfigurationException$ = exports2.XksProxyIncorrectAuthenticationCredentialException$ = exports2.XksKeyNotFoundException$ = exports2.XksKeyInvalidConfigurationException$ = exports2.XksKeyAlreadyInUseException$ = exports2.UnsupportedOperationException$ = exports2.TagException$ = exports2.NotFoundException$ = exports2.MalformedPolicyDocumentException$ = exports2.LimitExceededException$ = exports2.KMSInvalidStateException$ = exports2.KMSInvalidSignatureException$ = exports2.KMSInvalidMacException$ = exports2.KMSInternalException$ = exports2.KeyUnavailableException$ = exports2.InvalidMarkerException$ = exports2.InvalidKeyUsageException$ = exports2.InvalidImportTokenException$ = exports2.InvalidGrantTokenException$ = exports2.InvalidGrantIdException$ = exports2.InvalidCiphertextException$ = exports2.InvalidArnException$ = exports2.InvalidAliasNameException$ = exports2.IncorrectTrustAnchorException$ = exports2.IncorrectKeyMaterialException$ = exports2.IncorrectKeyException$ = exports2.ExpiredImportTokenException$ = exports2.DryRunOperationException$ = exports2.DisabledException$ = exports2.DependencyTimeoutException$ = exports2.CustomKeyStoreNotFoundException$ = exports2.CustomKeyStoreNameInUseException$ = exports2.CustomKeyStoreInvalidStateException$ = exports2.CustomKeyStoreHasCMKsException$ = exports2.ConflictException$ = exports2.CloudHsmClusterNotRelatedException$ = exports2.CloudHsmClusterNotFoundException$ = exports2.CloudHsmClusterNotActiveException$ = exports2.CloudHsmClusterInvalidConfigurationException$ = exports2.CloudHsmClusterInUseException$ = exports2.AlreadyExistsException$ = exports2.KMSServiceException$ = void 0;
    exports2.GetKeyPolicyResponse$ = exports2.GetKeyPolicyRequest$ = exports2.GetKeyLastUsageResponse$ = exports2.GetKeyLastUsageRequest$ = exports2.GenerateRandomResponse$ = exports2.GenerateRandomRequest$ = exports2.GenerateMacResponse$ = exports2.GenerateMacRequest$ = exports2.GenerateDataKeyWithoutPlaintextResponse$ = exports2.GenerateDataKeyWithoutPlaintextRequest$ = exports2.GenerateDataKeyResponse$ = exports2.GenerateDataKeyRequest$ = exports2.GenerateDataKeyPairWithoutPlaintextResponse$ = exports2.GenerateDataKeyPairWithoutPlaintextRequest$ = exports2.GenerateDataKeyPairResponse$ = exports2.GenerateDataKeyPairRequest$ = exports2.EncryptResponse$ = exports2.EncryptRequest$ = exports2.EnableKeyRotationRequest$ = exports2.EnableKeyRequest$ = exports2.DisconnectCustomKeyStoreResponse$ = exports2.DisconnectCustomKeyStoreRequest$ = exports2.DisableKeyRotationRequest$ = exports2.DisableKeyRequest$ = exports2.DescribeKeyResponse$ = exports2.DescribeKeyRequest$ = exports2.DescribeCustomKeyStoresResponse$ = exports2.DescribeCustomKeyStoresRequest$ = exports2.DeriveSharedSecretResponse$ = exports2.DeriveSharedSecretRequest$ = exports2.DeleteImportedKeyMaterialResponse$ = exports2.DeleteImportedKeyMaterialRequest$ = exports2.DeleteCustomKeyStoreResponse$ = exports2.DeleteCustomKeyStoreRequest$ = exports2.DeleteAliasRequest$ = exports2.DecryptResponse$ = exports2.DecryptRequest$ = exports2.CustomKeyStoresListEntry$ = exports2.CreateKeyResponse$ = exports2.CreateKeyRequest$ = exports2.CreateGrantResponse$ = exports2.CreateGrantRequest$ = exports2.CreateCustomKeyStoreResponse$ = exports2.CreateCustomKeyStoreRequest$ = exports2.CreateAliasRequest$ = exports2.ConnectCustomKeyStoreResponse$ = exports2.ConnectCustomKeyStoreRequest$ = exports2.CancelKeyDeletionResponse$ = exports2.CancelKeyDeletionRequest$ = exports2.AliasListEntry$ = void 0;
    exports2.UpdateKeyDescriptionRequest$ = exports2.UpdateCustomKeyStoreResponse$ = exports2.UpdateCustomKeyStoreRequest$ = exports2.UpdateAliasRequest$ = exports2.UntagResourceRequest$ = exports2.TagResourceRequest$ = exports2.Tag$ = exports2.SignResponse$ = exports2.SignRequest$ = exports2.ScheduleKeyDeletionResponse$ = exports2.ScheduleKeyDeletionRequest$ = exports2.RotationsListEntry$ = exports2.RotateKeyOnDemandResponse$ = exports2.RotateKeyOnDemandRequest$ = exports2.RevokeGrantRequest$ = exports2.RetireGrantRequest$ = exports2.ReplicateKeyResponse$ = exports2.ReplicateKeyRequest$ = exports2.ReEncryptResponse$ = exports2.ReEncryptRequest$ = exports2.RecipientInfo$ = exports2.PutKeyPolicyRequest$ = exports2.MultiRegionKey$ = exports2.MultiRegionConfiguration$ = exports2.ListRetirableGrantsRequest$ = exports2.ListResourceTagsResponse$ = exports2.ListResourceTagsRequest$ = exports2.ListKeysResponse$ = exports2.ListKeysRequest$ = exports2.ListKeyRotationsResponse$ = exports2.ListKeyRotationsRequest$ = exports2.ListKeyPoliciesResponse$ = exports2.ListKeyPoliciesRequest$ = exports2.ListGrantsResponse$ = exports2.ListGrantsRequest$ = exports2.ListAliasesResponse$ = exports2.ListAliasesRequest$ = exports2.KeyMetadata$ = exports2.KeyListEntry$ = exports2.KeyLastUsageData$ = exports2.ImportKeyMaterialResponse$ = exports2.ImportKeyMaterialRequest$ = exports2.GrantListEntry$ = exports2.GrantConstraints$ = exports2.GetPublicKeyResponse$ = exports2.GetPublicKeyRequest$ = exports2.GetParametersForImportResponse$ = exports2.GetParametersForImportRequest$ = exports2.GetKeyRotationStatusResponse$ = exports2.GetKeyRotationStatusRequest$ = void 0;
    exports2.RetireGrant$ = exports2.ReplicateKey$ = exports2.ReEncrypt$ = exports2.PutKeyPolicy$ = exports2.ListRetirableGrants$ = exports2.ListResourceTags$ = exports2.ListKeys$ = exports2.ListKeyRotations$ = exports2.ListKeyPolicies$ = exports2.ListGrants$ = exports2.ListAliases$ = exports2.ImportKeyMaterial$ = exports2.GetPublicKey$ = exports2.GetParametersForImport$ = exports2.GetKeyRotationStatus$ = exports2.GetKeyPolicy$ = exports2.GetKeyLastUsage$ = exports2.GenerateRandom$ = exports2.GenerateMac$ = exports2.GenerateDataKeyWithoutPlaintext$ = exports2.GenerateDataKeyPairWithoutPlaintext$ = exports2.GenerateDataKeyPair$ = exports2.GenerateDataKey$ = exports2.Encrypt$ = exports2.EnableKeyRotation$ = exports2.EnableKey$ = exports2.DisconnectCustomKeyStore$ = exports2.DisableKeyRotation$ = exports2.DisableKey$ = exports2.DescribeKey$ = exports2.DescribeCustomKeyStores$ = exports2.DeriveSharedSecret$ = exports2.DeleteImportedKeyMaterial$ = exports2.DeleteCustomKeyStore$ = exports2.DeleteAlias$ = exports2.Decrypt$ = exports2.CreateKey$ = exports2.CreateGrant$ = exports2.CreateCustomKeyStore$ = exports2.CreateAlias$ = exports2.ConnectCustomKeyStore$ = exports2.CancelKeyDeletion$ = exports2.XksProxyConfigurationType$ = exports2.XksProxyAuthenticationCredentialType$ = exports2.XksKeyConfigurationType$ = exports2.VerifyResponse$ = exports2.VerifyRequest$ = exports2.VerifyMacResponse$ = exports2.VerifyMacRequest$ = exports2.UpdatePrimaryRegionRequest$ = void 0;
    exports2.VerifyMac$ = exports2.Verify$ = exports2.UpdatePrimaryRegion$ = exports2.UpdateKeyDescription$ = exports2.UpdateCustomKeyStore$ = exports2.UpdateAlias$ = exports2.UntagResource$ = exports2.TagResource$ = exports2.Sign$ = exports2.ScheduleKeyDeletion$ = exports2.RotateKeyOnDemand$ = exports2.RevokeGrant$ = void 0;
    var _A10 = "Arn";
    var _AA = "AliasArn";
    var _AD = "AttestationDocument";
    var _AEE = "AlreadyExistsException";
    var _AKI11 = "AccessKeyId";
    var _AL = "AliasList";
    var _ALE = "AliasListEntry";
    var _AN = "AliasName";
    var _AWSAI = "AWSAccountId";
    var _Al = "Aliases";
    var _BPLSC = "BypassPolicyLockoutSafetyCheck";
    var _C11 = "Constraints";
    var _CA10 = "CreateAlias";
    var _CAR = "CreateAliasRequest";
    var _CB = "CiphertextBlob";
    var _CCKS = "ConnectCustomKeyStore";
    var _CCKSR = "ConnectCustomKeyStoreRequest";
    var _CCKSRo = "ConnectCustomKeyStoreResponse";
    var _CCKSRr = "CreateCustomKeyStoreRequest";
    var _CCKSRre = "CreateCustomKeyStoreResponse";
    var _CCKSr = "CreateCustomKeyStore";
    var _CD = "CreationDate";
    var _CE = "ConflictException";
    var _CEC = "ConnectionErrorCode";
    var _CFR = "CiphertextForRecipient";
    var _CG = "CreateGrant";
    var _CGR = "CreateGrantRequest";
    var _CGRr = "CreateGrantResponse";
    var _CHCI = "CloudHsmClusterId";
    var _CHCICE = "CloudHsmClusterInvalidConfigurationException";
    var _CHCIUE = "CloudHsmClusterInUseException";
    var _CHCNAE = "CloudHsmClusterNotActiveException";
    var _CHCNFE = "CloudHsmClusterNotFoundException";
    var _CHCNRE = "CloudHsmClusterNotRelatedException";
    var _CK = "CreateKey";
    var _CKD = "CancelKeyDeletion";
    var _CKDR = "CancelKeyDeletionRequest";
    var _CKDRa = "CancelKeyDeletionResponse";
    var _CKMI = "CurrentKeyMaterialId";
    var _CKR = "CreateKeyRequest";
    var _CKRr = "CreateKeyResponse";
    var _CKS = "CustomKeyStores";
    var _CKSHCMKE = "CustomKeyStoreHasCMKsException";
    var _CKSI = "CustomKeyStoreId";
    var _CKSISE = "CustomKeyStoreInvalidStateException";
    var _CKSL = "CustomKeyStoresList";
    var _CKSLE = "CustomKeyStoresListEntry";
    var _CKSN = "CustomKeyStoreName";
    var _CKSNFE = "CustomKeyStoreNotFoundException";
    var _CKSNIUE = "CustomKeyStoreNameInUseException";
    var _CKST = "CustomKeyStoreType";
    var _CMKS = "CustomerMasterKeySpec";
    var _CS4 = "ConnectionState";
    var _CTEI = "CloudTrailEventId";
    var _Co = "Connectivity";
    var _D = "Description";
    var _DA = "DeleteAlias";
    var _DAR = "DeleteAliasRequest";
    var _DCKS = "DeleteCustomKeyStore";
    var _DCKSR = "DeleteCustomKeyStoreRequest";
    var _DCKSRe = "DeleteCustomKeyStoreResponse";
    var _DCKSRes = "DescribeCustomKeyStoresRequest";
    var _DCKSResc = "DescribeCustomKeyStoresResponse";
    var _DCKSRi = "DisconnectCustomKeyStoreRequest";
    var _DCKSRis = "DisconnectCustomKeyStoreResponse";
    var _DCKSe = "DescribeCustomKeyStores";
    var _DCKSi = "DisconnectCustomKeyStore";
    var _DD = "DeletionDate";
    var _DE = "DisabledException";
    var _DEA = "DestinationEncryptionAlgorithm";
    var _DEC = "DestinationEncryptionContext";
    var _DIKM = "DeleteImportedKeyMaterial";
    var _DIKMR = "DeleteImportedKeyMaterialRequest";
    var _DIKMRe = "DeleteImportedKeyMaterialResponse";
    var _DK = "DescribeKey";
    var _DKI = "DestinationKeyId";
    var _DKMI = "DestinationKeyMaterialId";
    var _DKR = "DescribeKeyRequest";
    var _DKRR = "DisableKeyRotationRequest";
    var _DKRe = "DescribeKeyResponse";
    var _DKRi = "DisableKeyRequest";
    var _DKRis = "DisableKeyRotation";
    var _DKi = "DisableKey";
    var _DR = "DryRun";
    var _DRM = "DryRunModifiers";
    var _DROE = "DryRunOperationException";
    var _DRe = "DecryptRequest";
    var _DRec = "DecryptResponse";
    var _DSS = "DeriveSharedSecret";
    var _DSSR = "DeriveSharedSecretRequest";
    var _DSSRe = "DeriveSharedSecretResponse";
    var _DTE = "DependencyTimeoutException";
    var _De = "Decrypt";
    var _E11 = "Enabled";
    var _EA = "EncryptionAlgorithm";
    var _EAn = "EncryptionAlgorithms";
    var _EC = "EncryptionContext";
    var _ECE = "EncryptionContextEquals";
    var _ECS = "EncryptionContextSubset";
    var _EITE = "ExpiredImportTokenException";
    var _EK = "EnableKey";
    var _EKM = "EncryptedKeyMaterial";
    var _EKR = "EnableKeyRequest";
    var _EKRR = "EnableKeyRotationRequest";
    var _EKRn = "EnableKeyRotation";
    var _EM = "ExpirationModel";
    var _ER = "EncryptRequest";
    var _ERn = "EncryptResponse";
    var _En = "Encrypt";
    var _G = "Grants";
    var _GC = "GrantConstraints";
    var _GDK = "GenerateDataKey";
    var _GDKP = "GenerateDataKeyPair";
    var _GDKPR = "GenerateDataKeyPairRequest";
    var _GDKPRe = "GenerateDataKeyPairResponse";
    var _GDKPWP = "GenerateDataKeyPairWithoutPlaintext";
    var _GDKPWPR = "GenerateDataKeyPairWithoutPlaintextRequest";
    var _GDKPWPRe = "GenerateDataKeyPairWithoutPlaintextResponse";
    var _GDKR = "GenerateDataKeyRequest";
    var _GDKRe = "GenerateDataKeyResponse";
    var _GDKWP = "GenerateDataKeyWithoutPlaintext";
    var _GDKWPR = "GenerateDataKeyWithoutPlaintextRequest";
    var _GDKWPRe = "GenerateDataKeyWithoutPlaintextResponse";
    var _GI2 = "GrantId";
    var _GKLU = "GetKeyLastUsage";
    var _GKLUR = "GetKeyLastUsageRequest";
    var _GKLURe = "GetKeyLastUsageResponse";
    var _GKP = "GetKeyPolicy";
    var _GKPR = "GetKeyPolicyRequest";
    var _GKPRe = "GetKeyPolicyResponse";
    var _GKRS = "GetKeyRotationStatus";
    var _GKRSR = "GetKeyRotationStatusRequest";
    var _GKRSRe = "GetKeyRotationStatusResponse";
    var _GL = "GrantList";
    var _GLE = "GrantListEntry";
    var _GM = "GenerateMac";
    var _GMR = "GenerateMacRequest";
    var _GMRe = "GenerateMacResponse";
    var _GP = "GranteePrincipal";
    var _GPFI = "GetParametersForImport";
    var _GPFIR = "GetParametersForImportRequest";
    var _GPFIRe = "GetParametersForImportResponse";
    var _GPK = "GetPublicKey";
    var _GPKR = "GetPublicKeyRequest";
    var _GPKRe = "GetPublicKeyResponse";
    var _GR = "GenerateRandom";
    var _GRR = "GenerateRandomRequest";
    var _GRRe = "GenerateRandomResponse";
    var _GT = "GrantTokens";
    var _GTr = "GrantToken";
    var _I = "Id";
    var _IA = "IssuingAccount";
    var _IAE = "InvalidArnException";
    var _IANE = "InvalidAliasNameException";
    var _ICE4 = "InvalidCiphertextException";
    var _IGIE = "InvalidGrantIdException";
    var _IGTE = "InvalidGrantTokenException";
    var _IITE10 = "InvalidImportTokenException";
    var _IKE = "IncorrectKeyException";
    var _IKM = "IncludeKeyMaterial";
    var _IKME = "IncorrectKeyMaterialException";
    var _IKMR = "ImportKeyMaterialRequest";
    var _IKMRm = "ImportKeyMaterialResponse";
    var _IKMm = "ImportKeyMaterial";
    var _IKUE = "InvalidKeyUsageException";
    var _IME = "InvalidMarkerException";
    var _IS = "ImportState";
    var _IT4 = "ImportToken";
    var _ITAE = "IncorrectTrustAnchorException";
    var _ITm = "ImportType";
    var _K10 = "Keys";
    var _KA = "KeyArn";
    var _KAA = "KeyAgreementAlgorithm";
    var _KAAe = "KeyAgreementAlgorithms";
    var _KCD = "KeyCreationDate";
    var _KEA = "KeyEncryptionAlgorithm";
    var _KI = "KeyId";
    var _KL = "KeyList";
    var _KLE = "KeyListEntry";
    var _KLU = "KeyLastUsage";
    var _KLUD = "KeyLastUsageData";
    var _KM = "KeyMetadata";
    var _KMD = "KeyMaterialDescription";
    var _KMI = "KeyMaterialId";
    var _KMS = "KeyMaterialState";
    var _KMSIE = "KMSInternalException";
    var _KMSIME = "KMSInvalidMacException";
    var _KMSISE = "KMSInvalidSignatureException";
    var _KMSISEn = "KMSInvalidStateException";
    var _KMe = "KeyManager";
    var _KO = "KeyOrigin";
    var _KPS = "KeyPairSpec";
    var _KRE = "KeyRotationEnabled";
    var _KRI = "KmsRequestId";
    var _KS = "KeySpec";
    var _KSP = "KeyStorePassword";
    var _KSPT = "KeyStorePasswordType";
    var _KSe = "KeyState";
    var _KU = "KeyUsage";
    var _KUE = "KeyUnavailableException";
    var _L2 = "Limit";
    var _LA = "ListAliases";
    var _LAR = "ListAliasesRequest";
    var _LARi = "ListAliasesResponse";
    var _LEE2 = "LimitExceededException";
    var _LG = "ListGrants";
    var _LGR = "ListGrantsRequest";
    var _LGRi = "ListGrantsResponse";
    var _LK = "ListKeys";
    var _LKP = "ListKeyPolicies";
    var _LKPR = "ListKeyPoliciesRequest";
    var _LKPRi = "ListKeyPoliciesResponse";
    var _LKR = "ListKeysRequest";
    var _LKRR = "ListKeyRotationsRequest";
    var _LKRRi = "ListKeyRotationsResponse";
    var _LKRi = "ListKeysResponse";
    var _LKRis = "ListKeyRotations";
    var _LRG = "ListRetirableGrants";
    var _LRGR = "ListRetirableGrantsRequest";
    var _LRT = "ListResourceTags";
    var _LRTR = "ListResourceTagsRequest";
    var _LRTRi = "ListResourceTagsResponse";
    var _LUD = "LastUpdatedDate";
    var _M = "Marker";
    var _MA = "MacAlgorithm";
    var _MAa = "MacAlgorithms";
    var _MPDE10 = "MalformedPolicyDocumentException";
    var _MR = "MultiRegion";
    var _MRC = "MultiRegionConfiguration";
    var _MRK = "MultiRegionKey";
    var _MRKL = "MultiRegionKeyList";
    var _MRKT = "MultiRegionKeyType";
    var _MT = "MessageType";
    var _MV = "MacValid";
    var _Ma = "Mac";
    var _Me = "Message";
    var _N = "Name";
    var _NCKSN = "NewCustomKeyStoreName";
    var _NFE = "NotFoundException";
    var _NM = "NextMarker";
    var _NOB = "NumberOfBytes";
    var _NRD = "NextRotationDate";
    var _O = "Operations";
    var _ODRSD = "OnDemandRotationStartDate";
    var _Op = "Operation";
    var _Or = "Origin";
    var _P10 = "Policy";
    var _PDWID = "PendingDeletionWindowInDays";
    var _PK = "PublicKey";
    var _PKCB = "PrivateKeyCiphertextBlob";
    var _PKP = "PrivateKeyPlaintext";
    var _PKPR = "PutKeyPolicyRequest";
    var _PKPu = "PutKeyPolicy";
    var _PKr = "PrimaryKey";
    var _PN = "PolicyName";
    var _PNo = "PolicyNames";
    var _PR = "PrimaryRegion";
    var _PT = "PlaintextType";
    var _PVT = "ParametersValidTo";
    var _PWID = "PendingWindowInDays";
    var _Pl = "Plaintext";
    var _R = "Recipient";
    var _RD = "RotationDate";
    var _RE = "ReEncrypt";
    var _RER = "ReEncryptRequest";
    var _RERe = "ReEncryptResponse";
    var _RG = "RetireGrant";
    var _RGR = "RetireGrantRequest";
    var _RGRe = "RevokeGrantRequest";
    var _RGe = "RevokeGrant";
    var _RI = "RecipientInfo";
    var _RK = "ReplicaKeys";
    var _RKM = "ReplicaKeyMetadata";
    var _RKOD = "RotateKeyOnDemand";
    var _RKODR = "RotateKeyOnDemandRequest";
    var _RKODRo = "RotateKeyOnDemandResponse";
    var _RKR = "ReplicateKeyRequest";
    var _RKRe = "ReplicateKeyResponse";
    var _RKe = "ReplicateKey";
    var _RL = "RotationsList";
    var _RLE = "RotationsListEntry";
    var _RP = "RetiringPrincipal";
    var _RPID = "RotationPeriodInDays";
    var _RPe = "ReplicaPolicy";
    var _RR = "ReplicaRegion";
    var _RSAK = "RawSecretAccessKey";
    var _RT13 = "ReplicaTags";
    var _RTo = "RotationType";
    var _Re = "Region";
    var _Ro = "Rotations";
    var _S = "Signature";
    var _SA = "SigningAlgorithms";
    var _SAi = "SigningAlgorithm";
    var _SEA = "SourceEncryptionAlgorithm";
    var _SEC = "SourceEncryptionContext";
    var _SKD = "ScheduleKeyDeletion";
    var _SKDR = "ScheduleKeyDeletionRequest";
    var _SKDRc = "ScheduleKeyDeletionResponse";
    var _SKI = "SourceKeyId";
    var _SKMI = "SourceKeyMaterialId";
    var _SR = "SignRequest";
    var _SRi = "SignResponse";
    var _SS = "SharedSecret";
    var _SV = "SignatureValid";
    var _Si = "Sign";
    var _T10 = "Tags";
    var _TAC = "TrustAnchorCertificate";
    var _TE = "TagException";
    var _TK = "TagKey";
    var _TKI = "TargetKeyId";
    var _TKa = "TagKeys";
    var _TL = "TagList";
    var _TR = "TagResource";
    var _TRR = "TagResourceRequest";
    var _TSD = "TrackingStartDate";
    var _TV = "TagValue";
    var _Ta10 = "Tag";
    var _Ti = "Timestamp";
    var _Tr = "Truncated";
    var _UA = "UpdateAlias";
    var _UAR = "UpdateAliasRequest";
    var _UCKS = "UpdateCustomKeyStore";
    var _UCKSR = "UpdateCustomKeyStoreRequest";
    var _UCKSRp = "UpdateCustomKeyStoreResponse";
    var _UE10 = "UriEndpoint";
    var _UKD = "UpdateKeyDescription";
    var _UKDR = "UpdateKeyDescriptionRequest";
    var _UOE = "UnsupportedOperationException";
    var _UP = "UriPath";
    var _UPR = "UpdatePrimaryRegion";
    var _UPRR = "UpdatePrimaryRegionRequest";
    var _UR = "UntagResource";
    var _URR = "UntagResourceRequest";
    var _V10 = "Verify";
    var _VESN = "VpcEndpointServiceName";
    var _VESO = "VpcEndpointServiceOwner";
    var _VM = "VerifyMac";
    var _VMR = "VerifyMacRequest";
    var _VMRe = "VerifyMacResponse";
    var _VR = "VerifyRequest";
    var _VRe = "VerifyResponse";
    var _VT = "ValidTo";
    var _WA = "WrappingAlgorithm";
    var _WKS = "WrappingKeySpec";
    var _XKAIUE = "XksKeyAlreadyInUseException";
    var _XKC = "XksKeyConfiguration";
    var _XKCT = "XksKeyConfigurationType";
    var _XKI = "XksKeyId";
    var _XKICE = "XksKeyInvalidConfigurationException";
    var _XKNFE = "XksKeyNotFoundException";
    var _XPAAKIT = "XksProxyAuthenticationAccessKeyIdType";
    var _XPAC = "XksProxyAuthenticationCredential";
    var _XPACT = "XksProxyAuthenticationCredentialType";
    var _XPARSAKT = "XksProxyAuthenticationRawSecretAccessKeyType";
    var _XPC = "XksProxyConnectivity";
    var _XPCT = "XksProxyConfigurationType";
    var _XPCk = "XksProxyConfiguration";
    var _XPIACE = "XksProxyIncorrectAuthenticationCredentialException";
    var _XPICE = "XksProxyInvalidConfigurationException";
    var _XPIRE = "XksProxyInvalidResponseException";
    var _XPUE = "XksProxyUriEndpoint";
    var _XPUEIUE = "XksProxyUriEndpointInUseException";
    var _XPUIUE = "XksProxyUriInUseException";
    var _XPUP = "XksProxyUriPath";
    var _XPUUE = "XksProxyUriUnreachableException";
    var _XPVESICE = "XksProxyVpcEndpointServiceInvalidConfigurationException";
    var _XPVESIUE = "XksProxyVpcEndpointServiceInUseException";
    var _XPVESN = "XksProxyVpcEndpointServiceName";
    var _XPVESNFE = "XksProxyVpcEndpointServiceNotFoundException";
    var _XPVESO = "XksProxyVpcEndpointServiceOwner";
    var _aQE10 = "awsQueryError";
    var _c32 = "client";
    var _e32 = "error";
    var _hE32 = "httpError";
    var _m29 = "message";
    var _s32 = "smithy.ts.sdk.synthetic.com.amazonaws.kms";
    var _se14 = "server";
    var n032 = "com.amazonaws.kms";
    var schema_1 = (init_schema4(), __toCommonJS(schema_exports));
    var errors_1 = require_errors14();
    var KMSServiceException_1 = require_KMSServiceException();
    var _s_registry32 = schema_1.TypeRegistry.for(_s32);
    exports2.KMSServiceException$ = [-3, _s32, "KMSServiceException", 0, [], []];
    _s_registry32.registerError(exports2.KMSServiceException$, KMSServiceException_1.KMSServiceException);
    var n0_registry32 = schema_1.TypeRegistry.for(n032);
    exports2.AlreadyExistsException$ = [
      -3,
      n032,
      _AEE,
      { [_aQE10]: [`AlreadyExists`, 409], [_e32]: _c32, [_hE32]: 409 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.AlreadyExistsException$, errors_1.AlreadyExistsException);
    exports2.CloudHsmClusterInUseException$ = [
      -3,
      n032,
      _CHCIUE,
      { [_aQE10]: [`CloudHsmClusterInUseException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.CloudHsmClusterInUseException$, errors_1.CloudHsmClusterInUseException);
    exports2.CloudHsmClusterInvalidConfigurationException$ = [
      -3,
      n032,
      _CHCICE,
      { [_aQE10]: [`CloudHsmClusterInvalidConfigurationException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.CloudHsmClusterInvalidConfigurationException$, errors_1.CloudHsmClusterInvalidConfigurationException);
    exports2.CloudHsmClusterNotActiveException$ = [
      -3,
      n032,
      _CHCNAE,
      { [_aQE10]: [`CloudHsmClusterNotActiveException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.CloudHsmClusterNotActiveException$, errors_1.CloudHsmClusterNotActiveException);
    exports2.CloudHsmClusterNotFoundException$ = [
      -3,
      n032,
      _CHCNFE,
      { [_aQE10]: [`CloudHsmClusterNotFoundException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.CloudHsmClusterNotFoundException$, errors_1.CloudHsmClusterNotFoundException);
    exports2.CloudHsmClusterNotRelatedException$ = [
      -3,
      n032,
      _CHCNRE,
      { [_aQE10]: [`CloudHsmClusterNotRelatedException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.CloudHsmClusterNotRelatedException$, errors_1.CloudHsmClusterNotRelatedException);
    exports2.ConflictException$ = [
      -3,
      n032,
      _CE,
      { [_aQE10]: [`ConflictException`, 409], [_e32]: _c32, [_hE32]: 409 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ConflictException$, errors_1.ConflictException);
    exports2.CustomKeyStoreHasCMKsException$ = [
      -3,
      n032,
      _CKSHCMKE,
      { [_aQE10]: [`CustomKeyStoreHasCMKsException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.CustomKeyStoreHasCMKsException$, errors_1.CustomKeyStoreHasCMKsException);
    exports2.CustomKeyStoreInvalidStateException$ = [
      -3,
      n032,
      _CKSISE,
      { [_aQE10]: [`CustomKeyStoreInvalidStateException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.CustomKeyStoreInvalidStateException$, errors_1.CustomKeyStoreInvalidStateException);
    exports2.CustomKeyStoreNameInUseException$ = [
      -3,
      n032,
      _CKSNIUE,
      { [_aQE10]: [`CustomKeyStoreNameInUseException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.CustomKeyStoreNameInUseException$, errors_1.CustomKeyStoreNameInUseException);
    exports2.CustomKeyStoreNotFoundException$ = [
      -3,
      n032,
      _CKSNFE,
      { [_aQE10]: [`CustomKeyStoreNotFoundException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.CustomKeyStoreNotFoundException$, errors_1.CustomKeyStoreNotFoundException);
    exports2.DependencyTimeoutException$ = [
      -3,
      n032,
      _DTE,
      { [_aQE10]: [`DependencyTimeout`, 503], [_e32]: _se14, [_hE32]: 503 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.DependencyTimeoutException$, errors_1.DependencyTimeoutException);
    exports2.DisabledException$ = [
      -3,
      n032,
      _DE,
      { [_aQE10]: [`Disabled`, 409], [_e32]: _c32, [_hE32]: 409 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.DisabledException$, errors_1.DisabledException);
    exports2.DryRunOperationException$ = [
      -3,
      n032,
      _DROE,
      { [_aQE10]: [`DryRunOperation`, 412], [_e32]: _c32, [_hE32]: 412 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.DryRunOperationException$, errors_1.DryRunOperationException);
    exports2.ExpiredImportTokenException$ = [
      -3,
      n032,
      _EITE,
      { [_aQE10]: [`ExpiredImportTokenException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ExpiredImportTokenException$, errors_1.ExpiredImportTokenException);
    exports2.IncorrectKeyException$ = [
      -3,
      n032,
      _IKE,
      { [_aQE10]: [`IncorrectKeyException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.IncorrectKeyException$, errors_1.IncorrectKeyException);
    exports2.IncorrectKeyMaterialException$ = [
      -3,
      n032,
      _IKME,
      { [_aQE10]: [`IncorrectKeyMaterialException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.IncorrectKeyMaterialException$, errors_1.IncorrectKeyMaterialException);
    exports2.IncorrectTrustAnchorException$ = [
      -3,
      n032,
      _ITAE,
      { [_aQE10]: [`IncorrectTrustAnchorException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.IncorrectTrustAnchorException$, errors_1.IncorrectTrustAnchorException);
    exports2.InvalidAliasNameException$ = [
      -3,
      n032,
      _IANE,
      { [_aQE10]: [`InvalidAliasName`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidAliasNameException$, errors_1.InvalidAliasNameException);
    exports2.InvalidArnException$ = [
      -3,
      n032,
      _IAE,
      { [_aQE10]: [`InvalidArn`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidArnException$, errors_1.InvalidArnException);
    exports2.InvalidCiphertextException$ = [
      -3,
      n032,
      _ICE4,
      { [_aQE10]: [`InvalidCiphertext`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidCiphertextException$, errors_1.InvalidCiphertextException);
    exports2.InvalidGrantIdException$ = [
      -3,
      n032,
      _IGIE,
      { [_aQE10]: [`InvalidGrantId`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidGrantIdException$, errors_1.InvalidGrantIdException);
    exports2.InvalidGrantTokenException$ = [
      -3,
      n032,
      _IGTE,
      { [_aQE10]: [`InvalidGrantToken`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidGrantTokenException$, errors_1.InvalidGrantTokenException);
    exports2.InvalidImportTokenException$ = [
      -3,
      n032,
      _IITE10,
      { [_aQE10]: [`InvalidImportTokenException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidImportTokenException$, errors_1.InvalidImportTokenException);
    exports2.InvalidKeyUsageException$ = [
      -3,
      n032,
      _IKUE,
      { [_aQE10]: [`InvalidKeyUsage`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidKeyUsageException$, errors_1.InvalidKeyUsageException);
    exports2.InvalidMarkerException$ = [
      -3,
      n032,
      _IME,
      { [_aQE10]: [`InvalidMarker`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidMarkerException$, errors_1.InvalidMarkerException);
    exports2.KeyUnavailableException$ = [
      -3,
      n032,
      _KUE,
      { [_aQE10]: [`KeyUnavailable`, 500], [_e32]: _se14, [_hE32]: 500 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.KeyUnavailableException$, errors_1.KeyUnavailableException);
    exports2.KMSInternalException$ = [
      -3,
      n032,
      _KMSIE,
      { [_aQE10]: [`KMSInternal`, 500], [_e32]: _se14, [_hE32]: 500 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.KMSInternalException$, errors_1.KMSInternalException);
    exports2.KMSInvalidMacException$ = [
      -3,
      n032,
      _KMSIME,
      { [_aQE10]: [`KMSInvalidMac`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.KMSInvalidMacException$, errors_1.KMSInvalidMacException);
    exports2.KMSInvalidSignatureException$ = [
      -3,
      n032,
      _KMSISE,
      { [_aQE10]: [`KMSInvalidSignature`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.KMSInvalidSignatureException$, errors_1.KMSInvalidSignatureException);
    exports2.KMSInvalidStateException$ = [
      -3,
      n032,
      _KMSISEn,
      { [_aQE10]: [`KMSInvalidStateException`, 409], [_e32]: _c32, [_hE32]: 409 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.KMSInvalidStateException$, errors_1.KMSInvalidStateException);
    exports2.LimitExceededException$ = [
      -3,
      n032,
      _LEE2,
      { [_aQE10]: [`LimitExceeded`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.LimitExceededException$, errors_1.LimitExceededException);
    exports2.MalformedPolicyDocumentException$ = [
      -3,
      n032,
      _MPDE10,
      { [_aQE10]: [`MalformedPolicyDocument`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.MalformedPolicyDocumentException$, errors_1.MalformedPolicyDocumentException);
    exports2.NotFoundException$ = [
      -3,
      n032,
      _NFE,
      { [_aQE10]: [`NotFound`, 404], [_e32]: _c32, [_hE32]: 404 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.NotFoundException$, errors_1.NotFoundException);
    exports2.TagException$ = [
      -3,
      n032,
      _TE,
      { [_aQE10]: [`TagException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.TagException$, errors_1.TagException);
    exports2.UnsupportedOperationException$ = [
      -3,
      n032,
      _UOE,
      { [_aQE10]: [`UnsupportedOperation`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.UnsupportedOperationException$, errors_1.UnsupportedOperationException);
    exports2.XksKeyAlreadyInUseException$ = [
      -3,
      n032,
      _XKAIUE,
      { [_aQE10]: [`XksKeyAlreadyInUse`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.XksKeyAlreadyInUseException$, errors_1.XksKeyAlreadyInUseException);
    exports2.XksKeyInvalidConfigurationException$ = [
      -3,
      n032,
      _XKICE,
      { [_aQE10]: [`XksKeyInvalidConfiguration`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.XksKeyInvalidConfigurationException$, errors_1.XksKeyInvalidConfigurationException);
    exports2.XksKeyNotFoundException$ = [
      -3,
      n032,
      _XKNFE,
      { [_aQE10]: [`XksKeyNotFoundException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.XksKeyNotFoundException$, errors_1.XksKeyNotFoundException);
    exports2.XksProxyIncorrectAuthenticationCredentialException$ = [
      -3,
      n032,
      _XPIACE,
      { [_aQE10]: [`XksProxyIncorrectAuthenticationCredentialException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.XksProxyIncorrectAuthenticationCredentialException$, errors_1.XksProxyIncorrectAuthenticationCredentialException);
    exports2.XksProxyInvalidConfigurationException$ = [
      -3,
      n032,
      _XPICE,
      { [_aQE10]: [`XksProxyInvalidConfigurationException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.XksProxyInvalidConfigurationException$, errors_1.XksProxyInvalidConfigurationException);
    exports2.XksProxyInvalidResponseException$ = [
      -3,
      n032,
      _XPIRE,
      { [_aQE10]: [`XksProxyInvalidResponseException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.XksProxyInvalidResponseException$, errors_1.XksProxyInvalidResponseException);
    exports2.XksProxyUriEndpointInUseException$ = [
      -3,
      n032,
      _XPUEIUE,
      { [_aQE10]: [`XksProxyUriEndpointInUseException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.XksProxyUriEndpointInUseException$, errors_1.XksProxyUriEndpointInUseException);
    exports2.XksProxyUriInUseException$ = [
      -3,
      n032,
      _XPUIUE,
      { [_aQE10]: [`XksProxyUriInUseException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.XksProxyUriInUseException$, errors_1.XksProxyUriInUseException);
    exports2.XksProxyUriUnreachableException$ = [
      -3,
      n032,
      _XPUUE,
      { [_aQE10]: [`XksProxyUriUnreachableException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.XksProxyUriUnreachableException$, errors_1.XksProxyUriUnreachableException);
    exports2.XksProxyVpcEndpointServiceInUseException$ = [
      -3,
      n032,
      _XPVESIUE,
      { [_aQE10]: [`XksProxyVpcEndpointServiceInUseException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.XksProxyVpcEndpointServiceInUseException$, errors_1.XksProxyVpcEndpointServiceInUseException);
    exports2.XksProxyVpcEndpointServiceInvalidConfigurationException$ = [
      -3,
      n032,
      _XPVESICE,
      { [_aQE10]: [`XksProxyVpcEndpointServiceInvalidConfigurationException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.XksProxyVpcEndpointServiceInvalidConfigurationException$, errors_1.XksProxyVpcEndpointServiceInvalidConfigurationException);
    exports2.XksProxyVpcEndpointServiceNotFoundException$ = [
      -3,
      n032,
      _XPVESNFE,
      { [_aQE10]: [`XksProxyVpcEndpointServiceNotFoundException`, 400], [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.XksProxyVpcEndpointServiceNotFoundException$, errors_1.XksProxyVpcEndpointServiceNotFoundException);
    exports2.errorTypeRegistries = [
      _s_registry32,
      n0_registry32
    ];
    var KeyStorePasswordType = [0, n032, _KSPT, 8, 0];
    var PlaintextType = [0, n032, _PT, 8, 21];
    var XksProxyAuthenticationAccessKeyIdType = [0, n032, _XPAAKIT, 8, 0];
    var XksProxyAuthenticationRawSecretAccessKeyType = [0, n032, _XPARSAKT, 8, 0];
    exports2.AliasListEntry$ = [
      3,
      n032,
      _ALE,
      0,
      [_AN, _AA, _TKI, _CD, _LUD],
      [0, 0, 0, 4, 4]
    ];
    exports2.CancelKeyDeletionRequest$ = [
      3,
      n032,
      _CKDR,
      0,
      [_KI],
      [0],
      1
    ];
    exports2.CancelKeyDeletionResponse$ = [
      3,
      n032,
      _CKDRa,
      0,
      [_KI],
      [0]
    ];
    exports2.ConnectCustomKeyStoreRequest$ = [
      3,
      n032,
      _CCKSR,
      0,
      [_CKSI],
      [0],
      1
    ];
    exports2.ConnectCustomKeyStoreResponse$ = [
      3,
      n032,
      _CCKSRo,
      0,
      [],
      []
    ];
    exports2.CreateAliasRequest$ = [
      3,
      n032,
      _CAR,
      0,
      [_AN, _TKI],
      [0, 0],
      2
    ];
    exports2.CreateCustomKeyStoreRequest$ = [
      3,
      n032,
      _CCKSRr,
      0,
      [_CKSN, _CHCI, _TAC, _KSP, _CKST, _XPUE, _XPUP, _XPVESN, _XPVESO, _XPAC, _XPC],
      [0, 0, 0, [() => KeyStorePasswordType, 0], 0, 0, 0, 0, 0, [() => exports2.XksProxyAuthenticationCredentialType$, 0], 0],
      1
    ];
    exports2.CreateCustomKeyStoreResponse$ = [
      3,
      n032,
      _CCKSRre,
      0,
      [_CKSI],
      [0]
    ];
    exports2.CreateGrantRequest$ = [
      3,
      n032,
      _CGR,
      0,
      [_KI, _GP, _O, _RP, _C11, _GT, _N, _DR],
      [0, 0, 64 | 0, 0, () => exports2.GrantConstraints$, 64 | 0, 0, 2],
      3
    ];
    exports2.CreateGrantResponse$ = [
      3,
      n032,
      _CGRr,
      0,
      [_GTr, _GI2],
      [0, 0]
    ];
    exports2.CreateKeyRequest$ = [
      3,
      n032,
      _CKR,
      0,
      [_P10, _D, _KU, _CMKS, _KS, _Or, _CKSI, _BPLSC, _T10, _MR, _XKI],
      [0, 0, 0, 0, 0, 0, 0, 2, () => TagList, 2, 0]
    ];
    exports2.CreateKeyResponse$ = [
      3,
      n032,
      _CKRr,
      0,
      [_KM],
      [() => exports2.KeyMetadata$]
    ];
    exports2.CustomKeyStoresListEntry$ = [
      3,
      n032,
      _CKSLE,
      0,
      [_CKSI, _CKSN, _CHCI, _TAC, _CS4, _CEC, _CD, _CKST, _XPCk],
      [0, 0, 0, 0, 0, 0, 4, 0, [() => exports2.XksProxyConfigurationType$, 0]]
    ];
    exports2.DecryptRequest$ = [
      3,
      n032,
      _DRe,
      0,
      [_CB, _EC, _GT, _KI, _EA, _R, _DR, _DRM],
      [21, 128 | 0, 64 | 0, 0, 0, () => exports2.RecipientInfo$, 2, 64 | 0]
    ];
    exports2.DecryptResponse$ = [
      3,
      n032,
      _DRec,
      0,
      [_KI, _Pl, _EA, _CFR, _KMI],
      [0, [() => PlaintextType, 0], 0, 21, 0]
    ];
    exports2.DeleteAliasRequest$ = [
      3,
      n032,
      _DAR,
      0,
      [_AN],
      [0],
      1
    ];
    exports2.DeleteCustomKeyStoreRequest$ = [
      3,
      n032,
      _DCKSR,
      0,
      [_CKSI],
      [0],
      1
    ];
    exports2.DeleteCustomKeyStoreResponse$ = [
      3,
      n032,
      _DCKSRe,
      0,
      [],
      []
    ];
    exports2.DeleteImportedKeyMaterialRequest$ = [
      3,
      n032,
      _DIKMR,
      0,
      [_KI, _KMI],
      [0, 0],
      1
    ];
    exports2.DeleteImportedKeyMaterialResponse$ = [
      3,
      n032,
      _DIKMRe,
      0,
      [_KI, _KMI],
      [0, 0]
    ];
    exports2.DeriveSharedSecretRequest$ = [
      3,
      n032,
      _DSSR,
      0,
      [_KI, _KAA, _PK, _GT, _DR, _R],
      [0, 0, 21, 64 | 0, 2, () => exports2.RecipientInfo$],
      3
    ];
    exports2.DeriveSharedSecretResponse$ = [
      3,
      n032,
      _DSSRe,
      0,
      [_KI, _SS, _CFR, _KAA, _KO],
      [0, [() => PlaintextType, 0], 21, 0, 0]
    ];
    exports2.DescribeCustomKeyStoresRequest$ = [
      3,
      n032,
      _DCKSRes,
      0,
      [_CKSI, _CKSN, _L2, _M],
      [0, 0, 1, 0]
    ];
    exports2.DescribeCustomKeyStoresResponse$ = [
      3,
      n032,
      _DCKSResc,
      0,
      [_CKS, _NM, _Tr],
      [[() => CustomKeyStoresList, 0], 0, 2]
    ];
    exports2.DescribeKeyRequest$ = [
      3,
      n032,
      _DKR,
      0,
      [_KI, _GT],
      [0, 64 | 0],
      1
    ];
    exports2.DescribeKeyResponse$ = [
      3,
      n032,
      _DKRe,
      0,
      [_KM],
      [() => exports2.KeyMetadata$]
    ];
    exports2.DisableKeyRequest$ = [
      3,
      n032,
      _DKRi,
      0,
      [_KI],
      [0],
      1
    ];
    exports2.DisableKeyRotationRequest$ = [
      3,
      n032,
      _DKRR,
      0,
      [_KI],
      [0],
      1
    ];
    exports2.DisconnectCustomKeyStoreRequest$ = [
      3,
      n032,
      _DCKSRi,
      0,
      [_CKSI],
      [0],
      1
    ];
    exports2.DisconnectCustomKeyStoreResponse$ = [
      3,
      n032,
      _DCKSRis,
      0,
      [],
      []
    ];
    exports2.EnableKeyRequest$ = [
      3,
      n032,
      _EKR,
      0,
      [_KI],
      [0],
      1
    ];
    exports2.EnableKeyRotationRequest$ = [
      3,
      n032,
      _EKRR,
      0,
      [_KI, _RPID],
      [0, 1],
      1
    ];
    exports2.EncryptRequest$ = [
      3,
      n032,
      _ER,
      0,
      [_KI, _Pl, _EC, _GT, _EA, _DR],
      [0, [() => PlaintextType, 0], 128 | 0, 64 | 0, 0, 2],
      2
    ];
    exports2.EncryptResponse$ = [
      3,
      n032,
      _ERn,
      0,
      [_CB, _KI, _EA],
      [21, 0, 0]
    ];
    exports2.GenerateDataKeyPairRequest$ = [
      3,
      n032,
      _GDKPR,
      0,
      [_KI, _KPS, _EC, _GT, _R, _DR],
      [0, 0, 128 | 0, 64 | 0, () => exports2.RecipientInfo$, 2],
      2
    ];
    exports2.GenerateDataKeyPairResponse$ = [
      3,
      n032,
      _GDKPRe,
      0,
      [_PKCB, _PKP, _PK, _KI, _KPS, _CFR, _KMI],
      [21, [() => PlaintextType, 0], 21, 0, 0, 21, 0]
    ];
    exports2.GenerateDataKeyPairWithoutPlaintextRequest$ = [
      3,
      n032,
      _GDKPWPR,
      0,
      [_KI, _KPS, _EC, _GT, _DR],
      [0, 0, 128 | 0, 64 | 0, 2],
      2
    ];
    exports2.GenerateDataKeyPairWithoutPlaintextResponse$ = [
      3,
      n032,
      _GDKPWPRe,
      0,
      [_PKCB, _PK, _KI, _KPS, _KMI],
      [21, 21, 0, 0, 0]
    ];
    exports2.GenerateDataKeyRequest$ = [
      3,
      n032,
      _GDKR,
      0,
      [_KI, _EC, _NOB, _KS, _GT, _R, _DR],
      [0, 128 | 0, 1, 0, 64 | 0, () => exports2.RecipientInfo$, 2],
      1
    ];
    exports2.GenerateDataKeyResponse$ = [
      3,
      n032,
      _GDKRe,
      0,
      [_CB, _Pl, _KI, _CFR, _KMI],
      [21, [() => PlaintextType, 0], 0, 21, 0]
    ];
    exports2.GenerateDataKeyWithoutPlaintextRequest$ = [
      3,
      n032,
      _GDKWPR,
      0,
      [_KI, _EC, _KS, _NOB, _GT, _DR],
      [0, 128 | 0, 0, 1, 64 | 0, 2],
      1
    ];
    exports2.GenerateDataKeyWithoutPlaintextResponse$ = [
      3,
      n032,
      _GDKWPRe,
      0,
      [_CB, _KI, _KMI],
      [21, 0, 0]
    ];
    exports2.GenerateMacRequest$ = [
      3,
      n032,
      _GMR,
      0,
      [_Me, _KI, _MA, _GT, _DR],
      [[() => PlaintextType, 0], 0, 0, 64 | 0, 2],
      3
    ];
    exports2.GenerateMacResponse$ = [
      3,
      n032,
      _GMRe,
      0,
      [_Ma, _MA, _KI],
      [21, 0, 0]
    ];
    exports2.GenerateRandomRequest$ = [
      3,
      n032,
      _GRR,
      0,
      [_NOB, _CKSI, _R],
      [1, 0, () => exports2.RecipientInfo$]
    ];
    exports2.GenerateRandomResponse$ = [
      3,
      n032,
      _GRRe,
      0,
      [_Pl, _CFR],
      [[() => PlaintextType, 0], 21]
    ];
    exports2.GetKeyLastUsageRequest$ = [
      3,
      n032,
      _GKLUR,
      0,
      [_KI],
      [0],
      1
    ];
    exports2.GetKeyLastUsageResponse$ = [
      3,
      n032,
      _GKLURe,
      0,
      [_KI, _KLU, _TSD, _KCD],
      [0, () => exports2.KeyLastUsageData$, 4, 4]
    ];
    exports2.GetKeyPolicyRequest$ = [
      3,
      n032,
      _GKPR,
      0,
      [_KI, _PN],
      [0, 0],
      1
    ];
    exports2.GetKeyPolicyResponse$ = [
      3,
      n032,
      _GKPRe,
      0,
      [_P10, _PN],
      [0, 0]
    ];
    exports2.GetKeyRotationStatusRequest$ = [
      3,
      n032,
      _GKRSR,
      0,
      [_KI],
      [0],
      1
    ];
    exports2.GetKeyRotationStatusResponse$ = [
      3,
      n032,
      _GKRSRe,
      0,
      [_KRE, _KI, _RPID, _NRD, _ODRSD],
      [2, 0, 1, 4, 4]
    ];
    exports2.GetParametersForImportRequest$ = [
      3,
      n032,
      _GPFIR,
      0,
      [_KI, _WA, _WKS],
      [0, 0, 0],
      3
    ];
    exports2.GetParametersForImportResponse$ = [
      3,
      n032,
      _GPFIRe,
      0,
      [_KI, _IT4, _PK, _PVT],
      [0, 21, [() => PlaintextType, 0], 4]
    ];
    exports2.GetPublicKeyRequest$ = [
      3,
      n032,
      _GPKR,
      0,
      [_KI, _GT],
      [0, 64 | 0],
      1
    ];
    exports2.GetPublicKeyResponse$ = [
      3,
      n032,
      _GPKRe,
      0,
      [_KI, _PK, _CMKS, _KS, _KU, _EAn, _SA, _KAAe],
      [0, 21, 0, 0, 0, 64 | 0, 64 | 0, 64 | 0]
    ];
    exports2.GrantConstraints$ = [
      3,
      n032,
      _GC,
      0,
      [_ECS, _ECE],
      [128 | 0, 128 | 0]
    ];
    exports2.GrantListEntry$ = [
      3,
      n032,
      _GLE,
      0,
      [_KI, _GI2, _N, _CD, _GP, _RP, _IA, _O, _C11],
      [0, 0, 0, 4, 0, 0, 0, 64 | 0, () => exports2.GrantConstraints$]
    ];
    exports2.ImportKeyMaterialRequest$ = [
      3,
      n032,
      _IKMR,
      0,
      [_KI, _IT4, _EKM, _VT, _EM, _ITm, _KMD, _KMI],
      [0, 21, 21, 4, 0, 0, 0, 0],
      3
    ];
    exports2.ImportKeyMaterialResponse$ = [
      3,
      n032,
      _IKMRm,
      0,
      [_KI, _KMI],
      [0, 0]
    ];
    exports2.KeyLastUsageData$ = [
      3,
      n032,
      _KLUD,
      0,
      [_Op, _Ti, _CTEI, _KRI],
      [0, 4, 0, 0]
    ];
    exports2.KeyListEntry$ = [
      3,
      n032,
      _KLE,
      0,
      [_KI, _KA],
      [0, 0]
    ];
    exports2.KeyMetadata$ = [
      3,
      n032,
      _KM,
      0,
      [_KI, _AWSAI, _A10, _CD, _E11, _D, _KU, _KSe, _DD, _VT, _Or, _CKSI, _CHCI, _EM, _KMe, _CMKS, _KS, _EAn, _SA, _KAAe, _MR, _MRC, _PDWID, _MAa, _XKC, _CKMI],
      [0, 0, 0, 4, 2, 0, 0, 0, 4, 4, 0, 0, 0, 0, 0, 0, 0, 64 | 0, 64 | 0, 64 | 0, 2, () => exports2.MultiRegionConfiguration$, 1, 64 | 0, () => exports2.XksKeyConfigurationType$, 0],
      1
    ];
    exports2.ListAliasesRequest$ = [
      3,
      n032,
      _LAR,
      0,
      [_KI, _L2, _M],
      [0, 1, 0]
    ];
    exports2.ListAliasesResponse$ = [
      3,
      n032,
      _LARi,
      0,
      [_Al, _NM, _Tr],
      [() => AliasList, 0, 2]
    ];
    exports2.ListGrantsRequest$ = [
      3,
      n032,
      _LGR,
      0,
      [_KI, _L2, _M, _GI2, _GP],
      [0, 1, 0, 0, 0],
      1
    ];
    exports2.ListGrantsResponse$ = [
      3,
      n032,
      _LGRi,
      0,
      [_G, _NM, _Tr],
      [() => GrantList, 0, 2]
    ];
    exports2.ListKeyPoliciesRequest$ = [
      3,
      n032,
      _LKPR,
      0,
      [_KI, _L2, _M],
      [0, 1, 0],
      1
    ];
    exports2.ListKeyPoliciesResponse$ = [
      3,
      n032,
      _LKPRi,
      0,
      [_PNo, _NM, _Tr],
      [64 | 0, 0, 2]
    ];
    exports2.ListKeyRotationsRequest$ = [
      3,
      n032,
      _LKRR,
      0,
      [_KI, _IKM, _L2, _M],
      [0, 0, 1, 0],
      1
    ];
    exports2.ListKeyRotationsResponse$ = [
      3,
      n032,
      _LKRRi,
      0,
      [_Ro, _NM, _Tr],
      [() => RotationsList, 0, 2]
    ];
    exports2.ListKeysRequest$ = [
      3,
      n032,
      _LKR,
      0,
      [_L2, _M],
      [1, 0]
    ];
    exports2.ListKeysResponse$ = [
      3,
      n032,
      _LKRi,
      0,
      [_K10, _NM, _Tr],
      [() => KeyList, 0, 2]
    ];
    exports2.ListResourceTagsRequest$ = [
      3,
      n032,
      _LRTR,
      0,
      [_KI, _L2, _M],
      [0, 1, 0],
      1
    ];
    exports2.ListResourceTagsResponse$ = [
      3,
      n032,
      _LRTRi,
      0,
      [_T10, _NM, _Tr],
      [() => TagList, 0, 2]
    ];
    exports2.ListRetirableGrantsRequest$ = [
      3,
      n032,
      _LRGR,
      0,
      [_RP, _L2, _M],
      [0, 1, 0],
      1
    ];
    exports2.MultiRegionConfiguration$ = [
      3,
      n032,
      _MRC,
      0,
      [_MRKT, _PKr, _RK],
      [0, () => exports2.MultiRegionKey$, () => MultiRegionKeyList]
    ];
    exports2.MultiRegionKey$ = [
      3,
      n032,
      _MRK,
      0,
      [_A10, _Re],
      [0, 0]
    ];
    exports2.PutKeyPolicyRequest$ = [
      3,
      n032,
      _PKPR,
      0,
      [_KI, _P10, _PN, _BPLSC],
      [0, 0, 0, 2],
      2
    ];
    exports2.RecipientInfo$ = [
      3,
      n032,
      _RI,
      0,
      [_KEA, _AD],
      [0, 21]
    ];
    exports2.ReEncryptRequest$ = [
      3,
      n032,
      _RER,
      0,
      [_DKI, _CB, _SEC, _SKI, _DEC, _SEA, _DEA, _GT, _DR, _DRM],
      [0, 21, 128 | 0, 0, 128 | 0, 0, 0, 64 | 0, 2, 64 | 0],
      1
    ];
    exports2.ReEncryptResponse$ = [
      3,
      n032,
      _RERe,
      0,
      [_CB, _SKI, _KI, _SEA, _DEA, _SKMI, _DKMI],
      [21, 0, 0, 0, 0, 0, 0]
    ];
    exports2.ReplicateKeyRequest$ = [
      3,
      n032,
      _RKR,
      0,
      [_KI, _RR, _P10, _BPLSC, _D, _T10],
      [0, 0, 0, 2, 0, () => TagList],
      2
    ];
    exports2.ReplicateKeyResponse$ = [
      3,
      n032,
      _RKRe,
      0,
      [_RKM, _RPe, _RT13],
      [() => exports2.KeyMetadata$, 0, () => TagList]
    ];
    exports2.RetireGrantRequest$ = [
      3,
      n032,
      _RGR,
      0,
      [_GTr, _KI, _GI2, _DR],
      [0, 0, 0, 2]
    ];
    exports2.RevokeGrantRequest$ = [
      3,
      n032,
      _RGRe,
      0,
      [_KI, _GI2, _DR],
      [0, 0, 2],
      2
    ];
    exports2.RotateKeyOnDemandRequest$ = [
      3,
      n032,
      _RKODR,
      0,
      [_KI],
      [0],
      1
    ];
    exports2.RotateKeyOnDemandResponse$ = [
      3,
      n032,
      _RKODRo,
      0,
      [_KI],
      [0]
    ];
    exports2.RotationsListEntry$ = [
      3,
      n032,
      _RLE,
      0,
      [_KI, _KMI, _KMD, _IS, _KMS, _EM, _VT, _RD, _RTo],
      [0, 0, 0, 0, 0, 0, 4, 4, 0]
    ];
    exports2.ScheduleKeyDeletionRequest$ = [
      3,
      n032,
      _SKDR,
      0,
      [_KI, _PWID],
      [0, 1],
      1
    ];
    exports2.ScheduleKeyDeletionResponse$ = [
      3,
      n032,
      _SKDRc,
      0,
      [_KI, _DD, _KSe, _PWID],
      [0, 4, 0, 1]
    ];
    exports2.SignRequest$ = [
      3,
      n032,
      _SR,
      0,
      [_KI, _Me, _SAi, _MT, _GT, _DR],
      [0, [() => PlaintextType, 0], 0, 0, 64 | 0, 2],
      3
    ];
    exports2.SignResponse$ = [
      3,
      n032,
      _SRi,
      0,
      [_KI, _S, _SAi],
      [0, 21, 0]
    ];
    exports2.Tag$ = [
      3,
      n032,
      _Ta10,
      0,
      [_TK, _TV],
      [0, 0],
      2
    ];
    exports2.TagResourceRequest$ = [
      3,
      n032,
      _TRR,
      0,
      [_KI, _T10],
      [0, () => TagList],
      2
    ];
    exports2.UntagResourceRequest$ = [
      3,
      n032,
      _URR,
      0,
      [_KI, _TKa],
      [0, 64 | 0],
      2
    ];
    exports2.UpdateAliasRequest$ = [
      3,
      n032,
      _UAR,
      0,
      [_AN, _TKI],
      [0, 0],
      2
    ];
    exports2.UpdateCustomKeyStoreRequest$ = [
      3,
      n032,
      _UCKSR,
      0,
      [_CKSI, _NCKSN, _KSP, _CHCI, _XPUE, _XPUP, _XPVESN, _XPVESO, _XPAC, _XPC],
      [0, 0, [() => KeyStorePasswordType, 0], 0, 0, 0, 0, 0, [() => exports2.XksProxyAuthenticationCredentialType$, 0], 0],
      1
    ];
    exports2.UpdateCustomKeyStoreResponse$ = [
      3,
      n032,
      _UCKSRp,
      0,
      [],
      []
    ];
    exports2.UpdateKeyDescriptionRequest$ = [
      3,
      n032,
      _UKDR,
      0,
      [_KI, _D],
      [0, 0],
      2
    ];
    exports2.UpdatePrimaryRegionRequest$ = [
      3,
      n032,
      _UPRR,
      0,
      [_KI, _PR],
      [0, 0],
      2
    ];
    exports2.VerifyMacRequest$ = [
      3,
      n032,
      _VMR,
      0,
      [_Me, _KI, _MA, _Ma, _GT, _DR],
      [[() => PlaintextType, 0], 0, 0, 21, 64 | 0, 2],
      4
    ];
    exports2.VerifyMacResponse$ = [
      3,
      n032,
      _VMRe,
      0,
      [_KI, _MV, _MA],
      [0, 2, 0]
    ];
    exports2.VerifyRequest$ = [
      3,
      n032,
      _VR,
      0,
      [_KI, _Me, _S, _SAi, _MT, _GT, _DR],
      [0, [() => PlaintextType, 0], 21, 0, 0, 64 | 0, 2],
      4
    ];
    exports2.VerifyResponse$ = [
      3,
      n032,
      _VRe,
      0,
      [_KI, _SV, _SAi],
      [0, 2, 0]
    ];
    exports2.XksKeyConfigurationType$ = [
      3,
      n032,
      _XKCT,
      0,
      [_I],
      [0]
    ];
    exports2.XksProxyAuthenticationCredentialType$ = [
      3,
      n032,
      _XPACT,
      0,
      [_AKI11, _RSAK],
      [[() => XksProxyAuthenticationAccessKeyIdType, 0], [() => XksProxyAuthenticationRawSecretAccessKeyType, 0]],
      2
    ];
    exports2.XksProxyConfigurationType$ = [
      3,
      n032,
      _XPCT,
      0,
      [_Co, _AKI11, _UE10, _UP, _VESN, _VESO],
      [0, [() => XksProxyAuthenticationAccessKeyIdType, 0], 0, 0, 0, 0]
    ];
    var __Unit = "unit";
    var AliasList = [
      1,
      n032,
      _AL,
      0,
      () => exports2.AliasListEntry$
    ];
    var CustomKeyStoresList = [
      1,
      n032,
      _CKSL,
      0,
      [
        () => exports2.CustomKeyStoresListEntry$,
        0
      ]
    ];
    var DryRunModifierList = 64 | 0;
    var EncryptionAlgorithmSpecList = 64 | 0;
    var GrantList = [
      1,
      n032,
      _GL,
      0,
      () => exports2.GrantListEntry$
    ];
    var GrantOperationList = 64 | 0;
    var GrantTokenList = 64 | 0;
    var KeyAgreementAlgorithmSpecList = 64 | 0;
    var KeyList = [
      1,
      n032,
      _KL,
      0,
      () => exports2.KeyListEntry$
    ];
    var MacAlgorithmSpecList = 64 | 0;
    var MultiRegionKeyList = [
      1,
      n032,
      _MRKL,
      0,
      () => exports2.MultiRegionKey$
    ];
    var PolicyNameList = 64 | 0;
    var RotationsList = [
      1,
      n032,
      _RL,
      0,
      () => exports2.RotationsListEntry$
    ];
    var SigningAlgorithmSpecList = 64 | 0;
    var TagKeyList = 64 | 0;
    var TagList = [
      1,
      n032,
      _TL,
      0,
      () => exports2.Tag$
    ];
    var EncryptionContextType = 128 | 0;
    exports2.CancelKeyDeletion$ = [
      9,
      n032,
      _CKD,
      0,
      () => exports2.CancelKeyDeletionRequest$,
      () => exports2.CancelKeyDeletionResponse$
    ];
    exports2.ConnectCustomKeyStore$ = [
      9,
      n032,
      _CCKS,
      0,
      () => exports2.ConnectCustomKeyStoreRequest$,
      () => exports2.ConnectCustomKeyStoreResponse$
    ];
    exports2.CreateAlias$ = [
      9,
      n032,
      _CA10,
      0,
      () => exports2.CreateAliasRequest$,
      () => __Unit
    ];
    exports2.CreateCustomKeyStore$ = [
      9,
      n032,
      _CCKSr,
      0,
      () => exports2.CreateCustomKeyStoreRequest$,
      () => exports2.CreateCustomKeyStoreResponse$
    ];
    exports2.CreateGrant$ = [
      9,
      n032,
      _CG,
      0,
      () => exports2.CreateGrantRequest$,
      () => exports2.CreateGrantResponse$
    ];
    exports2.CreateKey$ = [
      9,
      n032,
      _CK,
      0,
      () => exports2.CreateKeyRequest$,
      () => exports2.CreateKeyResponse$
    ];
    exports2.Decrypt$ = [
      9,
      n032,
      _De,
      0,
      () => exports2.DecryptRequest$,
      () => exports2.DecryptResponse$
    ];
    exports2.DeleteAlias$ = [
      9,
      n032,
      _DA,
      0,
      () => exports2.DeleteAliasRequest$,
      () => __Unit
    ];
    exports2.DeleteCustomKeyStore$ = [
      9,
      n032,
      _DCKS,
      0,
      () => exports2.DeleteCustomKeyStoreRequest$,
      () => exports2.DeleteCustomKeyStoreResponse$
    ];
    exports2.DeleteImportedKeyMaterial$ = [
      9,
      n032,
      _DIKM,
      0,
      () => exports2.DeleteImportedKeyMaterialRequest$,
      () => exports2.DeleteImportedKeyMaterialResponse$
    ];
    exports2.DeriveSharedSecret$ = [
      9,
      n032,
      _DSS,
      0,
      () => exports2.DeriveSharedSecretRequest$,
      () => exports2.DeriveSharedSecretResponse$
    ];
    exports2.DescribeCustomKeyStores$ = [
      9,
      n032,
      _DCKSe,
      0,
      () => exports2.DescribeCustomKeyStoresRequest$,
      () => exports2.DescribeCustomKeyStoresResponse$
    ];
    exports2.DescribeKey$ = [
      9,
      n032,
      _DK,
      0,
      () => exports2.DescribeKeyRequest$,
      () => exports2.DescribeKeyResponse$
    ];
    exports2.DisableKey$ = [
      9,
      n032,
      _DKi,
      0,
      () => exports2.DisableKeyRequest$,
      () => __Unit
    ];
    exports2.DisableKeyRotation$ = [
      9,
      n032,
      _DKRis,
      0,
      () => exports2.DisableKeyRotationRequest$,
      () => __Unit
    ];
    exports2.DisconnectCustomKeyStore$ = [
      9,
      n032,
      _DCKSi,
      0,
      () => exports2.DisconnectCustomKeyStoreRequest$,
      () => exports2.DisconnectCustomKeyStoreResponse$
    ];
    exports2.EnableKey$ = [
      9,
      n032,
      _EK,
      0,
      () => exports2.EnableKeyRequest$,
      () => __Unit
    ];
    exports2.EnableKeyRotation$ = [
      9,
      n032,
      _EKRn,
      0,
      () => exports2.EnableKeyRotationRequest$,
      () => __Unit
    ];
    exports2.Encrypt$ = [
      9,
      n032,
      _En,
      0,
      () => exports2.EncryptRequest$,
      () => exports2.EncryptResponse$
    ];
    exports2.GenerateDataKey$ = [
      9,
      n032,
      _GDK,
      0,
      () => exports2.GenerateDataKeyRequest$,
      () => exports2.GenerateDataKeyResponse$
    ];
    exports2.GenerateDataKeyPair$ = [
      9,
      n032,
      _GDKP,
      0,
      () => exports2.GenerateDataKeyPairRequest$,
      () => exports2.GenerateDataKeyPairResponse$
    ];
    exports2.GenerateDataKeyPairWithoutPlaintext$ = [
      9,
      n032,
      _GDKPWP,
      0,
      () => exports2.GenerateDataKeyPairWithoutPlaintextRequest$,
      () => exports2.GenerateDataKeyPairWithoutPlaintextResponse$
    ];
    exports2.GenerateDataKeyWithoutPlaintext$ = [
      9,
      n032,
      _GDKWP,
      0,
      () => exports2.GenerateDataKeyWithoutPlaintextRequest$,
      () => exports2.GenerateDataKeyWithoutPlaintextResponse$
    ];
    exports2.GenerateMac$ = [
      9,
      n032,
      _GM,
      0,
      () => exports2.GenerateMacRequest$,
      () => exports2.GenerateMacResponse$
    ];
    exports2.GenerateRandom$ = [
      9,
      n032,
      _GR,
      0,
      () => exports2.GenerateRandomRequest$,
      () => exports2.GenerateRandomResponse$
    ];
    exports2.GetKeyLastUsage$ = [
      9,
      n032,
      _GKLU,
      0,
      () => exports2.GetKeyLastUsageRequest$,
      () => exports2.GetKeyLastUsageResponse$
    ];
    exports2.GetKeyPolicy$ = [
      9,
      n032,
      _GKP,
      0,
      () => exports2.GetKeyPolicyRequest$,
      () => exports2.GetKeyPolicyResponse$
    ];
    exports2.GetKeyRotationStatus$ = [
      9,
      n032,
      _GKRS,
      0,
      () => exports2.GetKeyRotationStatusRequest$,
      () => exports2.GetKeyRotationStatusResponse$
    ];
    exports2.GetParametersForImport$ = [
      9,
      n032,
      _GPFI,
      0,
      () => exports2.GetParametersForImportRequest$,
      () => exports2.GetParametersForImportResponse$
    ];
    exports2.GetPublicKey$ = [
      9,
      n032,
      _GPK,
      0,
      () => exports2.GetPublicKeyRequest$,
      () => exports2.GetPublicKeyResponse$
    ];
    exports2.ImportKeyMaterial$ = [
      9,
      n032,
      _IKMm,
      0,
      () => exports2.ImportKeyMaterialRequest$,
      () => exports2.ImportKeyMaterialResponse$
    ];
    exports2.ListAliases$ = [
      9,
      n032,
      _LA,
      0,
      () => exports2.ListAliasesRequest$,
      () => exports2.ListAliasesResponse$
    ];
    exports2.ListGrants$ = [
      9,
      n032,
      _LG,
      0,
      () => exports2.ListGrantsRequest$,
      () => exports2.ListGrantsResponse$
    ];
    exports2.ListKeyPolicies$ = [
      9,
      n032,
      _LKP,
      0,
      () => exports2.ListKeyPoliciesRequest$,
      () => exports2.ListKeyPoliciesResponse$
    ];
    exports2.ListKeyRotations$ = [
      9,
      n032,
      _LKRis,
      0,
      () => exports2.ListKeyRotationsRequest$,
      () => exports2.ListKeyRotationsResponse$
    ];
    exports2.ListKeys$ = [
      9,
      n032,
      _LK,
      0,
      () => exports2.ListKeysRequest$,
      () => exports2.ListKeysResponse$
    ];
    exports2.ListResourceTags$ = [
      9,
      n032,
      _LRT,
      0,
      () => exports2.ListResourceTagsRequest$,
      () => exports2.ListResourceTagsResponse$
    ];
    exports2.ListRetirableGrants$ = [
      9,
      n032,
      _LRG,
      0,
      () => exports2.ListRetirableGrantsRequest$,
      () => exports2.ListGrantsResponse$
    ];
    exports2.PutKeyPolicy$ = [
      9,
      n032,
      _PKPu,
      0,
      () => exports2.PutKeyPolicyRequest$,
      () => __Unit
    ];
    exports2.ReEncrypt$ = [
      9,
      n032,
      _RE,
      0,
      () => exports2.ReEncryptRequest$,
      () => exports2.ReEncryptResponse$
    ];
    exports2.ReplicateKey$ = [
      9,
      n032,
      _RKe,
      0,
      () => exports2.ReplicateKeyRequest$,
      () => exports2.ReplicateKeyResponse$
    ];
    exports2.RetireGrant$ = [
      9,
      n032,
      _RG,
      0,
      () => exports2.RetireGrantRequest$,
      () => __Unit
    ];
    exports2.RevokeGrant$ = [
      9,
      n032,
      _RGe,
      0,
      () => exports2.RevokeGrantRequest$,
      () => __Unit
    ];
    exports2.RotateKeyOnDemand$ = [
      9,
      n032,
      _RKOD,
      0,
      () => exports2.RotateKeyOnDemandRequest$,
      () => exports2.RotateKeyOnDemandResponse$
    ];
    exports2.ScheduleKeyDeletion$ = [
      9,
      n032,
      _SKD,
      0,
      () => exports2.ScheduleKeyDeletionRequest$,
      () => exports2.ScheduleKeyDeletionResponse$
    ];
    exports2.Sign$ = [
      9,
      n032,
      _Si,
      0,
      () => exports2.SignRequest$,
      () => exports2.SignResponse$
    ];
    exports2.TagResource$ = [
      9,
      n032,
      _TR,
      0,
      () => exports2.TagResourceRequest$,
      () => __Unit
    ];
    exports2.UntagResource$ = [
      9,
      n032,
      _UR,
      0,
      () => exports2.UntagResourceRequest$,
      () => __Unit
    ];
    exports2.UpdateAlias$ = [
      9,
      n032,
      _UA,
      0,
      () => exports2.UpdateAliasRequest$,
      () => __Unit
    ];
    exports2.UpdateCustomKeyStore$ = [
      9,
      n032,
      _UCKS,
      0,
      () => exports2.UpdateCustomKeyStoreRequest$,
      () => exports2.UpdateCustomKeyStoreResponse$
    ];
    exports2.UpdateKeyDescription$ = [
      9,
      n032,
      _UKD,
      0,
      () => exports2.UpdateKeyDescriptionRequest$,
      () => __Unit
    ];
    exports2.UpdatePrimaryRegion$ = [
      9,
      n032,
      _UPR,
      0,
      () => exports2.UpdatePrimaryRegionRequest$,
      () => __Unit
    ];
    exports2.Verify$ = [
      9,
      n032,
      _V10,
      0,
      () => exports2.VerifyRequest$,
      () => exports2.VerifyResponse$
    ];
    exports2.VerifyMac$ = [
      9,
      n032,
      _VM,
      0,
      () => exports2.VerifyMacRequest$,
      () => exports2.VerifyMacResponse$
    ];
  }
});

// ../../node_modules/@aws-sdk/client-kms/dist-cjs/runtimeConfig.shared.js
var require_runtimeConfig_shared16 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/dist-cjs/runtimeConfig.shared.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes10(), __toCommonJS(httpAuthSchemes_exports8));
    var protocols_1 = (init_protocols16(), __toCommonJS(protocols_exports13));
    var smithy_client_1 = require_dist_cjs34();
    var url_parser_1 = require_dist_cjs18();
    var util_base64_1 = require_dist_cjs10();
    var util_utf8_1 = require_dist_cjs9();
    var httpAuthSchemeProvider_1 = require_httpAuthSchemeProvider15();
    var endpointResolver_1 = require_endpointResolver15();
    var schemas_0_1 = require_schemas_015();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2014-11-01",
        base64Decoder: config2?.base64Decoder ?? util_base64_1.fromBase64,
        base64Encoder: config2?.base64Encoder ?? util_base64_1.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? endpointResolver_1.defaultEndpointResolver,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? httpAuthSchemeProvider_1.defaultKMSHttpAuthSchemeProvider,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new httpAuthSchemes_1.AwsSdkSigV4Signer()
          }
        ],
        logger: config2?.logger ?? new smithy_client_1.NoOpLogger(),
        protocol: config2?.protocol ?? protocols_1.AwsJson1_1Protocol,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.kms",
          errorTypeRegistries: schemas_0_1.errorTypeRegistries,
          xmlNamespace: "https://trent.amazonaws.com/doc/2014-11-01/",
          version: "2014-11-01",
          serviceTarget: "TrentService"
        },
        serviceId: config2?.serviceId ?? "KMS",
        urlParser: config2?.urlParser ?? url_parser_1.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? util_utf8_1.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? util_utf8_1.toUtf8
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-kms/dist-cjs/runtimeConfig.js
var require_runtimeConfig16 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/dist-cjs/runtimeConfig.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var package_json_1 = tslib_1.__importDefault(require_package15());
    var client_1 = (init_client17(), __toCommonJS(client_exports12));
    var httpAuthSchemes_1 = (init_httpAuthSchemes10(), __toCommonJS(httpAuthSchemes_exports8));
    var credential_provider_node_1 = require_dist_cjs178();
    var util_user_agent_node_1 = require_dist_cjs172();
    var config_resolver_1 = require_dist_cjs25();
    var hash_node_1 = require_dist_cjs44();
    var middleware_retry_1 = require_dist_cjs168();
    var node_config_provider_1 = require_dist_cjs29();
    var node_http_handler_1 = require_dist_cjs13();
    var smithy_client_1 = require_dist_cjs34();
    var util_body_length_node_1 = require_dist_cjs45();
    var util_defaults_mode_node_1 = require_dist_cjs46();
    var util_retry_1 = require_dist_cjs22();
    var runtimeConfig_shared_1 = require_runtimeConfig_shared16();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      (0, smithy_client_1.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, util_defaults_mode_node_1.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(smithy_client_1.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = (0, runtimeConfig_shared_1.getRuntimeConfig)(config2);
      (0, client_1.emitWarningIfUnsupportedVersion)(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, node_config_provider_1.loadConfig)(httpAuthSchemes_1.NODE_AUTH_SCHEME_PREFERENCE_OPTIONS, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? util_body_length_node_1.calculateBodyLength,
        credentialDefaultProvider: config2?.credentialDefaultProvider ?? credential_provider_node_1.defaultProvider,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, util_user_agent_node_1.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_json_1.default.version }),
        maxAttempts: config2?.maxAttempts ?? (0, node_config_provider_1.loadConfig)(middleware_retry_1.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_REGION_CONFIG_OPTIONS, { ...config_resolver_1.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: node_http_handler_1.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, node_config_provider_1.loadConfig)({
          ...middleware_retry_1.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || util_retry_1.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? hash_node_1.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? node_http_handler_1.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, node_config_provider_1.loadConfig)(util_user_agent_node_1.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-kms/dist-cjs/index.js
var require_dist_cjs179 = __commonJS({
  "../../node_modules/@aws-sdk/client-kms/dist-cjs/index.js"(exports2) {
    "use strict";
    var middlewareHostHeader = require_dist_cjs3();
    var middlewareLogger = require_dist_cjs4();
    var middlewareRecursionDetection = require_dist_cjs5();
    var middlewareUserAgent = require_dist_cjs167();
    var configResolver = require_dist_cjs25();
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var schema = (init_schema4(), __toCommonJS(schema_exports));
    var middlewareContentLength = require_dist_cjs26();
    var middlewareEndpoint = require_dist_cjs31();
    var middlewareRetry = require_dist_cjs168();
    var smithyClient = require_dist_cjs34();
    var httpAuthSchemeProvider = require_httpAuthSchemeProvider15();
    var runtimeConfig = require_runtimeConfig16();
    var regionConfigResolver = require_dist_cjs48();
    var protocolHttp = require_dist_cjs2();
    var schemas_0 = require_schemas_015();
    var errors = require_errors14();
    var KMSServiceException = require_KMSServiceException();
    var resolveClientEndpointParameters32 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "kms"
      });
    }, "resolveClientEndpointParameters");
    var commonParams32 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
    var getHttpAuthExtensionConfiguration32 = /* @__PURE__ */ __name((runtimeConfig2) => {
      const _httpAuthSchemes = runtimeConfig2.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig2.httpAuthSchemeProvider;
      let _credentials = runtimeConfig2.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider2) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider2;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    var resolveHttpAuthRuntimeConfig32 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
    var resolveRuntimeExtensions32 = /* @__PURE__ */ __name((runtimeConfig2, extensions) => {
      const extensionConfiguration = Object.assign(regionConfigResolver.getAwsRegionExtensionConfiguration(runtimeConfig2), smithyClient.getDefaultExtensionConfiguration(runtimeConfig2), protocolHttp.getHttpHandlerExtensionConfiguration(runtimeConfig2), getHttpAuthExtensionConfiguration32(runtimeConfig2));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig2, regionConfigResolver.resolveAwsRegionExtensionConfiguration(extensionConfiguration), smithyClient.resolveDefaultRuntimeConfig(extensionConfiguration), protocolHttp.resolveHttpHandlerRuntimeConfig(extensionConfiguration), resolveHttpAuthRuntimeConfig32(extensionConfiguration));
    }, "resolveRuntimeExtensions");
    var KMSClient2 = class extends smithyClient.Client {
      static {
        __name(this, "KMSClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = runtimeConfig.getRuntimeConfig(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters32(_config_0);
        const _config_2 = middlewareUserAgent.resolveUserAgentConfig(_config_1);
        const _config_3 = middlewareRetry.resolveRetryConfig(_config_2);
        const _config_4 = configResolver.resolveRegionConfig(_config_3);
        const _config_5 = middlewareHostHeader.resolveHostHeaderConfig(_config_4);
        const _config_6 = middlewareEndpoint.resolveEndpointConfig(_config_5);
        const _config_7 = httpAuthSchemeProvider.resolveHttpAuthSchemeConfig(_config_6);
        const _config_8 = resolveRuntimeExtensions32(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(schema.getSchemaSerdePlugin(this.config));
        this.middlewareStack.use(middlewareUserAgent.getUserAgentPlugin(this.config));
        this.middlewareStack.use(middlewareRetry.getRetryPlugin(this.config));
        this.middlewareStack.use(middlewareContentLength.getContentLengthPlugin(this.config));
        this.middlewareStack.use(middlewareHostHeader.getHostHeaderPlugin(this.config));
        this.middlewareStack.use(middlewareLogger.getLoggerPlugin(this.config));
        this.middlewareStack.use(middlewareRecursionDetection.getRecursionDetectionPlugin(this.config));
        this.middlewareStack.use(core.getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: httpAuthSchemeProvider.defaultKMSHttpAuthSchemeParametersProvider,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new core.DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(core.getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
    var CancelKeyDeletionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "CancelKeyDeletion", {}).n("KMSClient", "CancelKeyDeletionCommand").sc(schemas_0.CancelKeyDeletion$).build() {
      static {
        __name(this, "CancelKeyDeletionCommand");
      }
    };
    var ConnectCustomKeyStoreCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "ConnectCustomKeyStore", {}).n("KMSClient", "ConnectCustomKeyStoreCommand").sc(schemas_0.ConnectCustomKeyStore$).build() {
      static {
        __name(this, "ConnectCustomKeyStoreCommand");
      }
    };
    var CreateAliasCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "CreateAlias", {}).n("KMSClient", "CreateAliasCommand").sc(schemas_0.CreateAlias$).build() {
      static {
        __name(this, "CreateAliasCommand");
      }
    };
    var CreateCustomKeyStoreCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "CreateCustomKeyStore", {}).n("KMSClient", "CreateCustomKeyStoreCommand").sc(schemas_0.CreateCustomKeyStore$).build() {
      static {
        __name(this, "CreateCustomKeyStoreCommand");
      }
    };
    var CreateGrantCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "CreateGrant", {}).n("KMSClient", "CreateGrantCommand").sc(schemas_0.CreateGrant$).build() {
      static {
        __name(this, "CreateGrantCommand");
      }
    };
    var CreateKeyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "CreateKey", {}).n("KMSClient", "CreateKeyCommand").sc(schemas_0.CreateKey$).build() {
      static {
        __name(this, "CreateKeyCommand");
      }
    };
    var DecryptCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "Decrypt", {}).n("KMSClient", "DecryptCommand").sc(schemas_0.Decrypt$).build() {
      static {
        __name(this, "DecryptCommand");
      }
    };
    var DeleteAliasCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "DeleteAlias", {}).n("KMSClient", "DeleteAliasCommand").sc(schemas_0.DeleteAlias$).build() {
      static {
        __name(this, "DeleteAliasCommand");
      }
    };
    var DeleteCustomKeyStoreCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "DeleteCustomKeyStore", {}).n("KMSClient", "DeleteCustomKeyStoreCommand").sc(schemas_0.DeleteCustomKeyStore$).build() {
      static {
        __name(this, "DeleteCustomKeyStoreCommand");
      }
    };
    var DeleteImportedKeyMaterialCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "DeleteImportedKeyMaterial", {}).n("KMSClient", "DeleteImportedKeyMaterialCommand").sc(schemas_0.DeleteImportedKeyMaterial$).build() {
      static {
        __name(this, "DeleteImportedKeyMaterialCommand");
      }
    };
    var DeriveSharedSecretCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "DeriveSharedSecret", {}).n("KMSClient", "DeriveSharedSecretCommand").sc(schemas_0.DeriveSharedSecret$).build() {
      static {
        __name(this, "DeriveSharedSecretCommand");
      }
    };
    var DescribeCustomKeyStoresCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "DescribeCustomKeyStores", {}).n("KMSClient", "DescribeCustomKeyStoresCommand").sc(schemas_0.DescribeCustomKeyStores$).build() {
      static {
        __name(this, "DescribeCustomKeyStoresCommand");
      }
    };
    var DescribeKeyCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "DescribeKey", {}).n("KMSClient", "DescribeKeyCommand").sc(schemas_0.DescribeKey$).build() {
      static {
        __name(this, "DescribeKeyCommand");
      }
    };
    var DisableKeyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "DisableKey", {}).n("KMSClient", "DisableKeyCommand").sc(schemas_0.DisableKey$).build() {
      static {
        __name(this, "DisableKeyCommand");
      }
    };
    var DisableKeyRotationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "DisableKeyRotation", {}).n("KMSClient", "DisableKeyRotationCommand").sc(schemas_0.DisableKeyRotation$).build() {
      static {
        __name(this, "DisableKeyRotationCommand");
      }
    };
    var DisconnectCustomKeyStoreCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "DisconnectCustomKeyStore", {}).n("KMSClient", "DisconnectCustomKeyStoreCommand").sc(schemas_0.DisconnectCustomKeyStore$).build() {
      static {
        __name(this, "DisconnectCustomKeyStoreCommand");
      }
    };
    var EnableKeyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "EnableKey", {}).n("KMSClient", "EnableKeyCommand").sc(schemas_0.EnableKey$).build() {
      static {
        __name(this, "EnableKeyCommand");
      }
    };
    var EnableKeyRotationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "EnableKeyRotation", {}).n("KMSClient", "EnableKeyRotationCommand").sc(schemas_0.EnableKeyRotation$).build() {
      static {
        __name(this, "EnableKeyRotationCommand");
      }
    };
    var EncryptCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "Encrypt", {}).n("KMSClient", "EncryptCommand").sc(schemas_0.Encrypt$).build() {
      static {
        __name(this, "EncryptCommand");
      }
    };
    var GenerateDataKeyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "GenerateDataKey", {}).n("KMSClient", "GenerateDataKeyCommand").sc(schemas_0.GenerateDataKey$).build() {
      static {
        __name(this, "GenerateDataKeyCommand");
      }
    };
    var GenerateDataKeyPairCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "GenerateDataKeyPair", {}).n("KMSClient", "GenerateDataKeyPairCommand").sc(schemas_0.GenerateDataKeyPair$).build() {
      static {
        __name(this, "GenerateDataKeyPairCommand");
      }
    };
    var GenerateDataKeyPairWithoutPlaintextCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "GenerateDataKeyPairWithoutPlaintext", {}).n("KMSClient", "GenerateDataKeyPairWithoutPlaintextCommand").sc(schemas_0.GenerateDataKeyPairWithoutPlaintext$).build() {
      static {
        __name(this, "GenerateDataKeyPairWithoutPlaintextCommand");
      }
    };
    var GenerateDataKeyWithoutPlaintextCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "GenerateDataKeyWithoutPlaintext", {}).n("KMSClient", "GenerateDataKeyWithoutPlaintextCommand").sc(schemas_0.GenerateDataKeyWithoutPlaintext$).build() {
      static {
        __name(this, "GenerateDataKeyWithoutPlaintextCommand");
      }
    };
    var GenerateMacCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "GenerateMac", {}).n("KMSClient", "GenerateMacCommand").sc(schemas_0.GenerateMac$).build() {
      static {
        __name(this, "GenerateMacCommand");
      }
    };
    var GenerateRandomCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "GenerateRandom", {}).n("KMSClient", "GenerateRandomCommand").sc(schemas_0.GenerateRandom$).build() {
      static {
        __name(this, "GenerateRandomCommand");
      }
    };
    var GetKeyLastUsageCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "GetKeyLastUsage", {}).n("KMSClient", "GetKeyLastUsageCommand").sc(schemas_0.GetKeyLastUsage$).build() {
      static {
        __name(this, "GetKeyLastUsageCommand");
      }
    };
    var GetKeyPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "GetKeyPolicy", {}).n("KMSClient", "GetKeyPolicyCommand").sc(schemas_0.GetKeyPolicy$).build() {
      static {
        __name(this, "GetKeyPolicyCommand");
      }
    };
    var GetKeyRotationStatusCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "GetKeyRotationStatus", {}).n("KMSClient", "GetKeyRotationStatusCommand").sc(schemas_0.GetKeyRotationStatus$).build() {
      static {
        __name(this, "GetKeyRotationStatusCommand");
      }
    };
    var GetParametersForImportCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "GetParametersForImport", {}).n("KMSClient", "GetParametersForImportCommand").sc(schemas_0.GetParametersForImport$).build() {
      static {
        __name(this, "GetParametersForImportCommand");
      }
    };
    var GetPublicKeyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "GetPublicKey", {}).n("KMSClient", "GetPublicKeyCommand").sc(schemas_0.GetPublicKey$).build() {
      static {
        __name(this, "GetPublicKeyCommand");
      }
    };
    var ImportKeyMaterialCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "ImportKeyMaterial", {}).n("KMSClient", "ImportKeyMaterialCommand").sc(schemas_0.ImportKeyMaterial$).build() {
      static {
        __name(this, "ImportKeyMaterialCommand");
      }
    };
    var ListAliasesCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "ListAliases", {}).n("KMSClient", "ListAliasesCommand").sc(schemas_0.ListAliases$).build() {
      static {
        __name(this, "ListAliasesCommand");
      }
    };
    var ListGrantsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "ListGrants", {}).n("KMSClient", "ListGrantsCommand").sc(schemas_0.ListGrants$).build() {
      static {
        __name(this, "ListGrantsCommand");
      }
    };
    var ListKeyPoliciesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "ListKeyPolicies", {}).n("KMSClient", "ListKeyPoliciesCommand").sc(schemas_0.ListKeyPolicies$).build() {
      static {
        __name(this, "ListKeyPoliciesCommand");
      }
    };
    var ListKeyRotationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "ListKeyRotations", {}).n("KMSClient", "ListKeyRotationsCommand").sc(schemas_0.ListKeyRotations$).build() {
      static {
        __name(this, "ListKeyRotationsCommand");
      }
    };
    var ListKeysCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "ListKeys", {}).n("KMSClient", "ListKeysCommand").sc(schemas_0.ListKeys$).build() {
      static {
        __name(this, "ListKeysCommand");
      }
    };
    var ListResourceTagsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "ListResourceTags", {}).n("KMSClient", "ListResourceTagsCommand").sc(schemas_0.ListResourceTags$).build() {
      static {
        __name(this, "ListResourceTagsCommand");
      }
    };
    var ListRetirableGrantsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "ListRetirableGrants", {}).n("KMSClient", "ListRetirableGrantsCommand").sc(schemas_0.ListRetirableGrants$).build() {
      static {
        __name(this, "ListRetirableGrantsCommand");
      }
    };
    var PutKeyPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "PutKeyPolicy", {}).n("KMSClient", "PutKeyPolicyCommand").sc(schemas_0.PutKeyPolicy$).build() {
      static {
        __name(this, "PutKeyPolicyCommand");
      }
    };
    var ReEncryptCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "ReEncrypt", {}).n("KMSClient", "ReEncryptCommand").sc(schemas_0.ReEncrypt$).build() {
      static {
        __name(this, "ReEncryptCommand");
      }
    };
    var ReplicateKeyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "ReplicateKey", {}).n("KMSClient", "ReplicateKeyCommand").sc(schemas_0.ReplicateKey$).build() {
      static {
        __name(this, "ReplicateKeyCommand");
      }
    };
    var RetireGrantCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "RetireGrant", {}).n("KMSClient", "RetireGrantCommand").sc(schemas_0.RetireGrant$).build() {
      static {
        __name(this, "RetireGrantCommand");
      }
    };
    var RevokeGrantCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "RevokeGrant", {}).n("KMSClient", "RevokeGrantCommand").sc(schemas_0.RevokeGrant$).build() {
      static {
        __name(this, "RevokeGrantCommand");
      }
    };
    var RotateKeyOnDemandCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "RotateKeyOnDemand", {}).n("KMSClient", "RotateKeyOnDemandCommand").sc(schemas_0.RotateKeyOnDemand$).build() {
      static {
        __name(this, "RotateKeyOnDemandCommand");
      }
    };
    var ScheduleKeyDeletionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "ScheduleKeyDeletion", {}).n("KMSClient", "ScheduleKeyDeletionCommand").sc(schemas_0.ScheduleKeyDeletion$).build() {
      static {
        __name(this, "ScheduleKeyDeletionCommand");
      }
    };
    var SignCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "Sign", {}).n("KMSClient", "SignCommand").sc(schemas_0.Sign$).build() {
      static {
        __name(this, "SignCommand");
      }
    };
    var TagResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "TagResource", {}).n("KMSClient", "TagResourceCommand").sc(schemas_0.TagResource$).build() {
      static {
        __name(this, "TagResourceCommand");
      }
    };
    var UntagResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "UntagResource", {}).n("KMSClient", "UntagResourceCommand").sc(schemas_0.UntagResource$).build() {
      static {
        __name(this, "UntagResourceCommand");
      }
    };
    var UpdateAliasCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "UpdateAlias", {}).n("KMSClient", "UpdateAliasCommand").sc(schemas_0.UpdateAlias$).build() {
      static {
        __name(this, "UpdateAliasCommand");
      }
    };
    var UpdateCustomKeyStoreCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "UpdateCustomKeyStore", {}).n("KMSClient", "UpdateCustomKeyStoreCommand").sc(schemas_0.UpdateCustomKeyStore$).build() {
      static {
        __name(this, "UpdateCustomKeyStoreCommand");
      }
    };
    var UpdateKeyDescriptionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "UpdateKeyDescription", {}).n("KMSClient", "UpdateKeyDescriptionCommand").sc(schemas_0.UpdateKeyDescription$).build() {
      static {
        __name(this, "UpdateKeyDescriptionCommand");
      }
    };
    var UpdatePrimaryRegionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "UpdatePrimaryRegion", {}).n("KMSClient", "UpdatePrimaryRegionCommand").sc(schemas_0.UpdatePrimaryRegion$).build() {
      static {
        __name(this, "UpdatePrimaryRegionCommand");
      }
    };
    var VerifyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "Verify", {}).n("KMSClient", "VerifyCommand").sc(schemas_0.Verify$).build() {
      static {
        __name(this, "VerifyCommand");
      }
    };
    var VerifyMacCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("TrentService", "VerifyMac", {}).n("KMSClient", "VerifyMacCommand").sc(schemas_0.VerifyMac$).build() {
      static {
        __name(this, "VerifyMacCommand");
      }
    };
    var paginateDescribeCustomKeyStores = core.createPaginator(KMSClient2, DescribeCustomKeyStoresCommand, "Marker", "NextMarker", "Limit");
    var paginateListAliases = core.createPaginator(KMSClient2, ListAliasesCommand2, "Marker", "NextMarker", "Limit");
    var paginateListGrants = core.createPaginator(KMSClient2, ListGrantsCommand, "Marker", "NextMarker", "Limit");
    var paginateListKeyPolicies = core.createPaginator(KMSClient2, ListKeyPoliciesCommand, "Marker", "NextMarker", "Limit");
    var paginateListKeyRotations = core.createPaginator(KMSClient2, ListKeyRotationsCommand, "Marker", "NextMarker", "Limit");
    var paginateListKeys = core.createPaginator(KMSClient2, ListKeysCommand, "Marker", "NextMarker", "Limit");
    var paginateListResourceTags = core.createPaginator(KMSClient2, ListResourceTagsCommand, "Marker", "NextMarker", "Limit");
    var paginateListRetirableGrants = core.createPaginator(KMSClient2, ListRetirableGrantsCommand, "Marker", "NextMarker", "Limit");
    var commands32 = {
      CancelKeyDeletionCommand,
      ConnectCustomKeyStoreCommand,
      CreateAliasCommand,
      CreateCustomKeyStoreCommand,
      CreateGrantCommand,
      CreateKeyCommand,
      DecryptCommand,
      DeleteAliasCommand,
      DeleteCustomKeyStoreCommand,
      DeleteImportedKeyMaterialCommand,
      DeriveSharedSecretCommand,
      DescribeCustomKeyStoresCommand,
      DescribeKeyCommand: DescribeKeyCommand2,
      DisableKeyCommand,
      DisableKeyRotationCommand,
      DisconnectCustomKeyStoreCommand,
      EnableKeyCommand,
      EnableKeyRotationCommand,
      EncryptCommand,
      GenerateDataKeyCommand,
      GenerateDataKeyPairCommand,
      GenerateDataKeyPairWithoutPlaintextCommand,
      GenerateDataKeyWithoutPlaintextCommand,
      GenerateMacCommand,
      GenerateRandomCommand,
      GetKeyLastUsageCommand,
      GetKeyPolicyCommand,
      GetKeyRotationStatusCommand,
      GetParametersForImportCommand,
      GetPublicKeyCommand,
      ImportKeyMaterialCommand,
      ListAliasesCommand: ListAliasesCommand2,
      ListGrantsCommand,
      ListKeyPoliciesCommand,
      ListKeyRotationsCommand,
      ListKeysCommand,
      ListResourceTagsCommand,
      ListRetirableGrantsCommand,
      PutKeyPolicyCommand,
      ReEncryptCommand,
      ReplicateKeyCommand,
      RetireGrantCommand,
      RevokeGrantCommand,
      RotateKeyOnDemandCommand,
      ScheduleKeyDeletionCommand,
      SignCommand,
      TagResourceCommand,
      UntagResourceCommand,
      UpdateAliasCommand: UpdateAliasCommand2,
      UpdateCustomKeyStoreCommand,
      UpdateKeyDescriptionCommand,
      UpdatePrimaryRegionCommand,
      VerifyCommand,
      VerifyMacCommand
    };
    var paginators = {
      paginateDescribeCustomKeyStores,
      paginateListAliases,
      paginateListGrants,
      paginateListKeyPolicies,
      paginateListKeyRotations,
      paginateListKeys,
      paginateListResourceTags,
      paginateListRetirableGrants
    };
    var KMS = class extends KMSClient2 {
      static {
        __name(this, "KMS");
      }
    };
    smithyClient.createAggregatedClient(commands32, KMS, { paginators });
    var AlgorithmSpec = {
      RSAES_OAEP_SHA_1: "RSAES_OAEP_SHA_1",
      RSAES_OAEP_SHA_256: "RSAES_OAEP_SHA_256",
      RSAES_PKCS1_V1_5: "RSAES_PKCS1_V1_5",
      RSA_AES_KEY_WRAP_SHA_1: "RSA_AES_KEY_WRAP_SHA_1",
      RSA_AES_KEY_WRAP_SHA_256: "RSA_AES_KEY_WRAP_SHA_256",
      SM2PKE: "SM2PKE"
    };
    var ConnectionErrorCodeType = {
      CLUSTER_NOT_FOUND: "CLUSTER_NOT_FOUND",
      INSUFFICIENT_CLOUDHSM_HSMS: "INSUFFICIENT_CLOUDHSM_HSMS",
      INSUFFICIENT_FREE_ADDRESSES_IN_SUBNET: "INSUFFICIENT_FREE_ADDRESSES_IN_SUBNET",
      INTERNAL_ERROR: "INTERNAL_ERROR",
      INVALID_CREDENTIALS: "INVALID_CREDENTIALS",
      NETWORK_ERRORS: "NETWORK_ERRORS",
      SUBNET_NOT_FOUND: "SUBNET_NOT_FOUND",
      USER_LOCKED_OUT: "USER_LOCKED_OUT",
      USER_LOGGED_IN: "USER_LOGGED_IN",
      USER_NOT_FOUND: "USER_NOT_FOUND",
      XKS_PROXY_ACCESS_DENIED: "XKS_PROXY_ACCESS_DENIED",
      XKS_PROXY_INVALID_CONFIGURATION: "XKS_PROXY_INVALID_CONFIGURATION",
      XKS_PROXY_INVALID_RESPONSE: "XKS_PROXY_INVALID_RESPONSE",
      XKS_PROXY_INVALID_TLS_CONFIGURATION: "XKS_PROXY_INVALID_TLS_CONFIGURATION",
      XKS_PROXY_NOT_REACHABLE: "XKS_PROXY_NOT_REACHABLE",
      XKS_PROXY_TIMED_OUT: "XKS_PROXY_TIMED_OUT",
      XKS_VPC_ENDPOINT_SERVICE_INVALID_CONFIGURATION: "XKS_VPC_ENDPOINT_SERVICE_INVALID_CONFIGURATION",
      XKS_VPC_ENDPOINT_SERVICE_NOT_FOUND: "XKS_VPC_ENDPOINT_SERVICE_NOT_FOUND"
    };
    var ConnectionStateType = {
      CONNECTED: "CONNECTED",
      CONNECTING: "CONNECTING",
      DISCONNECTED: "DISCONNECTED",
      DISCONNECTING: "DISCONNECTING",
      FAILED: "FAILED"
    };
    var CustomKeyStoreType = {
      AWS_CLOUDHSM: "AWS_CLOUDHSM",
      EXTERNAL_KEY_STORE: "EXTERNAL_KEY_STORE"
    };
    var XksProxyConnectivityType = {
      PUBLIC_ENDPOINT: "PUBLIC_ENDPOINT",
      VPC_ENDPOINT_SERVICE: "VPC_ENDPOINT_SERVICE"
    };
    var GrantOperation = {
      CreateGrant: "CreateGrant",
      Decrypt: "Decrypt",
      DeriveSharedSecret: "DeriveSharedSecret",
      DescribeKey: "DescribeKey",
      Encrypt: "Encrypt",
      GenerateDataKey: "GenerateDataKey",
      GenerateDataKeyPair: "GenerateDataKeyPair",
      GenerateDataKeyPairWithoutPlaintext: "GenerateDataKeyPairWithoutPlaintext",
      GenerateDataKeyWithoutPlaintext: "GenerateDataKeyWithoutPlaintext",
      GenerateMac: "GenerateMac",
      GetPublicKey: "GetPublicKey",
      ReEncryptFrom: "ReEncryptFrom",
      ReEncryptTo: "ReEncryptTo",
      RetireGrant: "RetireGrant",
      Sign: "Sign",
      Verify: "Verify",
      VerifyMac: "VerifyMac"
    };
    var CustomerMasterKeySpec = {
      ECC_NIST_P256: "ECC_NIST_P256",
      ECC_NIST_P384: "ECC_NIST_P384",
      ECC_NIST_P521: "ECC_NIST_P521",
      ECC_SECG_P256K1: "ECC_SECG_P256K1",
      HMAC_224: "HMAC_224",
      HMAC_256: "HMAC_256",
      HMAC_384: "HMAC_384",
      HMAC_512: "HMAC_512",
      RSA_2048: "RSA_2048",
      RSA_3072: "RSA_3072",
      RSA_4096: "RSA_4096",
      SM2: "SM2",
      SYMMETRIC_DEFAULT: "SYMMETRIC_DEFAULT"
    };
    var KeySpec = {
      ECC_NIST_EDWARDS25519: "ECC_NIST_EDWARDS25519",
      ECC_NIST_P256: "ECC_NIST_P256",
      ECC_NIST_P384: "ECC_NIST_P384",
      ECC_NIST_P521: "ECC_NIST_P521",
      ECC_SECG_P256K1: "ECC_SECG_P256K1",
      HMAC_224: "HMAC_224",
      HMAC_256: "HMAC_256",
      HMAC_384: "HMAC_384",
      HMAC_512: "HMAC_512",
      ML_DSA_44: "ML_DSA_44",
      ML_DSA_65: "ML_DSA_65",
      ML_DSA_87: "ML_DSA_87",
      RSA_2048: "RSA_2048",
      RSA_3072: "RSA_3072",
      RSA_4096: "RSA_4096",
      SM2: "SM2",
      SYMMETRIC_DEFAULT: "SYMMETRIC_DEFAULT"
    };
    var KeyUsageType = {
      ENCRYPT_DECRYPT: "ENCRYPT_DECRYPT",
      GENERATE_VERIFY_MAC: "GENERATE_VERIFY_MAC",
      KEY_AGREEMENT: "KEY_AGREEMENT",
      SIGN_VERIFY: "SIGN_VERIFY"
    };
    var OriginType = {
      AWS_CLOUDHSM: "AWS_CLOUDHSM",
      AWS_KMS: "AWS_KMS",
      EXTERNAL: "EXTERNAL",
      EXTERNAL_KEY_STORE: "EXTERNAL_KEY_STORE"
    };
    var EncryptionAlgorithmSpec = {
      RSAES_OAEP_SHA_1: "RSAES_OAEP_SHA_1",
      RSAES_OAEP_SHA_256: "RSAES_OAEP_SHA_256",
      SM2PKE: "SM2PKE",
      SYMMETRIC_DEFAULT: "SYMMETRIC_DEFAULT"
    };
    var ExpirationModelType = {
      KEY_MATERIAL_DOES_NOT_EXPIRE: "KEY_MATERIAL_DOES_NOT_EXPIRE",
      KEY_MATERIAL_EXPIRES: "KEY_MATERIAL_EXPIRES"
    };
    var KeyAgreementAlgorithmSpec = {
      ECDH: "ECDH"
    };
    var KeyManagerType = {
      AWS: "AWS",
      CUSTOMER: "CUSTOMER"
    };
    var KeyState = {
      Creating: "Creating",
      Disabled: "Disabled",
      Enabled: "Enabled",
      PendingDeletion: "PendingDeletion",
      PendingImport: "PendingImport",
      PendingReplicaDeletion: "PendingReplicaDeletion",
      Unavailable: "Unavailable",
      Updating: "Updating"
    };
    var MacAlgorithmSpec = {
      HMAC_SHA_224: "HMAC_SHA_224",
      HMAC_SHA_256: "HMAC_SHA_256",
      HMAC_SHA_384: "HMAC_SHA_384",
      HMAC_SHA_512: "HMAC_SHA_512"
    };
    var MultiRegionKeyType = {
      PRIMARY: "PRIMARY",
      REPLICA: "REPLICA"
    };
    var SigningAlgorithmSpec = {
      ECDSA_SHA_256: "ECDSA_SHA_256",
      ECDSA_SHA_384: "ECDSA_SHA_384",
      ECDSA_SHA_512: "ECDSA_SHA_512",
      ED25519_PH_SHA_512: "ED25519_PH_SHA_512",
      ED25519_SHA_512: "ED25519_SHA_512",
      ML_DSA_SHAKE_256: "ML_DSA_SHAKE_256",
      RSASSA_PKCS1_V1_5_SHA_256: "RSASSA_PKCS1_V1_5_SHA_256",
      RSASSA_PKCS1_V1_5_SHA_384: "RSASSA_PKCS1_V1_5_SHA_384",
      RSASSA_PKCS1_V1_5_SHA_512: "RSASSA_PKCS1_V1_5_SHA_512",
      RSASSA_PSS_SHA_256: "RSASSA_PSS_SHA_256",
      RSASSA_PSS_SHA_384: "RSASSA_PSS_SHA_384",
      RSASSA_PSS_SHA_512: "RSASSA_PSS_SHA_512",
      SM2DSA: "SM2DSA"
    };
    var DataKeyPairSpec = {
      ECC_NIST_EDWARDS25519: "ECC_NIST_EDWARDS25519",
      ECC_NIST_P256: "ECC_NIST_P256",
      ECC_NIST_P384: "ECC_NIST_P384",
      ECC_NIST_P521: "ECC_NIST_P521",
      ECC_SECG_P256K1: "ECC_SECG_P256K1",
      RSA_2048: "RSA_2048",
      RSA_3072: "RSA_3072",
      RSA_4096: "RSA_4096",
      SM2: "SM2"
    };
    var DataKeySpec = {
      AES_128: "AES_128",
      AES_256: "AES_256"
    };
    var DryRunModifierType = {
      IGNORE_CIPHERTEXT: "IGNORE_CIPHERTEXT"
    };
    var KeyEncryptionMechanism = {
      RSAES_OAEP_SHA_256: "RSAES_OAEP_SHA_256"
    };
    var KeyLastUsageTrackingOperation = {
      Decrypt: "Decrypt",
      DeriveSharedSecret: "DeriveSharedSecret",
      Encrypt: "Encrypt",
      GenerateDataKey: "GenerateDataKey",
      GenerateDataKeyPair: "GenerateDataKeyPair",
      GenerateDataKeyPairWithoutPlaintext: "GenerateDataKeyPairWithoutPlaintext",
      GenerateDataKeyWithoutPlaintext: "GenerateDataKeyWithoutPlaintext",
      GenerateMac: "GenerateMac",
      ReEncrypt: "ReEncrypt",
      Sign: "Sign",
      Verify: "Verify",
      VerifyMac: "VerifyMac"
    };
    var WrappingKeySpec = {
      RSA_2048: "RSA_2048",
      RSA_3072: "RSA_3072",
      RSA_4096: "RSA_4096",
      SM2: "SM2"
    };
    var ImportType = {
      EXISTING_KEY_MATERIAL: "EXISTING_KEY_MATERIAL",
      NEW_KEY_MATERIAL: "NEW_KEY_MATERIAL"
    };
    var ImportState = {
      IMPORTED: "IMPORTED",
      PENDING_IMPORT: "PENDING_IMPORT"
    };
    var IncludeKeyMaterial = {
      ALL_KEY_MATERIAL: "ALL_KEY_MATERIAL",
      ROTATIONS_ONLY: "ROTATIONS_ONLY"
    };
    var KeyMaterialState = {
      CURRENT: "CURRENT",
      NON_CURRENT: "NON_CURRENT",
      PENDING_MULTI_REGION_IMPORT_AND_ROTATION: "PENDING_MULTI_REGION_IMPORT_AND_ROTATION",
      PENDING_ROTATION: "PENDING_ROTATION"
    };
    var RotationType = {
      AUTOMATIC: "AUTOMATIC",
      ON_DEMAND: "ON_DEMAND"
    };
    var MessageType = {
      DIGEST: "DIGEST",
      EXTERNAL_MU: "EXTERNAL_MU",
      RAW: "RAW"
    };
    exports2.$Command = smithyClient.Command;
    exports2.__Client = smithyClient.Client;
    exports2.KMSServiceException = KMSServiceException.KMSServiceException;
    exports2.AlgorithmSpec = AlgorithmSpec;
    exports2.CancelKeyDeletionCommand = CancelKeyDeletionCommand;
    exports2.ConnectCustomKeyStoreCommand = ConnectCustomKeyStoreCommand;
    exports2.ConnectionErrorCodeType = ConnectionErrorCodeType;
    exports2.ConnectionStateType = ConnectionStateType;
    exports2.CreateAliasCommand = CreateAliasCommand;
    exports2.CreateCustomKeyStoreCommand = CreateCustomKeyStoreCommand;
    exports2.CreateGrantCommand = CreateGrantCommand;
    exports2.CreateKeyCommand = CreateKeyCommand;
    exports2.CustomKeyStoreType = CustomKeyStoreType;
    exports2.CustomerMasterKeySpec = CustomerMasterKeySpec;
    exports2.DataKeyPairSpec = DataKeyPairSpec;
    exports2.DataKeySpec = DataKeySpec;
    exports2.DecryptCommand = DecryptCommand;
    exports2.DeleteAliasCommand = DeleteAliasCommand;
    exports2.DeleteCustomKeyStoreCommand = DeleteCustomKeyStoreCommand;
    exports2.DeleteImportedKeyMaterialCommand = DeleteImportedKeyMaterialCommand;
    exports2.DeriveSharedSecretCommand = DeriveSharedSecretCommand;
    exports2.DescribeCustomKeyStoresCommand = DescribeCustomKeyStoresCommand;
    exports2.DescribeKeyCommand = DescribeKeyCommand2;
    exports2.DisableKeyCommand = DisableKeyCommand;
    exports2.DisableKeyRotationCommand = DisableKeyRotationCommand;
    exports2.DisconnectCustomKeyStoreCommand = DisconnectCustomKeyStoreCommand;
    exports2.DryRunModifierType = DryRunModifierType;
    exports2.EnableKeyCommand = EnableKeyCommand;
    exports2.EnableKeyRotationCommand = EnableKeyRotationCommand;
    exports2.EncryptCommand = EncryptCommand;
    exports2.EncryptionAlgorithmSpec = EncryptionAlgorithmSpec;
    exports2.ExpirationModelType = ExpirationModelType;
    exports2.GenerateDataKeyCommand = GenerateDataKeyCommand;
    exports2.GenerateDataKeyPairCommand = GenerateDataKeyPairCommand;
    exports2.GenerateDataKeyPairWithoutPlaintextCommand = GenerateDataKeyPairWithoutPlaintextCommand;
    exports2.GenerateDataKeyWithoutPlaintextCommand = GenerateDataKeyWithoutPlaintextCommand;
    exports2.GenerateMacCommand = GenerateMacCommand;
    exports2.GenerateRandomCommand = GenerateRandomCommand;
    exports2.GetKeyLastUsageCommand = GetKeyLastUsageCommand;
    exports2.GetKeyPolicyCommand = GetKeyPolicyCommand;
    exports2.GetKeyRotationStatusCommand = GetKeyRotationStatusCommand;
    exports2.GetParametersForImportCommand = GetParametersForImportCommand;
    exports2.GetPublicKeyCommand = GetPublicKeyCommand;
    exports2.GrantOperation = GrantOperation;
    exports2.ImportKeyMaterialCommand = ImportKeyMaterialCommand;
    exports2.ImportState = ImportState;
    exports2.ImportType = ImportType;
    exports2.IncludeKeyMaterial = IncludeKeyMaterial;
    exports2.KMS = KMS;
    exports2.KMSClient = KMSClient2;
    exports2.KeyAgreementAlgorithmSpec = KeyAgreementAlgorithmSpec;
    exports2.KeyEncryptionMechanism = KeyEncryptionMechanism;
    exports2.KeyLastUsageTrackingOperation = KeyLastUsageTrackingOperation;
    exports2.KeyManagerType = KeyManagerType;
    exports2.KeyMaterialState = KeyMaterialState;
    exports2.KeySpec = KeySpec;
    exports2.KeyState = KeyState;
    exports2.KeyUsageType = KeyUsageType;
    exports2.ListAliasesCommand = ListAliasesCommand2;
    exports2.ListGrantsCommand = ListGrantsCommand;
    exports2.ListKeyPoliciesCommand = ListKeyPoliciesCommand;
    exports2.ListKeyRotationsCommand = ListKeyRotationsCommand;
    exports2.ListKeysCommand = ListKeysCommand;
    exports2.ListResourceTagsCommand = ListResourceTagsCommand;
    exports2.ListRetirableGrantsCommand = ListRetirableGrantsCommand;
    exports2.MacAlgorithmSpec = MacAlgorithmSpec;
    exports2.MessageType = MessageType;
    exports2.MultiRegionKeyType = MultiRegionKeyType;
    exports2.OriginType = OriginType;
    exports2.PutKeyPolicyCommand = PutKeyPolicyCommand;
    exports2.ReEncryptCommand = ReEncryptCommand;
    exports2.ReplicateKeyCommand = ReplicateKeyCommand;
    exports2.RetireGrantCommand = RetireGrantCommand;
    exports2.RevokeGrantCommand = RevokeGrantCommand;
    exports2.RotateKeyOnDemandCommand = RotateKeyOnDemandCommand;
    exports2.RotationType = RotationType;
    exports2.ScheduleKeyDeletionCommand = ScheduleKeyDeletionCommand;
    exports2.SignCommand = SignCommand;
    exports2.SigningAlgorithmSpec = SigningAlgorithmSpec;
    exports2.TagResourceCommand = TagResourceCommand;
    exports2.UntagResourceCommand = UntagResourceCommand;
    exports2.UpdateAliasCommand = UpdateAliasCommand2;
    exports2.UpdateCustomKeyStoreCommand = UpdateCustomKeyStoreCommand;
    exports2.UpdateKeyDescriptionCommand = UpdateKeyDescriptionCommand;
    exports2.UpdatePrimaryRegionCommand = UpdatePrimaryRegionCommand;
    exports2.VerifyCommand = VerifyCommand;
    exports2.VerifyMacCommand = VerifyMacCommand;
    exports2.WrappingKeySpec = WrappingKeySpec;
    exports2.XksProxyConnectivityType = XksProxyConnectivityType;
    exports2.paginateDescribeCustomKeyStores = paginateDescribeCustomKeyStores;
    exports2.paginateListAliases = paginateListAliases;
    exports2.paginateListGrants = paginateListGrants;
    exports2.paginateListKeyPolicies = paginateListKeyPolicies;
    exports2.paginateListKeyRotations = paginateListKeyRotations;
    exports2.paginateListKeys = paginateListKeys;
    exports2.paginateListResourceTags = paginateListResourceTags;
    exports2.paginateListRetirableGrants = paginateListRetirableGrants;
    Object.prototype.hasOwnProperty.call(schemas_0, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: schemas_0["__proto__"]
    });
    Object.keys(schemas_0).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = schemas_0[k32];
    });
    Object.prototype.hasOwnProperty.call(errors, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: errors["__proto__"]
    });
    Object.keys(errors).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = errors[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/client/emitWarningIfUnsupportedVersion.js
var state11, emitWarningIfUnsupportedVersion34;
var init_emitWarningIfUnsupportedVersion13 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/client/emitWarningIfUnsupportedVersion.js"() {
    state11 = {
      warningEmitted: false
    };
    emitWarningIfUnsupportedVersion34 = /* @__PURE__ */ __name((version) => {
      if (version && !state11.warningEmitted) {
        if (process.env.AWS_SDK_JS_NODE_VERSION_SUPPORT_WARNING_DISABLED === "true") {
          state11.warningEmitted = true;
          return;
        }
        const userMajorVersion = parseInt(version.substring(1, version.indexOf(".")));
        const vv = 22;
        if (userMajorVersion < vv) {
          state11.warningEmitted = true;
          process.emitWarning(`NodeVersionSupportWarning: The AWS SDK for JavaScript (v3)
versions published after the first week of January 2027
will require node >=${vv}. You are running node ${version}.

To continue receiving updates to AWS services, bug fixes,
and security updates please upgrade to node >=${vv}.

More information can be found at: https://a.co/c895JFp`);
        }
      }
    }, "emitWarningIfUnsupportedVersion");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/client/longPollMiddleware.js
var longPollMiddleware11, longPollMiddlewareOptions11, getLongPollPlugin11;
var init_longPollMiddleware11 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/client/longPollMiddleware.js"() {
    longPollMiddleware11 = /* @__PURE__ */ __name(() => (next, context) => async (args) => {
      context.__retryLongPoll = true;
      return next(args);
    }, "longPollMiddleware");
    longPollMiddlewareOptions11 = {
      name: "longPollMiddleware",
      tags: ["RETRY"],
      step: "initialize",
      override: true
    };
    getLongPollPlugin11 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(longPollMiddleware11(), longPollMiddlewareOptions11);
      }, "applyToStack")
    }), "getLongPollPlugin");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/client/setCredentialFeature.js
function setCredentialFeature11(credentials, feature, value) {
  if (!credentials.$source) {
    credentials.$source = {};
  }
  credentials.$source[feature] = value;
  return credentials;
}
var init_setCredentialFeature11 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/client/setCredentialFeature.js"() {
    __name(setCredentialFeature11, "setCredentialFeature");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/client/setFeature.js
function setFeature17(context, feature, value) {
  if (!context.__aws_sdk_context) {
    context.__aws_sdk_context = {
      features: {}
    };
  } else if (!context.__aws_sdk_context.features) {
    context.__aws_sdk_context.features = {};
  }
  context.__aws_sdk_context.features[feature] = value;
}
var import_util_retry31;
var init_setFeature13 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/client/setFeature.js"() {
    import_util_retry31 = __toESM(require_dist_cjs22());
    import_util_retry31.Retry.v2026 ||= typeof process === "object" && process.env?.AWS_NEW_RETRIES_2026 === "true";
    __name(setFeature17, "setFeature");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/client/setTokenFeature.js
function setTokenFeature11(token, feature, value) {
  if (!token.$source) {
    token.$source = {};
  }
  token.$source[feature] = value;
  return token;
}
var init_setTokenFeature11 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/client/setTokenFeature.js"() {
    __name(setTokenFeature11, "setTokenFeature");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/client/index.js
var client_exports13 = {};
__export(client_exports13, {
  emitWarningIfUnsupportedVersion: () => emitWarningIfUnsupportedVersion34,
  getLongPollPlugin: () => getLongPollPlugin11,
  setCredentialFeature: () => setCredentialFeature11,
  setFeature: () => setFeature17,
  setTokenFeature: () => setTokenFeature11,
  state: () => state11
});
var init_client18 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/client/index.js"() {
    init_emitWarningIfUnsupportedVersion13();
    init_longPollMiddleware11();
    init_setCredentialFeature11();
    init_setFeature13();
    init_setTokenFeature11();
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/middleware-user-agent/dist-cjs/index.js
var require_dist_cjs180 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/middleware-user-agent/dist-cjs/index.js"(exports2) {
    "use strict";
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var utilEndpoints = require_dist_cjs21();
    var protocolHttp = require_dist_cjs2();
    var client = (init_client18(), __toCommonJS(client_exports13));
    var utilRetry = require_dist_cjs22();
    var DEFAULT_UA_APP_ID2 = void 0;
    function isValidUserAgentAppId2(appId) {
      if (appId === void 0) {
        return true;
      }
      return typeof appId === "string" && appId.length <= 50;
    }
    __name(isValidUserAgentAppId2, "isValidUserAgentAppId");
    function resolveUserAgentConfig29(input) {
      const normalizedAppIdProvider = core.normalizeProvider(input.userAgentAppId ?? DEFAULT_UA_APP_ID2);
      const { customUserAgent } = input;
      return Object.assign(input, {
        customUserAgent: typeof customUserAgent === "string" ? [[customUserAgent]] : customUserAgent,
        userAgentAppId: /* @__PURE__ */ __name(async () => {
          const appId = await normalizedAppIdProvider();
          if (!isValidUserAgentAppId2(appId)) {
            const logger5 = input.logger?.constructor?.name === "NoOpLogger" || !input.logger ? console : input.logger;
            if (typeof appId !== "string") {
              logger5?.warn("userAgentAppId must be a string or undefined.");
            } else if (appId.length > 50) {
              logger5?.warn("The provided userAgentAppId exceeds the maximum length of 50 characters.");
            }
          }
          return appId;
        }, "userAgentAppId")
      });
    }
    __name(resolveUserAgentConfig29, "resolveUserAgentConfig");
    var ACCOUNT_ID_ENDPOINT_REGEX2 = /\d{12}\.ddb/;
    async function checkFeatures2(context, config2, args) {
      const request4 = args.request;
      if (request4?.headers?.["smithy-protocol"] === "rpc-v2-cbor") {
        client.setFeature(context, "PROTOCOL_RPC_V2_CBOR", "M");
      }
      if (typeof config2.retryStrategy === "function") {
        const retryStrategy = await config2.retryStrategy();
        if (typeof retryStrategy.mode === "string") {
          switch (retryStrategy.mode) {
            case utilRetry.RETRY_MODES.ADAPTIVE:
              client.setFeature(context, "RETRY_MODE_ADAPTIVE", "F");
              break;
            case utilRetry.RETRY_MODES.STANDARD:
              client.setFeature(context, "RETRY_MODE_STANDARD", "E");
              break;
          }
        }
      }
      if (typeof config2.accountIdEndpointMode === "function") {
        const endpointV2 = context.endpointV2;
        if (String(endpointV2?.url?.hostname).match(ACCOUNT_ID_ENDPOINT_REGEX2)) {
          client.setFeature(context, "ACCOUNT_ID_ENDPOINT", "O");
        }
        switch (await config2.accountIdEndpointMode?.()) {
          case "disabled":
            client.setFeature(context, "ACCOUNT_ID_MODE_DISABLED", "Q");
            break;
          case "preferred":
            client.setFeature(context, "ACCOUNT_ID_MODE_PREFERRED", "P");
            break;
          case "required":
            client.setFeature(context, "ACCOUNT_ID_MODE_REQUIRED", "R");
            break;
        }
      }
      const identity = context.__smithy_context?.selectedHttpAuthScheme?.identity;
      if (identity?.$source) {
        const credentials = identity;
        if (credentials.accountId) {
          client.setFeature(context, "RESOLVED_ACCOUNT_ID", "T");
        }
        for (const [key, value] of Object.entries(credentials.$source ?? {})) {
          client.setFeature(context, key, value);
        }
      }
    }
    __name(checkFeatures2, "checkFeatures");
    var USER_AGENT3 = "user-agent";
    var X_AMZ_USER_AGENT2 = "x-amz-user-agent";
    var SPACE2 = " ";
    var UA_NAME_SEPARATOR2 = "/";
    var UA_NAME_ESCAPE_REGEX2 = /[^!$%&'*+\-.^_`|~\w]/g;
    var UA_VALUE_ESCAPE_REGEX2 = /[^!$%&'*+\-.^_`|~\w#]/g;
    var UA_ESCAPE_CHAR2 = "-";
    var BYTE_LIMIT2 = 1024;
    function encodeFeatures2(features) {
      let buffer = "";
      for (const key in features) {
        const val = features[key];
        if (buffer.length + val.length + 1 <= BYTE_LIMIT2) {
          if (buffer.length) {
            buffer += "," + val;
          } else {
            buffer += val;
          }
          continue;
        }
        break;
      }
      return buffer;
    }
    __name(encodeFeatures2, "encodeFeatures");
    var userAgentMiddleware2 = /* @__PURE__ */ __name((options) => (next, context) => async (args) => {
      const { request: request4 } = args;
      if (!protocolHttp.HttpRequest.isInstance(request4)) {
        return next(args);
      }
      const { headers } = request4;
      const userAgent = context?.userAgent?.map(escapeUserAgent2) || [];
      const defaultUserAgent2 = (await options.defaultUserAgentProvider()).map(escapeUserAgent2);
      await checkFeatures2(context, options, args);
      const awsContext = context;
      defaultUserAgent2.push(`m/${encodeFeatures2(Object.assign({}, context.__smithy_context?.features, awsContext.__aws_sdk_context?.features))}`);
      const customUserAgent = options?.customUserAgent?.map(escapeUserAgent2) || [];
      const appId = await options.userAgentAppId();
      if (appId) {
        defaultUserAgent2.push(escapeUserAgent2([`app`, `${appId}`]));
      }
      const prefix = utilEndpoints.getUserAgentPrefix();
      const sdkUserAgentValue = (prefix ? [prefix] : []).concat([...defaultUserAgent2, ...userAgent, ...customUserAgent]).join(SPACE2);
      const normalUAValue = [
        ...defaultUserAgent2.filter((section) => section.startsWith("aws-sdk-")),
        ...customUserAgent
      ].join(SPACE2);
      if (options.runtime !== "browser") {
        if (normalUAValue) {
          headers[X_AMZ_USER_AGENT2] = headers[X_AMZ_USER_AGENT2] ? `${headers[USER_AGENT3]} ${normalUAValue}` : normalUAValue;
        }
        headers[USER_AGENT3] = sdkUserAgentValue;
      } else {
        headers[X_AMZ_USER_AGENT2] = sdkUserAgentValue;
      }
      return next({
        ...args,
        request: request4
      });
    }, "userAgentMiddleware");
    var escapeUserAgent2 = /* @__PURE__ */ __name((userAgentPair) => {
      const name = userAgentPair[0].split(UA_NAME_SEPARATOR2).map((part) => part.replace(UA_NAME_ESCAPE_REGEX2, UA_ESCAPE_CHAR2)).join(UA_NAME_SEPARATOR2);
      const version = userAgentPair[1]?.replace(UA_VALUE_ESCAPE_REGEX2, UA_ESCAPE_CHAR2);
      const prefixSeparatorIndex = name.indexOf(UA_NAME_SEPARATOR2);
      const prefix = name.substring(0, prefixSeparatorIndex);
      let uaName = name.substring(prefixSeparatorIndex + 1);
      if (prefix === "api") {
        uaName = uaName.toLowerCase();
      }
      return [prefix, uaName, version].filter((item) => item && item.length > 0).reduce((acc, item, index) => {
        switch (index) {
          case 0:
            return item;
          case 1:
            return `${acc}/${item}`;
          default:
            return `${acc}#${item}`;
        }
      }, "");
    }, "escapeUserAgent");
    var getUserAgentMiddlewareOptions2 = {
      name: "getUserAgentMiddleware",
      step: "build",
      priority: "low",
      tags: ["SET_USER_AGENT", "USER_AGENT"],
      override: true
    };
    var getUserAgentPlugin29 = /* @__PURE__ */ __name((config2) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(userAgentMiddleware2(config2), getUserAgentMiddlewareOptions2);
      }, "applyToStack")
    }), "getUserAgentPlugin");
    exports2.DEFAULT_UA_APP_ID = DEFAULT_UA_APP_ID2;
    exports2.getUserAgentMiddlewareOptions = getUserAgentMiddlewareOptions2;
    exports2.getUserAgentPlugin = getUserAgentPlugin29;
    exports2.resolveUserAgentConfig = resolveUserAgentConfig29;
    exports2.userAgentMiddleware = userAgentMiddleware2;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/middleware-retry/dist-cjs/isStreamingPayload/isStreamingPayload.js
var require_isStreamingPayload8 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/middleware-retry/dist-cjs/isStreamingPayload/isStreamingPayload.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isStreamingPayload = void 0;
    var stream_1 = require("stream");
    var isStreamingPayload3 = /* @__PURE__ */ __name((request4) => request4?.body instanceof stream_1.Readable || typeof ReadableStream !== "undefined" && request4?.body instanceof ReadableStream, "isStreamingPayload");
    exports2.isStreamingPayload = isStreamingPayload3;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/middleware-retry/dist-cjs/index.js
var require_dist_cjs181 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/middleware-retry/dist-cjs/index.js"(exports2) {
    "use strict";
    var utilRetry = require_dist_cjs22();
    var protocolHttp = require_dist_cjs2();
    var serviceErrorClassification = require_dist_cjs32();
    var uuid = require_dist_cjs19();
    var utilMiddleware = require_dist_cjs6();
    var smithyClient = require_dist_cjs34();
    var isStreamingPayload3 = require_isStreamingPayload8();
    var serde = (init_serde(), __toCommonJS(serde_exports));
    var asSdkError3 = /* @__PURE__ */ __name((error4) => {
      if (error4 instanceof Error)
        return error4;
      if (error4 instanceof Object)
        return Object.assign(new Error(), error4);
      if (typeof error4 === "string")
        return new Error(error4);
      return new Error(`AWS SDK error wrapper for ${error4}`);
    }, "asSdkError");
    var getDefaultRetryQuota3 = /* @__PURE__ */ __name((initialRetryTokens, options) => {
      const MAX_CAPACITY = initialRetryTokens;
      const noRetryIncrement = utilRetry.NO_RETRY_INCREMENT;
      const retryCost = utilRetry.RETRY_COST;
      const timeoutRetryCost = utilRetry.TIMEOUT_RETRY_COST;
      let availableCapacity = initialRetryTokens;
      const getCapacityAmount = /* @__PURE__ */ __name((error4) => error4.name === "TimeoutError" ? timeoutRetryCost : retryCost, "getCapacityAmount");
      const hasRetryTokens = /* @__PURE__ */ __name((error4) => getCapacityAmount(error4) <= availableCapacity, "hasRetryTokens");
      const retrieveRetryTokens = /* @__PURE__ */ __name((error4) => {
        if (!hasRetryTokens(error4)) {
          throw new Error("No retry token available");
        }
        const capacityAmount = getCapacityAmount(error4);
        availableCapacity -= capacityAmount;
        return capacityAmount;
      }, "retrieveRetryTokens");
      const releaseRetryTokens = /* @__PURE__ */ __name((capacityReleaseAmount) => {
        availableCapacity += capacityReleaseAmount ?? noRetryIncrement;
        availableCapacity = Math.min(availableCapacity, MAX_CAPACITY);
      }, "releaseRetryTokens");
      return Object.freeze({
        hasRetryTokens,
        retrieveRetryTokens,
        releaseRetryTokens
      });
    }, "getDefaultRetryQuota");
    var defaultDelayDecider3 = /* @__PURE__ */ __name((delayBase, attempts) => Math.floor(Math.min(utilRetry.MAXIMUM_RETRY_DELAY, Math.random() * 2 ** attempts * delayBase)), "defaultDelayDecider");
    var defaultRetryDecider3 = /* @__PURE__ */ __name((error4) => {
      if (!error4) {
        return false;
      }
      return serviceErrorClassification.isRetryableByTrait(error4) || serviceErrorClassification.isClockSkewError(error4) || serviceErrorClassification.isThrottlingError(error4) || serviceErrorClassification.isTransientError(error4);
    }, "defaultRetryDecider");
    var StandardRetryStrategy5 = class {
      static {
        __name(this, "StandardRetryStrategy");
      }
      maxAttemptsProvider;
      retryDecider;
      delayDecider;
      retryQuota;
      mode = utilRetry.RETRY_MODES.STANDARD;
      constructor(maxAttemptsProvider, options) {
        this.maxAttemptsProvider = maxAttemptsProvider;
        this.retryDecider = options?.retryDecider ?? defaultRetryDecider3;
        this.delayDecider = options?.delayDecider ?? defaultDelayDecider3;
        this.retryQuota = options?.retryQuota ?? getDefaultRetryQuota3(utilRetry.INITIAL_RETRY_TOKENS);
      }
      shouldRetry(error4, attempts, maxAttempts) {
        return attempts < maxAttempts && this.retryDecider(error4) && this.retryQuota.hasRetryTokens(error4);
      }
      async getMaxAttempts() {
        let maxAttempts;
        try {
          maxAttempts = await this.maxAttemptsProvider();
        } catch (error4) {
          maxAttempts = utilRetry.DEFAULT_MAX_ATTEMPTS;
        }
        return maxAttempts;
      }
      async retry(next, args, options) {
        let retryTokenAmount;
        let attempts = 0;
        let totalDelay = 0;
        const maxAttempts = await this.getMaxAttempts();
        const { request: request4 } = args;
        if (protocolHttp.HttpRequest.isInstance(request4)) {
          request4.headers[utilRetry.INVOCATION_ID_HEADER] = uuid.v4();
        }
        while (true) {
          try {
            if (protocolHttp.HttpRequest.isInstance(request4)) {
              request4.headers[utilRetry.REQUEST_HEADER] = `attempt=${attempts + 1}; max=${maxAttempts}`;
            }
            if (options?.beforeRequest) {
              await options.beforeRequest();
            }
            const { response, output } = await next(args);
            if (options?.afterRequest) {
              options.afterRequest(response);
            }
            this.retryQuota.releaseRetryTokens(retryTokenAmount);
            output.$metadata.attempts = attempts + 1;
            output.$metadata.totalRetryDelay = totalDelay;
            return { response, output };
          } catch (e32) {
            const err = asSdkError3(e32);
            attempts++;
            if (this.shouldRetry(err, attempts, maxAttempts)) {
              retryTokenAmount = this.retryQuota.retrieveRetryTokens(err);
              const delayFromDecider = this.delayDecider(serviceErrorClassification.isThrottlingError(err) ? utilRetry.THROTTLING_RETRY_DELAY_BASE : utilRetry.DEFAULT_RETRY_DELAY_BASE, attempts);
              const delayFromResponse = getDelayFromRetryAfterHeader3(err.$response);
              const delay = Math.max(delayFromResponse || 0, delayFromDecider);
              totalDelay += delay;
              await new Promise((resolve13) => setTimeout(resolve13, delay));
              continue;
            }
            if (!err.$metadata) {
              err.$metadata = {};
            }
            err.$metadata.attempts = attempts;
            err.$metadata.totalRetryDelay = totalDelay;
            throw err;
          }
        }
      }
    };
    var getDelayFromRetryAfterHeader3 = /* @__PURE__ */ __name((response) => {
      if (!protocolHttp.HttpResponse.isInstance(response))
        return;
      const retryAfterHeaderName = Object.keys(response.headers).find((key) => key.toLowerCase() === "retry-after");
      if (!retryAfterHeaderName)
        return;
      const retryAfter = response.headers[retryAfterHeaderName];
      const retryAfterSeconds = Number(retryAfter);
      if (!Number.isNaN(retryAfterSeconds))
        return retryAfterSeconds * 1e3;
      const retryAfterDate = new Date(retryAfter);
      return retryAfterDate.getTime() - Date.now();
    }, "getDelayFromRetryAfterHeader");
    var AdaptiveRetryStrategy5 = class extends StandardRetryStrategy5 {
      static {
        __name(this, "AdaptiveRetryStrategy");
      }
      rateLimiter;
      constructor(maxAttemptsProvider, options) {
        const { rateLimiter, ...superOptions } = options ?? {};
        super(maxAttemptsProvider, superOptions);
        this.rateLimiter = rateLimiter ?? new utilRetry.DefaultRateLimiter();
        this.mode = utilRetry.RETRY_MODES.ADAPTIVE;
      }
      async retry(next, args) {
        return super.retry(next, args, {
          beforeRequest: /* @__PURE__ */ __name(async () => {
            return this.rateLimiter.getSendToken();
          }, "beforeRequest"),
          afterRequest: /* @__PURE__ */ __name((response) => {
            this.rateLimiter.updateClientSendingRate(response);
          }, "afterRequest")
        });
      }
    };
    var ENV_MAX_ATTEMPTS3 = "AWS_MAX_ATTEMPTS";
    var CONFIG_MAX_ATTEMPTS3 = "max_attempts";
    var NODE_MAX_ATTEMPT_CONFIG_OPTIONS30 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => {
        const value = env3[ENV_MAX_ATTEMPTS3];
        if (!value)
          return void 0;
        const maxAttempt = parseInt(value);
        if (Number.isNaN(maxAttempt)) {
          throw new Error(`Environment variable ${ENV_MAX_ATTEMPTS3} mast be a number, got "${value}"`);
        }
        return maxAttempt;
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => {
        const value = profile[CONFIG_MAX_ATTEMPTS3];
        if (!value)
          return void 0;
        const maxAttempt = parseInt(value);
        if (Number.isNaN(maxAttempt)) {
          throw new Error(`Shared config file entry ${CONFIG_MAX_ATTEMPTS3} mast be a number, got "${value}"`);
        }
        return maxAttempt;
      }, "configFileSelector"),
      default: utilRetry.DEFAULT_MAX_ATTEMPTS
    };
    var resolveRetryConfig30 = /* @__PURE__ */ __name((input) => {
      const { retryStrategy, retryMode } = input;
      const maxAttempts = utilMiddleware.normalizeProvider(input.maxAttempts ?? utilRetry.DEFAULT_MAX_ATTEMPTS);
      let controller = retryStrategy ? Promise.resolve(retryStrategy) : void 0;
      const getDefault = /* @__PURE__ */ __name(async () => await utilMiddleware.normalizeProvider(retryMode)() === utilRetry.RETRY_MODES.ADAPTIVE ? new utilRetry.AdaptiveRetryStrategy(maxAttempts) : new utilRetry.StandardRetryStrategy(maxAttempts), "getDefault");
      return Object.assign(input, {
        maxAttempts,
        retryStrategy: /* @__PURE__ */ __name(() => controller ??= getDefault(), "retryStrategy")
      });
    }, "resolveRetryConfig");
    var ENV_RETRY_MODE3 = "AWS_RETRY_MODE";
    var CONFIG_RETRY_MODE3 = "retry_mode";
    var NODE_RETRY_MODE_CONFIG_OPTIONS30 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[ENV_RETRY_MODE3], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[CONFIG_RETRY_MODE3], "configFileSelector"),
      default: utilRetry.DEFAULT_RETRY_MODE
    };
    var omitRetryHeadersMiddleware3 = /* @__PURE__ */ __name(() => (next) => async (args) => {
      const { request: request4 } = args;
      if (protocolHttp.HttpRequest.isInstance(request4)) {
        delete request4.headers[utilRetry.INVOCATION_ID_HEADER];
        delete request4.headers[utilRetry.REQUEST_HEADER];
      }
      return next(args);
    }, "omitRetryHeadersMiddleware");
    var omitRetryHeadersMiddlewareOptions3 = {
      name: "omitRetryHeadersMiddleware",
      tags: ["RETRY", "HEADERS", "OMIT_RETRY_HEADERS"],
      relation: "before",
      toMiddleware: "awsAuthMiddleware",
      override: true
    };
    var getOmitRetryHeadersPlugin3 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.addRelativeTo(omitRetryHeadersMiddleware3(), omitRetryHeadersMiddlewareOptions3);
      }, "applyToStack")
    }), "getOmitRetryHeadersPlugin");
    function parseRetryAfterHeader3(response, logger5) {
      if (!protocolHttp.HttpResponse.isInstance(response)) {
        return;
      }
      for (const header of Object.keys(response.headers)) {
        const h32 = header.toLowerCase();
        if (h32 === "retry-after") {
          const retryAfter = response.headers[header];
          let retryAfterSeconds = NaN;
          if (retryAfter.endsWith("GMT")) {
            try {
              const date7 = serde.parseRfc7231DateTime(retryAfter);
              retryAfterSeconds = (date7.getTime() - Date.now()) / 1e3;
            } catch (e32) {
              logger5?.trace?.("Failed to parse retry-after header");
              logger5?.trace?.(e32);
            }
          } else if (retryAfter.match(/ GMT, ((\d+)|(\d+\.\d+))$/)) {
            retryAfterSeconds = Number(retryAfter.match(/ GMT, ([\d.]+)$/)?.[1]);
          } else if (retryAfter.match(/^((\d+)|(\d+\.\d+))$/)) {
            retryAfterSeconds = Number(retryAfter);
          } else if (Date.parse(retryAfter) >= Date.now()) {
            retryAfterSeconds = (Date.parse(retryAfter) - Date.now()) / 1e3;
          }
          if (isNaN(retryAfterSeconds)) {
            return;
          }
          return new Date(Date.now() + retryAfterSeconds * 1e3);
        } else if (h32 === "x-amz-retry-after") {
          const v = response.headers[header];
          const backoffMilliseconds = Number(v);
          if (isNaN(backoffMilliseconds)) {
            logger5?.trace?.(`Failed to parse x-amz-retry-after=${v}`);
            return;
          }
          return new Date(Date.now() + backoffMilliseconds);
        }
      }
    }
    __name(parseRetryAfterHeader3, "parseRetryAfterHeader");
    function getRetryAfterHint3(response, logger5) {
      return parseRetryAfterHeader3(response, logger5);
    }
    __name(getRetryAfterHint3, "getRetryAfterHint");
    var retryMiddleware3 = /* @__PURE__ */ __name((options) => (next, context) => async (args) => {
      let retryStrategy = await options.retryStrategy();
      const maxAttempts = await options.maxAttempts();
      if (isRetryStrategyV23(retryStrategy)) {
        retryStrategy = retryStrategy;
        let retryToken = await retryStrategy.acquireInitialRetryToken((context["partition_id"] ?? "") + (context.__retryLongPoll ? ":longpoll" : ""));
        let lastError = new Error();
        let attempts = 0;
        let totalRetryDelay = 0;
        const { request: request4 } = args;
        const isRequest = protocolHttp.HttpRequest.isInstance(request4);
        if (isRequest) {
          request4.headers[utilRetry.INVOCATION_ID_HEADER] = uuid.v4();
        }
        while (true) {
          try {
            if (isRequest) {
              request4.headers[utilRetry.REQUEST_HEADER] = `attempt=${attempts + 1}; max=${maxAttempts}`;
            }
            const { response, output } = await next(args);
            retryStrategy.recordSuccess(retryToken);
            output.$metadata.attempts = attempts + 1;
            output.$metadata.totalRetryDelay = totalRetryDelay;
            return { response, output };
          } catch (e32) {
            const retryErrorInfo = getRetryErrorInfo3(e32, options.logger);
            lastError = asSdkError3(e32);
            if (isRequest && isStreamingPayload3.isStreamingPayload(request4)) {
              (context.logger instanceof smithyClient.NoOpLogger ? console : context.logger)?.warn("An error was encountered in a non-retryable streaming request.");
              throw lastError;
            }
            try {
              retryToken = await retryStrategy.refreshRetryTokenForRetry(retryToken, retryErrorInfo);
            } catch (refreshError) {
              if (typeof refreshError.$backoff === "number") {
                await cooldown3(refreshError.$backoff);
              }
              if (!lastError.$metadata) {
                lastError.$metadata = {};
              }
              lastError.$metadata.attempts = attempts + 1;
              lastError.$metadata.totalRetryDelay = totalRetryDelay;
              throw lastError;
            }
            attempts = retryToken.getRetryCount();
            const delay = retryToken.getRetryDelay();
            totalRetryDelay += delay;
            await cooldown3(delay);
          }
        }
      } else {
        retryStrategy = retryStrategy;
        if (retryStrategy?.mode) {
          context.userAgent = [...context.userAgent || [], ["cfg/retry-mode", retryStrategy.mode]];
        }
        return retryStrategy.retry(next, args);
      }
    }, "retryMiddleware");
    var cooldown3 = /* @__PURE__ */ __name((ms) => new Promise((resolve13) => setTimeout(resolve13, ms)), "cooldown");
    var isRetryStrategyV23 = /* @__PURE__ */ __name((retryStrategy) => typeof retryStrategy.acquireInitialRetryToken !== "undefined" && typeof retryStrategy.refreshRetryTokenForRetry !== "undefined" && typeof retryStrategy.recordSuccess !== "undefined", "isRetryStrategyV2");
    var getRetryErrorInfo3 = /* @__PURE__ */ __name((error4, logger5) => {
      const errorInfo = {
        error: error4,
        errorType: getRetryErrorType3(error4)
      };
      const retryAfterHint = parseRetryAfterHeader3(error4.$response, logger5);
      if (retryAfterHint) {
        errorInfo.retryAfterHint = retryAfterHint;
      }
      return errorInfo;
    }, "getRetryErrorInfo");
    var getRetryErrorType3 = /* @__PURE__ */ __name((error4) => {
      if (serviceErrorClassification.isThrottlingError(error4))
        return "THROTTLING";
      if (serviceErrorClassification.isTransientError(error4))
        return "TRANSIENT";
      if (serviceErrorClassification.isServerError(error4))
        return "SERVER_ERROR";
      return "CLIENT_ERROR";
    }, "getRetryErrorType");
    var retryMiddlewareOptions3 = {
      name: "retryMiddleware",
      tags: ["RETRY"],
      step: "finalizeRequest",
      priority: "high",
      override: true
    };
    var getRetryPlugin30 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(retryMiddleware3(options), retryMiddlewareOptions3);
      }, "applyToStack")
    }), "getRetryPlugin");
    exports2.AdaptiveRetryStrategy = AdaptiveRetryStrategy5;
    exports2.CONFIG_MAX_ATTEMPTS = CONFIG_MAX_ATTEMPTS3;
    exports2.CONFIG_RETRY_MODE = CONFIG_RETRY_MODE3;
    exports2.ENV_MAX_ATTEMPTS = ENV_MAX_ATTEMPTS3;
    exports2.ENV_RETRY_MODE = ENV_RETRY_MODE3;
    exports2.NODE_MAX_ATTEMPT_CONFIG_OPTIONS = NODE_MAX_ATTEMPT_CONFIG_OPTIONS30;
    exports2.NODE_RETRY_MODE_CONFIG_OPTIONS = NODE_RETRY_MODE_CONFIG_OPTIONS30;
    exports2.StandardRetryStrategy = StandardRetryStrategy5;
    exports2.defaultDelayDecider = defaultDelayDecider3;
    exports2.defaultRetryDecider = defaultRetryDecider3;
    exports2.getOmitRetryHeadersPlugin = getOmitRetryHeadersPlugin3;
    exports2.getRetryAfterHint = getRetryAfterHint3;
    exports2.getRetryPlugin = getRetryPlugin30;
    exports2.omitRetryHeadersMiddleware = omitRetryHeadersMiddleware3;
    exports2.omitRetryHeadersMiddlewareOptions = omitRetryHeadersMiddlewareOptions3;
    exports2.resolveRetryConfig = resolveRetryConfig30;
    exports2.retryMiddleware = retryMiddleware3;
    exports2.retryMiddlewareOptions = retryMiddlewareOptions3;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getDateHeader.js
var import_protocol_http51, getDateHeader9;
var init_getDateHeader9 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getDateHeader.js"() {
    import_protocol_http51 = __toESM(require_dist_cjs2());
    getDateHeader9 = /* @__PURE__ */ __name((response) => import_protocol_http51.HttpResponse.isInstance(response) ? response.headers?.date ?? response.headers?.Date : void 0, "getDateHeader");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getSkewCorrectedDate.js
var getSkewCorrectedDate9;
var init_getSkewCorrectedDate9 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getSkewCorrectedDate.js"() {
    getSkewCorrectedDate9 = /* @__PURE__ */ __name((systemClockOffset) => new Date(Date.now() + systemClockOffset), "getSkewCorrectedDate");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/isClockSkewed.js
var isClockSkewed9;
var init_isClockSkewed9 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/isClockSkewed.js"() {
    init_getSkewCorrectedDate9();
    isClockSkewed9 = /* @__PURE__ */ __name((clockTime, systemClockOffset) => Math.abs(getSkewCorrectedDate9(systemClockOffset).getTime() - clockTime) >= 3e5, "isClockSkewed");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getUpdatedSystemClockOffset.js
var getUpdatedSystemClockOffset9;
var init_getUpdatedSystemClockOffset9 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getUpdatedSystemClockOffset.js"() {
    init_isClockSkewed9();
    getUpdatedSystemClockOffset9 = /* @__PURE__ */ __name((clockTime, currentSystemClockOffset) => {
      const clockTimeInMs = Date.parse(clockTime);
      if (isClockSkewed9(clockTimeInMs, currentSystemClockOffset)) {
        return clockTimeInMs - Date.now();
      }
      return currentSystemClockOffset;
    }, "getUpdatedSystemClockOffset");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/index.js
var init_utils16 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/index.js"() {
    init_getDateHeader9();
    init_getSkewCorrectedDate9();
    init_getUpdatedSystemClockOffset9();
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4Signer.js
var import_protocol_http52, throwSigningPropertyError9, validateSigningProperties9, AwsSdkSigV4Signer9, AWSSDKSigV4Signer9;
var init_AwsSdkSigV4Signer9 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4Signer.js"() {
    import_protocol_http52 = __toESM(require_dist_cjs2());
    init_utils16();
    throwSigningPropertyError9 = /* @__PURE__ */ __name((name, property) => {
      if (!property) {
        throw new Error(`Property \`${name}\` is not resolved for AWS SDK SigV4Auth`);
      }
      return property;
    }, "throwSigningPropertyError");
    validateSigningProperties9 = /* @__PURE__ */ __name(async (signingProperties) => {
      const context = throwSigningPropertyError9("context", signingProperties.context);
      const config2 = throwSigningPropertyError9("config", signingProperties.config);
      const authScheme = context.endpointV2?.properties?.authSchemes?.[0];
      const signerFunction = throwSigningPropertyError9("signer", config2.signer);
      const signer = await signerFunction(authScheme);
      const signingRegion = signingProperties?.signingRegion;
      const signingRegionSet = signingProperties?.signingRegionSet;
      const signingName = signingProperties?.signingName;
      return {
        config: config2,
        signer,
        signingRegion,
        signingRegionSet,
        signingName
      };
    }, "validateSigningProperties");
    AwsSdkSigV4Signer9 = class {
      static {
        __name(this, "AwsSdkSigV4Signer");
      }
      async sign(httpRequest, identity, signingProperties) {
        if (!import_protocol_http52.HttpRequest.isInstance(httpRequest)) {
          throw new Error("The request is not an instance of `HttpRequest` and cannot be signed");
        }
        const validatedProps = await validateSigningProperties9(signingProperties);
        const { config: config2, signer } = validatedProps;
        let { signingRegion, signingName } = validatedProps;
        const handlerExecutionContext = signingProperties.context;
        if (handlerExecutionContext?.authSchemes?.length ?? 0 > 1) {
          const [first, second] = handlerExecutionContext.authSchemes;
          if (first?.name === "sigv4a" && second?.name === "sigv4") {
            signingRegion = second?.signingRegion ?? signingRegion;
            signingName = second?.signingName ?? signingName;
          }
        }
        const signedRequest = await signer.sign(httpRequest, {
          signingDate: getSkewCorrectedDate9(config2.systemClockOffset),
          signingRegion,
          signingService: signingName
        });
        return signedRequest;
      }
      errorHandler(signingProperties) {
        return (error4) => {
          const serverTime = error4.ServerTime ?? getDateHeader9(error4.$response);
          if (serverTime) {
            const config2 = throwSigningPropertyError9("config", signingProperties.config);
            const initialSystemClockOffset = config2.systemClockOffset;
            config2.systemClockOffset = getUpdatedSystemClockOffset9(serverTime, config2.systemClockOffset);
            const clockSkewCorrected = config2.systemClockOffset !== initialSystemClockOffset;
            if (clockSkewCorrected && error4.$metadata) {
              error4.$metadata.clockSkewCorrected = true;
            }
          }
          throw error4;
        };
      }
      successHandler(httpResponse, signingProperties) {
        const dateHeader = getDateHeader9(httpResponse);
        if (dateHeader) {
          const config2 = throwSigningPropertyError9("config", signingProperties.config);
          config2.systemClockOffset = getUpdatedSystemClockOffset9(dateHeader, config2.systemClockOffset);
        }
      }
    };
    AWSSDKSigV4Signer9 = AwsSdkSigV4Signer9;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4ASigner.js
var import_protocol_http53, AwsSdkSigV4ASigner9;
var init_AwsSdkSigV4ASigner9 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4ASigner.js"() {
    import_protocol_http53 = __toESM(require_dist_cjs2());
    init_utils16();
    init_AwsSdkSigV4Signer9();
    AwsSdkSigV4ASigner9 = class extends AwsSdkSigV4Signer9 {
      static {
        __name(this, "AwsSdkSigV4ASigner");
      }
      async sign(httpRequest, identity, signingProperties) {
        if (!import_protocol_http53.HttpRequest.isInstance(httpRequest)) {
          throw new Error("The request is not an instance of `HttpRequest` and cannot be signed");
        }
        const { config: config2, signer, signingRegion, signingRegionSet, signingName } = await validateSigningProperties9(signingProperties);
        const configResolvedSigningRegionSet = await config2.sigv4aSigningRegionSet?.();
        const multiRegionOverride = (configResolvedSigningRegionSet ?? signingRegionSet ?? [signingRegion]).join(",");
        const signedRequest = await signer.sign(httpRequest, {
          signingDate: getSkewCorrectedDate9(config2.systemClockOffset),
          signingRegion: multiRegionOverride,
          signingService: signingName
        });
        return signedRequest;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getArrayForCommaSeparatedString.js
var getArrayForCommaSeparatedString9;
var init_getArrayForCommaSeparatedString9 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getArrayForCommaSeparatedString.js"() {
    getArrayForCommaSeparatedString9 = /* @__PURE__ */ __name((str) => typeof str === "string" && str.length > 0 ? str.split(",").map((item) => item.trim()) : [], "getArrayForCommaSeparatedString");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getBearerTokenEnvKey.js
var getBearerTokenEnvKey9;
var init_getBearerTokenEnvKey9 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getBearerTokenEnvKey.js"() {
    getBearerTokenEnvKey9 = /* @__PURE__ */ __name((signingName) => `AWS_BEARER_TOKEN_${signingName.replace(/[\s-]/g, "_").toUpperCase()}`, "getBearerTokenEnvKey");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/NODE_AUTH_SCHEME_PREFERENCE_OPTIONS.js
var NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY9, NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY9, NODE_AUTH_SCHEME_PREFERENCE_OPTIONS9;
var init_NODE_AUTH_SCHEME_PREFERENCE_OPTIONS9 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/NODE_AUTH_SCHEME_PREFERENCE_OPTIONS.js"() {
    init_getArrayForCommaSeparatedString9();
    init_getBearerTokenEnvKey9();
    NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY9 = "AWS_AUTH_SCHEME_PREFERENCE";
    NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY9 = "auth_scheme_preference";
    NODE_AUTH_SCHEME_PREFERENCE_OPTIONS9 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3, options) => {
        if (options?.signingName) {
          const bearerTokenKey = getBearerTokenEnvKey9(options.signingName);
          if (bearerTokenKey in env3)
            return ["httpBearerAuth"];
        }
        if (!(NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY9 in env3))
          return void 0;
        return getArrayForCommaSeparatedString9(env3[NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY9]);
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => {
        if (!(NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY9 in profile))
          return void 0;
        return getArrayForCommaSeparatedString9(profile[NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY9]);
      }, "configFileSelector"),
      default: []
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4AConfig.js
var import_property_provider8, resolveAwsSdkSigV4AConfig9, NODE_SIGV4A_CONFIG_OPTIONS9;
var init_resolveAwsSdkSigV4AConfig9 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4AConfig.js"() {
    init_dist_es();
    import_property_provider8 = __toESM(require_dist_cjs27());
    resolveAwsSdkSigV4AConfig9 = /* @__PURE__ */ __name((config2) => {
      config2.sigv4aSigningRegionSet = normalizeProvider(config2.sigv4aSigningRegionSet);
      return config2;
    }, "resolveAwsSdkSigV4AConfig");
    NODE_SIGV4A_CONFIG_OPTIONS9 = {
      environmentVariableSelector(env3) {
        if (env3.AWS_SIGV4A_SIGNING_REGION_SET) {
          return env3.AWS_SIGV4A_SIGNING_REGION_SET.split(",").map((_) => _.trim());
        }
        throw new import_property_provider8.ProviderError("AWS_SIGV4A_SIGNING_REGION_SET not set in env.", {
          tryNextLink: true
        });
      },
      configFileSelector(profile) {
        if (profile.sigv4a_signing_region_set) {
          return (profile.sigv4a_signing_region_set ?? "").split(",").map((_) => _.trim());
        }
        throw new import_property_provider8.ProviderError("sigv4a_signing_region_set not set in profile.", {
          tryNextLink: true
        });
      },
      default: void 0
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4Config.js
function normalizeCredentialProvider9(config2, { credentials, credentialDefaultProvider }) {
  let credentialsProvider;
  if (credentials) {
    if (!credentials?.memoized) {
      credentialsProvider = memoizeIdentityProvider(credentials, isIdentityExpired, doesIdentityRequireRefresh);
    } else {
      credentialsProvider = credentials;
    }
  } else {
    if (credentialDefaultProvider) {
      credentialsProvider = normalizeProvider(credentialDefaultProvider(Object.assign({}, config2, {
        parentClientConfig: config2
      })));
    } else {
      credentialsProvider = /* @__PURE__ */ __name(async () => {
        throw new Error("@aws-sdk/core::resolveAwsSdkSigV4Config - `credentials` not provided and no credentialDefaultProvider was configured.");
      }, "credentialsProvider");
    }
  }
  credentialsProvider.memoized = true;
  return credentialsProvider;
}
function bindCallerConfig9(config2, credentialsProvider) {
  if (credentialsProvider.configBound) {
    return credentialsProvider;
  }
  const fn = /* @__PURE__ */ __name(async (options) => credentialsProvider({ ...options, callerClientConfig: config2 }), "fn");
  fn.memoized = credentialsProvider.memoized;
  fn.configBound = true;
  return fn;
}
var import_signature_v49, resolveAwsSdkSigV4Config9, resolveAWSSDKSigV4Config9;
var init_resolveAwsSdkSigV4Config9 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4Config.js"() {
    init_client18();
    init_dist_es();
    import_signature_v49 = __toESM(require_dist_cjs36());
    resolveAwsSdkSigV4Config9 = /* @__PURE__ */ __name((config2) => {
      let inputCredentials = config2.credentials;
      let isUserSupplied = !!config2.credentials;
      let resolvedCredentials = void 0;
      Object.defineProperty(config2, "credentials", {
        set(credentials) {
          if (credentials && credentials !== inputCredentials && credentials !== resolvedCredentials) {
            isUserSupplied = true;
          }
          inputCredentials = credentials;
          const memoizedProvider = normalizeCredentialProvider9(config2, {
            credentials: inputCredentials,
            credentialDefaultProvider: config2.credentialDefaultProvider
          });
          const boundProvider = bindCallerConfig9(config2, memoizedProvider);
          if (isUserSupplied && !boundProvider.attributed) {
            const isCredentialObject = typeof inputCredentials === "object" && inputCredentials !== null;
            resolvedCredentials = /* @__PURE__ */ __name(async (options) => {
              const creds = await boundProvider(options);
              const attributedCreds = creds;
              if (isCredentialObject && (!attributedCreds.$source || Object.keys(attributedCreds.$source).length === 0)) {
                return setCredentialFeature11(attributedCreds, "CREDENTIALS_CODE", "e");
              }
              return attributedCreds;
            }, "resolvedCredentials");
            resolvedCredentials.memoized = boundProvider.memoized;
            resolvedCredentials.configBound = boundProvider.configBound;
            resolvedCredentials.attributed = true;
          } else {
            resolvedCredentials = boundProvider;
          }
        },
        get() {
          return resolvedCredentials;
        },
        enumerable: true,
        configurable: true
      });
      config2.credentials = inputCredentials;
      const { signingEscapePath = true, systemClockOffset = config2.systemClockOffset || 0, sha256 } = config2;
      let signer;
      if (config2.signer) {
        signer = normalizeProvider(config2.signer);
      } else if (config2.regionInfoProvider) {
        signer = /* @__PURE__ */ __name(() => normalizeProvider(config2.region)().then(async (region) => [
          await config2.regionInfoProvider(region, {
            useFipsEndpoint: await config2.useFipsEndpoint(),
            useDualstackEndpoint: await config2.useDualstackEndpoint()
          }) || {},
          region
        ]).then(([regionInfo, region]) => {
          const { signingRegion, signingService } = regionInfo;
          config2.signingRegion = config2.signingRegion || signingRegion || region;
          config2.signingName = config2.signingName || signingService || config2.serviceId;
          const params = {
            ...config2,
            credentials: config2.credentials,
            region: config2.signingRegion,
            service: config2.signingName,
            sha256,
            uriEscapePath: signingEscapePath
          };
          const SignerCtor = config2.signerConstructor || import_signature_v49.SignatureV4;
          return new SignerCtor(params);
        }), "signer");
      } else {
        signer = /* @__PURE__ */ __name(async (authScheme) => {
          authScheme = Object.assign({}, {
            name: "sigv4",
            signingName: config2.signingName || config2.defaultSigningName,
            signingRegion: await normalizeProvider(config2.region)(),
            properties: {}
          }, authScheme);
          const signingRegion = authScheme.signingRegion;
          const signingService = authScheme.signingName;
          config2.signingRegion = config2.signingRegion || signingRegion;
          config2.signingName = config2.signingName || signingService || config2.serviceId;
          const params = {
            ...config2,
            credentials: config2.credentials,
            region: config2.signingRegion,
            service: config2.signingName,
            sha256,
            uriEscapePath: signingEscapePath
          };
          const SignerCtor = config2.signerConstructor || import_signature_v49.SignatureV4;
          return new SignerCtor(params);
        }, "signer");
      }
      const resolvedConfig = Object.assign(config2, {
        systemClockOffset,
        signingEscapePath,
        signer
      });
      return resolvedConfig;
    }, "resolveAwsSdkSigV4Config");
    resolveAWSSDKSigV4Config9 = resolveAwsSdkSigV4Config9;
    __name(normalizeCredentialProvider9, "normalizeCredentialProvider");
    __name(bindCallerConfig9, "bindCallerConfig");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/index.js
var init_aws_sdk9 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/index.js"() {
    init_AwsSdkSigV4Signer9();
    init_AwsSdkSigV4ASigner9();
    init_NODE_AUTH_SCHEME_PREFERENCE_OPTIONS9();
    init_resolveAwsSdkSigV4AConfig9();
    init_resolveAwsSdkSigV4Config9();
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/index.js
var httpAuthSchemes_exports9 = {};
__export(httpAuthSchemes_exports9, {
  AWSSDKSigV4Signer: () => AWSSDKSigV4Signer9,
  AwsSdkSigV4ASigner: () => AwsSdkSigV4ASigner9,
  AwsSdkSigV4Signer: () => AwsSdkSigV4Signer9,
  NODE_AUTH_SCHEME_PREFERENCE_OPTIONS: () => NODE_AUTH_SCHEME_PREFERENCE_OPTIONS9,
  NODE_SIGV4A_CONFIG_OPTIONS: () => NODE_SIGV4A_CONFIG_OPTIONS9,
  getBearerTokenEnvKey: () => getBearerTokenEnvKey9,
  resolveAWSSDKSigV4Config: () => resolveAWSSDKSigV4Config9,
  resolveAwsSdkSigV4AConfig: () => resolveAwsSdkSigV4AConfig9,
  resolveAwsSdkSigV4Config: () => resolveAwsSdkSigV4Config9,
  validateSigningProperties: () => validateSigningProperties9
});
var init_httpAuthSchemes11 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/index.js"() {
    init_aws_sdk9();
    init_getBearerTokenEnvKey9();
  }
});

// ../../node_modules/@aws-sdk/client-lambda/dist-cjs/auth/httpAuthSchemeProvider.js
var require_httpAuthSchemeProvider16 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/dist-cjs/auth/httpAuthSchemeProvider.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.resolveHttpAuthSchemeConfig = exports2.defaultLambdaHttpAuthSchemeProvider = exports2.defaultLambdaHttpAuthSchemeParametersProvider = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes11(), __toCommonJS(httpAuthSchemes_exports9));
    var util_middleware_1 = require_dist_cjs6();
    var defaultLambdaHttpAuthSchemeParametersProvider = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, util_middleware_1.getSmithyContext)(context).operation,
        region: await (0, util_middleware_1.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultLambdaHttpAuthSchemeParametersProvider");
    exports2.defaultLambdaHttpAuthSchemeParametersProvider = defaultLambdaHttpAuthSchemeParametersProvider;
    function createAwsAuthSigv4HttpAuthOption32(authParameters) {
      return {
        schemeId: "aws.auth#sigv4",
        signingProperties: {
          name: "lambda",
          region: authParameters.region
        },
        propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
          signingProperties: {
            config: config2,
            context
          }
        }), "propertiesExtractor")
      };
    }
    __name(createAwsAuthSigv4HttpAuthOption32, "createAwsAuthSigv4HttpAuthOption");
    var defaultLambdaHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption32(authParameters));
        }
      }
      return options;
    }, "defaultLambdaHttpAuthSchemeProvider");
    exports2.defaultLambdaHttpAuthSchemeProvider = defaultLambdaHttpAuthSchemeProvider;
    var resolveHttpAuthSchemeConfig32 = /* @__PURE__ */ __name((config2) => {
      const config_0 = (0, httpAuthSchemes_1.resolveAwsSdkSigV4Config)(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, util_middleware_1.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
    exports2.resolveHttpAuthSchemeConfig = resolveHttpAuthSchemeConfig32;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/package.json
var require_package16 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/package.json"(exports2, module2) {
    module2.exports = {
      name: "@aws-sdk/client-lambda",
      description: "AWS SDK for JavaScript Lambda Client for Node.js, Browser and React Native",
      version: "3.1045.0",
      scripts: {
        build: "concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline client-lambda",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        "extract:docs": "api-extractor run --local",
        "generate:client": "node ../../scripts/generate-clients/single-service --solo lambda",
        test: "yarn g:vitest run --passWithNoTests",
        "test:e2e": "yarn g:vitest run -c vitest.config.e2e.mts --mode development",
        "test:e2e:watch": "yarn g:vitest watch -c vitest.config.e2e.mts",
        "test:index": "tsc --noEmit ./test/index-types.ts && node ./test/index-objects.spec.mjs",
        "test:integration": "yarn g:vitest run --passWithNoTests -c vitest.config.integ.mts",
        "test:integration:watch": "yarn g:vitest watch --passWithNoTests -c vitest.config.integ.mts",
        "test:watch": "yarn g:vitest watch --passWithNoTests"
      },
      main: "./dist-cjs/index.js",
      types: "./dist-types/index.d.ts",
      module: "./dist-es/index.js",
      sideEffects: false,
      dependencies: {
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.8",
        "@aws-sdk/credential-provider-node": "^3.972.39",
        "@aws-sdk/middleware-host-header": "^3.972.10",
        "@aws-sdk/middleware-logger": "^3.972.10",
        "@aws-sdk/middleware-recursion-detection": "^3.972.11",
        "@aws-sdk/middleware-user-agent": "^3.972.38",
        "@aws-sdk/region-config-resolver": "^3.972.13",
        "@aws-sdk/types": "^3.973.8",
        "@aws-sdk/util-endpoints": "^3.996.8",
        "@aws-sdk/util-user-agent-browser": "^3.972.10",
        "@aws-sdk/util-user-agent-node": "^3.973.24",
        "@smithy/config-resolver": "^4.4.17",
        "@smithy/core": "^3.23.17",
        "@smithy/eventstream-serde-browser": "^4.2.14",
        "@smithy/eventstream-serde-config-resolver": "^4.3.14",
        "@smithy/eventstream-serde-node": "^4.2.14",
        "@smithy/fetch-http-handler": "^5.3.17",
        "@smithy/hash-node": "^4.2.14",
        "@smithy/invalid-dependency": "^4.2.14",
        "@smithy/middleware-content-length": "^4.2.14",
        "@smithy/middleware-endpoint": "^4.4.32",
        "@smithy/middleware-retry": "^4.5.7",
        "@smithy/middleware-serde": "^4.2.20",
        "@smithy/middleware-stack": "^4.2.14",
        "@smithy/node-config-provider": "^4.3.14",
        "@smithy/node-http-handler": "^4.6.1",
        "@smithy/protocol-http": "^5.3.14",
        "@smithy/smithy-client": "^4.12.13",
        "@smithy/types": "^4.14.1",
        "@smithy/url-parser": "^4.2.14",
        "@smithy/util-base64": "^4.3.2",
        "@smithy/util-body-length-browser": "^4.2.2",
        "@smithy/util-body-length-node": "^4.2.3",
        "@smithy/util-defaults-mode-browser": "^4.3.49",
        "@smithy/util-defaults-mode-node": "^4.2.54",
        "@smithy/util-endpoints": "^3.4.2",
        "@smithy/util-middleware": "^4.2.14",
        "@smithy/util-retry": "^4.3.6",
        "@smithy/util-stream": "^4.5.25",
        "@smithy/util-utf8": "^4.2.2",
        "@smithy/util-waiter": "^4.3.0",
        tslib: "^2.6.2"
      },
      devDependencies: {
        "@smithy/snapshot-testing": "^2.0.8",
        "@tsconfig/node20": "20.1.8",
        "@types/node": "^20.14.8",
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3",
        vitest: "^4.0.17"
      },
      engines: {
        node: ">=20.0.0"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "dist-*/**"
      ],
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      browser: {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.browser"
      },
      "react-native": {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.native"
      },
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/clients/client-lambda",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "clients/client-lambda"
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-env/dist-cjs/index.js
var require_dist_cjs182 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-env/dist-cjs/index.js"(exports2) {
    "use strict";
    var client = (init_client18(), __toCommonJS(client_exports13));
    var propertyProvider = require_dist_cjs27();
    var ENV_KEY = "AWS_ACCESS_KEY_ID";
    var ENV_SECRET = "AWS_SECRET_ACCESS_KEY";
    var ENV_SESSION = "AWS_SESSION_TOKEN";
    var ENV_EXPIRATION = "AWS_CREDENTIAL_EXPIRATION";
    var ENV_CREDENTIAL_SCOPE = "AWS_CREDENTIAL_SCOPE";
    var ENV_ACCOUNT_ID = "AWS_ACCOUNT_ID";
    var fromEnv6 = /* @__PURE__ */ __name((init) => async () => {
      init?.logger?.debug("@aws-sdk/credential-provider-env - fromEnv");
      const accessKeyId = process.env[ENV_KEY];
      const secretAccessKey = process.env[ENV_SECRET];
      const sessionToken = process.env[ENV_SESSION];
      const expiry = process.env[ENV_EXPIRATION];
      const credentialScope = process.env[ENV_CREDENTIAL_SCOPE];
      const accountId = process.env[ENV_ACCOUNT_ID];
      if (accessKeyId && secretAccessKey) {
        const credentials = {
          accessKeyId,
          secretAccessKey,
          ...sessionToken && { sessionToken },
          ...expiry && { expiration: new Date(expiry) },
          ...credentialScope && { credentialScope },
          ...accountId && { accountId }
        };
        client.setCredentialFeature(credentials, "CREDENTIALS_ENV_VARS", "g");
        return credentials;
      }
      throw new propertyProvider.CredentialsProviderError("Unable to find environment variable credentials.", { logger: init?.logger });
    }, "fromEnv");
    exports2.ENV_ACCOUNT_ID = ENV_ACCOUNT_ID;
    exports2.ENV_CREDENTIAL_SCOPE = ENV_CREDENTIAL_SCOPE;
    exports2.ENV_EXPIRATION = ENV_EXPIRATION;
    exports2.ENV_KEY = ENV_KEY;
    exports2.ENV_SECRET = ENV_SECRET;
    exports2.ENV_SESSION = ENV_SESSION;
    exports2.fromEnv = fromEnv6;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/checkUrl.js
var require_checkUrl8 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/checkUrl.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.checkUrl = void 0;
    var property_provider_1 = require_dist_cjs27();
    var ECS_CONTAINER_HOST = "169.254.170.2";
    var EKS_CONTAINER_HOST_IPv4 = "169.254.170.23";
    var EKS_CONTAINER_HOST_IPv6 = "[fd00:ec2::23]";
    var checkUrl = /* @__PURE__ */ __name((url, logger5) => {
      if (url.protocol === "https:") {
        return;
      }
      if (url.hostname === ECS_CONTAINER_HOST || url.hostname === EKS_CONTAINER_HOST_IPv4 || url.hostname === EKS_CONTAINER_HOST_IPv6) {
        return;
      }
      if (url.hostname.includes("[")) {
        if (url.hostname === "[::1]" || url.hostname === "[0000:0000:0000:0000:0000:0000:0000:0001]") {
          return;
        }
      } else {
        if (url.hostname === "localhost") {
          return;
        }
        const ipComponents = url.hostname.split(".");
        const inRange = /* @__PURE__ */ __name((component) => {
          const num = parseInt(component, 10);
          return 0 <= num && num <= 255;
        }, "inRange");
        if (ipComponents[0] === "127" && inRange(ipComponents[1]) && inRange(ipComponents[2]) && inRange(ipComponents[3]) && ipComponents.length === 4) {
          return;
        }
      }
      throw new property_provider_1.CredentialsProviderError(`URL not accepted. It must either be HTTPS or match one of the following:
  - loopback CIDR 127.0.0.0/8 or [::1/128]
  - ECS container host 169.254.170.2
  - EKS container host 169.254.170.23 or [fd00:ec2::23]`, { logger: logger5 });
    }, "checkUrl");
    exports2.checkUrl = checkUrl;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.js
var require_ChecksumStream9 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ChecksumStream = void 0;
    var util_base64_1 = require_dist_cjs10();
    var stream_1 = require("stream");
    var ChecksumStream5 = class extends stream_1.Duplex {
      static {
        __name(this, "ChecksumStream");
      }
      expectedChecksum;
      checksumSourceLocation;
      checksum;
      source;
      base64Encoder;
      pendingCallback = null;
      constructor({ expectedChecksum, checksum, source, checksumSourceLocation, base64Encoder }) {
        super();
        if (typeof source.pipe === "function") {
          this.source = source;
        } else {
          throw new Error(`@smithy/util-stream: unsupported source type ${source?.constructor?.name ?? source} in ChecksumStream.`);
        }
        this.base64Encoder = base64Encoder ?? util_base64_1.toBase64;
        this.expectedChecksum = expectedChecksum;
        this.checksum = checksum;
        this.checksumSourceLocation = checksumSourceLocation;
        this.source.pipe(this);
      }
      _read(size) {
        if (this.pendingCallback) {
          const callback = this.pendingCallback;
          this.pendingCallback = null;
          callback();
        }
      }
      _write(chunk, encoding, callback) {
        try {
          this.checksum.update(chunk);
          const canPushMore = this.push(chunk);
          if (!canPushMore) {
            this.pendingCallback = callback;
            return;
          }
        } catch (e32) {
          return callback(e32);
        }
        return callback();
      }
      async _final(callback) {
        try {
          const digest = await this.checksum.digest();
          const received = this.base64Encoder(digest);
          if (this.expectedChecksum !== received) {
            return callback(new Error(`Checksum mismatch: expected "${this.expectedChecksum}" but received "${received}" in response header "${this.checksumSourceLocation}".`));
          }
        } catch (e32) {
          return callback(e32);
        }
        this.push(null);
        return callback();
      }
    };
    exports2.ChecksumStream = ChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/stream-type-check.js
var require_stream_type_check9 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/stream-type-check.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isBlob = exports2.isReadableStream = void 0;
    var isReadableStream6 = /* @__PURE__ */ __name((stream) => typeof ReadableStream === "function" && (stream?.constructor?.name === ReadableStream.name || stream instanceof ReadableStream), "isReadableStream");
    exports2.isReadableStream = isReadableStream6;
    var isBlob3 = /* @__PURE__ */ __name((blob) => {
      return typeof Blob === "function" && (blob?.constructor?.name === Blob.name || blob instanceof Blob);
    }, "isBlob");
    exports2.isBlob = isBlob3;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.browser.js
var require_ChecksumStream_browser9 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ChecksumStream = void 0;
    var ReadableStreamRef3 = typeof ReadableStream === "function" ? ReadableStream : function() {
    };
    var ChecksumStream5 = class extends ReadableStreamRef3 {
      static {
        __name(this, "ChecksumStream");
      }
    };
    exports2.ChecksumStream = ChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.browser.js
var require_createChecksumStream_browser9 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createChecksumStream = void 0;
    var util_base64_1 = require_dist_cjs10();
    var stream_type_check_1 = require_stream_type_check9();
    var ChecksumStream_browser_1 = require_ChecksumStream_browser9();
    var createChecksumStream5 = /* @__PURE__ */ __name(({ expectedChecksum, checksum, source, checksumSourceLocation, base64Encoder }) => {
      if (!(0, stream_type_check_1.isReadableStream)(source)) {
        throw new Error(`@smithy/util-stream: unsupported source type ${source?.constructor?.name ?? source} in ChecksumStream.`);
      }
      const encoder = base64Encoder ?? util_base64_1.toBase64;
      if (typeof TransformStream !== "function") {
        throw new Error("@smithy/util-stream: unable to instantiate ChecksumStream because API unavailable: ReadableStream/TransformStream.");
      }
      const transform = new TransformStream({
        start() {
        },
        async transform(chunk, controller) {
          checksum.update(chunk);
          controller.enqueue(chunk);
        },
        async flush(controller) {
          const digest = await checksum.digest();
          const received = encoder(digest);
          if (expectedChecksum !== received) {
            const error4 = new Error(`Checksum mismatch: expected "${expectedChecksum}" but received "${received}" in response header "${checksumSourceLocation}".`);
            controller.error(error4);
          } else {
            controller.terminate();
          }
        }
      });
      source.pipeThrough(transform);
      const readable = transform.readable;
      Object.setPrototypeOf(readable, ChecksumStream_browser_1.ChecksumStream.prototype);
      return readable;
    }, "createChecksumStream");
    exports2.createChecksumStream = createChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.js
var require_createChecksumStream9 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createChecksumStream = createChecksumStream5;
    var stream_type_check_1 = require_stream_type_check9();
    var ChecksumStream_1 = require_ChecksumStream9();
    var createChecksumStream_browser_1 = require_createChecksumStream_browser9();
    function createChecksumStream5(init) {
      if (typeof ReadableStream === "function" && (0, stream_type_check_1.isReadableStream)(init.source)) {
        return (0, createChecksumStream_browser_1.createChecksumStream)(init);
      }
      return new ChecksumStream_1.ChecksumStream(init);
    }
    __name(createChecksumStream5, "createChecksumStream");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/ByteArrayCollector.js
var require_ByteArrayCollector9 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/ByteArrayCollector.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ByteArrayCollector = void 0;
    var ByteArrayCollector3 = class {
      static {
        __name(this, "ByteArrayCollector");
      }
      allocByteArray;
      byteLength = 0;
      byteArrays = [];
      constructor(allocByteArray) {
        this.allocByteArray = allocByteArray;
      }
      push(byteArray) {
        this.byteArrays.push(byteArray);
        this.byteLength += byteArray.byteLength;
      }
      flush() {
        if (this.byteArrays.length === 1) {
          const bytes = this.byteArrays[0];
          this.reset();
          return bytes;
        }
        const aggregation = this.allocByteArray(this.byteLength);
        let cursor3 = 0;
        for (let i32 = 0; i32 < this.byteArrays.length; ++i32) {
          const bytes = this.byteArrays[i32];
          aggregation.set(bytes, cursor3);
          cursor3 += bytes.byteLength;
        }
        this.reset();
        return aggregation;
      }
      reset() {
        this.byteArrays = [];
        this.byteLength = 0;
      }
    };
    exports2.ByteArrayCollector = ByteArrayCollector3;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadableStream.js
var require_createBufferedReadableStream9 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadableStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createBufferedReadable = void 0;
    exports2.createBufferedReadableStream = createBufferedReadableStream3;
    exports2.merge = merge3;
    exports2.flush = flush3;
    exports2.sizeOf = sizeOf3;
    exports2.modeOf = modeOf3;
    var ByteArrayCollector_1 = require_ByteArrayCollector9();
    function createBufferedReadableStream3(upstream, size, logger5) {
      const reader = upstream.getReader();
      let streamBufferingLoggedWarning = false;
      let bytesSeen = 0;
      const buffers = ["", new ByteArrayCollector_1.ByteArrayCollector((size2) => new Uint8Array(size2))];
      let mode = -1;
      const pull = /* @__PURE__ */ __name(async (controller) => {
        const { value, done } = await reader.read();
        const chunk = value;
        if (done) {
          if (mode !== -1) {
            const remainder = flush3(buffers, mode);
            if (sizeOf3(remainder) > 0) {
              controller.enqueue(remainder);
            }
          }
          controller.close();
        } else {
          const chunkMode = modeOf3(chunk, false);
          if (mode !== chunkMode) {
            if (mode >= 0) {
              controller.enqueue(flush3(buffers, mode));
            }
            mode = chunkMode;
          }
          if (mode === -1) {
            controller.enqueue(chunk);
            return;
          }
          const chunkSize = sizeOf3(chunk);
          bytesSeen += chunkSize;
          const bufferSize = sizeOf3(buffers[mode]);
          if (chunkSize >= size && bufferSize === 0) {
            controller.enqueue(chunk);
          } else {
            const newSize = merge3(buffers, mode, chunk);
            if (!streamBufferingLoggedWarning && bytesSeen > size * 2) {
              streamBufferingLoggedWarning = true;
              logger5?.warn(`@smithy/util-stream - stream chunk size ${chunkSize} is below threshold of ${size}, automatically buffering.`);
            }
            if (newSize >= size) {
              controller.enqueue(flush3(buffers, mode));
            } else {
              await pull(controller);
            }
          }
        }
      }, "pull");
      return new ReadableStream({
        pull
      });
    }
    __name(createBufferedReadableStream3, "createBufferedReadableStream");
    exports2.createBufferedReadable = createBufferedReadableStream3;
    function merge3(buffers, mode, chunk) {
      switch (mode) {
        case 0:
          buffers[0] += chunk;
          return sizeOf3(buffers[0]);
        case 1:
        case 2:
          buffers[mode].push(chunk);
          return sizeOf3(buffers[mode]);
      }
    }
    __name(merge3, "merge");
    function flush3(buffers, mode) {
      switch (mode) {
        case 0:
          const s = buffers[0];
          buffers[0] = "";
          return s;
        case 1:
        case 2:
          return buffers[mode].flush();
      }
      throw new Error(`@smithy/util-stream - invalid index ${mode} given to flush()`);
    }
    __name(flush3, "flush");
    function sizeOf3(chunk) {
      return chunk?.byteLength ?? chunk?.length ?? 0;
    }
    __name(sizeOf3, "sizeOf");
    function modeOf3(chunk, allowBuffer = true) {
      if (allowBuffer && typeof Buffer !== "undefined" && chunk instanceof Buffer) {
        return 2;
      }
      if (chunk instanceof Uint8Array) {
        return 1;
      }
      if (typeof chunk === "string") {
        return 0;
      }
      return -1;
    }
    __name(modeOf3, "modeOf");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadable.js
var require_createBufferedReadable9 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadable.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createBufferedReadable = createBufferedReadable3;
    var node_stream_1 = require("node:stream");
    var ByteArrayCollector_1 = require_ByteArrayCollector9();
    var createBufferedReadableStream_1 = require_createBufferedReadableStream9();
    var stream_type_check_1 = require_stream_type_check9();
    function createBufferedReadable3(upstream, size, logger5) {
      if ((0, stream_type_check_1.isReadableStream)(upstream)) {
        return (0, createBufferedReadableStream_1.createBufferedReadableStream)(upstream, size, logger5);
      }
      const downstream = new node_stream_1.Readable({ read() {
      } });
      let streamBufferingLoggedWarning = false;
      let bytesSeen = 0;
      const buffers = [
        "",
        new ByteArrayCollector_1.ByteArrayCollector((size2) => new Uint8Array(size2)),
        new ByteArrayCollector_1.ByteArrayCollector((size2) => Buffer.from(new Uint8Array(size2)))
      ];
      let mode = -1;
      upstream.on("data", (chunk) => {
        const chunkMode = (0, createBufferedReadableStream_1.modeOf)(chunk, true);
        if (mode !== chunkMode) {
          if (mode >= 0) {
            downstream.push((0, createBufferedReadableStream_1.flush)(buffers, mode));
          }
          mode = chunkMode;
        }
        if (mode === -1) {
          downstream.push(chunk);
          return;
        }
        const chunkSize = (0, createBufferedReadableStream_1.sizeOf)(chunk);
        bytesSeen += chunkSize;
        const bufferSize = (0, createBufferedReadableStream_1.sizeOf)(buffers[mode]);
        if (chunkSize >= size && bufferSize === 0) {
          downstream.push(chunk);
        } else {
          const newSize = (0, createBufferedReadableStream_1.merge)(buffers, mode, chunk);
          if (!streamBufferingLoggedWarning && bytesSeen > size * 2) {
            streamBufferingLoggedWarning = true;
            logger5?.warn(`@smithy/util-stream - stream chunk size ${chunkSize} is below threshold of ${size}, automatically buffering.`);
          }
          if (newSize >= size) {
            downstream.push((0, createBufferedReadableStream_1.flush)(buffers, mode));
          }
        }
      });
      upstream.on("end", () => {
        if (mode !== -1) {
          const remainder = (0, createBufferedReadableStream_1.flush)(buffers, mode);
          if ((0, createBufferedReadableStream_1.sizeOf)(remainder) > 0) {
            downstream.push(remainder);
          }
        }
        downstream.push(null);
      });
      return downstream;
    }
    __name(createBufferedReadable3, "createBufferedReadable");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.browser.js
var require_getAwsChunkedEncodingStream_browser9 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getAwsChunkedEncodingStream = void 0;
    var getAwsChunkedEncodingStream5 = /* @__PURE__ */ __name((readableStream, options) => {
      const { base64Encoder, bodyLengthChecker, checksumAlgorithmFn, checksumLocationName, streamHasher } = options;
      const checksumRequired = base64Encoder !== void 0 && bodyLengthChecker !== void 0 && checksumAlgorithmFn !== void 0 && checksumLocationName !== void 0 && streamHasher !== void 0;
      const digest = checksumRequired ? streamHasher(checksumAlgorithmFn, readableStream) : void 0;
      const reader = readableStream.getReader();
      return new ReadableStream({
        async pull(controller) {
          const { value, done } = await reader.read();
          if (done) {
            controller.enqueue(`0\r
`);
            if (checksumRequired) {
              const checksum = base64Encoder(await digest);
              controller.enqueue(`${checksumLocationName}:${checksum}\r
`);
              controller.enqueue(`\r
`);
            }
            controller.close();
          } else {
            controller.enqueue(`${(bodyLengthChecker(value) || 0).toString(16)}\r
${value}\r
`);
          }
        }
      });
    }, "getAwsChunkedEncodingStream");
    exports2.getAwsChunkedEncodingStream = getAwsChunkedEncodingStream5;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.js
var require_getAwsChunkedEncodingStream9 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getAwsChunkedEncodingStream = getAwsChunkedEncodingStream5;
    var node_stream_1 = require("node:stream");
    var getAwsChunkedEncodingStream_browser_1 = require_getAwsChunkedEncodingStream_browser9();
    var stream_type_check_1 = require_stream_type_check9();
    function getAwsChunkedEncodingStream5(stream, options) {
      const readable = stream;
      const readableStream = stream;
      if ((0, stream_type_check_1.isReadableStream)(readableStream)) {
        return (0, getAwsChunkedEncodingStream_browser_1.getAwsChunkedEncodingStream)(readableStream, options);
      }
      const { base64Encoder, bodyLengthChecker, checksumAlgorithmFn, checksumLocationName, streamHasher } = options;
      const checksumRequired = base64Encoder !== void 0 && checksumAlgorithmFn !== void 0 && checksumLocationName !== void 0 && streamHasher !== void 0;
      const digest = checksumRequired ? streamHasher(checksumAlgorithmFn, readable) : void 0;
      const awsChunkedEncodingStream = new node_stream_1.Readable({
        read: /* @__PURE__ */ __name(() => {
        }, "read")
      });
      readable.on("data", (data3) => {
        const length = bodyLengthChecker(data3) || 0;
        if (length === 0) {
          return;
        }
        awsChunkedEncodingStream.push(`${length.toString(16)}\r
`);
        awsChunkedEncodingStream.push(data3);
        awsChunkedEncodingStream.push("\r\n");
      });
      readable.on("end", async () => {
        awsChunkedEncodingStream.push(`0\r
`);
        if (checksumRequired) {
          const checksum = base64Encoder(await digest);
          awsChunkedEncodingStream.push(`${checksumLocationName}:${checksum}\r
`);
          awsChunkedEncodingStream.push(`\r
`);
        }
        awsChunkedEncodingStream.push(null);
      });
      return awsChunkedEncodingStream;
    }
    __name(getAwsChunkedEncodingStream5, "getAwsChunkedEncodingStream");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/headStream.browser.js
var require_headStream_browser9 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/headStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.headStream = headStream5;
    async function headStream5(stream, bytes) {
      let byteLengthCounter = 0;
      const chunks2 = [];
      const reader = stream.getReader();
      let isDone = false;
      while (!isDone) {
        const { done, value } = await reader.read();
        if (value) {
          chunks2.push(value);
          byteLengthCounter += value?.byteLength ?? 0;
        }
        if (byteLengthCounter >= bytes) {
          break;
        }
        isDone = done;
      }
      reader.releaseLock();
      const collected = new Uint8Array(Math.min(bytes, byteLengthCounter));
      let offset = 0;
      for (const chunk of chunks2) {
        if (chunk.byteLength > collected.byteLength - offset) {
          collected.set(chunk.subarray(0, collected.byteLength - offset), offset);
          break;
        } else {
          collected.set(chunk, offset);
        }
        offset += chunk.length;
      }
      return collected;
    }
    __name(headStream5, "headStream");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/headStream.js
var require_headStream9 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/headStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.headStream = void 0;
    var stream_1 = require("stream");
    var headStream_browser_1 = require_headStream_browser9();
    var stream_type_check_1 = require_stream_type_check9();
    var headStream5 = /* @__PURE__ */ __name((stream, bytes) => {
      if ((0, stream_type_check_1.isReadableStream)(stream)) {
        return (0, headStream_browser_1.headStream)(stream, bytes);
      }
      return new Promise((resolve13, reject) => {
        const collector = new Collector8();
        collector.limit = bytes;
        stream.pipe(collector);
        stream.on("error", (err) => {
          collector.end();
          reject(err);
        });
        collector.on("error", reject);
        collector.on("finish", function() {
          const bytes2 = new Uint8Array(Buffer.concat(this.buffers));
          resolve13(bytes2);
        });
      });
    }, "headStream");
    exports2.headStream = headStream5;
    var Collector8 = class extends stream_1.Writable {
      static {
        __name(this, "Collector");
      }
      buffers = [];
      limit = Infinity;
      bytesBuffered = 0;
      _write(chunk, encoding, callback) {
        this.buffers.push(chunk);
        this.bytesBuffered += chunk.byteLength ?? 0;
        if (this.bytesBuffered >= this.limit) {
          const excess = this.bytesBuffered - this.limit;
          const tailBuffer = this.buffers[this.buffers.length - 1];
          this.buffers[this.buffers.length - 1] = tailBuffer.subarray(0, tailBuffer.byteLength - excess);
          this.emit("finish");
        }
        callback();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.browser.js
var require_sdk_stream_mixin_browser9 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.sdkStreamMixin = void 0;
    var fetch_http_handler_1 = require_dist_cjs14();
    var util_base64_1 = require_dist_cjs10();
    var util_hex_encoding_1 = require_dist_cjs15();
    var util_utf8_1 = require_dist_cjs9();
    var stream_type_check_1 = require_stream_type_check9();
    var ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11 = "The stream has already been transformed.";
    var sdkStreamMixin12 = /* @__PURE__ */ __name((stream) => {
      if (!isBlobInstance6(stream) && !(0, stream_type_check_1.isReadableStream)(stream)) {
        const name = stream?.__proto__?.constructor?.name || stream;
        throw new Error(`Unexpected stream implementation, expect Blob or ReadableStream, got ${name}`);
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
        }
        transformed = true;
        return await (0, fetch_http_handler_1.streamCollector)(stream);
      }, "transformToByteArray");
      const blobToWebStream = /* @__PURE__ */ __name((blob) => {
        if (typeof blob.stream !== "function") {
          throw new Error("Cannot transform payload Blob to web stream. Please make sure the Blob.stream() is polyfilled.\nIf you are using React Native, this API is not yet supported, see: https://react-native.canny.io/feature-requests/p/fetch-streaming-body");
        }
        return blob.stream();
      }, "blobToWebStream");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === "base64") {
            return (0, util_base64_1.toBase64)(buf);
          } else if (encoding === "hex") {
            return (0, util_hex_encoding_1.toHex)(buf);
          } else if (encoding === void 0 || encoding === "utf8" || encoding === "utf-8") {
            return (0, util_utf8_1.toUtf8)(buf);
          } else if (typeof TextDecoder === "function") {
            return new TextDecoder(encoding).decode(buf);
          } else {
            throw new Error("TextDecoder is not available, please make sure polyfill is provided.");
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
          }
          transformed = true;
          if (isBlobInstance6(stream)) {
            return blobToWebStream(stream);
          } else if ((0, stream_type_check_1.isReadableStream)(stream)) {
            return stream;
          } else {
            throw new Error(`Cannot transform payload to web stream, got ${stream}`);
          }
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
    exports2.sdkStreamMixin = sdkStreamMixin12;
    var isBlobInstance6 = /* @__PURE__ */ __name((stream) => typeof Blob === "function" && stream instanceof Blob, "isBlobInstance");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.js
var require_sdk_stream_mixin9 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.sdkStreamMixin = void 0;
    var node_http_handler_1 = require_dist_cjs13();
    var util_buffer_from_1 = require_dist_cjs8();
    var stream_1 = require("stream");
    var sdk_stream_mixin_browser_1 = require_sdk_stream_mixin_browser9();
    var ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11 = "The stream has already been transformed.";
    var sdkStreamMixin12 = /* @__PURE__ */ __name((stream) => {
      if (!(stream instanceof stream_1.Readable)) {
        try {
          return (0, sdk_stream_mixin_browser_1.sdkStreamMixin)(stream);
        } catch (e32) {
          const name = stream?.__proto__?.constructor?.name || stream;
          throw new Error(`Unexpected stream implementation, expect Stream.Readable instance, got ${name}`);
        }
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
        }
        transformed = true;
        return await (0, node_http_handler_1.streamCollector)(stream);
      }, "transformToByteArray");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === void 0 || Buffer.isEncoding(encoding)) {
            return (0, util_buffer_from_1.fromArrayBuffer)(buf.buffer, buf.byteOffset, buf.byteLength).toString(encoding);
          } else {
            const decoder = new TextDecoder(encoding);
            return decoder.decode(buf);
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
          }
          if (stream.readableFlowing !== null) {
            throw new Error("The stream has been consumed by other callbacks.");
          }
          if (typeof stream_1.Readable.toWeb !== "function") {
            throw new Error("Readable.toWeb() is not supported. Please ensure a polyfill is available.");
          }
          transformed = true;
          return stream_1.Readable.toWeb(stream);
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
    exports2.sdkStreamMixin = sdkStreamMixin12;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/splitStream.browser.js
var require_splitStream_browser9 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/splitStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.splitStream = splitStream5;
    async function splitStream5(stream) {
      if (typeof stream.stream === "function") {
        stream = stream.stream();
      }
      const readableStream = stream;
      return readableStream.tee();
    }
    __name(splitStream5, "splitStream");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/splitStream.js
var require_splitStream9 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/splitStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.splitStream = splitStream5;
    var stream_1 = require("stream");
    var splitStream_browser_1 = require_splitStream_browser9();
    var stream_type_check_1 = require_stream_type_check9();
    async function splitStream5(stream) {
      if ((0, stream_type_check_1.isReadableStream)(stream) || (0, stream_type_check_1.isBlob)(stream)) {
        return (0, splitStream_browser_1.splitStream)(stream);
      }
      const stream1 = new stream_1.PassThrough();
      const stream2 = new stream_1.PassThrough();
      stream.pipe(stream1);
      stream.pipe(stream2);
      return [stream1, stream2];
    }
    __name(splitStream5, "splitStream");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/index.js
var require_dist_cjs183 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-stream/dist-cjs/index.js"(exports2) {
    "use strict";
    var utilBase64 = require_dist_cjs10();
    var utilUtf8 = require_dist_cjs9();
    var ChecksumStream5 = require_ChecksumStream9();
    var createChecksumStream5 = require_createChecksumStream9();
    var createBufferedReadable3 = require_createBufferedReadable9();
    var getAwsChunkedEncodingStream5 = require_getAwsChunkedEncodingStream9();
    var headStream5 = require_headStream9();
    var sdkStreamMixin12 = require_sdk_stream_mixin9();
    var splitStream5 = require_splitStream9();
    var streamTypeCheck = require_stream_type_check9();
    var Uint8ArrayBlobAdapter8 = class _Uint8ArrayBlobAdapter extends Uint8Array {
      static {
        __name(this, "Uint8ArrayBlobAdapter");
      }
      static fromString(source, encoding = "utf-8") {
        if (typeof source === "string") {
          if (encoding === "base64") {
            return _Uint8ArrayBlobAdapter.mutate(utilBase64.fromBase64(source));
          }
          return _Uint8ArrayBlobAdapter.mutate(utilUtf8.fromUtf8(source));
        }
        throw new Error(`Unsupported conversion from ${typeof source} to Uint8ArrayBlobAdapter.`);
      }
      static mutate(source) {
        Object.setPrototypeOf(source, _Uint8ArrayBlobAdapter.prototype);
        return source;
      }
      transformToString(encoding = "utf-8") {
        if (encoding === "base64") {
          return utilBase64.toBase64(this);
        }
        return utilUtf8.toUtf8(this);
      }
    };
    exports2.isBlob = streamTypeCheck.isBlob;
    exports2.isReadableStream = streamTypeCheck.isReadableStream;
    exports2.Uint8ArrayBlobAdapter = Uint8ArrayBlobAdapter8;
    Object.prototype.hasOwnProperty.call(ChecksumStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: ChecksumStream5["__proto__"]
    });
    Object.keys(ChecksumStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = ChecksumStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(createChecksumStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: createChecksumStream5["__proto__"]
    });
    Object.keys(createChecksumStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = createChecksumStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(createBufferedReadable3, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: createBufferedReadable3["__proto__"]
    });
    Object.keys(createBufferedReadable3).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = createBufferedReadable3[k32];
    });
    Object.prototype.hasOwnProperty.call(getAwsChunkedEncodingStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: getAwsChunkedEncodingStream5["__proto__"]
    });
    Object.keys(getAwsChunkedEncodingStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = getAwsChunkedEncodingStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(headStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: headStream5["__proto__"]
    });
    Object.keys(headStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = headStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(sdkStreamMixin12, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: sdkStreamMixin12["__proto__"]
    });
    Object.keys(sdkStreamMixin12).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = sdkStreamMixin12[k32];
    });
    Object.prototype.hasOwnProperty.call(splitStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: splitStream5["__proto__"]
    });
    Object.keys(splitStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = splitStream5[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/requestHelpers.js
var require_requestHelpers8 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/requestHelpers.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createGetRequest = createGetRequest;
    exports2.getCredentials = getCredentials;
    var property_provider_1 = require_dist_cjs27();
    var protocol_http_1 = require_dist_cjs2();
    var smithy_client_1 = require_dist_cjs34();
    var util_stream_1 = require_dist_cjs183();
    function createGetRequest(url) {
      return new protocol_http_1.HttpRequest({
        protocol: url.protocol,
        hostname: url.hostname,
        port: Number(url.port),
        path: url.pathname,
        query: Array.from(url.searchParams.entries()).reduce((acc, [k32, v]) => {
          acc[k32] = v;
          return acc;
        }, {}),
        fragment: url.hash
      });
    }
    __name(createGetRequest, "createGetRequest");
    async function getCredentials(response, logger5) {
      const stream = (0, util_stream_1.sdkStreamMixin)(response.body);
      const str = await stream.transformToString();
      if (response.statusCode === 200) {
        const parsed = JSON.parse(str);
        if (typeof parsed.AccessKeyId !== "string" || typeof parsed.SecretAccessKey !== "string" || typeof parsed.Token !== "string" || typeof parsed.Expiration !== "string") {
          throw new property_provider_1.CredentialsProviderError("HTTP credential provider response not of the required format, an object matching: { AccessKeyId: string, SecretAccessKey: string, Token: string, Expiration: string(rfc3339) }", { logger: logger5 });
        }
        return {
          accessKeyId: parsed.AccessKeyId,
          secretAccessKey: parsed.SecretAccessKey,
          sessionToken: parsed.Token,
          expiration: (0, smithy_client_1.parseRfc3339DateTime)(parsed.Expiration)
        };
      }
      if (response.statusCode >= 400 && response.statusCode < 500) {
        let parsedBody = {};
        try {
          parsedBody = JSON.parse(str);
        } catch (e32) {
        }
        throw Object.assign(new property_provider_1.CredentialsProviderError(`Server responded with status: ${response.statusCode}`, { logger: logger5 }), {
          Code: parsedBody.Code,
          Message: parsedBody.Message
        });
      }
      throw new property_provider_1.CredentialsProviderError(`Server responded with status: ${response.statusCode}`, { logger: logger5 });
    }
    __name(getCredentials, "getCredentials");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/retry-wrapper.js
var require_retry_wrapper8 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/retry-wrapper.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.retryWrapper = void 0;
    var retryWrapper = /* @__PURE__ */ __name((toRetry, maxRetries, delayMs) => {
      return async () => {
        for (let i32 = 0; i32 < maxRetries; ++i32) {
          try {
            return await toRetry();
          } catch (e32) {
            await new Promise((resolve13) => setTimeout(resolve13, delayMs));
          }
        }
        return await toRetry();
      };
    }, "retryWrapper");
    exports2.retryWrapper = retryWrapper;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/fromHttp.js
var require_fromHttp8 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/fromHttp.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromHttp = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var client_1 = (init_client18(), __toCommonJS(client_exports13));
    var node_http_handler_1 = require_dist_cjs13();
    var property_provider_1 = require_dist_cjs27();
    var promises_1 = tslib_1.__importDefault(require("node:fs/promises"));
    var checkUrl_1 = require_checkUrl8();
    var requestHelpers_1 = require_requestHelpers8();
    var retry_wrapper_1 = require_retry_wrapper8();
    var AWS_CONTAINER_CREDENTIALS_RELATIVE_URI = "AWS_CONTAINER_CREDENTIALS_RELATIVE_URI";
    var DEFAULT_LINK_LOCAL_HOST = "http://169.254.170.2";
    var AWS_CONTAINER_CREDENTIALS_FULL_URI = "AWS_CONTAINER_CREDENTIALS_FULL_URI";
    var AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE = "AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE";
    var AWS_CONTAINER_AUTHORIZATION_TOKEN = "AWS_CONTAINER_AUTHORIZATION_TOKEN";
    var fromHttp = /* @__PURE__ */ __name((options = {}) => {
      options.logger?.debug("@aws-sdk/credential-provider-http - fromHttp");
      let host;
      const relative5 = options.awsContainerCredentialsRelativeUri ?? process.env[AWS_CONTAINER_CREDENTIALS_RELATIVE_URI];
      const full = options.awsContainerCredentialsFullUri ?? process.env[AWS_CONTAINER_CREDENTIALS_FULL_URI];
      const token = options.awsContainerAuthorizationToken ?? process.env[AWS_CONTAINER_AUTHORIZATION_TOKEN];
      const tokenFile = options.awsContainerAuthorizationTokenFile ?? process.env[AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE];
      const warn2 = options.logger?.constructor?.name === "NoOpLogger" || !options.logger?.warn ? console.warn : options.logger.warn.bind(options.logger);
      if (relative5 && full) {
        warn2("@aws-sdk/credential-provider-http: you have set both awsContainerCredentialsRelativeUri and awsContainerCredentialsFullUri.");
        warn2("awsContainerCredentialsFullUri will take precedence.");
      }
      if (token && tokenFile) {
        warn2("@aws-sdk/credential-provider-http: you have set both awsContainerAuthorizationToken and awsContainerAuthorizationTokenFile.");
        warn2("awsContainerAuthorizationToken will take precedence.");
      }
      if (full) {
        host = full;
      } else if (relative5) {
        host = `${DEFAULT_LINK_LOCAL_HOST}${relative5}`;
      } else {
        throw new property_provider_1.CredentialsProviderError(`No HTTP credential provider host provided.
Set AWS_CONTAINER_CREDENTIALS_FULL_URI or AWS_CONTAINER_CREDENTIALS_RELATIVE_URI.`, { logger: options.logger });
      }
      const url = new URL(host);
      (0, checkUrl_1.checkUrl)(url, options.logger);
      const requestHandler = node_http_handler_1.NodeHttpHandler.create({
        requestTimeout: options.timeout ?? 1e3,
        connectionTimeout: options.timeout ?? 1e3
      });
      return (0, retry_wrapper_1.retryWrapper)(async () => {
        const request4 = (0, requestHelpers_1.createGetRequest)(url);
        if (token) {
          request4.headers.Authorization = token;
        } else if (tokenFile) {
          request4.headers.Authorization = (await promises_1.default.readFile(tokenFile)).toString();
        }
        try {
          const result2 = await requestHandler.handle(request4);
          return (0, requestHelpers_1.getCredentials)(result2.response).then((creds) => (0, client_1.setCredentialFeature)(creds, "CREDENTIALS_HTTP", "z"));
        } catch (e32) {
          throw new property_provider_1.CredentialsProviderError(String(e32), { logger: options.logger });
        }
      }, options.maxRetries ?? 3, options.timeout ?? 1e3);
    }, "fromHttp");
    exports2.fromHttp = fromHttp;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-http/dist-cjs/index.js
var require_dist_cjs184 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-http/dist-cjs/index.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromHttp = void 0;
    var fromHttp_1 = require_fromHttp8();
    Object.defineProperty(exports2, "fromHttp", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return fromHttp_1.fromHttp;
    }, "get") });
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption26(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "awsssoportal",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption26(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var import_util_middleware27, defaultSSOHttpAuthSchemeParametersProvider8, defaultSSOHttpAuthSchemeProvider8, resolveHttpAuthSchemeConfig26;
var init_httpAuthSchemeProvider26 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes11();
    import_util_middleware27 = __toESM(require_dist_cjs6());
    defaultSSOHttpAuthSchemeParametersProvider8 = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, import_util_middleware27.getSmithyContext)(context).operation,
        region: await (0, import_util_middleware27.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultSSOHttpAuthSchemeParametersProvider");
    __name(createAwsAuthSigv4HttpAuthOption26, "createAwsAuthSigv4HttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption26, "createSmithyApiNoAuthHttpAuthOption");
    defaultSSOHttpAuthSchemeProvider8 = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "GetRoleCredentials": {
          options.push(createSmithyApiNoAuthHttpAuthOption26(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption26(authParameters));
        }
      }
      return options;
    }, "defaultSSOHttpAuthSchemeProvider");
    resolveHttpAuthSchemeConfig26 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveAwsSdkSigV4Config9(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, import_util_middleware27.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/EndpointParameters.js
var resolveClientEndpointParameters26, commonParams26;
var init_EndpointParameters26 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters26 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "awsssoportal"
      });
    }, "resolveClientEndpointParameters");
    commonParams26 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/package.json
var package_default9;
var init_package9 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/package.json"() {
    package_default9 = {
      name: "@aws-sdk/nested-clients",
      version: "3.997.6",
      description: "Nested clients for AWS SDK packages.",
      main: "./dist-cjs/index.js",
      module: "./dist-es/index.js",
      types: "./dist-types/index.d.ts",
      scripts: {
        build: "yarn lint && concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline nested-clients",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        lint: "node ../../scripts/validation/submodules-linter.js --pkg nested-clients",
        test: "yarn g:vitest run",
        "test:watch": "yarn g:vitest watch"
      },
      engines: {
        node: ">=20.0.0"
      },
      sideEffects: false,
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      dependencies: {
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.8",
        "@aws-sdk/middleware-host-header": "^3.972.10",
        "@aws-sdk/middleware-logger": "^3.972.10",
        "@aws-sdk/middleware-recursion-detection": "^3.972.11",
        "@aws-sdk/middleware-user-agent": "^3.972.38",
        "@aws-sdk/region-config-resolver": "^3.972.13",
        "@aws-sdk/signature-v4-multi-region": "^3.996.25",
        "@aws-sdk/types": "^3.973.8",
        "@aws-sdk/util-endpoints": "^3.996.8",
        "@aws-sdk/util-user-agent-browser": "^3.972.10",
        "@aws-sdk/util-user-agent-node": "^3.973.24",
        "@smithy/config-resolver": "^4.4.17",
        "@smithy/core": "^3.23.17",
        "@smithy/fetch-http-handler": "^5.3.17",
        "@smithy/hash-node": "^4.2.14",
        "@smithy/invalid-dependency": "^4.2.14",
        "@smithy/middleware-content-length": "^4.2.14",
        "@smithy/middleware-endpoint": "^4.4.32",
        "@smithy/middleware-retry": "^4.5.7",
        "@smithy/middleware-serde": "^4.2.20",
        "@smithy/middleware-stack": "^4.2.14",
        "@smithy/node-config-provider": "^4.3.14",
        "@smithy/node-http-handler": "^4.6.1",
        "@smithy/protocol-http": "^5.3.14",
        "@smithy/smithy-client": "^4.12.13",
        "@smithy/types": "^4.14.1",
        "@smithy/url-parser": "^4.2.14",
        "@smithy/util-base64": "^4.3.2",
        "@smithy/util-body-length-browser": "^4.2.2",
        "@smithy/util-body-length-node": "^4.2.3",
        "@smithy/util-defaults-mode-browser": "^4.3.49",
        "@smithy/util-defaults-mode-node": "^4.2.54",
        "@smithy/util-endpoints": "^3.4.2",
        "@smithy/util-middleware": "^4.2.14",
        "@smithy/util-retry": "^4.3.6",
        "@smithy/util-utf8": "^4.2.2",
        tslib: "^2.6.2"
      },
      devDependencies: {
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "./cognito-identity.d.ts",
        "./cognito-identity.js",
        "./signin.d.ts",
        "./signin.js",
        "./sso-oidc.d.ts",
        "./sso-oidc.js",
        "./sso.d.ts",
        "./sso.js",
        "./sts.d.ts",
        "./sts.js",
        "dist-*/**"
      ],
      browser: {
        "./dist-es/submodules/cognito-identity/runtimeConfig": "./dist-es/submodules/cognito-identity/runtimeConfig.browser",
        "./dist-es/submodules/signin/runtimeConfig": "./dist-es/submodules/signin/runtimeConfig.browser",
        "./dist-es/submodules/sso-oidc/runtimeConfig": "./dist-es/submodules/sso-oidc/runtimeConfig.browser",
        "./dist-es/submodules/sso/runtimeConfig": "./dist-es/submodules/sso/runtimeConfig.browser",
        "./dist-es/submodules/sts/runtimeConfig": "./dist-es/submodules/sts/runtimeConfig.browser"
      },
      "react-native": {},
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/packages/nested-clients",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "packages/nested-clients"
      },
      exports: {
        "./package.json": "./package.json",
        "./sso-oidc": {
          types: "./dist-types/submodules/sso-oidc/index.d.ts",
          module: "./dist-es/submodules/sso-oidc/index.js",
          node: "./dist-cjs/submodules/sso-oidc/index.js",
          import: "./dist-es/submodules/sso-oidc/index.js",
          require: "./dist-cjs/submodules/sso-oidc/index.js"
        },
        "./sts": {
          types: "./dist-types/submodules/sts/index.d.ts",
          module: "./dist-es/submodules/sts/index.js",
          node: "./dist-cjs/submodules/sts/index.js",
          import: "./dist-es/submodules/sts/index.js",
          require: "./dist-cjs/submodules/sts/index.js"
        },
        "./signin": {
          types: "./dist-types/submodules/signin/index.d.ts",
          module: "./dist-es/submodules/signin/index.js",
          node: "./dist-cjs/submodules/signin/index.js",
          import: "./dist-es/submodules/signin/index.js",
          require: "./dist-cjs/submodules/signin/index.js"
        },
        "./cognito-identity": {
          types: "./dist-types/submodules/cognito-identity/index.d.ts",
          module: "./dist-es/submodules/cognito-identity/index.js",
          node: "./dist-cjs/submodules/cognito-identity/index.js",
          import: "./dist-es/submodules/cognito-identity/index.js",
          require: "./dist-cjs/submodules/cognito-identity/index.js"
        },
        "./sso": {
          types: "./dist-types/submodules/sso/index.d.ts",
          module: "./dist-es/submodules/sso/index.js",
          node: "./dist-cjs/submodules/sso/index.js",
          import: "./dist-es/submodules/sso/index.js",
          require: "./dist-cjs/submodules/sso/index.js"
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/util-user-agent-node/dist-cjs/index.js
var require_dist_cjs185 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/util-user-agent-node/dist-cjs/index.js"(exports2) {
    "use strict";
    var node_os = require("node:os");
    var node_process = require("node:process");
    var utilConfigProvider = require_dist_cjs24();
    var promises5 = require("node:fs/promises");
    var node_path = require("node:path");
    var middlewareUserAgent = require_dist_cjs180();
    var getRuntimeUserAgentPair2 = /* @__PURE__ */ __name(() => {
      const runtimesToCheck = ["deno", "bun", "llrt"];
      for (const runtime of runtimesToCheck) {
        if (node_process.versions[runtime]) {
          return [`md/${runtime}`, node_process.versions[runtime]];
        }
      }
      return ["md/nodejs", node_process.versions.node];
    }, "getRuntimeUserAgentPair");
    var getNodeModulesParentDirs2 = /* @__PURE__ */ __name((dirname14) => {
      const cwd = process.cwd();
      if (!dirname14) {
        return [cwd];
      }
      const normalizedPath = node_path.normalize(dirname14);
      const parts = normalizedPath.split(node_path.sep);
      const nodeModulesIndex = parts.indexOf("node_modules");
      const parentDir = nodeModulesIndex !== -1 ? parts.slice(0, nodeModulesIndex).join(node_path.sep) : normalizedPath;
      if (cwd === parentDir) {
        return [cwd];
      }
      return [parentDir, cwd];
    }, "getNodeModulesParentDirs");
    var SEMVER_REGEX2 = /^(0|[1-9]\d*)\.(0|[1-9]\d*)\.(0|[1-9]\d*)(?:-((?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*)(?:\.(?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*))*))?(?:\+[0-9a-zA-Z-]+(?:\.[0-9a-zA-Z-]+)*)?$/;
    var getSanitizedTypeScriptVersion2 = /* @__PURE__ */ __name((version = "") => {
      const match = version.match(SEMVER_REGEX2);
      if (!match) {
        return void 0;
      }
      const [major6, minor, patch, prerelease] = [match[1], match[2], match[3], match[4]];
      return prerelease ? `${major6}.${minor}.${patch}-${prerelease}` : `${major6}.${minor}.${patch}`;
    }, "getSanitizedTypeScriptVersion");
    var ALLOWED_PREFIXES2 = ["^", "~", ">=", "<=", ">", "<"];
    var ALLOWED_DIST_TAGS2 = ["latest", "beta", "dev", "rc", "insiders", "next"];
    var getSanitizedDevTypeScriptVersion2 = /* @__PURE__ */ __name((version = "") => {
      if (ALLOWED_DIST_TAGS2.includes(version)) {
        return version;
      }
      const prefix = ALLOWED_PREFIXES2.find((p10) => version.startsWith(p10)) ?? "";
      const sanitizedTypeScriptVersion = getSanitizedTypeScriptVersion2(version.slice(prefix.length));
      if (!sanitizedTypeScriptVersion) {
        return void 0;
      }
      return `${prefix}${sanitizedTypeScriptVersion}`;
    }, "getSanitizedDevTypeScriptVersion");
    var tscVersion2;
    var TS_PACKAGE_JSON2 = node_path.join("node_modules", "typescript", "package.json");
    var getTypeScriptUserAgentPair2 = /* @__PURE__ */ __name(async () => {
      if (tscVersion2 === null) {
        return void 0;
      } else if (typeof tscVersion2 === "string") {
        return ["md/tsc", tscVersion2];
      }
      let isTypeScriptDetectionDisabled = false;
      try {
        isTypeScriptDetectionDisabled = utilConfigProvider.booleanSelector(process.env, "AWS_SDK_JS_TYPESCRIPT_DETECTION_DISABLED", utilConfigProvider.SelectorType.ENV) || false;
      } catch {
      }
      if (isTypeScriptDetectionDisabled) {
        tscVersion2 = null;
        return void 0;
      }
      const dirname14 = typeof __dirname !== "undefined" ? __dirname : void 0;
      const nodeModulesParentDirs = getNodeModulesParentDirs2(dirname14);
      let versionFromApp;
      for (const nodeModulesParentDir of nodeModulesParentDirs) {
        try {
          const appPackageJsonPath = node_path.join(nodeModulesParentDir, "package.json");
          const packageJson = await promises5.readFile(appPackageJsonPath, "utf-8");
          const { dependencies, devDependencies } = JSON.parse(packageJson);
          const version = devDependencies?.typescript ?? dependencies?.typescript;
          if (typeof version !== "string") {
            continue;
          }
          versionFromApp = version;
          break;
        } catch {
        }
      }
      if (!versionFromApp) {
        tscVersion2 = null;
        return void 0;
      }
      let versionFromNodeModules;
      for (const nodeModulesParentDir of nodeModulesParentDirs) {
        try {
          const tsPackageJsonPath = node_path.join(nodeModulesParentDir, TS_PACKAGE_JSON2);
          const packageJson = await promises5.readFile(tsPackageJsonPath, "utf-8");
          const { version } = JSON.parse(packageJson);
          const sanitizedVersion2 = getSanitizedTypeScriptVersion2(version);
          if (typeof sanitizedVersion2 !== "string") {
            continue;
          }
          versionFromNodeModules = sanitizedVersion2;
          break;
        } catch {
        }
      }
      if (versionFromNodeModules) {
        tscVersion2 = versionFromNodeModules;
        return ["md/tsc", tscVersion2];
      }
      const sanitizedVersion = getSanitizedDevTypeScriptVersion2(versionFromApp);
      if (typeof sanitizedVersion !== "string") {
        tscVersion2 = null;
        return void 0;
      }
      tscVersion2 = `dev_${sanitizedVersion}`;
      return ["md/tsc", tscVersion2];
    }, "getTypeScriptUserAgentPair");
    var crtAvailability2 = {
      isCrtAvailable: false
    };
    var isCrtAvailable2 = /* @__PURE__ */ __name(() => {
      if (crtAvailability2.isCrtAvailable) {
        return ["md/crt-avail"];
      }
      return null;
    }, "isCrtAvailable");
    var createDefaultUserAgentProvider29 = /* @__PURE__ */ __name(({ serviceId, clientVersion }) => {
      const runtimeUserAgentPair = getRuntimeUserAgentPair2();
      return async (config2) => {
        const sections = [
          ["aws-sdk-js", clientVersion],
          ["ua", "2.1"],
          [`os/${node_os.platform()}`, node_os.release()],
          ["lang/js"],
          runtimeUserAgentPair
        ];
        const typescriptUserAgentPair = await getTypeScriptUserAgentPair2();
        if (typescriptUserAgentPair) {
          sections.push(typescriptUserAgentPair);
        }
        const crtAvailable = isCrtAvailable2();
        if (crtAvailable) {
          sections.push(crtAvailable);
        }
        if (serviceId) {
          sections.push([`api/${serviceId}`, clientVersion]);
        }
        if (node_process.env.AWS_EXECUTION_ENV) {
          sections.push([`exec-env/${node_process.env.AWS_EXECUTION_ENV}`]);
        }
        const appId = await config2?.userAgentAppId?.();
        const resolvedUserAgent = appId ? [...sections, [`app/${appId}`]] : [...sections];
        return resolvedUserAgent;
      };
    }, "createDefaultUserAgentProvider");
    var defaultUserAgent2 = createDefaultUserAgentProvider29;
    var UA_APP_ID_ENV_NAME2 = "AWS_SDK_UA_APP_ID";
    var UA_APP_ID_INI_NAME2 = "sdk_ua_app_id";
    var UA_APP_ID_INI_NAME_DEPRECATED2 = "sdk-ua-app-id";
    var NODE_APP_ID_CONFIG_OPTIONS29 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[UA_APP_ID_ENV_NAME2], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[UA_APP_ID_INI_NAME2] ?? profile[UA_APP_ID_INI_NAME_DEPRECATED2], "configFileSelector"),
      default: middlewareUserAgent.DEFAULT_UA_APP_ID
    };
    exports2.NODE_APP_ID_CONFIG_OPTIONS = NODE_APP_ID_CONFIG_OPTIONS29;
    exports2.UA_APP_ID_ENV_NAME = UA_APP_ID_ENV_NAME2;
    exports2.UA_APP_ID_INI_NAME = UA_APP_ID_INI_NAME2;
    exports2.createDefaultUserAgentProvider = createDefaultUserAgentProvider29;
    exports2.crtAvailability = crtAvailability2;
    exports2.defaultUserAgent = defaultUserAgent2;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ProtocolLib.js
var import_smithy_client203, ProtocolLib10;
var init_ProtocolLib10 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ProtocolLib.js"() {
    init_schema4();
    import_smithy_client203 = __toESM(require_dist_cjs34());
    ProtocolLib10 = class {
      static {
        __name(this, "ProtocolLib");
      }
      queryCompat;
      errorRegistry;
      constructor(queryCompat = false) {
        this.queryCompat = queryCompat;
      }
      resolveRestContentType(defaultContentType, inputSchema) {
        const members = inputSchema.getMemberSchemas();
        const httpPayloadMember = Object.values(members).find((m20) => {
          return !!m20.getMergedTraits().httpPayload;
        });
        if (httpPayloadMember) {
          const mediaType = httpPayloadMember.getMergedTraits().mediaType;
          if (mediaType) {
            return mediaType;
          } else if (httpPayloadMember.isStringSchema()) {
            return "text/plain";
          } else if (httpPayloadMember.isBlobSchema()) {
            return "application/octet-stream";
          } else {
            return defaultContentType;
          }
        } else if (!inputSchema.isUnitSchema()) {
          const hasBody = Object.values(members).find((m20) => {
            const { httpQuery, httpQueryParams, httpHeader, httpLabel, httpPrefixHeaders } = m20.getMergedTraits();
            const noPrefixHeaders = httpPrefixHeaders === void 0;
            return !httpQuery && !httpQueryParams && !httpHeader && !httpLabel && noPrefixHeaders;
          });
          if (hasBody) {
            return defaultContentType;
          }
        }
      }
      async getErrorSchemaOrThrowBaseException(errorIdentifier, defaultNamespace, response, dataObject, metadata, getErrorSchema) {
        let errorName = errorIdentifier;
        if (errorIdentifier.includes("#")) {
          [, errorName] = errorIdentifier.split("#");
        }
        const errorMetadata = {
          $metadata: metadata,
          $fault: response.statusCode < 500 ? "client" : "server"
        };
        if (!this.errorRegistry) {
          throw new Error("@aws-sdk/core/protocols - error handler not initialized.");
        }
        try {
          const errorSchema = getErrorSchema?.(this.errorRegistry, errorName) ?? this.errorRegistry.getSchema(errorIdentifier);
          return { errorSchema, errorMetadata };
        } catch (e32) {
          dataObject.message = dataObject.message ?? dataObject.Message ?? "UnknownError";
          const synthetic = this.errorRegistry;
          const baseExceptionSchema = synthetic.getBaseException();
          if (baseExceptionSchema) {
            const ErrorCtor = synthetic.getErrorCtor(baseExceptionSchema) ?? Error;
            throw this.decorateServiceException(Object.assign(new ErrorCtor({ name: errorName }), errorMetadata), dataObject);
          }
          const d32 = dataObject;
          const message2 = d32?.message ?? d32?.Message ?? d32?.Error?.Message ?? d32?.Error?.message;
          throw this.decorateServiceException(Object.assign(new Error(message2), {
            name: errorName
          }, errorMetadata), dataObject);
        }
      }
      compose(composite, errorIdentifier, defaultNamespace) {
        let namespace = defaultNamespace;
        if (errorIdentifier.includes("#")) {
          [namespace] = errorIdentifier.split("#");
        }
        const staticRegistry = TypeRegistry.for(namespace);
        const defaultSyntheticRegistry = TypeRegistry.for("smithy.ts.sdk.synthetic." + defaultNamespace);
        composite.copyFrom(staticRegistry);
        composite.copyFrom(defaultSyntheticRegistry);
        this.errorRegistry = composite;
      }
      decorateServiceException(exception, additions = {}) {
        if (this.queryCompat) {
          const msg = exception.Message ?? additions.Message;
          const error4 = (0, import_smithy_client203.decorateServiceException)(exception, additions);
          if (msg) {
            error4.message = msg;
          }
          const errorObj = error4.Error ?? {};
          errorObj.Type = error4.Error?.Type;
          errorObj.Code = error4.Error?.Code;
          errorObj.Message = error4.Error?.message ?? error4.Error?.Message ?? msg;
          error4.Error = errorObj;
          const reqId = error4.$metadata.requestId;
          if (reqId) {
            error4.RequestId = reqId;
          }
          return error4;
        }
        return (0, import_smithy_client203.decorateServiceException)(exception, additions);
      }
      setQueryCompatError(output, response) {
        const queryErrorHeader = response.headers?.["x-amzn-query-error"];
        if (output !== void 0 && queryErrorHeader != null) {
          const [Code, Type] = queryErrorHeader.split(";");
          const keys = Object.keys(output);
          const Error2 = {
            Code,
            Type
          };
          output.Code = Code;
          output.Type = Type;
          for (let i32 = 0; i32 < keys.length; i32++) {
            const k32 = keys[i32];
            Error2[k32 === "message" ? "Message" : k32] = output[k32];
          }
          delete Error2.__type;
          output.Error = Error2;
        }
      }
      queryCompatOutput(queryCompatErrorData, errorData) {
        if (queryCompatErrorData.Error) {
          errorData.Error = queryCompatErrorData.Error;
        }
        if (queryCompatErrorData.Type) {
          errorData.Type = queryCompatErrorData.Type;
        }
        if (queryCompatErrorData.Code) {
          errorData.Code = queryCompatErrorData.Code;
        }
      }
      findQueryCompatibleError(registry, errorName) {
        try {
          return registry.getSchema(errorName);
        } catch (e32) {
          return registry.find((schema) => NormalizedSchema.of(schema).getMergedTraits().awsQueryError?.[0] === errorName);
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/cbor/AwsSmithyRpcV2CborProtocol.js
var AwsSmithyRpcV2CborProtocol8;
var init_AwsSmithyRpcV2CborProtocol10 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/cbor/AwsSmithyRpcV2CborProtocol.js"() {
    init_cbor2();
    init_schema4();
    init_ProtocolLib10();
    AwsSmithyRpcV2CborProtocol8 = class extends SmithyRpcV2CborProtocol {
      static {
        __name(this, "AwsSmithyRpcV2CborProtocol");
      }
      awsQueryCompatible;
      mixin;
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, awsQueryCompatible }) {
        super({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32 });
        this.awsQueryCompatible = !!awsQueryCompatible;
        this.mixin = new ProtocolLib10(this.awsQueryCompatible);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        if (this.awsQueryCompatible) {
          request4.headers["x-amzn-query-mode"] = "true";
        }
        return request4;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        if (this.awsQueryCompatible) {
          this.mixin.setQueryCompatError(dataObject, response);
        }
        const errorName = (() => {
          const compatHeader = response.headers["x-amzn-query-error"];
          if (compatHeader && this.awsQueryCompatible) {
            return compatHeader.split(";")[0];
          }
          return loadSmithyRpcV2CborErrorCode(response, dataObject) ?? "Unknown";
        })();
        this.mixin.compose(this.compositeErrorRegistry, errorName, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorName, this.options.defaultNamespace, response, dataObject, metadata, this.awsQueryCompatible ? this.mixin.findQueryCompatibleError : void 0);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        const output = {};
        for (const [name, member7] of ns.structIterator()) {
          if (dataObject[name] != null) {
            output[name] = this.deserializer.readValue(member7, dataObject[name]);
          }
        }
        if (this.awsQueryCompatible) {
          this.mixin.queryCompatOutput(dataObject, output);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/coercing-serializers.js
var _toStr8, _toBool8, _toNum8;
var init_coercing_serializers10 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/coercing-serializers.js"() {
    _toStr8 = /* @__PURE__ */ __name((val) => {
      if (val == null) {
        return val;
      }
      if (typeof val === "number" || typeof val === "bigint") {
        const warning2 = new Error(`Received number ${val} where a string was expected.`);
        warning2.name = "Warning";
        console.warn(warning2);
        return String(val);
      }
      if (typeof val === "boolean") {
        const warning2 = new Error(`Received boolean ${val} where a string was expected.`);
        warning2.name = "Warning";
        console.warn(warning2);
        return String(val);
      }
      return val;
    }, "_toStr");
    _toBool8 = /* @__PURE__ */ __name((val) => {
      if (val == null) {
        return val;
      }
      if (typeof val === "number") {
      }
      if (typeof val === "string") {
        const lowercase = val.toLowerCase();
        if (val !== "" && lowercase !== "false" && lowercase !== "true") {
          const warning2 = new Error(`Received string "${val}" where a boolean was expected.`);
          warning2.name = "Warning";
          console.warn(warning2);
        }
        return val !== "" && lowercase !== "false";
      }
      return val;
    }, "_toBool");
    _toNum8 = /* @__PURE__ */ __name((val) => {
      if (val == null) {
        return val;
      }
      if (typeof val === "boolean") {
      }
      if (typeof val === "string") {
        const num = Number(val);
        if (num.toString() !== val) {
          const warning2 = new Error(`Received string "${val}" where a number was expected.`);
          warning2.name = "Warning";
          console.warn(warning2);
          return val;
        }
        return num;
      }
      return val;
    }, "_toNum");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ConfigurableSerdeContext.js
var SerdeContextConfig10;
var init_ConfigurableSerdeContext10 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ConfigurableSerdeContext.js"() {
    SerdeContextConfig10 = class {
      static {
        __name(this, "SerdeContextConfig");
      }
      serdeContext;
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/UnionSerde.js
var UnionSerde10;
var init_UnionSerde10 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/UnionSerde.js"() {
    UnionSerde10 = class {
      static {
        __name(this, "UnionSerde");
      }
      from;
      to;
      keys;
      constructor(from, to) {
        this.from = from;
        this.to = to;
        const keys = Object.keys(this.from);
        const set = new Set(keys);
        set.delete("__type");
        this.keys = set;
      }
      mark(key) {
        this.keys.delete(key);
      }
      hasUnknown() {
        return this.keys.size === 1 && Object.keys(this.to).length === 0;
      }
      writeUnknown() {
        if (this.hasUnknown()) {
          const k32 = this.keys.values().next().value;
          const v = this.from[k32];
          this.to.$unknown = [k32, v];
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReviver.js
function jsonReviver10(key, value, context) {
  if (context?.source) {
    const numericString = context.source;
    if (typeof value === "number") {
      if (value > Number.MAX_SAFE_INTEGER || value < Number.MIN_SAFE_INTEGER || numericString !== String(value)) {
        const isFractional = numericString.includes(".");
        if (isFractional) {
          return new NumericValue(numericString, "bigDecimal");
        } else {
          return BigInt(numericString);
        }
      }
    }
  }
  return value;
}
var init_jsonReviver10 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReviver.js"() {
    init_serde();
    __name(jsonReviver10, "jsonReviver");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/common.js
var import_smithy_client204, import_util_utf842, collectBodyString10;
var init_common12 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/common.js"() {
    import_smithy_client204 = __toESM(require_dist_cjs34());
    import_util_utf842 = __toESM(require_dist_cjs9());
    collectBodyString10 = /* @__PURE__ */ __name((streamBody, context) => (0, import_smithy_client204.collectBody)(streamBody, context).then((body) => (context?.utf8Encoder ?? import_util_utf842.toUtf8)(body)), "collectBodyString");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/parseJsonBody.js
var parseJsonBody10, parseJsonErrorBody8, findKey10, sanitizeErrorCode10, loadRestJsonErrorCode10;
var init_parseJsonBody10 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/parseJsonBody.js"() {
    init_common12();
    parseJsonBody10 = /* @__PURE__ */ __name((streamBody, context) => collectBodyString10(streamBody, context).then((encoded) => {
      if (encoded.length) {
        try {
          return JSON.parse(encoded);
        } catch (e32) {
          if (e32?.name === "SyntaxError") {
            Object.defineProperty(e32, "$responseBodyText", {
              value: encoded
            });
          }
          throw e32;
        }
      }
      return {};
    }), "parseJsonBody");
    parseJsonErrorBody8 = /* @__PURE__ */ __name(async (errorBody, context) => {
      const value = await parseJsonBody10(errorBody, context);
      value.message = value.message ?? value.Message;
      return value;
    }, "parseJsonErrorBody");
    findKey10 = /* @__PURE__ */ __name((object, key) => Object.keys(object).find((k32) => k32.toLowerCase() === key.toLowerCase()), "findKey");
    sanitizeErrorCode10 = /* @__PURE__ */ __name((rawValue) => {
      let cleanValue = rawValue;
      if (typeof cleanValue === "number") {
        cleanValue = cleanValue.toString();
      }
      if (cleanValue.indexOf(",") >= 0) {
        cleanValue = cleanValue.split(",")[0];
      }
      if (cleanValue.indexOf(":") >= 0) {
        cleanValue = cleanValue.split(":")[0];
      }
      if (cleanValue.indexOf("#") >= 0) {
        cleanValue = cleanValue.split("#")[1];
      }
      return cleanValue;
    }, "sanitizeErrorCode");
    loadRestJsonErrorCode10 = /* @__PURE__ */ __name((output, data3) => {
      const headerKey = findKey10(output.headers, "x-amzn-errortype");
      if (headerKey !== void 0) {
        return sanitizeErrorCode10(output.headers[headerKey]);
      }
      if (data3 && typeof data3 === "object") {
        const codeKey = findKey10(data3, "code");
        if (codeKey && data3[codeKey] !== void 0) {
          return sanitizeErrorCode10(data3[codeKey]);
        }
        if (data3["__type"] !== void 0) {
          return sanitizeErrorCode10(data3["__type"]);
        }
      }
    }, "loadRestJsonErrorCode");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeDeserializer.js
var import_util_base6454, JsonShapeDeserializer10;
var init_JsonShapeDeserializer10 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeDeserializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_util_base6454 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext10();
    init_UnionSerde10();
    init_jsonReviver10();
    init_parseJsonBody10();
    JsonShapeDeserializer10 = class extends SerdeContextConfig10 {
      static {
        __name(this, "JsonShapeDeserializer");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      async read(schema, data3) {
        return this._read(schema, typeof data3 === "string" ? JSON.parse(data3, jsonReviver10) : await parseJsonBody10(data3, this.serdeContext));
      }
      readObject(schema, data3) {
        return this._read(schema, data3);
      }
      _read(schema, value) {
        const isObject3 = value !== null && typeof value === "object";
        const ns = NormalizedSchema.of(schema);
        if (isObject3) {
          if (ns.isStructSchema()) {
            const record = value;
            const union = ns.isUnionSchema();
            const out = {};
            let nameMap = void 0;
            const { jsonName } = this.settings;
            if (jsonName) {
              nameMap = {};
            }
            let unionSerde;
            if (union) {
              unionSerde = new UnionSerde10(record, out);
            }
            for (const [memberName, memberSchema] of ns.structIterator()) {
              let fromKey = memberName;
              if (jsonName) {
                fromKey = memberSchema.getMergedTraits().jsonName ?? fromKey;
                nameMap[fromKey] = memberName;
              }
              if (union) {
                unionSerde.mark(fromKey);
              }
              if (record[fromKey] != null) {
                out[memberName] = this._read(memberSchema, record[fromKey]);
              }
            }
            if (union) {
              unionSerde.writeUnknown();
            } else if (typeof record.__type === "string") {
              for (const k32 in record) {
                const v = record[k32];
                const t = jsonName ? nameMap[k32] ?? k32 : k32;
                if (!(t in out)) {
                  out[t] = v;
                }
              }
            }
            return out;
          }
          if (Array.isArray(value) && ns.isListSchema()) {
            const listMember = ns.getValueSchema();
            const out = [];
            for (const item of value) {
              out.push(this._read(listMember, item));
            }
            return out;
          }
          if (ns.isMapSchema()) {
            const mapMember = ns.getValueSchema();
            const out = {};
            for (const _k in value) {
              out[_k] = this._read(mapMember, value[_k]);
            }
            return out;
          }
        }
        if (ns.isBlobSchema() && typeof value === "string") {
          return (0, import_util_base6454.fromBase64)(value);
        }
        const mediaType = ns.getMergedTraits().mediaType;
        if (ns.isStringSchema() && typeof value === "string" && mediaType) {
          const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
          if (isJson) {
            return LazyJsonString.from(value);
          }
          return value;
        }
        if (ns.isTimestampSchema() && value != null) {
          const format32 = determineTimestampFormat(ns, this.settings);
          switch (format32) {
            case 5:
              return parseRfc3339DateTimeWithOffset(value);
            case 6:
              return parseRfc7231DateTime(value);
            case 7:
              return parseEpochTimestamp(value);
            default:
              console.warn("Missing timestamp format, parsing value with Date constructor:", value);
              return new Date(value);
          }
        }
        if (ns.isBigIntegerSchema() && (typeof value === "number" || typeof value === "string")) {
          return BigInt(value);
        }
        if (ns.isBigDecimalSchema() && value != void 0) {
          if (value instanceof NumericValue) {
            return value;
          }
          const untyped = value;
          if (untyped.type === "bigDecimal" && "string" in untyped) {
            return new NumericValue(untyped.string, untyped.type);
          }
          return new NumericValue(String(value), "bigDecimal");
        }
        if (ns.isNumericSchema() && typeof value === "string") {
          switch (value) {
            case "Infinity":
              return Infinity;
            case "-Infinity":
              return -Infinity;
            case "NaN":
              return NaN;
          }
          return value;
        }
        if (ns.isDocumentSchema()) {
          if (isObject3) {
            const out = Array.isArray(value) ? [] : {};
            for (const k32 in value) {
              const v = value[k32];
              if (v instanceof NumericValue) {
                out[k32] = v;
              } else {
                out[k32] = this._read(ns, v);
              }
            }
            return out;
          } else {
            return structuredClone(value);
          }
        }
        return value;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReplacer.js
var NUMERIC_CONTROL_CHAR10, JsonReplacer10;
var init_jsonReplacer10 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReplacer.js"() {
    init_serde();
    NUMERIC_CONTROL_CHAR10 = String.fromCharCode(925);
    JsonReplacer10 = class {
      static {
        __name(this, "JsonReplacer");
      }
      values = /* @__PURE__ */ new Map();
      counter = 0;
      stage = 0;
      createReplacer() {
        if (this.stage === 1) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer already created.");
        }
        if (this.stage === 2) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer exhausted.");
        }
        this.stage = 1;
        return (key, value) => {
          if (value instanceof NumericValue) {
            const v = `${NUMERIC_CONTROL_CHAR10 + "nv" + this.counter++}_` + value.string;
            this.values.set(`"${v}"`, value.string);
            return v;
          }
          if (typeof value === "bigint") {
            const s = value.toString();
            const v = `${NUMERIC_CONTROL_CHAR10 + "b" + this.counter++}_` + s;
            this.values.set(`"${v}"`, s);
            return v;
          }
          return value;
        };
      }
      replaceInJson(json) {
        if (this.stage === 0) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer not created yet.");
        }
        if (this.stage === 2) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer exhausted.");
        }
        this.stage = 2;
        if (this.counter === 0) {
          return json;
        }
        for (const [key, value] of this.values) {
          json = json.replace(key, value);
        }
        return json;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeSerializer.js
var import_util_base6455, JsonShapeSerializer10;
var init_JsonShapeSerializer10 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeSerializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_util_base6455 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext10();
    init_jsonReplacer10();
    JsonShapeSerializer10 = class extends SerdeContextConfig10 {
      static {
        __name(this, "JsonShapeSerializer");
      }
      settings;
      buffer;
      useReplacer = false;
      rootSchema;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value) {
        this.rootSchema = NormalizedSchema.of(schema);
        this.buffer = this._write(this.rootSchema, value);
      }
      flush() {
        const { rootSchema, useReplacer } = this;
        this.rootSchema = void 0;
        this.useReplacer = false;
        if (rootSchema?.isStructSchema() || rootSchema?.isDocumentSchema()) {
          if (!useReplacer) {
            return JSON.stringify(this.buffer);
          }
          const replacer = new JsonReplacer10();
          return replacer.replaceInJson(JSON.stringify(this.buffer, replacer.createReplacer(), 0));
        }
        return this.buffer;
      }
      writeDiscriminatedDocument(schema, value) {
        this.write(schema, value);
        if (typeof this.buffer === "object") {
          this.buffer.__type = NormalizedSchema.of(schema).getName(true);
        }
      }
      _write(schema, value, container) {
        const isObject3 = value !== null && typeof value === "object";
        const ns = NormalizedSchema.of(schema);
        if (isObject3) {
          if (ns.isStructSchema()) {
            const record = value;
            const out = {};
            const { jsonName } = this.settings;
            let nameMap = void 0;
            if (jsonName) {
              nameMap = {};
            }
            let outCount = 0;
            for (const [memberName, memberSchema] of ns.structIterator()) {
              const serializableValue = this._write(memberSchema, record[memberName], ns);
              if (serializableValue !== void 0) {
                let targetKey = memberName;
                if (jsonName) {
                  targetKey = memberSchema.getMergedTraits().jsonName ?? memberName;
                  nameMap[memberName] = targetKey;
                }
                out[targetKey] = serializableValue;
                outCount++;
              }
            }
            if (ns.isUnionSchema() && outCount === 0) {
              const { $unknown } = record;
              if (Array.isArray($unknown)) {
                const [k32, v] = $unknown;
                out[k32] = this._write(15, v);
              }
            } else if (typeof record.__type === "string") {
              for (const k32 in record) {
                const v = record[k32];
                const targetKey = jsonName ? nameMap[k32] ?? k32 : k32;
                if (!(targetKey in out)) {
                  out[targetKey] = this._write(15, v);
                }
              }
            }
            return out;
          }
          if (Array.isArray(value) && ns.isListSchema()) {
            const listMember = ns.getValueSchema();
            const out = [];
            const sparse = !!ns.getMergedTraits().sparse;
            for (const item of value) {
              if (sparse || item != null) {
                out.push(this._write(listMember, item));
              }
            }
            return out;
          }
          if (ns.isMapSchema()) {
            const mapMember = ns.getValueSchema();
            const out = {};
            const sparse = !!ns.getMergedTraits().sparse;
            for (const _k in value) {
              const _v = value[_k];
              if (sparse || _v != null) {
                out[_k] = this._write(mapMember, _v);
              }
            }
            return out;
          }
          if (value instanceof Uint8Array && (ns.isBlobSchema() || ns.isDocumentSchema())) {
            if (ns === this.rootSchema) {
              return value;
            }
            return (this.serdeContext?.base64Encoder ?? import_util_base6455.toBase64)(value);
          }
          if (value instanceof Date && (ns.isTimestampSchema() || ns.isDocumentSchema())) {
            const format32 = determineTimestampFormat(ns, this.settings);
            switch (format32) {
              case 5:
                return value.toISOString().replace(".000Z", "Z");
              case 6:
                return dateToUtcString(value);
              case 7:
                return value.getTime() / 1e3;
              default:
                console.warn("Missing timestamp format, using epoch seconds", value);
                return value.getTime() / 1e3;
            }
          }
          if (value instanceof NumericValue) {
            this.useReplacer = true;
          }
        }
        if (value === null && container?.isStructSchema()) {
          return void 0;
        }
        if (ns.isStringSchema()) {
          if (typeof value === "undefined" && ns.isIdempotencyToken()) {
            return (0, import_uuid.v4)();
          }
          const mediaType = ns.getMergedTraits().mediaType;
          if (value != null && mediaType) {
            const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
            if (isJson) {
              return LazyJsonString.from(value);
            }
          }
          return value;
        }
        if (typeof value === "number" && ns.isNumericSchema()) {
          if (Math.abs(value) === Infinity || isNaN(value)) {
            return String(value);
          }
          return value;
        }
        if (typeof value === "string" && ns.isBlobSchema()) {
          if (ns === this.rootSchema) {
            return value;
          }
          return (this.serdeContext?.base64Encoder ?? import_util_base6455.toBase64)(value);
        }
        if (typeof value === "bigint") {
          this.useReplacer = true;
        }
        if (ns.isDocumentSchema()) {
          if (isObject3) {
            const out = Array.isArray(value) ? [] : {};
            for (const k32 in value) {
              const v = value[k32];
              if (v instanceof NumericValue) {
                this.useReplacer = true;
                out[k32] = v;
              } else {
                out[k32] = this._write(ns, v);
              }
            }
            return out;
          } else {
            return structuredClone(value);
          }
        }
        return value;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonCodec.js
var JsonCodec10;
var init_JsonCodec10 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonCodec.js"() {
    init_ConfigurableSerdeContext10();
    init_JsonShapeDeserializer10();
    init_JsonShapeSerializer10();
    JsonCodec10 = class extends SerdeContextConfig10 {
      static {
        __name(this, "JsonCodec");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      createSerializer() {
        const serializer = new JsonShapeSerializer10(this.settings);
        serializer.setSerdeContext(this.serdeContext);
        return serializer;
      }
      createDeserializer() {
        const deserializer = new JsonShapeDeserializer10(this.settings);
        deserializer.setSerdeContext(this.serdeContext);
        return deserializer;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJsonRpcProtocol.js
var AwsJsonRpcProtocol8;
var init_AwsJsonRpcProtocol10 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJsonRpcProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib10();
    init_JsonCodec10();
    init_parseJsonBody10();
    AwsJsonRpcProtocol8 = class extends RpcProtocol {
      static {
        __name(this, "AwsJsonRpcProtocol");
      }
      serializer;
      deserializer;
      serviceTarget;
      codec;
      mixin;
      awsQueryCompatible;
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, serviceTarget, awsQueryCompatible, jsonCodec }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32
        });
        this.serviceTarget = serviceTarget;
        this.codec = jsonCodec ?? new JsonCodec10({
          timestampFormat: {
            useTrait: true,
            default: 7
          },
          jsonName: false
        });
        this.serializer = this.codec.createSerializer();
        this.deserializer = this.codec.createDeserializer();
        this.awsQueryCompatible = !!awsQueryCompatible;
        this.mixin = new ProtocolLib10(this.awsQueryCompatible);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        if (!request4.path.endsWith("/")) {
          request4.path += "/";
        }
        request4.headers["content-type"] = `application/x-amz-json-${this.getJsonRpcVersion()}`;
        request4.headers["x-amz-target"] = `${this.serviceTarget}.${operationSchema.name}`;
        if (this.awsQueryCompatible) {
          request4.headers["x-amzn-query-mode"] = "true";
        }
        if (deref(operationSchema.input) === "unit" || !request4.body) {
          request4.body = "{}";
        }
        return request4;
      }
      getPayloadCodec() {
        return this.codec;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        if (this.awsQueryCompatible) {
          this.mixin.setQueryCompatError(dataObject, response);
        }
        const errorIdentifier = loadRestJsonErrorCode10(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata, this.awsQueryCompatible ? this.mixin.findQueryCompatibleError : void 0);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          if (dataObject[name] != null) {
            output[name] = errorDeserializer.readObject(member7, dataObject[name]);
          }
        }
        if (this.awsQueryCompatible) {
          this.mixin.queryCompatOutput(dataObject, output);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_0Protocol.js
var AwsJson1_0Protocol8;
var init_AwsJson1_0Protocol10 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_0Protocol.js"() {
    init_AwsJsonRpcProtocol10();
    AwsJson1_0Protocol8 = class extends AwsJsonRpcProtocol8 {
      static {
        __name(this, "AwsJson1_0Protocol");
      }
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, serviceTarget, awsQueryCompatible, jsonCodec }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32,
          serviceTarget,
          awsQueryCompatible,
          jsonCodec
        });
      }
      getShapeId() {
        return "aws.protocols#awsJson1_0";
      }
      getJsonRpcVersion() {
        return "1.0";
      }
      getDefaultContentType() {
        return "application/x-amz-json-1.0";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_1Protocol.js
var AwsJson1_1Protocol8;
var init_AwsJson1_1Protocol10 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_1Protocol.js"() {
    init_AwsJsonRpcProtocol10();
    AwsJson1_1Protocol8 = class extends AwsJsonRpcProtocol8 {
      static {
        __name(this, "AwsJson1_1Protocol");
      }
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, serviceTarget, awsQueryCompatible, jsonCodec }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32,
          serviceTarget,
          awsQueryCompatible,
          jsonCodec
        });
      }
      getShapeId() {
        return "aws.protocols#awsJson1_1";
      }
      getJsonRpcVersion() {
        return "1.1";
      }
      getDefaultContentType() {
        return "application/x-amz-json-1.1";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsRestJsonProtocol.js
var AwsRestJsonProtocol10;
var init_AwsRestJsonProtocol10 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsRestJsonProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib10();
    init_JsonCodec10();
    init_parseJsonBody10();
    AwsRestJsonProtocol10 = class extends HttpBindingProtocol {
      static {
        __name(this, "AwsRestJsonProtocol");
      }
      serializer;
      deserializer;
      codec;
      mixin = new ProtocolLib10();
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32 }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32
        });
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 7
          },
          httpBindings: true,
          jsonName: true
        };
        this.codec = new JsonCodec10(settings);
        this.serializer = new HttpInterceptingShapeSerializer(this.codec.createSerializer(), settings);
        this.deserializer = new HttpInterceptingShapeDeserializer(this.codec.createDeserializer(), settings);
      }
      getShapeId() {
        return "aws.protocols#restJson1";
      }
      getPayloadCodec() {
        return this.codec;
      }
      setSerdeContext(serdeContext) {
        this.codec.setSerdeContext(serdeContext);
        super.setSerdeContext(serdeContext);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        const inputSchema = NormalizedSchema.of(operationSchema.input);
        if (!request4.headers["content-type"]) {
          const contentType = this.mixin.resolveRestContentType(this.getDefaultContentType(), inputSchema);
          if (contentType) {
            request4.headers["content-type"] = contentType;
          }
        }
        if (request4.body == null && request4.headers["content-type"] === this.getDefaultContentType()) {
          request4.body = "{}";
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        const output = await super.deserializeResponse(operationSchema, context, response);
        const outputSchema = NormalizedSchema.of(operationSchema.output);
        for (const [name, member7] of outputSchema.structIterator()) {
          if (member7.getMemberTraits().httpPayload && !(name in output)) {
            output[name] = null;
          }
        }
        return output;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = loadRestJsonErrorCode10(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        await this.deserializeHttpMessage(errorSchema, context, response, dataObject);
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().jsonName ?? name;
          output[name] = errorDeserializer.readObject(member7, dataObject[target]);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      getDefaultContentType() {
        return "application/json";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/awsExpectUnion.js
var import_smithy_client205, awsExpectUnion8;
var init_awsExpectUnion10 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/awsExpectUnion.js"() {
    import_smithy_client205 = __toESM(require_dist_cjs34());
    awsExpectUnion8 = /* @__PURE__ */ __name((value) => {
      if (value == null) {
        return void 0;
      }
      if (typeof value === "object" && "__type" in value) {
        delete value.__type;
      }
      return (0, import_smithy_client205.expectUnion)(value);
    }, "awsExpectUnion");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeDeserializer.js
var import_xml_builder23, import_smithy_client206, import_util_utf843, XmlShapeDeserializer9;
var init_XmlShapeDeserializer10 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeDeserializer.js"() {
    import_xml_builder23 = __toESM(require_dist_cjs47());
    init_protocols();
    init_schema4();
    import_smithy_client206 = __toESM(require_dist_cjs34());
    import_util_utf843 = __toESM(require_dist_cjs9());
    init_ConfigurableSerdeContext10();
    init_UnionSerde10();
    XmlShapeDeserializer9 = class extends SerdeContextConfig10 {
      static {
        __name(this, "XmlShapeDeserializer");
      }
      settings;
      stringDeserializer;
      constructor(settings) {
        super();
        this.settings = settings;
        this.stringDeserializer = new FromStringShapeDeserializer(settings);
      }
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
        this.stringDeserializer.setSerdeContext(serdeContext);
      }
      read(schema, bytes, key) {
        const ns = NormalizedSchema.of(schema);
        const memberSchemas = ns.getMemberSchemas();
        const isEventPayload = ns.isStructSchema() && ns.isMemberSchema() && !!Object.values(memberSchemas).find((memberNs) => {
          return !!memberNs.getMemberTraits().eventPayload;
        });
        if (isEventPayload) {
          const output = {};
          const memberName = Object.keys(memberSchemas)[0];
          const eventMemberSchema = memberSchemas[memberName];
          if (eventMemberSchema.isBlobSchema()) {
            output[memberName] = bytes;
          } else {
            output[memberName] = this.read(memberSchemas[memberName], bytes);
          }
          return output;
        }
        const xmlString = (this.serdeContext?.utf8Encoder ?? import_util_utf843.toUtf8)(bytes);
        const parsedObject = this.parseXml(xmlString);
        return this.readSchema(schema, key ? parsedObject[key] : parsedObject);
      }
      readSchema(_schema, value) {
        const ns = NormalizedSchema.of(_schema);
        if (ns.isUnitSchema()) {
          return;
        }
        const traits = ns.getMergedTraits();
        if (ns.isListSchema() && !Array.isArray(value)) {
          return this.readSchema(ns, [value]);
        }
        if (value == null) {
          return value;
        }
        if (typeof value === "object") {
          const flat = !!traits.xmlFlattened;
          if (ns.isListSchema()) {
            const listValue = ns.getValueSchema();
            const buffer2 = [];
            const sourceKey = listValue.getMergedTraits().xmlName ?? "member";
            const source = flat ? value : (value[0] ?? value)[sourceKey];
            if (source == null) {
              return buffer2;
            }
            const sourceArray = Array.isArray(source) ? source : [source];
            for (const v of sourceArray) {
              buffer2.push(this.readSchema(listValue, v));
            }
            return buffer2;
          }
          const buffer = {};
          if (ns.isMapSchema()) {
            const keyNs = ns.getKeySchema();
            const memberNs = ns.getValueSchema();
            let entries;
            if (flat) {
              entries = Array.isArray(value) ? value : [value];
            } else {
              entries = Array.isArray(value.entry) ? value.entry : [value.entry];
            }
            const keyProperty = keyNs.getMergedTraits().xmlName ?? "key";
            const valueProperty = memberNs.getMergedTraits().xmlName ?? "value";
            for (const entry of entries) {
              const key = entry[keyProperty];
              const value2 = entry[valueProperty];
              buffer[key] = this.readSchema(memberNs, value2);
            }
            return buffer;
          }
          if (ns.isStructSchema()) {
            const union = ns.isUnionSchema();
            let unionSerde;
            if (union) {
              unionSerde = new UnionSerde10(value, buffer);
            }
            for (const [memberName, memberSchema] of ns.structIterator()) {
              const memberTraits = memberSchema.getMergedTraits();
              const xmlObjectKey = !memberTraits.httpPayload ? memberSchema.getMemberTraits().xmlName ?? memberName : memberTraits.xmlName ?? memberSchema.getName();
              if (union) {
                unionSerde.mark(xmlObjectKey);
              }
              if (value[xmlObjectKey] != null) {
                buffer[memberName] = this.readSchema(memberSchema, value[xmlObjectKey]);
              }
            }
            if (union) {
              unionSerde.writeUnknown();
            }
            return buffer;
          }
          if (ns.isDocumentSchema()) {
            return value;
          }
          throw new Error(`@aws-sdk/core/protocols - xml deserializer unhandled schema type for ${ns.getName(true)}`);
        }
        if (ns.isListSchema()) {
          return [];
        }
        if (ns.isMapSchema() || ns.isStructSchema()) {
          return {};
        }
        return this.stringDeserializer.read(ns, value);
      }
      parseXml(xml) {
        if (xml.length) {
          let parsedObj;
          try {
            parsedObj = (0, import_xml_builder23.parseXML)(xml);
          } catch (e32) {
            if (e32 && typeof e32 === "object") {
              Object.defineProperty(e32, "$responseBodyText", {
                value: xml
              });
            }
            throw e32;
          }
          const textNodeName = "#text";
          const key = Object.keys(parsedObj)[0];
          const parsedObjToReturn = parsedObj[key];
          if (parsedObjToReturn[textNodeName]) {
            parsedObjToReturn[key] = parsedObjToReturn[textNodeName];
            delete parsedObjToReturn[textNodeName];
          }
          return (0, import_smithy_client206.getValueFromTextNode)(parsedObjToReturn);
        }
        return {};
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QueryShapeSerializer.js
var import_smithy_client207, import_util_base6456, QueryShapeSerializer9;
var init_QueryShapeSerializer10 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QueryShapeSerializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_smithy_client207 = __toESM(require_dist_cjs34());
    import_util_base6456 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext10();
    QueryShapeSerializer9 = class extends SerdeContextConfig10 {
      static {
        __name(this, "QueryShapeSerializer");
      }
      settings;
      buffer;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value, prefix = "") {
        if (this.buffer === void 0) {
          this.buffer = "";
        }
        const ns = NormalizedSchema.of(schema);
        if (prefix && !prefix.endsWith(".")) {
          prefix += ".";
        }
        if (ns.isBlobSchema()) {
          if (typeof value === "string" || value instanceof Uint8Array) {
            this.writeKey(prefix);
            this.writeValue((this.serdeContext?.base64Encoder ?? import_util_base6456.toBase64)(value));
          }
        } else if (ns.isBooleanSchema() || ns.isNumericSchema() || ns.isStringSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(String(value));
          } else if (ns.isIdempotencyToken()) {
            this.writeKey(prefix);
            this.writeValue((0, import_uuid.v4)());
          }
        } else if (ns.isBigIntegerSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(String(value));
          }
        } else if (ns.isBigDecimalSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(value instanceof NumericValue ? value.string : String(value));
          }
        } else if (ns.isTimestampSchema()) {
          if (value instanceof Date) {
            this.writeKey(prefix);
            const format32 = determineTimestampFormat(ns, this.settings);
            switch (format32) {
              case 5:
                this.writeValue(value.toISOString().replace(".000Z", "Z"));
                break;
              case 6:
                this.writeValue((0, import_smithy_client207.dateToUtcString)(value));
                break;
              case 7:
                this.writeValue(String(value.getTime() / 1e3));
                break;
            }
          }
        } else if (ns.isDocumentSchema()) {
          if (Array.isArray(value)) {
            this.write(64 | 15, value, prefix);
          } else if (value instanceof Date) {
            this.write(4, value, prefix);
          } else if (value instanceof Uint8Array) {
            this.write(21, value, prefix);
          } else if (value && typeof value === "object") {
            this.write(128 | 15, value, prefix);
          } else {
            this.writeKey(prefix);
            this.writeValue(String(value));
          }
        } else if (ns.isListSchema()) {
          if (Array.isArray(value)) {
            if (value.length === 0) {
              if (this.settings.serializeEmptyLists) {
                this.writeKey(prefix);
                this.writeValue("");
              }
            } else {
              const member7 = ns.getValueSchema();
              const flat = this.settings.flattenLists || ns.getMergedTraits().xmlFlattened;
              let i32 = 1;
              for (const item of value) {
                if (item == null) {
                  continue;
                }
                const traits = member7.getMergedTraits();
                const suffix = this.getKey("member", traits.xmlName, traits.ec2QueryName);
                const key = flat ? `${prefix}${i32}` : `${prefix}${suffix}.${i32}`;
                this.write(member7, item, key);
                ++i32;
              }
            }
          }
        } else if (ns.isMapSchema()) {
          if (value && typeof value === "object") {
            const keySchema = ns.getKeySchema();
            const memberSchema = ns.getValueSchema();
            const flat = ns.getMergedTraits().xmlFlattened;
            let i32 = 1;
            for (const k32 in value) {
              const v = value[k32];
              if (v == null) {
                continue;
              }
              const keyTraits = keySchema.getMergedTraits();
              const keySuffix = this.getKey("key", keyTraits.xmlName, keyTraits.ec2QueryName);
              const key = flat ? `${prefix}${i32}.${keySuffix}` : `${prefix}entry.${i32}.${keySuffix}`;
              const valTraits = memberSchema.getMergedTraits();
              const valueSuffix = this.getKey("value", valTraits.xmlName, valTraits.ec2QueryName);
              const valueKey = flat ? `${prefix}${i32}.${valueSuffix}` : `${prefix}entry.${i32}.${valueSuffix}`;
              this.write(keySchema, k32, key);
              this.write(memberSchema, v, valueKey);
              ++i32;
            }
          }
        } else if (ns.isStructSchema()) {
          if (value && typeof value === "object") {
            let didWriteMember = false;
            for (const [memberName, member7] of ns.structIterator()) {
              if (value[memberName] == null && !member7.isIdempotencyToken()) {
                continue;
              }
              const traits = member7.getMergedTraits();
              const suffix = this.getKey(memberName, traits.xmlName, traits.ec2QueryName, "struct");
              const key = `${prefix}${suffix}`;
              this.write(member7, value[memberName], key);
              didWriteMember = true;
            }
            if (!didWriteMember && ns.isUnionSchema()) {
              const { $unknown } = value;
              if (Array.isArray($unknown)) {
                const [k32, v] = $unknown;
                const key = `${prefix}${k32}`;
                this.write(15, v, key);
              }
            }
          }
        } else if (ns.isUnitSchema()) {
        } else {
          throw new Error(`@aws-sdk/core/protocols - QuerySerializer unrecognized schema type ${ns.getName(true)}`);
        }
      }
      flush() {
        if (this.buffer === void 0) {
          throw new Error("@aws-sdk/core/protocols - QuerySerializer cannot flush with nothing written to buffer.");
        }
        const str = this.buffer;
        delete this.buffer;
        return str;
      }
      getKey(memberName, xmlName, ec2QueryName, keySource) {
        const { ec2, capitalizeKeys } = this.settings;
        if (ec2 && ec2QueryName) {
          return ec2QueryName;
        }
        const key = xmlName ?? memberName;
        if (capitalizeKeys && keySource === "struct") {
          return key[0].toUpperCase() + key.slice(1);
        }
        return key;
      }
      writeKey(key) {
        if (key.endsWith(".")) {
          key = key.slice(0, key.length - 1);
        }
        this.buffer += `&${extendedEncodeURIComponent(key)}=`;
      }
      writeValue(value) {
        this.buffer += extendedEncodeURIComponent(value);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsQueryProtocol.js
var AwsQueryProtocol9;
var init_AwsQueryProtocol10 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsQueryProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib10();
    init_XmlShapeDeserializer10();
    init_QueryShapeSerializer10();
    AwsQueryProtocol9 = class extends RpcProtocol {
      static {
        __name(this, "AwsQueryProtocol");
      }
      options;
      serializer;
      deserializer;
      mixin = new ProtocolLib10();
      constructor(options) {
        super({
          defaultNamespace: options.defaultNamespace,
          errorTypeRegistries: options.errorTypeRegistries
        });
        this.options = options;
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 5
          },
          httpBindings: false,
          xmlNamespace: options.xmlNamespace,
          serviceNamespace: options.defaultNamespace,
          serializeEmptyLists: true
        };
        this.serializer = new QueryShapeSerializer9(settings);
        this.deserializer = new XmlShapeDeserializer9(settings);
      }
      getShapeId() {
        return "aws.protocols#awsQuery";
      }
      setSerdeContext(serdeContext) {
        this.serializer.setSerdeContext(serdeContext);
        this.deserializer.setSerdeContext(serdeContext);
      }
      getPayloadCodec() {
        throw new Error("AWSQuery protocol has no payload codec.");
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        if (!request4.path.endsWith("/")) {
          request4.path += "/";
        }
        request4.headers["content-type"] = "application/x-www-form-urlencoded";
        if (deref(operationSchema.input) === "unit" || !request4.body) {
          request4.body = "";
        }
        const action = operationSchema.name.split("#")[1] ?? operationSchema.name;
        request4.body = `Action=${action}&Version=${this.options.version}` + request4.body;
        if (request4.body.endsWith("&")) {
          request4.body = request4.body.slice(-1);
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        const deserializer = this.deserializer;
        const ns = NormalizedSchema.of(operationSchema.output);
        const dataObject = {};
        if (response.statusCode >= 300) {
          const bytes2 = await collectBody(response.body, context);
          if (bytes2.byteLength > 0) {
            Object.assign(dataObject, await deserializer.read(15, bytes2));
          }
          await this.handleError(operationSchema, context, response, dataObject, this.deserializeMetadata(response));
        }
        for (const header in response.headers) {
          const value = response.headers[header];
          delete response.headers[header];
          response.headers[header.toLowerCase()] = value;
        }
        const shortName = operationSchema.name.split("#")[1] ?? operationSchema.name;
        const awsQueryResultKey = ns.isStructSchema() && this.useNestedResult() ? shortName + "Result" : void 0;
        const bytes = await collectBody(response.body, context);
        if (bytes.byteLength > 0) {
          Object.assign(dataObject, await deserializer.read(ns, bytes, awsQueryResultKey));
        }
        dataObject.$metadata = this.deserializeMetadata(response);
        return dataObject;
      }
      useNestedResult() {
        return true;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = this.loadQueryErrorCode(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const errorData = this.loadQueryError(dataObject) ?? {};
        const message2 = this.loadQueryErrorMessage(dataObject);
        errorData.message = message2;
        errorData.Error = {
          Type: errorData.Type,
          Code: errorData.Code,
          Message: message2
        };
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, errorData, metadata, this.mixin.findQueryCompatibleError);
        const ns = NormalizedSchema.of(errorSchema);
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        const output = {
          Type: errorData.Error.Type,
          Code: errorData.Error.Code,
          Error: errorData.Error
        };
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().xmlName ?? name;
          const value = errorData[target] ?? dataObject[target];
          output[name] = this.deserializer.readSchema(member7, value);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      loadQueryErrorCode(output, data3) {
        const code = (data3.Errors?.[0]?.Error ?? data3.Errors?.Error ?? data3.Error)?.Code;
        if (code !== void 0) {
          return code;
        }
        if (output.statusCode == 404) {
          return "NotFound";
        }
      }
      loadQueryError(data3) {
        return data3.Errors?.[0]?.Error ?? data3.Errors?.Error ?? data3.Error;
      }
      loadQueryErrorMessage(data3) {
        const errorData = this.loadQueryError(data3);
        return errorData?.message ?? errorData?.Message ?? data3.message ?? data3.Message ?? "Unknown";
      }
      getDefaultContentType() {
        return "application/x-www-form-urlencoded";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsEc2QueryProtocol.js
var AwsEc2QueryProtocol8;
var init_AwsEc2QueryProtocol10 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsEc2QueryProtocol.js"() {
    init_AwsQueryProtocol10();
    AwsEc2QueryProtocol8 = class extends AwsQueryProtocol9 {
      static {
        __name(this, "AwsEc2QueryProtocol");
      }
      options;
      constructor(options) {
        super(options);
        this.options = options;
        const ec2Settings = {
          capitalizeKeys: true,
          flattenLists: true,
          serializeEmptyLists: false,
          ec2: true
        };
        Object.assign(this.serializer.settings, ec2Settings);
      }
      getShapeId() {
        return "aws.protocols#ec2Query";
      }
      useNestedResult() {
        return false;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QuerySerializerSettings.js
var init_QuerySerializerSettings10 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QuerySerializerSettings.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/parseXmlBody.js
var import_xml_builder24, import_smithy_client208, parseXmlBody8, parseXmlErrorBody8, loadRestXmlErrorCode8;
var init_parseXmlBody10 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/parseXmlBody.js"() {
    import_xml_builder24 = __toESM(require_dist_cjs47());
    import_smithy_client208 = __toESM(require_dist_cjs34());
    init_common12();
    parseXmlBody8 = /* @__PURE__ */ __name((streamBody, context) => collectBodyString10(streamBody, context).then((encoded) => {
      if (encoded.length) {
        let parsedObj;
        try {
          parsedObj = (0, import_xml_builder24.parseXML)(encoded);
        } catch (e32) {
          if (e32 && typeof e32 === "object") {
            Object.defineProperty(e32, "$responseBodyText", {
              value: encoded
            });
          }
          throw e32;
        }
        const textNodeName = "#text";
        const key = Object.keys(parsedObj)[0];
        const parsedObjToReturn = parsedObj[key];
        if (parsedObjToReturn[textNodeName]) {
          parsedObjToReturn[key] = parsedObjToReturn[textNodeName];
          delete parsedObjToReturn[textNodeName];
        }
        return (0, import_smithy_client208.getValueFromTextNode)(parsedObjToReturn);
      }
      return {};
    }), "parseXmlBody");
    parseXmlErrorBody8 = /* @__PURE__ */ __name(async (errorBody, context) => {
      const value = await parseXmlBody8(errorBody, context);
      if (value.Error) {
        value.Error.message = value.Error.message ?? value.Error.Message;
      }
      return value;
    }, "parseXmlErrorBody");
    loadRestXmlErrorCode8 = /* @__PURE__ */ __name((output, data3) => {
      if (data3?.Error?.Code !== void 0) {
        return data3.Error.Code;
      }
      if (data3?.Code !== void 0) {
        return data3.Code;
      }
      if (output.statusCode == 404) {
        return "NotFound";
      }
    }, "loadRestXmlErrorCode");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeSerializer.js
var import_xml_builder25, import_smithy_client209, import_util_base6457, XmlShapeSerializer8;
var init_XmlShapeSerializer10 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeSerializer.js"() {
    import_xml_builder25 = __toESM(require_dist_cjs47());
    init_protocols();
    init_schema4();
    init_serde();
    import_smithy_client209 = __toESM(require_dist_cjs34());
    import_util_base6457 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext10();
    XmlShapeSerializer8 = class extends SerdeContextConfig10 {
      static {
        __name(this, "XmlShapeSerializer");
      }
      settings;
      stringBuffer;
      byteBuffer;
      buffer;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value) {
        const ns = NormalizedSchema.of(schema);
        if (ns.isStringSchema() && typeof value === "string") {
          this.stringBuffer = value;
        } else if (ns.isBlobSchema()) {
          this.byteBuffer = "byteLength" in value ? value : (this.serdeContext?.base64Decoder ?? import_util_base6457.fromBase64)(value);
        } else {
          this.buffer = this.writeStruct(ns, value, void 0);
          const traits = ns.getMergedTraits();
          if (traits.httpPayload && !traits.xmlName) {
            this.buffer.withName(ns.getName());
          }
        }
      }
      flush() {
        if (this.byteBuffer !== void 0) {
          const bytes = this.byteBuffer;
          delete this.byteBuffer;
          return bytes;
        }
        if (this.stringBuffer !== void 0) {
          const str = this.stringBuffer;
          delete this.stringBuffer;
          return str;
        }
        const buffer = this.buffer;
        if (this.settings.xmlNamespace) {
          if (!buffer?.attributes?.["xmlns"]) {
            buffer.addAttribute("xmlns", this.settings.xmlNamespace);
          }
        }
        delete this.buffer;
        return buffer.toString();
      }
      writeStruct(ns, value, parentXmlns) {
        const traits = ns.getMergedTraits();
        const name = ns.isMemberSchema() && !traits.httpPayload ? ns.getMemberTraits().xmlName ?? ns.getMemberName() : traits.xmlName ?? ns.getName();
        if (!name || !ns.isStructSchema()) {
          throw new Error(`@aws-sdk/core/protocols - xml serializer, cannot write struct with empty name or non-struct, schema=${ns.getName(true)}.`);
        }
        const structXmlNode = import_xml_builder25.XmlNode.of(name);
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(ns, parentXmlns);
        for (const [memberName, memberSchema] of ns.structIterator()) {
          const val = value[memberName];
          if (val != null || memberSchema.isIdempotencyToken()) {
            if (memberSchema.getMergedTraits().xmlAttribute) {
              structXmlNode.addAttribute(memberSchema.getMergedTraits().xmlName ?? memberName, this.writeSimple(memberSchema, val));
              continue;
            }
            if (memberSchema.isListSchema()) {
              this.writeList(memberSchema, val, structXmlNode, xmlns);
            } else if (memberSchema.isMapSchema()) {
              this.writeMap(memberSchema, val, structXmlNode, xmlns);
            } else if (memberSchema.isStructSchema()) {
              structXmlNode.addChildNode(this.writeStruct(memberSchema, val, xmlns));
            } else {
              const memberNode = import_xml_builder25.XmlNode.of(memberSchema.getMergedTraits().xmlName ?? memberSchema.getMemberName());
              this.writeSimpleInto(memberSchema, val, memberNode, xmlns);
              structXmlNode.addChildNode(memberNode);
            }
          }
        }
        const { $unknown } = value;
        if ($unknown && ns.isUnionSchema() && Array.isArray($unknown) && Object.keys(value).length === 1) {
          const [k32, v] = $unknown;
          const node = import_xml_builder25.XmlNode.of(k32);
          if (typeof v !== "string") {
            if (value instanceof import_xml_builder25.XmlNode || value instanceof import_xml_builder25.XmlText) {
              structXmlNode.addChildNode(value);
            } else {
              throw new Error(`@aws-sdk - $unknown union member in XML requires value of type string, @aws-sdk/xml-builder::XmlNode or XmlText.`);
            }
          }
          this.writeSimpleInto(0, v, node, xmlns);
          structXmlNode.addChildNode(node);
        }
        if (xmlns) {
          structXmlNode.addAttribute(xmlnsAttr, xmlns);
        }
        return structXmlNode;
      }
      writeList(listMember, array, container, parentXmlns) {
        if (!listMember.isMemberSchema()) {
          throw new Error(`@aws-sdk/core/protocols - xml serializer, cannot write non-member list: ${listMember.getName(true)}`);
        }
        const listTraits = listMember.getMergedTraits();
        const listValueSchema = listMember.getValueSchema();
        const listValueTraits = listValueSchema.getMergedTraits();
        const sparse = !!listValueTraits.sparse;
        const flat = !!listTraits.xmlFlattened;
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(listMember, parentXmlns);
        const writeItem = /* @__PURE__ */ __name((container2, value) => {
          if (listValueSchema.isListSchema()) {
            this.writeList(listValueSchema, Array.isArray(value) ? value : [value], container2, xmlns);
          } else if (listValueSchema.isMapSchema()) {
            this.writeMap(listValueSchema, value, container2, xmlns);
          } else if (listValueSchema.isStructSchema()) {
            const struct3 = this.writeStruct(listValueSchema, value, xmlns);
            container2.addChildNode(struct3.withName(flat ? listTraits.xmlName ?? listMember.getMemberName() : listValueTraits.xmlName ?? "member"));
          } else {
            const listItemNode = import_xml_builder25.XmlNode.of(flat ? listTraits.xmlName ?? listMember.getMemberName() : listValueTraits.xmlName ?? "member");
            this.writeSimpleInto(listValueSchema, value, listItemNode, xmlns);
            container2.addChildNode(listItemNode);
          }
        }, "writeItem");
        if (flat) {
          for (const value of array) {
            if (sparse || value != null) {
              writeItem(container, value);
            }
          }
        } else {
          const listNode = import_xml_builder25.XmlNode.of(listTraits.xmlName ?? listMember.getMemberName());
          if (xmlns) {
            listNode.addAttribute(xmlnsAttr, xmlns);
          }
          for (const value of array) {
            if (sparse || value != null) {
              writeItem(listNode, value);
            }
          }
          container.addChildNode(listNode);
        }
      }
      writeMap(mapMember, map5, container, parentXmlns, containerIsMap = false) {
        if (!mapMember.isMemberSchema()) {
          throw new Error(`@aws-sdk/core/protocols - xml serializer, cannot write non-member map: ${mapMember.getName(true)}`);
        }
        const mapTraits = mapMember.getMergedTraits();
        const mapKeySchema = mapMember.getKeySchema();
        const mapKeyTraits = mapKeySchema.getMergedTraits();
        const keyTag = mapKeyTraits.xmlName ?? "key";
        const mapValueSchema = mapMember.getValueSchema();
        const mapValueTraits = mapValueSchema.getMergedTraits();
        const valueTag = mapValueTraits.xmlName ?? "value";
        const sparse = !!mapValueTraits.sparse;
        const flat = !!mapTraits.xmlFlattened;
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(mapMember, parentXmlns);
        const addKeyValue = /* @__PURE__ */ __name((entry, key, val) => {
          const keyNode = import_xml_builder25.XmlNode.of(keyTag, key);
          const [keyXmlnsAttr, keyXmlns] = this.getXmlnsAttribute(mapKeySchema, xmlns);
          if (keyXmlns) {
            keyNode.addAttribute(keyXmlnsAttr, keyXmlns);
          }
          entry.addChildNode(keyNode);
          let valueNode = import_xml_builder25.XmlNode.of(valueTag);
          if (mapValueSchema.isListSchema()) {
            this.writeList(mapValueSchema, val, valueNode, xmlns);
          } else if (mapValueSchema.isMapSchema()) {
            this.writeMap(mapValueSchema, val, valueNode, xmlns, true);
          } else if (mapValueSchema.isStructSchema()) {
            valueNode = this.writeStruct(mapValueSchema, val, xmlns);
          } else {
            this.writeSimpleInto(mapValueSchema, val, valueNode, xmlns);
          }
          entry.addChildNode(valueNode);
        }, "addKeyValue");
        if (flat) {
          for (const key in map5) {
            const val = map5[key];
            if (sparse || val != null) {
              const entry = import_xml_builder25.XmlNode.of(mapTraits.xmlName ?? mapMember.getMemberName());
              addKeyValue(entry, key, val);
              container.addChildNode(entry);
            }
          }
        } else {
          let mapNode;
          if (!containerIsMap) {
            mapNode = import_xml_builder25.XmlNode.of(mapTraits.xmlName ?? mapMember.getMemberName());
            if (xmlns) {
              mapNode.addAttribute(xmlnsAttr, xmlns);
            }
            container.addChildNode(mapNode);
          }
          for (const key in map5) {
            const val = map5[key];
            if (sparse || val != null) {
              const entry = import_xml_builder25.XmlNode.of("entry");
              addKeyValue(entry, key, val);
              (containerIsMap ? container : mapNode).addChildNode(entry);
            }
          }
        }
      }
      writeSimple(_schema, value) {
        if (null === value) {
          throw new Error("@aws-sdk/core/protocols - (XML serializer) cannot write null value.");
        }
        const ns = NormalizedSchema.of(_schema);
        let nodeContents = null;
        if (value && typeof value === "object") {
          if (ns.isBlobSchema()) {
            nodeContents = (this.serdeContext?.base64Encoder ?? import_util_base6457.toBase64)(value);
          } else if (ns.isTimestampSchema() && value instanceof Date) {
            const format32 = determineTimestampFormat(ns, this.settings);
            switch (format32) {
              case 5:
                nodeContents = value.toISOString().replace(".000Z", "Z");
                break;
              case 6:
                nodeContents = (0, import_smithy_client209.dateToUtcString)(value);
                break;
              case 7:
                nodeContents = String(value.getTime() / 1e3);
                break;
              default:
                console.warn("Missing timestamp format, using http date", value);
                nodeContents = (0, import_smithy_client209.dateToUtcString)(value);
                break;
            }
          } else if (ns.isBigDecimalSchema() && value) {
            if (value instanceof NumericValue) {
              return value.string;
            }
            return String(value);
          } else if (ns.isMapSchema() || ns.isListSchema()) {
            throw new Error("@aws-sdk/core/protocols - xml serializer, cannot call _write() on List/Map schema, call writeList or writeMap() instead.");
          } else {
            throw new Error(`@aws-sdk/core/protocols - xml serializer, unhandled schema type for object value and schema: ${ns.getName(true)}`);
          }
        }
        if (ns.isBooleanSchema() || ns.isNumericSchema() || ns.isBigIntegerSchema() || ns.isBigDecimalSchema()) {
          nodeContents = String(value);
        }
        if (ns.isStringSchema()) {
          if (value === void 0 && ns.isIdempotencyToken()) {
            nodeContents = (0, import_uuid.v4)();
          } else {
            nodeContents = String(value);
          }
        }
        if (nodeContents === null) {
          throw new Error(`Unhandled schema-value pair ${ns.getName(true)}=${value}`);
        }
        return nodeContents;
      }
      writeSimpleInto(_schema, value, into, parentXmlns) {
        const nodeContents = this.writeSimple(_schema, value);
        const ns = NormalizedSchema.of(_schema);
        const content = new import_xml_builder25.XmlText(nodeContents);
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(ns, parentXmlns);
        if (xmlns) {
          into.addAttribute(xmlnsAttr, xmlns);
        }
        into.addChildNode(content);
      }
      getXmlnsAttribute(ns, parentXmlns) {
        const traits = ns.getMergedTraits();
        const [prefix, xmlns] = traits.xmlNamespace ?? [];
        if (xmlns && xmlns !== parentXmlns) {
          return [prefix ? `xmlns:${prefix}` : "xmlns", xmlns];
        }
        return [void 0, void 0];
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlCodec.js
var XmlCodec8;
var init_XmlCodec10 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlCodec.js"() {
    init_ConfigurableSerdeContext10();
    init_XmlShapeDeserializer10();
    init_XmlShapeSerializer10();
    XmlCodec8 = class extends SerdeContextConfig10 {
      static {
        __name(this, "XmlCodec");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      createSerializer() {
        const serializer = new XmlShapeSerializer8(this.settings);
        serializer.setSerdeContext(this.serdeContext);
        return serializer;
      }
      createDeserializer() {
        const deserializer = new XmlShapeDeserializer9(this.settings);
        deserializer.setSerdeContext(this.serdeContext);
        return deserializer;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/AwsRestXmlProtocol.js
var AwsRestXmlProtocol8;
var init_AwsRestXmlProtocol10 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/AwsRestXmlProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib10();
    init_parseXmlBody10();
    init_XmlCodec10();
    AwsRestXmlProtocol8 = class extends HttpBindingProtocol {
      static {
        __name(this, "AwsRestXmlProtocol");
      }
      codec;
      serializer;
      deserializer;
      mixin = new ProtocolLib10();
      constructor(options) {
        super(options);
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 5
          },
          httpBindings: true,
          xmlNamespace: options.xmlNamespace,
          serviceNamespace: options.defaultNamespace
        };
        this.codec = new XmlCodec8(settings);
        this.serializer = new HttpInterceptingShapeSerializer(this.codec.createSerializer(), settings);
        this.deserializer = new HttpInterceptingShapeDeserializer(this.codec.createDeserializer(), settings);
      }
      getPayloadCodec() {
        return this.codec;
      }
      getShapeId() {
        return "aws.protocols#restXml";
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        const inputSchema = NormalizedSchema.of(operationSchema.input);
        if (!request4.headers["content-type"]) {
          const contentType = this.mixin.resolveRestContentType(this.getDefaultContentType(), inputSchema);
          if (contentType) {
            request4.headers["content-type"] = contentType;
          }
        }
        if (typeof request4.body === "string" && request4.headers["content-type"] === this.getDefaultContentType() && !request4.body.startsWith("<?xml ") && !this.hasUnstructuredPayloadBinding(inputSchema)) {
          request4.body = '<?xml version="1.0" encoding="UTF-8"?>' + request4.body;
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        return super.deserializeResponse(operationSchema, context, response);
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = loadRestXmlErrorCode8(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        if (dataObject.Error && typeof dataObject.Error === "object") {
          for (const key of Object.keys(dataObject.Error)) {
            dataObject[key] = dataObject.Error[key];
            if (key.toLowerCase() === "message") {
              dataObject.message = dataObject.Error[key];
            }
          }
        }
        if (dataObject.RequestId && !metadata.requestId) {
          metadata.requestId = dataObject.RequestId;
        }
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.Error?.message ?? dataObject.Error?.Message ?? dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        await this.deserializeHttpMessage(errorSchema, context, response, dataObject);
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().xmlName ?? name;
          const value = dataObject.Error?.[target] ?? dataObject[target];
          output[name] = errorDeserializer.readSchema(member7, value);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      getDefaultContentType() {
        return "application/xml";
      }
      hasUnstructuredPayloadBinding(ns) {
        for (const [, member7] of ns.structIterator()) {
          if (member7.getMergedTraits().httpPayload) {
            return !(member7.isStructSchema() || member7.isMapSchema() || member7.isListSchema());
          }
        }
        return false;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/index.js
var protocols_exports14 = {};
__export(protocols_exports14, {
  AwsEc2QueryProtocol: () => AwsEc2QueryProtocol8,
  AwsJson1_0Protocol: () => AwsJson1_0Protocol8,
  AwsJson1_1Protocol: () => AwsJson1_1Protocol8,
  AwsJsonRpcProtocol: () => AwsJsonRpcProtocol8,
  AwsQueryProtocol: () => AwsQueryProtocol9,
  AwsRestJsonProtocol: () => AwsRestJsonProtocol10,
  AwsRestXmlProtocol: () => AwsRestXmlProtocol8,
  AwsSmithyRpcV2CborProtocol: () => AwsSmithyRpcV2CborProtocol8,
  JsonCodec: () => JsonCodec10,
  JsonShapeDeserializer: () => JsonShapeDeserializer10,
  JsonShapeSerializer: () => JsonShapeSerializer10,
  QueryShapeSerializer: () => QueryShapeSerializer9,
  XmlCodec: () => XmlCodec8,
  XmlShapeDeserializer: () => XmlShapeDeserializer9,
  XmlShapeSerializer: () => XmlShapeSerializer8,
  _toBool: () => _toBool8,
  _toNum: () => _toNum8,
  _toStr: () => _toStr8,
  awsExpectUnion: () => awsExpectUnion8,
  loadRestJsonErrorCode: () => loadRestJsonErrorCode10,
  loadRestXmlErrorCode: () => loadRestXmlErrorCode8,
  parseJsonBody: () => parseJsonBody10,
  parseJsonErrorBody: () => parseJsonErrorBody8,
  parseXmlBody: () => parseXmlBody8,
  parseXmlErrorBody: () => parseXmlErrorBody8
});
var init_protocols17 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/core/dist-es/submodules/protocols/index.js"() {
    init_AwsSmithyRpcV2CborProtocol10();
    init_coercing_serializers10();
    init_AwsJson1_0Protocol10();
    init_AwsJson1_1Protocol10();
    init_AwsJsonRpcProtocol10();
    init_AwsRestJsonProtocol10();
    init_JsonCodec10();
    init_JsonShapeDeserializer10();
    init_JsonShapeSerializer10();
    init_awsExpectUnion10();
    init_parseJsonBody10();
    init_AwsEc2QueryProtocol10();
    init_AwsQueryProtocol10();
    init_QuerySerializerSettings10();
    init_QueryShapeSerializer10();
    init_AwsRestXmlProtocol10();
    init_XmlCodec10();
    init_XmlShapeDeserializer10();
    init_XmlShapeSerializer10();
    init_parseXmlBody10();
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/bdd.js
var import_util_endpoints64, k26, a26, b26, c26, d26, e26, f26, g26, h26, i26, j26, _data26, root26, r26, nodes26, bdd26;
var init_bdd26 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/bdd.js"() {
    import_util_endpoints64 = __toESM(require_dist_cjs20());
    k26 = "ref";
    a26 = -1;
    b26 = true;
    c26 = "isSet";
    d26 = "PartitionResult";
    e26 = "booleanEquals";
    f26 = "getAttr";
    g26 = { [k26]: "Endpoint" };
    h26 = { [k26]: d26 };
    i26 = {};
    j26 = [{ [k26]: "Region" }];
    _data26 = {
      conditions: [
        [c26, [g26]],
        [c26, j26],
        ["aws.partition", j26, d26],
        [e26, [{ [k26]: "UseFIPS" }, b26]],
        [e26, [{ [k26]: "UseDualStack" }, b26]],
        [e26, [{ fn: f26, argv: [h26, "supportsDualStack"] }, b26]],
        [e26, [{ fn: f26, argv: [h26, "supportsFIPS"] }, b26]],
        ["stringEquals", [{ fn: f26, argv: [h26, "name"] }, "aws-us-gov"]]
      ],
      results: [
        [a26],
        [a26, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a26, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [g26, i26],
        ["https://portal.sso-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", i26],
        [a26, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://portal.sso.{Region}.amazonaws.com", i26],
        ["https://portal.sso-fips.{Region}.{PartitionResult#dnsSuffix}", i26],
        [a26, "FIPS is enabled but this partition does not support FIPS"],
        ["https://portal.sso.{Region}.{PartitionResult#dualStackDnsSuffix}", i26],
        [a26, "DualStack is enabled but this partition does not support DualStack"],
        ["https://portal.sso.{Region}.{PartitionResult#dnsSuffix}", i26],
        [a26, "Invalid Configuration: Missing Region"]
      ]
    };
    root26 = 2;
    r26 = 1e8;
    nodes26 = new Int32Array([
      -1,
      1,
      -1,
      0,
      13,
      3,
      1,
      4,
      r26 + 12,
      2,
      5,
      r26 + 12,
      3,
      8,
      6,
      4,
      7,
      r26 + 11,
      5,
      r26 + 9,
      r26 + 10,
      4,
      11,
      9,
      6,
      10,
      r26 + 8,
      7,
      r26 + 6,
      r26 + 7,
      5,
      12,
      r26 + 5,
      6,
      r26 + 4,
      r26 + 5,
      3,
      r26 + 1,
      14,
      4,
      r26 + 2,
      r26 + 3
    ]);
    bdd26 = import_util_endpoints64.BinaryDecisionDiagram.from(nodes26, root26, _data26.conditions, _data26.results);
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/endpointResolver.js
var import_util_endpoints65, import_util_endpoints66, cache26, defaultEndpointResolver26;
var init_endpointResolver26 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/endpointResolver.js"() {
    import_util_endpoints65 = __toESM(require_dist_cjs21());
    import_util_endpoints66 = __toESM(require_dist_cjs20());
    init_bdd26();
    cache26 = new import_util_endpoints66.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    defaultEndpointResolver26 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache26.get(endpointParams, () => (0, import_util_endpoints66.decideEndpoint)(bdd26, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    import_util_endpoints66.customEndpointFunctions.aws = import_util_endpoints65.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/SSOServiceException.js
var import_smithy_client210, SSOServiceException8;
var init_SSOServiceException8 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/SSOServiceException.js"() {
    import_smithy_client210 = __toESM(require_dist_cjs34());
    SSOServiceException8 = class _SSOServiceException extends import_smithy_client210.ServiceException {
      static {
        __name(this, "SSOServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _SSOServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/errors.js
var InvalidRequestException11, ResourceNotFoundException9, TooManyRequestsException9, UnauthorizedException8;
var init_errors26 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/errors.js"() {
    init_SSOServiceException8();
    InvalidRequestException11 = class _InvalidRequestException extends SSOServiceException8 {
      static {
        __name(this, "InvalidRequestException");
      }
      name = "InvalidRequestException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidRequestException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidRequestException.prototype);
      }
    };
    ResourceNotFoundException9 = class _ResourceNotFoundException extends SSOServiceException8 {
      static {
        __name(this, "ResourceNotFoundException");
      }
      name = "ResourceNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ResourceNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceNotFoundException.prototype);
      }
    };
    TooManyRequestsException9 = class _TooManyRequestsException extends SSOServiceException8 {
      static {
        __name(this, "TooManyRequestsException");
      }
      name = "TooManyRequestsException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TooManyRequestsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyRequestsException.prototype);
      }
    };
    UnauthorizedException8 = class _UnauthorizedException extends SSOServiceException8 {
      static {
        __name(this, "UnauthorizedException");
      }
      name = "UnauthorizedException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "UnauthorizedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnauthorizedException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/schemas/schemas_0.js
var _ATT8, _GRC8, _GRCR8, _GRCRe8, _IRE11, _RC8, _RNFE9, _SAKT8, _STT8, _TMRE16, _UE8, _aI8, _aKI15, _aT18, _ai8, _c26, _e26, _ex8, _h18, _hE26, _hH8, _hQ8, _m23, _rC8, _rN8, _rn8, _s26, _sAK15, _sT15, _xasbt8, n026, _s_registry26, SSOServiceException$8, n0_registry26, InvalidRequestException$11, ResourceNotFoundException$9, TooManyRequestsException$9, UnauthorizedException$8, errorTypeRegistries26, AccessTokenType8, SecretAccessKeyType8, SessionTokenType8, GetRoleCredentialsRequest$8, GetRoleCredentialsResponse$8, RoleCredentials$8, GetRoleCredentials$8;
var init_schemas_026 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/schemas/schemas_0.js"() {
    init_schema4();
    init_errors26();
    init_SSOServiceException8();
    _ATT8 = "AccessTokenType";
    _GRC8 = "GetRoleCredentials";
    _GRCR8 = "GetRoleCredentialsRequest";
    _GRCRe8 = "GetRoleCredentialsResponse";
    _IRE11 = "InvalidRequestException";
    _RC8 = "RoleCredentials";
    _RNFE9 = "ResourceNotFoundException";
    _SAKT8 = "SecretAccessKeyType";
    _STT8 = "SessionTokenType";
    _TMRE16 = "TooManyRequestsException";
    _UE8 = "UnauthorizedException";
    _aI8 = "accountId";
    _aKI15 = "accessKeyId";
    _aT18 = "accessToken";
    _ai8 = "account_id";
    _c26 = "client";
    _e26 = "error";
    _ex8 = "expiration";
    _h18 = "http";
    _hE26 = "httpError";
    _hH8 = "httpHeader";
    _hQ8 = "httpQuery";
    _m23 = "message";
    _rC8 = "roleCredentials";
    _rN8 = "roleName";
    _rn8 = "role_name";
    _s26 = "smithy.ts.sdk.synthetic.com.amazonaws.sso";
    _sAK15 = "secretAccessKey";
    _sT15 = "sessionToken";
    _xasbt8 = "x-amz-sso_bearer_token";
    n026 = "com.amazonaws.sso";
    _s_registry26 = TypeRegistry.for(_s26);
    SSOServiceException$8 = [-3, _s26, "SSOServiceException", 0, [], []];
    _s_registry26.registerError(SSOServiceException$8, SSOServiceException8);
    n0_registry26 = TypeRegistry.for(n026);
    InvalidRequestException$11 = [-3, n026, _IRE11, { [_e26]: _c26, [_hE26]: 400 }, [_m23], [0]];
    n0_registry26.registerError(InvalidRequestException$11, InvalidRequestException11);
    ResourceNotFoundException$9 = [-3, n026, _RNFE9, { [_e26]: _c26, [_hE26]: 404 }, [_m23], [0]];
    n0_registry26.registerError(ResourceNotFoundException$9, ResourceNotFoundException9);
    TooManyRequestsException$9 = [-3, n026, _TMRE16, { [_e26]: _c26, [_hE26]: 429 }, [_m23], [0]];
    n0_registry26.registerError(TooManyRequestsException$9, TooManyRequestsException9);
    UnauthorizedException$8 = [-3, n026, _UE8, { [_e26]: _c26, [_hE26]: 401 }, [_m23], [0]];
    n0_registry26.registerError(UnauthorizedException$8, UnauthorizedException8);
    errorTypeRegistries26 = [_s_registry26, n0_registry26];
    AccessTokenType8 = [0, n026, _ATT8, 8, 0];
    SecretAccessKeyType8 = [0, n026, _SAKT8, 8, 0];
    SessionTokenType8 = [0, n026, _STT8, 8, 0];
    GetRoleCredentialsRequest$8 = [
      3,
      n026,
      _GRCR8,
      0,
      [_rN8, _aI8, _aT18],
      [
        [0, { [_hQ8]: _rn8 }],
        [0, { [_hQ8]: _ai8 }],
        [() => AccessTokenType8, { [_hH8]: _xasbt8 }]
      ],
      3
    ];
    GetRoleCredentialsResponse$8 = [
      3,
      n026,
      _GRCRe8,
      0,
      [_rC8],
      [[() => RoleCredentials$8, 0]]
    ];
    RoleCredentials$8 = [
      3,
      n026,
      _RC8,
      0,
      [_aKI15, _sAK15, _sT15, _ex8],
      [0, [() => SecretAccessKeyType8, 0], [() => SessionTokenType8, 0], 1]
    ];
    GetRoleCredentials$8 = [
      9,
      n026,
      _GRC8,
      { [_h18]: ["GET", "/federation/credentials", 200] },
      () => GetRoleCredentialsRequest$8,
      () => GetRoleCredentialsResponse$8
    ];
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.shared.js
var import_smithy_client211, import_url_parser23, import_util_base6458, import_util_utf844, getRuntimeConfig51;
var init_runtimeConfig_shared26 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.shared.js"() {
    init_httpAuthSchemes11();
    init_protocols17();
    init_dist_es();
    import_smithy_client211 = __toESM(require_dist_cjs34());
    import_url_parser23 = __toESM(require_dist_cjs18());
    import_util_base6458 = __toESM(require_dist_cjs10());
    import_util_utf844 = __toESM(require_dist_cjs9());
    init_httpAuthSchemeProvider26();
    init_endpointResolver26();
    init_schemas_026();
    getRuntimeConfig51 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2019-06-10",
        base64Decoder: config2?.base64Decoder ?? import_util_base6458.fromBase64,
        base64Encoder: config2?.base64Encoder ?? import_util_base6458.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver26,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSSOHttpAuthSchemeProvider8,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer9()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        logger: config2?.logger ?? new import_smithy_client211.NoOpLogger(),
        protocol: config2?.protocol ?? AwsRestJsonProtocol10,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.sso",
          errorTypeRegistries: errorTypeRegistries26,
          version: "2019-06-10",
          serviceTarget: "SWBPortalService"
        },
        serviceId: config2?.serviceId ?? "SSO",
        urlParser: config2?.urlParser ?? import_url_parser23.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? import_util_utf844.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? import_util_utf844.toUtf8
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.js
var import_util_user_agent_node22, import_config_resolver44, import_hash_node24, import_middleware_retry43, import_node_config_provider23, import_node_http_handler26, import_smithy_client212, import_util_body_length_node22, import_util_defaults_mode_node22, import_util_retry32, getRuntimeConfig52;
var init_runtimeConfig26 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.js"() {
    init_package9();
    init_client18();
    init_httpAuthSchemes11();
    import_util_user_agent_node22 = __toESM(require_dist_cjs185());
    import_config_resolver44 = __toESM(require_dist_cjs25());
    import_hash_node24 = __toESM(require_dist_cjs44());
    import_middleware_retry43 = __toESM(require_dist_cjs181());
    import_node_config_provider23 = __toESM(require_dist_cjs29());
    import_node_http_handler26 = __toESM(require_dist_cjs13());
    import_smithy_client212 = __toESM(require_dist_cjs34());
    import_util_body_length_node22 = __toESM(require_dist_cjs45());
    import_util_defaults_mode_node22 = __toESM(require_dist_cjs46());
    import_util_retry32 = __toESM(require_dist_cjs22());
    init_runtimeConfig_shared26();
    getRuntimeConfig52 = /* @__PURE__ */ __name((config2) => {
      (0, import_smithy_client212.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, import_util_defaults_mode_node22.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(import_smithy_client212.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig51(config2);
      emitWarningIfUnsupportedVersion34(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, import_node_config_provider23.loadConfig)(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS9, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? import_util_body_length_node22.calculateBodyLength,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, import_util_user_agent_node22.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_default9.version }),
        maxAttempts: config2?.maxAttempts ?? (0, import_node_config_provider23.loadConfig)(import_middleware_retry43.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, import_node_config_provider23.loadConfig)(import_config_resolver44.NODE_REGION_CONFIG_OPTIONS, { ...import_config_resolver44.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: import_node_http_handler26.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, import_node_config_provider23.loadConfig)({
          ...import_middleware_retry43.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || import_util_retry32.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? import_hash_node24.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? import_node_http_handler26.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, import_node_config_provider23.loadConfig)(import_config_resolver44.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, import_node_config_provider23.loadConfig)(import_config_resolver44.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, import_node_config_provider23.loadConfig)(import_util_user_agent_node22.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration26, resolveHttpAuthRuntimeConfig26;
var init_httpAuthExtensionConfiguration26 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration26 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig26 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeExtensions.js
var import_region_config_resolver28, import_protocol_http54, import_smithy_client213, resolveRuntimeExtensions26;
var init_runtimeExtensions26 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeExtensions.js"() {
    import_region_config_resolver28 = __toESM(require_dist_cjs48());
    import_protocol_http54 = __toESM(require_dist_cjs2());
    import_smithy_client213 = __toESM(require_dist_cjs34());
    init_httpAuthExtensionConfiguration26();
    resolveRuntimeExtensions26 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign((0, import_region_config_resolver28.getAwsRegionExtensionConfiguration)(runtimeConfig), (0, import_smithy_client213.getDefaultExtensionConfiguration)(runtimeConfig), (0, import_protocol_http54.getHttpHandlerExtensionConfiguration)(runtimeConfig), getHttpAuthExtensionConfiguration26(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, (0, import_region_config_resolver28.resolveAwsRegionExtensionConfiguration)(extensionConfiguration), (0, import_smithy_client213.resolveDefaultRuntimeConfig)(extensionConfiguration), (0, import_protocol_http54.resolveHttpHandlerRuntimeConfig)(extensionConfiguration), resolveHttpAuthRuntimeConfig26(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSOClient.js
var import_middleware_host_header22, import_middleware_logger22, import_middleware_recursion_detection22, import_middleware_user_agent22, import_config_resolver45, import_middleware_content_length22, import_middleware_endpoint57, import_middleware_retry44, import_smithy_client214, SSOClient8;
var init_SSOClient8 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSOClient.js"() {
    import_middleware_host_header22 = __toESM(require_dist_cjs3());
    import_middleware_logger22 = __toESM(require_dist_cjs4());
    import_middleware_recursion_detection22 = __toESM(require_dist_cjs5());
    import_middleware_user_agent22 = __toESM(require_dist_cjs180());
    import_config_resolver45 = __toESM(require_dist_cjs25());
    init_dist_es();
    init_schema4();
    import_middleware_content_length22 = __toESM(require_dist_cjs26());
    import_middleware_endpoint57 = __toESM(require_dist_cjs31());
    import_middleware_retry44 = __toESM(require_dist_cjs181());
    import_smithy_client214 = __toESM(require_dist_cjs34());
    init_httpAuthSchemeProvider26();
    init_EndpointParameters26();
    init_runtimeConfig26();
    init_runtimeExtensions26();
    SSOClient8 = class extends import_smithy_client214.Client {
      static {
        __name(this, "SSOClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig52(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters26(_config_0);
        const _config_2 = (0, import_middleware_user_agent22.resolveUserAgentConfig)(_config_1);
        const _config_3 = (0, import_middleware_retry44.resolveRetryConfig)(_config_2);
        const _config_4 = (0, import_config_resolver45.resolveRegionConfig)(_config_3);
        const _config_5 = (0, import_middleware_host_header22.resolveHostHeaderConfig)(_config_4);
        const _config_6 = (0, import_middleware_endpoint57.resolveEndpointConfig)(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig26(_config_6);
        const _config_8 = resolveRuntimeExtensions26(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin(this.config));
        this.middlewareStack.use((0, import_middleware_user_agent22.getUserAgentPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_retry44.getRetryPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_content_length22.getContentLengthPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_host_header22.getHostHeaderPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_logger22.getLoggerPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_recursion_detection22.getRecursionDetectionPlugin)(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: defaultSSOHttpAuthSchemeParametersProvider8,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/GetRoleCredentialsCommand.js
var import_middleware_endpoint58, import_smithy_client215, GetRoleCredentialsCommand8;
var init_GetRoleCredentialsCommand8 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/GetRoleCredentialsCommand.js"() {
    import_middleware_endpoint58 = __toESM(require_dist_cjs31());
    import_smithy_client215 = __toESM(require_dist_cjs34());
    init_EndpointParameters26();
    init_schemas_026();
    GetRoleCredentialsCommand8 = class extends import_smithy_client215.Command.classBuilder().ep(commonParams26).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint58.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("SWBPortalService", "GetRoleCredentials", {}).n("SSOClient", "GetRoleCredentialsCommand").sc(GetRoleCredentials$8).build() {
      static {
        __name(this, "GetRoleCredentialsCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSO.js
var import_smithy_client216, commands26, SSO8;
var init_SSO8 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSO.js"() {
    import_smithy_client216 = __toESM(require_dist_cjs34());
    init_GetRoleCredentialsCommand8();
    init_SSOClient8();
    commands26 = {
      GetRoleCredentialsCommand: GetRoleCredentialsCommand8
    };
    SSO8 = class extends SSOClient8 {
      static {
        __name(this, "SSO");
      }
    };
    (0, import_smithy_client216.createAggregatedClient)(commands26, SSO8);
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/index.js
var init_commands27 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/index.js"() {
    init_GetRoleCredentialsCommand8();
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/models_0.js
var init_models_026 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/index.js
var sso_exports8 = {};
__export(sso_exports8, {
  $Command: () => import_smithy_client215.Command,
  GetRoleCredentials$: () => GetRoleCredentials$8,
  GetRoleCredentialsCommand: () => GetRoleCredentialsCommand8,
  GetRoleCredentialsRequest$: () => GetRoleCredentialsRequest$8,
  GetRoleCredentialsResponse$: () => GetRoleCredentialsResponse$8,
  InvalidRequestException: () => InvalidRequestException11,
  InvalidRequestException$: () => InvalidRequestException$11,
  ResourceNotFoundException: () => ResourceNotFoundException9,
  ResourceNotFoundException$: () => ResourceNotFoundException$9,
  RoleCredentials$: () => RoleCredentials$8,
  SSO: () => SSO8,
  SSOClient: () => SSOClient8,
  SSOServiceException: () => SSOServiceException8,
  SSOServiceException$: () => SSOServiceException$8,
  TooManyRequestsException: () => TooManyRequestsException9,
  TooManyRequestsException$: () => TooManyRequestsException$9,
  UnauthorizedException: () => UnauthorizedException8,
  UnauthorizedException$: () => UnauthorizedException$8,
  __Client: () => import_smithy_client214.Client,
  errorTypeRegistries: () => errorTypeRegistries26
});
var init_sso8 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/index.js"() {
    init_SSOClient8();
    init_SSO8();
    init_commands27();
    init_schemas_026();
    init_errors26();
    init_models_026();
    init_SSOServiceException8();
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/loadSso-BKDNrsal.js
var require_loadSso_BKDNrsal8 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/loadSso-BKDNrsal.js"(exports2) {
    "use strict";
    var sso = (init_sso8(), __toCommonJS(sso_exports8));
    exports2.GetRoleCredentialsCommand = sso.GetRoleCredentialsCommand;
    exports2.SSOClient = sso.SSOClient;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/index.js
var require_dist_cjs186 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/index.js"(exports2) {
    "use strict";
    var propertyProvider = require_dist_cjs27();
    var sharedIniFileLoader = require_dist_cjs28();
    var client = (init_client18(), __toCommonJS(client_exports13));
    var tokenProviders = require_dist_cjs49();
    var isSsoProfile = /* @__PURE__ */ __name((arg) => arg && (typeof arg.sso_start_url === "string" || typeof arg.sso_account_id === "string" || typeof arg.sso_session === "string" || typeof arg.sso_region === "string" || typeof arg.sso_role_name === "string"), "isSsoProfile");
    var SHOULD_FAIL_CREDENTIAL_CHAIN = false;
    var resolveSSOCredentials = /* @__PURE__ */ __name(async ({ ssoStartUrl, ssoSession, ssoAccountId, ssoRegion, ssoRoleName, ssoClient, clientConfig, parentClientConfig, callerClientConfig, profile, filepath, configFilepath, ignoreCache, logger: logger5 }) => {
      let token;
      const refreshMessage = `To refresh this SSO session run aws sso login with the corresponding profile.`;
      if (ssoSession) {
        try {
          const _token = await tokenProviders.fromSso({
            profile,
            filepath,
            configFilepath,
            ignoreCache
          })();
          token = {
            accessToken: _token.token,
            expiresAt: new Date(_token.expiration).toISOString()
          };
        } catch (e32) {
          throw new propertyProvider.CredentialsProviderError(e32.message, {
            tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
            logger: logger5
          });
        }
      } else {
        try {
          token = await sharedIniFileLoader.getSSOTokenFromFile(ssoStartUrl);
        } catch (e32) {
          throw new propertyProvider.CredentialsProviderError(`The SSO session associated with this profile is invalid. ${refreshMessage}`, {
            tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
            logger: logger5
          });
        }
      }
      if (new Date(token.expiresAt).getTime() - Date.now() <= 0) {
        throw new propertyProvider.CredentialsProviderError(`The SSO session associated with this profile has expired. ${refreshMessage}`, {
          tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
          logger: logger5
        });
      }
      const { accessToken } = token;
      const { SSOClient: SSOClient10, GetRoleCredentialsCommand: GetRoleCredentialsCommand10 } = await Promise.resolve().then(function() {
        return require_loadSso_BKDNrsal8();
      });
      const sso = ssoClient || new SSOClient10(Object.assign({}, clientConfig ?? {}, {
        logger: clientConfig?.logger ?? callerClientConfig?.logger ?? parentClientConfig?.logger,
        region: clientConfig?.region ?? ssoRegion,
        userAgentAppId: clientConfig?.userAgentAppId ?? callerClientConfig?.userAgentAppId ?? parentClientConfig?.userAgentAppId
      }));
      let ssoResp;
      try {
        ssoResp = await sso.send(new GetRoleCredentialsCommand10({
          accountId: ssoAccountId,
          roleName: ssoRoleName,
          accessToken
        }));
      } catch (e32) {
        throw new propertyProvider.CredentialsProviderError(e32, {
          tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
          logger: logger5
        });
      }
      const { roleCredentials: { accessKeyId, secretAccessKey, sessionToken, expiration, credentialScope, accountId } = {} } = ssoResp;
      if (!accessKeyId || !secretAccessKey || !sessionToken || !expiration) {
        throw new propertyProvider.CredentialsProviderError("SSO returns an invalid temporary credential.", {
          tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
          logger: logger5
        });
      }
      const credentials = {
        accessKeyId,
        secretAccessKey,
        sessionToken,
        expiration: new Date(expiration),
        ...credentialScope && { credentialScope },
        ...accountId && { accountId }
      };
      if (ssoSession) {
        client.setCredentialFeature(credentials, "CREDENTIALS_SSO", "s");
      } else {
        client.setCredentialFeature(credentials, "CREDENTIALS_SSO_LEGACY", "u");
      }
      return credentials;
    }, "resolveSSOCredentials");
    var validateSsoProfile = /* @__PURE__ */ __name((profile, logger5) => {
      const { sso_start_url, sso_account_id, sso_region, sso_role_name } = profile;
      if (!sso_start_url || !sso_account_id || !sso_region || !sso_role_name) {
        throw new propertyProvider.CredentialsProviderError(`Profile is configured with invalid SSO credentials. Required parameters "sso_account_id", "sso_region", "sso_role_name", "sso_start_url". Got ${Object.keys(profile).join(", ")}
Reference: https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-sso.html`, { tryNextLink: false, logger: logger5 });
      }
      return profile;
    }, "validateSsoProfile");
    var fromSSO = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/credential-provider-sso - fromSSO");
      const { ssoStartUrl, ssoAccountId, ssoRegion, ssoRoleName, ssoSession } = init;
      const { ssoClient } = init;
      const profileName = sharedIniFileLoader.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      });
      if (!ssoStartUrl && !ssoAccountId && !ssoRegion && !ssoRoleName && !ssoSession) {
        const profiles = await sharedIniFileLoader.parseKnownFiles(init);
        const profile = profiles[profileName];
        if (!profile) {
          throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} was not found.`, { logger: init.logger });
        }
        if (!isSsoProfile(profile)) {
          throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} is not configured with SSO credentials.`, {
            logger: init.logger
          });
        }
        if (profile?.sso_session) {
          const ssoSessions = await sharedIniFileLoader.loadSsoSessionData(init);
          const session = ssoSessions[profile.sso_session];
          const conflictMsg = ` configurations in profile ${profileName} and sso-session ${profile.sso_session}`;
          if (ssoRegion && ssoRegion !== session.sso_region) {
            throw new propertyProvider.CredentialsProviderError(`Conflicting SSO region` + conflictMsg, {
              tryNextLink: false,
              logger: init.logger
            });
          }
          if (ssoStartUrl && ssoStartUrl !== session.sso_start_url) {
            throw new propertyProvider.CredentialsProviderError(`Conflicting SSO start_url` + conflictMsg, {
              tryNextLink: false,
              logger: init.logger
            });
          }
          profile.sso_region = session.sso_region;
          profile.sso_start_url = session.sso_start_url;
        }
        const { sso_start_url, sso_account_id, sso_region, sso_role_name, sso_session } = validateSsoProfile(profile, init.logger);
        return resolveSSOCredentials({
          ssoStartUrl: sso_start_url,
          ssoSession: sso_session,
          ssoAccountId: sso_account_id,
          ssoRegion: sso_region,
          ssoRoleName: sso_role_name,
          ssoClient,
          clientConfig: init.clientConfig,
          parentClientConfig: init.parentClientConfig,
          callerClientConfig: init.callerClientConfig,
          profile: profileName,
          filepath: init.filepath,
          configFilepath: init.configFilepath,
          ignoreCache: init.ignoreCache,
          logger: init.logger
        });
      } else if (!ssoStartUrl || !ssoAccountId || !ssoRegion || !ssoRoleName) {
        throw new propertyProvider.CredentialsProviderError('Incomplete configuration. The fromSSO() argument hash must include "ssoStartUrl", "ssoAccountId", "ssoRegion", "ssoRoleName"', { tryNextLink: false, logger: init.logger });
      } else {
        return resolveSSOCredentials({
          ssoStartUrl,
          ssoSession,
          ssoAccountId,
          ssoRegion,
          ssoRoleName,
          ssoClient,
          clientConfig: init.clientConfig,
          parentClientConfig: init.parentClientConfig,
          callerClientConfig: init.callerClientConfig,
          profile: profileName,
          filepath: init.filepath,
          configFilepath: init.configFilepath,
          ignoreCache: init.ignoreCache,
          logger: init.logger
        });
      }
    }, "fromSSO");
    exports2.fromSSO = fromSSO;
    exports2.isSsoProfile = isSsoProfile;
    exports2.validateSsoProfile = validateSsoProfile;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption27(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "signin",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption27(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var import_util_middleware28, defaultSigninHttpAuthSchemeParametersProvider8, defaultSigninHttpAuthSchemeProvider8, resolveHttpAuthSchemeConfig27;
var init_httpAuthSchemeProvider27 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes11();
    import_util_middleware28 = __toESM(require_dist_cjs6());
    defaultSigninHttpAuthSchemeParametersProvider8 = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, import_util_middleware28.getSmithyContext)(context).operation,
        region: await (0, import_util_middleware28.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultSigninHttpAuthSchemeParametersProvider");
    __name(createAwsAuthSigv4HttpAuthOption27, "createAwsAuthSigv4HttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption27, "createSmithyApiNoAuthHttpAuthOption");
    defaultSigninHttpAuthSchemeProvider8 = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "CreateOAuth2Token": {
          options.push(createSmithyApiNoAuthHttpAuthOption27(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption27(authParameters));
        }
      }
      return options;
    }, "defaultSigninHttpAuthSchemeProvider");
    resolveHttpAuthSchemeConfig27 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveAwsSdkSigV4Config9(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, import_util_middleware28.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/EndpointParameters.js
var resolveClientEndpointParameters27, commonParams27;
var init_EndpointParameters27 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters27 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "signin"
      });
    }, "resolveClientEndpointParameters");
    commonParams27 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/bdd.js
var import_util_endpoints67, m16, a27, b27, c27, d27, e27, f27, g27, h27, i27, j27, k27, l16, _data27, root27, r27, nodes27, bdd27;
var init_bdd27 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/bdd.js"() {
    import_util_endpoints67 = __toESM(require_dist_cjs20());
    m16 = "ref";
    a27 = -1;
    b27 = true;
    c27 = "isSet";
    d27 = "PartitionResult";
    e27 = "booleanEquals";
    f27 = "getAttr";
    g27 = "stringEquals";
    h27 = { [m16]: "Endpoint" };
    i27 = { [m16]: d27 };
    j27 = { fn: f27, argv: [i27, "name"] };
    k27 = {};
    l16 = [{ [m16]: "Region" }];
    _data27 = {
      conditions: [
        [c27, [h27]],
        [c27, l16],
        ["aws.partition", l16, d27],
        [e27, [{ [m16]: "UseFIPS" }, b27]],
        [e27, [{ [m16]: "UseDualStack" }, b27]],
        [e27, [{ fn: f27, argv: [i27, "supportsDualStack"] }, b27]],
        [e27, [{ fn: f27, argv: [i27, "supportsFIPS"] }, b27]],
        [g27, [j27, "aws"]],
        [g27, [j27, "aws-cn"]],
        [g27, [j27, "aws-us-gov"]]
      ],
      results: [
        [a27],
        [a27, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a27, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [h27, k27],
        ["https://{Region}.signin.aws.amazon.com", k27],
        ["https://{Region}.signin.amazonaws.cn", k27],
        ["https://{Region}.signin.amazonaws-us-gov.com", k27],
        ["https://signin-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", k27],
        [a27, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://signin-fips.{Region}.{PartitionResult#dnsSuffix}", k27],
        [a27, "FIPS is enabled but this partition does not support FIPS"],
        ["https://signin.{Region}.{PartitionResult#dualStackDnsSuffix}", k27],
        [a27, "DualStack is enabled but this partition does not support DualStack"],
        ["https://signin.{Region}.{PartitionResult#dnsSuffix}", k27],
        [a27, "Invalid Configuration: Missing Region"]
      ]
    };
    root27 = 2;
    r27 = 1e8;
    nodes27 = new Int32Array([
      -1,
      1,
      -1,
      0,
      15,
      3,
      1,
      4,
      r27 + 14,
      2,
      5,
      r27 + 14,
      3,
      11,
      6,
      4,
      10,
      7,
      7,
      r27 + 4,
      8,
      8,
      r27 + 5,
      9,
      9,
      r27 + 6,
      r27 + 13,
      5,
      r27 + 11,
      r27 + 12,
      4,
      13,
      12,
      6,
      r27 + 9,
      r27 + 10,
      5,
      14,
      r27 + 8,
      6,
      r27 + 7,
      r27 + 8,
      3,
      r27 + 1,
      16,
      4,
      r27 + 2,
      r27 + 3
    ]);
    bdd27 = import_util_endpoints67.BinaryDecisionDiagram.from(nodes27, root27, _data27.conditions, _data27.results);
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/endpointResolver.js
var import_util_endpoints68, import_util_endpoints69, cache27, defaultEndpointResolver27;
var init_endpointResolver27 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/endpointResolver.js"() {
    import_util_endpoints68 = __toESM(require_dist_cjs21());
    import_util_endpoints69 = __toESM(require_dist_cjs20());
    init_bdd27();
    cache27 = new import_util_endpoints69.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    defaultEndpointResolver27 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache27.get(endpointParams, () => (0, import_util_endpoints69.decideEndpoint)(bdd27, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    import_util_endpoints69.customEndpointFunctions.aws = import_util_endpoints68.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/SigninServiceException.js
var import_smithy_client217, SigninServiceException8;
var init_SigninServiceException8 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/SigninServiceException.js"() {
    import_smithy_client217 = __toESM(require_dist_cjs34());
    SigninServiceException8 = class _SigninServiceException extends import_smithy_client217.ServiceException {
      static {
        __name(this, "SigninServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _SigninServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/errors.js
var AccessDeniedException11, InternalServerException11, TooManyRequestsError8, ValidationException8;
var init_errors27 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/errors.js"() {
    init_SigninServiceException8();
    AccessDeniedException11 = class _AccessDeniedException extends SigninServiceException8 {
      static {
        __name(this, "AccessDeniedException");
      }
      name = "AccessDeniedException";
      $fault = "client";
      error;
      constructor(opts) {
        super({
          name: "AccessDeniedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AccessDeniedException.prototype);
        this.error = opts.error;
      }
    };
    InternalServerException11 = class _InternalServerException extends SigninServiceException8 {
      static {
        __name(this, "InternalServerException");
      }
      name = "InternalServerException";
      $fault = "server";
      error;
      constructor(opts) {
        super({
          name: "InternalServerException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _InternalServerException.prototype);
        this.error = opts.error;
      }
    };
    TooManyRequestsError8 = class _TooManyRequestsError extends SigninServiceException8 {
      static {
        __name(this, "TooManyRequestsError");
      }
      name = "TooManyRequestsError";
      $fault = "client";
      error;
      constructor(opts) {
        super({
          name: "TooManyRequestsError",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyRequestsError.prototype);
        this.error = opts.error;
      }
    };
    ValidationException8 = class _ValidationException extends SigninServiceException8 {
      static {
        __name(this, "ValidationException");
      }
      name = "ValidationException";
      $fault = "client";
      error;
      constructor(opts) {
        super({
          name: "ValidationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ValidationException.prototype);
        this.error = opts.error;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/schemas/schemas_0.js
var _ADE11, _AT11, _COAT8, _COATR8, _COATRB8, _COATRBr8, _COATRr8, _ISE11, _RT11, _TMRE17, _VE8, _aKI16, _aT19, _c27, _cI11, _cV11, _co11, _e27, _eI11, _gT11, _h19, _hE27, _iT11, _jN8, _m24, _rT11, _rU11, _s27, _sAK16, _sT16, _se12, _tI8, _tO8, _tT11, n027, _s_registry27, SigninServiceException$8, n0_registry27, AccessDeniedException$11, InternalServerException$11, TooManyRequestsError$8, ValidationException$8, errorTypeRegistries27, RefreshToken11, AccessToken$8, CreateOAuth2TokenRequest$8, CreateOAuth2TokenRequestBody$8, CreateOAuth2TokenResponse$8, CreateOAuth2TokenResponseBody$8, CreateOAuth2Token$8;
var init_schemas_027 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/schemas/schemas_0.js"() {
    init_schema4();
    init_errors27();
    init_SigninServiceException8();
    _ADE11 = "AccessDeniedException";
    _AT11 = "AccessToken";
    _COAT8 = "CreateOAuth2Token";
    _COATR8 = "CreateOAuth2TokenRequest";
    _COATRB8 = "CreateOAuth2TokenRequestBody";
    _COATRBr8 = "CreateOAuth2TokenResponseBody";
    _COATRr8 = "CreateOAuth2TokenResponse";
    _ISE11 = "InternalServerException";
    _RT11 = "RefreshToken";
    _TMRE17 = "TooManyRequestsError";
    _VE8 = "ValidationException";
    _aKI16 = "accessKeyId";
    _aT19 = "accessToken";
    _c27 = "client";
    _cI11 = "clientId";
    _cV11 = "codeVerifier";
    _co11 = "code";
    _e27 = "error";
    _eI11 = "expiresIn";
    _gT11 = "grantType";
    _h19 = "http";
    _hE27 = "httpError";
    _iT11 = "idToken";
    _jN8 = "jsonName";
    _m24 = "message";
    _rT11 = "refreshToken";
    _rU11 = "redirectUri";
    _s27 = "smithy.ts.sdk.synthetic.com.amazonaws.signin";
    _sAK16 = "secretAccessKey";
    _sT16 = "sessionToken";
    _se12 = "server";
    _tI8 = "tokenInput";
    _tO8 = "tokenOutput";
    _tT11 = "tokenType";
    n027 = "com.amazonaws.signin";
    _s_registry27 = TypeRegistry.for(_s27);
    SigninServiceException$8 = [-3, _s27, "SigninServiceException", 0, [], []];
    _s_registry27.registerError(SigninServiceException$8, SigninServiceException8);
    n0_registry27 = TypeRegistry.for(n027);
    AccessDeniedException$11 = [-3, n027, _ADE11, { [_e27]: _c27 }, [_e27, _m24], [0, 0], 2];
    n0_registry27.registerError(AccessDeniedException$11, AccessDeniedException11);
    InternalServerException$11 = [-3, n027, _ISE11, { [_e27]: _se12, [_hE27]: 500 }, [_e27, _m24], [0, 0], 2];
    n0_registry27.registerError(InternalServerException$11, InternalServerException11);
    TooManyRequestsError$8 = [-3, n027, _TMRE17, { [_e27]: _c27, [_hE27]: 429 }, [_e27, _m24], [0, 0], 2];
    n0_registry27.registerError(TooManyRequestsError$8, TooManyRequestsError8);
    ValidationException$8 = [-3, n027, _VE8, { [_e27]: _c27, [_hE27]: 400 }, [_e27, _m24], [0, 0], 2];
    n0_registry27.registerError(ValidationException$8, ValidationException8);
    errorTypeRegistries27 = [_s_registry27, n0_registry27];
    RefreshToken11 = [0, n027, _RT11, 8, 0];
    AccessToken$8 = [
      3,
      n027,
      _AT11,
      8,
      [_aKI16, _sAK16, _sT16],
      [
        [0, { [_jN8]: _aKI16 }],
        [0, { [_jN8]: _sAK16 }],
        [0, { [_jN8]: _sT16 }]
      ],
      3
    ];
    CreateOAuth2TokenRequest$8 = [
      3,
      n027,
      _COATR8,
      0,
      [_tI8],
      [[() => CreateOAuth2TokenRequestBody$8, 16]],
      1
    ];
    CreateOAuth2TokenRequestBody$8 = [
      3,
      n027,
      _COATRB8,
      0,
      [_cI11, _gT11, _co11, _rU11, _cV11, _rT11],
      [
        [0, { [_jN8]: _cI11 }],
        [0, { [_jN8]: _gT11 }],
        0,
        [0, { [_jN8]: _rU11 }],
        [0, { [_jN8]: _cV11 }],
        [() => RefreshToken11, { [_jN8]: _rT11 }]
      ],
      2
    ];
    CreateOAuth2TokenResponse$8 = [
      3,
      n027,
      _COATRr8,
      0,
      [_tO8],
      [[() => CreateOAuth2TokenResponseBody$8, 16]],
      1
    ];
    CreateOAuth2TokenResponseBody$8 = [
      3,
      n027,
      _COATRBr8,
      0,
      [_aT19, _tT11, _eI11, _rT11, _iT11],
      [
        [() => AccessToken$8, { [_jN8]: _aT19 }],
        [0, { [_jN8]: _tT11 }],
        [1, { [_jN8]: _eI11 }],
        [() => RefreshToken11, { [_jN8]: _rT11 }],
        [0, { [_jN8]: _iT11 }]
      ],
      4
    ];
    CreateOAuth2Token$8 = [
      9,
      n027,
      _COAT8,
      { [_h19]: ["POST", "/v1/token", 200] },
      () => CreateOAuth2TokenRequest$8,
      () => CreateOAuth2TokenResponse$8
    ];
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.shared.js
var import_smithy_client218, import_url_parser24, import_util_base6459, import_util_utf845, getRuntimeConfig53;
var init_runtimeConfig_shared27 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.shared.js"() {
    init_httpAuthSchemes11();
    init_protocols17();
    init_dist_es();
    import_smithy_client218 = __toESM(require_dist_cjs34());
    import_url_parser24 = __toESM(require_dist_cjs18());
    import_util_base6459 = __toESM(require_dist_cjs10());
    import_util_utf845 = __toESM(require_dist_cjs9());
    init_httpAuthSchemeProvider27();
    init_endpointResolver27();
    init_schemas_027();
    getRuntimeConfig53 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2023-01-01",
        base64Decoder: config2?.base64Decoder ?? import_util_base6459.fromBase64,
        base64Encoder: config2?.base64Encoder ?? import_util_base6459.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver27,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSigninHttpAuthSchemeProvider8,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer9()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        logger: config2?.logger ?? new import_smithy_client218.NoOpLogger(),
        protocol: config2?.protocol ?? AwsRestJsonProtocol10,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.signin",
          errorTypeRegistries: errorTypeRegistries27,
          version: "2023-01-01",
          serviceTarget: "Signin"
        },
        serviceId: config2?.serviceId ?? "Signin",
        urlParser: config2?.urlParser ?? import_url_parser24.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? import_util_utf845.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? import_util_utf845.toUtf8
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.js
var import_util_user_agent_node23, import_config_resolver46, import_hash_node25, import_middleware_retry45, import_node_config_provider24, import_node_http_handler27, import_smithy_client219, import_util_body_length_node23, import_util_defaults_mode_node23, import_util_retry33, getRuntimeConfig54;
var init_runtimeConfig27 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.js"() {
    init_package9();
    init_client18();
    init_httpAuthSchemes11();
    import_util_user_agent_node23 = __toESM(require_dist_cjs185());
    import_config_resolver46 = __toESM(require_dist_cjs25());
    import_hash_node25 = __toESM(require_dist_cjs44());
    import_middleware_retry45 = __toESM(require_dist_cjs181());
    import_node_config_provider24 = __toESM(require_dist_cjs29());
    import_node_http_handler27 = __toESM(require_dist_cjs13());
    import_smithy_client219 = __toESM(require_dist_cjs34());
    import_util_body_length_node23 = __toESM(require_dist_cjs45());
    import_util_defaults_mode_node23 = __toESM(require_dist_cjs46());
    import_util_retry33 = __toESM(require_dist_cjs22());
    init_runtimeConfig_shared27();
    getRuntimeConfig54 = /* @__PURE__ */ __name((config2) => {
      (0, import_smithy_client219.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, import_util_defaults_mode_node23.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(import_smithy_client219.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig53(config2);
      emitWarningIfUnsupportedVersion34(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, import_node_config_provider24.loadConfig)(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS9, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? import_util_body_length_node23.calculateBodyLength,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, import_util_user_agent_node23.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_default9.version }),
        maxAttempts: config2?.maxAttempts ?? (0, import_node_config_provider24.loadConfig)(import_middleware_retry45.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, import_node_config_provider24.loadConfig)(import_config_resolver46.NODE_REGION_CONFIG_OPTIONS, { ...import_config_resolver46.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: import_node_http_handler27.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, import_node_config_provider24.loadConfig)({
          ...import_middleware_retry45.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || import_util_retry33.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? import_hash_node25.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? import_node_http_handler27.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, import_node_config_provider24.loadConfig)(import_config_resolver46.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, import_node_config_provider24.loadConfig)(import_config_resolver46.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, import_node_config_provider24.loadConfig)(import_util_user_agent_node23.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration27, resolveHttpAuthRuntimeConfig27;
var init_httpAuthExtensionConfiguration27 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration27 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig27 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeExtensions.js
var import_region_config_resolver29, import_protocol_http55, import_smithy_client220, resolveRuntimeExtensions27;
var init_runtimeExtensions27 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeExtensions.js"() {
    import_region_config_resolver29 = __toESM(require_dist_cjs48());
    import_protocol_http55 = __toESM(require_dist_cjs2());
    import_smithy_client220 = __toESM(require_dist_cjs34());
    init_httpAuthExtensionConfiguration27();
    resolveRuntimeExtensions27 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign((0, import_region_config_resolver29.getAwsRegionExtensionConfiguration)(runtimeConfig), (0, import_smithy_client220.getDefaultExtensionConfiguration)(runtimeConfig), (0, import_protocol_http55.getHttpHandlerExtensionConfiguration)(runtimeConfig), getHttpAuthExtensionConfiguration27(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, (0, import_region_config_resolver29.resolveAwsRegionExtensionConfiguration)(extensionConfiguration), (0, import_smithy_client220.resolveDefaultRuntimeConfig)(extensionConfiguration), (0, import_protocol_http55.resolveHttpHandlerRuntimeConfig)(extensionConfiguration), resolveHttpAuthRuntimeConfig27(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/SigninClient.js
var import_middleware_host_header23, import_middleware_logger23, import_middleware_recursion_detection23, import_middleware_user_agent23, import_config_resolver47, import_middleware_content_length23, import_middleware_endpoint59, import_middleware_retry46, import_smithy_client221, SigninClient8;
var init_SigninClient8 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/SigninClient.js"() {
    import_middleware_host_header23 = __toESM(require_dist_cjs3());
    import_middleware_logger23 = __toESM(require_dist_cjs4());
    import_middleware_recursion_detection23 = __toESM(require_dist_cjs5());
    import_middleware_user_agent23 = __toESM(require_dist_cjs180());
    import_config_resolver47 = __toESM(require_dist_cjs25());
    init_dist_es();
    init_schema4();
    import_middleware_content_length23 = __toESM(require_dist_cjs26());
    import_middleware_endpoint59 = __toESM(require_dist_cjs31());
    import_middleware_retry46 = __toESM(require_dist_cjs181());
    import_smithy_client221 = __toESM(require_dist_cjs34());
    init_httpAuthSchemeProvider27();
    init_EndpointParameters27();
    init_runtimeConfig27();
    init_runtimeExtensions27();
    SigninClient8 = class extends import_smithy_client221.Client {
      static {
        __name(this, "SigninClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig54(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters27(_config_0);
        const _config_2 = (0, import_middleware_user_agent23.resolveUserAgentConfig)(_config_1);
        const _config_3 = (0, import_middleware_retry46.resolveRetryConfig)(_config_2);
        const _config_4 = (0, import_config_resolver47.resolveRegionConfig)(_config_3);
        const _config_5 = (0, import_middleware_host_header23.resolveHostHeaderConfig)(_config_4);
        const _config_6 = (0, import_middleware_endpoint59.resolveEndpointConfig)(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig27(_config_6);
        const _config_8 = resolveRuntimeExtensions27(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin(this.config));
        this.middlewareStack.use((0, import_middleware_user_agent23.getUserAgentPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_retry46.getRetryPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_content_length23.getContentLengthPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_host_header23.getHostHeaderPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_logger23.getLoggerPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_recursion_detection23.getRecursionDetectionPlugin)(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: defaultSigninHttpAuthSchemeParametersProvider8,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/CreateOAuth2TokenCommand.js
var import_middleware_endpoint60, import_smithy_client222, CreateOAuth2TokenCommand8;
var init_CreateOAuth2TokenCommand8 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/CreateOAuth2TokenCommand.js"() {
    import_middleware_endpoint60 = __toESM(require_dist_cjs31());
    import_smithy_client222 = __toESM(require_dist_cjs34());
    init_EndpointParameters27();
    init_schemas_027();
    CreateOAuth2TokenCommand8 = class extends import_smithy_client222.Command.classBuilder().ep(commonParams27).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint60.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("Signin", "CreateOAuth2Token", {}).n("SigninClient", "CreateOAuth2TokenCommand").sc(CreateOAuth2Token$8).build() {
      static {
        __name(this, "CreateOAuth2TokenCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/Signin.js
var import_smithy_client223, commands27, Signin8;
var init_Signin8 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/Signin.js"() {
    import_smithy_client223 = __toESM(require_dist_cjs34());
    init_CreateOAuth2TokenCommand8();
    init_SigninClient8();
    commands27 = {
      CreateOAuth2TokenCommand: CreateOAuth2TokenCommand8
    };
    Signin8 = class extends SigninClient8 {
      static {
        __name(this, "Signin");
      }
    };
    (0, import_smithy_client223.createAggregatedClient)(commands27, Signin8);
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/index.js
var init_commands28 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/index.js"() {
    init_CreateOAuth2TokenCommand8();
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/enums.js
var OAuth2ErrorCode8;
var init_enums11 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/enums.js"() {
    OAuth2ErrorCode8 = {
      AUTHCODE_EXPIRED: "AUTHCODE_EXPIRED",
      INSUFFICIENT_PERMISSIONS: "INSUFFICIENT_PERMISSIONS",
      INVALID_REQUEST: "INVALID_REQUEST",
      SERVER_ERROR: "server_error",
      TOKEN_EXPIRED: "TOKEN_EXPIRED",
      USER_CREDENTIALS_CHANGED: "USER_CREDENTIALS_CHANGED"
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/models_0.js
var init_models_027 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/index.js
var signin_exports8 = {};
__export(signin_exports8, {
  $Command: () => import_smithy_client222.Command,
  AccessDeniedException: () => AccessDeniedException11,
  AccessDeniedException$: () => AccessDeniedException$11,
  AccessToken$: () => AccessToken$8,
  CreateOAuth2Token$: () => CreateOAuth2Token$8,
  CreateOAuth2TokenCommand: () => CreateOAuth2TokenCommand8,
  CreateOAuth2TokenRequest$: () => CreateOAuth2TokenRequest$8,
  CreateOAuth2TokenRequestBody$: () => CreateOAuth2TokenRequestBody$8,
  CreateOAuth2TokenResponse$: () => CreateOAuth2TokenResponse$8,
  CreateOAuth2TokenResponseBody$: () => CreateOAuth2TokenResponseBody$8,
  InternalServerException: () => InternalServerException11,
  InternalServerException$: () => InternalServerException$11,
  OAuth2ErrorCode: () => OAuth2ErrorCode8,
  Signin: () => Signin8,
  SigninClient: () => SigninClient8,
  SigninServiceException: () => SigninServiceException8,
  SigninServiceException$: () => SigninServiceException$8,
  TooManyRequestsError: () => TooManyRequestsError8,
  TooManyRequestsError$: () => TooManyRequestsError$8,
  ValidationException: () => ValidationException8,
  ValidationException$: () => ValidationException$8,
  __Client: () => import_smithy_client221.Client,
  errorTypeRegistries: () => errorTypeRegistries27
});
var init_signin8 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/index.js"() {
    init_SigninClient8();
    init_Signin8();
    init_commands28();
    init_schemas_027();
    init_enums11();
    init_errors27();
    init_models_027();
    init_SigninServiceException8();
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-login/dist-cjs/index.js
var require_dist_cjs187 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-login/dist-cjs/index.js"(exports2) {
    "use strict";
    var client = (init_client18(), __toCommonJS(client_exports13));
    var propertyProvider = require_dist_cjs27();
    var sharedIniFileLoader = require_dist_cjs28();
    var protocolHttp = require_dist_cjs2();
    var node_crypto = require("node:crypto");
    var node_fs = require("node:fs");
    var node_os = require("node:os");
    var node_path = require("node:path");
    var LoginCredentialsFetcher = class _LoginCredentialsFetcher {
      static {
        __name(this, "LoginCredentialsFetcher");
      }
      profileData;
      init;
      callerClientConfig;
      static REFRESH_THRESHOLD = 5 * 60 * 1e3;
      constructor(profileData, init, callerClientConfig) {
        this.profileData = profileData;
        this.init = init;
        this.callerClientConfig = callerClientConfig;
      }
      async loadCredentials() {
        const token = await this.loadToken();
        if (!token) {
          throw new propertyProvider.CredentialsProviderError(`Failed to load a token for session ${this.loginSession}, please re-authenticate using aws login`, { tryNextLink: false, logger: this.logger });
        }
        const accessToken = token.accessToken;
        const now = Date.now();
        const expiryTime = new Date(accessToken.expiresAt).getTime();
        const timeUntilExpiry = expiryTime - now;
        if (timeUntilExpiry <= _LoginCredentialsFetcher.REFRESH_THRESHOLD) {
          return this.refresh(token);
        }
        return {
          accessKeyId: accessToken.accessKeyId,
          secretAccessKey: accessToken.secretAccessKey,
          sessionToken: accessToken.sessionToken,
          accountId: accessToken.accountId,
          expiration: new Date(accessToken.expiresAt)
        };
      }
      get logger() {
        return this.init?.logger;
      }
      get loginSession() {
        return this.profileData.login_session;
      }
      async refresh(token) {
        const { SigninClient: SigninClient10, CreateOAuth2TokenCommand: CreateOAuth2TokenCommand10 } = await Promise.resolve().then(() => (init_signin8(), signin_exports8));
        const { logger: logger5, userAgentAppId } = this.callerClientConfig ?? {};
        const isH210 = /* @__PURE__ */ __name((requestHandler2) => {
          return requestHandler2?.metadata?.handlerProtocol === "h2";
        }, "isH2");
        const requestHandler = isH210(this.callerClientConfig?.requestHandler) ? void 0 : this.callerClientConfig?.requestHandler;
        const region = this.profileData.region ?? await this.callerClientConfig?.region?.() ?? process.env.AWS_REGION;
        const client2 = new SigninClient10({
          credentials: {
            accessKeyId: "",
            secretAccessKey: ""
          },
          region,
          requestHandler,
          logger: logger5,
          userAgentAppId,
          ...this.init?.clientConfig
        });
        this.createDPoPInterceptor(client2.middlewareStack);
        const commandInput = {
          tokenInput: {
            clientId: token.clientId,
            refreshToken: token.refreshToken,
            grantType: "refresh_token"
          }
        };
        try {
          const response = await client2.send(new CreateOAuth2TokenCommand10(commandInput));
          const { accessKeyId, secretAccessKey, sessionToken } = response.tokenOutput?.accessToken ?? {};
          const { refreshToken, expiresIn } = response.tokenOutput ?? {};
          if (!accessKeyId || !secretAccessKey || !sessionToken || !refreshToken) {
            throw new propertyProvider.CredentialsProviderError("Token refresh response missing required fields", {
              logger: this.logger,
              tryNextLink: false
            });
          }
          const expiresInMs = (expiresIn ?? 900) * 1e3;
          const expiration = new Date(Date.now() + expiresInMs);
          const updatedToken = {
            ...token,
            accessToken: {
              ...token.accessToken,
              accessKeyId,
              secretAccessKey,
              sessionToken,
              expiresAt: expiration.toISOString()
            },
            refreshToken
          };
          await this.saveToken(updatedToken);
          const newAccessToken = updatedToken.accessToken;
          return {
            accessKeyId: newAccessToken.accessKeyId,
            secretAccessKey: newAccessToken.secretAccessKey,
            sessionToken: newAccessToken.sessionToken,
            accountId: newAccessToken.accountId,
            expiration
          };
        } catch (error4) {
          if (error4.name === "AccessDeniedException") {
            const errorType = error4.error;
            let message2;
            switch (errorType) {
              case "TOKEN_EXPIRED":
                message2 = "Your session has expired. Please reauthenticate.";
                break;
              case "USER_CREDENTIALS_CHANGED":
                message2 = "Unable to refresh credentials because of a change in your password. Please reauthenticate with your new password.";
                break;
              case "INSUFFICIENT_PERMISSIONS":
                message2 = "Unable to refresh credentials due to insufficient permissions. You may be missing permission for the 'CreateOAuth2Token' action.";
                break;
              default:
                message2 = `Failed to refresh token: ${String(error4)}. Please re-authenticate using \`aws login\``;
            }
            throw new propertyProvider.CredentialsProviderError(message2, { logger: this.logger, tryNextLink: false });
          }
          throw new propertyProvider.CredentialsProviderError(`Failed to refresh token: ${String(error4)}. Please re-authenticate using aws login`, { logger: this.logger });
        }
      }
      async loadToken() {
        const tokenFilePath = this.getTokenFilePath();
        try {
          let tokenData;
          try {
            tokenData = await sharedIniFileLoader.readFile(tokenFilePath, { ignoreCache: this.init?.ignoreCache });
          } catch {
            tokenData = await node_fs.promises.readFile(tokenFilePath, "utf8");
          }
          const token = JSON.parse(tokenData);
          const missingFields = ["accessToken", "clientId", "refreshToken", "dpopKey"].filter((k32) => !token[k32]);
          if (!token.accessToken?.accountId) {
            missingFields.push("accountId");
          }
          if (missingFields.length > 0) {
            throw new propertyProvider.CredentialsProviderError(`Token validation failed, missing fields: ${missingFields.join(", ")}`, {
              logger: this.logger,
              tryNextLink: false
            });
          }
          return token;
        } catch (error4) {
          throw new propertyProvider.CredentialsProviderError(`Failed to load token from ${tokenFilePath}: ${String(error4)}`, {
            logger: this.logger,
            tryNextLink: false
          });
        }
      }
      async saveToken(token) {
        const tokenFilePath = this.getTokenFilePath();
        const directory = node_path.dirname(tokenFilePath);
        try {
          await node_fs.promises.mkdir(directory, { recursive: true });
        } catch (error4) {
        }
        await node_fs.promises.writeFile(tokenFilePath, JSON.stringify(token, null, 2), "utf8");
      }
      getTokenFilePath() {
        const directory = process.env.AWS_LOGIN_CACHE_DIRECTORY ?? node_path.join(node_os.homedir(), ".aws", "login", "cache");
        const loginSessionBytes = Buffer.from(this.loginSession, "utf8");
        const loginSessionSha256 = node_crypto.createHash("sha256").update(loginSessionBytes).digest("hex");
        return node_path.join(directory, `${loginSessionSha256}.json`);
      }
      derToRawSignature(derSignature) {
        let offset = 2;
        if (derSignature[offset] !== 2) {
          throw new Error("Invalid DER signature");
        }
        offset++;
        const rLength = derSignature[offset++];
        let r32 = derSignature.subarray(offset, offset + rLength);
        offset += rLength;
        if (derSignature[offset] !== 2) {
          throw new Error("Invalid DER signature");
        }
        offset++;
        const sLength = derSignature[offset++];
        let s = derSignature.subarray(offset, offset + sLength);
        r32 = r32[0] === 0 ? r32.subarray(1) : r32;
        s = s[0] === 0 ? s.subarray(1) : s;
        const rPadded = Buffer.concat([Buffer.alloc(32 - r32.length), r32]);
        const sPadded = Buffer.concat([Buffer.alloc(32 - s.length), s]);
        return Buffer.concat([rPadded, sPadded]);
      }
      createDPoPInterceptor(middlewareStack) {
        middlewareStack.add((next) => async (args) => {
          if (protocolHttp.HttpRequest.isInstance(args.request)) {
            const request4 = args.request;
            const actualEndpoint = `${request4.protocol}//${request4.hostname}${request4.port ? `:${request4.port}` : ""}${request4.path}`;
            const dpop = await this.generateDpop(request4.method, actualEndpoint);
            request4.headers = {
              ...request4.headers,
              DPoP: dpop
            };
          }
          return next(args);
        }, {
          step: "finalizeRequest",
          name: "dpopInterceptor",
          override: true
        });
      }
      async generateDpop(method = "POST", endpoint) {
        const token = await this.loadToken();
        try {
          const privateKey = node_crypto.createPrivateKey({
            key: token.dpopKey,
            format: "pem",
            type: "sec1"
          });
          const publicKey = node_crypto.createPublicKey(privateKey);
          const publicDer = publicKey.export({ format: "der", type: "spki" });
          let pointStart = -1;
          for (let i32 = 0; i32 < publicDer.length; i32++) {
            if (publicDer[i32] === 4) {
              pointStart = i32;
              break;
            }
          }
          const x = publicDer.slice(pointStart + 1, pointStart + 33);
          const y = publicDer.slice(pointStart + 33, pointStart + 65);
          const header = {
            alg: "ES256",
            typ: "dpop+jwt",
            jwk: {
              kty: "EC",
              crv: "P-256",
              x: x.toString("base64url"),
              y: y.toString("base64url")
            }
          };
          const payload3 = {
            jti: crypto.randomUUID(),
            htm: method,
            htu: endpoint,
            iat: Math.floor(Date.now() / 1e3)
          };
          const headerB64 = Buffer.from(JSON.stringify(header)).toString("base64url");
          const payloadB64 = Buffer.from(JSON.stringify(payload3)).toString("base64url");
          const message2 = `${headerB64}.${payloadB64}`;
          const asn1Signature = node_crypto.sign("sha256", Buffer.from(message2), privateKey);
          const rawSignature = this.derToRawSignature(asn1Signature);
          const signatureB64 = rawSignature.toString("base64url");
          return `${message2}.${signatureB64}`;
        } catch (error4) {
          throw new propertyProvider.CredentialsProviderError(`Failed to generate Dpop proof: ${error4 instanceof Error ? error4.message : String(error4)}`, { logger: this.logger, tryNextLink: false });
        }
      }
    };
    var fromLoginCredentials = /* @__PURE__ */ __name((init) => async ({ callerClientConfig } = {}) => {
      init?.logger?.debug?.("@aws-sdk/credential-providers - fromLoginCredentials");
      const profiles = await sharedIniFileLoader.parseKnownFiles(init || {});
      const profileName = sharedIniFileLoader.getProfileName({
        profile: init?.profile ?? callerClientConfig?.profile
      });
      const profile = profiles[profileName];
      if (!profile?.login_session) {
        throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} does not contain login_session.`, {
          tryNextLink: true,
          logger: init?.logger
        });
      }
      const fetcher = new LoginCredentialsFetcher(profile, init, callerClientConfig);
      const credentials = await fetcher.loadCredentials();
      return client.setCredentialFeature(credentials, "CREDENTIALS_LOGIN", "AD");
    }, "fromLoginCredentials");
    exports2.fromLoginCredentials = fromLoginCredentials;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/bdd.js
var import_util_endpoints70, q8, a28, b28, c28, d28, e28, f28, g28, h28, i28, j28, k28, l17, m17, n8, o8, p8, _data28, root28, r28, nodes28, bdd28;
var init_bdd28 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/bdd.js"() {
    import_util_endpoints70 = __toESM(require_dist_cjs20());
    q8 = "ref";
    a28 = -1;
    b28 = true;
    c28 = "isSet";
    d28 = "PartitionResult";
    e28 = "booleanEquals";
    f28 = "stringEquals";
    g28 = "getAttr";
    h28 = "us-east-1";
    i28 = "sigv4";
    j28 = "sts";
    k28 = "https://sts.{Region}.{PartitionResult#dnsSuffix}";
    l17 = { [q8]: "Endpoint" };
    m17 = { [q8]: "Region" };
    n8 = { [q8]: d28 };
    o8 = {};
    p8 = [m17];
    _data28 = {
      conditions: [
        [c28, [l17]],
        [c28, p8],
        ["aws.partition", p8, d28],
        [e28, [{ [q8]: "UseFIPS" }, b28]],
        [e28, [{ [q8]: "UseDualStack" }, b28]],
        [f28, [m17, "aws-global"]],
        [e28, [{ [q8]: "UseGlobalEndpoint" }, b28]],
        [f28, [m17, "eu-central-1"]],
        [e28, [{ fn: g28, argv: [n8, "supportsDualStack"] }, b28]],
        [e28, [{ fn: g28, argv: [n8, "supportsFIPS"] }, b28]],
        [f28, [m17, "ap-south-1"]],
        [f28, [m17, "eu-north-1"]],
        [f28, [m17, "eu-west-1"]],
        [f28, [m17, "eu-west-2"]],
        [f28, [m17, "eu-west-3"]],
        [f28, [m17, "sa-east-1"]],
        [f28, [m17, h28]],
        [f28, [m17, "us-east-2"]],
        [f28, [m17, "us-west-2"]],
        [f28, [m17, "us-west-1"]],
        [f28, [m17, "ca-central-1"]],
        [f28, [m17, "ap-southeast-1"]],
        [f28, [m17, "ap-northeast-1"]],
        [f28, [m17, "ap-southeast-2"]],
        [f28, [{ fn: g28, argv: [n8, "name"] }, "aws-us-gov"]]
      ],
      results: [
        [a28],
        ["https://sts.amazonaws.com", { authSchemes: [{ name: i28, signingName: j28, signingRegion: h28 }] }],
        [k28, { authSchemes: [{ name: i28, signingName: j28, signingRegion: "{Region}" }] }],
        [a28, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a28, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [l17, o8],
        ["https://sts-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", o8],
        [a28, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://sts.{Region}.amazonaws.com", o8],
        ["https://sts-fips.{Region}.{PartitionResult#dnsSuffix}", o8],
        [a28, "FIPS is enabled but this partition does not support FIPS"],
        ["https://sts.{Region}.{PartitionResult#dualStackDnsSuffix}", o8],
        [a28, "DualStack is enabled but this partition does not support DualStack"],
        [k28, o8],
        [a28, "Invalid Configuration: Missing Region"]
      ]
    };
    root28 = 2;
    r28 = 1e8;
    nodes28 = new Int32Array([
      -1,
      1,
      -1,
      0,
      30,
      3,
      1,
      4,
      r28 + 14,
      2,
      5,
      r28 + 14,
      3,
      25,
      6,
      4,
      24,
      7,
      5,
      r28 + 1,
      8,
      6,
      9,
      r28 + 13,
      7,
      r28 + 1,
      10,
      10,
      r28 + 1,
      11,
      11,
      r28 + 1,
      12,
      12,
      r28 + 1,
      13,
      13,
      r28 + 1,
      14,
      14,
      r28 + 1,
      15,
      15,
      r28 + 1,
      16,
      16,
      r28 + 1,
      17,
      17,
      r28 + 1,
      18,
      18,
      r28 + 1,
      19,
      19,
      r28 + 1,
      20,
      20,
      r28 + 1,
      21,
      21,
      r28 + 1,
      22,
      22,
      r28 + 1,
      23,
      23,
      r28 + 1,
      r28 + 2,
      8,
      r28 + 11,
      r28 + 12,
      4,
      28,
      26,
      9,
      27,
      r28 + 10,
      24,
      r28 + 8,
      r28 + 9,
      8,
      29,
      r28 + 7,
      9,
      r28 + 6,
      r28 + 7,
      3,
      r28 + 3,
      31,
      4,
      r28 + 4,
      r28 + 5
    ]);
    bdd28 = import_util_endpoints70.BinaryDecisionDiagram.from(nodes28, root28, _data28.conditions, _data28.results);
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/endpointResolver.js
var import_util_endpoints71, import_util_endpoints72, cache28, defaultEndpointResolver28;
var init_endpointResolver28 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/endpointResolver.js"() {
    import_util_endpoints71 = __toESM(require_dist_cjs21());
    import_util_endpoints72 = __toESM(require_dist_cjs20());
    init_bdd28();
    cache28 = new import_util_endpoints72.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS", "UseGlobalEndpoint"]
    });
    defaultEndpointResolver28 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache28.get(endpointParams, () => (0, import_util_endpoints72.decideEndpoint)(bdd28, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    import_util_endpoints72.customEndpointFunctions.aws = import_util_endpoints71.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption28(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "sts",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createAwsAuthSigv4aHttpAuthOption8(authParameters) {
  return {
    schemeId: "aws.auth#sigv4a",
    signingProperties: {
      name: "sts",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption28(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var import_signature_v4_multi_region15, import_middleware_endpoint61, import_util_middleware29, createEndpointRuleSetHttpAuthSchemeParametersProvider8, _defaultSTSHttpAuthSchemeParametersProvider8, defaultSTSHttpAuthSchemeParametersProvider8, createEndpointRuleSetHttpAuthSchemeProvider8, _defaultSTSHttpAuthSchemeProvider8, defaultSTSHttpAuthSchemeProvider8, resolveStsAuthConfig7, resolveHttpAuthSchemeConfig28;
var init_httpAuthSchemeProvider28 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes11();
    import_signature_v4_multi_region15 = __toESM(require_dist_cjs55());
    import_middleware_endpoint61 = __toESM(require_dist_cjs31());
    import_util_middleware29 = __toESM(require_dist_cjs6());
    init_endpointResolver28();
    init_STSClient8();
    createEndpointRuleSetHttpAuthSchemeParametersProvider8 = /* @__PURE__ */ __name((defaultHttpAuthSchemeParametersProvider) => async (config2, context, input) => {
      if (!input) {
        throw new Error("Could not find `input` for `defaultEndpointRuleSetHttpAuthSchemeParametersProvider`");
      }
      const defaultParameters = await defaultHttpAuthSchemeParametersProvider(config2, context, input);
      const instructionsFn = (0, import_util_middleware29.getSmithyContext)(context)?.commandInstance?.constructor?.getEndpointParameterInstructions;
      if (!instructionsFn) {
        throw new Error(`getEndpointParameterInstructions() is not defined on '${context.commandName}'`);
      }
      const endpointParameters = await (0, import_middleware_endpoint61.resolveParams)(input, { getEndpointParameterInstructions: instructionsFn }, config2);
      return Object.assign(defaultParameters, endpointParameters);
    }, "createEndpointRuleSetHttpAuthSchemeParametersProvider");
    _defaultSTSHttpAuthSchemeParametersProvider8 = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, import_util_middleware29.getSmithyContext)(context).operation,
        region: await (0, import_util_middleware29.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "_defaultSTSHttpAuthSchemeParametersProvider");
    defaultSTSHttpAuthSchemeParametersProvider8 = createEndpointRuleSetHttpAuthSchemeParametersProvider8(_defaultSTSHttpAuthSchemeParametersProvider8);
    __name(createAwsAuthSigv4HttpAuthOption28, "createAwsAuthSigv4HttpAuthOption");
    __name(createAwsAuthSigv4aHttpAuthOption8, "createAwsAuthSigv4aHttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption28, "createSmithyApiNoAuthHttpAuthOption");
    createEndpointRuleSetHttpAuthSchemeProvider8 = /* @__PURE__ */ __name((defaultEndpointResolver32, defaultHttpAuthSchemeResolver, createHttpAuthOptionFunctions) => {
      const endpointRuleSetHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
        const endpoint = defaultEndpointResolver32(authParameters);
        const authSchemes = endpoint.properties?.authSchemes;
        if (!authSchemes) {
          return defaultHttpAuthSchemeResolver(authParameters);
        }
        const options = [];
        for (const scheme of authSchemes) {
          const { name: resolvedName, properties = {}, ...rest } = scheme;
          const name = resolvedName.toLowerCase();
          if (resolvedName !== name) {
            console.warn(`HttpAuthScheme has been normalized with lowercasing: '${resolvedName}' to '${name}'`);
          }
          let schemeId;
          if (name === "sigv4a") {
            schemeId = "aws.auth#sigv4a";
            const sigv4Present = authSchemes.find((s) => {
              const name2 = s.name.toLowerCase();
              return name2 !== "sigv4a" && name2.startsWith("sigv4");
            });
            if (import_signature_v4_multi_region15.SignatureV4MultiRegion.sigv4aDependency() === "none" && sigv4Present) {
              continue;
            }
          } else if (name.startsWith("sigv4")) {
            schemeId = "aws.auth#sigv4";
          } else {
            throw new Error(`Unknown HttpAuthScheme found in '@smithy.rules#endpointRuleSet': '${name}'`);
          }
          const createOption = createHttpAuthOptionFunctions[schemeId];
          if (!createOption) {
            throw new Error(`Could not find HttpAuthOption create function for '${schemeId}'`);
          }
          const option = createOption(authParameters);
          option.schemeId = schemeId;
          option.signingProperties = { ...option.signingProperties || {}, ...rest, ...properties };
          options.push(option);
        }
        return options;
      }, "endpointRuleSetHttpAuthSchemeProvider");
      return endpointRuleSetHttpAuthSchemeProvider;
    }, "createEndpointRuleSetHttpAuthSchemeProvider");
    _defaultSTSHttpAuthSchemeProvider8 = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "AssumeRoleWithWebIdentity": {
          options.push(createSmithyApiNoAuthHttpAuthOption28(authParameters));
          options.push(createAwsAuthSigv4aHttpAuthOption8(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption28(authParameters));
          options.push(createAwsAuthSigv4aHttpAuthOption8(authParameters));
        }
      }
      return options;
    }, "_defaultSTSHttpAuthSchemeProvider");
    defaultSTSHttpAuthSchemeProvider8 = createEndpointRuleSetHttpAuthSchemeProvider8(defaultEndpointResolver28, _defaultSTSHttpAuthSchemeProvider8, {
      "aws.auth#sigv4": createAwsAuthSigv4HttpAuthOption28,
      "aws.auth#sigv4a": createAwsAuthSigv4aHttpAuthOption8,
      "smithy.api#noAuth": createSmithyApiNoAuthHttpAuthOption28
    });
    resolveStsAuthConfig7 = /* @__PURE__ */ __name((input) => Object.assign(input, {
      stsClientCtor: STSClient9
    }), "resolveStsAuthConfig");
    resolveHttpAuthSchemeConfig28 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveStsAuthConfig7(config2);
      const config_1 = resolveAwsSdkSigV4Config9(config_0);
      const config_2 = resolveAwsSdkSigV4AConfig9(config_1);
      return Object.assign(config_2, {
        authSchemePreference: (0, import_util_middleware29.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/EndpointParameters.js
var resolveClientEndpointParameters28, commonParams28;
var init_EndpointParameters28 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters28 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        useGlobalEndpoint: options.useGlobalEndpoint ?? false,
        defaultSigningName: "sts"
      });
    }, "resolveClientEndpointParameters");
    commonParams28 = {
      UseGlobalEndpoint: { type: "builtInParams", name: "useGlobalEndpoint" },
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/STSServiceException.js
var import_smithy_client224, STSServiceException8;
var init_STSServiceException8 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/STSServiceException.js"() {
    import_smithy_client224 = __toESM(require_dist_cjs34());
    STSServiceException8 = class _STSServiceException extends import_smithy_client224.ServiceException {
      static {
        __name(this, "STSServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _STSServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/errors.js
var ExpiredTokenException11, MalformedPolicyDocumentException8, PackedPolicyTooLargeException8, RegionDisabledException8, IDPRejectedClaimException8, InvalidIdentityTokenException8, IDPCommunicationErrorException8;
var init_errors28 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/errors.js"() {
    init_STSServiceException8();
    ExpiredTokenException11 = class _ExpiredTokenException extends STSServiceException8 {
      static {
        __name(this, "ExpiredTokenException");
      }
      name = "ExpiredTokenException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ExpiredTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ExpiredTokenException.prototype);
      }
    };
    MalformedPolicyDocumentException8 = class _MalformedPolicyDocumentException extends STSServiceException8 {
      static {
        __name(this, "MalformedPolicyDocumentException");
      }
      name = "MalformedPolicyDocumentException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "MalformedPolicyDocumentException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _MalformedPolicyDocumentException.prototype);
      }
    };
    PackedPolicyTooLargeException8 = class _PackedPolicyTooLargeException extends STSServiceException8 {
      static {
        __name(this, "PackedPolicyTooLargeException");
      }
      name = "PackedPolicyTooLargeException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "PackedPolicyTooLargeException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _PackedPolicyTooLargeException.prototype);
      }
    };
    RegionDisabledException8 = class _RegionDisabledException extends STSServiceException8 {
      static {
        __name(this, "RegionDisabledException");
      }
      name = "RegionDisabledException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "RegionDisabledException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _RegionDisabledException.prototype);
      }
    };
    IDPRejectedClaimException8 = class _IDPRejectedClaimException extends STSServiceException8 {
      static {
        __name(this, "IDPRejectedClaimException");
      }
      name = "IDPRejectedClaimException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "IDPRejectedClaimException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _IDPRejectedClaimException.prototype);
      }
    };
    InvalidIdentityTokenException8 = class _InvalidIdentityTokenException extends STSServiceException8 {
      static {
        __name(this, "InvalidIdentityTokenException");
      }
      name = "InvalidIdentityTokenException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidIdentityTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidIdentityTokenException.prototype);
      }
    };
    IDPCommunicationErrorException8 = class _IDPCommunicationErrorException extends STSServiceException8 {
      static {
        __name(this, "IDPCommunicationErrorException");
      }
      name = "IDPCommunicationErrorException";
      $fault = "client";
      $retryable = {};
      constructor(opts) {
        super({
          name: "IDPCommunicationErrorException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _IDPCommunicationErrorException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/schemas/schemas_0.js
var _A8, _AKI9, _AR8, _ARI8, _ARR8, _ARRs8, _ARU8, _ARWWI8, _ARWWIR8, _ARWWIRs8, _Au8, _C9, _CA8, _DS8, _E9, _EI8, _ETE11, _IDPCEE8, _IDPRCE8, _IITE8, _K8, _MPDE8, _P8, _PA8, _PAr8, _PC8, _PCLT8, _PCr8, _PDT8, _PI8, _PPS8, _PPTLE8, _Pr8, _RA8, _RDE8, _RSN8, _SAK8, _SFWIT8, _SI8, _SN8, _ST9, _T8, _TC8, _TTK8, _Ta8, _V8, _WIT8, _a8, _aKST8, _aQE8, _c28, _cTT8, _e28, _hE28, _m25, _pDLT8, _s28, _tLT8, n028, _s_registry28, STSServiceException$8, n0_registry28, ExpiredTokenException$11, IDPCommunicationErrorException$8, IDPRejectedClaimException$8, InvalidIdentityTokenException$8, MalformedPolicyDocumentException$8, PackedPolicyTooLargeException$8, RegionDisabledException$8, errorTypeRegistries28, accessKeySecretType8, clientTokenType8, AssumedRoleUser$8, AssumeRoleRequest$8, AssumeRoleResponse$8, AssumeRoleWithWebIdentityRequest$8, AssumeRoleWithWebIdentityResponse$8, Credentials$9, PolicyDescriptorType$8, ProvidedContext$8, Tag$8, policyDescriptorListType8, ProvidedContextsListType8, tagKeyListType8, tagListType8, AssumeRole$8, AssumeRoleWithWebIdentity$8;
var init_schemas_028 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/schemas/schemas_0.js"() {
    init_schema4();
    init_errors28();
    init_STSServiceException8();
    _A8 = "Arn";
    _AKI9 = "AccessKeyId";
    _AR8 = "AssumeRole";
    _ARI8 = "AssumedRoleId";
    _ARR8 = "AssumeRoleRequest";
    _ARRs8 = "AssumeRoleResponse";
    _ARU8 = "AssumedRoleUser";
    _ARWWI8 = "AssumeRoleWithWebIdentity";
    _ARWWIR8 = "AssumeRoleWithWebIdentityRequest";
    _ARWWIRs8 = "AssumeRoleWithWebIdentityResponse";
    _Au8 = "Audience";
    _C9 = "Credentials";
    _CA8 = "ContextAssertion";
    _DS8 = "DurationSeconds";
    _E9 = "Expiration";
    _EI8 = "ExternalId";
    _ETE11 = "ExpiredTokenException";
    _IDPCEE8 = "IDPCommunicationErrorException";
    _IDPRCE8 = "IDPRejectedClaimException";
    _IITE8 = "InvalidIdentityTokenException";
    _K8 = "Key";
    _MPDE8 = "MalformedPolicyDocumentException";
    _P8 = "Policy";
    _PA8 = "PolicyArns";
    _PAr8 = "ProviderArn";
    _PC8 = "ProvidedContexts";
    _PCLT8 = "ProvidedContextsListType";
    _PCr8 = "ProvidedContext";
    _PDT8 = "PolicyDescriptorType";
    _PI8 = "ProviderId";
    _PPS8 = "PackedPolicySize";
    _PPTLE8 = "PackedPolicyTooLargeException";
    _Pr8 = "Provider";
    _RA8 = "RoleArn";
    _RDE8 = "RegionDisabledException";
    _RSN8 = "RoleSessionName";
    _SAK8 = "SecretAccessKey";
    _SFWIT8 = "SubjectFromWebIdentityToken";
    _SI8 = "SourceIdentity";
    _SN8 = "SerialNumber";
    _ST9 = "SessionToken";
    _T8 = "Tags";
    _TC8 = "TokenCode";
    _TTK8 = "TransitiveTagKeys";
    _Ta8 = "Tag";
    _V8 = "Value";
    _WIT8 = "WebIdentityToken";
    _a8 = "arn";
    _aKST8 = "accessKeySecretType";
    _aQE8 = "awsQueryError";
    _c28 = "client";
    _cTT8 = "clientTokenType";
    _e28 = "error";
    _hE28 = "httpError";
    _m25 = "message";
    _pDLT8 = "policyDescriptorListType";
    _s28 = "smithy.ts.sdk.synthetic.com.amazonaws.sts";
    _tLT8 = "tagListType";
    n028 = "com.amazonaws.sts";
    _s_registry28 = TypeRegistry.for(_s28);
    STSServiceException$8 = [-3, _s28, "STSServiceException", 0, [], []];
    _s_registry28.registerError(STSServiceException$8, STSServiceException8);
    n0_registry28 = TypeRegistry.for(n028);
    ExpiredTokenException$11 = [
      -3,
      n028,
      _ETE11,
      { [_aQE8]: [`ExpiredTokenException`, 400], [_e28]: _c28, [_hE28]: 400 },
      [_m25],
      [0]
    ];
    n0_registry28.registerError(ExpiredTokenException$11, ExpiredTokenException11);
    IDPCommunicationErrorException$8 = [
      -3,
      n028,
      _IDPCEE8,
      { [_aQE8]: [`IDPCommunicationError`, 400], [_e28]: _c28, [_hE28]: 400 },
      [_m25],
      [0]
    ];
    n0_registry28.registerError(IDPCommunicationErrorException$8, IDPCommunicationErrorException8);
    IDPRejectedClaimException$8 = [
      -3,
      n028,
      _IDPRCE8,
      { [_aQE8]: [`IDPRejectedClaim`, 403], [_e28]: _c28, [_hE28]: 403 },
      [_m25],
      [0]
    ];
    n0_registry28.registerError(IDPRejectedClaimException$8, IDPRejectedClaimException8);
    InvalidIdentityTokenException$8 = [
      -3,
      n028,
      _IITE8,
      { [_aQE8]: [`InvalidIdentityToken`, 400], [_e28]: _c28, [_hE28]: 400 },
      [_m25],
      [0]
    ];
    n0_registry28.registerError(InvalidIdentityTokenException$8, InvalidIdentityTokenException8);
    MalformedPolicyDocumentException$8 = [
      -3,
      n028,
      _MPDE8,
      { [_aQE8]: [`MalformedPolicyDocument`, 400], [_e28]: _c28, [_hE28]: 400 },
      [_m25],
      [0]
    ];
    n0_registry28.registerError(MalformedPolicyDocumentException$8, MalformedPolicyDocumentException8);
    PackedPolicyTooLargeException$8 = [
      -3,
      n028,
      _PPTLE8,
      { [_aQE8]: [`PackedPolicyTooLarge`, 400], [_e28]: _c28, [_hE28]: 400 },
      [_m25],
      [0]
    ];
    n0_registry28.registerError(PackedPolicyTooLargeException$8, PackedPolicyTooLargeException8);
    RegionDisabledException$8 = [
      -3,
      n028,
      _RDE8,
      { [_aQE8]: [`RegionDisabledException`, 403], [_e28]: _c28, [_hE28]: 403 },
      [_m25],
      [0]
    ];
    n0_registry28.registerError(RegionDisabledException$8, RegionDisabledException8);
    errorTypeRegistries28 = [_s_registry28, n0_registry28];
    accessKeySecretType8 = [0, n028, _aKST8, 8, 0];
    clientTokenType8 = [0, n028, _cTT8, 8, 0];
    AssumedRoleUser$8 = [3, n028, _ARU8, 0, [_ARI8, _A8], [0, 0], 2];
    AssumeRoleRequest$8 = [
      3,
      n028,
      _ARR8,
      0,
      [_RA8, _RSN8, _PA8, _P8, _DS8, _T8, _TTK8, _EI8, _SN8, _TC8, _SI8, _PC8],
      [0, 0, () => policyDescriptorListType8, 0, 1, () => tagListType8, 64 | 0, 0, 0, 0, 0, () => ProvidedContextsListType8],
      2
    ];
    AssumeRoleResponse$8 = [
      3,
      n028,
      _ARRs8,
      0,
      [_C9, _ARU8, _PPS8, _SI8],
      [[() => Credentials$9, 0], () => AssumedRoleUser$8, 1, 0]
    ];
    AssumeRoleWithWebIdentityRequest$8 = [
      3,
      n028,
      _ARWWIR8,
      0,
      [_RA8, _RSN8, _WIT8, _PI8, _PA8, _P8, _DS8],
      [0, 0, [() => clientTokenType8, 0], 0, () => policyDescriptorListType8, 0, 1],
      3
    ];
    AssumeRoleWithWebIdentityResponse$8 = [
      3,
      n028,
      _ARWWIRs8,
      0,
      [_C9, _SFWIT8, _ARU8, _PPS8, _Pr8, _Au8, _SI8],
      [[() => Credentials$9, 0], 0, () => AssumedRoleUser$8, 1, 0, 0, 0]
    ];
    Credentials$9 = [
      3,
      n028,
      _C9,
      0,
      [_AKI9, _SAK8, _ST9, _E9],
      [0, [() => accessKeySecretType8, 0], 0, 4],
      4
    ];
    PolicyDescriptorType$8 = [3, n028, _PDT8, 0, [_a8], [0]];
    ProvidedContext$8 = [3, n028, _PCr8, 0, [_PAr8, _CA8], [0, 0]];
    Tag$8 = [3, n028, _Ta8, 0, [_K8, _V8], [0, 0], 2];
    policyDescriptorListType8 = [1, n028, _pDLT8, 0, () => PolicyDescriptorType$8];
    ProvidedContextsListType8 = [1, n028, _PCLT8, 0, () => ProvidedContext$8];
    tagKeyListType8 = 64 | 0;
    tagListType8 = [1, n028, _tLT8, 0, () => Tag$8];
    AssumeRole$8 = [9, n028, _AR8, 0, () => AssumeRoleRequest$8, () => AssumeRoleResponse$8];
    AssumeRoleWithWebIdentity$8 = [
      9,
      n028,
      _ARWWI8,
      0,
      () => AssumeRoleWithWebIdentityRequest$8,
      () => AssumeRoleWithWebIdentityResponse$8
    ];
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.shared.js
var import_signature_v4_multi_region16, import_smithy_client225, import_url_parser25, import_util_base6460, import_util_utf846, getRuntimeConfig55;
var init_runtimeConfig_shared28 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.shared.js"() {
    init_httpAuthSchemes11();
    init_protocols17();
    import_signature_v4_multi_region16 = __toESM(require_dist_cjs55());
    init_dist_es();
    import_smithy_client225 = __toESM(require_dist_cjs34());
    import_url_parser25 = __toESM(require_dist_cjs18());
    import_util_base6460 = __toESM(require_dist_cjs10());
    import_util_utf846 = __toESM(require_dist_cjs9());
    init_httpAuthSchemeProvider28();
    init_endpointResolver28();
    init_schemas_028();
    getRuntimeConfig55 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2011-06-15",
        base64Decoder: config2?.base64Decoder ?? import_util_base6460.fromBase64,
        base64Encoder: config2?.base64Encoder ?? import_util_base6460.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver28,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSTSHttpAuthSchemeProvider8,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer9()
          },
          {
            schemeId: "aws.auth#sigv4a",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4a"), "identityProvider"),
            signer: new AwsSdkSigV4ASigner9()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        logger: config2?.logger ?? new import_smithy_client225.NoOpLogger(),
        protocol: config2?.protocol ?? AwsQueryProtocol9,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.sts",
          errorTypeRegistries: errorTypeRegistries28,
          xmlNamespace: "https://sts.amazonaws.com/doc/2011-06-15/",
          version: "2011-06-15",
          serviceTarget: "AWSSecurityTokenServiceV20110615"
        },
        serviceId: config2?.serviceId ?? "STS",
        signerConstructor: config2?.signerConstructor ?? import_signature_v4_multi_region16.SignatureV4MultiRegion,
        urlParser: config2?.urlParser ?? import_url_parser25.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? import_util_utf846.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? import_util_utf846.toUtf8
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.js
var import_util_user_agent_node24, import_config_resolver48, import_hash_node26, import_middleware_retry47, import_node_config_provider25, import_node_http_handler28, import_smithy_client226, import_util_body_length_node24, import_util_defaults_mode_node24, import_util_retry34, getRuntimeConfig56;
var init_runtimeConfig28 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.js"() {
    init_package9();
    init_client18();
    init_httpAuthSchemes11();
    import_util_user_agent_node24 = __toESM(require_dist_cjs185());
    import_config_resolver48 = __toESM(require_dist_cjs25());
    init_dist_es();
    import_hash_node26 = __toESM(require_dist_cjs44());
    import_middleware_retry47 = __toESM(require_dist_cjs181());
    import_node_config_provider25 = __toESM(require_dist_cjs29());
    import_node_http_handler28 = __toESM(require_dist_cjs13());
    import_smithy_client226 = __toESM(require_dist_cjs34());
    import_util_body_length_node24 = __toESM(require_dist_cjs45());
    import_util_defaults_mode_node24 = __toESM(require_dist_cjs46());
    import_util_retry34 = __toESM(require_dist_cjs22());
    init_runtimeConfig_shared28();
    getRuntimeConfig56 = /* @__PURE__ */ __name((config2) => {
      (0, import_smithy_client226.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, import_util_defaults_mode_node24.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(import_smithy_client226.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig55(config2);
      emitWarningIfUnsupportedVersion34(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, import_node_config_provider25.loadConfig)(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS9, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? import_util_body_length_node24.calculateBodyLength,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, import_util_user_agent_node24.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_default9.version }),
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4") || (async (idProps) => await config2.credentialDefaultProvider(idProps?.__config || {})()), "identityProvider"),
            signer: new AwsSdkSigV4Signer9()
          },
          {
            schemeId: "aws.auth#sigv4a",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4a"), "identityProvider"),
            signer: new AwsSdkSigV4ASigner9()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        maxAttempts: config2?.maxAttempts ?? (0, import_node_config_provider25.loadConfig)(import_middleware_retry47.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, import_node_config_provider25.loadConfig)(import_config_resolver48.NODE_REGION_CONFIG_OPTIONS, { ...import_config_resolver48.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: import_node_http_handler28.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, import_node_config_provider25.loadConfig)({
          ...import_middleware_retry47.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || import_util_retry34.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? import_hash_node26.Hash.bind(null, "sha256"),
        sigv4aSigningRegionSet: config2?.sigv4aSigningRegionSet ?? (0, import_node_config_provider25.loadConfig)(NODE_SIGV4A_CONFIG_OPTIONS9, loaderConfig),
        streamCollector: config2?.streamCollector ?? import_node_http_handler28.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, import_node_config_provider25.loadConfig)(import_config_resolver48.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, import_node_config_provider25.loadConfig)(import_config_resolver48.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, import_node_config_provider25.loadConfig)(import_util_user_agent_node24.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration28, resolveHttpAuthRuntimeConfig28;
var init_httpAuthExtensionConfiguration28 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration28 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig28 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeExtensions.js
var import_region_config_resolver30, import_protocol_http56, import_smithy_client227, resolveRuntimeExtensions28;
var init_runtimeExtensions28 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeExtensions.js"() {
    import_region_config_resolver30 = __toESM(require_dist_cjs48());
    import_protocol_http56 = __toESM(require_dist_cjs2());
    import_smithy_client227 = __toESM(require_dist_cjs34());
    init_httpAuthExtensionConfiguration28();
    resolveRuntimeExtensions28 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign((0, import_region_config_resolver30.getAwsRegionExtensionConfiguration)(runtimeConfig), (0, import_smithy_client227.getDefaultExtensionConfiguration)(runtimeConfig), (0, import_protocol_http56.getHttpHandlerExtensionConfiguration)(runtimeConfig), getHttpAuthExtensionConfiguration28(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, (0, import_region_config_resolver30.resolveAwsRegionExtensionConfiguration)(extensionConfiguration), (0, import_smithy_client227.resolveDefaultRuntimeConfig)(extensionConfiguration), (0, import_protocol_http56.resolveHttpHandlerRuntimeConfig)(extensionConfiguration), resolveHttpAuthRuntimeConfig28(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STSClient.js
var import_middleware_host_header24, import_middleware_logger24, import_middleware_recursion_detection24, import_middleware_user_agent24, import_config_resolver49, import_middleware_content_length24, import_middleware_endpoint62, import_middleware_retry48, import_smithy_client228, STSClient9;
var init_STSClient8 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STSClient.js"() {
    import_middleware_host_header24 = __toESM(require_dist_cjs3());
    import_middleware_logger24 = __toESM(require_dist_cjs4());
    import_middleware_recursion_detection24 = __toESM(require_dist_cjs5());
    import_middleware_user_agent24 = __toESM(require_dist_cjs180());
    import_config_resolver49 = __toESM(require_dist_cjs25());
    init_dist_es();
    init_schema4();
    import_middleware_content_length24 = __toESM(require_dist_cjs26());
    import_middleware_endpoint62 = __toESM(require_dist_cjs31());
    import_middleware_retry48 = __toESM(require_dist_cjs181());
    import_smithy_client228 = __toESM(require_dist_cjs34());
    init_httpAuthSchemeProvider28();
    init_EndpointParameters28();
    init_runtimeConfig28();
    init_runtimeExtensions28();
    STSClient9 = class extends import_smithy_client228.Client {
      static {
        __name(this, "STSClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig56(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters28(_config_0);
        const _config_2 = (0, import_middleware_user_agent24.resolveUserAgentConfig)(_config_1);
        const _config_3 = (0, import_middleware_retry48.resolveRetryConfig)(_config_2);
        const _config_4 = (0, import_config_resolver49.resolveRegionConfig)(_config_3);
        const _config_5 = (0, import_middleware_host_header24.resolveHostHeaderConfig)(_config_4);
        const _config_6 = (0, import_middleware_endpoint62.resolveEndpointConfig)(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig28(_config_6);
        const _config_8 = resolveRuntimeExtensions28(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin(this.config));
        this.middlewareStack.use((0, import_middleware_user_agent24.getUserAgentPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_retry48.getRetryPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_content_length24.getContentLengthPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_host_header24.getHostHeaderPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_logger24.getLoggerPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_recursion_detection24.getRecursionDetectionPlugin)(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: defaultSTSHttpAuthSchemeParametersProvider8,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials,
            "aws.auth#sigv4a": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleCommand.js
var import_middleware_endpoint63, import_smithy_client229, AssumeRoleCommand8;
var init_AssumeRoleCommand8 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleCommand.js"() {
    import_middleware_endpoint63 = __toESM(require_dist_cjs31());
    import_smithy_client229 = __toESM(require_dist_cjs34());
    init_EndpointParameters28();
    init_schemas_028();
    AssumeRoleCommand8 = class extends import_smithy_client229.Command.classBuilder().ep(commonParams28).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint63.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "AssumeRole", {}).n("STSClient", "AssumeRoleCommand").sc(AssumeRole$8).build() {
      static {
        __name(this, "AssumeRoleCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleWithWebIdentityCommand.js
var import_middleware_endpoint64, import_smithy_client230, AssumeRoleWithWebIdentityCommand8;
var init_AssumeRoleWithWebIdentityCommand8 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleWithWebIdentityCommand.js"() {
    import_middleware_endpoint64 = __toESM(require_dist_cjs31());
    import_smithy_client230 = __toESM(require_dist_cjs34());
    init_EndpointParameters28();
    init_schemas_028();
    AssumeRoleWithWebIdentityCommand8 = class extends import_smithy_client230.Command.classBuilder().ep(commonParams28).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint64.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "AssumeRoleWithWebIdentity", {}).n("STSClient", "AssumeRoleWithWebIdentityCommand").sc(AssumeRoleWithWebIdentity$8).build() {
      static {
        __name(this, "AssumeRoleWithWebIdentityCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STS.js
var import_smithy_client231, commands28, STS8;
var init_STS8 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STS.js"() {
    import_smithy_client231 = __toESM(require_dist_cjs34());
    init_AssumeRoleCommand8();
    init_AssumeRoleWithWebIdentityCommand8();
    init_STSClient8();
    commands28 = {
      AssumeRoleCommand: AssumeRoleCommand8,
      AssumeRoleWithWebIdentityCommand: AssumeRoleWithWebIdentityCommand8
    };
    STS8 = class extends STSClient9 {
      static {
        __name(this, "STS");
      }
    };
    (0, import_smithy_client231.createAggregatedClient)(commands28, STS8);
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/index.js
var init_commands29 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/index.js"() {
    init_AssumeRoleCommand8();
    init_AssumeRoleWithWebIdentityCommand8();
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/models_0.js
var init_models_028 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultStsRoleAssumers.js
var import_region_config_resolver31, getAccountIdFromAssumedRoleUser8, resolveRegion8, getDefaultRoleAssumer15, getDefaultRoleAssumerWithWebIdentity15, isH28;
var init_defaultStsRoleAssumers8 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultStsRoleAssumers.js"() {
    init_client18();
    import_region_config_resolver31 = __toESM(require_dist_cjs48());
    init_AssumeRoleCommand8();
    init_AssumeRoleWithWebIdentityCommand8();
    getAccountIdFromAssumedRoleUser8 = /* @__PURE__ */ __name((assumedRoleUser) => {
      if (typeof assumedRoleUser?.Arn === "string") {
        const arnComponents = assumedRoleUser.Arn.split(":");
        if (arnComponents.length > 4 && arnComponents[4] !== "") {
          return arnComponents[4];
        }
      }
      return void 0;
    }, "getAccountIdFromAssumedRoleUser");
    resolveRegion8 = /* @__PURE__ */ __name(async (_region, _parentRegion, credentialProviderLogger, loaderConfig = {}) => {
      const region = typeof _region === "function" ? await _region() : _region;
      const parentRegion = typeof _parentRegion === "function" ? await _parentRegion() : _parentRegion;
      let stsDefaultRegion = "";
      const resolvedRegion = region ?? parentRegion ?? (stsDefaultRegion = await (0, import_region_config_resolver31.stsRegionDefaultResolver)(loaderConfig)());
      credentialProviderLogger?.debug?.("@aws-sdk/client-sts::resolveRegion", "accepting first of:", `${region} (credential provider clientConfig)`, `${parentRegion} (contextual client)`, `${stsDefaultRegion} (STS default: AWS_REGION, profile region, or us-east-1)`);
      return resolvedRegion;
    }, "resolveRegion");
    getDefaultRoleAssumer15 = /* @__PURE__ */ __name((stsOptions, STSClient12) => {
      let stsClient;
      let closureSourceCreds;
      return async (sourceCreds, params) => {
        closureSourceCreds = sourceCreds;
        if (!stsClient) {
          const { logger: logger5 = stsOptions?.parentClientConfig?.logger, profile = stsOptions?.parentClientConfig?.profile, region, requestHandler = stsOptions?.parentClientConfig?.requestHandler, credentialProviderLogger, userAgentAppId = stsOptions?.parentClientConfig?.userAgentAppId } = stsOptions;
          const resolvedRegion = await resolveRegion8(region, stsOptions?.parentClientConfig?.region, credentialProviderLogger, {
            logger: logger5,
            profile
          });
          const isCompatibleRequestHandler = !isH28(requestHandler);
          stsClient = new STSClient12({
            ...stsOptions,
            userAgentAppId,
            profile,
            credentialDefaultProvider: /* @__PURE__ */ __name(() => async () => closureSourceCreds, "credentialDefaultProvider"),
            region: resolvedRegion,
            requestHandler: isCompatibleRequestHandler ? requestHandler : void 0,
            logger: logger5
          });
        }
        const { Credentials, AssumedRoleUser } = await stsClient.send(new AssumeRoleCommand8(params));
        if (!Credentials || !Credentials.AccessKeyId || !Credentials.SecretAccessKey) {
          throw new Error(`Invalid response from STS.assumeRole call with role ${params.RoleArn}`);
        }
        const accountId = getAccountIdFromAssumedRoleUser8(AssumedRoleUser);
        const credentials = {
          accessKeyId: Credentials.AccessKeyId,
          secretAccessKey: Credentials.SecretAccessKey,
          sessionToken: Credentials.SessionToken,
          expiration: Credentials.Expiration,
          ...Credentials.CredentialScope && { credentialScope: Credentials.CredentialScope },
          ...accountId && { accountId }
        };
        setCredentialFeature11(credentials, "CREDENTIALS_STS_ASSUME_ROLE", "i");
        return credentials;
      };
    }, "getDefaultRoleAssumer");
    getDefaultRoleAssumerWithWebIdentity15 = /* @__PURE__ */ __name((stsOptions, STSClient12) => {
      let stsClient;
      return async (params) => {
        if (!stsClient) {
          const { logger: logger5 = stsOptions?.parentClientConfig?.logger, profile = stsOptions?.parentClientConfig?.profile, region, requestHandler = stsOptions?.parentClientConfig?.requestHandler, credentialProviderLogger, userAgentAppId = stsOptions?.parentClientConfig?.userAgentAppId } = stsOptions;
          const resolvedRegion = await resolveRegion8(region, stsOptions?.parentClientConfig?.region, credentialProviderLogger, {
            logger: logger5,
            profile
          });
          const isCompatibleRequestHandler = !isH28(requestHandler);
          stsClient = new STSClient12({
            ...stsOptions,
            userAgentAppId,
            profile,
            region: resolvedRegion,
            requestHandler: isCompatibleRequestHandler ? requestHandler : void 0,
            logger: logger5
          });
        }
        const { Credentials, AssumedRoleUser } = await stsClient.send(new AssumeRoleWithWebIdentityCommand8(params));
        if (!Credentials || !Credentials.AccessKeyId || !Credentials.SecretAccessKey) {
          throw new Error(`Invalid response from STS.assumeRoleWithWebIdentity call with role ${params.RoleArn}`);
        }
        const accountId = getAccountIdFromAssumedRoleUser8(AssumedRoleUser);
        const credentials = {
          accessKeyId: Credentials.AccessKeyId,
          secretAccessKey: Credentials.SecretAccessKey,
          sessionToken: Credentials.SessionToken,
          expiration: Credentials.Expiration,
          ...Credentials.CredentialScope && { credentialScope: Credentials.CredentialScope },
          ...accountId && { accountId }
        };
        if (accountId) {
          setCredentialFeature11(credentials, "RESOLVED_ACCOUNT_ID", "T");
        }
        setCredentialFeature11(credentials, "CREDENTIALS_STS_ASSUME_ROLE_WEB_ID", "k");
        return credentials;
      };
    }, "getDefaultRoleAssumerWithWebIdentity");
    isH28 = /* @__PURE__ */ __name((requestHandler) => {
      return requestHandler?.metadata?.handlerProtocol === "h2";
    }, "isH2");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultRoleAssumers.js
var getCustomizableStsClientCtor8, getDefaultRoleAssumer16, getDefaultRoleAssumerWithWebIdentity16, decorateDefaultCredentialProvider8;
var init_defaultRoleAssumers8 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultRoleAssumers.js"() {
    init_defaultStsRoleAssumers8();
    init_STSClient8();
    getCustomizableStsClientCtor8 = /* @__PURE__ */ __name((baseCtor, customizations) => {
      if (!customizations)
        return baseCtor;
      else
        return class CustomizableSTSClient extends baseCtor {
          static {
            __name(this, "CustomizableSTSClient");
          }
          constructor(config2) {
            super(config2);
            for (const customization of customizations) {
              this.middlewareStack.use(customization);
            }
          }
        };
    }, "getCustomizableStsClientCtor");
    getDefaultRoleAssumer16 = /* @__PURE__ */ __name((stsOptions = {}, stsPlugins) => getDefaultRoleAssumer15(stsOptions, getCustomizableStsClientCtor8(STSClient9, stsPlugins)), "getDefaultRoleAssumer");
    getDefaultRoleAssumerWithWebIdentity16 = /* @__PURE__ */ __name((stsOptions = {}, stsPlugins) => getDefaultRoleAssumerWithWebIdentity15(stsOptions, getCustomizableStsClientCtor8(STSClient9, stsPlugins)), "getDefaultRoleAssumerWithWebIdentity");
    decorateDefaultCredentialProvider8 = /* @__PURE__ */ __name((provider) => (input) => provider({
      roleAssumer: getDefaultRoleAssumer16(input),
      roleAssumerWithWebIdentity: getDefaultRoleAssumerWithWebIdentity16(input),
      ...input
    }), "decorateDefaultCredentialProvider");
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/index.js
var sts_exports8 = {};
__export(sts_exports8, {
  AssumeRole$: () => AssumeRole$8,
  AssumeRoleCommand: () => AssumeRoleCommand8,
  AssumeRoleRequest$: () => AssumeRoleRequest$8,
  AssumeRoleResponse$: () => AssumeRoleResponse$8,
  AssumeRoleWithWebIdentity$: () => AssumeRoleWithWebIdentity$8,
  AssumeRoleWithWebIdentityCommand: () => AssumeRoleWithWebIdentityCommand8,
  AssumeRoleWithWebIdentityRequest$: () => AssumeRoleWithWebIdentityRequest$8,
  AssumeRoleWithWebIdentityResponse$: () => AssumeRoleWithWebIdentityResponse$8,
  AssumedRoleUser$: () => AssumedRoleUser$8,
  Credentials$: () => Credentials$9,
  ExpiredTokenException: () => ExpiredTokenException11,
  ExpiredTokenException$: () => ExpiredTokenException$11,
  IDPCommunicationErrorException: () => IDPCommunicationErrorException8,
  IDPCommunicationErrorException$: () => IDPCommunicationErrorException$8,
  IDPRejectedClaimException: () => IDPRejectedClaimException8,
  IDPRejectedClaimException$: () => IDPRejectedClaimException$8,
  InvalidIdentityTokenException: () => InvalidIdentityTokenException8,
  InvalidIdentityTokenException$: () => InvalidIdentityTokenException$8,
  MalformedPolicyDocumentException: () => MalformedPolicyDocumentException8,
  MalformedPolicyDocumentException$: () => MalformedPolicyDocumentException$8,
  PackedPolicyTooLargeException: () => PackedPolicyTooLargeException8,
  PackedPolicyTooLargeException$: () => PackedPolicyTooLargeException$8,
  PolicyDescriptorType$: () => PolicyDescriptorType$8,
  ProvidedContext$: () => ProvidedContext$8,
  RegionDisabledException: () => RegionDisabledException8,
  RegionDisabledException$: () => RegionDisabledException$8,
  STS: () => STS8,
  STSClient: () => STSClient9,
  STSServiceException: () => STSServiceException8,
  STSServiceException$: () => STSServiceException$8,
  Tag$: () => Tag$8,
  __Client: () => import_smithy_client228.Client,
  decorateDefaultCredentialProvider: () => decorateDefaultCredentialProvider8,
  errorTypeRegistries: () => errorTypeRegistries28,
  getDefaultRoleAssumer: () => getDefaultRoleAssumer16,
  getDefaultRoleAssumerWithWebIdentity: () => getDefaultRoleAssumerWithWebIdentity16
});
var init_sts8 = __esm({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/index.js"() {
    init_STSClient8();
    init_STS8();
    init_commands29();
    init_schemas_028();
    init_errors28();
    init_models_028();
    init_defaultRoleAssumers8();
    init_STSServiceException8();
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-process/dist-cjs/index.js
var require_dist_cjs188 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-process/dist-cjs/index.js"(exports2) {
    "use strict";
    var sharedIniFileLoader = require_dist_cjs28();
    var propertyProvider = require_dist_cjs27();
    var node_child_process = require("node:child_process");
    var node_util = require("node:util");
    var client = (init_client18(), __toCommonJS(client_exports13));
    var getValidatedProcessCredentials = /* @__PURE__ */ __name((profileName, data3, profiles) => {
      if (data3.Version !== 1) {
        throw Error(`Profile ${profileName} credential_process did not return Version 1.`);
      }
      if (data3.AccessKeyId === void 0 || data3.SecretAccessKey === void 0) {
        throw Error(`Profile ${profileName} credential_process returned invalid credentials.`);
      }
      if (data3.Expiration) {
        const currentTime = /* @__PURE__ */ new Date();
        const expireTime = new Date(data3.Expiration);
        if (expireTime < currentTime) {
          throw Error(`Profile ${profileName} credential_process returned expired credentials.`);
        }
      }
      let accountId = data3.AccountId;
      if (!accountId && profiles?.[profileName]?.aws_account_id) {
        accountId = profiles[profileName].aws_account_id;
      }
      const credentials = {
        accessKeyId: data3.AccessKeyId,
        secretAccessKey: data3.SecretAccessKey,
        ...data3.SessionToken && { sessionToken: data3.SessionToken },
        ...data3.Expiration && { expiration: new Date(data3.Expiration) },
        ...data3.CredentialScope && { credentialScope: data3.CredentialScope },
        ...accountId && { accountId }
      };
      client.setCredentialFeature(credentials, "CREDENTIALS_PROCESS", "w");
      return credentials;
    }, "getValidatedProcessCredentials");
    var resolveProcessCredentials = /* @__PURE__ */ __name(async (profileName, profiles, logger5) => {
      const profile = profiles[profileName];
      if (profiles[profileName]) {
        const credentialProcess = profile["credential_process"];
        if (credentialProcess !== void 0) {
          const execPromise = node_util.promisify(sharedIniFileLoader.externalDataInterceptor?.getTokenRecord?.().exec ?? node_child_process.exec);
          try {
            const { stdout } = await execPromise(credentialProcess);
            let data3;
            try {
              data3 = JSON.parse(stdout.trim());
            } catch {
              throw Error(`Profile ${profileName} credential_process returned invalid JSON.`);
            }
            return getValidatedProcessCredentials(profileName, data3, profiles);
          } catch (error4) {
            throw new propertyProvider.CredentialsProviderError(error4.message, { logger: logger5 });
          }
        } else {
          throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} did not contain credential_process.`, { logger: logger5 });
        }
      } else {
        throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} could not be found in shared credentials file.`, {
          logger: logger5
        });
      }
    }, "resolveProcessCredentials");
    var fromProcess = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/credential-provider-process - fromProcess");
      const profiles = await sharedIniFileLoader.parseKnownFiles(init);
      return resolveProcessCredentials(sharedIniFileLoader.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      }), profiles, init.logger);
    }, "fromProcess");
    exports2.fromProcess = fromProcess;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromWebToken.js
var require_fromWebToken9 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromWebToken.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __setModuleDefault2 = exports2 && exports2.__setModuleDefault || (Object.create ? (function(o10, v) {
      Object.defineProperty(o10, "default", { enumerable: true, value: v });
    }) : function(o10, v) {
      o10["default"] = v;
    });
    var __importStar2 = exports2 && exports2.__importStar || /* @__PURE__ */ (function() {
      var ownKeys2 = /* @__PURE__ */ __name(function(o10) {
        ownKeys2 = Object.getOwnPropertyNames || function(o11) {
          var ar = [];
          for (var k32 in o11) if (Object.prototype.hasOwnProperty.call(o11, k32)) ar[ar.length] = k32;
          return ar;
        };
        return ownKeys2(o10);
      }, "ownKeys");
      return function(mod) {
        if (mod && mod.__esModule) return mod;
        var result2 = {};
        if (mod != null) {
          for (var k32 = ownKeys2(mod), i32 = 0; i32 < k32.length; i32++) if (k32[i32] !== "default") __createBinding3(result2, mod, k32[i32]);
        }
        __setModuleDefault2(result2, mod);
        return result2;
      };
    })();
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromWebToken = void 0;
    var fromWebToken = /* @__PURE__ */ __name((init) => async (awsIdentityProperties) => {
      init.logger?.debug("@aws-sdk/credential-provider-web-identity - fromWebToken");
      const { roleArn, roleSessionName, webIdentityToken, providerId, policyArns, policy, durationSeconds } = init;
      let { roleAssumerWithWebIdentity } = init;
      if (!roleAssumerWithWebIdentity) {
        const { getDefaultRoleAssumerWithWebIdentity: getDefaultRoleAssumerWithWebIdentity19 } = await Promise.resolve().then(() => __importStar2((init_sts8(), __toCommonJS(sts_exports8))));
        roleAssumerWithWebIdentity = getDefaultRoleAssumerWithWebIdentity19({
          ...init.clientConfig,
          credentialProviderLogger: init.logger,
          parentClientConfig: {
            ...awsIdentityProperties?.callerClientConfig,
            ...init.parentClientConfig
          }
        }, init.clientPlugins);
      }
      return roleAssumerWithWebIdentity({
        RoleArn: roleArn,
        RoleSessionName: roleSessionName ?? `aws-sdk-js-session-${Date.now()}`,
        WebIdentityToken: webIdentityToken,
        ProviderId: providerId,
        PolicyArns: policyArns,
        Policy: policy,
        DurationSeconds: durationSeconds
      });
    }, "fromWebToken");
    exports2.fromWebToken = fromWebToken;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromTokenFile.js
var require_fromTokenFile9 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromTokenFile.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromTokenFile = void 0;
    var client_1 = (init_client18(), __toCommonJS(client_exports13));
    var property_provider_1 = require_dist_cjs27();
    var shared_ini_file_loader_1 = require_dist_cjs28();
    var node_fs_1 = require("node:fs");
    var fromWebToken_1 = require_fromWebToken9();
    var ENV_TOKEN_FILE = "AWS_WEB_IDENTITY_TOKEN_FILE";
    var ENV_ROLE_ARN = "AWS_ROLE_ARN";
    var ENV_ROLE_SESSION_NAME = "AWS_ROLE_SESSION_NAME";
    var fromTokenFile = /* @__PURE__ */ __name((init = {}) => async (awsIdentityProperties) => {
      init.logger?.debug("@aws-sdk/credential-provider-web-identity - fromTokenFile");
      const webIdentityTokenFile = init?.webIdentityTokenFile ?? process.env[ENV_TOKEN_FILE];
      const roleArn = init?.roleArn ?? process.env[ENV_ROLE_ARN];
      const roleSessionName = init?.roleSessionName ?? process.env[ENV_ROLE_SESSION_NAME];
      if (!webIdentityTokenFile || !roleArn) {
        throw new property_provider_1.CredentialsProviderError("Web identity configuration not specified", {
          logger: init.logger
        });
      }
      const credentials = await (0, fromWebToken_1.fromWebToken)({
        ...init,
        webIdentityToken: shared_ini_file_loader_1.externalDataInterceptor?.getTokenRecord?.()[webIdentityTokenFile] ?? (0, node_fs_1.readFileSync)(webIdentityTokenFile, { encoding: "ascii" }),
        roleArn,
        roleSessionName
      })(awsIdentityProperties);
      if (webIdentityTokenFile === process.env[ENV_TOKEN_FILE]) {
        (0, client_1.setCredentialFeature)(credentials, "CREDENTIALS_ENV_VARS_STS_WEB_ID_TOKEN", "h");
      }
      return credentials;
    }, "fromTokenFile");
    exports2.fromTokenFile = fromTokenFile;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/index.js
var require_dist_cjs189 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/index.js"(exports2) {
    "use strict";
    var fromTokenFile = require_fromTokenFile9();
    var fromWebToken = require_fromWebToken9();
    Object.prototype.hasOwnProperty.call(fromTokenFile, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: fromTokenFile["__proto__"]
    });
    Object.keys(fromTokenFile).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = fromTokenFile[k32];
    });
    Object.prototype.hasOwnProperty.call(fromWebToken, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: fromWebToken["__proto__"]
    });
    Object.keys(fromWebToken).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = fromWebToken[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-ini/dist-cjs/index.js
var require_dist_cjs190 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-ini/dist-cjs/index.js"(exports2) {
    "use strict";
    var sharedIniFileLoader = require_dist_cjs28();
    var propertyProvider = require_dist_cjs27();
    var client = (init_client18(), __toCommonJS(client_exports13));
    var credentialProviderLogin = require_dist_cjs187();
    var resolveCredentialSource = /* @__PURE__ */ __name((credentialSource, profileName, logger5) => {
      const sourceProvidersMap = {
        EcsContainer: /* @__PURE__ */ __name(async (options) => {
          const { fromHttp } = await Promise.resolve().then(() => __toESM(require_dist_cjs184()));
          const { fromContainerMetadata } = await Promise.resolve().then(() => __toESM(require_dist_cjs38()));
          logger5?.debug("@aws-sdk/credential-provider-ini - credential_source is EcsContainer");
          return async () => propertyProvider.chain(fromHttp(options ?? {}), fromContainerMetadata(options))().then(setNamedProvider);
        }, "EcsContainer"),
        Ec2InstanceMetadata: /* @__PURE__ */ __name(async (options) => {
          logger5?.debug("@aws-sdk/credential-provider-ini - credential_source is Ec2InstanceMetadata");
          const { fromInstanceMetadata } = await Promise.resolve().then(() => __toESM(require_dist_cjs38()));
          return async () => fromInstanceMetadata(options)().then(setNamedProvider);
        }, "Ec2InstanceMetadata"),
        Environment: /* @__PURE__ */ __name(async (options) => {
          logger5?.debug("@aws-sdk/credential-provider-ini - credential_source is Environment");
          const { fromEnv: fromEnv6 } = await Promise.resolve().then(() => __toESM(require_dist_cjs182()));
          return async () => fromEnv6(options)().then(setNamedProvider);
        }, "Environment")
      };
      if (credentialSource in sourceProvidersMap) {
        return sourceProvidersMap[credentialSource];
      } else {
        throw new propertyProvider.CredentialsProviderError(`Unsupported credential source in profile ${profileName}. Got ${credentialSource}, expected EcsContainer or Ec2InstanceMetadata or Environment.`, { logger: logger5 });
      }
    }, "resolveCredentialSource");
    var setNamedProvider = /* @__PURE__ */ __name((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_NAMED_PROVIDER", "p"), "setNamedProvider");
    var isAssumeRoleProfile = /* @__PURE__ */ __name((arg, { profile = "default", logger: logger5 } = {}) => {
      return Boolean(arg) && typeof arg === "object" && typeof arg.role_arn === "string" && ["undefined", "string"].indexOf(typeof arg.role_session_name) > -1 && ["undefined", "string"].indexOf(typeof arg.external_id) > -1 && ["undefined", "string"].indexOf(typeof arg.mfa_serial) > -1 && (isAssumeRoleWithSourceProfile(arg, { profile, logger: logger5 }) || isCredentialSourceProfile(arg, { profile, logger: logger5 }));
    }, "isAssumeRoleProfile");
    var isAssumeRoleWithSourceProfile = /* @__PURE__ */ __name((arg, { profile, logger: logger5 }) => {
      const withSourceProfile = typeof arg.source_profile === "string" && typeof arg.credential_source === "undefined";
      if (withSourceProfile) {
        logger5?.debug?.(`    ${profile} isAssumeRoleWithSourceProfile source_profile=${arg.source_profile}`);
      }
      return withSourceProfile;
    }, "isAssumeRoleWithSourceProfile");
    var isCredentialSourceProfile = /* @__PURE__ */ __name((arg, { profile, logger: logger5 }) => {
      const withProviderProfile = typeof arg.credential_source === "string" && typeof arg.source_profile === "undefined";
      if (withProviderProfile) {
        logger5?.debug?.(`    ${profile} isCredentialSourceProfile credential_source=${arg.credential_source}`);
      }
      return withProviderProfile;
    }, "isCredentialSourceProfile");
    var resolveAssumeRoleCredentials = /* @__PURE__ */ __name(async (profileName, profiles, options, callerClientConfig, visitedProfiles = {}, resolveProfileData2) => {
      options.logger?.debug("@aws-sdk/credential-provider-ini - resolveAssumeRoleCredentials (STS)");
      const profileData = profiles[profileName];
      const { source_profile, region } = profileData;
      if (!options.roleAssumer) {
        const { getDefaultRoleAssumer: getDefaultRoleAssumer19 } = await Promise.resolve().then(() => (init_sts8(), sts_exports8));
        options.roleAssumer = getDefaultRoleAssumer19({
          ...options.clientConfig,
          credentialProviderLogger: options.logger,
          parentClientConfig: {
            ...callerClientConfig,
            ...options?.parentClientConfig,
            region: region ?? options?.parentClientConfig?.region ?? callerClientConfig?.region
          }
        }, options.clientPlugins);
      }
      if (source_profile && source_profile in visitedProfiles) {
        throw new propertyProvider.CredentialsProviderError(`Detected a cycle attempting to resolve credentials for profile ${sharedIniFileLoader.getProfileName(options)}. Profiles visited: ` + Object.keys(visitedProfiles).join(", "), { logger: options.logger });
      }
      options.logger?.debug(`@aws-sdk/credential-provider-ini - finding credential resolver using ${source_profile ? `source_profile=[${source_profile}]` : `profile=[${profileName}]`}`);
      const sourceCredsProvider = source_profile ? resolveProfileData2(source_profile, profiles, options, callerClientConfig, {
        ...visitedProfiles,
        [source_profile]: true
      }, isCredentialSourceWithoutRoleArn(profiles[source_profile] ?? {})) : (await resolveCredentialSource(profileData.credential_source, profileName, options.logger)(options))();
      if (isCredentialSourceWithoutRoleArn(profileData)) {
        return sourceCredsProvider.then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SOURCE_PROFILE", "o"));
      } else {
        const params = {
          RoleArn: profileData.role_arn,
          RoleSessionName: profileData.role_session_name || `aws-sdk-js-${Date.now()}`,
          ExternalId: profileData.external_id,
          DurationSeconds: parseInt(profileData.duration_seconds || "3600", 10)
        };
        const { mfa_serial } = profileData;
        if (mfa_serial) {
          if (!options.mfaCodeProvider) {
            throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} requires multi-factor authentication, but no MFA code callback was provided.`, { logger: options.logger, tryNextLink: false });
          }
          params.SerialNumber = mfa_serial;
          params.TokenCode = await options.mfaCodeProvider(mfa_serial);
        }
        const sourceCreds = await sourceCredsProvider;
        return options.roleAssumer(sourceCreds, params).then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SOURCE_PROFILE", "o"));
      }
    }, "resolveAssumeRoleCredentials");
    var isCredentialSourceWithoutRoleArn = /* @__PURE__ */ __name((section) => {
      return !section.role_arn && !!section.credential_source;
    }, "isCredentialSourceWithoutRoleArn");
    var isLoginProfile = /* @__PURE__ */ __name((data3) => {
      return Boolean(data3 && data3.login_session);
    }, "isLoginProfile");
    var resolveLoginCredentials = /* @__PURE__ */ __name(async (profileName, options, callerClientConfig) => {
      const credentials = await credentialProviderLogin.fromLoginCredentials({
        ...options,
        profile: profileName
      })({ callerClientConfig });
      return client.setCredentialFeature(credentials, "CREDENTIALS_PROFILE_LOGIN", "AC");
    }, "resolveLoginCredentials");
    var isProcessProfile = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.credential_process === "string", "isProcessProfile");
    var resolveProcessCredentials = /* @__PURE__ */ __name(async (options, profile) => Promise.resolve().then(() => __toESM(require_dist_cjs188())).then(({ fromProcess }) => fromProcess({
      ...options,
      profile
    })().then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_PROCESS", "v"))), "resolveProcessCredentials");
    var resolveSsoCredentials = /* @__PURE__ */ __name(async (profile, profileData, options = {}, callerClientConfig) => {
      const { fromSSO } = await Promise.resolve().then(() => __toESM(require_dist_cjs186()));
      return fromSSO({
        profile,
        logger: options.logger,
        parentClientConfig: options.parentClientConfig,
        clientConfig: options.clientConfig
      })({
        callerClientConfig
      }).then((creds) => {
        if (profileData.sso_session) {
          return client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SSO", "r");
        } else {
          return client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SSO_LEGACY", "t");
        }
      });
    }, "resolveSsoCredentials");
    var isSsoProfile = /* @__PURE__ */ __name((arg) => arg && (typeof arg.sso_start_url === "string" || typeof arg.sso_account_id === "string" || typeof arg.sso_session === "string" || typeof arg.sso_region === "string" || typeof arg.sso_role_name === "string"), "isSsoProfile");
    var isStaticCredsProfile = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.aws_access_key_id === "string" && typeof arg.aws_secret_access_key === "string" && ["undefined", "string"].indexOf(typeof arg.aws_session_token) > -1 && ["undefined", "string"].indexOf(typeof arg.aws_account_id) > -1, "isStaticCredsProfile");
    var resolveStaticCredentials = /* @__PURE__ */ __name(async (profile, options) => {
      options?.logger?.debug("@aws-sdk/credential-provider-ini - resolveStaticCredentials");
      const credentials = {
        accessKeyId: profile.aws_access_key_id,
        secretAccessKey: profile.aws_secret_access_key,
        sessionToken: profile.aws_session_token,
        ...profile.aws_credential_scope && { credentialScope: profile.aws_credential_scope },
        ...profile.aws_account_id && { accountId: profile.aws_account_id }
      };
      return client.setCredentialFeature(credentials, "CREDENTIALS_PROFILE", "n");
    }, "resolveStaticCredentials");
    var isWebIdentityProfile = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.web_identity_token_file === "string" && typeof arg.role_arn === "string" && ["undefined", "string"].indexOf(typeof arg.role_session_name) > -1, "isWebIdentityProfile");
    var resolveWebIdentityCredentials = /* @__PURE__ */ __name(async (profile, options, callerClientConfig) => Promise.resolve().then(() => __toESM(require_dist_cjs189())).then(({ fromTokenFile }) => fromTokenFile({
      webIdentityTokenFile: profile.web_identity_token_file,
      roleArn: profile.role_arn,
      roleSessionName: profile.role_session_name,
      roleAssumerWithWebIdentity: options.roleAssumerWithWebIdentity,
      logger: options.logger,
      parentClientConfig: options.parentClientConfig
    })({
      callerClientConfig
    }).then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_STS_WEB_ID_TOKEN", "q"))), "resolveWebIdentityCredentials");
    var resolveProfileData = /* @__PURE__ */ __name(async (profileName, profiles, options, callerClientConfig, visitedProfiles = {}, isAssumeRoleRecursiveCall = false) => {
      const data3 = profiles[profileName];
      if (Object.keys(visitedProfiles).length > 0 && isStaticCredsProfile(data3)) {
        return resolveStaticCredentials(data3, options);
      }
      if (isAssumeRoleRecursiveCall || isAssumeRoleProfile(data3, { profile: profileName, logger: options.logger })) {
        return resolveAssumeRoleCredentials(profileName, profiles, options, callerClientConfig, visitedProfiles, resolveProfileData);
      }
      if (isStaticCredsProfile(data3)) {
        return resolveStaticCredentials(data3, options);
      }
      if (isWebIdentityProfile(data3)) {
        return resolveWebIdentityCredentials(data3, options, callerClientConfig);
      }
      if (isProcessProfile(data3)) {
        return resolveProcessCredentials(options, profileName);
      }
      if (isSsoProfile(data3)) {
        return await resolveSsoCredentials(profileName, data3, options, callerClientConfig);
      }
      if (isLoginProfile(data3)) {
        return resolveLoginCredentials(profileName, options, callerClientConfig);
      }
      throw new propertyProvider.CredentialsProviderError(`Could not resolve credentials using profile: [${profileName}] in configuration/credentials file(s).`, { logger: options.logger });
    }, "resolveProfileData");
    var fromIni2 = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/credential-provider-ini - fromIni");
      const profiles = await sharedIniFileLoader.parseKnownFiles(init);
      return resolveProfileData(sharedIniFileLoader.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      }), profiles, init, callerClientConfig);
    }, "fromIni");
    exports2.fromIni = fromIni2;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-node/dist-cjs/index.js
var require_dist_cjs191 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@aws-sdk/credential-provider-node/dist-cjs/index.js"(exports2) {
    "use strict";
    var credentialProviderEnv = require_dist_cjs182();
    var propertyProvider = require_dist_cjs27();
    var sharedIniFileLoader = require_dist_cjs28();
    var ENV_IMDS_DISABLED3 = "AWS_EC2_METADATA_DISABLED";
    var remoteProvider = /* @__PURE__ */ __name(async (init) => {
      const { ENV_CMDS_FULL_URI, ENV_CMDS_RELATIVE_URI, fromContainerMetadata, fromInstanceMetadata } = await Promise.resolve().then(() => __toESM(require_dist_cjs38()));
      if (process.env[ENV_CMDS_RELATIVE_URI] || process.env[ENV_CMDS_FULL_URI]) {
        init.logger?.debug("@aws-sdk/credential-provider-node - remoteProvider::fromHttp/fromContainerMetadata");
        const { fromHttp } = await Promise.resolve().then(() => __toESM(require_dist_cjs184()));
        return propertyProvider.chain(fromHttp(init), fromContainerMetadata(init));
      }
      if (process.env[ENV_IMDS_DISABLED3] && process.env[ENV_IMDS_DISABLED3] !== "false") {
        return async () => {
          throw new propertyProvider.CredentialsProviderError("EC2 Instance Metadata Service access disabled", { logger: init.logger });
        };
      }
      init.logger?.debug("@aws-sdk/credential-provider-node - remoteProvider::fromInstanceMetadata");
      return fromInstanceMetadata(init);
    }, "remoteProvider");
    function memoizeChain(providers, treatAsExpired) {
      const chain5 = internalCreateChain(providers);
      let activeLock;
      let passiveLock;
      let credentials;
      const provider = /* @__PURE__ */ __name(async (options) => {
        if (options?.forceRefresh) {
          return await chain5(options);
        }
        if (credentials?.expiration) {
          if (credentials?.expiration?.getTime() < Date.now()) {
            credentials = void 0;
          }
        }
        if (activeLock) {
          await activeLock;
        } else if (!credentials || treatAsExpired?.(credentials)) {
          if (credentials) {
            if (!passiveLock) {
              passiveLock = chain5(options).then((c32) => {
                credentials = c32;
              }).finally(() => {
                passiveLock = void 0;
              });
            }
          } else {
            activeLock = chain5(options).then((c32) => {
              credentials = c32;
            }).finally(() => {
              activeLock = void 0;
            });
            return provider(options);
          }
        }
        return credentials;
      }, "provider");
      return provider;
    }
    __name(memoizeChain, "memoizeChain");
    var internalCreateChain = /* @__PURE__ */ __name((providers) => async (awsIdentityProperties) => {
      let lastProviderError;
      for (const provider of providers) {
        try {
          return await provider(awsIdentityProperties);
        } catch (err) {
          lastProviderError = err;
          if (err?.tryNextLink) {
            continue;
          }
          throw err;
        }
      }
      throw lastProviderError;
    }, "internalCreateChain");
    var multipleCredentialSourceWarningEmitted = false;
    var defaultProvider = /* @__PURE__ */ __name((init = {}) => memoizeChain([
      async () => {
        const profile = init.profile ?? process.env[sharedIniFileLoader.ENV_PROFILE];
        if (profile) {
          const envStaticCredentialsAreSet = process.env[credentialProviderEnv.ENV_KEY] && process.env[credentialProviderEnv.ENV_SECRET];
          if (envStaticCredentialsAreSet) {
            if (!multipleCredentialSourceWarningEmitted) {
              const warnFn = init.logger?.warn && init.logger?.constructor?.name !== "NoOpLogger" ? init.logger.warn.bind(init.logger) : console.warn;
              warnFn(`@aws-sdk/credential-provider-node - defaultProvider::fromEnv WARNING:
    Multiple credential sources detected: 
    Both AWS_PROFILE and the pair AWS_ACCESS_KEY_ID/AWS_SECRET_ACCESS_KEY static credentials are set.
    This SDK will proceed with the AWS_PROFILE value.
    
    However, a future version may change this behavior to prefer the ENV static credentials.
    Please ensure that your environment only sets either the AWS_PROFILE or the
    AWS_ACCESS_KEY_ID/AWS_SECRET_ACCESS_KEY pair.
`);
              multipleCredentialSourceWarningEmitted = true;
            }
          }
          throw new propertyProvider.CredentialsProviderError("AWS_PROFILE is set, skipping fromEnv provider.", {
            logger: init.logger,
            tryNextLink: true
          });
        }
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromEnv");
        return credentialProviderEnv.fromEnv(init)();
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromSSO");
        const { ssoStartUrl, ssoAccountId, ssoRegion, ssoRoleName, ssoSession } = init;
        if (!ssoStartUrl && !ssoAccountId && !ssoRegion && !ssoRoleName && !ssoSession) {
          throw new propertyProvider.CredentialsProviderError("Skipping SSO provider in default chain (inputs do not include SSO fields).", { logger: init.logger });
        }
        const { fromSSO } = await Promise.resolve().then(() => __toESM(require_dist_cjs186()));
        return fromSSO(init)(awsIdentityProperties);
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromIni");
        const { fromIni: fromIni2 } = await Promise.resolve().then(() => __toESM(require_dist_cjs190()));
        return fromIni2(init)(awsIdentityProperties);
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromProcess");
        const { fromProcess } = await Promise.resolve().then(() => __toESM(require_dist_cjs188()));
        return fromProcess(init)(awsIdentityProperties);
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromTokenFile");
        const { fromTokenFile } = await Promise.resolve().then(() => __toESM(require_dist_cjs189()));
        return fromTokenFile(init)(awsIdentityProperties);
      },
      async () => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::remoteProvider");
        return (await remoteProvider(init))();
      },
      async () => {
        throw new propertyProvider.CredentialsProviderError("Could not load credentials from any providers", {
          tryNextLink: false,
          logger: init.logger
        });
      }
    ], credentialsTreatedAsExpired), "defaultProvider");
    var credentialsWillNeedRefresh = /* @__PURE__ */ __name((credentials) => credentials?.expiration !== void 0, "credentialsWillNeedRefresh");
    var credentialsTreatedAsExpired = /* @__PURE__ */ __name((credentials) => credentials?.expiration !== void 0 && credentials.expiration.getTime() - Date.now() < 3e5, "credentialsTreatedAsExpired");
    exports2.credentialsTreatedAsExpired = credentialsTreatedAsExpired;
    exports2.credentialsWillNeedRefresh = credentialsWillNeedRefresh;
    exports2.defaultProvider = defaultProvider;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/dist-cjs/endpoint/bdd.js
var require_bdd16 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/dist-cjs/endpoint/bdd.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.bdd = void 0;
    var util_endpoints_1 = require_dist_cjs20();
    var k32 = "ref";
    var a32 = -1;
    var b32 = true;
    var c32 = "isSet";
    var d32 = "PartitionResult";
    var e32 = "booleanEquals";
    var f32 = "getAttr";
    var g32 = { [k32]: "Endpoint" };
    var h32 = { [k32]: d32 };
    var i32 = {};
    var j32 = [{ [k32]: "Region" }];
    var _data32 = {
      conditions: [
        [c32, [g32]],
        [c32, j32],
        ["aws.partition", j32, d32],
        [e32, [{ [k32]: "UseFIPS" }, b32]],
        [e32, [{ [k32]: "UseDualStack" }, b32]],
        [e32, [{ fn: f32, argv: [h32, "supportsDualStack"] }, b32]],
        [e32, [{ fn: f32, argv: [h32, "supportsFIPS"] }, b32]]
      ],
      results: [
        [a32],
        [a32, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a32, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [g32, i32],
        ["https://lambda-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", i32],
        [a32, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://lambda-fips.{Region}.{PartitionResult#dnsSuffix}", i32],
        [a32, "FIPS is enabled but this partition does not support FIPS"],
        ["https://lambda.{Region}.{PartitionResult#dualStackDnsSuffix}", i32],
        [a32, "DualStack is enabled but this partition does not support DualStack"],
        ["https://lambda.{Region}.{PartitionResult#dnsSuffix}", i32],
        [a32, "Invalid Configuration: Missing Region"]
      ]
    };
    var root32 = 2;
    var r32 = 1e8;
    var nodes32 = new Int32Array([
      -1,
      1,
      -1,
      0,
      12,
      3,
      1,
      4,
      r32 + 11,
      2,
      5,
      r32 + 11,
      3,
      8,
      6,
      4,
      7,
      r32 + 10,
      5,
      r32 + 8,
      r32 + 9,
      4,
      10,
      9,
      6,
      r32 + 6,
      r32 + 7,
      5,
      11,
      r32 + 5,
      6,
      r32 + 4,
      r32 + 5,
      3,
      r32 + 1,
      13,
      4,
      r32 + 2,
      r32 + 3
    ]);
    exports2.bdd = util_endpoints_1.BinaryDecisionDiagram.from(nodes32, root32, _data32.conditions, _data32.results);
  }
});

// ../../node_modules/@aws-sdk/client-lambda/dist-cjs/endpoint/endpointResolver.js
var require_endpointResolver16 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/dist-cjs/endpoint/endpointResolver.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.defaultEndpointResolver = void 0;
    var util_endpoints_1 = require_dist_cjs21();
    var util_endpoints_2 = require_dist_cjs20();
    var bdd_1 = require_bdd16();
    var cache32 = new util_endpoints_2.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    var defaultEndpointResolver32 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache32.get(endpointParams, () => (0, util_endpoints_2.decideEndpoint)(bdd_1.bdd, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    exports2.defaultEndpointResolver = defaultEndpointResolver32;
    util_endpoints_2.customEndpointFunctions.aws = util_endpoints_1.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/dist-cjs/models/LambdaServiceException.js
var require_LambdaServiceException = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/dist-cjs/models/LambdaServiceException.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.LambdaServiceException = exports2.__ServiceException = void 0;
    var smithy_client_1 = require_dist_cjs34();
    Object.defineProperty(exports2, "__ServiceException", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return smithy_client_1.ServiceException;
    }, "get") });
    var LambdaServiceException = class _LambdaServiceException extends smithy_client_1.ServiceException {
      static {
        __name(this, "LambdaServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _LambdaServiceException.prototype);
      }
    };
    exports2.LambdaServiceException = LambdaServiceException;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/dist-cjs/models/errors.js
var require_errors15 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/dist-cjs/models/errors.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.CallbackTimeoutException = exports2.ProvisionedConcurrencyConfigNotFoundException = exports2.UnsupportedMediaTypeException = exports2.SubnetIPAddressLimitReachedException = exports2.SnapStartTimeoutException = exports2.SnapStartNotReadyException = exports2.SnapStartException = exports2.SerializedRequestEntityTooLargeException = exports2.S3FilesMountTimeoutException = exports2.S3FilesMountFailureException = exports2.S3FilesMountConnectivityException = exports2.ResourceNotReadyException = exports2.RequestTooLargeException = exports2.RecursiveInvocationException = exports2.NoPublishedVersionException = exports2.KMSNotFoundException = exports2.KMSInvalidStateException = exports2.KMSDisabledException = exports2.KMSAccessDeniedException = exports2.InvalidZipFileException = exports2.InvalidSubnetIDException = exports2.InvalidSecurityGroupIDException = exports2.InvalidRuntimeException = exports2.InvalidRequestContentException = exports2.ENILimitReachedException = exports2.EFSMountTimeoutException = exports2.EFSMountFailureException = exports2.EFSMountConnectivityException = exports2.EFSIOException = exports2.EC2UnexpectedException = exports2.EC2ThrottledException = exports2.EC2AccessDeniedException = exports2.DurableExecutionAlreadyStartedException = exports2.InvalidCodeSignatureException = exports2.FunctionVersionsPerCapacityProviderLimitExceededException = exports2.CodeVerificationFailedException = exports2.CodeStorageExceededException = exports2.CodeSigningConfigNotFoundException = exports2.ResourceInUseException = exports2.CapacityProviderLimitExceededException = exports2.TooManyRequestsException = exports2.ServiceException = exports2.ResourceNotFoundException = exports2.ResourceConflictException = exports2.PreconditionFailedException = exports2.PolicyLengthExceededException = exports2.InvalidParameterValueException = void 0;
    var LambdaServiceException_1 = require_LambdaServiceException();
    var InvalidParameterValueException = class _InvalidParameterValueException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "InvalidParameterValueException");
      }
      name = "InvalidParameterValueException";
      $fault = "client";
      Type;
      constructor(opts) {
        super({
          name: "InvalidParameterValueException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidParameterValueException.prototype);
        this.Type = opts.Type;
      }
    };
    exports2.InvalidParameterValueException = InvalidParameterValueException;
    var PolicyLengthExceededException = class _PolicyLengthExceededException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "PolicyLengthExceededException");
      }
      name = "PolicyLengthExceededException";
      $fault = "client";
      Type;
      constructor(opts) {
        super({
          name: "PolicyLengthExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _PolicyLengthExceededException.prototype);
        this.Type = opts.Type;
      }
    };
    exports2.PolicyLengthExceededException = PolicyLengthExceededException;
    var PreconditionFailedException = class _PreconditionFailedException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "PreconditionFailedException");
      }
      name = "PreconditionFailedException";
      $fault = "client";
      Type;
      constructor(opts) {
        super({
          name: "PreconditionFailedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _PreconditionFailedException.prototype);
        this.Type = opts.Type;
      }
    };
    exports2.PreconditionFailedException = PreconditionFailedException;
    var ResourceConflictException2 = class _ResourceConflictException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "ResourceConflictException");
      }
      name = "ResourceConflictException";
      $fault = "client";
      Type;
      constructor(opts) {
        super({
          name: "ResourceConflictException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceConflictException.prototype);
        this.Type = opts.Type;
      }
    };
    exports2.ResourceConflictException = ResourceConflictException2;
    var ResourceNotFoundException12 = class _ResourceNotFoundException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "ResourceNotFoundException");
      }
      name = "ResourceNotFoundException";
      $fault = "client";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "ResourceNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceNotFoundException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.ResourceNotFoundException = ResourceNotFoundException12;
    var ServiceException4 = class _ServiceException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "ServiceException");
      }
      name = "ServiceException";
      $fault = "server";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "ServiceException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _ServiceException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.ServiceException = ServiceException4;
    var TooManyRequestsException11 = class _TooManyRequestsException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "TooManyRequestsException");
      }
      name = "TooManyRequestsException";
      $fault = "client";
      retryAfterSeconds;
      Type;
      Reason;
      constructor(opts) {
        super({
          name: "TooManyRequestsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyRequestsException.prototype);
        this.retryAfterSeconds = opts.retryAfterSeconds;
        this.Type = opts.Type;
        this.Reason = opts.Reason;
      }
    };
    exports2.TooManyRequestsException = TooManyRequestsException11;
    var CapacityProviderLimitExceededException = class _CapacityProviderLimitExceededException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "CapacityProviderLimitExceededException");
      }
      name = "CapacityProviderLimitExceededException";
      $fault = "client";
      Type;
      constructor(opts) {
        super({
          name: "CapacityProviderLimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CapacityProviderLimitExceededException.prototype);
        this.Type = opts.Type;
      }
    };
    exports2.CapacityProviderLimitExceededException = CapacityProviderLimitExceededException;
    var ResourceInUseException = class _ResourceInUseException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "ResourceInUseException");
      }
      name = "ResourceInUseException";
      $fault = "client";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "ResourceInUseException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceInUseException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.ResourceInUseException = ResourceInUseException;
    var CodeSigningConfigNotFoundException = class _CodeSigningConfigNotFoundException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "CodeSigningConfigNotFoundException");
      }
      name = "CodeSigningConfigNotFoundException";
      $fault = "client";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "CodeSigningConfigNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CodeSigningConfigNotFoundException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.CodeSigningConfigNotFoundException = CodeSigningConfigNotFoundException;
    var CodeStorageExceededException = class _CodeStorageExceededException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "CodeStorageExceededException");
      }
      name = "CodeStorageExceededException";
      $fault = "client";
      Type;
      constructor(opts) {
        super({
          name: "CodeStorageExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CodeStorageExceededException.prototype);
        this.Type = opts.Type;
      }
    };
    exports2.CodeStorageExceededException = CodeStorageExceededException;
    var CodeVerificationFailedException = class _CodeVerificationFailedException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "CodeVerificationFailedException");
      }
      name = "CodeVerificationFailedException";
      $fault = "client";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "CodeVerificationFailedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CodeVerificationFailedException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.CodeVerificationFailedException = CodeVerificationFailedException;
    var FunctionVersionsPerCapacityProviderLimitExceededException = class _FunctionVersionsPerCapacityProviderLimitExceededException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "FunctionVersionsPerCapacityProviderLimitExceededException");
      }
      name = "FunctionVersionsPerCapacityProviderLimitExceededException";
      $fault = "client";
      Type;
      constructor(opts) {
        super({
          name: "FunctionVersionsPerCapacityProviderLimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _FunctionVersionsPerCapacityProviderLimitExceededException.prototype);
        this.Type = opts.Type;
      }
    };
    exports2.FunctionVersionsPerCapacityProviderLimitExceededException = FunctionVersionsPerCapacityProviderLimitExceededException;
    var InvalidCodeSignatureException = class _InvalidCodeSignatureException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "InvalidCodeSignatureException");
      }
      name = "InvalidCodeSignatureException";
      $fault = "client";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "InvalidCodeSignatureException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidCodeSignatureException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.InvalidCodeSignatureException = InvalidCodeSignatureException;
    var DurableExecutionAlreadyStartedException = class _DurableExecutionAlreadyStartedException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "DurableExecutionAlreadyStartedException");
      }
      name = "DurableExecutionAlreadyStartedException";
      $fault = "client";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "DurableExecutionAlreadyStartedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DurableExecutionAlreadyStartedException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.DurableExecutionAlreadyStartedException = DurableExecutionAlreadyStartedException;
    var EC2AccessDeniedException = class _EC2AccessDeniedException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "EC2AccessDeniedException");
      }
      name = "EC2AccessDeniedException";
      $fault = "server";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "EC2AccessDeniedException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _EC2AccessDeniedException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.EC2AccessDeniedException = EC2AccessDeniedException;
    var EC2ThrottledException = class _EC2ThrottledException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "EC2ThrottledException");
      }
      name = "EC2ThrottledException";
      $fault = "server";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "EC2ThrottledException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _EC2ThrottledException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.EC2ThrottledException = EC2ThrottledException;
    var EC2UnexpectedException = class _EC2UnexpectedException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "EC2UnexpectedException");
      }
      name = "EC2UnexpectedException";
      $fault = "server";
      Type;
      Message;
      EC2ErrorCode;
      constructor(opts) {
        super({
          name: "EC2UnexpectedException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _EC2UnexpectedException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
        this.EC2ErrorCode = opts.EC2ErrorCode;
      }
    };
    exports2.EC2UnexpectedException = EC2UnexpectedException;
    var EFSIOException = class _EFSIOException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "EFSIOException");
      }
      name = "EFSIOException";
      $fault = "client";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "EFSIOException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _EFSIOException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.EFSIOException = EFSIOException;
    var EFSMountConnectivityException = class _EFSMountConnectivityException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "EFSMountConnectivityException");
      }
      name = "EFSMountConnectivityException";
      $fault = "client";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "EFSMountConnectivityException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _EFSMountConnectivityException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.EFSMountConnectivityException = EFSMountConnectivityException;
    var EFSMountFailureException = class _EFSMountFailureException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "EFSMountFailureException");
      }
      name = "EFSMountFailureException";
      $fault = "client";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "EFSMountFailureException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _EFSMountFailureException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.EFSMountFailureException = EFSMountFailureException;
    var EFSMountTimeoutException = class _EFSMountTimeoutException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "EFSMountTimeoutException");
      }
      name = "EFSMountTimeoutException";
      $fault = "client";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "EFSMountTimeoutException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _EFSMountTimeoutException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.EFSMountTimeoutException = EFSMountTimeoutException;
    var ENILimitReachedException = class _ENILimitReachedException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "ENILimitReachedException");
      }
      name = "ENILimitReachedException";
      $fault = "server";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "ENILimitReachedException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _ENILimitReachedException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.ENILimitReachedException = ENILimitReachedException;
    var InvalidRequestContentException = class _InvalidRequestContentException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "InvalidRequestContentException");
      }
      name = "InvalidRequestContentException";
      $fault = "client";
      Type;
      constructor(opts) {
        super({
          name: "InvalidRequestContentException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidRequestContentException.prototype);
        this.Type = opts.Type;
      }
    };
    exports2.InvalidRequestContentException = InvalidRequestContentException;
    var InvalidRuntimeException = class _InvalidRuntimeException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "InvalidRuntimeException");
      }
      name = "InvalidRuntimeException";
      $fault = "server";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "InvalidRuntimeException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidRuntimeException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.InvalidRuntimeException = InvalidRuntimeException;
    var InvalidSecurityGroupIDException = class _InvalidSecurityGroupIDException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "InvalidSecurityGroupIDException");
      }
      name = "InvalidSecurityGroupIDException";
      $fault = "server";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "InvalidSecurityGroupIDException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidSecurityGroupIDException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.InvalidSecurityGroupIDException = InvalidSecurityGroupIDException;
    var InvalidSubnetIDException = class _InvalidSubnetIDException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "InvalidSubnetIDException");
      }
      name = "InvalidSubnetIDException";
      $fault = "server";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "InvalidSubnetIDException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidSubnetIDException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.InvalidSubnetIDException = InvalidSubnetIDException;
    var InvalidZipFileException = class _InvalidZipFileException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "InvalidZipFileException");
      }
      name = "InvalidZipFileException";
      $fault = "server";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "InvalidZipFileException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidZipFileException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.InvalidZipFileException = InvalidZipFileException;
    var KMSAccessDeniedException = class _KMSAccessDeniedException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "KMSAccessDeniedException");
      }
      name = "KMSAccessDeniedException";
      $fault = "server";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "KMSAccessDeniedException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _KMSAccessDeniedException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.KMSAccessDeniedException = KMSAccessDeniedException;
    var KMSDisabledException = class _KMSDisabledException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "KMSDisabledException");
      }
      name = "KMSDisabledException";
      $fault = "server";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "KMSDisabledException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _KMSDisabledException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.KMSDisabledException = KMSDisabledException;
    var KMSInvalidStateException = class _KMSInvalidStateException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "KMSInvalidStateException");
      }
      name = "KMSInvalidStateException";
      $fault = "server";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "KMSInvalidStateException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _KMSInvalidStateException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.KMSInvalidStateException = KMSInvalidStateException;
    var KMSNotFoundException = class _KMSNotFoundException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "KMSNotFoundException");
      }
      name = "KMSNotFoundException";
      $fault = "server";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "KMSNotFoundException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _KMSNotFoundException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.KMSNotFoundException = KMSNotFoundException;
    var NoPublishedVersionException = class _NoPublishedVersionException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "NoPublishedVersionException");
      }
      name = "NoPublishedVersionException";
      $fault = "client";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "NoPublishedVersionException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _NoPublishedVersionException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.NoPublishedVersionException = NoPublishedVersionException;
    var RecursiveInvocationException = class _RecursiveInvocationException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "RecursiveInvocationException");
      }
      name = "RecursiveInvocationException";
      $fault = "client";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "RecursiveInvocationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _RecursiveInvocationException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.RecursiveInvocationException = RecursiveInvocationException;
    var RequestTooLargeException = class _RequestTooLargeException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "RequestTooLargeException");
      }
      name = "RequestTooLargeException";
      $fault = "client";
      Type;
      constructor(opts) {
        super({
          name: "RequestTooLargeException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _RequestTooLargeException.prototype);
        this.Type = opts.Type;
      }
    };
    exports2.RequestTooLargeException = RequestTooLargeException;
    var ResourceNotReadyException = class _ResourceNotReadyException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "ResourceNotReadyException");
      }
      name = "ResourceNotReadyException";
      $fault = "server";
      Type;
      constructor(opts) {
        super({
          name: "ResourceNotReadyException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceNotReadyException.prototype);
        this.Type = opts.Type;
      }
    };
    exports2.ResourceNotReadyException = ResourceNotReadyException;
    var S3FilesMountConnectivityException = class _S3FilesMountConnectivityException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "S3FilesMountConnectivityException");
      }
      name = "S3FilesMountConnectivityException";
      $fault = "client";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "S3FilesMountConnectivityException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _S3FilesMountConnectivityException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.S3FilesMountConnectivityException = S3FilesMountConnectivityException;
    var S3FilesMountFailureException = class _S3FilesMountFailureException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "S3FilesMountFailureException");
      }
      name = "S3FilesMountFailureException";
      $fault = "client";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "S3FilesMountFailureException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _S3FilesMountFailureException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.S3FilesMountFailureException = S3FilesMountFailureException;
    var S3FilesMountTimeoutException = class _S3FilesMountTimeoutException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "S3FilesMountTimeoutException");
      }
      name = "S3FilesMountTimeoutException";
      $fault = "client";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "S3FilesMountTimeoutException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _S3FilesMountTimeoutException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.S3FilesMountTimeoutException = S3FilesMountTimeoutException;
    var SerializedRequestEntityTooLargeException = class _SerializedRequestEntityTooLargeException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "SerializedRequestEntityTooLargeException");
      }
      name = "SerializedRequestEntityTooLargeException";
      $fault = "client";
      Type;
      constructor(opts) {
        super({
          name: "SerializedRequestEntityTooLargeException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _SerializedRequestEntityTooLargeException.prototype);
        this.Type = opts.Type;
      }
    };
    exports2.SerializedRequestEntityTooLargeException = SerializedRequestEntityTooLargeException;
    var SnapStartException = class _SnapStartException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "SnapStartException");
      }
      name = "SnapStartException";
      $fault = "client";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "SnapStartException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _SnapStartException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.SnapStartException = SnapStartException;
    var SnapStartNotReadyException = class _SnapStartNotReadyException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "SnapStartNotReadyException");
      }
      name = "SnapStartNotReadyException";
      $fault = "client";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "SnapStartNotReadyException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _SnapStartNotReadyException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.SnapStartNotReadyException = SnapStartNotReadyException;
    var SnapStartTimeoutException = class _SnapStartTimeoutException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "SnapStartTimeoutException");
      }
      name = "SnapStartTimeoutException";
      $fault = "client";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "SnapStartTimeoutException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _SnapStartTimeoutException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.SnapStartTimeoutException = SnapStartTimeoutException;
    var SubnetIPAddressLimitReachedException = class _SubnetIPAddressLimitReachedException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "SubnetIPAddressLimitReachedException");
      }
      name = "SubnetIPAddressLimitReachedException";
      $fault = "server";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "SubnetIPAddressLimitReachedException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _SubnetIPAddressLimitReachedException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.SubnetIPAddressLimitReachedException = SubnetIPAddressLimitReachedException;
    var UnsupportedMediaTypeException = class _UnsupportedMediaTypeException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "UnsupportedMediaTypeException");
      }
      name = "UnsupportedMediaTypeException";
      $fault = "client";
      Type;
      constructor(opts) {
        super({
          name: "UnsupportedMediaTypeException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnsupportedMediaTypeException.prototype);
        this.Type = opts.Type;
      }
    };
    exports2.UnsupportedMediaTypeException = UnsupportedMediaTypeException;
    var ProvisionedConcurrencyConfigNotFoundException = class _ProvisionedConcurrencyConfigNotFoundException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "ProvisionedConcurrencyConfigNotFoundException");
      }
      name = "ProvisionedConcurrencyConfigNotFoundException";
      $fault = "client";
      Type;
      constructor(opts) {
        super({
          name: "ProvisionedConcurrencyConfigNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ProvisionedConcurrencyConfigNotFoundException.prototype);
        this.Type = opts.Type;
      }
    };
    exports2.ProvisionedConcurrencyConfigNotFoundException = ProvisionedConcurrencyConfigNotFoundException;
    var CallbackTimeoutException = class _CallbackTimeoutException extends LambdaServiceException_1.LambdaServiceException {
      static {
        __name(this, "CallbackTimeoutException");
      }
      name = "CallbackTimeoutException";
      $fault = "client";
      Type;
      Message;
      constructor(opts) {
        super({
          name: "CallbackTimeoutException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CallbackTimeoutException.prototype);
        this.Type = opts.Type;
        this.Message = opts.Message;
      }
    };
    exports2.CallbackTimeoutException = CallbackTimeoutException;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/dist-cjs/schemas/schemas_0.js
var require_schemas_016 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/dist-cjs/schemas/schemas_0.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.AccountLimit$ = exports2.errorTypeRegistries = exports2.UnsupportedMediaTypeException$ = exports2.TooManyRequestsException$ = exports2.SubnetIPAddressLimitReachedException$ = exports2.SnapStartTimeoutException$ = exports2.SnapStartNotReadyException$ = exports2.SnapStartException$ = exports2.ServiceException$ = exports2.SerializedRequestEntityTooLargeException$ = exports2.S3FilesMountTimeoutException$ = exports2.S3FilesMountFailureException$ = exports2.S3FilesMountConnectivityException$ = exports2.ResourceNotReadyException$ = exports2.ResourceNotFoundException$ = exports2.ResourceInUseException$ = exports2.ResourceConflictException$ = exports2.RequestTooLargeException$ = exports2.RecursiveInvocationException$ = exports2.ProvisionedConcurrencyConfigNotFoundException$ = exports2.PreconditionFailedException$ = exports2.PolicyLengthExceededException$ = exports2.NoPublishedVersionException$ = exports2.KMSNotFoundException$ = exports2.KMSInvalidStateException$ = exports2.KMSDisabledException$ = exports2.KMSAccessDeniedException$ = exports2.InvalidZipFileException$ = exports2.InvalidSubnetIDException$ = exports2.InvalidSecurityGroupIDException$ = exports2.InvalidRuntimeException$ = exports2.InvalidRequestContentException$ = exports2.InvalidParameterValueException$ = exports2.InvalidCodeSignatureException$ = exports2.FunctionVersionsPerCapacityProviderLimitExceededException$ = exports2.ENILimitReachedException$ = exports2.EFSMountTimeoutException$ = exports2.EFSMountFailureException$ = exports2.EFSMountConnectivityException$ = exports2.EFSIOException$ = exports2.EC2UnexpectedException$ = exports2.EC2ThrottledException$ = exports2.EC2AccessDeniedException$ = exports2.DurableExecutionAlreadyStartedException$ = exports2.CodeVerificationFailedException$ = exports2.CodeStorageExceededException$ = exports2.CodeSigningConfigNotFoundException$ = exports2.CapacityProviderLimitExceededException$ = exports2.CallbackTimeoutException$ = exports2.LambdaServiceException$ = void 0;
    exports2.DeleteAliasRequest$ = exports2.DeadLetterConfig$ = exports2.CreateFunctionUrlConfigResponse$ = exports2.CreateFunctionUrlConfigRequest$ = exports2.CreateFunctionRequest$ = exports2.CreateEventSourceMappingRequest$ = exports2.CreateCodeSigningConfigResponse$ = exports2.CreateCodeSigningConfigRequest$ = exports2.CreateCapacityProviderResponse$ = exports2.CreateCapacityProviderRequest$ = exports2.CreateAliasRequest$ = exports2.Cors$ = exports2.ContextSucceededDetails$ = exports2.ContextStartedDetails$ = exports2.ContextOptions$ = exports2.ContextFailedDetails$ = exports2.ContextDetails$ = exports2.Concurrency$ = exports2.CodeSigningPolicies$ = exports2.CodeSigningConfig$ = exports2.CheckpointUpdatedExecutionState$ = exports2.CheckpointDurableExecutionResponse$ = exports2.CheckpointDurableExecutionRequest$ = exports2.ChainedInvokeTimedOutDetails$ = exports2.ChainedInvokeSucceededDetails$ = exports2.ChainedInvokeStoppedDetails$ = exports2.ChainedInvokeStartedDetails$ = exports2.ChainedInvokeOptions$ = exports2.ChainedInvokeFailedDetails$ = exports2.ChainedInvokeDetails$ = exports2.CapacityProviderVpcConfig$ = exports2.CapacityProviderScalingConfig$ = exports2.CapacityProviderPermissionsConfig$ = exports2.CapacityProviderConfig$ = exports2.CapacityProvider$ = exports2.CallbackTimedOutDetails$ = exports2.CallbackSucceededDetails$ = exports2.CallbackStartedDetails$ = exports2.CallbackOptions$ = exports2.CallbackFailedDetails$ = exports2.CallbackDetails$ = exports2.AmazonManagedKafkaEventSourceConfig$ = exports2.AllowedPublishers$ = exports2.AliasRoutingConfiguration$ = exports2.AliasConfiguration$ = exports2.AddPermissionResponse$ = exports2.AddPermissionRequest$ = exports2.AddLayerVersionPermissionResponse$ = exports2.AddLayerVersionPermissionRequest$ = exports2.AccountUsage$ = void 0;
    exports2.GetCapacityProviderRequest$ = exports2.GetAliasRequest$ = exports2.GetAccountSettingsResponse$ = exports2.GetAccountSettingsRequest$ = exports2.FunctionVersionsByCapacityProviderListItem$ = exports2.FunctionUrlConfig$ = exports2.FunctionScalingConfig$ = exports2.FunctionEventInvokeConfig$ = exports2.FunctionConfiguration$ = exports2.FunctionCodeLocation$ = exports2.FunctionCode$ = exports2.FilterCriteriaError$ = exports2.FilterCriteria$ = exports2.Filter$ = exports2.FileSystemConfig$ = exports2.ExecutionTimedOutDetails$ = exports2.ExecutionSucceededDetails$ = exports2.ExecutionStoppedDetails$ = exports2.ExecutionStartedDetails$ = exports2.ExecutionFailedDetails$ = exports2.ExecutionDetails$ = exports2.Execution$ = exports2.EventSourceMappingMetricsConfig$ = exports2.EventSourceMappingLoggingConfig$ = exports2.EventSourceMappingConfiguration$ = exports2.EventResult$ = exports2.EventInput$ = exports2.EventError$ = exports2.Event$ = exports2.ErrorObject$ = exports2.EphemeralStorage$ = exports2.EnvironmentResponse$ = exports2.EnvironmentError$ = exports2.Environment$ = exports2.DurableConfig$ = exports2.DocumentDBEventSourceConfig$ = exports2.DestinationConfig$ = exports2.DeleteProvisionedConcurrencyConfigRequest$ = exports2.DeleteLayerVersionRequest$ = exports2.DeleteFunctionUrlConfigRequest$ = exports2.DeleteFunctionResponse$ = exports2.DeleteFunctionRequest$ = exports2.DeleteFunctionEventInvokeConfigRequest$ = exports2.DeleteFunctionConcurrencyRequest$ = exports2.DeleteFunctionCodeSigningConfigRequest$ = exports2.DeleteEventSourceMappingRequest$ = exports2.DeleteCodeSigningConfigResponse$ = exports2.DeleteCodeSigningConfigRequest$ = exports2.DeleteCapacityProviderResponse$ = exports2.DeleteCapacityProviderRequest$ = void 0;
    exports2.KafkaSchemaRegistryConfig$ = exports2.KafkaSchemaRegistryAccessConfig$ = exports2.InvokeWithResponseStreamResponse$ = exports2.InvokeWithResponseStreamRequest$ = exports2.InvokeWithResponseStreamCompleteEvent$ = exports2.InvokeResponseStreamUpdate$ = exports2.InvokeAsyncResponse$ = exports2.InvokeAsyncRequest$ = exports2.InvocationResponse$ = exports2.InvocationRequest$ = exports2.InvocationCompletedDetails$ = exports2.InstanceRequirements$ = exports2.ImageConfigResponse$ = exports2.ImageConfigError$ = exports2.ImageConfig$ = exports2.GetRuntimeManagementConfigResponse$ = exports2.GetRuntimeManagementConfigRequest$ = exports2.GetProvisionedConcurrencyConfigResponse$ = exports2.GetProvisionedConcurrencyConfigRequest$ = exports2.GetPolicyResponse$ = exports2.GetPolicyRequest$ = exports2.GetLayerVersionResponse$ = exports2.GetLayerVersionRequest$ = exports2.GetLayerVersionPolicyResponse$ = exports2.GetLayerVersionPolicyRequest$ = exports2.GetLayerVersionByArnRequest$ = exports2.GetFunctionUrlConfigResponse$ = exports2.GetFunctionUrlConfigRequest$ = exports2.GetFunctionScalingConfigResponse$ = exports2.GetFunctionScalingConfigRequest$ = exports2.GetFunctionResponse$ = exports2.GetFunctionRequest$ = exports2.GetFunctionRecursionConfigResponse$ = exports2.GetFunctionRecursionConfigRequest$ = exports2.GetFunctionEventInvokeConfigRequest$ = exports2.GetFunctionConfigurationRequest$ = exports2.GetFunctionConcurrencyResponse$ = exports2.GetFunctionConcurrencyRequest$ = exports2.GetFunctionCodeSigningConfigResponse$ = exports2.GetFunctionCodeSigningConfigRequest$ = exports2.GetEventSourceMappingRequest$ = exports2.GetDurableExecutionStateResponse$ = exports2.GetDurableExecutionStateRequest$ = exports2.GetDurableExecutionResponse$ = exports2.GetDurableExecutionRequest$ = exports2.GetDurableExecutionHistoryResponse$ = exports2.GetDurableExecutionHistoryRequest$ = exports2.GetCodeSigningConfigResponse$ = exports2.GetCodeSigningConfigRequest$ = exports2.GetCapacityProviderResponse$ = void 0;
    exports2.PutFunctionConcurrencyRequest$ = exports2.PutFunctionCodeSigningConfigResponse$ = exports2.PutFunctionCodeSigningConfigRequest$ = exports2.PublishVersionRequest$ = exports2.PublishLayerVersionResponse$ = exports2.PublishLayerVersionRequest$ = exports2.ProvisionedPollerConfig$ = exports2.ProvisionedConcurrencyConfigListItem$ = exports2.OperationUpdate$ = exports2.Operation$ = exports2.OnSuccess$ = exports2.OnFailure$ = exports2.LoggingConfig$ = exports2.ListVersionsByFunctionResponse$ = exports2.ListVersionsByFunctionRequest$ = exports2.ListTagsResponse$ = exports2.ListTagsRequest$ = exports2.ListProvisionedConcurrencyConfigsResponse$ = exports2.ListProvisionedConcurrencyConfigsRequest$ = exports2.ListLayerVersionsResponse$ = exports2.ListLayerVersionsRequest$ = exports2.ListLayersResponse$ = exports2.ListLayersRequest$ = exports2.ListFunctionVersionsByCapacityProviderResponse$ = exports2.ListFunctionVersionsByCapacityProviderRequest$ = exports2.ListFunctionUrlConfigsResponse$ = exports2.ListFunctionUrlConfigsRequest$ = exports2.ListFunctionsResponse$ = exports2.ListFunctionsRequest$ = exports2.ListFunctionsByCodeSigningConfigResponse$ = exports2.ListFunctionsByCodeSigningConfigRequest$ = exports2.ListFunctionEventInvokeConfigsResponse$ = exports2.ListFunctionEventInvokeConfigsRequest$ = exports2.ListEventSourceMappingsResponse$ = exports2.ListEventSourceMappingsRequest$ = exports2.ListDurableExecutionsByFunctionResponse$ = exports2.ListDurableExecutionsByFunctionRequest$ = exports2.ListCodeSigningConfigsResponse$ = exports2.ListCodeSigningConfigsRequest$ = exports2.ListCapacityProvidersResponse$ = exports2.ListCapacityProvidersRequest$ = exports2.ListAliasesResponse$ = exports2.ListAliasesRequest$ = exports2.LayerVersionsListItem$ = exports2.LayerVersionContentOutput$ = exports2.LayerVersionContentInput$ = exports2.LayersListItem$ = exports2.Layer$ = exports2.LambdaManagedInstancesCapacityProviderConfig$ = exports2.KafkaSchemaValidationConfig$ = void 0;
    exports2.UpdateFunctionEventInvokeConfigRequest$ = exports2.UpdateFunctionConfigurationRequest$ = exports2.UpdateFunctionCodeRequest$ = exports2.UpdateEventSourceMappingRequest$ = exports2.UpdateCodeSigningConfigResponse$ = exports2.UpdateCodeSigningConfigRequest$ = exports2.UpdateCapacityProviderResponse$ = exports2.UpdateCapacityProviderRequest$ = exports2.UpdateAliasRequest$ = exports2.UntagResourceRequest$ = exports2.TracingConfigResponse$ = exports2.TracingConfig$ = exports2.TraceHeader$ = exports2.TenancyConfig$ = exports2.TargetTrackingScalingPolicy$ = exports2.TagsError$ = exports2.TagResourceRequest$ = exports2.StopDurableExecutionResponse$ = exports2.StopDurableExecutionRequest$ = exports2.StepSucceededDetails$ = exports2.StepStartedDetails$ = exports2.StepOptions$ = exports2.StepFailedDetails$ = exports2.StepDetails$ = exports2.SourceAccessConfiguration$ = exports2.SnapStartResponse$ = exports2.SnapStart$ = exports2.SendDurableExecutionCallbackSuccessResponse$ = exports2.SendDurableExecutionCallbackSuccessRequest$ = exports2.SendDurableExecutionCallbackHeartbeatResponse$ = exports2.SendDurableExecutionCallbackHeartbeatRequest$ = exports2.SendDurableExecutionCallbackFailureResponse$ = exports2.SendDurableExecutionCallbackFailureRequest$ = exports2.SelfManagedKafkaEventSourceConfig$ = exports2.SelfManagedEventSource$ = exports2.ScalingConfig$ = exports2.RuntimeVersionError$ = exports2.RuntimeVersionConfig$ = exports2.RetryDetails$ = exports2.RemovePermissionRequest$ = exports2.RemoveLayerVersionPermissionRequest$ = exports2.PutRuntimeManagementConfigResponse$ = exports2.PutRuntimeManagementConfigRequest$ = exports2.PutProvisionedConcurrencyConfigResponse$ = exports2.PutProvisionedConcurrencyConfigRequest$ = exports2.PutFunctionScalingConfigResponse$ = exports2.PutFunctionScalingConfigRequest$ = exports2.PutFunctionRecursionConfigResponse$ = exports2.PutFunctionRecursionConfigRequest$ = exports2.PutFunctionEventInvokeConfigRequest$ = void 0;
    exports2.GetPolicy$ = exports2.GetLayerVersionPolicy$ = exports2.GetLayerVersionByArn$ = exports2.GetLayerVersion$ = exports2.GetFunctionUrlConfig$ = exports2.GetFunctionScalingConfig$ = exports2.GetFunctionRecursionConfig$ = exports2.GetFunctionEventInvokeConfig$ = exports2.GetFunctionConfiguration$ = exports2.GetFunctionConcurrency$ = exports2.GetFunctionCodeSigningConfig$ = exports2.GetFunction$ = exports2.GetEventSourceMapping$ = exports2.GetDurableExecutionState$ = exports2.GetDurableExecutionHistory$ = exports2.GetDurableExecution$ = exports2.GetCodeSigningConfig$ = exports2.GetCapacityProvider$ = exports2.GetAlias$ = exports2.GetAccountSettings$ = exports2.DeleteProvisionedConcurrencyConfig$ = exports2.DeleteLayerVersion$ = exports2.DeleteFunctionUrlConfig$ = exports2.DeleteFunctionEventInvokeConfig$ = exports2.DeleteFunctionConcurrency$ = exports2.DeleteFunctionCodeSigningConfig$ = exports2.DeleteFunction$ = exports2.DeleteEventSourceMapping$ = exports2.DeleteCodeSigningConfig$ = exports2.DeleteCapacityProvider$ = exports2.DeleteAlias$ = exports2.CreateFunctionUrlConfig$ = exports2.CreateFunction$ = exports2.CreateEventSourceMapping$ = exports2.CreateCodeSigningConfig$ = exports2.CreateCapacityProvider$ = exports2.CreateAlias$ = exports2.CheckpointDurableExecution$ = exports2.AddPermission$ = exports2.AddLayerVersionPermission$ = exports2.InvokeWithResponseStreamResponseEvent$ = exports2.WaitSucceededDetails$ = exports2.WaitStartedDetails$ = exports2.WaitOptions$ = exports2.WaitDetails$ = exports2.WaitCancelledDetails$ = exports2.VpcConfigResponse$ = exports2.VpcConfig$ = exports2.UpdateFunctionUrlConfigResponse$ = exports2.UpdateFunctionUrlConfigRequest$ = void 0;
    exports2.UpdateFunctionUrlConfig$ = exports2.UpdateFunctionEventInvokeConfig$ = exports2.UpdateFunctionConfiguration$ = exports2.UpdateFunctionCode$ = exports2.UpdateEventSourceMapping$ = exports2.UpdateCodeSigningConfig$ = exports2.UpdateCapacityProvider$ = exports2.UpdateAlias$ = exports2.UntagResource$ = exports2.TagResource$ = exports2.StopDurableExecution$ = exports2.SendDurableExecutionCallbackSuccess$ = exports2.SendDurableExecutionCallbackHeartbeat$ = exports2.SendDurableExecutionCallbackFailure$ = exports2.RemovePermission$ = exports2.RemoveLayerVersionPermission$ = exports2.PutRuntimeManagementConfig$ = exports2.PutProvisionedConcurrencyConfig$ = exports2.PutFunctionScalingConfig$ = exports2.PutFunctionRecursionConfig$ = exports2.PutFunctionEventInvokeConfig$ = exports2.PutFunctionConcurrency$ = exports2.PutFunctionCodeSigningConfig$ = exports2.PublishVersion$ = exports2.PublishLayerVersion$ = exports2.ListVersionsByFunction$ = exports2.ListTags$ = exports2.ListProvisionedConcurrencyConfigs$ = exports2.ListLayerVersions$ = exports2.ListLayers$ = exports2.ListFunctionVersionsByCapacityProvider$ = exports2.ListFunctionUrlConfigs$ = exports2.ListFunctionsByCodeSigningConfig$ = exports2.ListFunctions$ = exports2.ListFunctionEventInvokeConfigs$ = exports2.ListEventSourceMappings$ = exports2.ListDurableExecutionsByFunction$ = exports2.ListCodeSigningConfigs$ = exports2.ListCapacityProviders$ = exports2.ListAliases$ = exports2.InvokeWithResponseStream$ = exports2.InvokeAsync$ = exports2.Invoke$ = exports2.GetRuntimeManagementConfig$ = exports2.GetProvisionedConcurrencyConfig$ = void 0;
    var _A10 = "Action";
    var _AA = "AliasArn";
    var _AC = "AliasConfiguration";
    var _ACc = "AccessConfigs";
    var _ACl = "AllowCredentials";
    var _AFSC = "AppliedFunctionScalingConfig";
    var _AH = "AllowHeaders";
    var _AIT = "AllowedInstanceTypes";
    var _AL = "AccountLimit";
    var _ALL = "ApplicationLogLevel";
    var _ALVP = "AddLayerVersionPermission";
    var _ALVPR = "AddLayerVersionPermissionRequest";
    var _ALVPRd = "AddLayerVersionPermissionResponse";
    var _ALl = "AliasList";
    var _AM = "AllowMethods";
    var _AMKESC = "AmazonManagedKafkaEventSourceConfig";
    var _AO = "AllowOrigins";
    var _AOp = "ApplyOn";
    var _AP = "AllowedPublishers";
    var _APCE = "AvailableProvisionedConcurrentExecutions";
    var _APCEl = "AllocatedProvisionedConcurrentExecutions";
    var _APR = "AddPermissionRequest";
    var _APRd = "AddPermissionResponse";
    var _APd = "AddPermission";
    var _ARC = "AliasRoutingConfiguration";
    var _AT13 = "AuthType";
    var _AU = "AccountUsage";
    var _AVW = "AdditionalVersionWeights";
    var _Al = "Aliases";
    var _Ar = "Architectures";
    var _Arn = "Arn";
    var _At = "Attribute";
    var _Att = "Attempt";
    var _B = "Blob";
    var _BBOFE = "BisectBatchOnFunctionError";
    var _BOP = "BinaryOperationPayload";
    var _BS = "BlobStream";
    var _BSa = "BatchSize";
    var _C11 = "Concurrency";
    var _CA10 = "CompatibleArchitectures";
    var _CAR = "CreateAliasRequest";
    var _CAo = "CompatibleArchitecture";
    var _CAr = "CreateAlias";
    var _CAu = "CurrentAttempt";
    var _CC = "ClientContext";
    var _CCP = "CreateCapacityProvider";
    var _CCPR = "CreateCapacityProviderRequest";
    var _CCPRr = "CreateCapacityProviderResponse";
    var _CCSC = "CreateCodeSigningConfig";
    var _CCSCR = "CreateCodeSigningConfigRequest";
    var _CCSCRr = "CreateCodeSigningConfigResponse";
    var _CD = "CallbackDetails";
    var _CDE = "CheckpointDurableExecution";
    var _CDER = "CheckpointDurableExecutionRequest";
    var _CDERh = "CheckpointDurableExecutionResponse";
    var _CDo = "ContextDetails";
    var _CDr = "CreatedDate";
    var _CE = "ConcurrentExecutions";
    var _CESM = "CreateEventSourceMapping";
    var _CESMR = "CreateEventSourceMappingRequest";
    var _CF = "CreateFunction";
    var _CFD = "CallbackFailedDetails";
    var _CFDo = "ContextFailedDetails";
    var _CFR = "CreateFunctionRequest";
    var _CFUC = "CreateFunctionUrlConfig";
    var _CFUCR = "CreateFunctionUrlConfigRequest";
    var _CFUCRr = "CreateFunctionUrlConfigResponse";
    var _CGI = "ConsumerGroupId";
    var _CI = "CallbackId";
    var _CID = "ChainedInvokeDetails";
    var _CIFD = "ChainedInvokeFailedDetails";
    var _CIO = "ChainedInvokeOptions";
    var _CISD = "ChainedInvokeStartedDetails";
    var _CISDh = "ChainedInvokeStoppedDetails";
    var _CISDha = "ChainedInvokeSucceededDetails";
    var _CITOD = "ChainedInvokeTimedOutDetails";
    var _CN = "CollectionName";
    var _CO = "CallbackOptions";
    var _COo = "ContextOptions";
    var _CP = "CapacityProvider";
    var _CPA = "CapacityProviderArn";
    var _CPC = "CapacityProviderConfig";
    var _CPL = "CapacityProvidersList";
    var _CPLEE = "CapacityProviderLimitExceededException";
    var _CPN = "CapacityProviderName";
    var _CPORA = "CapacityProviderOperatorRoleArn";
    var _CPPC = "CapacityProviderPermissionsConfig";
    var _CPSC = "CapacityProviderScalingConfig";
    var _CPSPL = "CapacityProviderScalingPoliciesList";
    var _CPVC = "CapacityProviderVpcConfig";
    var _CPa = "CapacityProviders";
    var _CR = "CompatibleRuntimes";
    var _CRo = "CompatibleRuntime";
    var _CS4 = "CodeSize";
    var _CSC = "CodeSigningConfig";
    var _CSCA = "CodeSigningConfigArn";
    var _CSCI = "CodeSigningConfigId";
    var _CSCL = "CodeSigningConfigList";
    var _CSCNFE = "CodeSigningConfigNotFoundException";
    var _CSCo = "CodeSigningConfigs";
    var _CSD = "CallbackStartedDetails";
    var _CSDa = "CallbackSucceededDetails";
    var _CSDo = "ContextStartedDetails";
    var _CSDon = "ContextSucceededDetails";
    var _CSEE = "CodeStorageExceededException";
    var _CSP = "CodeSigningPolicies";
    var _CSU = "CodeSizeUnzipped";
    var _CSZ = "CodeSizeZipped";
    var _CSo = "CodeSha256";
    var _CSon = "ConfigSha256";
    var _CT4 = "CheckpointToken";
    var _CTE = "CallbackTimeoutException";
    var _CTOD = "CallbackTimedOutDetails";
    var _CT_ = "Content-Type";
    var _CTl = "ClientToken";
    var _CTr = "CreationTime";
    var _CUES = "CheckpointUpdatedExecutionState";
    var _CVFE = "CodeVerificationFailedException";
    var _Co = "Cors";
    var _Cod = "Code";
    var _Com = "Command";
    var _Con = "Configuration";
    var _Cont = "Content";
    var _D = "Description";
    var _DA = "DeleteAlias";
    var _DAR = "DeleteAliasRequest";
    var _DC = "DestinationConfig";
    var _DCP = "DeleteCapacityProvider";
    var _DCPR = "DeleteCapacityProviderRequest";
    var _DCPRe = "DeleteCapacityProviderResponse";
    var _DCSC = "DeleteCodeSigningConfig";
    var _DCSCR = "DeleteCodeSigningConfigRequest";
    var _DCSCRe = "DeleteCodeSigningConfigResponse";
    var _DCu = "DurableConfig";
    var _DDBESC = "DocumentDBEventSourceConfig";
    var _DE = "DurableExecutions";
    var _DEA = "DurableExecutionArn";
    var _DEASE = "DurableExecutionAlreadyStartedException";
    var _DEN = "DurableExecutionName";
    var _DESM = "DeleteEventSourceMapping";
    var _DESMR = "DeleteEventSourceMappingRequest";
    var _DF = "DeleteFunction";
    var _DFC = "DeleteFunctionConcurrency";
    var _DFCR = "DeleteFunctionConcurrencyRequest";
    var _DFCSC = "DeleteFunctionCodeSigningConfig";
    var _DFCSCR = "DeleteFunctionCodeSigningConfigRequest";
    var _DFEIC = "DeleteFunctionEventInvokeConfig";
    var _DFEICR = "DeleteFunctionEventInvokeConfigRequest";
    var _DFR = "DeleteFunctionRequest";
    var _DFRe = "DeleteFunctionResponse";
    var _DFUC = "DeleteFunctionUrlConfig";
    var _DFUCR = "DeleteFunctionUrlConfigRequest";
    var _DLC = "DeadLetterConfig";
    var _DLV = "DeleteLayerVersion";
    var _DLVR = "DeleteLayerVersionRequest";
    var _DN = "DatabaseName";
    var _DPCC = "DeleteProvisionedConcurrencyConfig";
    var _DPCCR = "DeleteProvisionedConcurrencyConfigRequest";
    var _DR = "DryRun";
    var _De = "Destination";
    var _Du = "Duration";
    var _E11 = "Error";
    var _EC = "ErrorCode";
    var _ECADE = "EC2AccessDeniedException";
    var _ECEC = "EC2ErrorCode";
    var _ECTE = "EC2ThrottledException";
    var _ECUE = "EC2UnexpectedException";
    var _ED = "ErrorData";
    var _EDr = "ErrorDetails";
    var _EDx = "ExecutionDetails";
    var _EE = "EnvironmentError";
    var _EEMGBPVC = "ExecutionEnvironmentMemoryGiBPerVCpu";
    var _EEv = "EventError";
    var _EFD = "ExecutionFailedDetails";
    var _EFSIOE = "EFSIOException";
    var _EFSMCE = "EFSMountConnectivityException";
    var _EFSMFE = "EFSMountFailureException";
    var _EFSMTE = "EFSMountTimeoutException";
    var _EH = "ExposeHeaders";
    var _EI10 = "EventId";
    var _EIT = "ExcludedInstanceTypes";
    var _EIv = "EventInput";
    var _EM = "ErrorMessage";
    var _ENILRE = "ENILimitReachedException";
    var _EO = "ErrorObject";
    var _EP = "EntryPoint";
    var _ER = "EnvironmentResponse";
    var _ERF = "EventRecordFormat";
    var _ERv = "EventResult";
    var _ES = "EphemeralStorage";
    var _ESA = "EventSourceArn";
    var _ESD = "ExecutionStartedDetails";
    var _ESDx = "ExecutionSucceededDetails";
    var _ESDxe = "ExecutionStoppedDetails";
    var _ESM = "EventSourceMappings";
    var _ESMA = "EventSourceMappingArn";
    var _ESMC = "EventSourceMappingConfiguration";
    var _ESML = "EventSourceMappingsList";
    var _ESMLC = "EventSourceMappingLoggingConfig";
    var _ESMMC = "EventSourceMappingMetricsConfig";
    var _EST = "EventSourceToken";
    var _ESv = "EventStream";
    var _ET = "ErrorType";
    var _ETOD = "ExecutionTimedOutDetails";
    var _ETn = "EndTimestamp";
    var _ETv = "EventType";
    var _ETve = "EventTimestamp";
    var _ETx = "ExecutionTimeout";
    var _EV = "ExecutedVersion";
    var _EVN = "EnvironmentVariableName";
    var _EVV = "EnvironmentVariableValue";
    var _EVn = "EnvironmentVariables";
    var _En = "Enabled";
    var _End = "Endpoints";
    var _Env = "Environment";
    var _Ev = "Event";
    var _Eve = "Events";
    var _Ex = "Execution";
    var _F = "Filter";
    var _FA = "FunctionArn";
    var _FAu = "FunctionArns";
    var _FC = "FunctionCount";
    var _FCE = "FilterCriteriaError";
    var _FCL = "FunctionCodeLocation";
    var _FCi = "FilterCriteria";
    var _FCu = "FunctionCode";
    var _FCun = "FunctionConfiguration";
    var _FD = "FullDocument";
    var _FE = "FunctionError";
    var _FEIC = "FunctionEventInvokeConfig";
    var _FEICL = "FunctionEventInvokeConfigList";
    var _FEICu = "FunctionEventInvokeConfigs";
    var _FL = "FilterList";
    var _FLu = "FunctionList";
    var _FN = "FunctionName";
    var _FRT = "FunctionResponseTypes";
    var _FS = "FunctionState";
    var _FSC = "FileSystemConfigs";
    var _FSCL = "FileSystemConfigList";
    var _FSCi = "FileSystemConfig";
    var _FSCu = "FunctionScalingConfig";
    var _FU = "FunctionUrl";
    var _FUAT = "FunctionUrlAuthType";
    var _FUC = "FunctionUrlConfig";
    var _FUCL = "FunctionUrlConfigList";
    var _FUCu = "FunctionUrlConfigs";
    var _FV = "FunctionVersion";
    var _FVBCPL = "FunctionVersionsByCapacityProviderList";
    var _FVBCPLI = "FunctionVersionsByCapacityProviderListItem";
    var _FVPCPLEE = "FunctionVersionsPerCapacityProviderLimitExceededException";
    var _FVu = "FunctionVersions";
    var _Fi = "Filters";
    var _Fu = "Functions";
    var _GA = "GetAlias";
    var _GAR = "GetAliasRequest";
    var _GAS = "GetAccountSettings";
    var _GASR = "GetAccountSettingsRequest";
    var _GASRe = "GetAccountSettingsResponse";
    var _GCP = "GetCapacityProvider";
    var _GCPR = "GetCapacityProviderRequest";
    var _GCPRe = "GetCapacityProviderResponse";
    var _GCSC = "GetCodeSigningConfig";
    var _GCSCR = "GetCodeSigningConfigRequest";
    var _GCSCRe = "GetCodeSigningConfigResponse";
    var _GDE = "GetDurableExecution";
    var _GDEH = "GetDurableExecutionHistory";
    var _GDEHR = "GetDurableExecutionHistoryRequest";
    var _GDEHRe = "GetDurableExecutionHistoryResponse";
    var _GDER = "GetDurableExecutionRequest";
    var _GDERe = "GetDurableExecutionResponse";
    var _GDES = "GetDurableExecutionState";
    var _GDESR = "GetDurableExecutionStateRequest";
    var _GDESRe = "GetDurableExecutionStateResponse";
    var _GESM = "GetEventSourceMapping";
    var _GESMR = "GetEventSourceMappingRequest";
    var _GF = "GetFunction";
    var _GFC = "GetFunctionConcurrency";
    var _GFCR = "GetFunctionConcurrencyRequest";
    var _GFCRe = "GetFunctionConcurrencyResponse";
    var _GFCRet = "GetFunctionConfigurationRequest";
    var _GFCSC = "GetFunctionCodeSigningConfig";
    var _GFCSCR = "GetFunctionCodeSigningConfigRequest";
    var _GFCSCRe = "GetFunctionCodeSigningConfigResponse";
    var _GFCe = "GetFunctionConfiguration";
    var _GFEIC = "GetFunctionEventInvokeConfig";
    var _GFEICR = "GetFunctionEventInvokeConfigRequest";
    var _GFR = "GetFunctionRequest";
    var _GFRC = "GetFunctionRecursionConfig";
    var _GFRCR = "GetFunctionRecursionConfigRequest";
    var _GFRCRe = "GetFunctionRecursionConfigResponse";
    var _GFRe = "GetFunctionResponse";
    var _GFSC = "GetFunctionScalingConfig";
    var _GFSCR = "GetFunctionScalingConfigRequest";
    var _GFSCRe = "GetFunctionScalingConfigResponse";
    var _GFUC = "GetFunctionUrlConfig";
    var _GFUCR = "GetFunctionUrlConfigRequest";
    var _GFUCRe = "GetFunctionUrlConfigResponse";
    var _GLV = "GetLayerVersion";
    var _GLVBA = "GetLayerVersionByArn";
    var _GLVBAR = "GetLayerVersionByArnRequest";
    var _GLVP = "GetLayerVersionPolicy";
    var _GLVPR = "GetLayerVersionPolicyRequest";
    var _GLVPRe = "GetLayerVersionPolicyResponse";
    var _GLVR = "GetLayerVersionRequest";
    var _GLVRe = "GetLayerVersionResponse";
    var _GP = "GetPolicy";
    var _GPCC = "GetProvisionedConcurrencyConfig";
    var _GPCCR = "GetProvisionedConcurrencyConfigRequest";
    var _GPCCRe = "GetProvisionedConcurrencyConfigResponse";
    var _GPR = "GetPolicyRequest";
    var _GPRe = "GetPolicyResponse";
    var _GRMC = "GetRuntimeManagementConfig";
    var _GRMCR = "GetRuntimeManagementConfigRequest";
    var _GRMCRe = "GetRuntimeManagementConfigResponse";
    var _H = "Handler";
    var _HT = "HeartbeatTimeout";
    var _HTS = "HeartbeatTimeoutSeconds";
    var _I = "Input";
    var _IA = "InvokeArgs";
    var _IAFDS = "Ipv6AllowedForDualStack";
    var _IAR = "InvokeAsyncRequest";
    var _IARn = "InvokeAsyncResponse";
    var _IAn = "InvokeAsync";
    var _IC = "ImageConfig";
    var _ICD = "InvocationCompletedDetails";
    var _ICE4 = "ImageConfigError";
    var _ICR = "ImageConfigResponse";
    var _ICSE = "InvalidCodeSignatureException";
    var _ICn = "InvokeComplete";
    var _IED = "IncludeExecutionData";
    var _IM = "InvokeMode";
    var _IP = "InputPayload";
    var _IPVE = "InvalidParameterValueException";
    var _IR = "InstanceRequirements";
    var _IRCE = "InvalidRequestContentException";
    var _IRE13 = "InvalidRuntimeException";
    var _IRSU = "InvokeResponseStreamUpdate";
    var _IRn = "InvocationRequest";
    var _IRnv = "InvocationResponse";
    var _ISGIDE = "InvalidSecurityGroupIDException";
    var _ISIDE = "InvalidSubnetIDException";
    var _IT4 = "InvocationType";
    var _IU = "ImageUri";
    var _IVFU = "InvokedViaFunctionUrl";
    var _IWRS = "InvokeWithResponseStream";
    var _IWRSCE = "InvokeWithResponseStreamCompleteEvent";
    var _IWRSR = "InvokeWithResponseStreamRequest";
    var _IWRSRE = "InvokeWithResponseStreamResponseEvent";
    var _IWRSRn = "InvokeWithResponseStreamResponse";
    var _IZFE = "InvalidZipFileException";
    var _Id = "Id";
    var _In = "Invoke";
    var _KKA = "KmsKeyArn";
    var _KMSADE = "KMSAccessDeniedException";
    var _KMSDE = "KMSDisabledException";
    var _KMSISE = "KMSInvalidStateException";
    var _KMSKA = "KMSKeyArn";
    var _KMSNFE = "KMSNotFoundException";
    var _KSRAC = "KafkaSchemaRegistryAccessConfig";
    var _KSRACL = "KafkaSchemaRegistryAccessConfigList";
    var _KSRC = "KafkaSchemaRegistryConfig";
    var _KSVC = "KafkaSchemaValidationConfig";
    var _KSVCL = "KafkaSchemaValidationConfigList";
    var _L2 = "Layers";
    var _LA = "LayerArn";
    var _LAR = "ListAliasesRequest";
    var _LARi = "ListAliasesResponse";
    var _LAi = "ListAliases";
    var _LC = "LoggingConfig";
    var _LCP = "ListCapacityProviders";
    var _LCPR = "ListCapacityProvidersRequest";
    var _LCPRi = "ListCapacityProvidersResponse";
    var _LCSC = "ListCodeSigningConfigs";
    var _LCSCR = "ListCodeSigningConfigsRequest";
    var _LCSCRi = "ListCodeSigningConfigsResponse";
    var _LDEBF = "ListDurableExecutionsByFunction";
    var _LDEBFR = "ListDurableExecutionsByFunctionRequest";
    var _LDEBFRi = "ListDurableExecutionsByFunctionResponse";
    var _LESM = "ListEventSourceMappings";
    var _LESMR = "ListEventSourceMappingsRequest";
    var _LESMRi = "ListEventSourceMappingsResponse";
    var _LF = "LogFormat";
    var _LFBCSC = "ListFunctionsByCodeSigningConfig";
    var _LFBCSCR = "ListFunctionsByCodeSigningConfigRequest";
    var _LFBCSCRi = "ListFunctionsByCodeSigningConfigResponse";
    var _LFEIC = "ListFunctionEventInvokeConfigs";
    var _LFEICR = "ListFunctionEventInvokeConfigsRequest";
    var _LFEICRi = "ListFunctionEventInvokeConfigsResponse";
    var _LFR = "ListFunctionsRequest";
    var _LFRi = "ListFunctionsResponse";
    var _LFUC = "ListFunctionUrlConfigs";
    var _LFUCR = "ListFunctionUrlConfigsRequest";
    var _LFUCRi = "ListFunctionUrlConfigsResponse";
    var _LFVBCP = "ListFunctionVersionsByCapacityProvider";
    var _LFVBCPR = "ListFunctionVersionsByCapacityProviderRequest";
    var _LFVBCPRi = "ListFunctionVersionsByCapacityProviderResponse";
    var _LFi = "ListFunctions";
    var _LG = "LogGroup";
    var _LI = "LicenseInfo";
    var _LL = "LayersList";
    var _LLI = "LayersListItem";
    var _LLR = "ListLayersRequest";
    var _LLRi = "ListLayersResponse";
    var _LLV = "ListLayerVersions";
    var _LLVR = "ListLayerVersionsRequest";
    var _LLVRi = "ListLayerVersionsResponse";
    var _LLi = "ListLayers";
    var _LM2 = "LastModified";
    var _LMICPC = "LambdaManagedInstancesCapacityProviderConfig";
    var _LMP = "LocalMountPath";
    var _LMT = "LastModifiedTime";
    var _LMV = "LatestMatchingVersion";
    var _LN = "LayerName";
    var _LPCC = "ListProvisionedConcurrencyConfigs";
    var _LPCCR = "ListProvisionedConcurrencyConfigsRequest";
    var _LPCCRi = "ListProvisionedConcurrencyConfigsResponse";
    var _LPR = "LastProcessingResult";
    var _LR = "LogResult";
    var _LRL = "LayersReferenceList";
    var _LT = "LogType";
    var _LTR = "ListTagsRequest";
    var _LTRi = "ListTagsResponse";
    var _LTi = "ListTags";
    var _LUS = "LastUpdateStatus";
    var _LUSR = "LastUpdateStatusReason";
    var _LUSRC = "LastUpdateStatusReasonCode";
    var _LV = "LayerVersions";
    var _LVA = "LayerVersionArn";
    var _LVBF = "ListVersionsByFunction";
    var _LVBFR = "ListVersionsByFunctionRequest";
    var _LVBFRi = "ListVersionsByFunctionResponse";
    var _LVCI = "LayerVersionContentInput";
    var _LVCO = "LayerVersionContentOutput";
    var _LVL = "LayerVersionsList";
    var _LVLI = "LayerVersionsListItem";
    var _La = "Layer";
    var _Lo = "Location";
    var _M = "Message";
    var _MA = "MaxAge";
    var _MAa = "MasterArn";
    var _MBWIS = "MaximumBatchingWindowInSeconds";
    var _MC = "MetricsConfig";
    var _MCa = "MaximumConcurrency";
    var _MEAIS = "MaximumEventAgeInSeconds";
    var _MEE = "MinExecutionEnvironments";
    var _MEEa = "MaxExecutionEnvironments";
    var _MI = "MaxItems";
    var _MP = "MinimumPollers";
    var _MPa = "MaximumPollers";
    var _MR = "MasterRegion";
    var _MRA = "MaximumRetryAttempts";
    var _MRAIS = "MaximumRecordAgeInSeconds";
    var _MS = "MemorySize";
    var _MVCC = "MaxVCpuCount";
    var _Ma = "Marker";
    var _Me = "Metrics";
    var _Mo = "Mode";
    var _N = "Name";
    var _NADS = "NextAttemptDelaySeconds";
    var _NAT = "NextAttemptTimestamp";
    var _NES = "NewExecutionState";
    var _NM = "NextMarker";
    var _NPVE = "NoPublishedVersionException";
    var _O = "Operations";
    var _OF = "OnFailure";
    var _OI = "OrganizationId";
    var _OP = "OperationPayload";
    var _OPu = "OutputPayload";
    var _OS = "OnSuccess";
    var _OSp = "OptimizationStatus";
    var _OU = "OperationUpdate";
    var _OUp = "OperationUpdates";
    var _Op = "Operation";
    var _P10 = "Principal";
    var _PC10 = "PermissionsConfig";
    var _PCC = "ProvisionedConcurrencyConfigs";
    var _PCCL = "ProvisionedConcurrencyConfigList";
    var _PCCLI = "ProvisionedConcurrencyConfigListItem";
    var _PCCNFE = "ProvisionedConcurrencyConfigNotFoundException";
    var _PCE = "ProvisionedConcurrentExecutions";
    var _PCa = "PayloadChunk";
    var _PEEMC = "PerExecutionEnvironmentMaxConcurrency";
    var _PF = "ParallelizationFactor";
    var _PFC = "PutFunctionConcurrency";
    var _PFCR = "PutFunctionConcurrencyRequest";
    var _PFCSC = "PutFunctionCodeSigningConfig";
    var _PFCSCR = "PutFunctionCodeSigningConfigRequest";
    var _PFCSCRu = "PutFunctionCodeSigningConfigResponse";
    var _PFE = "PreconditionFailedException";
    var _PFEIC = "PutFunctionEventInvokeConfig";
    var _PFEICR = "PutFunctionEventInvokeConfigRequest";
    var _PFRC = "PutFunctionRecursionConfig";
    var _PFRCR = "PutFunctionRecursionConfigRequest";
    var _PFRCRu = "PutFunctionRecursionConfigResponse";
    var _PFSC = "PutFunctionScalingConfig";
    var _PFSCR = "PutFunctionScalingConfigRequest";
    var _PFSCRu = "PutFunctionScalingConfigResponse";
    var _PGN = "PollerGroupName";
    var _PI10 = "ParentId";
    var _PLEE = "PolicyLengthExceededException";
    var _PLV = "PublishLayerVersion";
    var _PLVR = "PublishLayerVersionRequest";
    var _PLVRu = "PublishLayerVersionResponse";
    var _PMT = "PredefinedMetricType";
    var _POID = "PrincipalOrgID";
    var _PPC = "ProvisionedPollerConfig";
    var _PPCC = "PutProvisionedConcurrencyConfig";
    var _PPCCR = "PutProvisionedConcurrencyConfigRequest";
    var _PPCCRu = "PutProvisionedConcurrencyConfigResponse";
    var _PRMC = "PutRuntimeManagementConfig";
    var _PRMCR = "PutRuntimeManagementConfigRequest";
    var _PRMCRu = "PutRuntimeManagementConfigResponse";
    var _PT = "PackageType";
    var _PTu = "PublishTo";
    var _PV = "PublishVersion";
    var _PVR = "PublishVersionRequest";
    var _Pa = "Payload";
    var _Pat = "Pattern";
    var _Po = "Policy";
    var _Pu = "Publish";
    var _Q = "Qualifier";
    var _Qu = "Queues";
    var _R = "Reason";
    var _RA10 = "Retry-After";
    var _RC10 = "RoutingConfig";
    var _RCE2 = "ResourceConflictException";
    var _RCEe = "ReservedConcurrentExecutions";
    var _RCe = "ReplayChildren";
    var _RD = "RetryDetails";
    var _RFSC = "RequestedFunctionScalingConfig";
    var _RI = "RevisionId";
    var _RIE = "RecursiveInvocationException";
    var _RIU = "ResolvedImageUri";
    var _RIUE = "ResourceInUseException";
    var _RIe = "RequestId";
    var _RL = "RecursiveLoop";
    var _RLVP = "RemoveLayerVersionPermission";
    var _RLVPR = "RemoveLayerVersionPermissionRequest";
    var _RNFE11 = "ResourceNotFoundException";
    var _RNRE = "ResourceNotReadyException";
    var _RO = "ReverseOrder";
    var _RP = "RemovePermission";
    var _RPCE = "RequestedProvisionedConcurrentExecutions";
    var _RPID = "RetentionPeriodInDays";
    var _RPR = "RemovePermissionRequest";
    var _RSCT = "ResponseStreamContentType";
    var _RT13 = "RepositoryType";
    var _RTLE = "RequestTooLargeException";
    var _RVA = "RuntimeVersionArn";
    var _RVC = "RuntimeVersionConfig";
    var _RVE = "RuntimeVersionError";
    var _Re = "Result";
    var _Res = "Resource";
    var _Ro = "Role";
    var _Ru = "Runtime";
    var _S = "Statement";
    var _SA = "SourceArn";
    var _SAC = "SourceAccessConfigurations";
    var _SACo = "SourceAccessConfiguration";
    var _SAo = "SourceAccount";
    var _SAt = "StartedAfter";
    var _SB = "S3Bucket";
    var _SBt = "StartedBefore";
    var _SC = "ScalingConfig";
    var _SCt = "StatusCode";
    var _SD = "StepDetails";
    var _SDE4 = "StopDurableExecution";
    var _SDECF = "SendDurableExecutionCallbackFailure";
    var _SDECFR = "SendDurableExecutionCallbackFailureRequest";
    var _SDECFRe = "SendDurableExecutionCallbackFailureResponse";
    var _SDECH = "SendDurableExecutionCallbackHeartbeat";
    var _SDECHR = "SendDurableExecutionCallbackHeartbeatRequest";
    var _SDECHRe = "SendDurableExecutionCallbackHeartbeatResponse";
    var _SDECS = "SendDurableExecutionCallbackSuccess";
    var _SDECSR = "SendDurableExecutionCallbackSuccessRequest";
    var _SDECSRe = "SendDurableExecutionCallbackSuccessResponse";
    var _SDER = "StopDurableExecutionRequest";
    var _SDERt = "StopDurableExecutionResponse";
    var _SE = "ServiceException";
    var _SET = "ScheduledEndTimestamp";
    var _SFD = "StepFailedDetails";
    var _SFMCE = "S3FilesMountConnectivityException";
    var _SFMFE = "S3FilesMountFailureException";
    var _SFMTE = "S3FilesMountTimeoutException";
    var _SGI = "SecurityGroupIds";
    var _SI10 = "StatementId";
    var _SIPALRE = "SubnetIPAddressLimitReachedException";
    var _SIu = "SubnetIds";
    var _SJA = "SigningJobArn";
    var _SK2 = "S3Key";
    var _SKMSKA = "SourceKMSKeyArn";
    var _SLL = "SystemLogLevel";
    var _SM = "ScalingMode";
    var _SMES = "SelfManagedEventSource";
    var _SMKESC = "SelfManagedKafkaEventSourceConfig";
    var _SO = "StepOptions";
    var _SOV = "S3ObjectVersion";
    var _SP = "ScalingPolicies";
    var _SPT = "StartingPositionTimestamp";
    var _SPVA = "SigningProfileVersionArns";
    var _SPVAi = "SigningProfileVersionArn";
    var _SPt = "StartingPosition";
    var _SR = "StateReason";
    var _SRC = "SchemaRegistryConfig";
    var _SRCt = "StateReasonCode";
    var _SRETLE = "SerializedRequestEntityTooLargeException";
    var _SRURI = "SchemaRegistryURI";
    var _SRt = "StatusReason";
    var _SS = "SensitiveString";
    var _SSD = "StepStartedDetails";
    var _SSDt = "StepSucceededDetails";
    var _SSE = "SnapStartException";
    var _SSNRE = "SnapStartNotReadyException";
    var _SSR = "SnapStartResponse";
    var _SSTE = "SnapStartTimeoutException";
    var _SSn = "SnapStart";
    var _ST11 = "StackTrace";
    var _STE = "StackTraceEntry";
    var _STEt = "StackTraceEntries";
    var _STR = "StateTransitionReason";
    var _STt = "StartTimestamp";
    var _STto = "StopTimestamp";
    var _STu = "SubType";
    var _SVC = "SchemaValidationConfigs";
    var _Si = "Size";
    var _St = "State";
    var _Sta = "Status";
    var _Stat = "Statuses";
    var _T10 = "Type";
    var _TA = "TargetArn";
    var _TC10 = "TracingConfig";
    var _TCR = "TracingConfigResponse";
    var _TCS = "TotalCodeSize";
    var _TCe = "TenancyConfig";
    var _TE = "TagsError";
    var _TH = "TraceHeader";
    var _TI = "TenantId";
    var _TIM = "TenantIsolationMode";
    var _TK = "TagKeys";
    var _TMRE20 = "TooManyRequestsException";
    var _TR = "TagResource";
    var _TRR = "TagResourceRequest";
    var _TS = "TimeoutSeconds";
    var _TTSP = "TargetTrackingScalingPolicy";
    var _TV = "TargetValue";
    var _TWIS = "TumblingWindowInSeconds";
    var _Ta10 = "Tags";
    var _Ti = "Timeout";
    var _To = "Topics";
    var _Tr = "Truncated";
    var _U = "Updates";
    var _UA = "UpdateAlias";
    var _UAOD = "UntrustedArtifactOnDeployment";
    var _UAR = "UpdateAliasRequest";
    var _UCE4 = "UnreservedConcurrentExecutions";
    var _UCP = "UpdateCapacityProvider";
    var _UCPR = "UpdateCapacityProviderRequest";
    var _UCPRp = "UpdateCapacityProviderResponse";
    var _UCSC = "UpdateCodeSigningConfig";
    var _UCSCR = "UpdateCodeSigningConfigRequest";
    var _UCSCRp = "UpdateCodeSigningConfigResponse";
    var _UESM = "UpdateEventSourceMapping";
    var _UESMR = "UpdateEventSourceMappingRequest";
    var _UFC = "UpdateFunctionCode";
    var _UFCR = "UpdateFunctionCodeRequest";
    var _UFCRp = "UpdateFunctionConfigurationRequest";
    var _UFCp = "UpdateFunctionConfiguration";
    var _UFEIC = "UpdateFunctionEventInvokeConfig";
    var _UFEICR = "UpdateFunctionEventInvokeConfigRequest";
    var _UFUC = "UpdateFunctionUrlConfig";
    var _UFUCR = "UpdateFunctionUrlConfigRequest";
    var _UFUCRp = "UpdateFunctionUrlConfigResponse";
    var _UMTE = "UnsupportedMediaTypeException";
    var _UR = "UntagResource";
    var _URI = "URI";
    var _URO = "UpdateRuntimeOn";
    var _URR = "UntagResourceRequest";
    var _UUID = "UUID";
    var _V10 = "Variables";
    var _VC = "VpcConfig";
    var _VCR = "VpcConfigResponse";
    var _VI = "VpcId";
    var _VN = "VersionNumber";
    var _Ve = "Version";
    var _Ver = "Versions";
    var _WCD = "WaitCancelledDetails";
    var _WD = "WorkingDirectory";
    var _WDa = "WaitDetails";
    var _WO = "WaitOptions";
    var _WS = "WaitSeconds";
    var _WSD = "WaitStartedDetails";
    var _WSDa = "WaitSucceededDetails";
    var _XACC = "X-Amz-Client-Context";
    var _XADEA = "X-Amz-Durable-Execution-Arn";
    var _XADEN = "X-Amz-Durable-Execution-Name";
    var _XAEV = "X-Amz-Executed-Version";
    var _XAFE = "X-Amz-Function-Error";
    var _XAIT = "X-Amz-Invocation-Type";
    var _XALR = "X-Amz-Log-Result";
    var _XALT = "X-Amz-Log-Type";
    var _XATI = "X-Amz-Tenant-Id";
    var _XATIm = "XAmznTraceId";
    var _ZF = "ZipFile";
    var _c32 = "client";
    var _e32 = "error";
    var _eP = "eventPayload";
    var _h22 = "http";
    var _hE32 = "httpError";
    var _hH10 = "httpHeader";
    var _hQ10 = "httpQuery";
    var _m29 = "message";
    var _rAS = "retryAfterSeconds";
    var _s32 = "smithy.ts.sdk.synthetic.com.amazonaws.lambda";
    var _se14 = "server";
    var _st = "streaming";
    var _tK = "tagKeys";
    var n032 = "com.amazonaws.lambda";
    var schema_1 = (init_schema4(), __toCommonJS(schema_exports));
    var errors_1 = require_errors15();
    var LambdaServiceException_1 = require_LambdaServiceException();
    var _s_registry32 = schema_1.TypeRegistry.for(_s32);
    exports2.LambdaServiceException$ = [-3, _s32, "LambdaServiceException", 0, [], []];
    _s_registry32.registerError(exports2.LambdaServiceException$, LambdaServiceException_1.LambdaServiceException);
    var n0_registry32 = schema_1.TypeRegistry.for(n032);
    exports2.CallbackTimeoutException$ = [
      -3,
      n032,
      _CTE,
      { [_e32]: _c32, [_hE32]: 400 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.CallbackTimeoutException$, errors_1.CallbackTimeoutException);
    exports2.CapacityProviderLimitExceededException$ = [
      -3,
      n032,
      _CPLEE,
      { [_e32]: _c32, [_hE32]: 400 },
      [_T10, _m29],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.CapacityProviderLimitExceededException$, errors_1.CapacityProviderLimitExceededException);
    exports2.CodeSigningConfigNotFoundException$ = [
      -3,
      n032,
      _CSCNFE,
      { [_e32]: _c32, [_hE32]: 404 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.CodeSigningConfigNotFoundException$, errors_1.CodeSigningConfigNotFoundException);
    exports2.CodeStorageExceededException$ = [
      -3,
      n032,
      _CSEE,
      { [_e32]: _c32, [_hE32]: 400 },
      [_T10, _m29],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.CodeStorageExceededException$, errors_1.CodeStorageExceededException);
    exports2.CodeVerificationFailedException$ = [
      -3,
      n032,
      _CVFE,
      { [_e32]: _c32, [_hE32]: 400 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.CodeVerificationFailedException$, errors_1.CodeVerificationFailedException);
    exports2.DurableExecutionAlreadyStartedException$ = [
      -3,
      n032,
      _DEASE,
      { [_e32]: _c32, [_hE32]: 409 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.DurableExecutionAlreadyStartedException$, errors_1.DurableExecutionAlreadyStartedException);
    exports2.EC2AccessDeniedException$ = [
      -3,
      n032,
      _ECADE,
      { [_e32]: _se14, [_hE32]: 502 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.EC2AccessDeniedException$, errors_1.EC2AccessDeniedException);
    exports2.EC2ThrottledException$ = [
      -3,
      n032,
      _ECTE,
      { [_e32]: _se14, [_hE32]: 502 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.EC2ThrottledException$, errors_1.EC2ThrottledException);
    exports2.EC2UnexpectedException$ = [
      -3,
      n032,
      _ECUE,
      { [_e32]: _se14, [_hE32]: 502 },
      [_T10, _M, _ECEC],
      [0, 0, 0]
    ];
    n0_registry32.registerError(exports2.EC2UnexpectedException$, errors_1.EC2UnexpectedException);
    exports2.EFSIOException$ = [
      -3,
      n032,
      _EFSIOE,
      { [_e32]: _c32, [_hE32]: 410 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.EFSIOException$, errors_1.EFSIOException);
    exports2.EFSMountConnectivityException$ = [
      -3,
      n032,
      _EFSMCE,
      { [_e32]: _c32, [_hE32]: 408 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.EFSMountConnectivityException$, errors_1.EFSMountConnectivityException);
    exports2.EFSMountFailureException$ = [
      -3,
      n032,
      _EFSMFE,
      { [_e32]: _c32, [_hE32]: 403 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.EFSMountFailureException$, errors_1.EFSMountFailureException);
    exports2.EFSMountTimeoutException$ = [
      -3,
      n032,
      _EFSMTE,
      { [_e32]: _c32, [_hE32]: 408 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.EFSMountTimeoutException$, errors_1.EFSMountTimeoutException);
    exports2.ENILimitReachedException$ = [
      -3,
      n032,
      _ENILRE,
      { [_e32]: _se14, [_hE32]: 502 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.ENILimitReachedException$, errors_1.ENILimitReachedException);
    exports2.FunctionVersionsPerCapacityProviderLimitExceededException$ = [
      -3,
      n032,
      _FVPCPLEE,
      { [_e32]: _c32, [_hE32]: 400 },
      [_T10, _m29],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.FunctionVersionsPerCapacityProviderLimitExceededException$, errors_1.FunctionVersionsPerCapacityProviderLimitExceededException);
    exports2.InvalidCodeSignatureException$ = [
      -3,
      n032,
      _ICSE,
      { [_e32]: _c32, [_hE32]: 400 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.InvalidCodeSignatureException$, errors_1.InvalidCodeSignatureException);
    exports2.InvalidParameterValueException$ = [
      -3,
      n032,
      _IPVE,
      { [_e32]: _c32, [_hE32]: 400 },
      [_T10, _m29],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.InvalidParameterValueException$, errors_1.InvalidParameterValueException);
    exports2.InvalidRequestContentException$ = [
      -3,
      n032,
      _IRCE,
      { [_e32]: _c32, [_hE32]: 400 },
      [_T10, _m29],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.InvalidRequestContentException$, errors_1.InvalidRequestContentException);
    exports2.InvalidRuntimeException$ = [
      -3,
      n032,
      _IRE13,
      { [_e32]: _se14, [_hE32]: 502 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.InvalidRuntimeException$, errors_1.InvalidRuntimeException);
    exports2.InvalidSecurityGroupIDException$ = [
      -3,
      n032,
      _ISGIDE,
      { [_e32]: _se14, [_hE32]: 502 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.InvalidSecurityGroupIDException$, errors_1.InvalidSecurityGroupIDException);
    exports2.InvalidSubnetIDException$ = [
      -3,
      n032,
      _ISIDE,
      { [_e32]: _se14, [_hE32]: 502 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.InvalidSubnetIDException$, errors_1.InvalidSubnetIDException);
    exports2.InvalidZipFileException$ = [
      -3,
      n032,
      _IZFE,
      { [_e32]: _se14, [_hE32]: 502 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.InvalidZipFileException$, errors_1.InvalidZipFileException);
    exports2.KMSAccessDeniedException$ = [
      -3,
      n032,
      _KMSADE,
      { [_e32]: _se14, [_hE32]: 502 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.KMSAccessDeniedException$, errors_1.KMSAccessDeniedException);
    exports2.KMSDisabledException$ = [
      -3,
      n032,
      _KMSDE,
      { [_e32]: _se14, [_hE32]: 502 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.KMSDisabledException$, errors_1.KMSDisabledException);
    exports2.KMSInvalidStateException$ = [
      -3,
      n032,
      _KMSISE,
      { [_e32]: _se14, [_hE32]: 502 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.KMSInvalidStateException$, errors_1.KMSInvalidStateException);
    exports2.KMSNotFoundException$ = [
      -3,
      n032,
      _KMSNFE,
      { [_e32]: _se14, [_hE32]: 502 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.KMSNotFoundException$, errors_1.KMSNotFoundException);
    exports2.NoPublishedVersionException$ = [
      -3,
      n032,
      _NPVE,
      { [_e32]: _c32, [_hE32]: 400 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.NoPublishedVersionException$, errors_1.NoPublishedVersionException);
    exports2.PolicyLengthExceededException$ = [
      -3,
      n032,
      _PLEE,
      { [_e32]: _c32, [_hE32]: 400 },
      [_T10, _m29],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.PolicyLengthExceededException$, errors_1.PolicyLengthExceededException);
    exports2.PreconditionFailedException$ = [
      -3,
      n032,
      _PFE,
      { [_e32]: _c32, [_hE32]: 412 },
      [_T10, _m29],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.PreconditionFailedException$, errors_1.PreconditionFailedException);
    exports2.ProvisionedConcurrencyConfigNotFoundException$ = [
      -3,
      n032,
      _PCCNFE,
      { [_e32]: _c32, [_hE32]: 404 },
      [_T10, _m29],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.ProvisionedConcurrencyConfigNotFoundException$, errors_1.ProvisionedConcurrencyConfigNotFoundException);
    exports2.RecursiveInvocationException$ = [
      -3,
      n032,
      _RIE,
      { [_e32]: _c32, [_hE32]: 400 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.RecursiveInvocationException$, errors_1.RecursiveInvocationException);
    exports2.RequestTooLargeException$ = [
      -3,
      n032,
      _RTLE,
      { [_e32]: _c32, [_hE32]: 413 },
      [_T10, _m29],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.RequestTooLargeException$, errors_1.RequestTooLargeException);
    exports2.ResourceConflictException$ = [
      -3,
      n032,
      _RCE2,
      { [_e32]: _c32, [_hE32]: 409 },
      [_T10, _m29],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.ResourceConflictException$, errors_1.ResourceConflictException);
    exports2.ResourceInUseException$ = [
      -3,
      n032,
      _RIUE,
      { [_e32]: _c32, [_hE32]: 400 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.ResourceInUseException$, errors_1.ResourceInUseException);
    exports2.ResourceNotFoundException$ = [
      -3,
      n032,
      _RNFE11,
      { [_e32]: _c32, [_hE32]: 404 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.ResourceNotFoundException$, errors_1.ResourceNotFoundException);
    exports2.ResourceNotReadyException$ = [
      -3,
      n032,
      _RNRE,
      { [_e32]: _se14, [_hE32]: 502 },
      [_T10, _m29],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.ResourceNotReadyException$, errors_1.ResourceNotReadyException);
    exports2.S3FilesMountConnectivityException$ = [
      -3,
      n032,
      _SFMCE,
      { [_e32]: _c32, [_hE32]: 408 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.S3FilesMountConnectivityException$, errors_1.S3FilesMountConnectivityException);
    exports2.S3FilesMountFailureException$ = [
      -3,
      n032,
      _SFMFE,
      { [_e32]: _c32, [_hE32]: 403 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.S3FilesMountFailureException$, errors_1.S3FilesMountFailureException);
    exports2.S3FilesMountTimeoutException$ = [
      -3,
      n032,
      _SFMTE,
      { [_e32]: _c32, [_hE32]: 408 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.S3FilesMountTimeoutException$, errors_1.S3FilesMountTimeoutException);
    exports2.SerializedRequestEntityTooLargeException$ = [
      -3,
      n032,
      _SRETLE,
      { [_e32]: _c32, [_hE32]: 413 },
      [_T10, _m29],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.SerializedRequestEntityTooLargeException$, errors_1.SerializedRequestEntityTooLargeException);
    exports2.ServiceException$ = [
      -3,
      n032,
      _SE,
      { [_e32]: _se14, [_hE32]: 500 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.ServiceException$, errors_1.ServiceException);
    exports2.SnapStartException$ = [
      -3,
      n032,
      _SSE,
      { [_e32]: _c32, [_hE32]: 400 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.SnapStartException$, errors_1.SnapStartException);
    exports2.SnapStartNotReadyException$ = [
      -3,
      n032,
      _SSNRE,
      { [_e32]: _c32, [_hE32]: 409 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.SnapStartNotReadyException$, errors_1.SnapStartNotReadyException);
    exports2.SnapStartTimeoutException$ = [
      -3,
      n032,
      _SSTE,
      { [_e32]: _c32, [_hE32]: 408 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.SnapStartTimeoutException$, errors_1.SnapStartTimeoutException);
    exports2.SubnetIPAddressLimitReachedException$ = [
      -3,
      n032,
      _SIPALRE,
      { [_e32]: _se14, [_hE32]: 502 },
      [_T10, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.SubnetIPAddressLimitReachedException$, errors_1.SubnetIPAddressLimitReachedException);
    exports2.TooManyRequestsException$ = [
      -3,
      n032,
      _TMRE20,
      { [_e32]: _c32, [_hE32]: 429 },
      [_rAS, _T10, _m29, _R],
      [[0, { [_hH10]: _RA10 }], 0, 0, 0]
    ];
    n0_registry32.registerError(exports2.TooManyRequestsException$, errors_1.TooManyRequestsException);
    exports2.UnsupportedMediaTypeException$ = [
      -3,
      n032,
      _UMTE,
      { [_e32]: _c32, [_hE32]: 415 },
      [_T10, _m29],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.UnsupportedMediaTypeException$, errors_1.UnsupportedMediaTypeException);
    exports2.errorTypeRegistries = [
      _s_registry32,
      n0_registry32
    ];
    var BinaryOperationPayload = [0, n032, _BOP, 8, 21];
    var _Blob = [0, n032, _B, 8, 21];
    var BlobStream = [0, n032, _BS, { [_st]: 1 }, 42];
    var EnvironmentVariableName = [0, n032, _EVN, 8, 0];
    var EnvironmentVariableValue = [0, n032, _EVV, 8, 0];
    var ErrorData = [0, n032, _ED, 8, 0];
    var ErrorMessage = [0, n032, _EM, 8, 0];
    var ErrorType = [0, n032, _ET, 8, 0];
    var InputPayload = [0, n032, _IP, 8, 0];
    var OperationPayload = [0, n032, _OP, 8, 0];
    var OutputPayload = [0, n032, _OPu, 8, 0];
    var SensitiveString = [0, n032, _SS, 8, 0];
    var StackTraceEntry = [0, n032, _STE, 8, 0];
    exports2.AccountLimit$ = [
      3,
      n032,
      _AL,
      0,
      [_TCS, _CSU, _CSZ, _CE, _UCE4],
      [1, 1, 1, 1, 1]
    ];
    exports2.AccountUsage$ = [
      3,
      n032,
      _AU,
      0,
      [_TCS, _FC],
      [1, 1]
    ];
    exports2.AddLayerVersionPermissionRequest$ = [
      3,
      n032,
      _ALVPR,
      0,
      [_LN, _VN, _SI10, _A10, _P10, _OI, _RI],
      [[0, 1], [1, 1], 0, 0, 0, 0, [0, { [_hQ10]: _RI }]],
      5
    ];
    exports2.AddLayerVersionPermissionResponse$ = [
      3,
      n032,
      _ALVPRd,
      0,
      [_S, _RI],
      [0, 0]
    ];
    exports2.AddPermissionRequest$ = [
      3,
      n032,
      _APR,
      0,
      [_FN, _SI10, _A10, _P10, _SA, _SAo, _EST, _Q, _RI, _POID, _FUAT, _IVFU],
      [[0, 1], 0, 0, 0, 0, 0, 0, [0, { [_hQ10]: _Q }], 0, 0, 0, 2],
      4
    ];
    exports2.AddPermissionResponse$ = [
      3,
      n032,
      _APRd,
      0,
      [_S],
      [0]
    ];
    exports2.AliasConfiguration$ = [
      3,
      n032,
      _AC,
      0,
      [_AA, _N, _FV, _D, _RC10, _RI],
      [0, 0, 0, 0, () => exports2.AliasRoutingConfiguration$, 0]
    ];
    exports2.AliasRoutingConfiguration$ = [
      3,
      n032,
      _ARC,
      0,
      [_AVW],
      [128 | 1]
    ];
    exports2.AllowedPublishers$ = [
      3,
      n032,
      _AP,
      0,
      [_SPVA],
      [64 | 0],
      1
    ];
    exports2.AmazonManagedKafkaEventSourceConfig$ = [
      3,
      n032,
      _AMKESC,
      0,
      [_CGI, _SRC],
      [0, () => exports2.KafkaSchemaRegistryConfig$]
    ];
    exports2.CallbackDetails$ = [
      3,
      n032,
      _CD,
      0,
      [_CI, _Re, _E11],
      [0, [() => OperationPayload, 0], [() => exports2.ErrorObject$, 0]]
    ];
    exports2.CallbackFailedDetails$ = [
      3,
      n032,
      _CFD,
      0,
      [_E11],
      [[() => exports2.EventError$, 0]],
      1
    ];
    exports2.CallbackOptions$ = [
      3,
      n032,
      _CO,
      0,
      [_TS, _HTS],
      [1, 1]
    ];
    exports2.CallbackStartedDetails$ = [
      3,
      n032,
      _CSD,
      0,
      [_CI, _HT, _Ti],
      [0, 1, 1],
      1
    ];
    exports2.CallbackSucceededDetails$ = [
      3,
      n032,
      _CSDa,
      0,
      [_Re],
      [[() => exports2.EventResult$, 0]],
      1
    ];
    exports2.CallbackTimedOutDetails$ = [
      3,
      n032,
      _CTOD,
      0,
      [_E11],
      [[() => exports2.EventError$, 0]],
      1
    ];
    exports2.CapacityProvider$ = [
      3,
      n032,
      _CP,
      0,
      [_CPA, _St, _VC, _PC10, _IR, _CPSC, _KKA, _LM2],
      [0, 0, () => exports2.CapacityProviderVpcConfig$, () => exports2.CapacityProviderPermissionsConfig$, () => exports2.InstanceRequirements$, () => exports2.CapacityProviderScalingConfig$, 0, 0],
      4
    ];
    exports2.CapacityProviderConfig$ = [
      3,
      n032,
      _CPC,
      0,
      [_LMICPC],
      [() => exports2.LambdaManagedInstancesCapacityProviderConfig$],
      1
    ];
    exports2.CapacityProviderPermissionsConfig$ = [
      3,
      n032,
      _CPPC,
      0,
      [_CPORA],
      [0],
      1
    ];
    exports2.CapacityProviderScalingConfig$ = [
      3,
      n032,
      _CPSC,
      0,
      [_MVCC, _SM, _SP],
      [1, 0, () => CapacityProviderScalingPoliciesList]
    ];
    exports2.CapacityProviderVpcConfig$ = [
      3,
      n032,
      _CPVC,
      0,
      [_SIu, _SGI],
      [64 | 0, 64 | 0],
      2
    ];
    exports2.ChainedInvokeDetails$ = [
      3,
      n032,
      _CID,
      0,
      [_Re, _E11],
      [[() => OperationPayload, 0], [() => exports2.ErrorObject$, 0]]
    ];
    exports2.ChainedInvokeFailedDetails$ = [
      3,
      n032,
      _CIFD,
      0,
      [_E11],
      [[() => exports2.EventError$, 0]],
      1
    ];
    exports2.ChainedInvokeOptions$ = [
      3,
      n032,
      _CIO,
      0,
      [_FN, _TI],
      [0, 0],
      1
    ];
    exports2.ChainedInvokeStartedDetails$ = [
      3,
      n032,
      _CISD,
      0,
      [_FN, _TI, _I, _EV, _DEA],
      [0, 0, [() => exports2.EventInput$, 0], 0, 0],
      1
    ];
    exports2.ChainedInvokeStoppedDetails$ = [
      3,
      n032,
      _CISDh,
      0,
      [_E11],
      [[() => exports2.EventError$, 0]],
      1
    ];
    exports2.ChainedInvokeSucceededDetails$ = [
      3,
      n032,
      _CISDha,
      0,
      [_Re],
      [[() => exports2.EventResult$, 0]],
      1
    ];
    exports2.ChainedInvokeTimedOutDetails$ = [
      3,
      n032,
      _CITOD,
      0,
      [_E11],
      [[() => exports2.EventError$, 0]],
      1
    ];
    exports2.CheckpointDurableExecutionRequest$ = [
      3,
      n032,
      _CDER,
      0,
      [_DEA, _CT4, _U, _CTl],
      [[0, 1], 0, [() => OperationUpdates, 0], [0, 4]],
      2
    ];
    exports2.CheckpointDurableExecutionResponse$ = [
      3,
      n032,
      _CDERh,
      0,
      [_NES, _CT4],
      [[() => exports2.CheckpointUpdatedExecutionState$, 0], 0],
      1
    ];
    exports2.CheckpointUpdatedExecutionState$ = [
      3,
      n032,
      _CUES,
      0,
      [_O, _NM],
      [[() => Operations, 0], 0]
    ];
    exports2.CodeSigningConfig$ = [
      3,
      n032,
      _CSC,
      0,
      [_CSCI, _CSCA, _AP, _CSP, _LM2, _D],
      [0, 0, () => exports2.AllowedPublishers$, () => exports2.CodeSigningPolicies$, 0, 0],
      5
    ];
    exports2.CodeSigningPolicies$ = [
      3,
      n032,
      _CSP,
      0,
      [_UAOD],
      [0]
    ];
    exports2.Concurrency$ = [
      3,
      n032,
      _C11,
      0,
      [_RCEe],
      [1]
    ];
    exports2.ContextDetails$ = [
      3,
      n032,
      _CDo,
      0,
      [_RCe, _Re, _E11],
      [2, [() => OperationPayload, 0], [() => exports2.ErrorObject$, 0]]
    ];
    exports2.ContextFailedDetails$ = [
      3,
      n032,
      _CFDo,
      0,
      [_E11],
      [[() => exports2.EventError$, 0]],
      1
    ];
    exports2.ContextOptions$ = [
      3,
      n032,
      _COo,
      0,
      [_RCe],
      [2]
    ];
    exports2.ContextStartedDetails$ = [
      3,
      n032,
      _CSDo,
      0,
      [],
      []
    ];
    exports2.ContextSucceededDetails$ = [
      3,
      n032,
      _CSDon,
      0,
      [_Re],
      [[() => exports2.EventResult$, 0]],
      1
    ];
    exports2.Cors$ = [
      3,
      n032,
      _Co,
      0,
      [_ACl, _AH, _AM, _AO, _EH, _MA],
      [2, 64 | 0, 64 | 0, 64 | 0, 64 | 0, 1]
    ];
    exports2.CreateAliasRequest$ = [
      3,
      n032,
      _CAR,
      0,
      [_FN, _N, _FV, _D, _RC10],
      [[0, 1], 0, 0, 0, () => exports2.AliasRoutingConfiguration$],
      3
    ];
    exports2.CreateCapacityProviderRequest$ = [
      3,
      n032,
      _CCPR,
      0,
      [_CPN, _VC, _PC10, _IR, _CPSC, _KKA, _Ta10],
      [0, () => exports2.CapacityProviderVpcConfig$, () => exports2.CapacityProviderPermissionsConfig$, () => exports2.InstanceRequirements$, () => exports2.CapacityProviderScalingConfig$, 0, 128 | 0],
      3
    ];
    exports2.CreateCapacityProviderResponse$ = [
      3,
      n032,
      _CCPRr,
      0,
      [_CP],
      [() => exports2.CapacityProvider$],
      1
    ];
    exports2.CreateCodeSigningConfigRequest$ = [
      3,
      n032,
      _CCSCR,
      0,
      [_AP, _D, _CSP, _Ta10],
      [() => exports2.AllowedPublishers$, 0, () => exports2.CodeSigningPolicies$, 128 | 0],
      1
    ];
    exports2.CreateCodeSigningConfigResponse$ = [
      3,
      n032,
      _CCSCRr,
      0,
      [_CSC],
      [() => exports2.CodeSigningConfig$],
      1
    ];
    exports2.CreateEventSourceMappingRequest$ = [
      3,
      n032,
      _CESMR,
      0,
      [_FN, _ESA, _En, _BSa, _FCi, _MBWIS, _PF, _SPt, _SPT, _DC, _MRAIS, _BBOFE, _MRA, _Ta10, _TWIS, _To, _Qu, _SAC, _SMES, _FRT, _AMKESC, _SMKESC, _SC, _DDBESC, _KMSKA, _MC, _LC, _PPC],
      [0, 0, 2, 1, () => exports2.FilterCriteria$, 1, 1, 0, 4, () => exports2.DestinationConfig$, 1, 2, 1, 128 | 0, 1, 64 | 0, 64 | 0, () => SourceAccessConfigurations, () => exports2.SelfManagedEventSource$, 64 | 0, () => exports2.AmazonManagedKafkaEventSourceConfig$, () => exports2.SelfManagedKafkaEventSourceConfig$, () => exports2.ScalingConfig$, () => exports2.DocumentDBEventSourceConfig$, 0, () => exports2.EventSourceMappingMetricsConfig$, () => exports2.EventSourceMappingLoggingConfig$, () => exports2.ProvisionedPollerConfig$],
      1
    ];
    exports2.CreateFunctionRequest$ = [
      3,
      n032,
      _CFR,
      0,
      [_FN, _Ro, _Cod, _Ru, _H, _D, _Ti, _MS, _Pu, _VC, _PT, _DLC, _Env, _KMSKA, _TC10, _Ta10, _L2, _FSC, _IC, _CSCA, _Ar, _ES, _SSn, _LC, _CPC, _PTu, _DCu, _TCe],
      [0, 0, [() => exports2.FunctionCode$, 0], 0, 0, 0, 1, 1, 2, () => exports2.VpcConfig$, 0, () => exports2.DeadLetterConfig$, [() => exports2.Environment$, 0], 0, () => exports2.TracingConfig$, 128 | 0, 64 | 0, () => FileSystemConfigList, () => exports2.ImageConfig$, 0, 64 | 0, () => exports2.EphemeralStorage$, () => exports2.SnapStart$, () => exports2.LoggingConfig$, () => exports2.CapacityProviderConfig$, 0, () => exports2.DurableConfig$, () => exports2.TenancyConfig$],
      3
    ];
    exports2.CreateFunctionUrlConfigRequest$ = [
      3,
      n032,
      _CFUCR,
      0,
      [_FN, _AT13, _Q, _Co, _IM],
      [[0, 1], 0, [0, { [_hQ10]: _Q }], () => exports2.Cors$, 0],
      2
    ];
    exports2.CreateFunctionUrlConfigResponse$ = [
      3,
      n032,
      _CFUCRr,
      0,
      [_FU, _FA, _AT13, _CTr, _Co, _IM],
      [0, 0, 0, 0, () => exports2.Cors$, 0],
      4
    ];
    exports2.DeadLetterConfig$ = [
      3,
      n032,
      _DLC,
      0,
      [_TA],
      [0]
    ];
    exports2.DeleteAliasRequest$ = [
      3,
      n032,
      _DAR,
      0,
      [_FN, _N],
      [[0, 1], [0, 1]],
      2
    ];
    exports2.DeleteCapacityProviderRequest$ = [
      3,
      n032,
      _DCPR,
      0,
      [_CPN],
      [[0, 1]],
      1
    ];
    exports2.DeleteCapacityProviderResponse$ = [
      3,
      n032,
      _DCPRe,
      0,
      [_CP],
      [() => exports2.CapacityProvider$],
      1
    ];
    exports2.DeleteCodeSigningConfigRequest$ = [
      3,
      n032,
      _DCSCR,
      0,
      [_CSCA],
      [[0, 1]],
      1
    ];
    exports2.DeleteCodeSigningConfigResponse$ = [
      3,
      n032,
      _DCSCRe,
      0,
      [],
      []
    ];
    exports2.DeleteEventSourceMappingRequest$ = [
      3,
      n032,
      _DESMR,
      0,
      [_UUID],
      [[0, 1]],
      1
    ];
    exports2.DeleteFunctionCodeSigningConfigRequest$ = [
      3,
      n032,
      _DFCSCR,
      0,
      [_FN],
      [[0, 1]],
      1
    ];
    exports2.DeleteFunctionConcurrencyRequest$ = [
      3,
      n032,
      _DFCR,
      0,
      [_FN],
      [[0, 1]],
      1
    ];
    exports2.DeleteFunctionEventInvokeConfigRequest$ = [
      3,
      n032,
      _DFEICR,
      0,
      [_FN, _Q],
      [[0, 1], [0, { [_hQ10]: _Q }]],
      1
    ];
    exports2.DeleteFunctionRequest$ = [
      3,
      n032,
      _DFR,
      0,
      [_FN, _Q],
      [[0, 1], [0, { [_hQ10]: _Q }]],
      1
    ];
    exports2.DeleteFunctionResponse$ = [
      3,
      n032,
      _DFRe,
      0,
      [_SCt],
      [[1, 32]]
    ];
    exports2.DeleteFunctionUrlConfigRequest$ = [
      3,
      n032,
      _DFUCR,
      0,
      [_FN, _Q],
      [[0, 1], [0, { [_hQ10]: _Q }]],
      1
    ];
    exports2.DeleteLayerVersionRequest$ = [
      3,
      n032,
      _DLVR,
      0,
      [_LN, _VN],
      [[0, 1], [1, 1]],
      2
    ];
    exports2.DeleteProvisionedConcurrencyConfigRequest$ = [
      3,
      n032,
      _DPCCR,
      0,
      [_FN, _Q],
      [[0, 1], [0, { [_hQ10]: _Q }]],
      2
    ];
    exports2.DestinationConfig$ = [
      3,
      n032,
      _DC,
      0,
      [_OS, _OF],
      [() => exports2.OnSuccess$, () => exports2.OnFailure$]
    ];
    exports2.DocumentDBEventSourceConfig$ = [
      3,
      n032,
      _DDBESC,
      0,
      [_DN, _CN, _FD],
      [0, 0, 0]
    ];
    exports2.DurableConfig$ = [
      3,
      n032,
      _DCu,
      0,
      [_RPID, _ETx],
      [1, 1]
    ];
    exports2.Environment$ = [
      3,
      n032,
      _Env,
      0,
      [_V10],
      [[() => EnvironmentVariables, 0]]
    ];
    exports2.EnvironmentError$ = [
      3,
      n032,
      _EE,
      0,
      [_EC, _M],
      [0, [() => SensitiveString, 0]]
    ];
    exports2.EnvironmentResponse$ = [
      3,
      n032,
      _ER,
      0,
      [_V10, _E11],
      [[() => EnvironmentVariables, 0], [() => exports2.EnvironmentError$, 0]]
    ];
    exports2.EphemeralStorage$ = [
      3,
      n032,
      _ES,
      0,
      [_Si],
      [1],
      1
    ];
    exports2.ErrorObject$ = [
      3,
      n032,
      _EO,
      0,
      [_EM, _ET, _ED, _ST11],
      [[() => ErrorMessage, 0], [() => ErrorType, 0], [() => ErrorData, 0], [() => StackTraceEntries, 0]]
    ];
    exports2.Event$ = [
      3,
      n032,
      _Ev,
      0,
      [_ETv, _STu, _EI10, _Id, _N, _ETve, _PI10, _ESD, _ESDx, _EFD, _ETOD, _ESDxe, _CSDo, _CSDon, _CFDo, _WSD, _WSDa, _WCD, _SSD, _SSDt, _SFD, _CISD, _CISDha, _CIFD, _CITOD, _CISDh, _CSD, _CSDa, _CFD, _CTOD, _ICD],
      [0, 0, 1, 0, 0, 4, 0, [() => exports2.ExecutionStartedDetails$, 0], [() => exports2.ExecutionSucceededDetails$, 0], [() => exports2.ExecutionFailedDetails$, 0], [() => exports2.ExecutionTimedOutDetails$, 0], [() => exports2.ExecutionStoppedDetails$, 0], () => exports2.ContextStartedDetails$, [() => exports2.ContextSucceededDetails$, 0], [() => exports2.ContextFailedDetails$, 0], () => exports2.WaitStartedDetails$, () => exports2.WaitSucceededDetails$, [() => exports2.WaitCancelledDetails$, 0], () => exports2.StepStartedDetails$, [() => exports2.StepSucceededDetails$, 0], [() => exports2.StepFailedDetails$, 0], [() => exports2.ChainedInvokeStartedDetails$, 0], [() => exports2.ChainedInvokeSucceededDetails$, 0], [() => exports2.ChainedInvokeFailedDetails$, 0], [() => exports2.ChainedInvokeTimedOutDetails$, 0], [() => exports2.ChainedInvokeStoppedDetails$, 0], () => exports2.CallbackStartedDetails$, [() => exports2.CallbackSucceededDetails$, 0], [() => exports2.CallbackFailedDetails$, 0], [() => exports2.CallbackTimedOutDetails$, 0], [() => exports2.InvocationCompletedDetails$, 0]]
    ];
    exports2.EventError$ = [
      3,
      n032,
      _EEv,
      0,
      [_Pa, _Tr],
      [[() => exports2.ErrorObject$, 0], 2]
    ];
    exports2.EventInput$ = [
      3,
      n032,
      _EIv,
      0,
      [_Pa, _Tr],
      [[() => InputPayload, 0], 2]
    ];
    exports2.EventResult$ = [
      3,
      n032,
      _ERv,
      0,
      [_Pa, _Tr],
      [[() => OperationPayload, 0], 2]
    ];
    exports2.EventSourceMappingConfiguration$ = [
      3,
      n032,
      _ESMC,
      0,
      [_UUID, _SPt, _SPT, _BSa, _MBWIS, _PF, _ESA, _FCi, _FA, _LM2, _LPR, _St, _STR, _DC, _To, _Qu, _SAC, _SMES, _MRAIS, _BBOFE, _MRA, _TWIS, _FRT, _AMKESC, _SMKESC, _SC, _DDBESC, _KMSKA, _FCE, _ESMA, _MC, _LC, _PPC],
      [0, 0, 4, 1, 1, 1, 0, () => exports2.FilterCriteria$, 0, 4, 0, 0, 0, () => exports2.DestinationConfig$, 64 | 0, 64 | 0, () => SourceAccessConfigurations, () => exports2.SelfManagedEventSource$, 1, 2, 1, 1, 64 | 0, () => exports2.AmazonManagedKafkaEventSourceConfig$, () => exports2.SelfManagedKafkaEventSourceConfig$, () => exports2.ScalingConfig$, () => exports2.DocumentDBEventSourceConfig$, 0, () => exports2.FilterCriteriaError$, 0, () => exports2.EventSourceMappingMetricsConfig$, () => exports2.EventSourceMappingLoggingConfig$, () => exports2.ProvisionedPollerConfig$]
    ];
    exports2.EventSourceMappingLoggingConfig$ = [
      3,
      n032,
      _ESMLC,
      0,
      [_SLL],
      [0]
    ];
    exports2.EventSourceMappingMetricsConfig$ = [
      3,
      n032,
      _ESMMC,
      0,
      [_Me],
      [64 | 0]
    ];
    exports2.Execution$ = [
      3,
      n032,
      _Ex,
      0,
      [_DEA, _DEN, _FA, _Sta, _STt, _ETn],
      [0, 0, 0, 0, 4, 4],
      5
    ];
    exports2.ExecutionDetails$ = [
      3,
      n032,
      _EDx,
      0,
      [_IP],
      [[() => InputPayload, 0]]
    ];
    exports2.ExecutionFailedDetails$ = [
      3,
      n032,
      _EFD,
      0,
      [_E11],
      [[() => exports2.EventError$, 0]],
      1
    ];
    exports2.ExecutionStartedDetails$ = [
      3,
      n032,
      _ESD,
      0,
      [_I, _ETx],
      [[() => exports2.EventInput$, 0], 1],
      2
    ];
    exports2.ExecutionStoppedDetails$ = [
      3,
      n032,
      _ESDxe,
      0,
      [_E11],
      [[() => exports2.EventError$, 0]],
      1
    ];
    exports2.ExecutionSucceededDetails$ = [
      3,
      n032,
      _ESDx,
      0,
      [_Re],
      [[() => exports2.EventResult$, 0]],
      1
    ];
    exports2.ExecutionTimedOutDetails$ = [
      3,
      n032,
      _ETOD,
      0,
      [_E11],
      [[() => exports2.EventError$, 0]]
    ];
    exports2.FileSystemConfig$ = [
      3,
      n032,
      _FSCi,
      0,
      [_Arn, _LMP],
      [0, 0],
      2
    ];
    exports2.Filter$ = [
      3,
      n032,
      _F,
      0,
      [_Pat],
      [0]
    ];
    exports2.FilterCriteria$ = [
      3,
      n032,
      _FCi,
      0,
      [_Fi],
      [() => FilterList]
    ];
    exports2.FilterCriteriaError$ = [
      3,
      n032,
      _FCE,
      0,
      [_EC, _M],
      [0, 0]
    ];
    exports2.FunctionCode$ = [
      3,
      n032,
      _FCu,
      0,
      [_ZF, _SB, _SK2, _SOV, _IU, _SKMSKA],
      [[() => _Blob, 0], 0, 0, 0, 0, 0]
    ];
    exports2.FunctionCodeLocation$ = [
      3,
      n032,
      _FCL,
      0,
      [_RT13, _Lo, _IU, _RIU, _SKMSKA],
      [0, 0, 0, 0, 0]
    ];
    exports2.FunctionConfiguration$ = [
      3,
      n032,
      _FCun,
      0,
      [_FN, _FA, _Ru, _Ro, _H, _CS4, _D, _Ti, _MS, _LM2, _CSo, _Ve, _VC, _DLC, _Env, _KMSKA, _TC10, _MAa, _RI, _L2, _St, _SR, _SRCt, _LUS, _LUSR, _LUSRC, _FSC, _PT, _ICR, _SPVAi, _SJA, _Ar, _ES, _SSn, _RVC, _LC, _CPC, _CSon, _DCu, _TCe],
      [0, 0, 0, 0, 0, 1, 0, 1, 1, 0, 0, 0, () => exports2.VpcConfigResponse$, () => exports2.DeadLetterConfig$, [() => exports2.EnvironmentResponse$, 0], 0, () => exports2.TracingConfigResponse$, 0, 0, () => LayersReferenceList, 0, 0, 0, 0, 0, 0, () => FileSystemConfigList, 0, [() => exports2.ImageConfigResponse$, 0], 0, 0, 64 | 0, () => exports2.EphemeralStorage$, () => exports2.SnapStartResponse$, [() => exports2.RuntimeVersionConfig$, 0], () => exports2.LoggingConfig$, () => exports2.CapacityProviderConfig$, 0, () => exports2.DurableConfig$, () => exports2.TenancyConfig$]
    ];
    exports2.FunctionEventInvokeConfig$ = [
      3,
      n032,
      _FEIC,
      0,
      [_LM2, _FA, _MRA, _MEAIS, _DC],
      [4, 0, 1, 1, () => exports2.DestinationConfig$]
    ];
    exports2.FunctionScalingConfig$ = [
      3,
      n032,
      _FSCu,
      0,
      [_MEE, _MEEa],
      [1, 1]
    ];
    exports2.FunctionUrlConfig$ = [
      3,
      n032,
      _FUC,
      0,
      [_FU, _FA, _CTr, _LMT, _AT13, _Co, _IM],
      [0, 0, 0, 0, 0, () => exports2.Cors$, 0],
      5
    ];
    exports2.FunctionVersionsByCapacityProviderListItem$ = [
      3,
      n032,
      _FVBCPLI,
      0,
      [_FA, _St],
      [0, 0],
      2
    ];
    exports2.GetAccountSettingsRequest$ = [
      3,
      n032,
      _GASR,
      0,
      [],
      []
    ];
    exports2.GetAccountSettingsResponse$ = [
      3,
      n032,
      _GASRe,
      0,
      [_AL, _AU],
      [() => exports2.AccountLimit$, () => exports2.AccountUsage$]
    ];
    exports2.GetAliasRequest$ = [
      3,
      n032,
      _GAR,
      0,
      [_FN, _N],
      [[0, 1], [0, 1]],
      2
    ];
    exports2.GetCapacityProviderRequest$ = [
      3,
      n032,
      _GCPR,
      0,
      [_CPN],
      [[0, 1]],
      1
    ];
    exports2.GetCapacityProviderResponse$ = [
      3,
      n032,
      _GCPRe,
      0,
      [_CP],
      [() => exports2.CapacityProvider$],
      1
    ];
    exports2.GetCodeSigningConfigRequest$ = [
      3,
      n032,
      _GCSCR,
      0,
      [_CSCA],
      [[0, 1]],
      1
    ];
    exports2.GetCodeSigningConfigResponse$ = [
      3,
      n032,
      _GCSCRe,
      0,
      [_CSC],
      [() => exports2.CodeSigningConfig$],
      1
    ];
    exports2.GetDurableExecutionHistoryRequest$ = [
      3,
      n032,
      _GDEHR,
      0,
      [_DEA, _IED, _MI, _Ma, _RO],
      [[0, 1], [2, { [_hQ10]: _IED }], [1, { [_hQ10]: _MI }], [0, { [_hQ10]: _Ma }], [2, { [_hQ10]: _RO }]],
      1
    ];
    exports2.GetDurableExecutionHistoryResponse$ = [
      3,
      n032,
      _GDEHRe,
      0,
      [_Eve, _NM],
      [[() => Events, 0], 0],
      1
    ];
    exports2.GetDurableExecutionRequest$ = [
      3,
      n032,
      _GDER,
      0,
      [_DEA],
      [[0, 1]],
      1
    ];
    exports2.GetDurableExecutionResponse$ = [
      3,
      n032,
      _GDERe,
      0,
      [_DEA, _DEN, _FA, _STt, _Sta, _IP, _Re, _E11, _ETn, _Ve, _TH],
      [0, 0, 0, 4, 0, [() => InputPayload, 0], [() => OutputPayload, 0], [() => exports2.ErrorObject$, 0], 4, 0, () => exports2.TraceHeader$],
      5
    ];
    exports2.GetDurableExecutionStateRequest$ = [
      3,
      n032,
      _GDESR,
      0,
      [_DEA, _CT4, _Ma, _MI],
      [[0, 1], [0, { [_hQ10]: _CT4 }], [0, { [_hQ10]: _Ma }], [1, { [_hQ10]: _MI }]],
      2
    ];
    exports2.GetDurableExecutionStateResponse$ = [
      3,
      n032,
      _GDESRe,
      0,
      [_O, _NM],
      [[() => Operations, 0], 0],
      1
    ];
    exports2.GetEventSourceMappingRequest$ = [
      3,
      n032,
      _GESMR,
      0,
      [_UUID],
      [[0, 1]],
      1
    ];
    exports2.GetFunctionCodeSigningConfigRequest$ = [
      3,
      n032,
      _GFCSCR,
      0,
      [_FN],
      [[0, 1]],
      1
    ];
    exports2.GetFunctionCodeSigningConfigResponse$ = [
      3,
      n032,
      _GFCSCRe,
      0,
      [_CSCA, _FN],
      [0, 0],
      2
    ];
    exports2.GetFunctionConcurrencyRequest$ = [
      3,
      n032,
      _GFCR,
      0,
      [_FN],
      [[0, 1]],
      1
    ];
    exports2.GetFunctionConcurrencyResponse$ = [
      3,
      n032,
      _GFCRe,
      0,
      [_RCEe],
      [1]
    ];
    exports2.GetFunctionConfigurationRequest$ = [
      3,
      n032,
      _GFCRet,
      0,
      [_FN, _Q],
      [[0, 1], [0, { [_hQ10]: _Q }]],
      1
    ];
    exports2.GetFunctionEventInvokeConfigRequest$ = [
      3,
      n032,
      _GFEICR,
      0,
      [_FN, _Q],
      [[0, 1], [0, { [_hQ10]: _Q }]],
      1
    ];
    exports2.GetFunctionRecursionConfigRequest$ = [
      3,
      n032,
      _GFRCR,
      0,
      [_FN],
      [[0, 1]],
      1
    ];
    exports2.GetFunctionRecursionConfigResponse$ = [
      3,
      n032,
      _GFRCRe,
      0,
      [_RL],
      [0]
    ];
    exports2.GetFunctionRequest$ = [
      3,
      n032,
      _GFR,
      0,
      [_FN, _Q],
      [[0, 1], [0, { [_hQ10]: _Q }]],
      1
    ];
    exports2.GetFunctionResponse$ = [
      3,
      n032,
      _GFRe,
      0,
      [_Con, _Cod, _Ta10, _TE, _C11],
      [[() => exports2.FunctionConfiguration$, 0], () => exports2.FunctionCodeLocation$, 128 | 0, () => exports2.TagsError$, () => exports2.Concurrency$]
    ];
    exports2.GetFunctionScalingConfigRequest$ = [
      3,
      n032,
      _GFSCR,
      0,
      [_FN, _Q],
      [[0, 1], [0, { [_hQ10]: _Q }]],
      2
    ];
    exports2.GetFunctionScalingConfigResponse$ = [
      3,
      n032,
      _GFSCRe,
      0,
      [_FA, _AFSC, _RFSC],
      [0, () => exports2.FunctionScalingConfig$, () => exports2.FunctionScalingConfig$]
    ];
    exports2.GetFunctionUrlConfigRequest$ = [
      3,
      n032,
      _GFUCR,
      0,
      [_FN, _Q],
      [[0, 1], [0, { [_hQ10]: _Q }]],
      1
    ];
    exports2.GetFunctionUrlConfigResponse$ = [
      3,
      n032,
      _GFUCRe,
      0,
      [_FU, _FA, _AT13, _CTr, _LMT, _Co, _IM],
      [0, 0, 0, 0, 0, () => exports2.Cors$, 0],
      5
    ];
    exports2.GetLayerVersionByArnRequest$ = [
      3,
      n032,
      _GLVBAR,
      0,
      [_Arn],
      [[0, { [_hQ10]: _Arn }]],
      1
    ];
    exports2.GetLayerVersionPolicyRequest$ = [
      3,
      n032,
      _GLVPR,
      0,
      [_LN, _VN],
      [[0, 1], [1, 1]],
      2
    ];
    exports2.GetLayerVersionPolicyResponse$ = [
      3,
      n032,
      _GLVPRe,
      0,
      [_Po, _RI],
      [0, 0]
    ];
    exports2.GetLayerVersionRequest$ = [
      3,
      n032,
      _GLVR,
      0,
      [_LN, _VN],
      [[0, 1], [1, 1]],
      2
    ];
    exports2.GetLayerVersionResponse$ = [
      3,
      n032,
      _GLVRe,
      0,
      [_Cont, _LA, _LVA, _D, _CDr, _Ve, _CR, _LI, _CA10],
      [() => exports2.LayerVersionContentOutput$, 0, 0, 0, 0, 1, 64 | 0, 0, 64 | 0]
    ];
    exports2.GetPolicyRequest$ = [
      3,
      n032,
      _GPR,
      0,
      [_FN, _Q],
      [[0, 1], [0, { [_hQ10]: _Q }]],
      1
    ];
    exports2.GetPolicyResponse$ = [
      3,
      n032,
      _GPRe,
      0,
      [_Po, _RI],
      [0, 0]
    ];
    exports2.GetProvisionedConcurrencyConfigRequest$ = [
      3,
      n032,
      _GPCCR,
      0,
      [_FN, _Q],
      [[0, 1], [0, { [_hQ10]: _Q }]],
      2
    ];
    exports2.GetProvisionedConcurrencyConfigResponse$ = [
      3,
      n032,
      _GPCCRe,
      0,
      [_RPCE, _APCE, _APCEl, _Sta, _SRt, _LM2],
      [1, 1, 1, 0, 0, 0]
    ];
    exports2.GetRuntimeManagementConfigRequest$ = [
      3,
      n032,
      _GRMCR,
      0,
      [_FN, _Q],
      [[0, 1], [0, { [_hQ10]: _Q }]],
      1
    ];
    exports2.GetRuntimeManagementConfigResponse$ = [
      3,
      n032,
      _GRMCRe,
      0,
      [_URO, _RVA, _FA],
      [0, 0, 0]
    ];
    exports2.ImageConfig$ = [
      3,
      n032,
      _IC,
      0,
      [_EP, _Com, _WD],
      [64 | 0, 64 | 0, 0]
    ];
    exports2.ImageConfigError$ = [
      3,
      n032,
      _ICE4,
      0,
      [_EC, _M],
      [0, [() => SensitiveString, 0]]
    ];
    exports2.ImageConfigResponse$ = [
      3,
      n032,
      _ICR,
      0,
      [_IC, _E11],
      [() => exports2.ImageConfig$, [() => exports2.ImageConfigError$, 0]]
    ];
    exports2.InstanceRequirements$ = [
      3,
      n032,
      _IR,
      0,
      [_Ar, _AIT, _EIT],
      [64 | 0, 64 | 0, 64 | 0]
    ];
    exports2.InvocationCompletedDetails$ = [
      3,
      n032,
      _ICD,
      0,
      [_STt, _ETn, _RIe, _E11],
      [4, 4, 0, [() => exports2.EventError$, 0]],
      3
    ];
    exports2.InvocationRequest$ = [
      3,
      n032,
      _IRn,
      0,
      [_FN, _IT4, _LT, _CC, _DEN, _Pa, _Q, _TI],
      [[0, 1], [0, { [_hH10]: _XAIT }], [0, { [_hH10]: _XALT }], [0, { [_hH10]: _XACC }], [0, { [_hH10]: _XADEN }], [() => _Blob, 16], [0, { [_hQ10]: _Q }], [0, { [_hH10]: _XATI }]],
      1
    ];
    exports2.InvocationResponse$ = [
      3,
      n032,
      _IRnv,
      0,
      [_SCt, _FE, _LR, _Pa, _EV, _DEA],
      [[1, 32], [0, { [_hH10]: _XAFE }], [0, { [_hH10]: _XALR }], [() => _Blob, 16], [0, { [_hH10]: _XAEV }], [0, { [_hH10]: _XADEA }]]
    ];
    exports2.InvokeAsyncRequest$ = [
      3,
      n032,
      _IAR,
      0,
      [_FN, _IA],
      [[0, 1], [() => BlobStream, 16]],
      2
    ];
    exports2.InvokeAsyncResponse$ = [
      3,
      n032,
      _IARn,
      0,
      [_Sta],
      [[1, 32]]
    ];
    exports2.InvokeResponseStreamUpdate$ = [
      3,
      n032,
      _IRSU,
      0,
      [_Pa],
      [[() => _Blob, { [_eP]: 1 }]]
    ];
    exports2.InvokeWithResponseStreamCompleteEvent$ = [
      3,
      n032,
      _IWRSCE,
      0,
      [_EC, _EDr, _LR],
      [0, 0, 0]
    ];
    exports2.InvokeWithResponseStreamRequest$ = [
      3,
      n032,
      _IWRSR,
      0,
      [_FN, _IT4, _LT, _CC, _Q, _Pa, _TI],
      [[0, 1], [0, { [_hH10]: _XAIT }], [0, { [_hH10]: _XALT }], [0, { [_hH10]: _XACC }], [0, { [_hQ10]: _Q }], [() => _Blob, 16], [0, { [_hH10]: _XATI }]],
      1
    ];
    exports2.InvokeWithResponseStreamResponse$ = [
      3,
      n032,
      _IWRSRn,
      0,
      [_SCt, _EV, _ESv, _RSCT],
      [[1, 32], [0, { [_hH10]: _XAEV }], [() => exports2.InvokeWithResponseStreamResponseEvent$, 16], [0, { [_hH10]: _CT_ }]]
    ];
    exports2.KafkaSchemaRegistryAccessConfig$ = [
      3,
      n032,
      _KSRAC,
      0,
      [_T10, _URI],
      [0, 0]
    ];
    exports2.KafkaSchemaRegistryConfig$ = [
      3,
      n032,
      _KSRC,
      0,
      [_SRURI, _ERF, _ACc, _SVC],
      [0, 0, () => KafkaSchemaRegistryAccessConfigList, () => KafkaSchemaValidationConfigList]
    ];
    exports2.KafkaSchemaValidationConfig$ = [
      3,
      n032,
      _KSVC,
      0,
      [_At],
      [0]
    ];
    exports2.LambdaManagedInstancesCapacityProviderConfig$ = [
      3,
      n032,
      _LMICPC,
      0,
      [_CPA, _PEEMC, _EEMGBPVC],
      [0, 1, 1],
      1
    ];
    exports2.Layer$ = [
      3,
      n032,
      _La,
      0,
      [_Arn, _CS4, _SPVAi, _SJA],
      [0, 1, 0, 0]
    ];
    exports2.LayersListItem$ = [
      3,
      n032,
      _LLI,
      0,
      [_LN, _LA, _LMV],
      [0, 0, () => exports2.LayerVersionsListItem$]
    ];
    exports2.LayerVersionContentInput$ = [
      3,
      n032,
      _LVCI,
      0,
      [_SB, _SK2, _SOV, _ZF],
      [0, 0, 0, [() => _Blob, 0]]
    ];
    exports2.LayerVersionContentOutput$ = [
      3,
      n032,
      _LVCO,
      0,
      [_Lo, _CSo, _CS4, _SPVAi, _SJA],
      [0, 0, 1, 0, 0]
    ];
    exports2.LayerVersionsListItem$ = [
      3,
      n032,
      _LVLI,
      0,
      [_LVA, _Ve, _D, _CDr, _CR, _LI, _CA10],
      [0, 1, 0, 0, 64 | 0, 0, 64 | 0]
    ];
    exports2.ListAliasesRequest$ = [
      3,
      n032,
      _LAR,
      0,
      [_FN, _FV, _Ma, _MI],
      [[0, 1], [0, { [_hQ10]: _FV }], [0, { [_hQ10]: _Ma }], [1, { [_hQ10]: _MI }]],
      1
    ];
    exports2.ListAliasesResponse$ = [
      3,
      n032,
      _LARi,
      0,
      [_NM, _Al],
      [0, () => AliasList]
    ];
    exports2.ListCapacityProvidersRequest$ = [
      3,
      n032,
      _LCPR,
      0,
      [_St, _Ma, _MI],
      [[0, { [_hQ10]: _St }], [0, { [_hQ10]: _Ma }], [1, { [_hQ10]: _MI }]]
    ];
    exports2.ListCapacityProvidersResponse$ = [
      3,
      n032,
      _LCPRi,
      0,
      [_CPa, _NM],
      [() => CapacityProvidersList, 0],
      1
    ];
    exports2.ListCodeSigningConfigsRequest$ = [
      3,
      n032,
      _LCSCR,
      0,
      [_Ma, _MI],
      [[0, { [_hQ10]: _Ma }], [1, { [_hQ10]: _MI }]]
    ];
    exports2.ListCodeSigningConfigsResponse$ = [
      3,
      n032,
      _LCSCRi,
      0,
      [_NM, _CSCo],
      [0, () => CodeSigningConfigList]
    ];
    exports2.ListDurableExecutionsByFunctionRequest$ = [
      3,
      n032,
      _LDEBFR,
      0,
      [_FN, _Q, _DEN, _Stat, _SAt, _SBt, _RO, _Ma, _MI],
      [[0, 1], [0, { [_hQ10]: _Q }], [0, { [_hQ10]: _DEN }], [64 | 0, { [_hQ10]: _Stat }], [4, { [_hQ10]: _SAt }], [4, { [_hQ10]: _SBt }], [2, { [_hQ10]: _RO }], [0, { [_hQ10]: _Ma }], [1, { [_hQ10]: _MI }]],
      1
    ];
    exports2.ListDurableExecutionsByFunctionResponse$ = [
      3,
      n032,
      _LDEBFRi,
      0,
      [_DE, _NM],
      [() => DurableExecutions, 0]
    ];
    exports2.ListEventSourceMappingsRequest$ = [
      3,
      n032,
      _LESMR,
      0,
      [_ESA, _FN, _Ma, _MI],
      [[0, { [_hQ10]: _ESA }], [0, { [_hQ10]: _FN }], [0, { [_hQ10]: _Ma }], [1, { [_hQ10]: _MI }]]
    ];
    exports2.ListEventSourceMappingsResponse$ = [
      3,
      n032,
      _LESMRi,
      0,
      [_NM, _ESM],
      [0, () => EventSourceMappingsList]
    ];
    exports2.ListFunctionEventInvokeConfigsRequest$ = [
      3,
      n032,
      _LFEICR,
      0,
      [_FN, _Ma, _MI],
      [[0, 1], [0, { [_hQ10]: _Ma }], [1, { [_hQ10]: _MI }]],
      1
    ];
    exports2.ListFunctionEventInvokeConfigsResponse$ = [
      3,
      n032,
      _LFEICRi,
      0,
      [_FEICu, _NM],
      [() => FunctionEventInvokeConfigList, 0]
    ];
    exports2.ListFunctionsByCodeSigningConfigRequest$ = [
      3,
      n032,
      _LFBCSCR,
      0,
      [_CSCA, _Ma, _MI],
      [[0, 1], [0, { [_hQ10]: _Ma }], [1, { [_hQ10]: _MI }]],
      1
    ];
    exports2.ListFunctionsByCodeSigningConfigResponse$ = [
      3,
      n032,
      _LFBCSCRi,
      0,
      [_NM, _FAu],
      [0, 64 | 0]
    ];
    exports2.ListFunctionsRequest$ = [
      3,
      n032,
      _LFR,
      0,
      [_MR, _FV, _Ma, _MI],
      [[0, { [_hQ10]: _MR }], [0, { [_hQ10]: _FV }], [0, { [_hQ10]: _Ma }], [1, { [_hQ10]: _MI }]]
    ];
    exports2.ListFunctionsResponse$ = [
      3,
      n032,
      _LFRi,
      0,
      [_NM, _Fu],
      [0, [() => FunctionList, 0]]
    ];
    exports2.ListFunctionUrlConfigsRequest$ = [
      3,
      n032,
      _LFUCR,
      0,
      [_FN, _Ma, _MI],
      [[0, 1], [0, { [_hQ10]: _Ma }], [1, { [_hQ10]: _MI }]],
      1
    ];
    exports2.ListFunctionUrlConfigsResponse$ = [
      3,
      n032,
      _LFUCRi,
      0,
      [_FUCu, _NM],
      [() => FunctionUrlConfigList, 0],
      1
    ];
    exports2.ListFunctionVersionsByCapacityProviderRequest$ = [
      3,
      n032,
      _LFVBCPR,
      0,
      [_CPN, _Ma, _MI],
      [[0, 1], [0, { [_hQ10]: _Ma }], [1, { [_hQ10]: _MI }]],
      1
    ];
    exports2.ListFunctionVersionsByCapacityProviderResponse$ = [
      3,
      n032,
      _LFVBCPRi,
      0,
      [_CPA, _FVu, _NM],
      [0, () => FunctionVersionsByCapacityProviderList, 0],
      2
    ];
    exports2.ListLayersRequest$ = [
      3,
      n032,
      _LLR,
      0,
      [_CRo, _Ma, _MI, _CAo],
      [[0, { [_hQ10]: _CRo }], [0, { [_hQ10]: _Ma }], [1, { [_hQ10]: _MI }], [0, { [_hQ10]: _CAo }]]
    ];
    exports2.ListLayersResponse$ = [
      3,
      n032,
      _LLRi,
      0,
      [_NM, _L2],
      [0, () => LayersList]
    ];
    exports2.ListLayerVersionsRequest$ = [
      3,
      n032,
      _LLVR,
      0,
      [_LN, _CRo, _Ma, _MI, _CAo],
      [[0, 1], [0, { [_hQ10]: _CRo }], [0, { [_hQ10]: _Ma }], [1, { [_hQ10]: _MI }], [0, { [_hQ10]: _CAo }]],
      1
    ];
    exports2.ListLayerVersionsResponse$ = [
      3,
      n032,
      _LLVRi,
      0,
      [_NM, _LV],
      [0, () => LayerVersionsList]
    ];
    exports2.ListProvisionedConcurrencyConfigsRequest$ = [
      3,
      n032,
      _LPCCR,
      0,
      [_FN, _Ma, _MI],
      [[0, 1], [0, { [_hQ10]: _Ma }], [1, { [_hQ10]: _MI }]],
      1
    ];
    exports2.ListProvisionedConcurrencyConfigsResponse$ = [
      3,
      n032,
      _LPCCRi,
      0,
      [_PCC, _NM],
      [() => ProvisionedConcurrencyConfigList, 0]
    ];
    exports2.ListTagsRequest$ = [
      3,
      n032,
      _LTR,
      0,
      [_Res],
      [[0, 1]],
      1
    ];
    exports2.ListTagsResponse$ = [
      3,
      n032,
      _LTRi,
      0,
      [_Ta10],
      [128 | 0]
    ];
    exports2.ListVersionsByFunctionRequest$ = [
      3,
      n032,
      _LVBFR,
      0,
      [_FN, _Ma, _MI],
      [[0, 1], [0, { [_hQ10]: _Ma }], [1, { [_hQ10]: _MI }]],
      1
    ];
    exports2.ListVersionsByFunctionResponse$ = [
      3,
      n032,
      _LVBFRi,
      0,
      [_NM, _Ver],
      [0, [() => FunctionList, 0]]
    ];
    exports2.LoggingConfig$ = [
      3,
      n032,
      _LC,
      0,
      [_LF, _ALL, _SLL, _LG],
      [0, 0, 0, 0]
    ];
    exports2.OnFailure$ = [
      3,
      n032,
      _OF,
      0,
      [_De],
      [0]
    ];
    exports2.OnSuccess$ = [
      3,
      n032,
      _OS,
      0,
      [_De],
      [0]
    ];
    exports2.Operation$ = [
      3,
      n032,
      _Op,
      0,
      [_Id, _T10, _STt, _Sta, _PI10, _N, _STu, _ETn, _EDx, _CDo, _SD, _WDa, _CD, _CID],
      [0, 0, 4, 0, 0, 0, 0, 4, [() => exports2.ExecutionDetails$, 0], [() => exports2.ContextDetails$, 0], [() => exports2.StepDetails$, 0], () => exports2.WaitDetails$, [() => exports2.CallbackDetails$, 0], [() => exports2.ChainedInvokeDetails$, 0]],
      4
    ];
    exports2.OperationUpdate$ = [
      3,
      n032,
      _OU,
      0,
      [_Id, _T10, _A10, _PI10, _N, _STu, _Pa, _E11, _COo, _SO, _WO, _CO, _CIO],
      [0, 0, 0, 0, 0, 0, [() => OperationPayload, 0], [() => exports2.ErrorObject$, 0], () => exports2.ContextOptions$, () => exports2.StepOptions$, () => exports2.WaitOptions$, () => exports2.CallbackOptions$, () => exports2.ChainedInvokeOptions$],
      3
    ];
    exports2.ProvisionedConcurrencyConfigListItem$ = [
      3,
      n032,
      _PCCLI,
      0,
      [_FA, _RPCE, _APCE, _APCEl, _Sta, _SRt, _LM2],
      [0, 1, 1, 1, 0, 0, 0]
    ];
    exports2.ProvisionedPollerConfig$ = [
      3,
      n032,
      _PPC,
      0,
      [_MP, _MPa, _PGN],
      [1, 1, 0]
    ];
    exports2.PublishLayerVersionRequest$ = [
      3,
      n032,
      _PLVR,
      0,
      [_LN, _Cont, _D, _CR, _LI, _CA10],
      [[0, 1], [() => exports2.LayerVersionContentInput$, 0], 0, 64 | 0, 0, 64 | 0],
      2
    ];
    exports2.PublishLayerVersionResponse$ = [
      3,
      n032,
      _PLVRu,
      0,
      [_Cont, _LA, _LVA, _D, _CDr, _Ve, _CR, _LI, _CA10],
      [() => exports2.LayerVersionContentOutput$, 0, 0, 0, 0, 1, 64 | 0, 0, 64 | 0]
    ];
    exports2.PublishVersionRequest$ = [
      3,
      n032,
      _PVR,
      0,
      [_FN, _CSo, _D, _RI, _PTu],
      [[0, 1], 0, 0, 0, 0],
      1
    ];
    exports2.PutFunctionCodeSigningConfigRequest$ = [
      3,
      n032,
      _PFCSCR,
      0,
      [_CSCA, _FN],
      [0, [0, 1]],
      2
    ];
    exports2.PutFunctionCodeSigningConfigResponse$ = [
      3,
      n032,
      _PFCSCRu,
      0,
      [_CSCA, _FN],
      [0, 0],
      2
    ];
    exports2.PutFunctionConcurrencyRequest$ = [
      3,
      n032,
      _PFCR,
      0,
      [_FN, _RCEe],
      [[0, 1], 1],
      2
    ];
    exports2.PutFunctionEventInvokeConfigRequest$ = [
      3,
      n032,
      _PFEICR,
      0,
      [_FN, _Q, _MRA, _MEAIS, _DC],
      [[0, 1], [0, { [_hQ10]: _Q }], 1, 1, () => exports2.DestinationConfig$],
      1
    ];
    exports2.PutFunctionRecursionConfigRequest$ = [
      3,
      n032,
      _PFRCR,
      0,
      [_FN, _RL],
      [[0, 1], 0],
      2
    ];
    exports2.PutFunctionRecursionConfigResponse$ = [
      3,
      n032,
      _PFRCRu,
      0,
      [_RL],
      [0]
    ];
    exports2.PutFunctionScalingConfigRequest$ = [
      3,
      n032,
      _PFSCR,
      0,
      [_FN, _Q, _FSCu],
      [[0, 1], [0, { [_hQ10]: _Q }], () => exports2.FunctionScalingConfig$],
      2
    ];
    exports2.PutFunctionScalingConfigResponse$ = [
      3,
      n032,
      _PFSCRu,
      0,
      [_FS],
      [0]
    ];
    exports2.PutProvisionedConcurrencyConfigRequest$ = [
      3,
      n032,
      _PPCCR,
      0,
      [_FN, _Q, _PCE],
      [[0, 1], [0, { [_hQ10]: _Q }], 1],
      3
    ];
    exports2.PutProvisionedConcurrencyConfigResponse$ = [
      3,
      n032,
      _PPCCRu,
      0,
      [_RPCE, _APCE, _APCEl, _Sta, _SRt, _LM2],
      [1, 1, 1, 0, 0, 0]
    ];
    exports2.PutRuntimeManagementConfigRequest$ = [
      3,
      n032,
      _PRMCR,
      0,
      [_FN, _URO, _Q, _RVA],
      [[0, 1], 0, [0, { [_hQ10]: _Q }], 0],
      2
    ];
    exports2.PutRuntimeManagementConfigResponse$ = [
      3,
      n032,
      _PRMCRu,
      0,
      [_URO, _FA, _RVA],
      [0, 0, 0],
      2
    ];
    exports2.RemoveLayerVersionPermissionRequest$ = [
      3,
      n032,
      _RLVPR,
      0,
      [_LN, _VN, _SI10, _RI],
      [[0, 1], [1, 1], [0, 1], [0, { [_hQ10]: _RI }]],
      3
    ];
    exports2.RemovePermissionRequest$ = [
      3,
      n032,
      _RPR,
      0,
      [_FN, _SI10, _Q, _RI],
      [[0, 1], [0, 1], [0, { [_hQ10]: _Q }], [0, { [_hQ10]: _RI }]],
      2
    ];
    exports2.RetryDetails$ = [
      3,
      n032,
      _RD,
      0,
      [_CAu, _NADS],
      [1, 1]
    ];
    exports2.RuntimeVersionConfig$ = [
      3,
      n032,
      _RVC,
      0,
      [_RVA, _E11],
      [0, [() => exports2.RuntimeVersionError$, 0]]
    ];
    exports2.RuntimeVersionError$ = [
      3,
      n032,
      _RVE,
      0,
      [_EC, _M],
      [0, [() => SensitiveString, 0]]
    ];
    exports2.ScalingConfig$ = [
      3,
      n032,
      _SC,
      0,
      [_MCa],
      [1]
    ];
    exports2.SelfManagedEventSource$ = [
      3,
      n032,
      _SMES,
      0,
      [_End],
      [[2, n032, _End, 0, 0, 64 | 0]]
    ];
    exports2.SelfManagedKafkaEventSourceConfig$ = [
      3,
      n032,
      _SMKESC,
      0,
      [_CGI, _SRC],
      [0, () => exports2.KafkaSchemaRegistryConfig$]
    ];
    exports2.SendDurableExecutionCallbackFailureRequest$ = [
      3,
      n032,
      _SDECFR,
      0,
      [_CI, _E11],
      [[0, 1], [() => exports2.ErrorObject$, 16]],
      1
    ];
    exports2.SendDurableExecutionCallbackFailureResponse$ = [
      3,
      n032,
      _SDECFRe,
      0,
      [],
      []
    ];
    exports2.SendDurableExecutionCallbackHeartbeatRequest$ = [
      3,
      n032,
      _SDECHR,
      0,
      [_CI],
      [[0, 1]],
      1
    ];
    exports2.SendDurableExecutionCallbackHeartbeatResponse$ = [
      3,
      n032,
      _SDECHRe,
      0,
      [],
      []
    ];
    exports2.SendDurableExecutionCallbackSuccessRequest$ = [
      3,
      n032,
      _SDECSR,
      0,
      [_CI, _Re],
      [[0, 1], [() => BinaryOperationPayload, 16]],
      1
    ];
    exports2.SendDurableExecutionCallbackSuccessResponse$ = [
      3,
      n032,
      _SDECSRe,
      0,
      [],
      []
    ];
    exports2.SnapStart$ = [
      3,
      n032,
      _SSn,
      0,
      [_AOp],
      [0]
    ];
    exports2.SnapStartResponse$ = [
      3,
      n032,
      _SSR,
      0,
      [_AOp, _OSp],
      [0, 0]
    ];
    exports2.SourceAccessConfiguration$ = [
      3,
      n032,
      _SACo,
      0,
      [_T10, _URI],
      [0, 0]
    ];
    exports2.StepDetails$ = [
      3,
      n032,
      _SD,
      0,
      [_Att, _NAT, _Re, _E11],
      [1, 4, [() => OperationPayload, 0], [() => exports2.ErrorObject$, 0]]
    ];
    exports2.StepFailedDetails$ = [
      3,
      n032,
      _SFD,
      0,
      [_E11, _RD],
      [[() => exports2.EventError$, 0], () => exports2.RetryDetails$],
      2
    ];
    exports2.StepOptions$ = [
      3,
      n032,
      _SO,
      0,
      [_NADS],
      [1]
    ];
    exports2.StepStartedDetails$ = [
      3,
      n032,
      _SSD,
      0,
      [],
      []
    ];
    exports2.StepSucceededDetails$ = [
      3,
      n032,
      _SSDt,
      0,
      [_Re, _RD],
      [[() => exports2.EventResult$, 0], () => exports2.RetryDetails$],
      2
    ];
    exports2.StopDurableExecutionRequest$ = [
      3,
      n032,
      _SDER,
      0,
      [_DEA, _E11],
      [[0, 1], [() => exports2.ErrorObject$, 16]],
      1
    ];
    exports2.StopDurableExecutionResponse$ = [
      3,
      n032,
      _SDERt,
      0,
      [_STto],
      [4],
      1
    ];
    exports2.TagResourceRequest$ = [
      3,
      n032,
      _TRR,
      0,
      [_Res, _Ta10],
      [[0, 1], 128 | 0],
      2
    ];
    exports2.TagsError$ = [
      3,
      n032,
      _TE,
      0,
      [_EC, _M],
      [0, 0],
      2
    ];
    exports2.TargetTrackingScalingPolicy$ = [
      3,
      n032,
      _TTSP,
      0,
      [_PMT, _TV],
      [0, 1],
      2
    ];
    exports2.TenancyConfig$ = [
      3,
      n032,
      _TCe,
      0,
      [_TIM],
      [0],
      1
    ];
    exports2.TraceHeader$ = [
      3,
      n032,
      _TH,
      0,
      [_XATIm],
      [0]
    ];
    exports2.TracingConfig$ = [
      3,
      n032,
      _TC10,
      0,
      [_Mo],
      [0]
    ];
    exports2.TracingConfigResponse$ = [
      3,
      n032,
      _TCR,
      0,
      [_Mo],
      [0]
    ];
    exports2.UntagResourceRequest$ = [
      3,
      n032,
      _URR,
      0,
      [_Res, _TK],
      [[0, 1], [64 | 0, { [_hQ10]: _tK }]],
      2
    ];
    exports2.UpdateAliasRequest$ = [
      3,
      n032,
      _UAR,
      0,
      [_FN, _N, _FV, _D, _RC10, _RI],
      [[0, 1], [0, 1], 0, 0, () => exports2.AliasRoutingConfiguration$, 0],
      2
    ];
    exports2.UpdateCapacityProviderRequest$ = [
      3,
      n032,
      _UCPR,
      0,
      [_CPN, _CPSC],
      [[0, 1], () => exports2.CapacityProviderScalingConfig$],
      1
    ];
    exports2.UpdateCapacityProviderResponse$ = [
      3,
      n032,
      _UCPRp,
      0,
      [_CP],
      [() => exports2.CapacityProvider$],
      1
    ];
    exports2.UpdateCodeSigningConfigRequest$ = [
      3,
      n032,
      _UCSCR,
      0,
      [_CSCA, _D, _AP, _CSP],
      [[0, 1], 0, () => exports2.AllowedPublishers$, () => exports2.CodeSigningPolicies$],
      1
    ];
    exports2.UpdateCodeSigningConfigResponse$ = [
      3,
      n032,
      _UCSCRp,
      0,
      [_CSC],
      [() => exports2.CodeSigningConfig$],
      1
    ];
    exports2.UpdateEventSourceMappingRequest$ = [
      3,
      n032,
      _UESMR,
      0,
      [_UUID, _FN, _En, _BSa, _FCi, _MBWIS, _DC, _MRAIS, _BBOFE, _MRA, _PF, _SAC, _TWIS, _FRT, _SC, _AMKESC, _SMKESC, _DDBESC, _KMSKA, _MC, _LC, _PPC],
      [[0, 1], 0, 2, 1, () => exports2.FilterCriteria$, 1, () => exports2.DestinationConfig$, 1, 2, 1, 1, () => SourceAccessConfigurations, 1, 64 | 0, () => exports2.ScalingConfig$, () => exports2.AmazonManagedKafkaEventSourceConfig$, () => exports2.SelfManagedKafkaEventSourceConfig$, () => exports2.DocumentDBEventSourceConfig$, 0, () => exports2.EventSourceMappingMetricsConfig$, () => exports2.EventSourceMappingLoggingConfig$, () => exports2.ProvisionedPollerConfig$],
      1
    ];
    exports2.UpdateFunctionCodeRequest$ = [
      3,
      n032,
      _UFCR,
      0,
      [_FN, _ZF, _SB, _SK2, _SOV, _IU, _Pu, _DR, _RI, _Ar, _SKMSKA, _PTu],
      [[0, 1], [() => _Blob, 0], 0, 0, 0, 0, 2, 2, 0, 64 | 0, 0, 0],
      1
    ];
    exports2.UpdateFunctionConfigurationRequest$ = [
      3,
      n032,
      _UFCRp,
      0,
      [_FN, _Ro, _H, _D, _Ti, _MS, _VC, _Env, _Ru, _DLC, _KMSKA, _TC10, _RI, _L2, _FSC, _IC, _ES, _SSn, _LC, _CPC, _DCu],
      [[0, 1], 0, 0, 0, 1, 1, () => exports2.VpcConfig$, [() => exports2.Environment$, 0], 0, () => exports2.DeadLetterConfig$, 0, () => exports2.TracingConfig$, 0, 64 | 0, () => FileSystemConfigList, () => exports2.ImageConfig$, () => exports2.EphemeralStorage$, () => exports2.SnapStart$, () => exports2.LoggingConfig$, () => exports2.CapacityProviderConfig$, () => exports2.DurableConfig$],
      1
    ];
    exports2.UpdateFunctionEventInvokeConfigRequest$ = [
      3,
      n032,
      _UFEICR,
      0,
      [_FN, _Q, _MRA, _MEAIS, _DC],
      [[0, 1], [0, { [_hQ10]: _Q }], 1, 1, () => exports2.DestinationConfig$],
      1
    ];
    exports2.UpdateFunctionUrlConfigRequest$ = [
      3,
      n032,
      _UFUCR,
      0,
      [_FN, _Q, _AT13, _Co, _IM],
      [[0, 1], [0, { [_hQ10]: _Q }], 0, () => exports2.Cors$, 0],
      1
    ];
    exports2.UpdateFunctionUrlConfigResponse$ = [
      3,
      n032,
      _UFUCRp,
      0,
      [_FU, _FA, _AT13, _CTr, _LMT, _Co, _IM],
      [0, 0, 0, 0, 0, () => exports2.Cors$, 0],
      5
    ];
    exports2.VpcConfig$ = [
      3,
      n032,
      _VC,
      0,
      [_SIu, _SGI, _IAFDS],
      [64 | 0, 64 | 0, 2]
    ];
    exports2.VpcConfigResponse$ = [
      3,
      n032,
      _VCR,
      0,
      [_SIu, _SGI, _VI, _IAFDS],
      [64 | 0, 64 | 0, 0, 2]
    ];
    exports2.WaitCancelledDetails$ = [
      3,
      n032,
      _WCD,
      0,
      [_E11],
      [[() => exports2.EventError$, 0]]
    ];
    exports2.WaitDetails$ = [
      3,
      n032,
      _WDa,
      0,
      [_SET],
      [4]
    ];
    exports2.WaitOptions$ = [
      3,
      n032,
      _WO,
      0,
      [_WS],
      [1]
    ];
    exports2.WaitStartedDetails$ = [
      3,
      n032,
      _WSD,
      0,
      [_Du, _SET],
      [1, 4],
      2
    ];
    exports2.WaitSucceededDetails$ = [
      3,
      n032,
      _WSDa,
      0,
      [_Du],
      [1]
    ];
    var __Unit = "unit";
    var AliasList = [
      1,
      n032,
      _ALl,
      0,
      () => exports2.AliasConfiguration$
    ];
    var AllowMethodsList = 64 | 0;
    var AllowOriginsList = 64 | 0;
    var ArchitecturesList = 64 | 0;
    var CapacityProviderScalingPoliciesList = [
      1,
      n032,
      _CPSPL,
      0,
      () => exports2.TargetTrackingScalingPolicy$
    ];
    var CapacityProviderSecurityGroupIds = 64 | 0;
    var CapacityProvidersList = [
      1,
      n032,
      _CPL,
      0,
      () => exports2.CapacityProvider$
    ];
    var CapacityProviderSubnetIds = 64 | 0;
    var CodeSigningConfigList = [
      1,
      n032,
      _CSCL,
      0,
      () => exports2.CodeSigningConfig$
    ];
    var CompatibleArchitectures = 64 | 0;
    var CompatibleRuntimes = 64 | 0;
    var DurableExecutions = [
      1,
      n032,
      _DE,
      0,
      () => exports2.Execution$
    ];
    var EndpointLists = 64 | 0;
    var Events = [
      1,
      n032,
      _Eve,
      0,
      [
        () => exports2.Event$,
        0
      ]
    ];
    var EventSourceMappingMetricList = 64 | 0;
    var EventSourceMappingsList = [
      1,
      n032,
      _ESML,
      0,
      () => exports2.EventSourceMappingConfiguration$
    ];
    var ExecutionStatusList = 64 | 0;
    var FileSystemConfigList = [
      1,
      n032,
      _FSCL,
      0,
      () => exports2.FileSystemConfig$
    ];
    var FilterList = [
      1,
      n032,
      _FL,
      0,
      () => exports2.Filter$
    ];
    var FunctionArnList = 64 | 0;
    var FunctionEventInvokeConfigList = [
      1,
      n032,
      _FEICL,
      0,
      () => exports2.FunctionEventInvokeConfig$
    ];
    var FunctionList = [
      1,
      n032,
      _FLu,
      0,
      [
        () => exports2.FunctionConfiguration$,
        0
      ]
    ];
    var FunctionResponseTypeList = 64 | 0;
    var FunctionUrlConfigList = [
      1,
      n032,
      _FUCL,
      0,
      () => exports2.FunctionUrlConfig$
    ];
    var FunctionVersionsByCapacityProviderList = [
      1,
      n032,
      _FVBCPL,
      0,
      () => exports2.FunctionVersionsByCapacityProviderListItem$
    ];
    var HeadersList = 64 | 0;
    var InstanceTypeSet = 64 | 0;
    var KafkaSchemaRegistryAccessConfigList = [
      1,
      n032,
      _KSRACL,
      0,
      () => exports2.KafkaSchemaRegistryAccessConfig$
    ];
    var KafkaSchemaValidationConfigList = [
      1,
      n032,
      _KSVCL,
      0,
      () => exports2.KafkaSchemaValidationConfig$
    ];
    var LayerList = 64 | 0;
    var LayersList = [
      1,
      n032,
      _LL,
      0,
      () => exports2.LayersListItem$
    ];
    var LayersReferenceList = [
      1,
      n032,
      _LRL,
      0,
      () => exports2.Layer$
    ];
    var LayerVersionsList = [
      1,
      n032,
      _LVL,
      0,
      () => exports2.LayerVersionsListItem$
    ];
    var Operations = [
      1,
      n032,
      _O,
      0,
      [
        () => exports2.Operation$,
        0
      ]
    ];
    var OperationUpdates = [
      1,
      n032,
      _OUp,
      0,
      [
        () => exports2.OperationUpdate$,
        0
      ]
    ];
    var ProvisionedConcurrencyConfigList = [
      1,
      n032,
      _PCCL,
      0,
      () => exports2.ProvisionedConcurrencyConfigListItem$
    ];
    var Queues = 64 | 0;
    var SecurityGroupIds = 64 | 0;
    var SigningProfileVersionArns = 64 | 0;
    var SourceAccessConfigurations = [
      1,
      n032,
      _SAC,
      0,
      () => exports2.SourceAccessConfiguration$
    ];
    var StackTraceEntries = [
      1,
      n032,
      _STEt,
      0,
      [
        () => StackTraceEntry,
        0
      ]
    ];
    var StringList = 64 | 0;
    var SubnetIds = 64 | 0;
    var TagKeyList = 64 | 0;
    var Topics = 64 | 0;
    var AdditionalVersionWeights = 128 | 1;
    var Endpoints = [
      2,
      n032,
      _End,
      0,
      0,
      64 | 0
    ];
    var EnvironmentVariables = [
      2,
      n032,
      _EVn,
      8,
      [
        () => EnvironmentVariableName,
        0
      ],
      [
        () => EnvironmentVariableValue,
        0
      ]
    ];
    var Tags = 128 | 0;
    exports2.InvokeWithResponseStreamResponseEvent$ = [
      4,
      n032,
      _IWRSRE,
      { [_st]: 1 },
      [_PCa, _ICn],
      [[() => exports2.InvokeResponseStreamUpdate$, 0], () => exports2.InvokeWithResponseStreamCompleteEvent$]
    ];
    exports2.AddLayerVersionPermission$ = [
      9,
      n032,
      _ALVP,
      { [_h22]: ["POST", "/2018-10-31/layers/{LayerName}/versions/{VersionNumber}/policy", 201] },
      () => exports2.AddLayerVersionPermissionRequest$,
      () => exports2.AddLayerVersionPermissionResponse$
    ];
    exports2.AddPermission$ = [
      9,
      n032,
      _APd,
      { [_h22]: ["POST", "/2015-03-31/functions/{FunctionName}/policy", 201] },
      () => exports2.AddPermissionRequest$,
      () => exports2.AddPermissionResponse$
    ];
    exports2.CheckpointDurableExecution$ = [
      9,
      n032,
      _CDE,
      { [_h22]: ["POST", "/2025-12-01/durable-executions/{DurableExecutionArn}/checkpoint", 200] },
      () => exports2.CheckpointDurableExecutionRequest$,
      () => exports2.CheckpointDurableExecutionResponse$
    ];
    exports2.CreateAlias$ = [
      9,
      n032,
      _CAr,
      { [_h22]: ["POST", "/2015-03-31/functions/{FunctionName}/aliases", 201] },
      () => exports2.CreateAliasRequest$,
      () => exports2.AliasConfiguration$
    ];
    exports2.CreateCapacityProvider$ = [
      9,
      n032,
      _CCP,
      { [_h22]: ["POST", "/2025-11-30/capacity-providers", 202] },
      () => exports2.CreateCapacityProviderRequest$,
      () => exports2.CreateCapacityProviderResponse$
    ];
    exports2.CreateCodeSigningConfig$ = [
      9,
      n032,
      _CCSC,
      { [_h22]: ["POST", "/2020-04-22/code-signing-configs", 201] },
      () => exports2.CreateCodeSigningConfigRequest$,
      () => exports2.CreateCodeSigningConfigResponse$
    ];
    exports2.CreateEventSourceMapping$ = [
      9,
      n032,
      _CESM,
      { [_h22]: ["POST", "/2015-03-31/event-source-mappings", 202] },
      () => exports2.CreateEventSourceMappingRequest$,
      () => exports2.EventSourceMappingConfiguration$
    ];
    exports2.CreateFunction$ = [
      9,
      n032,
      _CF,
      { [_h22]: ["POST", "/2015-03-31/functions", 201] },
      () => exports2.CreateFunctionRequest$,
      () => exports2.FunctionConfiguration$
    ];
    exports2.CreateFunctionUrlConfig$ = [
      9,
      n032,
      _CFUC,
      { [_h22]: ["POST", "/2021-10-31/functions/{FunctionName}/url", 201] },
      () => exports2.CreateFunctionUrlConfigRequest$,
      () => exports2.CreateFunctionUrlConfigResponse$
    ];
    exports2.DeleteAlias$ = [
      9,
      n032,
      _DA,
      { [_h22]: ["DELETE", "/2015-03-31/functions/{FunctionName}/aliases/{Name}", 204] },
      () => exports2.DeleteAliasRequest$,
      () => __Unit
    ];
    exports2.DeleteCapacityProvider$ = [
      9,
      n032,
      _DCP,
      { [_h22]: ["DELETE", "/2025-11-30/capacity-providers/{CapacityProviderName}", 202] },
      () => exports2.DeleteCapacityProviderRequest$,
      () => exports2.DeleteCapacityProviderResponse$
    ];
    exports2.DeleteCodeSigningConfig$ = [
      9,
      n032,
      _DCSC,
      { [_h22]: ["DELETE", "/2020-04-22/code-signing-configs/{CodeSigningConfigArn}", 204] },
      () => exports2.DeleteCodeSigningConfigRequest$,
      () => exports2.DeleteCodeSigningConfigResponse$
    ];
    exports2.DeleteEventSourceMapping$ = [
      9,
      n032,
      _DESM,
      { [_h22]: ["DELETE", "/2015-03-31/event-source-mappings/{UUID}", 202] },
      () => exports2.DeleteEventSourceMappingRequest$,
      () => exports2.EventSourceMappingConfiguration$
    ];
    exports2.DeleteFunction$ = [
      9,
      n032,
      _DF,
      { [_h22]: ["DELETE", "/2015-03-31/functions/{FunctionName}", 200] },
      () => exports2.DeleteFunctionRequest$,
      () => exports2.DeleteFunctionResponse$
    ];
    exports2.DeleteFunctionCodeSigningConfig$ = [
      9,
      n032,
      _DFCSC,
      { [_h22]: ["DELETE", "/2020-06-30/functions/{FunctionName}/code-signing-config", 204] },
      () => exports2.DeleteFunctionCodeSigningConfigRequest$,
      () => __Unit
    ];
    exports2.DeleteFunctionConcurrency$ = [
      9,
      n032,
      _DFC,
      { [_h22]: ["DELETE", "/2017-10-31/functions/{FunctionName}/concurrency", 204] },
      () => exports2.DeleteFunctionConcurrencyRequest$,
      () => __Unit
    ];
    exports2.DeleteFunctionEventInvokeConfig$ = [
      9,
      n032,
      _DFEIC,
      { [_h22]: ["DELETE", "/2019-09-25/functions/{FunctionName}/event-invoke-config", 204] },
      () => exports2.DeleteFunctionEventInvokeConfigRequest$,
      () => __Unit
    ];
    exports2.DeleteFunctionUrlConfig$ = [
      9,
      n032,
      _DFUC,
      { [_h22]: ["DELETE", "/2021-10-31/functions/{FunctionName}/url", 204] },
      () => exports2.DeleteFunctionUrlConfigRequest$,
      () => __Unit
    ];
    exports2.DeleteLayerVersion$ = [
      9,
      n032,
      _DLV,
      { [_h22]: ["DELETE", "/2018-10-31/layers/{LayerName}/versions/{VersionNumber}", 204] },
      () => exports2.DeleteLayerVersionRequest$,
      () => __Unit
    ];
    exports2.DeleteProvisionedConcurrencyConfig$ = [
      9,
      n032,
      _DPCC,
      { [_h22]: ["DELETE", "/2019-09-30/functions/{FunctionName}/provisioned-concurrency", 204] },
      () => exports2.DeleteProvisionedConcurrencyConfigRequest$,
      () => __Unit
    ];
    exports2.GetAccountSettings$ = [
      9,
      n032,
      _GAS,
      { [_h22]: ["GET", "/2016-08-19/account-settings", 200] },
      () => exports2.GetAccountSettingsRequest$,
      () => exports2.GetAccountSettingsResponse$
    ];
    exports2.GetAlias$ = [
      9,
      n032,
      _GA,
      { [_h22]: ["GET", "/2015-03-31/functions/{FunctionName}/aliases/{Name}", 200] },
      () => exports2.GetAliasRequest$,
      () => exports2.AliasConfiguration$
    ];
    exports2.GetCapacityProvider$ = [
      9,
      n032,
      _GCP,
      { [_h22]: ["GET", "/2025-11-30/capacity-providers/{CapacityProviderName}", 200] },
      () => exports2.GetCapacityProviderRequest$,
      () => exports2.GetCapacityProviderResponse$
    ];
    exports2.GetCodeSigningConfig$ = [
      9,
      n032,
      _GCSC,
      { [_h22]: ["GET", "/2020-04-22/code-signing-configs/{CodeSigningConfigArn}", 200] },
      () => exports2.GetCodeSigningConfigRequest$,
      () => exports2.GetCodeSigningConfigResponse$
    ];
    exports2.GetDurableExecution$ = [
      9,
      n032,
      _GDE,
      { [_h22]: ["GET", "/2025-12-01/durable-executions/{DurableExecutionArn}", 200] },
      () => exports2.GetDurableExecutionRequest$,
      () => exports2.GetDurableExecutionResponse$
    ];
    exports2.GetDurableExecutionHistory$ = [
      9,
      n032,
      _GDEH,
      { [_h22]: ["GET", "/2025-12-01/durable-executions/{DurableExecutionArn}/history", 200] },
      () => exports2.GetDurableExecutionHistoryRequest$,
      () => exports2.GetDurableExecutionHistoryResponse$
    ];
    exports2.GetDurableExecutionState$ = [
      9,
      n032,
      _GDES,
      { [_h22]: ["GET", "/2025-12-01/durable-executions/{DurableExecutionArn}/state", 200] },
      () => exports2.GetDurableExecutionStateRequest$,
      () => exports2.GetDurableExecutionStateResponse$
    ];
    exports2.GetEventSourceMapping$ = [
      9,
      n032,
      _GESM,
      { [_h22]: ["GET", "/2015-03-31/event-source-mappings/{UUID}", 200] },
      () => exports2.GetEventSourceMappingRequest$,
      () => exports2.EventSourceMappingConfiguration$
    ];
    exports2.GetFunction$ = [
      9,
      n032,
      _GF,
      { [_h22]: ["GET", "/2015-03-31/functions/{FunctionName}", 200] },
      () => exports2.GetFunctionRequest$,
      () => exports2.GetFunctionResponse$
    ];
    exports2.GetFunctionCodeSigningConfig$ = [
      9,
      n032,
      _GFCSC,
      { [_h22]: ["GET", "/2020-06-30/functions/{FunctionName}/code-signing-config", 200] },
      () => exports2.GetFunctionCodeSigningConfigRequest$,
      () => exports2.GetFunctionCodeSigningConfigResponse$
    ];
    exports2.GetFunctionConcurrency$ = [
      9,
      n032,
      _GFC,
      { [_h22]: ["GET", "/2019-09-30/functions/{FunctionName}/concurrency", 200] },
      () => exports2.GetFunctionConcurrencyRequest$,
      () => exports2.GetFunctionConcurrencyResponse$
    ];
    exports2.GetFunctionConfiguration$ = [
      9,
      n032,
      _GFCe,
      { [_h22]: ["GET", "/2015-03-31/functions/{FunctionName}/configuration", 200] },
      () => exports2.GetFunctionConfigurationRequest$,
      () => exports2.FunctionConfiguration$
    ];
    exports2.GetFunctionEventInvokeConfig$ = [
      9,
      n032,
      _GFEIC,
      { [_h22]: ["GET", "/2019-09-25/functions/{FunctionName}/event-invoke-config", 200] },
      () => exports2.GetFunctionEventInvokeConfigRequest$,
      () => exports2.FunctionEventInvokeConfig$
    ];
    exports2.GetFunctionRecursionConfig$ = [
      9,
      n032,
      _GFRC,
      { [_h22]: ["GET", "/2024-08-31/functions/{FunctionName}/recursion-config", 200] },
      () => exports2.GetFunctionRecursionConfigRequest$,
      () => exports2.GetFunctionRecursionConfigResponse$
    ];
    exports2.GetFunctionScalingConfig$ = [
      9,
      n032,
      _GFSC,
      { [_h22]: ["GET", "/2025-11-30/functions/{FunctionName}/function-scaling-config", 200] },
      () => exports2.GetFunctionScalingConfigRequest$,
      () => exports2.GetFunctionScalingConfigResponse$
    ];
    exports2.GetFunctionUrlConfig$ = [
      9,
      n032,
      _GFUC,
      { [_h22]: ["GET", "/2021-10-31/functions/{FunctionName}/url", 200] },
      () => exports2.GetFunctionUrlConfigRequest$,
      () => exports2.GetFunctionUrlConfigResponse$
    ];
    exports2.GetLayerVersion$ = [
      9,
      n032,
      _GLV,
      { [_h22]: ["GET", "/2018-10-31/layers/{LayerName}/versions/{VersionNumber}", 200] },
      () => exports2.GetLayerVersionRequest$,
      () => exports2.GetLayerVersionResponse$
    ];
    exports2.GetLayerVersionByArn$ = [
      9,
      n032,
      _GLVBA,
      { [_h22]: ["GET", "/2018-10-31/layers?find=LayerVersion", 200] },
      () => exports2.GetLayerVersionByArnRequest$,
      () => exports2.GetLayerVersionResponse$
    ];
    exports2.GetLayerVersionPolicy$ = [
      9,
      n032,
      _GLVP,
      { [_h22]: ["GET", "/2018-10-31/layers/{LayerName}/versions/{VersionNumber}/policy", 200] },
      () => exports2.GetLayerVersionPolicyRequest$,
      () => exports2.GetLayerVersionPolicyResponse$
    ];
    exports2.GetPolicy$ = [
      9,
      n032,
      _GP,
      { [_h22]: ["GET", "/2015-03-31/functions/{FunctionName}/policy", 200] },
      () => exports2.GetPolicyRequest$,
      () => exports2.GetPolicyResponse$
    ];
    exports2.GetProvisionedConcurrencyConfig$ = [
      9,
      n032,
      _GPCC,
      { [_h22]: ["GET", "/2019-09-30/functions/{FunctionName}/provisioned-concurrency", 200] },
      () => exports2.GetProvisionedConcurrencyConfigRequest$,
      () => exports2.GetProvisionedConcurrencyConfigResponse$
    ];
    exports2.GetRuntimeManagementConfig$ = [
      9,
      n032,
      _GRMC,
      { [_h22]: ["GET", "/2021-07-20/functions/{FunctionName}/runtime-management-config", 200] },
      () => exports2.GetRuntimeManagementConfigRequest$,
      () => exports2.GetRuntimeManagementConfigResponse$
    ];
    exports2.Invoke$ = [
      9,
      n032,
      _In,
      { [_h22]: ["POST", "/2015-03-31/functions/{FunctionName}/invocations", 200] },
      () => exports2.InvocationRequest$,
      () => exports2.InvocationResponse$
    ];
    exports2.InvokeAsync$ = [
      9,
      n032,
      _IAn,
      { [_h22]: ["POST", "/2014-11-13/functions/{FunctionName}/invoke-async", 202] },
      () => exports2.InvokeAsyncRequest$,
      () => exports2.InvokeAsyncResponse$
    ];
    exports2.InvokeWithResponseStream$ = [
      9,
      n032,
      _IWRS,
      { [_h22]: ["POST", "/2021-11-15/functions/{FunctionName}/response-streaming-invocations", 200] },
      () => exports2.InvokeWithResponseStreamRequest$,
      () => exports2.InvokeWithResponseStreamResponse$
    ];
    exports2.ListAliases$ = [
      9,
      n032,
      _LAi,
      { [_h22]: ["GET", "/2015-03-31/functions/{FunctionName}/aliases", 200] },
      () => exports2.ListAliasesRequest$,
      () => exports2.ListAliasesResponse$
    ];
    exports2.ListCapacityProviders$ = [
      9,
      n032,
      _LCP,
      { [_h22]: ["GET", "/2025-11-30/capacity-providers", 200] },
      () => exports2.ListCapacityProvidersRequest$,
      () => exports2.ListCapacityProvidersResponse$
    ];
    exports2.ListCodeSigningConfigs$ = [
      9,
      n032,
      _LCSC,
      { [_h22]: ["GET", "/2020-04-22/code-signing-configs", 200] },
      () => exports2.ListCodeSigningConfigsRequest$,
      () => exports2.ListCodeSigningConfigsResponse$
    ];
    exports2.ListDurableExecutionsByFunction$ = [
      9,
      n032,
      _LDEBF,
      { [_h22]: ["GET", "/2025-12-01/functions/{FunctionName}/durable-executions", 200] },
      () => exports2.ListDurableExecutionsByFunctionRequest$,
      () => exports2.ListDurableExecutionsByFunctionResponse$
    ];
    exports2.ListEventSourceMappings$ = [
      9,
      n032,
      _LESM,
      { [_h22]: ["GET", "/2015-03-31/event-source-mappings", 200] },
      () => exports2.ListEventSourceMappingsRequest$,
      () => exports2.ListEventSourceMappingsResponse$
    ];
    exports2.ListFunctionEventInvokeConfigs$ = [
      9,
      n032,
      _LFEIC,
      { [_h22]: ["GET", "/2019-09-25/functions/{FunctionName}/event-invoke-config/list", 200] },
      () => exports2.ListFunctionEventInvokeConfigsRequest$,
      () => exports2.ListFunctionEventInvokeConfigsResponse$
    ];
    exports2.ListFunctions$ = [
      9,
      n032,
      _LFi,
      { [_h22]: ["GET", "/2015-03-31/functions", 200] },
      () => exports2.ListFunctionsRequest$,
      () => exports2.ListFunctionsResponse$
    ];
    exports2.ListFunctionsByCodeSigningConfig$ = [
      9,
      n032,
      _LFBCSC,
      { [_h22]: ["GET", "/2020-04-22/code-signing-configs/{CodeSigningConfigArn}/functions", 200] },
      () => exports2.ListFunctionsByCodeSigningConfigRequest$,
      () => exports2.ListFunctionsByCodeSigningConfigResponse$
    ];
    exports2.ListFunctionUrlConfigs$ = [
      9,
      n032,
      _LFUC,
      { [_h22]: ["GET", "/2021-10-31/functions/{FunctionName}/urls", 200] },
      () => exports2.ListFunctionUrlConfigsRequest$,
      () => exports2.ListFunctionUrlConfigsResponse$
    ];
    exports2.ListFunctionVersionsByCapacityProvider$ = [
      9,
      n032,
      _LFVBCP,
      { [_h22]: ["GET", "/2025-11-30/capacity-providers/{CapacityProviderName}/function-versions", 200] },
      () => exports2.ListFunctionVersionsByCapacityProviderRequest$,
      () => exports2.ListFunctionVersionsByCapacityProviderResponse$
    ];
    exports2.ListLayers$ = [
      9,
      n032,
      _LLi,
      { [_h22]: ["GET", "/2018-10-31/layers", 200] },
      () => exports2.ListLayersRequest$,
      () => exports2.ListLayersResponse$
    ];
    exports2.ListLayerVersions$ = [
      9,
      n032,
      _LLV,
      { [_h22]: ["GET", "/2018-10-31/layers/{LayerName}/versions", 200] },
      () => exports2.ListLayerVersionsRequest$,
      () => exports2.ListLayerVersionsResponse$
    ];
    exports2.ListProvisionedConcurrencyConfigs$ = [
      9,
      n032,
      _LPCC,
      { [_h22]: ["GET", "/2019-09-30/functions/{FunctionName}/provisioned-concurrency?List=ALL", 200] },
      () => exports2.ListProvisionedConcurrencyConfigsRequest$,
      () => exports2.ListProvisionedConcurrencyConfigsResponse$
    ];
    exports2.ListTags$ = [
      9,
      n032,
      _LTi,
      { [_h22]: ["GET", "/2017-03-31/tags/{Resource}", 200] },
      () => exports2.ListTagsRequest$,
      () => exports2.ListTagsResponse$
    ];
    exports2.ListVersionsByFunction$ = [
      9,
      n032,
      _LVBF,
      { [_h22]: ["GET", "/2015-03-31/functions/{FunctionName}/versions", 200] },
      () => exports2.ListVersionsByFunctionRequest$,
      () => exports2.ListVersionsByFunctionResponse$
    ];
    exports2.PublishLayerVersion$ = [
      9,
      n032,
      _PLV,
      { [_h22]: ["POST", "/2018-10-31/layers/{LayerName}/versions", 201] },
      () => exports2.PublishLayerVersionRequest$,
      () => exports2.PublishLayerVersionResponse$
    ];
    exports2.PublishVersion$ = [
      9,
      n032,
      _PV,
      { [_h22]: ["POST", "/2015-03-31/functions/{FunctionName}/versions", 201] },
      () => exports2.PublishVersionRequest$,
      () => exports2.FunctionConfiguration$
    ];
    exports2.PutFunctionCodeSigningConfig$ = [
      9,
      n032,
      _PFCSC,
      { [_h22]: ["PUT", "/2020-06-30/functions/{FunctionName}/code-signing-config", 200] },
      () => exports2.PutFunctionCodeSigningConfigRequest$,
      () => exports2.PutFunctionCodeSigningConfigResponse$
    ];
    exports2.PutFunctionConcurrency$ = [
      9,
      n032,
      _PFC,
      { [_h22]: ["PUT", "/2017-10-31/functions/{FunctionName}/concurrency", 200] },
      () => exports2.PutFunctionConcurrencyRequest$,
      () => exports2.Concurrency$
    ];
    exports2.PutFunctionEventInvokeConfig$ = [
      9,
      n032,
      _PFEIC,
      { [_h22]: ["PUT", "/2019-09-25/functions/{FunctionName}/event-invoke-config", 200] },
      () => exports2.PutFunctionEventInvokeConfigRequest$,
      () => exports2.FunctionEventInvokeConfig$
    ];
    exports2.PutFunctionRecursionConfig$ = [
      9,
      n032,
      _PFRC,
      { [_h22]: ["PUT", "/2024-08-31/functions/{FunctionName}/recursion-config", 200] },
      () => exports2.PutFunctionRecursionConfigRequest$,
      () => exports2.PutFunctionRecursionConfigResponse$
    ];
    exports2.PutFunctionScalingConfig$ = [
      9,
      n032,
      _PFSC,
      { [_h22]: ["PUT", "/2025-11-30/functions/{FunctionName}/function-scaling-config", 202] },
      () => exports2.PutFunctionScalingConfigRequest$,
      () => exports2.PutFunctionScalingConfigResponse$
    ];
    exports2.PutProvisionedConcurrencyConfig$ = [
      9,
      n032,
      _PPCC,
      { [_h22]: ["PUT", "/2019-09-30/functions/{FunctionName}/provisioned-concurrency", 202] },
      () => exports2.PutProvisionedConcurrencyConfigRequest$,
      () => exports2.PutProvisionedConcurrencyConfigResponse$
    ];
    exports2.PutRuntimeManagementConfig$ = [
      9,
      n032,
      _PRMC,
      { [_h22]: ["PUT", "/2021-07-20/functions/{FunctionName}/runtime-management-config", 200] },
      () => exports2.PutRuntimeManagementConfigRequest$,
      () => exports2.PutRuntimeManagementConfigResponse$
    ];
    exports2.RemoveLayerVersionPermission$ = [
      9,
      n032,
      _RLVP,
      { [_h22]: ["DELETE", "/2018-10-31/layers/{LayerName}/versions/{VersionNumber}/policy/{StatementId}", 204] },
      () => exports2.RemoveLayerVersionPermissionRequest$,
      () => __Unit
    ];
    exports2.RemovePermission$ = [
      9,
      n032,
      _RP,
      { [_h22]: ["DELETE", "/2015-03-31/functions/{FunctionName}/policy/{StatementId}", 204] },
      () => exports2.RemovePermissionRequest$,
      () => __Unit
    ];
    exports2.SendDurableExecutionCallbackFailure$ = [
      9,
      n032,
      _SDECF,
      { [_h22]: ["POST", "/2025-12-01/durable-execution-callbacks/{CallbackId}/fail", 200] },
      () => exports2.SendDurableExecutionCallbackFailureRequest$,
      () => exports2.SendDurableExecutionCallbackFailureResponse$
    ];
    exports2.SendDurableExecutionCallbackHeartbeat$ = [
      9,
      n032,
      _SDECH,
      { [_h22]: ["POST", "/2025-12-01/durable-execution-callbacks/{CallbackId}/heartbeat", 200] },
      () => exports2.SendDurableExecutionCallbackHeartbeatRequest$,
      () => exports2.SendDurableExecutionCallbackHeartbeatResponse$
    ];
    exports2.SendDurableExecutionCallbackSuccess$ = [
      9,
      n032,
      _SDECS,
      { [_h22]: ["POST", "/2025-12-01/durable-execution-callbacks/{CallbackId}/succeed", 200] },
      () => exports2.SendDurableExecutionCallbackSuccessRequest$,
      () => exports2.SendDurableExecutionCallbackSuccessResponse$
    ];
    exports2.StopDurableExecution$ = [
      9,
      n032,
      _SDE4,
      { [_h22]: ["POST", "/2025-12-01/durable-executions/{DurableExecutionArn}/stop", 200] },
      () => exports2.StopDurableExecutionRequest$,
      () => exports2.StopDurableExecutionResponse$
    ];
    exports2.TagResource$ = [
      9,
      n032,
      _TR,
      { [_h22]: ["POST", "/2017-03-31/tags/{Resource}", 204] },
      () => exports2.TagResourceRequest$,
      () => __Unit
    ];
    exports2.UntagResource$ = [
      9,
      n032,
      _UR,
      { [_h22]: ["DELETE", "/2017-03-31/tags/{Resource}", 204] },
      () => exports2.UntagResourceRequest$,
      () => __Unit
    ];
    exports2.UpdateAlias$ = [
      9,
      n032,
      _UA,
      { [_h22]: ["PUT", "/2015-03-31/functions/{FunctionName}/aliases/{Name}", 200] },
      () => exports2.UpdateAliasRequest$,
      () => exports2.AliasConfiguration$
    ];
    exports2.UpdateCapacityProvider$ = [
      9,
      n032,
      _UCP,
      { [_h22]: ["PUT", "/2025-11-30/capacity-providers/{CapacityProviderName}", 202] },
      () => exports2.UpdateCapacityProviderRequest$,
      () => exports2.UpdateCapacityProviderResponse$
    ];
    exports2.UpdateCodeSigningConfig$ = [
      9,
      n032,
      _UCSC,
      { [_h22]: ["PUT", "/2020-04-22/code-signing-configs/{CodeSigningConfigArn}", 200] },
      () => exports2.UpdateCodeSigningConfigRequest$,
      () => exports2.UpdateCodeSigningConfigResponse$
    ];
    exports2.UpdateEventSourceMapping$ = [
      9,
      n032,
      _UESM,
      { [_h22]: ["PUT", "/2015-03-31/event-source-mappings/{UUID}", 202] },
      () => exports2.UpdateEventSourceMappingRequest$,
      () => exports2.EventSourceMappingConfiguration$
    ];
    exports2.UpdateFunctionCode$ = [
      9,
      n032,
      _UFC,
      { [_h22]: ["PUT", "/2015-03-31/functions/{FunctionName}/code", 200] },
      () => exports2.UpdateFunctionCodeRequest$,
      () => exports2.FunctionConfiguration$
    ];
    exports2.UpdateFunctionConfiguration$ = [
      9,
      n032,
      _UFCp,
      { [_h22]: ["PUT", "/2015-03-31/functions/{FunctionName}/configuration", 200] },
      () => exports2.UpdateFunctionConfigurationRequest$,
      () => exports2.FunctionConfiguration$
    ];
    exports2.UpdateFunctionEventInvokeConfig$ = [
      9,
      n032,
      _UFEIC,
      { [_h22]: ["POST", "/2019-09-25/functions/{FunctionName}/event-invoke-config", 200] },
      () => exports2.UpdateFunctionEventInvokeConfigRequest$,
      () => exports2.FunctionEventInvokeConfig$
    ];
    exports2.UpdateFunctionUrlConfig$ = [
      9,
      n032,
      _UFUC,
      { [_h22]: ["PUT", "/2021-10-31/functions/{FunctionName}/url", 200] },
      () => exports2.UpdateFunctionUrlConfigRequest$,
      () => exports2.UpdateFunctionUrlConfigResponse$
    ];
  }
});

// ../../node_modules/@aws-sdk/client-lambda/dist-cjs/runtimeConfig.shared.js
var require_runtimeConfig_shared17 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/dist-cjs/runtimeConfig.shared.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes11(), __toCommonJS(httpAuthSchemes_exports9));
    var protocols_1 = (init_protocols17(), __toCommonJS(protocols_exports14));
    var smithy_client_1 = require_dist_cjs34();
    var url_parser_1 = require_dist_cjs18();
    var util_base64_1 = require_dist_cjs10();
    var util_utf8_1 = require_dist_cjs9();
    var httpAuthSchemeProvider_1 = require_httpAuthSchemeProvider16();
    var endpointResolver_1 = require_endpointResolver16();
    var schemas_0_1 = require_schemas_016();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2015-03-31",
        base64Decoder: config2?.base64Decoder ?? util_base64_1.fromBase64,
        base64Encoder: config2?.base64Encoder ?? util_base64_1.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? endpointResolver_1.defaultEndpointResolver,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? httpAuthSchemeProvider_1.defaultLambdaHttpAuthSchemeProvider,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new httpAuthSchemes_1.AwsSdkSigV4Signer()
          }
        ],
        logger: config2?.logger ?? new smithy_client_1.NoOpLogger(),
        protocol: config2?.protocol ?? protocols_1.AwsRestJsonProtocol,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.lambda",
          errorTypeRegistries: schemas_0_1.errorTypeRegistries,
          version: "2015-03-31",
          serviceTarget: "AWSGirApiService"
        },
        serviceId: config2?.serviceId ?? "Lambda",
        urlParser: config2?.urlParser ?? url_parser_1.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? util_utf8_1.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? util_utf8_1.toUtf8
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/dist-cjs/runtimeConfig.js
var require_runtimeConfig17 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/dist-cjs/runtimeConfig.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var package_json_1 = tslib_1.__importDefault(require_package16());
    var client_1 = (init_client18(), __toCommonJS(client_exports13));
    var httpAuthSchemes_1 = (init_httpAuthSchemes11(), __toCommonJS(httpAuthSchemes_exports9));
    var credential_provider_node_1 = require_dist_cjs191();
    var util_user_agent_node_1 = require_dist_cjs185();
    var config_resolver_1 = require_dist_cjs25();
    var eventstream_serde_node_1 = require_dist_cjs85();
    var hash_node_1 = require_dist_cjs44();
    var middleware_retry_1 = require_dist_cjs181();
    var node_config_provider_1 = require_dist_cjs29();
    var node_http_handler_1 = require_dist_cjs13();
    var smithy_client_1 = require_dist_cjs34();
    var util_body_length_node_1 = require_dist_cjs45();
    var util_defaults_mode_node_1 = require_dist_cjs46();
    var util_retry_1 = require_dist_cjs22();
    var runtimeConfig_shared_1 = require_runtimeConfig_shared17();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      (0, smithy_client_1.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, util_defaults_mode_node_1.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(smithy_client_1.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = (0, runtimeConfig_shared_1.getRuntimeConfig)(config2);
      (0, client_1.emitWarningIfUnsupportedVersion)(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, node_config_provider_1.loadConfig)(httpAuthSchemes_1.NODE_AUTH_SCHEME_PREFERENCE_OPTIONS, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? util_body_length_node_1.calculateBodyLength,
        credentialDefaultProvider: config2?.credentialDefaultProvider ?? credential_provider_node_1.defaultProvider,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, util_user_agent_node_1.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_json_1.default.version }),
        eventStreamSerdeProvider: config2?.eventStreamSerdeProvider ?? eventstream_serde_node_1.eventStreamSerdeProvider,
        maxAttempts: config2?.maxAttempts ?? (0, node_config_provider_1.loadConfig)(middleware_retry_1.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_REGION_CONFIG_OPTIONS, { ...config_resolver_1.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: node_http_handler_1.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, node_config_provider_1.loadConfig)({
          ...middleware_retry_1.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || util_retry_1.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? hash_node_1.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? node_http_handler_1.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, node_config_provider_1.loadConfig)(util_user_agent_node_1.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-waiter/dist-cjs/index.js
var require_dist_cjs192 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/node_modules/@smithy/util-waiter/dist-cjs/index.js"(exports2) {
    "use strict";
    var getCircularReplacer3 = /* @__PURE__ */ __name(() => {
      const seen = /* @__PURE__ */ new WeakSet();
      return (key, value) => {
        if (typeof value === "object" && value !== null) {
          if (seen.has(value)) {
            return "[Circular]";
          }
          seen.add(value);
        }
        return value;
      };
    }, "getCircularReplacer");
    var sleep4 = /* @__PURE__ */ __name((seconds) => {
      return new Promise((resolve13) => setTimeout(resolve13, seconds * 1e3));
    }, "sleep");
    var waiterServiceDefaults3 = {
      minDelay: 2,
      maxDelay: 120
    };
    exports2.WaiterState = void 0;
    (function(WaiterState3) {
      WaiterState3["ABORTED"] = "ABORTED";
      WaiterState3["FAILURE"] = "FAILURE";
      WaiterState3["SUCCESS"] = "SUCCESS";
      WaiterState3["RETRY"] = "RETRY";
      WaiterState3["TIMEOUT"] = "TIMEOUT";
    })(exports2.WaiterState || (exports2.WaiterState = {}));
    var checkExceptions3 = /* @__PURE__ */ __name((result2) => {
      if (result2.state === exports2.WaiterState.ABORTED) {
        const abortError = new Error(`${JSON.stringify({
          ...result2,
          reason: "Request was aborted"
        }, getCircularReplacer3())}`);
        abortError.name = "AbortError";
        throw abortError;
      } else if (result2.state === exports2.WaiterState.TIMEOUT) {
        const timeoutError = new Error(`${JSON.stringify({
          ...result2,
          reason: "Waiter has timed out"
        }, getCircularReplacer3())}`);
        timeoutError.name = "TimeoutError";
        throw timeoutError;
      } else if (result2.state !== exports2.WaiterState.SUCCESS) {
        throw new Error(`${JSON.stringify(result2, getCircularReplacer3())}`);
      }
      return result2;
    }, "checkExceptions");
    var runPolling3 = /* @__PURE__ */ __name(async ({ minDelay, maxDelay, maxWaitTime, abortController, client, abortSignal }, input, acceptorChecks) => {
      const observedResponses = {};
      const [minDelayMs, maxDelayMs] = [minDelay * 1e3, maxDelay * 1e3];
      let currentAttempt = 0;
      const waitUntil = Date.now() + maxWaitTime * 1e3;
      const warn403Time = Date.now() + 6e4;
      let didWarn403 = false;
      while (true) {
        if (currentAttempt > 0) {
          const delayMs = exponentialBackoffWithJitter3(minDelayMs, maxDelayMs, currentAttempt, waitUntil);
          if (abortController?.signal?.aborted || abortSignal?.aborted) {
            const message2 = "AbortController signal aborted.";
            observedResponses[message2] |= 0;
            observedResponses[message2] += 1;
            return { state: exports2.WaiterState.ABORTED, observedResponses };
          }
          if (Date.now() + delayMs > waitUntil) {
            return { state: exports2.WaiterState.TIMEOUT, observedResponses };
          }
          await sleep4(delayMs / 1e3);
        }
        const { state: state13, reason } = await acceptorChecks(client, input);
        if (reason) {
          const message2 = createMessageFromResponse3(reason);
          observedResponses[message2] |= 0;
          observedResponses[message2] += 1;
        }
        if (state13 !== exports2.WaiterState.RETRY) {
          return { state: state13, reason, final: reason, observedResponses };
        }
        currentAttempt += 1;
        if (!didWarn403 && Date.now() >= warn403Time) {
          checkWarn4033(observedResponses, client);
          didWarn403 = true;
        }
      }
    }, "runPolling");
    var checkWarn4033 = /* @__PURE__ */ __name((observedResponses = {}, client) => {
      const orderedErrors = Object.keys(observedResponses);
      let count403 = 0;
      for (const response of orderedErrors) {
        const n10 = observedResponses[response] | 0;
        if (response.startsWith("403:")) {
          count403 += n10;
        }
      }
      const clientLogger = client?.config?.logger;
      const warningLogger = typeof clientLogger?.warn === "function" && !clientLogger.constructor?.name?.includes?.("NoOpLogger") ? clientLogger : console;
      if (count403 >= 3 || orderedErrors[orderedErrors.length - 1].startsWith("403:")) {
        warningLogger.warn(`@smithy/util-waiter WARN - 403 status code encountered during waiter polling.`);
      }
    }, "checkWarn403");
    var createMessageFromResponse3 = /* @__PURE__ */ __name((reason) => {
      const status = reason?.$response?.statusCode ?? reason?.$metadata?.httpStatusCode;
      if (reason?.$responseBodyText) {
        return `${status ? status + ": " : ""}Deserialization error for body: ${reason.$responseBodyText}`;
      }
      if (status) {
        if (reason?.$response || reason?.message) {
          return `${status ?? "Unknown"}: ${reason?.message}`;
        }
        return `${status}: OK`;
      }
      return String(reason?.message ?? JSON.stringify(reason, getCircularReplacer3()) ?? "Unknown");
    }, "createMessageFromResponse");
    var exponentialBackoffWithJitter3 = /* @__PURE__ */ __name((minDelayMs, maxDelayMs, attempt, waitUntil) => {
      const attemptCountCeiling = Math.log(maxDelayMs / minDelayMs) / Math.log(2) + 1;
      if (attempt > attemptCountCeiling) {
        return maxDelayMs;
      }
      const delay = minDelayMs * 2 ** (attempt - 1);
      const capped = Math.min(delay, maxDelayMs);
      const waitFor2 = randomInRange3(minDelayMs, capped);
      if (Date.now() + waitFor2 > waitUntil) {
        const timeRemaining = waitUntil - Date.now();
        return Math.max(0, timeRemaining - 500);
      }
      return waitFor2;
    }, "exponentialBackoffWithJitter");
    var randomInRange3 = /* @__PURE__ */ __name((min, max) => min + Math.random() * (max - min), "randomInRange");
    var validateWaiterOptions3 = /* @__PURE__ */ __name((options) => {
      if (options.maxWaitTime <= 0) {
        throw new Error(`WaiterConfiguration.maxWaitTime must be greater than 0`);
      } else if (options.minDelay <= 0) {
        throw new Error(`WaiterConfiguration.minDelay must be greater than 0`);
      } else if (options.maxDelay <= 0) {
        throw new Error(`WaiterConfiguration.maxDelay must be greater than 0`);
      } else if (options.maxWaitTime <= options.minDelay) {
        throw new Error(`WaiterConfiguration.maxWaitTime [${options.maxWaitTime}] must be greater than WaiterConfiguration.minDelay [${options.minDelay}] for this waiter`);
      } else if (options.maxDelay < options.minDelay) {
        throw new Error(`WaiterConfiguration.maxDelay [${options.maxDelay}] must be greater than WaiterConfiguration.minDelay [${options.minDelay}] for this waiter`);
      }
    }, "validateWaiterOptions");
    var abortTimeout3 = /* @__PURE__ */ __name((abortSignal) => {
      let onAbort;
      const promise = new Promise((resolve13) => {
        onAbort = /* @__PURE__ */ __name(() => resolve13({ state: exports2.WaiterState.ABORTED }), "onAbort");
        if (typeof abortSignal.addEventListener === "function") {
          abortSignal.addEventListener("abort", onAbort);
        } else {
          abortSignal.onabort = onAbort;
        }
      });
      return {
        clearListener() {
          if (typeof abortSignal.removeEventListener === "function") {
            abortSignal.removeEventListener("abort", onAbort);
          }
        },
        aborted: promise
      };
    }, "abortTimeout");
    var createWaiter3 = /* @__PURE__ */ __name(async (options, input, acceptorChecks) => {
      const params = {
        ...waiterServiceDefaults3,
        ...options
      };
      validateWaiterOptions3(params);
      const exitConditions = [runPolling3(params, input, acceptorChecks)];
      const finalize = [];
      if (options.abortSignal) {
        const { aborted, clearListener } = abortTimeout3(options.abortSignal);
        finalize.push(clearListener);
        exitConditions.push(aborted);
      }
      if (options.abortController?.signal) {
        const { aborted, clearListener } = abortTimeout3(options.abortController.signal);
        finalize.push(clearListener);
        exitConditions.push(aborted);
      }
      return Promise.race(exitConditions).then((result2) => {
        for (const fn of finalize) {
          fn();
        }
        return result2;
      });
    }, "createWaiter");
    exports2.checkExceptions = checkExceptions3;
    exports2.createWaiter = createWaiter3;
    exports2.waiterServiceDefaults = waiterServiceDefaults3;
  }
});

// ../../node_modules/@aws-sdk/client-lambda/dist-cjs/index.js
var require_dist_cjs193 = __commonJS({
  "../../node_modules/@aws-sdk/client-lambda/dist-cjs/index.js"(exports2) {
    "use strict";
    var middlewareHostHeader = require_dist_cjs3();
    var middlewareLogger = require_dist_cjs4();
    var middlewareRecursionDetection = require_dist_cjs5();
    var middlewareUserAgent = require_dist_cjs180();
    var configResolver = require_dist_cjs25();
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var schema = (init_schema4(), __toCommonJS(schema_exports));
    var eventstreamSerdeConfigResolver = require_dist_cjs70();
    var middlewareContentLength = require_dist_cjs26();
    var middlewareEndpoint = require_dist_cjs31();
    var middlewareRetry = require_dist_cjs181();
    var smithyClient = require_dist_cjs34();
    var httpAuthSchemeProvider = require_httpAuthSchemeProvider16();
    var runtimeConfig = require_runtimeConfig17();
    var regionConfigResolver = require_dist_cjs48();
    var protocolHttp = require_dist_cjs2();
    var schemas_0 = require_schemas_016();
    var utilWaiter = require_dist_cjs192();
    var errors = require_errors15();
    var LambdaServiceException = require_LambdaServiceException();
    var resolveClientEndpointParameters32 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "lambda"
      });
    }, "resolveClientEndpointParameters");
    var commonParams32 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
    var getHttpAuthExtensionConfiguration32 = /* @__PURE__ */ __name((runtimeConfig2) => {
      const _httpAuthSchemes = runtimeConfig2.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig2.httpAuthSchemeProvider;
      let _credentials = runtimeConfig2.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider2) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider2;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    var resolveHttpAuthRuntimeConfig32 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
    var resolveRuntimeExtensions32 = /* @__PURE__ */ __name((runtimeConfig2, extensions) => {
      const extensionConfiguration = Object.assign(regionConfigResolver.getAwsRegionExtensionConfiguration(runtimeConfig2), smithyClient.getDefaultExtensionConfiguration(runtimeConfig2), protocolHttp.getHttpHandlerExtensionConfiguration(runtimeConfig2), getHttpAuthExtensionConfiguration32(runtimeConfig2));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig2, regionConfigResolver.resolveAwsRegionExtensionConfiguration(extensionConfiguration), smithyClient.resolveDefaultRuntimeConfig(extensionConfiguration), protocolHttp.resolveHttpHandlerRuntimeConfig(extensionConfiguration), resolveHttpAuthRuntimeConfig32(extensionConfiguration));
    }, "resolveRuntimeExtensions");
    var LambdaClient2 = class extends smithyClient.Client {
      static {
        __name(this, "LambdaClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = runtimeConfig.getRuntimeConfig(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters32(_config_0);
        const _config_2 = middlewareUserAgent.resolveUserAgentConfig(_config_1);
        const _config_3 = middlewareRetry.resolveRetryConfig(_config_2);
        const _config_4 = configResolver.resolveRegionConfig(_config_3);
        const _config_5 = middlewareHostHeader.resolveHostHeaderConfig(_config_4);
        const _config_6 = middlewareEndpoint.resolveEndpointConfig(_config_5);
        const _config_7 = eventstreamSerdeConfigResolver.resolveEventStreamSerdeConfig(_config_6);
        const _config_8 = httpAuthSchemeProvider.resolveHttpAuthSchemeConfig(_config_7);
        const _config_9 = resolveRuntimeExtensions32(_config_8, configuration?.extensions || []);
        this.config = _config_9;
        this.middlewareStack.use(schema.getSchemaSerdePlugin(this.config));
        this.middlewareStack.use(middlewareUserAgent.getUserAgentPlugin(this.config));
        this.middlewareStack.use(middlewareRetry.getRetryPlugin(this.config));
        this.middlewareStack.use(middlewareContentLength.getContentLengthPlugin(this.config));
        this.middlewareStack.use(middlewareHostHeader.getHostHeaderPlugin(this.config));
        this.middlewareStack.use(middlewareLogger.getLoggerPlugin(this.config));
        this.middlewareStack.use(middlewareRecursionDetection.getRecursionDetectionPlugin(this.config));
        this.middlewareStack.use(core.getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: httpAuthSchemeProvider.defaultLambdaHttpAuthSchemeParametersProvider,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new core.DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(core.getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
    var AddLayerVersionPermissionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "AddLayerVersionPermission", {}).n("LambdaClient", "AddLayerVersionPermissionCommand").sc(schemas_0.AddLayerVersionPermission$).build() {
      static {
        __name(this, "AddLayerVersionPermissionCommand");
      }
    };
    var AddPermissionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "AddPermission", {}).n("LambdaClient", "AddPermissionCommand").sc(schemas_0.AddPermission$).build() {
      static {
        __name(this, "AddPermissionCommand");
      }
    };
    var CheckpointDurableExecutionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "CheckpointDurableExecution", {}).n("LambdaClient", "CheckpointDurableExecutionCommand").sc(schemas_0.CheckpointDurableExecution$).build() {
      static {
        __name(this, "CheckpointDurableExecutionCommand");
      }
    };
    var CreateAliasCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "CreateAlias", {}).n("LambdaClient", "CreateAliasCommand").sc(schemas_0.CreateAlias$).build() {
      static {
        __name(this, "CreateAliasCommand");
      }
    };
    var CreateCapacityProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "CreateCapacityProvider", {}).n("LambdaClient", "CreateCapacityProviderCommand").sc(schemas_0.CreateCapacityProvider$).build() {
      static {
        __name(this, "CreateCapacityProviderCommand");
      }
    };
    var CreateCodeSigningConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "CreateCodeSigningConfig", {}).n("LambdaClient", "CreateCodeSigningConfigCommand").sc(schemas_0.CreateCodeSigningConfig$).build() {
      static {
        __name(this, "CreateCodeSigningConfigCommand");
      }
    };
    var CreateEventSourceMappingCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "CreateEventSourceMapping", {}).n("LambdaClient", "CreateEventSourceMappingCommand").sc(schemas_0.CreateEventSourceMapping$).build() {
      static {
        __name(this, "CreateEventSourceMappingCommand");
      }
    };
    var CreateFunctionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "CreateFunction", {}).n("LambdaClient", "CreateFunctionCommand").sc(schemas_0.CreateFunction$).build() {
      static {
        __name(this, "CreateFunctionCommand");
      }
    };
    var CreateFunctionUrlConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "CreateFunctionUrlConfig", {}).n("LambdaClient", "CreateFunctionUrlConfigCommand").sc(schemas_0.CreateFunctionUrlConfig$).build() {
      static {
        __name(this, "CreateFunctionUrlConfigCommand");
      }
    };
    var DeleteAliasCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "DeleteAlias", {}).n("LambdaClient", "DeleteAliasCommand").sc(schemas_0.DeleteAlias$).build() {
      static {
        __name(this, "DeleteAliasCommand");
      }
    };
    var DeleteCapacityProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "DeleteCapacityProvider", {}).n("LambdaClient", "DeleteCapacityProviderCommand").sc(schemas_0.DeleteCapacityProvider$).build() {
      static {
        __name(this, "DeleteCapacityProviderCommand");
      }
    };
    var DeleteCodeSigningConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "DeleteCodeSigningConfig", {}).n("LambdaClient", "DeleteCodeSigningConfigCommand").sc(schemas_0.DeleteCodeSigningConfig$).build() {
      static {
        __name(this, "DeleteCodeSigningConfigCommand");
      }
    };
    var DeleteEventSourceMappingCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "DeleteEventSourceMapping", {}).n("LambdaClient", "DeleteEventSourceMappingCommand").sc(schemas_0.DeleteEventSourceMapping$).build() {
      static {
        __name(this, "DeleteEventSourceMappingCommand");
      }
    };
    var DeleteFunctionCodeSigningConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "DeleteFunctionCodeSigningConfig", {}).n("LambdaClient", "DeleteFunctionCodeSigningConfigCommand").sc(schemas_0.DeleteFunctionCodeSigningConfig$).build() {
      static {
        __name(this, "DeleteFunctionCodeSigningConfigCommand");
      }
    };
    var DeleteFunctionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "DeleteFunction", {}).n("LambdaClient", "DeleteFunctionCommand").sc(schemas_0.DeleteFunction$).build() {
      static {
        __name(this, "DeleteFunctionCommand");
      }
    };
    var DeleteFunctionConcurrencyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "DeleteFunctionConcurrency", {}).n("LambdaClient", "DeleteFunctionConcurrencyCommand").sc(schemas_0.DeleteFunctionConcurrency$).build() {
      static {
        __name(this, "DeleteFunctionConcurrencyCommand");
      }
    };
    var DeleteFunctionEventInvokeConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "DeleteFunctionEventInvokeConfig", {}).n("LambdaClient", "DeleteFunctionEventInvokeConfigCommand").sc(schemas_0.DeleteFunctionEventInvokeConfig$).build() {
      static {
        __name(this, "DeleteFunctionEventInvokeConfigCommand");
      }
    };
    var DeleteFunctionUrlConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "DeleteFunctionUrlConfig", {}).n("LambdaClient", "DeleteFunctionUrlConfigCommand").sc(schemas_0.DeleteFunctionUrlConfig$).build() {
      static {
        __name(this, "DeleteFunctionUrlConfigCommand");
      }
    };
    var DeleteLayerVersionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "DeleteLayerVersion", {}).n("LambdaClient", "DeleteLayerVersionCommand").sc(schemas_0.DeleteLayerVersion$).build() {
      static {
        __name(this, "DeleteLayerVersionCommand");
      }
    };
    var DeleteProvisionedConcurrencyConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "DeleteProvisionedConcurrencyConfig", {}).n("LambdaClient", "DeleteProvisionedConcurrencyConfigCommand").sc(schemas_0.DeleteProvisionedConcurrencyConfig$).build() {
      static {
        __name(this, "DeleteProvisionedConcurrencyConfigCommand");
      }
    };
    var GetAccountSettingsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "GetAccountSettings", {}).n("LambdaClient", "GetAccountSettingsCommand").sc(schemas_0.GetAccountSettings$).build() {
      static {
        __name(this, "GetAccountSettingsCommand");
      }
    };
    var GetAliasCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "GetAlias", {}).n("LambdaClient", "GetAliasCommand").sc(schemas_0.GetAlias$).build() {
      static {
        __name(this, "GetAliasCommand");
      }
    };
    var GetCapacityProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "GetCapacityProvider", {}).n("LambdaClient", "GetCapacityProviderCommand").sc(schemas_0.GetCapacityProvider$).build() {
      static {
        __name(this, "GetCapacityProviderCommand");
      }
    };
    var GetCodeSigningConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "GetCodeSigningConfig", {}).n("LambdaClient", "GetCodeSigningConfigCommand").sc(schemas_0.GetCodeSigningConfig$).build() {
      static {
        __name(this, "GetCodeSigningConfigCommand");
      }
    };
    var GetDurableExecutionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "GetDurableExecution", {}).n("LambdaClient", "GetDurableExecutionCommand").sc(schemas_0.GetDurableExecution$).build() {
      static {
        __name(this, "GetDurableExecutionCommand");
      }
    };
    var GetDurableExecutionHistoryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "GetDurableExecutionHistory", {}).n("LambdaClient", "GetDurableExecutionHistoryCommand").sc(schemas_0.GetDurableExecutionHistory$).build() {
      static {
        __name(this, "GetDurableExecutionHistoryCommand");
      }
    };
    var GetDurableExecutionStateCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "GetDurableExecutionState", {}).n("LambdaClient", "GetDurableExecutionStateCommand").sc(schemas_0.GetDurableExecutionState$).build() {
      static {
        __name(this, "GetDurableExecutionStateCommand");
      }
    };
    var GetEventSourceMappingCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "GetEventSourceMapping", {}).n("LambdaClient", "GetEventSourceMappingCommand").sc(schemas_0.GetEventSourceMapping$).build() {
      static {
        __name(this, "GetEventSourceMappingCommand");
      }
    };
    var GetFunctionCodeSigningConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "GetFunctionCodeSigningConfig", {}).n("LambdaClient", "GetFunctionCodeSigningConfigCommand").sc(schemas_0.GetFunctionCodeSigningConfig$).build() {
      static {
        __name(this, "GetFunctionCodeSigningConfigCommand");
      }
    };
    var GetFunctionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "GetFunction", {}).n("LambdaClient", "GetFunctionCommand").sc(schemas_0.GetFunction$).build() {
      static {
        __name(this, "GetFunctionCommand");
      }
    };
    var GetFunctionConcurrencyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "GetFunctionConcurrency", {}).n("LambdaClient", "GetFunctionConcurrencyCommand").sc(schemas_0.GetFunctionConcurrency$).build() {
      static {
        __name(this, "GetFunctionConcurrencyCommand");
      }
    };
    var GetFunctionConfigurationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "GetFunctionConfiguration", {}).n("LambdaClient", "GetFunctionConfigurationCommand").sc(schemas_0.GetFunctionConfiguration$).build() {
      static {
        __name(this, "GetFunctionConfigurationCommand");
      }
    };
    var GetFunctionEventInvokeConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "GetFunctionEventInvokeConfig", {}).n("LambdaClient", "GetFunctionEventInvokeConfigCommand").sc(schemas_0.GetFunctionEventInvokeConfig$).build() {
      static {
        __name(this, "GetFunctionEventInvokeConfigCommand");
      }
    };
    var GetFunctionRecursionConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "GetFunctionRecursionConfig", {}).n("LambdaClient", "GetFunctionRecursionConfigCommand").sc(schemas_0.GetFunctionRecursionConfig$).build() {
      static {
        __name(this, "GetFunctionRecursionConfigCommand");
      }
    };
    var GetFunctionScalingConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "GetFunctionScalingConfig", {}).n("LambdaClient", "GetFunctionScalingConfigCommand").sc(schemas_0.GetFunctionScalingConfig$).build() {
      static {
        __name(this, "GetFunctionScalingConfigCommand");
      }
    };
    var GetFunctionUrlConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "GetFunctionUrlConfig", {}).n("LambdaClient", "GetFunctionUrlConfigCommand").sc(schemas_0.GetFunctionUrlConfig$).build() {
      static {
        __name(this, "GetFunctionUrlConfigCommand");
      }
    };
    var GetLayerVersionByArnCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "GetLayerVersionByArn", {}).n("LambdaClient", "GetLayerVersionByArnCommand").sc(schemas_0.GetLayerVersionByArn$).build() {
      static {
        __name(this, "GetLayerVersionByArnCommand");
      }
    };
    var GetLayerVersionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "GetLayerVersion", {}).n("LambdaClient", "GetLayerVersionCommand").sc(schemas_0.GetLayerVersion$).build() {
      static {
        __name(this, "GetLayerVersionCommand");
      }
    };
    var GetLayerVersionPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "GetLayerVersionPolicy", {}).n("LambdaClient", "GetLayerVersionPolicyCommand").sc(schemas_0.GetLayerVersionPolicy$).build() {
      static {
        __name(this, "GetLayerVersionPolicyCommand");
      }
    };
    var GetPolicyCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "GetPolicy", {}).n("LambdaClient", "GetPolicyCommand").sc(schemas_0.GetPolicy$).build() {
      static {
        __name(this, "GetPolicyCommand");
      }
    };
    var GetProvisionedConcurrencyConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "GetProvisionedConcurrencyConfig", {}).n("LambdaClient", "GetProvisionedConcurrencyConfigCommand").sc(schemas_0.GetProvisionedConcurrencyConfig$).build() {
      static {
        __name(this, "GetProvisionedConcurrencyConfigCommand");
      }
    };
    var GetRuntimeManagementConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "GetRuntimeManagementConfig", {}).n("LambdaClient", "GetRuntimeManagementConfigCommand").sc(schemas_0.GetRuntimeManagementConfig$).build() {
      static {
        __name(this, "GetRuntimeManagementConfigCommand");
      }
    };
    var InvokeAsyncCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "InvokeAsync", {}).n("LambdaClient", "InvokeAsyncCommand").sc(schemas_0.InvokeAsync$).build() {
      static {
        __name(this, "InvokeAsyncCommand");
      }
    };
    var InvokeCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "Invoke", {}).n("LambdaClient", "InvokeCommand").sc(schemas_0.Invoke$).build() {
      static {
        __name(this, "InvokeCommand");
      }
    };
    var InvokeWithResponseStreamCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "InvokeWithResponseStream", {
      eventStream: {
        output: true
      }
    }).n("LambdaClient", "InvokeWithResponseStreamCommand").sc(schemas_0.InvokeWithResponseStream$).build() {
      static {
        __name(this, "InvokeWithResponseStreamCommand");
      }
    };
    var ListAliasesCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "ListAliases", {}).n("LambdaClient", "ListAliasesCommand").sc(schemas_0.ListAliases$).build() {
      static {
        __name(this, "ListAliasesCommand");
      }
    };
    var ListCapacityProvidersCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "ListCapacityProviders", {}).n("LambdaClient", "ListCapacityProvidersCommand").sc(schemas_0.ListCapacityProviders$).build() {
      static {
        __name(this, "ListCapacityProvidersCommand");
      }
    };
    var ListCodeSigningConfigsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "ListCodeSigningConfigs", {}).n("LambdaClient", "ListCodeSigningConfigsCommand").sc(schemas_0.ListCodeSigningConfigs$).build() {
      static {
        __name(this, "ListCodeSigningConfigsCommand");
      }
    };
    var ListDurableExecutionsByFunctionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "ListDurableExecutionsByFunction", {}).n("LambdaClient", "ListDurableExecutionsByFunctionCommand").sc(schemas_0.ListDurableExecutionsByFunction$).build() {
      static {
        __name(this, "ListDurableExecutionsByFunctionCommand");
      }
    };
    var ListEventSourceMappingsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "ListEventSourceMappings", {}).n("LambdaClient", "ListEventSourceMappingsCommand").sc(schemas_0.ListEventSourceMappings$).build() {
      static {
        __name(this, "ListEventSourceMappingsCommand");
      }
    };
    var ListFunctionEventInvokeConfigsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "ListFunctionEventInvokeConfigs", {}).n("LambdaClient", "ListFunctionEventInvokeConfigsCommand").sc(schemas_0.ListFunctionEventInvokeConfigs$).build() {
      static {
        __name(this, "ListFunctionEventInvokeConfigsCommand");
      }
    };
    var ListFunctionsByCodeSigningConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "ListFunctionsByCodeSigningConfig", {}).n("LambdaClient", "ListFunctionsByCodeSigningConfigCommand").sc(schemas_0.ListFunctionsByCodeSigningConfig$).build() {
      static {
        __name(this, "ListFunctionsByCodeSigningConfigCommand");
      }
    };
    var ListFunctionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "ListFunctions", {}).n("LambdaClient", "ListFunctionsCommand").sc(schemas_0.ListFunctions$).build() {
      static {
        __name(this, "ListFunctionsCommand");
      }
    };
    var ListFunctionUrlConfigsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "ListFunctionUrlConfigs", {}).n("LambdaClient", "ListFunctionUrlConfigsCommand").sc(schemas_0.ListFunctionUrlConfigs$).build() {
      static {
        __name(this, "ListFunctionUrlConfigsCommand");
      }
    };
    var ListFunctionVersionsByCapacityProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "ListFunctionVersionsByCapacityProvider", {}).n("LambdaClient", "ListFunctionVersionsByCapacityProviderCommand").sc(schemas_0.ListFunctionVersionsByCapacityProvider$).build() {
      static {
        __name(this, "ListFunctionVersionsByCapacityProviderCommand");
      }
    };
    var ListLayersCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "ListLayers", {}).n("LambdaClient", "ListLayersCommand").sc(schemas_0.ListLayers$).build() {
      static {
        __name(this, "ListLayersCommand");
      }
    };
    var ListLayerVersionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "ListLayerVersions", {}).n("LambdaClient", "ListLayerVersionsCommand").sc(schemas_0.ListLayerVersions$).build() {
      static {
        __name(this, "ListLayerVersionsCommand");
      }
    };
    var ListProvisionedConcurrencyConfigsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "ListProvisionedConcurrencyConfigs", {}).n("LambdaClient", "ListProvisionedConcurrencyConfigsCommand").sc(schemas_0.ListProvisionedConcurrencyConfigs$).build() {
      static {
        __name(this, "ListProvisionedConcurrencyConfigsCommand");
      }
    };
    var ListTagsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "ListTags", {}).n("LambdaClient", "ListTagsCommand").sc(schemas_0.ListTags$).build() {
      static {
        __name(this, "ListTagsCommand");
      }
    };
    var ListVersionsByFunctionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "ListVersionsByFunction", {}).n("LambdaClient", "ListVersionsByFunctionCommand").sc(schemas_0.ListVersionsByFunction$).build() {
      static {
        __name(this, "ListVersionsByFunctionCommand");
      }
    };
    var PublishLayerVersionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "PublishLayerVersion", {}).n("LambdaClient", "PublishLayerVersionCommand").sc(schemas_0.PublishLayerVersion$).build() {
      static {
        __name(this, "PublishLayerVersionCommand");
      }
    };
    var PublishVersionCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "PublishVersion", {}).n("LambdaClient", "PublishVersionCommand").sc(schemas_0.PublishVersion$).build() {
      static {
        __name(this, "PublishVersionCommand");
      }
    };
    var PutFunctionCodeSigningConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "PutFunctionCodeSigningConfig", {}).n("LambdaClient", "PutFunctionCodeSigningConfigCommand").sc(schemas_0.PutFunctionCodeSigningConfig$).build() {
      static {
        __name(this, "PutFunctionCodeSigningConfigCommand");
      }
    };
    var PutFunctionConcurrencyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "PutFunctionConcurrency", {}).n("LambdaClient", "PutFunctionConcurrencyCommand").sc(schemas_0.PutFunctionConcurrency$).build() {
      static {
        __name(this, "PutFunctionConcurrencyCommand");
      }
    };
    var PutFunctionEventInvokeConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "PutFunctionEventInvokeConfig", {}).n("LambdaClient", "PutFunctionEventInvokeConfigCommand").sc(schemas_0.PutFunctionEventInvokeConfig$).build() {
      static {
        __name(this, "PutFunctionEventInvokeConfigCommand");
      }
    };
    var PutFunctionRecursionConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "PutFunctionRecursionConfig", {}).n("LambdaClient", "PutFunctionRecursionConfigCommand").sc(schemas_0.PutFunctionRecursionConfig$).build() {
      static {
        __name(this, "PutFunctionRecursionConfigCommand");
      }
    };
    var PutFunctionScalingConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "PutFunctionScalingConfig", {}).n("LambdaClient", "PutFunctionScalingConfigCommand").sc(schemas_0.PutFunctionScalingConfig$).build() {
      static {
        __name(this, "PutFunctionScalingConfigCommand");
      }
    };
    var PutProvisionedConcurrencyConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "PutProvisionedConcurrencyConfig", {}).n("LambdaClient", "PutProvisionedConcurrencyConfigCommand").sc(schemas_0.PutProvisionedConcurrencyConfig$).build() {
      static {
        __name(this, "PutProvisionedConcurrencyConfigCommand");
      }
    };
    var PutRuntimeManagementConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "PutRuntimeManagementConfig", {}).n("LambdaClient", "PutRuntimeManagementConfigCommand").sc(schemas_0.PutRuntimeManagementConfig$).build() {
      static {
        __name(this, "PutRuntimeManagementConfigCommand");
      }
    };
    var RemoveLayerVersionPermissionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "RemoveLayerVersionPermission", {}).n("LambdaClient", "RemoveLayerVersionPermissionCommand").sc(schemas_0.RemoveLayerVersionPermission$).build() {
      static {
        __name(this, "RemoveLayerVersionPermissionCommand");
      }
    };
    var RemovePermissionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "RemovePermission", {}).n("LambdaClient", "RemovePermissionCommand").sc(schemas_0.RemovePermission$).build() {
      static {
        __name(this, "RemovePermissionCommand");
      }
    };
    var SendDurableExecutionCallbackFailureCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "SendDurableExecutionCallbackFailure", {}).n("LambdaClient", "SendDurableExecutionCallbackFailureCommand").sc(schemas_0.SendDurableExecutionCallbackFailure$).build() {
      static {
        __name(this, "SendDurableExecutionCallbackFailureCommand");
      }
    };
    var SendDurableExecutionCallbackHeartbeatCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "SendDurableExecutionCallbackHeartbeat", {}).n("LambdaClient", "SendDurableExecutionCallbackHeartbeatCommand").sc(schemas_0.SendDurableExecutionCallbackHeartbeat$).build() {
      static {
        __name(this, "SendDurableExecutionCallbackHeartbeatCommand");
      }
    };
    var SendDurableExecutionCallbackSuccessCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "SendDurableExecutionCallbackSuccess", {}).n("LambdaClient", "SendDurableExecutionCallbackSuccessCommand").sc(schemas_0.SendDurableExecutionCallbackSuccess$).build() {
      static {
        __name(this, "SendDurableExecutionCallbackSuccessCommand");
      }
    };
    var StopDurableExecutionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "StopDurableExecution", {}).n("LambdaClient", "StopDurableExecutionCommand").sc(schemas_0.StopDurableExecution$).build() {
      static {
        __name(this, "StopDurableExecutionCommand");
      }
    };
    var TagResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "TagResource", {}).n("LambdaClient", "TagResourceCommand").sc(schemas_0.TagResource$).build() {
      static {
        __name(this, "TagResourceCommand");
      }
    };
    var UntagResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "UntagResource", {}).n("LambdaClient", "UntagResourceCommand").sc(schemas_0.UntagResource$).build() {
      static {
        __name(this, "UntagResourceCommand");
      }
    };
    var UpdateAliasCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "UpdateAlias", {}).n("LambdaClient", "UpdateAliasCommand").sc(schemas_0.UpdateAlias$).build() {
      static {
        __name(this, "UpdateAliasCommand");
      }
    };
    var UpdateCapacityProviderCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "UpdateCapacityProvider", {}).n("LambdaClient", "UpdateCapacityProviderCommand").sc(schemas_0.UpdateCapacityProvider$).build() {
      static {
        __name(this, "UpdateCapacityProviderCommand");
      }
    };
    var UpdateCodeSigningConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "UpdateCodeSigningConfig", {}).n("LambdaClient", "UpdateCodeSigningConfigCommand").sc(schemas_0.UpdateCodeSigningConfig$).build() {
      static {
        __name(this, "UpdateCodeSigningConfigCommand");
      }
    };
    var UpdateEventSourceMappingCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "UpdateEventSourceMapping", {}).n("LambdaClient", "UpdateEventSourceMappingCommand").sc(schemas_0.UpdateEventSourceMapping$).build() {
      static {
        __name(this, "UpdateEventSourceMappingCommand");
      }
    };
    var UpdateFunctionCodeCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "UpdateFunctionCode", {}).n("LambdaClient", "UpdateFunctionCodeCommand").sc(schemas_0.UpdateFunctionCode$).build() {
      static {
        __name(this, "UpdateFunctionCodeCommand");
      }
    };
    var UpdateFunctionConfigurationCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "UpdateFunctionConfiguration", {}).n("LambdaClient", "UpdateFunctionConfigurationCommand").sc(schemas_0.UpdateFunctionConfiguration$).build() {
      static {
        __name(this, "UpdateFunctionConfigurationCommand");
      }
    };
    var UpdateFunctionEventInvokeConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "UpdateFunctionEventInvokeConfig", {}).n("LambdaClient", "UpdateFunctionEventInvokeConfigCommand").sc(schemas_0.UpdateFunctionEventInvokeConfig$).build() {
      static {
        __name(this, "UpdateFunctionEventInvokeConfigCommand");
      }
    };
    var UpdateFunctionUrlConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSGirApiService", "UpdateFunctionUrlConfig", {}).n("LambdaClient", "UpdateFunctionUrlConfigCommand").sc(schemas_0.UpdateFunctionUrlConfig$).build() {
      static {
        __name(this, "UpdateFunctionUrlConfigCommand");
      }
    };
    var paginateGetDurableExecutionHistory = core.createPaginator(LambdaClient2, GetDurableExecutionHistoryCommand, "Marker", "NextMarker", "MaxItems");
    var paginateGetDurableExecutionState = core.createPaginator(LambdaClient2, GetDurableExecutionStateCommand, "Marker", "NextMarker", "MaxItems");
    var paginateListAliases = core.createPaginator(LambdaClient2, ListAliasesCommand2, "Marker", "NextMarker", "MaxItems");
    var paginateListCapacityProviders = core.createPaginator(LambdaClient2, ListCapacityProvidersCommand, "Marker", "NextMarker", "MaxItems");
    var paginateListCodeSigningConfigs = core.createPaginator(LambdaClient2, ListCodeSigningConfigsCommand, "Marker", "NextMarker", "MaxItems");
    var paginateListDurableExecutionsByFunction = core.createPaginator(LambdaClient2, ListDurableExecutionsByFunctionCommand, "Marker", "NextMarker", "MaxItems");
    var paginateListEventSourceMappings = core.createPaginator(LambdaClient2, ListEventSourceMappingsCommand, "Marker", "NextMarker", "MaxItems");
    var paginateListFunctionEventInvokeConfigs = core.createPaginator(LambdaClient2, ListFunctionEventInvokeConfigsCommand, "Marker", "NextMarker", "MaxItems");
    var paginateListFunctionsByCodeSigningConfig = core.createPaginator(LambdaClient2, ListFunctionsByCodeSigningConfigCommand, "Marker", "NextMarker", "MaxItems");
    var paginateListFunctions2 = core.createPaginator(LambdaClient2, ListFunctionsCommand, "Marker", "NextMarker", "MaxItems");
    var paginateListFunctionUrlConfigs = core.createPaginator(LambdaClient2, ListFunctionUrlConfigsCommand, "Marker", "NextMarker", "MaxItems");
    var paginateListFunctionVersionsByCapacityProvider = core.createPaginator(LambdaClient2, ListFunctionVersionsByCapacityProviderCommand, "Marker", "NextMarker", "MaxItems");
    var paginateListLayers = core.createPaginator(LambdaClient2, ListLayersCommand, "Marker", "NextMarker", "MaxItems");
    var paginateListLayerVersions = core.createPaginator(LambdaClient2, ListLayerVersionsCommand, "Marker", "NextMarker", "MaxItems");
    var paginateListProvisionedConcurrencyConfigs = core.createPaginator(LambdaClient2, ListProvisionedConcurrencyConfigsCommand, "Marker", "NextMarker", "MaxItems");
    var paginateListVersionsByFunction = core.createPaginator(LambdaClient2, ListVersionsByFunctionCommand, "Marker", "NextMarker", "MaxItems");
    var checkState$5 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new GetFunctionConfigurationCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.State;
          }, "returnComparator");
          if (returnComparator() === "Active") {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.State;
          }, "returnComparator");
          if (returnComparator() === "Failed") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.State;
          }, "returnComparator");
          if (returnComparator() === "Pending") {
            return { state: utilWaiter.WaiterState.RETRY, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$5");
    var waitForFunctionActive = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 300 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$5);
    }, "waitForFunctionActive");
    var waitUntilFunctionActive = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 300 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$5);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilFunctionActive");
    var checkState$4 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new GetFunctionCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.Configuration.State;
          }, "returnComparator");
          if (returnComparator() === "Active") {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.Configuration.State;
          }, "returnComparator");
          if (returnComparator() === "Failed") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.Configuration.State;
          }, "returnComparator");
          if (returnComparator() === "Pending") {
            return { state: utilWaiter.WaiterState.RETRY, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$4");
    var waitForFunctionActiveV2 = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 1, maxDelay: 300 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$4);
    }, "waitForFunctionActiveV2");
    var waitUntilFunctionActiveV2 = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 1, maxDelay: 300 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$4);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilFunctionActiveV2");
    var checkState$3 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new GetFunctionCommand(input));
        reason = result2;
        return { state: utilWaiter.WaiterState.SUCCESS, reason };
      } catch (exception) {
        reason = exception;
        if (exception.name === "ResourceNotFoundException") {
          return { state: utilWaiter.WaiterState.RETRY, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$3");
    var waitForFunctionExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 1, maxDelay: 20 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$3);
    }, "waitForFunctionExists");
    var waitUntilFunctionExists = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 1, maxDelay: 20 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$3);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilFunctionExists");
    var checkState$2 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new GetFunctionConfigurationCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.LastUpdateStatus;
          }, "returnComparator");
          if (returnComparator() === "Successful") {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.LastUpdateStatus;
          }, "returnComparator");
          if (returnComparator() === "Failed") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.LastUpdateStatus;
          }, "returnComparator");
          if (returnComparator() === "InProgress") {
            return { state: utilWaiter.WaiterState.RETRY, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$2");
    var waitForFunctionUpdated = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 300 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$2);
    }, "waitForFunctionUpdated");
    var waitUntilFunctionUpdated = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 300 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$2);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilFunctionUpdated");
    var checkState$1 = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new GetFunctionCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.Configuration.LastUpdateStatus;
          }, "returnComparator");
          if (returnComparator() === "Successful") {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.Configuration.LastUpdateStatus;
          }, "returnComparator");
          if (returnComparator() === "Failed") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.Configuration.LastUpdateStatus;
          }, "returnComparator");
          if (returnComparator() === "InProgress") {
            return { state: utilWaiter.WaiterState.RETRY, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState$1");
    var waitForFunctionUpdatedV2 = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 1, maxDelay: 300 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$1);
    }, "waitForFunctionUpdatedV2");
    var waitUntilFunctionUpdatedV22 = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 1, maxDelay: 300 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState$1);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilFunctionUpdatedV2");
    var checkState = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new GetFunctionConfigurationCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.State;
          }, "returnComparator");
          if (returnComparator() === "Active") {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.State;
          }, "returnComparator");
          if (returnComparator() === "Failed") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.State;
          }, "returnComparator");
          if (returnComparator() === "Pending") {
            return { state: utilWaiter.WaiterState.RETRY, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState");
    var waitForPublishedVersionActive = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 1560 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState);
    }, "waitForPublishedVersionActive");
    var waitUntilPublishedVersionActive = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 1560 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilPublishedVersionActive");
    var commands32 = {
      AddLayerVersionPermissionCommand,
      AddPermissionCommand,
      CheckpointDurableExecutionCommand,
      CreateAliasCommand,
      CreateCapacityProviderCommand,
      CreateCodeSigningConfigCommand,
      CreateEventSourceMappingCommand,
      CreateFunctionCommand,
      CreateFunctionUrlConfigCommand,
      DeleteAliasCommand,
      DeleteCapacityProviderCommand,
      DeleteCodeSigningConfigCommand,
      DeleteEventSourceMappingCommand,
      DeleteFunctionCommand,
      DeleteFunctionCodeSigningConfigCommand,
      DeleteFunctionConcurrencyCommand,
      DeleteFunctionEventInvokeConfigCommand,
      DeleteFunctionUrlConfigCommand,
      DeleteLayerVersionCommand,
      DeleteProvisionedConcurrencyConfigCommand,
      GetAccountSettingsCommand,
      GetAliasCommand,
      GetCapacityProviderCommand,
      GetCodeSigningConfigCommand,
      GetDurableExecutionCommand,
      GetDurableExecutionHistoryCommand,
      GetDurableExecutionStateCommand,
      GetEventSourceMappingCommand,
      GetFunctionCommand,
      GetFunctionCodeSigningConfigCommand,
      GetFunctionConcurrencyCommand,
      GetFunctionConfigurationCommand,
      GetFunctionEventInvokeConfigCommand,
      GetFunctionRecursionConfigCommand,
      GetFunctionScalingConfigCommand,
      GetFunctionUrlConfigCommand,
      GetLayerVersionCommand,
      GetLayerVersionByArnCommand,
      GetLayerVersionPolicyCommand,
      GetPolicyCommand: GetPolicyCommand2,
      GetProvisionedConcurrencyConfigCommand,
      GetRuntimeManagementConfigCommand,
      InvokeCommand: InvokeCommand2,
      InvokeAsyncCommand,
      InvokeWithResponseStreamCommand,
      ListAliasesCommand: ListAliasesCommand2,
      ListCapacityProvidersCommand,
      ListCodeSigningConfigsCommand,
      ListDurableExecutionsByFunctionCommand,
      ListEventSourceMappingsCommand,
      ListFunctionEventInvokeConfigsCommand,
      ListFunctionsCommand,
      ListFunctionsByCodeSigningConfigCommand,
      ListFunctionUrlConfigsCommand,
      ListFunctionVersionsByCapacityProviderCommand,
      ListLayersCommand,
      ListLayerVersionsCommand,
      ListProvisionedConcurrencyConfigsCommand,
      ListTagsCommand,
      ListVersionsByFunctionCommand,
      PublishLayerVersionCommand,
      PublishVersionCommand: PublishVersionCommand2,
      PutFunctionCodeSigningConfigCommand,
      PutFunctionConcurrencyCommand,
      PutFunctionEventInvokeConfigCommand,
      PutFunctionRecursionConfigCommand,
      PutFunctionScalingConfigCommand,
      PutProvisionedConcurrencyConfigCommand,
      PutRuntimeManagementConfigCommand,
      RemoveLayerVersionPermissionCommand,
      RemovePermissionCommand,
      SendDurableExecutionCallbackFailureCommand,
      SendDurableExecutionCallbackHeartbeatCommand,
      SendDurableExecutionCallbackSuccessCommand,
      StopDurableExecutionCommand,
      TagResourceCommand,
      UntagResourceCommand,
      UpdateAliasCommand: UpdateAliasCommand2,
      UpdateCapacityProviderCommand,
      UpdateCodeSigningConfigCommand,
      UpdateEventSourceMappingCommand,
      UpdateFunctionCodeCommand: UpdateFunctionCodeCommand2,
      UpdateFunctionConfigurationCommand: UpdateFunctionConfigurationCommand2,
      UpdateFunctionEventInvokeConfigCommand,
      UpdateFunctionUrlConfigCommand
    };
    var paginators = {
      paginateGetDurableExecutionHistory,
      paginateGetDurableExecutionState,
      paginateListAliases,
      paginateListCapacityProviders,
      paginateListCodeSigningConfigs,
      paginateListDurableExecutionsByFunction,
      paginateListEventSourceMappings,
      paginateListFunctionEventInvokeConfigs,
      paginateListFunctions: paginateListFunctions2,
      paginateListFunctionsByCodeSigningConfig,
      paginateListFunctionUrlConfigs,
      paginateListFunctionVersionsByCapacityProvider,
      paginateListLayers,
      paginateListLayerVersions,
      paginateListProvisionedConcurrencyConfigs,
      paginateListVersionsByFunction
    };
    var waiters = {
      waitUntilFunctionActiveV2,
      waitUntilFunctionExists,
      waitUntilFunctionUpdatedV2: waitUntilFunctionUpdatedV22,
      waitUntilFunctionActive,
      waitUntilFunctionUpdated,
      waitUntilPublishedVersionActive
    };
    var Lambda = class extends LambdaClient2 {
      static {
        __name(this, "Lambda");
      }
    };
    smithyClient.createAggregatedClient(commands32, Lambda, { paginators, waiters });
    var ThrottleReason = {
      CallerRateLimitExceeded: "CallerRateLimitExceeded",
      ConcurrentInvocationLimitExceeded: "ConcurrentInvocationLimitExceeded",
      ConcurrentSnapshotCreateLimitExceeded: "ConcurrentSnapshotCreateLimitExceeded",
      FunctionInvocationRateLimitExceeded: "FunctionInvocationRateLimitExceeded",
      ReservedFunctionConcurrentInvocationLimitExceeded: "ReservedFunctionConcurrentInvocationLimitExceeded",
      ReservedFunctionInvocationRateLimitExceeded: "ReservedFunctionInvocationRateLimitExceeded"
    };
    var FunctionUrlAuthType = {
      AWS_IAM: "AWS_IAM",
      NONE: "NONE"
    };
    var KafkaSchemaRegistryAuthType = {
      BASIC_AUTH: "BASIC_AUTH",
      CLIENT_CERTIFICATE_TLS_AUTH: "CLIENT_CERTIFICATE_TLS_AUTH",
      SERVER_ROOT_CA_CERTIFICATE: "SERVER_ROOT_CA_CERTIFICATE"
    };
    var SchemaRegistryEventRecordFormat = {
      JSON: "JSON",
      SOURCE: "SOURCE"
    };
    var KafkaSchemaValidationAttribute = {
      KEY: "KEY",
      VALUE: "VALUE"
    };
    var ApplicationLogLevel = {
      Debug: "DEBUG",
      Error: "ERROR",
      Fatal: "FATAL",
      Info: "INFO",
      Trace: "TRACE",
      Warn: "WARN"
    };
    var Architecture = {
      arm64: "arm64",
      x86_64: "x86_64"
    };
    var CapacityProviderScalingMode = {
      Auto: "Auto",
      Manual: "Manual"
    };
    var CapacityProviderPredefinedMetricType = {
      LambdaCapacityProviderAverageCPUUtilization: "LambdaCapacityProviderAverageCPUUtilization"
    };
    var CapacityProviderState = {
      Active: "Active",
      Deleting: "Deleting",
      Failed: "Failed",
      Pending: "Pending"
    };
    var State = {
      Active: "Active",
      ActiveNonInvocable: "ActiveNonInvocable",
      Deactivated: "Deactivated",
      Deactivating: "Deactivating",
      Deleting: "Deleting",
      Failed: "Failed",
      Inactive: "Inactive",
      Pending: "Pending"
    };
    var OperationAction = {
      CANCEL: "CANCEL",
      FAIL: "FAIL",
      RETRY: "RETRY",
      START: "START",
      SUCCEED: "SUCCEED"
    };
    var OperationType = {
      CALLBACK: "CALLBACK",
      CHAINED_INVOKE: "CHAINED_INVOKE",
      CONTEXT: "CONTEXT",
      EXECUTION: "EXECUTION",
      STEP: "STEP",
      WAIT: "WAIT"
    };
    var OperationStatus = {
      CANCELLED: "CANCELLED",
      FAILED: "FAILED",
      PENDING: "PENDING",
      READY: "READY",
      STARTED: "STARTED",
      STOPPED: "STOPPED",
      SUCCEEDED: "SUCCEEDED",
      TIMED_OUT: "TIMED_OUT"
    };
    var CodeSigningPolicy = {
      Enforce: "Enforce",
      Warn: "Warn"
    };
    var FullDocument = {
      Default: "Default",
      UpdateLookup: "UpdateLookup"
    };
    var FunctionResponseType = {
      ReportBatchItemFailures: "ReportBatchItemFailures"
    };
    var EventSourceMappingSystemLogLevel = {
      Debug: "DEBUG",
      Info: "INFO",
      Warn: "WARN"
    };
    var EventSourceMappingMetric = {
      ErrorCount: "ErrorCount",
      EventCount: "EventCount",
      KafkaMetrics: "KafkaMetrics"
    };
    var EndPointType = {
      KAFKA_BOOTSTRAP_SERVERS: "KAFKA_BOOTSTRAP_SERVERS"
    };
    var SourceAccessType = {
      BASIC_AUTH: "BASIC_AUTH",
      CLIENT_CERTIFICATE_TLS_AUTH: "CLIENT_CERTIFICATE_TLS_AUTH",
      SASL_SCRAM_256_AUTH: "SASL_SCRAM_256_AUTH",
      SASL_SCRAM_512_AUTH: "SASL_SCRAM_512_AUTH",
      SERVER_ROOT_CA_CERTIFICATE: "SERVER_ROOT_CA_CERTIFICATE",
      VIRTUAL_HOST: "VIRTUAL_HOST",
      VPC_SECURITY_GROUP: "VPC_SECURITY_GROUP",
      VPC_SUBNET: "VPC_SUBNET"
    };
    var EventSourcePosition = {
      AT_TIMESTAMP: "AT_TIMESTAMP",
      LATEST: "LATEST",
      TRIM_HORIZON: "TRIM_HORIZON"
    };
    var LogFormat = {
      Json: "JSON",
      Text: "Text"
    };
    var SystemLogLevel = {
      Debug: "DEBUG",
      Info: "INFO",
      Warn: "WARN"
    };
    var PackageType = {
      Image: "Image",
      Zip: "Zip"
    };
    var FunctionVersionLatestPublished = {
      LATEST_PUBLISHED: "LATEST_PUBLISHED"
    };
    var Runtime = {
      dotnet10: "dotnet10",
      dotnet6: "dotnet6",
      dotnet8: "dotnet8",
      dotnetcore10: "dotnetcore1.0",
      dotnetcore20: "dotnetcore2.0",
      dotnetcore21: "dotnetcore2.1",
      dotnetcore31: "dotnetcore3.1",
      go1x: "go1.x",
      java11: "java11",
      java17: "java17",
      java21: "java21",
      java25: "java25",
      java8: "java8",
      java8al2: "java8.al2",
      nodejs: "nodejs",
      nodejs10x: "nodejs10.x",
      nodejs12x: "nodejs12.x",
      nodejs14x: "nodejs14.x",
      nodejs16x: "nodejs16.x",
      nodejs18x: "nodejs18.x",
      nodejs20x: "nodejs20.x",
      nodejs22x: "nodejs22.x",
      nodejs24x: "nodejs24.x",
      nodejs43: "nodejs4.3",
      nodejs43edge: "nodejs4.3-edge",
      nodejs610: "nodejs6.10",
      nodejs810: "nodejs8.10",
      provided: "provided",
      providedal2: "provided.al2",
      providedal2023: "provided.al2023",
      python27: "python2.7",
      python310: "python3.10",
      python311: "python3.11",
      python312: "python3.12",
      python313: "python3.13",
      python314: "python3.14",
      python36: "python3.6",
      python37: "python3.7",
      python38: "python3.8",
      python39: "python3.9",
      ruby25: "ruby2.5",
      ruby27: "ruby2.7",
      ruby32: "ruby3.2",
      ruby33: "ruby3.3",
      ruby34: "ruby3.4",
      ruby40: "ruby4.0"
    };
    var SnapStartApplyOn = {
      None: "None",
      PublishedVersions: "PublishedVersions"
    };
    var TenantIsolationMode = {
      PER_TENANT: "PER_TENANT"
    };
    var TracingMode = {
      Active: "Active",
      PassThrough: "PassThrough"
    };
    var LastUpdateStatus = {
      Failed: "Failed",
      InProgress: "InProgress",
      Successful: "Successful"
    };
    var LastUpdateStatusReasonCode = {
      CapacityProviderScalingLimitExceeded: "CapacityProviderScalingLimitExceeded",
      DisabledKMSKey: "DisabledKMSKey",
      DisallowedByVpcEncryptionControl: "DisallowedByVpcEncryptionControl",
      EC2RequestLimitExceeded: "EC2RequestLimitExceeded",
      EFSIOError: "EFSIOError",
      EFSMountConnectivityError: "EFSMountConnectivityError",
      EFSMountFailure: "EFSMountFailure",
      EFSMountTimeout: "EFSMountTimeout",
      EniLimitExceeded: "EniLimitExceeded",
      FunctionError: "FunctionError",
      FunctionErrorExtensionInitError: "FunctionError.ExtensionInitError",
      FunctionErrorInitResourceExhausted: "FunctionError.InitResourceExhausted",
      FunctionErrorInitTimeout: "FunctionError.InitTimeout",
      FunctionErrorInvalidEntryPoint: "FunctionError.InvalidEntryPoint",
      FunctionErrorInvalidWorkingDirectory: "FunctionError.InvalidWorkingDirectory",
      FunctionErrorPermissionDenied: "FunctionError.PermissionDenied",
      FunctionErrorRuntimeInitError: "FunctionError.RuntimeInitError",
      FunctionErrorTooManyExtensions: "FunctionError.TooManyExtensions",
      ImageAccessDenied: "ImageAccessDenied",
      ImageDeleted: "ImageDeleted",
      InsufficientCapacity: "InsufficientCapacity",
      InsufficientRolePermissions: "InsufficientRolePermissions",
      InternalError: "InternalError",
      InvalidConfiguration: "InvalidConfiguration",
      InvalidImage: "InvalidImage",
      InvalidRuntime: "InvalidRuntime",
      InvalidSecurityGroup: "InvalidSecurityGroup",
      InvalidStateKMSKey: "InvalidStateKMSKey",
      InvalidSubnet: "InvalidSubnet",
      InvalidZipFileException: "InvalidZipFileException",
      KMSKeyAccessDenied: "KMSKeyAccessDenied",
      KMSKeyNotFound: "KMSKeyNotFound",
      SubnetOutOfIPAddresses: "SubnetOutOfIPAddresses",
      VcpuLimitExceeded: "VcpuLimitExceeded"
    };
    var SnapStartOptimizationStatus = {
      Off: "Off",
      On: "On"
    };
    var StateReasonCode = {
      CapacityProviderScalingLimitExceeded: "CapacityProviderScalingLimitExceeded",
      Creating: "Creating",
      DisabledKMSKey: "DisabledKMSKey",
      DisallowedByVpcEncryptionControl: "DisallowedByVpcEncryptionControl",
      DrainingDurableExecutions: "DrainingDurableExecutions",
      EC2RequestLimitExceeded: "EC2RequestLimitExceeded",
      EFSIOError: "EFSIOError",
      EFSMountConnectivityError: "EFSMountConnectivityError",
      EFSMountFailure: "EFSMountFailure",
      EFSMountTimeout: "EFSMountTimeout",
      EniLimitExceeded: "EniLimitExceeded",
      FunctionError: "FunctionError",
      FunctionErrorExtensionInitError: "FunctionError.ExtensionInitError",
      FunctionErrorInitResourceExhausted: "FunctionError.InitResourceExhausted",
      FunctionErrorInitTimeout: "FunctionError.InitTimeout",
      FunctionErrorInvalidEntryPoint: "FunctionError.InvalidEntryPoint",
      FunctionErrorInvalidWorkingDirectory: "FunctionError.InvalidWorkingDirectory",
      FunctionErrorPermissionDenied: "FunctionError.PermissionDenied",
      FunctionErrorRuntimeInitError: "FunctionError.RuntimeInitError",
      FunctionErrorTooManyExtensions: "FunctionError.TooManyExtensions",
      Idle: "Idle",
      ImageAccessDenied: "ImageAccessDenied",
      ImageDeleted: "ImageDeleted",
      InsufficientCapacity: "InsufficientCapacity",
      InsufficientRolePermissions: "InsufficientRolePermissions",
      InternalError: "InternalError",
      InvalidConfiguration: "InvalidConfiguration",
      InvalidImage: "InvalidImage",
      InvalidRuntime: "InvalidRuntime",
      InvalidSecurityGroup: "InvalidSecurityGroup",
      InvalidStateKMSKey: "InvalidStateKMSKey",
      InvalidSubnet: "InvalidSubnet",
      InvalidZipFileException: "InvalidZipFileException",
      KMSKeyAccessDenied: "KMSKeyAccessDenied",
      KMSKeyNotFound: "KMSKeyNotFound",
      Restoring: "Restoring",
      SubnetOutOfIPAddresses: "SubnetOutOfIPAddresses",
      VcpuLimitExceeded: "VcpuLimitExceeded"
    };
    var InvokeMode = {
      BUFFERED: "BUFFERED",
      RESPONSE_STREAM: "RESPONSE_STREAM"
    };
    var RecursiveLoop = {
      Allow: "Allow",
      Terminate: "Terminate"
    };
    var UpdateRuntimeOn = {
      Auto: "Auto",
      FunctionUpdate: "FunctionUpdate",
      Manual: "Manual"
    };
    var InvocationType = {
      DryRun: "DryRun",
      Event: "Event",
      RequestResponse: "RequestResponse"
    };
    var LogType = {
      None: "None",
      Tail: "Tail"
    };
    var ResponseStreamingInvocationType = {
      DryRun: "DryRun",
      RequestResponse: "RequestResponse"
    };
    var FunctionVersion = {
      ALL: "ALL"
    };
    var ProvisionedConcurrencyStatusEnum = {
      FAILED: "FAILED",
      IN_PROGRESS: "IN_PROGRESS",
      READY: "READY"
    };
    var ExecutionStatus = {
      FAILED: "FAILED",
      RUNNING: "RUNNING",
      STOPPED: "STOPPED",
      SUCCEEDED: "SUCCEEDED",
      TIMED_OUT: "TIMED_OUT"
    };
    var EventType2 = {
      CallbackFailed: "CallbackFailed",
      CallbackStarted: "CallbackStarted",
      CallbackSucceeded: "CallbackSucceeded",
      CallbackTimedOut: "CallbackTimedOut",
      ChainedInvokeFailed: "ChainedInvokeFailed",
      ChainedInvokeStarted: "ChainedInvokeStarted",
      ChainedInvokeStopped: "ChainedInvokeStopped",
      ChainedInvokeSucceeded: "ChainedInvokeSucceeded",
      ChainedInvokeTimedOut: "ChainedInvokeTimedOut",
      ContextFailed: "ContextFailed",
      ContextStarted: "ContextStarted",
      ContextSucceeded: "ContextSucceeded",
      ExecutionFailed: "ExecutionFailed",
      ExecutionStarted: "ExecutionStarted",
      ExecutionStopped: "ExecutionStopped",
      ExecutionSucceeded: "ExecutionSucceeded",
      ExecutionTimedOut: "ExecutionTimedOut",
      InvocationCompleted: "InvocationCompleted",
      StepFailed: "StepFailed",
      StepStarted: "StepStarted",
      StepSucceeded: "StepSucceeded",
      WaitCancelled: "WaitCancelled",
      WaitStarted: "WaitStarted",
      WaitSucceeded: "WaitSucceeded"
    };
    exports2.$Command = smithyClient.Command;
    exports2.__Client = smithyClient.Client;
    exports2.LambdaServiceException = LambdaServiceException.LambdaServiceException;
    exports2.AddLayerVersionPermissionCommand = AddLayerVersionPermissionCommand;
    exports2.AddPermissionCommand = AddPermissionCommand;
    exports2.ApplicationLogLevel = ApplicationLogLevel;
    exports2.Architecture = Architecture;
    exports2.CapacityProviderPredefinedMetricType = CapacityProviderPredefinedMetricType;
    exports2.CapacityProviderScalingMode = CapacityProviderScalingMode;
    exports2.CapacityProviderState = CapacityProviderState;
    exports2.CheckpointDurableExecutionCommand = CheckpointDurableExecutionCommand;
    exports2.CodeSigningPolicy = CodeSigningPolicy;
    exports2.CreateAliasCommand = CreateAliasCommand;
    exports2.CreateCapacityProviderCommand = CreateCapacityProviderCommand;
    exports2.CreateCodeSigningConfigCommand = CreateCodeSigningConfigCommand;
    exports2.CreateEventSourceMappingCommand = CreateEventSourceMappingCommand;
    exports2.CreateFunctionCommand = CreateFunctionCommand;
    exports2.CreateFunctionUrlConfigCommand = CreateFunctionUrlConfigCommand;
    exports2.DeleteAliasCommand = DeleteAliasCommand;
    exports2.DeleteCapacityProviderCommand = DeleteCapacityProviderCommand;
    exports2.DeleteCodeSigningConfigCommand = DeleteCodeSigningConfigCommand;
    exports2.DeleteEventSourceMappingCommand = DeleteEventSourceMappingCommand;
    exports2.DeleteFunctionCodeSigningConfigCommand = DeleteFunctionCodeSigningConfigCommand;
    exports2.DeleteFunctionCommand = DeleteFunctionCommand;
    exports2.DeleteFunctionConcurrencyCommand = DeleteFunctionConcurrencyCommand;
    exports2.DeleteFunctionEventInvokeConfigCommand = DeleteFunctionEventInvokeConfigCommand;
    exports2.DeleteFunctionUrlConfigCommand = DeleteFunctionUrlConfigCommand;
    exports2.DeleteLayerVersionCommand = DeleteLayerVersionCommand;
    exports2.DeleteProvisionedConcurrencyConfigCommand = DeleteProvisionedConcurrencyConfigCommand;
    exports2.EndPointType = EndPointType;
    exports2.EventSourceMappingMetric = EventSourceMappingMetric;
    exports2.EventSourceMappingSystemLogLevel = EventSourceMappingSystemLogLevel;
    exports2.EventSourcePosition = EventSourcePosition;
    exports2.EventType = EventType2;
    exports2.ExecutionStatus = ExecutionStatus;
    exports2.FullDocument = FullDocument;
    exports2.FunctionResponseType = FunctionResponseType;
    exports2.FunctionUrlAuthType = FunctionUrlAuthType;
    exports2.FunctionVersion = FunctionVersion;
    exports2.FunctionVersionLatestPublished = FunctionVersionLatestPublished;
    exports2.GetAccountSettingsCommand = GetAccountSettingsCommand;
    exports2.GetAliasCommand = GetAliasCommand;
    exports2.GetCapacityProviderCommand = GetCapacityProviderCommand;
    exports2.GetCodeSigningConfigCommand = GetCodeSigningConfigCommand;
    exports2.GetDurableExecutionCommand = GetDurableExecutionCommand;
    exports2.GetDurableExecutionHistoryCommand = GetDurableExecutionHistoryCommand;
    exports2.GetDurableExecutionStateCommand = GetDurableExecutionStateCommand;
    exports2.GetEventSourceMappingCommand = GetEventSourceMappingCommand;
    exports2.GetFunctionCodeSigningConfigCommand = GetFunctionCodeSigningConfigCommand;
    exports2.GetFunctionCommand = GetFunctionCommand;
    exports2.GetFunctionConcurrencyCommand = GetFunctionConcurrencyCommand;
    exports2.GetFunctionConfigurationCommand = GetFunctionConfigurationCommand;
    exports2.GetFunctionEventInvokeConfigCommand = GetFunctionEventInvokeConfigCommand;
    exports2.GetFunctionRecursionConfigCommand = GetFunctionRecursionConfigCommand;
    exports2.GetFunctionScalingConfigCommand = GetFunctionScalingConfigCommand;
    exports2.GetFunctionUrlConfigCommand = GetFunctionUrlConfigCommand;
    exports2.GetLayerVersionByArnCommand = GetLayerVersionByArnCommand;
    exports2.GetLayerVersionCommand = GetLayerVersionCommand;
    exports2.GetLayerVersionPolicyCommand = GetLayerVersionPolicyCommand;
    exports2.GetPolicyCommand = GetPolicyCommand2;
    exports2.GetProvisionedConcurrencyConfigCommand = GetProvisionedConcurrencyConfigCommand;
    exports2.GetRuntimeManagementConfigCommand = GetRuntimeManagementConfigCommand;
    exports2.InvocationType = InvocationType;
    exports2.InvokeAsyncCommand = InvokeAsyncCommand;
    exports2.InvokeCommand = InvokeCommand2;
    exports2.InvokeMode = InvokeMode;
    exports2.InvokeWithResponseStreamCommand = InvokeWithResponseStreamCommand;
    exports2.KafkaSchemaRegistryAuthType = KafkaSchemaRegistryAuthType;
    exports2.KafkaSchemaValidationAttribute = KafkaSchemaValidationAttribute;
    exports2.Lambda = Lambda;
    exports2.LambdaClient = LambdaClient2;
    exports2.LastUpdateStatus = LastUpdateStatus;
    exports2.LastUpdateStatusReasonCode = LastUpdateStatusReasonCode;
    exports2.ListAliasesCommand = ListAliasesCommand2;
    exports2.ListCapacityProvidersCommand = ListCapacityProvidersCommand;
    exports2.ListCodeSigningConfigsCommand = ListCodeSigningConfigsCommand;
    exports2.ListDurableExecutionsByFunctionCommand = ListDurableExecutionsByFunctionCommand;
    exports2.ListEventSourceMappingsCommand = ListEventSourceMappingsCommand;
    exports2.ListFunctionEventInvokeConfigsCommand = ListFunctionEventInvokeConfigsCommand;
    exports2.ListFunctionUrlConfigsCommand = ListFunctionUrlConfigsCommand;
    exports2.ListFunctionVersionsByCapacityProviderCommand = ListFunctionVersionsByCapacityProviderCommand;
    exports2.ListFunctionsByCodeSigningConfigCommand = ListFunctionsByCodeSigningConfigCommand;
    exports2.ListFunctionsCommand = ListFunctionsCommand;
    exports2.ListLayerVersionsCommand = ListLayerVersionsCommand;
    exports2.ListLayersCommand = ListLayersCommand;
    exports2.ListProvisionedConcurrencyConfigsCommand = ListProvisionedConcurrencyConfigsCommand;
    exports2.ListTagsCommand = ListTagsCommand;
    exports2.ListVersionsByFunctionCommand = ListVersionsByFunctionCommand;
    exports2.LogFormat = LogFormat;
    exports2.LogType = LogType;
    exports2.OperationAction = OperationAction;
    exports2.OperationStatus = OperationStatus;
    exports2.OperationType = OperationType;
    exports2.PackageType = PackageType;
    exports2.ProvisionedConcurrencyStatusEnum = ProvisionedConcurrencyStatusEnum;
    exports2.PublishLayerVersionCommand = PublishLayerVersionCommand;
    exports2.PublishVersionCommand = PublishVersionCommand2;
    exports2.PutFunctionCodeSigningConfigCommand = PutFunctionCodeSigningConfigCommand;
    exports2.PutFunctionConcurrencyCommand = PutFunctionConcurrencyCommand;
    exports2.PutFunctionEventInvokeConfigCommand = PutFunctionEventInvokeConfigCommand;
    exports2.PutFunctionRecursionConfigCommand = PutFunctionRecursionConfigCommand;
    exports2.PutFunctionScalingConfigCommand = PutFunctionScalingConfigCommand;
    exports2.PutProvisionedConcurrencyConfigCommand = PutProvisionedConcurrencyConfigCommand;
    exports2.PutRuntimeManagementConfigCommand = PutRuntimeManagementConfigCommand;
    exports2.RecursiveLoop = RecursiveLoop;
    exports2.RemoveLayerVersionPermissionCommand = RemoveLayerVersionPermissionCommand;
    exports2.RemovePermissionCommand = RemovePermissionCommand;
    exports2.ResponseStreamingInvocationType = ResponseStreamingInvocationType;
    exports2.Runtime = Runtime;
    exports2.SchemaRegistryEventRecordFormat = SchemaRegistryEventRecordFormat;
    exports2.SendDurableExecutionCallbackFailureCommand = SendDurableExecutionCallbackFailureCommand;
    exports2.SendDurableExecutionCallbackHeartbeatCommand = SendDurableExecutionCallbackHeartbeatCommand;
    exports2.SendDurableExecutionCallbackSuccessCommand = SendDurableExecutionCallbackSuccessCommand;
    exports2.SnapStartApplyOn = SnapStartApplyOn;
    exports2.SnapStartOptimizationStatus = SnapStartOptimizationStatus;
    exports2.SourceAccessType = SourceAccessType;
    exports2.State = State;
    exports2.StateReasonCode = StateReasonCode;
    exports2.StopDurableExecutionCommand = StopDurableExecutionCommand;
    exports2.SystemLogLevel = SystemLogLevel;
    exports2.TagResourceCommand = TagResourceCommand;
    exports2.TenantIsolationMode = TenantIsolationMode;
    exports2.ThrottleReason = ThrottleReason;
    exports2.TracingMode = TracingMode;
    exports2.UntagResourceCommand = UntagResourceCommand;
    exports2.UpdateAliasCommand = UpdateAliasCommand2;
    exports2.UpdateCapacityProviderCommand = UpdateCapacityProviderCommand;
    exports2.UpdateCodeSigningConfigCommand = UpdateCodeSigningConfigCommand;
    exports2.UpdateEventSourceMappingCommand = UpdateEventSourceMappingCommand;
    exports2.UpdateFunctionCodeCommand = UpdateFunctionCodeCommand2;
    exports2.UpdateFunctionConfigurationCommand = UpdateFunctionConfigurationCommand2;
    exports2.UpdateFunctionEventInvokeConfigCommand = UpdateFunctionEventInvokeConfigCommand;
    exports2.UpdateFunctionUrlConfigCommand = UpdateFunctionUrlConfigCommand;
    exports2.UpdateRuntimeOn = UpdateRuntimeOn;
    exports2.paginateGetDurableExecutionHistory = paginateGetDurableExecutionHistory;
    exports2.paginateGetDurableExecutionState = paginateGetDurableExecutionState;
    exports2.paginateListAliases = paginateListAliases;
    exports2.paginateListCapacityProviders = paginateListCapacityProviders;
    exports2.paginateListCodeSigningConfigs = paginateListCodeSigningConfigs;
    exports2.paginateListDurableExecutionsByFunction = paginateListDurableExecutionsByFunction;
    exports2.paginateListEventSourceMappings = paginateListEventSourceMappings;
    exports2.paginateListFunctionEventInvokeConfigs = paginateListFunctionEventInvokeConfigs;
    exports2.paginateListFunctionUrlConfigs = paginateListFunctionUrlConfigs;
    exports2.paginateListFunctionVersionsByCapacityProvider = paginateListFunctionVersionsByCapacityProvider;
    exports2.paginateListFunctions = paginateListFunctions2;
    exports2.paginateListFunctionsByCodeSigningConfig = paginateListFunctionsByCodeSigningConfig;
    exports2.paginateListLayerVersions = paginateListLayerVersions;
    exports2.paginateListLayers = paginateListLayers;
    exports2.paginateListProvisionedConcurrencyConfigs = paginateListProvisionedConcurrencyConfigs;
    exports2.paginateListVersionsByFunction = paginateListVersionsByFunction;
    exports2.waitForFunctionActive = waitForFunctionActive;
    exports2.waitForFunctionActiveV2 = waitForFunctionActiveV2;
    exports2.waitForFunctionExists = waitForFunctionExists;
    exports2.waitForFunctionUpdated = waitForFunctionUpdated;
    exports2.waitForFunctionUpdatedV2 = waitForFunctionUpdatedV2;
    exports2.waitForPublishedVersionActive = waitForPublishedVersionActive;
    exports2.waitUntilFunctionActive = waitUntilFunctionActive;
    exports2.waitUntilFunctionActiveV2 = waitUntilFunctionActiveV2;
    exports2.waitUntilFunctionExists = waitUntilFunctionExists;
    exports2.waitUntilFunctionUpdated = waitUntilFunctionUpdated;
    exports2.waitUntilFunctionUpdatedV2 = waitUntilFunctionUpdatedV22;
    exports2.waitUntilPublishedVersionActive = waitUntilPublishedVersionActive;
    Object.prototype.hasOwnProperty.call(schemas_0, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: schemas_0["__proto__"]
    });
    Object.keys(schemas_0).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = schemas_0[k32];
    });
    Object.prototype.hasOwnProperty.call(errors, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: errors["__proto__"]
    });
    Object.keys(errors).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = errors[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-route-53/dist-cjs/auth/httpAuthSchemeProvider.js
var require_httpAuthSchemeProvider17 = __commonJS({
  "../../node_modules/@aws-sdk/client-route-53/dist-cjs/auth/httpAuthSchemeProvider.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.resolveHttpAuthSchemeConfig = exports2.defaultRoute53HttpAuthSchemeProvider = exports2.defaultRoute53HttpAuthSchemeParametersProvider = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var util_middleware_1 = require_dist_cjs6();
    var defaultRoute53HttpAuthSchemeParametersProvider = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, util_middleware_1.getSmithyContext)(context).operation,
        region: await (0, util_middleware_1.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultRoute53HttpAuthSchemeParametersProvider");
    exports2.defaultRoute53HttpAuthSchemeParametersProvider = defaultRoute53HttpAuthSchemeParametersProvider;
    function createAwsAuthSigv4HttpAuthOption32(authParameters) {
      return {
        schemeId: "aws.auth#sigv4",
        signingProperties: {
          name: "route53",
          region: authParameters.region
        },
        propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
          signingProperties: {
            config: config2,
            context
          }
        }), "propertiesExtractor")
      };
    }
    __name(createAwsAuthSigv4HttpAuthOption32, "createAwsAuthSigv4HttpAuthOption");
    var defaultRoute53HttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption32(authParameters));
        }
      }
      return options;
    }, "defaultRoute53HttpAuthSchemeProvider");
    exports2.defaultRoute53HttpAuthSchemeProvider = defaultRoute53HttpAuthSchemeProvider;
    var resolveHttpAuthSchemeConfig32 = /* @__PURE__ */ __name((config2) => {
      const config_0 = (0, httpAuthSchemes_1.resolveAwsSdkSigV4Config)(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, util_middleware_1.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
    exports2.resolveHttpAuthSchemeConfig = resolveHttpAuthSchemeConfig32;
  }
});

// ../../node_modules/@aws-sdk/client-route-53/package.json
var require_package17 = __commonJS({
  "../../node_modules/@aws-sdk/client-route-53/package.json"(exports2, module2) {
    module2.exports = {
      name: "@aws-sdk/client-route-53",
      description: "AWS SDK for JavaScript Route 53 Client for Node.js, Browser and React Native",
      version: "3.1036.0",
      scripts: {
        build: "concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline client-route-53",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        "extract:docs": "api-extractor run --local",
        "generate:client": "node ../../scripts/generate-clients/single-service --solo route-53",
        test: "yarn g:vitest run --passWithNoTests",
        "test:e2e": "yarn g:vitest run -c vitest.config.e2e.mts --mode development",
        "test:e2e:watch": "yarn g:vitest watch -c vitest.config.e2e.mts",
        "test:index": "tsc --noEmit ./test/index-types.ts && node ./test/index-objects.spec.mjs",
        "test:integration": "yarn g:vitest run --passWithNoTests -c vitest.config.integ.mts",
        "test:integration:watch": "yarn g:vitest run --passWithNoTests -c vitest.config.integ.mts",
        "test:watch": "yarn g:vitest watch --passWithNoTests"
      },
      main: "./dist-cjs/index.js",
      types: "./dist-types/index.d.ts",
      module: "./dist-es/index.js",
      sideEffects: false,
      dependencies: {
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.5",
        "@aws-sdk/credential-provider-node": "^3.972.36",
        "@aws-sdk/middleware-host-header": "^3.972.10",
        "@aws-sdk/middleware-logger": "^3.972.10",
        "@aws-sdk/middleware-recursion-detection": "^3.972.11",
        "@aws-sdk/middleware-sdk-route53": "^3.972.12",
        "@aws-sdk/middleware-user-agent": "^3.972.35",
        "@aws-sdk/region-config-resolver": "^3.972.13",
        "@aws-sdk/types": "^3.973.8",
        "@aws-sdk/util-endpoints": "^3.996.8",
        "@aws-sdk/util-user-agent-browser": "^3.972.10",
        "@aws-sdk/util-user-agent-node": "^3.973.21",
        "@smithy/config-resolver": "^4.4.17",
        "@smithy/core": "^3.23.17",
        "@smithy/fetch-http-handler": "^5.3.17",
        "@smithy/hash-node": "^4.2.14",
        "@smithy/invalid-dependency": "^4.2.14",
        "@smithy/middleware-content-length": "^4.2.14",
        "@smithy/middleware-endpoint": "^4.4.32",
        "@smithy/middleware-retry": "^4.5.5",
        "@smithy/middleware-serde": "^4.2.20",
        "@smithy/middleware-stack": "^4.2.14",
        "@smithy/node-config-provider": "^4.3.14",
        "@smithy/node-http-handler": "^4.6.1",
        "@smithy/protocol-http": "^5.3.14",
        "@smithy/smithy-client": "^4.12.13",
        "@smithy/types": "^4.14.1",
        "@smithy/url-parser": "^4.2.14",
        "@smithy/util-base64": "^4.3.2",
        "@smithy/util-body-length-browser": "^4.2.2",
        "@smithy/util-body-length-node": "^4.2.3",
        "@smithy/util-defaults-mode-browser": "^4.3.49",
        "@smithy/util-defaults-mode-node": "^4.2.54",
        "@smithy/util-endpoints": "^3.4.2",
        "@smithy/util-middleware": "^4.2.14",
        "@smithy/util-retry": "^4.3.4",
        "@smithy/util-utf8": "^4.2.2",
        "@smithy/util-waiter": "^4.2.16",
        tslib: "^2.6.2"
      },
      devDependencies: {
        "@smithy/snapshot-testing": "^2.0.8",
        "@tsconfig/node20": "20.1.8",
        "@types/node": "^20.14.8",
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3",
        vitest: "^4.0.17"
      },
      engines: {
        node: ">=20.0.0"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "dist-*/**"
      ],
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      browser: {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.browser"
      },
      "react-native": {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.native"
      },
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/clients/client-route-53",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "clients/client-route-53"
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-route-53/dist-cjs/endpoint/bdd.js
var require_bdd17 = __commonJS({
  "../../node_modules/@aws-sdk/client-route-53/dist-cjs/endpoint/bdd.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.bdd = void 0;
    var util_endpoints_1 = require_dist_cjs20();
    var s = "ref";
    var t = "authSchemes";
    var u = "name";
    var v = "signingRegion";
    var a32 = -1;
    var b32 = true;
    var c32 = "isSet";
    var d32 = "PartitionResult";
    var e32 = "booleanEquals";
    var f32 = "stringEquals";
    var g32 = "getAttr";
    var h32 = "sigv4";
    var i32 = { [s]: "Endpoint" };
    var j32 = { "fn": g32, "argv": [{ [s]: d32 }, "name"] };
    var k32 = { [s]: d32 };
    var l20 = { [t]: [{ [u]: h32, [v]: "us-east-1" }] };
    var m20 = { [t]: [{ [u]: h32, [v]: "cn-northwest-1" }] };
    var n10 = { [t]: [{ [u]: h32, [v]: "us-gov-west-1" }] };
    var o10 = { [t]: [{ [u]: h32, [v]: "eusc-de-east-1" }] };
    var p10 = { [t]: [{ [u]: h32, [v]: "{PartitionResult#implicitGlobalRegion}" }] };
    var q10 = [{ [s]: "Region" }];
    var _data32 = {
      conditions: [
        [c32, [i32]],
        [c32, q10],
        ["aws.partition", q10, d32],
        [e32, [{ [s]: "UseFIPS" }, b32]],
        [f32, [j32, "aws"]],
        [f32, [j32, "aws-cn"]],
        [f32, [j32, "aws-us-gov"]],
        [e32, [{ [s]: "UseDualStack" }, b32]],
        [e32, [{ fn: g32, argv: [k32, "supportsFIPS"] }, b32]],
        [f32, [j32, "aws-iso"]],
        [f32, [j32, "aws-iso-b"]],
        [f32, [j32, "aws-iso-e"]],
        [f32, [j32, "aws-iso-f"]],
        [f32, [j32, "aws-eusc"]],
        [e32, [{ fn: g32, argv: [k32, "supportsDualStack"] }, b32]]
      ],
      results: [
        [a32],
        [a32, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a32, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [i32, {}],
        ["https://route53.amazonaws.com", l20],
        ["https://route53-fips.amazonaws.com", l20],
        ["https://route53.global.api.aws", l20],
        ["https://route53-fips.global.api.aws", l20],
        ["https://route53.amazonaws.com.cn", m20],
        ["https://route53.global.api.amazonwebservices.com.cn", m20],
        ["https://route53.us-gov.amazonaws.com", n10],
        ["https://route53.us-gov.api.aws", n10],
        ["https://route53.c2s.ic.gov", { [t]: [{ [u]: h32, [v]: "us-iso-east-1" }] }],
        ["https://route53.sc2s.sgov.gov", { [t]: [{ [u]: h32, [v]: "us-isob-east-1" }] }],
        ["https://route53.cloud.adc-e.uk", { [t]: [{ [u]: h32, [v]: "eu-isoe-west-1" }] }],
        ["https://route53.csp.hci.ic.gov", { [t]: [{ [u]: h32, [v]: "us-isof-south-1" }] }],
        ["https://route53.amazonaws.eu", o10],
        ["https://route53.global.api.amazonwebservices.eu", o10],
        ["https://route53-fips.{PartitionResult#dualStackDnsSuffix}", p10],
        [a32, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://route53-fips.{PartitionResult#dnsSuffix}", p10],
        [a32, "FIPS is enabled but this partition does not support FIPS"],
        ["https://route53.{PartitionResult#dualStackDnsSuffix}", p10],
        [a32, "DualStack is enabled but this partition does not support DualStack"],
        ["https://route53.{PartitionResult#dnsSuffix}", p10],
        [a32, "Invalid Configuration: Missing Region"]
      ]
    };
    var root32 = 2;
    var r32 = 1e8;
    var nodes32 = new Int32Array([
      -1,
      1,
      -1,
      0,
      27,
      3,
      1,
      4,
      r32 + 25,
      2,
      5,
      r32 + 25,
      3,
      19,
      6,
      4,
      18,
      7,
      5,
      17,
      8,
      6,
      25,
      9,
      7,
      15,
      10,
      9,
      r32 + 12,
      11,
      10,
      r32 + 13,
      12,
      11,
      r32 + 14,
      13,
      12,
      r32 + 15,
      14,
      13,
      r32 + 16,
      r32 + 24,
      13,
      r32 + 17,
      16,
      14,
      r32 + 22,
      r32 + 23,
      7,
      r32 + 9,
      r32 + 8,
      7,
      r32 + 6,
      r32 + 4,
      4,
      26,
      20,
      6,
      25,
      21,
      7,
      23,
      22,
      8,
      r32 + 20,
      r32 + 21,
      8,
      24,
      r32 + 19,
      14,
      r32 + 18,
      r32 + 19,
      7,
      r32 + 11,
      r32 + 10,
      7,
      r32 + 7,
      r32 + 5,
      3,
      r32 + 1,
      28,
      7,
      r32 + 2,
      r32 + 3
    ]);
    exports2.bdd = util_endpoints_1.BinaryDecisionDiagram.from(nodes32, root32, _data32.conditions, _data32.results);
  }
});

// ../../node_modules/@aws-sdk/client-route-53/dist-cjs/endpoint/endpointResolver.js
var require_endpointResolver17 = __commonJS({
  "../../node_modules/@aws-sdk/client-route-53/dist-cjs/endpoint/endpointResolver.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.defaultEndpointResolver = void 0;
    var util_endpoints_1 = require_dist_cjs21();
    var util_endpoints_2 = require_dist_cjs20();
    var bdd_1 = require_bdd17();
    var cache32 = new util_endpoints_2.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    var defaultEndpointResolver32 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache32.get(endpointParams, () => (0, util_endpoints_2.decideEndpoint)(bdd_1.bdd, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    exports2.defaultEndpointResolver = defaultEndpointResolver32;
    util_endpoints_2.customEndpointFunctions.aws = util_endpoints_1.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-route-53/dist-cjs/models/Route53ServiceException.js
var require_Route53ServiceException = __commonJS({
  "../../node_modules/@aws-sdk/client-route-53/dist-cjs/models/Route53ServiceException.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.Route53ServiceException = exports2.__ServiceException = void 0;
    var smithy_client_1 = require_dist_cjs34();
    Object.defineProperty(exports2, "__ServiceException", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return smithy_client_1.ServiceException;
    }, "get") });
    var Route53ServiceException = class _Route53ServiceException extends smithy_client_1.ServiceException {
      static {
        __name(this, "Route53ServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _Route53ServiceException.prototype);
      }
    };
    exports2.Route53ServiceException = Route53ServiceException;
  }
});

// ../../node_modules/@aws-sdk/client-route-53/dist-cjs/models/errors.js
var require_errors16 = __commonJS({
  "../../node_modules/@aws-sdk/client-route-53/dist-cjs/models/errors.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.HealthCheckInUse = exports2.CidrCollectionInUseException = exports2.KeySigningKeyInUse = exports2.KeySigningKeyInParentDSRecord = exports2.TooManyVPCAssociationAuthorizations = exports2.TooManyTrafficPolicyVersionsForCurrentPolicy = exports2.TrafficPolicyInstanceAlreadyExists = exports2.TooManyTrafficPolicyInstances = exports2.NoSuchTrafficPolicy = exports2.TrafficPolicyAlreadyExists = exports2.TooManyTrafficPolicies = exports2.InvalidTrafficPolicyDocument = exports2.HostedZoneNotFound = exports2.DelegationSetAlreadyReusable = exports2.DelegationSetAlreadyCreated = exports2.QueryLoggingConfigAlreadyExists = exports2.NoSuchCloudWatchLogsLogGroup = exports2.InsufficientCloudWatchLogsResourcePolicy = exports2.TooManyKeySigningKeys = exports2.KeySigningKeyAlreadyExists = exports2.InvalidKeySigningKeyName = exports2.InvalidArgument = exports2.TooManyHostedZones = exports2.NoSuchDelegationSet = exports2.InvalidDomainName = exports2.HostedZoneAlreadyExists = exports2.DelegationSetNotReusable = exports2.DelegationSetNotAvailable = exports2.TooManyHealthChecks = exports2.HealthCheckAlreadyExists = exports2.CidrCollectionAlreadyExistsException = exports2.ThrottlingException = exports2.NoSuchHealthCheck = exports2.InvalidChangeBatch = exports2.NoSuchCidrCollectionException = exports2.CidrCollectionVersionMismatchException = exports2.CidrBlockInUseException = exports2.PublicZoneVPCAssociation = exports2.PriorRequestNotComplete = exports2.NotAuthorizedException = exports2.NoSuchHostedZone = exports2.LimitsExceeded = exports2.InvalidVPCId = exports2.ConflictingDomainExists = exports2.NoSuchKeySigningKey = exports2.InvalidSigningStatus = exports2.InvalidKMSArn = exports2.InvalidKeySigningKeyStatus = exports2.InvalidInput = exports2.ConcurrentModification = void 0;
    exports2.ConflictingTypes = exports2.HealthCheckVersionMismatch = exports2.InvalidPaginationToken = exports2.NoSuchCidrLocationException = exports2.HostedZoneNotPrivate = exports2.IncompatibleVersion = exports2.NoSuchGeoLocation = exports2.NoSuchChange = exports2.KeySigningKeyWithActiveStatusNotFound = exports2.HostedZonePartiallyDelegated = exports2.VPCAssociationNotFound = exports2.LastVPCAssociation = exports2.DNSSECNotFound = exports2.VPCAssociationAuthorizationNotFound = exports2.NoSuchTrafficPolicyInstance = exports2.TrafficPolicyInUse = exports2.DelegationSetInUse = exports2.NoSuchQueryLoggingConfig = exports2.HostedZoneNotEmpty = void 0;
    var Route53ServiceException_1 = require_Route53ServiceException();
    var ConcurrentModification = class _ConcurrentModification extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "ConcurrentModification");
      }
      name = "ConcurrentModification";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ConcurrentModification",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ConcurrentModification.prototype);
      }
    };
    exports2.ConcurrentModification = ConcurrentModification;
    var InvalidInput = class _InvalidInput extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "InvalidInput");
      }
      name = "InvalidInput";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidInput",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidInput.prototype);
      }
    };
    exports2.InvalidInput = InvalidInput;
    var InvalidKeySigningKeyStatus = class _InvalidKeySigningKeyStatus extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "InvalidKeySigningKeyStatus");
      }
      name = "InvalidKeySigningKeyStatus";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidKeySigningKeyStatus",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidKeySigningKeyStatus.prototype);
      }
    };
    exports2.InvalidKeySigningKeyStatus = InvalidKeySigningKeyStatus;
    var InvalidKMSArn = class _InvalidKMSArn extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "InvalidKMSArn");
      }
      name = "InvalidKMSArn";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidKMSArn",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidKMSArn.prototype);
      }
    };
    exports2.InvalidKMSArn = InvalidKMSArn;
    var InvalidSigningStatus = class _InvalidSigningStatus extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "InvalidSigningStatus");
      }
      name = "InvalidSigningStatus";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidSigningStatus",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidSigningStatus.prototype);
      }
    };
    exports2.InvalidSigningStatus = InvalidSigningStatus;
    var NoSuchKeySigningKey = class _NoSuchKeySigningKey extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "NoSuchKeySigningKey");
      }
      name = "NoSuchKeySigningKey";
      $fault = "client";
      constructor(opts) {
        super({
          name: "NoSuchKeySigningKey",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _NoSuchKeySigningKey.prototype);
      }
    };
    exports2.NoSuchKeySigningKey = NoSuchKeySigningKey;
    var ConflictingDomainExists = class _ConflictingDomainExists extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "ConflictingDomainExists");
      }
      name = "ConflictingDomainExists";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ConflictingDomainExists",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ConflictingDomainExists.prototype);
      }
    };
    exports2.ConflictingDomainExists = ConflictingDomainExists;
    var InvalidVPCId = class _InvalidVPCId extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "InvalidVPCId");
      }
      name = "InvalidVPCId";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidVPCId",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidVPCId.prototype);
      }
    };
    exports2.InvalidVPCId = InvalidVPCId;
    var LimitsExceeded = class _LimitsExceeded extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "LimitsExceeded");
      }
      name = "LimitsExceeded";
      $fault = "client";
      constructor(opts) {
        super({
          name: "LimitsExceeded",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _LimitsExceeded.prototype);
      }
    };
    exports2.LimitsExceeded = LimitsExceeded;
    var NoSuchHostedZone = class _NoSuchHostedZone extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "NoSuchHostedZone");
      }
      name = "NoSuchHostedZone";
      $fault = "client";
      constructor(opts) {
        super({
          name: "NoSuchHostedZone",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _NoSuchHostedZone.prototype);
      }
    };
    exports2.NoSuchHostedZone = NoSuchHostedZone;
    var NotAuthorizedException2 = class _NotAuthorizedException extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "NotAuthorizedException");
      }
      name = "NotAuthorizedException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "NotAuthorizedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _NotAuthorizedException.prototype);
      }
    };
    exports2.NotAuthorizedException = NotAuthorizedException2;
    var PriorRequestNotComplete = class _PriorRequestNotComplete extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "PriorRequestNotComplete");
      }
      name = "PriorRequestNotComplete";
      $fault = "client";
      constructor(opts) {
        super({
          name: "PriorRequestNotComplete",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _PriorRequestNotComplete.prototype);
      }
    };
    exports2.PriorRequestNotComplete = PriorRequestNotComplete;
    var PublicZoneVPCAssociation = class _PublicZoneVPCAssociation extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "PublicZoneVPCAssociation");
      }
      name = "PublicZoneVPCAssociation";
      $fault = "client";
      constructor(opts) {
        super({
          name: "PublicZoneVPCAssociation",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _PublicZoneVPCAssociation.prototype);
      }
    };
    exports2.PublicZoneVPCAssociation = PublicZoneVPCAssociation;
    var CidrBlockInUseException = class _CidrBlockInUseException extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "CidrBlockInUseException");
      }
      name = "CidrBlockInUseException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "CidrBlockInUseException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CidrBlockInUseException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.CidrBlockInUseException = CidrBlockInUseException;
    var CidrCollectionVersionMismatchException = class _CidrCollectionVersionMismatchException extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "CidrCollectionVersionMismatchException");
      }
      name = "CidrCollectionVersionMismatchException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "CidrCollectionVersionMismatchException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CidrCollectionVersionMismatchException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.CidrCollectionVersionMismatchException = CidrCollectionVersionMismatchException;
    var NoSuchCidrCollectionException = class _NoSuchCidrCollectionException extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "NoSuchCidrCollectionException");
      }
      name = "NoSuchCidrCollectionException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "NoSuchCidrCollectionException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _NoSuchCidrCollectionException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.NoSuchCidrCollectionException = NoSuchCidrCollectionException;
    var InvalidChangeBatch = class _InvalidChangeBatch extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "InvalidChangeBatch");
      }
      name = "InvalidChangeBatch";
      $fault = "client";
      messages;
      constructor(opts) {
        super({
          name: "InvalidChangeBatch",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidChangeBatch.prototype);
        this.messages = opts.messages;
      }
    };
    exports2.InvalidChangeBatch = InvalidChangeBatch;
    var NoSuchHealthCheck = class _NoSuchHealthCheck extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "NoSuchHealthCheck");
      }
      name = "NoSuchHealthCheck";
      $fault = "client";
      constructor(opts) {
        super({
          name: "NoSuchHealthCheck",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _NoSuchHealthCheck.prototype);
      }
    };
    exports2.NoSuchHealthCheck = NoSuchHealthCheck;
    var ThrottlingException = class _ThrottlingException extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "ThrottlingException");
      }
      name = "ThrottlingException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ThrottlingException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ThrottlingException.prototype);
      }
    };
    exports2.ThrottlingException = ThrottlingException;
    var CidrCollectionAlreadyExistsException = class _CidrCollectionAlreadyExistsException extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "CidrCollectionAlreadyExistsException");
      }
      name = "CidrCollectionAlreadyExistsException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "CidrCollectionAlreadyExistsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CidrCollectionAlreadyExistsException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.CidrCollectionAlreadyExistsException = CidrCollectionAlreadyExistsException;
    var HealthCheckAlreadyExists = class _HealthCheckAlreadyExists extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "HealthCheckAlreadyExists");
      }
      name = "HealthCheckAlreadyExists";
      $fault = "client";
      constructor(opts) {
        super({
          name: "HealthCheckAlreadyExists",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _HealthCheckAlreadyExists.prototype);
      }
    };
    exports2.HealthCheckAlreadyExists = HealthCheckAlreadyExists;
    var TooManyHealthChecks = class _TooManyHealthChecks extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "TooManyHealthChecks");
      }
      name = "TooManyHealthChecks";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TooManyHealthChecks",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyHealthChecks.prototype);
      }
    };
    exports2.TooManyHealthChecks = TooManyHealthChecks;
    var DelegationSetNotAvailable = class _DelegationSetNotAvailable extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "DelegationSetNotAvailable");
      }
      name = "DelegationSetNotAvailable";
      $fault = "client";
      constructor(opts) {
        super({
          name: "DelegationSetNotAvailable",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DelegationSetNotAvailable.prototype);
      }
    };
    exports2.DelegationSetNotAvailable = DelegationSetNotAvailable;
    var DelegationSetNotReusable = class _DelegationSetNotReusable extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "DelegationSetNotReusable");
      }
      name = "DelegationSetNotReusable";
      $fault = "client";
      constructor(opts) {
        super({
          name: "DelegationSetNotReusable",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DelegationSetNotReusable.prototype);
      }
    };
    exports2.DelegationSetNotReusable = DelegationSetNotReusable;
    var HostedZoneAlreadyExists = class _HostedZoneAlreadyExists extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "HostedZoneAlreadyExists");
      }
      name = "HostedZoneAlreadyExists";
      $fault = "client";
      constructor(opts) {
        super({
          name: "HostedZoneAlreadyExists",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _HostedZoneAlreadyExists.prototype);
      }
    };
    exports2.HostedZoneAlreadyExists = HostedZoneAlreadyExists;
    var InvalidDomainName = class _InvalidDomainName extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "InvalidDomainName");
      }
      name = "InvalidDomainName";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidDomainName",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidDomainName.prototype);
      }
    };
    exports2.InvalidDomainName = InvalidDomainName;
    var NoSuchDelegationSet = class _NoSuchDelegationSet extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "NoSuchDelegationSet");
      }
      name = "NoSuchDelegationSet";
      $fault = "client";
      constructor(opts) {
        super({
          name: "NoSuchDelegationSet",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _NoSuchDelegationSet.prototype);
      }
    };
    exports2.NoSuchDelegationSet = NoSuchDelegationSet;
    var TooManyHostedZones = class _TooManyHostedZones extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "TooManyHostedZones");
      }
      name = "TooManyHostedZones";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TooManyHostedZones",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyHostedZones.prototype);
      }
    };
    exports2.TooManyHostedZones = TooManyHostedZones;
    var InvalidArgument = class _InvalidArgument extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "InvalidArgument");
      }
      name = "InvalidArgument";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidArgument",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidArgument.prototype);
      }
    };
    exports2.InvalidArgument = InvalidArgument;
    var InvalidKeySigningKeyName = class _InvalidKeySigningKeyName extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "InvalidKeySigningKeyName");
      }
      name = "InvalidKeySigningKeyName";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidKeySigningKeyName",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidKeySigningKeyName.prototype);
      }
    };
    exports2.InvalidKeySigningKeyName = InvalidKeySigningKeyName;
    var KeySigningKeyAlreadyExists = class _KeySigningKeyAlreadyExists extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "KeySigningKeyAlreadyExists");
      }
      name = "KeySigningKeyAlreadyExists";
      $fault = "client";
      constructor(opts) {
        super({
          name: "KeySigningKeyAlreadyExists",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _KeySigningKeyAlreadyExists.prototype);
      }
    };
    exports2.KeySigningKeyAlreadyExists = KeySigningKeyAlreadyExists;
    var TooManyKeySigningKeys = class _TooManyKeySigningKeys extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "TooManyKeySigningKeys");
      }
      name = "TooManyKeySigningKeys";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TooManyKeySigningKeys",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyKeySigningKeys.prototype);
      }
    };
    exports2.TooManyKeySigningKeys = TooManyKeySigningKeys;
    var InsufficientCloudWatchLogsResourcePolicy = class _InsufficientCloudWatchLogsResourcePolicy extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "InsufficientCloudWatchLogsResourcePolicy");
      }
      name = "InsufficientCloudWatchLogsResourcePolicy";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InsufficientCloudWatchLogsResourcePolicy",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InsufficientCloudWatchLogsResourcePolicy.prototype);
      }
    };
    exports2.InsufficientCloudWatchLogsResourcePolicy = InsufficientCloudWatchLogsResourcePolicy;
    var NoSuchCloudWatchLogsLogGroup = class _NoSuchCloudWatchLogsLogGroup extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "NoSuchCloudWatchLogsLogGroup");
      }
      name = "NoSuchCloudWatchLogsLogGroup";
      $fault = "client";
      constructor(opts) {
        super({
          name: "NoSuchCloudWatchLogsLogGroup",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _NoSuchCloudWatchLogsLogGroup.prototype);
      }
    };
    exports2.NoSuchCloudWatchLogsLogGroup = NoSuchCloudWatchLogsLogGroup;
    var QueryLoggingConfigAlreadyExists = class _QueryLoggingConfigAlreadyExists extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "QueryLoggingConfigAlreadyExists");
      }
      name = "QueryLoggingConfigAlreadyExists";
      $fault = "client";
      constructor(opts) {
        super({
          name: "QueryLoggingConfigAlreadyExists",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _QueryLoggingConfigAlreadyExists.prototype);
      }
    };
    exports2.QueryLoggingConfigAlreadyExists = QueryLoggingConfigAlreadyExists;
    var DelegationSetAlreadyCreated = class _DelegationSetAlreadyCreated extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "DelegationSetAlreadyCreated");
      }
      name = "DelegationSetAlreadyCreated";
      $fault = "client";
      constructor(opts) {
        super({
          name: "DelegationSetAlreadyCreated",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DelegationSetAlreadyCreated.prototype);
      }
    };
    exports2.DelegationSetAlreadyCreated = DelegationSetAlreadyCreated;
    var DelegationSetAlreadyReusable = class _DelegationSetAlreadyReusable extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "DelegationSetAlreadyReusable");
      }
      name = "DelegationSetAlreadyReusable";
      $fault = "client";
      constructor(opts) {
        super({
          name: "DelegationSetAlreadyReusable",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DelegationSetAlreadyReusable.prototype);
      }
    };
    exports2.DelegationSetAlreadyReusable = DelegationSetAlreadyReusable;
    var HostedZoneNotFound = class _HostedZoneNotFound extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "HostedZoneNotFound");
      }
      name = "HostedZoneNotFound";
      $fault = "client";
      constructor(opts) {
        super({
          name: "HostedZoneNotFound",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _HostedZoneNotFound.prototype);
      }
    };
    exports2.HostedZoneNotFound = HostedZoneNotFound;
    var InvalidTrafficPolicyDocument = class _InvalidTrafficPolicyDocument extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "InvalidTrafficPolicyDocument");
      }
      name = "InvalidTrafficPolicyDocument";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidTrafficPolicyDocument",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidTrafficPolicyDocument.prototype);
      }
    };
    exports2.InvalidTrafficPolicyDocument = InvalidTrafficPolicyDocument;
    var TooManyTrafficPolicies = class _TooManyTrafficPolicies extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "TooManyTrafficPolicies");
      }
      name = "TooManyTrafficPolicies";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TooManyTrafficPolicies",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyTrafficPolicies.prototype);
      }
    };
    exports2.TooManyTrafficPolicies = TooManyTrafficPolicies;
    var TrafficPolicyAlreadyExists = class _TrafficPolicyAlreadyExists extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "TrafficPolicyAlreadyExists");
      }
      name = "TrafficPolicyAlreadyExists";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TrafficPolicyAlreadyExists",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TrafficPolicyAlreadyExists.prototype);
      }
    };
    exports2.TrafficPolicyAlreadyExists = TrafficPolicyAlreadyExists;
    var NoSuchTrafficPolicy = class _NoSuchTrafficPolicy extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "NoSuchTrafficPolicy");
      }
      name = "NoSuchTrafficPolicy";
      $fault = "client";
      constructor(opts) {
        super({
          name: "NoSuchTrafficPolicy",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _NoSuchTrafficPolicy.prototype);
      }
    };
    exports2.NoSuchTrafficPolicy = NoSuchTrafficPolicy;
    var TooManyTrafficPolicyInstances = class _TooManyTrafficPolicyInstances extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "TooManyTrafficPolicyInstances");
      }
      name = "TooManyTrafficPolicyInstances";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TooManyTrafficPolicyInstances",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyTrafficPolicyInstances.prototype);
      }
    };
    exports2.TooManyTrafficPolicyInstances = TooManyTrafficPolicyInstances;
    var TrafficPolicyInstanceAlreadyExists = class _TrafficPolicyInstanceAlreadyExists extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "TrafficPolicyInstanceAlreadyExists");
      }
      name = "TrafficPolicyInstanceAlreadyExists";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TrafficPolicyInstanceAlreadyExists",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TrafficPolicyInstanceAlreadyExists.prototype);
      }
    };
    exports2.TrafficPolicyInstanceAlreadyExists = TrafficPolicyInstanceAlreadyExists;
    var TooManyTrafficPolicyVersionsForCurrentPolicy = class _TooManyTrafficPolicyVersionsForCurrentPolicy extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "TooManyTrafficPolicyVersionsForCurrentPolicy");
      }
      name = "TooManyTrafficPolicyVersionsForCurrentPolicy";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TooManyTrafficPolicyVersionsForCurrentPolicy",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyTrafficPolicyVersionsForCurrentPolicy.prototype);
      }
    };
    exports2.TooManyTrafficPolicyVersionsForCurrentPolicy = TooManyTrafficPolicyVersionsForCurrentPolicy;
    var TooManyVPCAssociationAuthorizations = class _TooManyVPCAssociationAuthorizations extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "TooManyVPCAssociationAuthorizations");
      }
      name = "TooManyVPCAssociationAuthorizations";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TooManyVPCAssociationAuthorizations",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyVPCAssociationAuthorizations.prototype);
      }
    };
    exports2.TooManyVPCAssociationAuthorizations = TooManyVPCAssociationAuthorizations;
    var KeySigningKeyInParentDSRecord = class _KeySigningKeyInParentDSRecord extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "KeySigningKeyInParentDSRecord");
      }
      name = "KeySigningKeyInParentDSRecord";
      $fault = "client";
      constructor(opts) {
        super({
          name: "KeySigningKeyInParentDSRecord",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _KeySigningKeyInParentDSRecord.prototype);
      }
    };
    exports2.KeySigningKeyInParentDSRecord = KeySigningKeyInParentDSRecord;
    var KeySigningKeyInUse = class _KeySigningKeyInUse extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "KeySigningKeyInUse");
      }
      name = "KeySigningKeyInUse";
      $fault = "client";
      constructor(opts) {
        super({
          name: "KeySigningKeyInUse",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _KeySigningKeyInUse.prototype);
      }
    };
    exports2.KeySigningKeyInUse = KeySigningKeyInUse;
    var CidrCollectionInUseException = class _CidrCollectionInUseException extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "CidrCollectionInUseException");
      }
      name = "CidrCollectionInUseException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "CidrCollectionInUseException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CidrCollectionInUseException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.CidrCollectionInUseException = CidrCollectionInUseException;
    var HealthCheckInUse = class _HealthCheckInUse extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "HealthCheckInUse");
      }
      name = "HealthCheckInUse";
      $fault = "client";
      constructor(opts) {
        super({
          name: "HealthCheckInUse",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _HealthCheckInUse.prototype);
      }
    };
    exports2.HealthCheckInUse = HealthCheckInUse;
    var HostedZoneNotEmpty = class _HostedZoneNotEmpty extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "HostedZoneNotEmpty");
      }
      name = "HostedZoneNotEmpty";
      $fault = "client";
      constructor(opts) {
        super({
          name: "HostedZoneNotEmpty",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _HostedZoneNotEmpty.prototype);
      }
    };
    exports2.HostedZoneNotEmpty = HostedZoneNotEmpty;
    var NoSuchQueryLoggingConfig = class _NoSuchQueryLoggingConfig extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "NoSuchQueryLoggingConfig");
      }
      name = "NoSuchQueryLoggingConfig";
      $fault = "client";
      constructor(opts) {
        super({
          name: "NoSuchQueryLoggingConfig",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _NoSuchQueryLoggingConfig.prototype);
      }
    };
    exports2.NoSuchQueryLoggingConfig = NoSuchQueryLoggingConfig;
    var DelegationSetInUse = class _DelegationSetInUse extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "DelegationSetInUse");
      }
      name = "DelegationSetInUse";
      $fault = "client";
      constructor(opts) {
        super({
          name: "DelegationSetInUse",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DelegationSetInUse.prototype);
      }
    };
    exports2.DelegationSetInUse = DelegationSetInUse;
    var TrafficPolicyInUse = class _TrafficPolicyInUse extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "TrafficPolicyInUse");
      }
      name = "TrafficPolicyInUse";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TrafficPolicyInUse",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TrafficPolicyInUse.prototype);
      }
    };
    exports2.TrafficPolicyInUse = TrafficPolicyInUse;
    var NoSuchTrafficPolicyInstance = class _NoSuchTrafficPolicyInstance extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "NoSuchTrafficPolicyInstance");
      }
      name = "NoSuchTrafficPolicyInstance";
      $fault = "client";
      constructor(opts) {
        super({
          name: "NoSuchTrafficPolicyInstance",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _NoSuchTrafficPolicyInstance.prototype);
      }
    };
    exports2.NoSuchTrafficPolicyInstance = NoSuchTrafficPolicyInstance;
    var VPCAssociationAuthorizationNotFound = class _VPCAssociationAuthorizationNotFound extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "VPCAssociationAuthorizationNotFound");
      }
      name = "VPCAssociationAuthorizationNotFound";
      $fault = "client";
      constructor(opts) {
        super({
          name: "VPCAssociationAuthorizationNotFound",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _VPCAssociationAuthorizationNotFound.prototype);
      }
    };
    exports2.VPCAssociationAuthorizationNotFound = VPCAssociationAuthorizationNotFound;
    var DNSSECNotFound = class _DNSSECNotFound extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "DNSSECNotFound");
      }
      name = "DNSSECNotFound";
      $fault = "client";
      constructor(opts) {
        super({
          name: "DNSSECNotFound",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DNSSECNotFound.prototype);
      }
    };
    exports2.DNSSECNotFound = DNSSECNotFound;
    var LastVPCAssociation = class _LastVPCAssociation extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "LastVPCAssociation");
      }
      name = "LastVPCAssociation";
      $fault = "client";
      constructor(opts) {
        super({
          name: "LastVPCAssociation",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _LastVPCAssociation.prototype);
      }
    };
    exports2.LastVPCAssociation = LastVPCAssociation;
    var VPCAssociationNotFound = class _VPCAssociationNotFound extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "VPCAssociationNotFound");
      }
      name = "VPCAssociationNotFound";
      $fault = "client";
      constructor(opts) {
        super({
          name: "VPCAssociationNotFound",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _VPCAssociationNotFound.prototype);
      }
    };
    exports2.VPCAssociationNotFound = VPCAssociationNotFound;
    var HostedZonePartiallyDelegated = class _HostedZonePartiallyDelegated extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "HostedZonePartiallyDelegated");
      }
      name = "HostedZonePartiallyDelegated";
      $fault = "client";
      constructor(opts) {
        super({
          name: "HostedZonePartiallyDelegated",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _HostedZonePartiallyDelegated.prototype);
      }
    };
    exports2.HostedZonePartiallyDelegated = HostedZonePartiallyDelegated;
    var KeySigningKeyWithActiveStatusNotFound = class _KeySigningKeyWithActiveStatusNotFound extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "KeySigningKeyWithActiveStatusNotFound");
      }
      name = "KeySigningKeyWithActiveStatusNotFound";
      $fault = "client";
      constructor(opts) {
        super({
          name: "KeySigningKeyWithActiveStatusNotFound",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _KeySigningKeyWithActiveStatusNotFound.prototype);
      }
    };
    exports2.KeySigningKeyWithActiveStatusNotFound = KeySigningKeyWithActiveStatusNotFound;
    var NoSuchChange = class _NoSuchChange extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "NoSuchChange");
      }
      name = "NoSuchChange";
      $fault = "client";
      constructor(opts) {
        super({
          name: "NoSuchChange",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _NoSuchChange.prototype);
      }
    };
    exports2.NoSuchChange = NoSuchChange;
    var NoSuchGeoLocation = class _NoSuchGeoLocation extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "NoSuchGeoLocation");
      }
      name = "NoSuchGeoLocation";
      $fault = "client";
      constructor(opts) {
        super({
          name: "NoSuchGeoLocation",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _NoSuchGeoLocation.prototype);
      }
    };
    exports2.NoSuchGeoLocation = NoSuchGeoLocation;
    var IncompatibleVersion = class _IncompatibleVersion extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "IncompatibleVersion");
      }
      name = "IncompatibleVersion";
      $fault = "client";
      constructor(opts) {
        super({
          name: "IncompatibleVersion",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _IncompatibleVersion.prototype);
      }
    };
    exports2.IncompatibleVersion = IncompatibleVersion;
    var HostedZoneNotPrivate = class _HostedZoneNotPrivate extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "HostedZoneNotPrivate");
      }
      name = "HostedZoneNotPrivate";
      $fault = "client";
      constructor(opts) {
        super({
          name: "HostedZoneNotPrivate",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _HostedZoneNotPrivate.prototype);
      }
    };
    exports2.HostedZoneNotPrivate = HostedZoneNotPrivate;
    var NoSuchCidrLocationException = class _NoSuchCidrLocationException extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "NoSuchCidrLocationException");
      }
      name = "NoSuchCidrLocationException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "NoSuchCidrLocationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _NoSuchCidrLocationException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.NoSuchCidrLocationException = NoSuchCidrLocationException;
    var InvalidPaginationToken = class _InvalidPaginationToken extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "InvalidPaginationToken");
      }
      name = "InvalidPaginationToken";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidPaginationToken",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidPaginationToken.prototype);
      }
    };
    exports2.InvalidPaginationToken = InvalidPaginationToken;
    var HealthCheckVersionMismatch = class _HealthCheckVersionMismatch extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "HealthCheckVersionMismatch");
      }
      name = "HealthCheckVersionMismatch";
      $fault = "client";
      constructor(opts) {
        super({
          name: "HealthCheckVersionMismatch",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _HealthCheckVersionMismatch.prototype);
      }
    };
    exports2.HealthCheckVersionMismatch = HealthCheckVersionMismatch;
    var ConflictingTypes = class _ConflictingTypes extends Route53ServiceException_1.Route53ServiceException {
      static {
        __name(this, "ConflictingTypes");
      }
      name = "ConflictingTypes";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ConflictingTypes",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ConflictingTypes.prototype);
      }
    };
    exports2.ConflictingTypes = ConflictingTypes;
  }
});

// ../../node_modules/@aws-sdk/client-route-53/dist-cjs/schemas/schemas_0.js
var require_schemas_017 = __commonJS({
  "../../node_modules/@aws-sdk/client-route-53/dist-cjs/schemas/schemas_0.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.NoSuchKeySigningKey$ = exports2.NoSuchHostedZone$ = exports2.NoSuchHealthCheck$ = exports2.NoSuchGeoLocation$ = exports2.NoSuchDelegationSet$ = exports2.NoSuchCloudWatchLogsLogGroup$ = exports2.NoSuchCidrLocationException$ = exports2.NoSuchCidrCollectionException$ = exports2.NoSuchChange$ = exports2.LimitsExceeded$ = exports2.LastVPCAssociation$ = exports2.KeySigningKeyWithActiveStatusNotFound$ = exports2.KeySigningKeyInUse$ = exports2.KeySigningKeyInParentDSRecord$ = exports2.KeySigningKeyAlreadyExists$ = exports2.InvalidVPCId$ = exports2.InvalidTrafficPolicyDocument$ = exports2.InvalidSigningStatus$ = exports2.InvalidPaginationToken$ = exports2.InvalidKMSArn$ = exports2.InvalidKeySigningKeyStatus$ = exports2.InvalidKeySigningKeyName$ = exports2.InvalidInput$ = exports2.InvalidDomainName$ = exports2.InvalidChangeBatch$ = exports2.InvalidArgument$ = exports2.InsufficientCloudWatchLogsResourcePolicy$ = exports2.IncompatibleVersion$ = exports2.HostedZonePartiallyDelegated$ = exports2.HostedZoneNotPrivate$ = exports2.HostedZoneNotFound$ = exports2.HostedZoneNotEmpty$ = exports2.HostedZoneAlreadyExists$ = exports2.HealthCheckVersionMismatch$ = exports2.HealthCheckInUse$ = exports2.HealthCheckAlreadyExists$ = exports2.DNSSECNotFound$ = exports2.DelegationSetNotReusable$ = exports2.DelegationSetNotAvailable$ = exports2.DelegationSetInUse$ = exports2.DelegationSetAlreadyReusable$ = exports2.DelegationSetAlreadyCreated$ = exports2.ConflictingTypes$ = exports2.ConflictingDomainExists$ = exports2.ConcurrentModification$ = exports2.CidrCollectionVersionMismatchException$ = exports2.CidrCollectionInUseException$ = exports2.CidrCollectionAlreadyExistsException$ = exports2.CidrBlockInUseException$ = exports2.Route53ServiceException$ = void 0;
    exports2.CreateHostedZoneResponse$ = exports2.CreateHostedZoneRequest$ = exports2.CreateHealthCheckResponse$ = exports2.CreateHealthCheckRequest$ = exports2.CreateCidrCollectionResponse$ = exports2.CreateCidrCollectionRequest$ = exports2.Coordinates$ = exports2.CollectionSummary$ = exports2.CloudWatchAlarmConfiguration$ = exports2.CidrRoutingConfig$ = exports2.CidrCollectionChange$ = exports2.CidrCollection$ = exports2.CidrBlockSummary$ = exports2.ChangeTagsForResourceResponse$ = exports2.ChangeTagsForResourceRequest$ = exports2.ChangeResourceRecordSetsResponse$ = exports2.ChangeResourceRecordSetsRequest$ = exports2.ChangeInfo$ = exports2.ChangeCidrCollectionResponse$ = exports2.ChangeCidrCollectionRequest$ = exports2.ChangeBatch$ = exports2.Change$ = exports2.AssociateVPCWithHostedZoneResponse$ = exports2.AssociateVPCWithHostedZoneRequest$ = exports2.AliasTarget$ = exports2.AlarmIdentifier$ = exports2.ActivateKeySigningKeyResponse$ = exports2.ActivateKeySigningKeyRequest$ = exports2.AccountLimit$ = exports2.errorTypeRegistries = exports2.VPCAssociationNotFound$ = exports2.VPCAssociationAuthorizationNotFound$ = exports2.TrafficPolicyInUse$ = exports2.TrafficPolicyInstanceAlreadyExists$ = exports2.TrafficPolicyAlreadyExists$ = exports2.TooManyVPCAssociationAuthorizations$ = exports2.TooManyTrafficPolicyVersionsForCurrentPolicy$ = exports2.TooManyTrafficPolicyInstances$ = exports2.TooManyTrafficPolicies$ = exports2.TooManyKeySigningKeys$ = exports2.TooManyHostedZones$ = exports2.TooManyHealthChecks$ = exports2.ThrottlingException$ = exports2.QueryLoggingConfigAlreadyExists$ = exports2.PublicZoneVPCAssociation$ = exports2.PriorRequestNotComplete$ = exports2.NotAuthorizedException$ = exports2.NoSuchTrafficPolicyInstance$ = exports2.NoSuchTrafficPolicy$ = exports2.NoSuchQueryLoggingConfig$ = void 0;
    exports2.GetChangeResponse$ = exports2.GetChangeRequest$ = exports2.GetAccountLimitResponse$ = exports2.GetAccountLimitRequest$ = exports2.GeoProximityLocation$ = exports2.GeoLocationDetails$ = exports2.GeoLocation$ = exports2.EnableHostedZoneDNSSECResponse$ = exports2.EnableHostedZoneDNSSECRequest$ = exports2.DNSSECStatus$ = exports2.DisassociateVPCFromHostedZoneResponse$ = exports2.DisassociateVPCFromHostedZoneRequest$ = exports2.DisableHostedZoneDNSSECResponse$ = exports2.DisableHostedZoneDNSSECRequest$ = exports2.Dimension$ = exports2.DeleteVPCAssociationAuthorizationResponse$ = exports2.DeleteVPCAssociationAuthorizationRequest$ = exports2.DeleteTrafficPolicyResponse$ = exports2.DeleteTrafficPolicyRequest$ = exports2.DeleteTrafficPolicyInstanceResponse$ = exports2.DeleteTrafficPolicyInstanceRequest$ = exports2.DeleteReusableDelegationSetResponse$ = exports2.DeleteReusableDelegationSetRequest$ = exports2.DeleteQueryLoggingConfigResponse$ = exports2.DeleteQueryLoggingConfigRequest$ = exports2.DeleteKeySigningKeyResponse$ = exports2.DeleteKeySigningKeyRequest$ = exports2.DeleteHostedZoneResponse$ = exports2.DeleteHostedZoneRequest$ = exports2.DeleteHealthCheckResponse$ = exports2.DeleteHealthCheckRequest$ = exports2.DeleteCidrCollectionResponse$ = exports2.DeleteCidrCollectionRequest$ = exports2.DelegationSet$ = exports2.DeactivateKeySigningKeyResponse$ = exports2.DeactivateKeySigningKeyRequest$ = exports2.CreateVPCAssociationAuthorizationResponse$ = exports2.CreateVPCAssociationAuthorizationRequest$ = exports2.CreateTrafficPolicyVersionResponse$ = exports2.CreateTrafficPolicyVersionRequest$ = exports2.CreateTrafficPolicyResponse$ = exports2.CreateTrafficPolicyRequest$ = exports2.CreateTrafficPolicyInstanceResponse$ = exports2.CreateTrafficPolicyInstanceRequest$ = exports2.CreateReusableDelegationSetResponse$ = exports2.CreateReusableDelegationSetRequest$ = exports2.CreateQueryLoggingConfigResponse$ = exports2.CreateQueryLoggingConfigRequest$ = exports2.CreateKeySigningKeyResponse$ = exports2.CreateKeySigningKeyRequest$ = void 0;
    exports2.ListCidrLocationsResponse$ = exports2.ListCidrLocationsRequest$ = exports2.ListCidrCollectionsResponse$ = exports2.ListCidrCollectionsRequest$ = exports2.ListCidrBlocksResponse$ = exports2.ListCidrBlocksRequest$ = exports2.LinkedService$ = exports2.KeySigningKey$ = exports2.HostedZoneSummary$ = exports2.HostedZoneOwner$ = exports2.HostedZoneLimit$ = exports2.HostedZoneFeatures$ = exports2.HostedZoneFailureReasons$ = exports2.HostedZoneConfig$ = exports2.HostedZone$ = exports2.HealthCheckObservation$ = exports2.HealthCheckConfig$ = exports2.HealthCheck$ = exports2.GetTrafficPolicyResponse$ = exports2.GetTrafficPolicyRequest$ = exports2.GetTrafficPolicyInstanceResponse$ = exports2.GetTrafficPolicyInstanceRequest$ = exports2.GetTrafficPolicyInstanceCountResponse$ = exports2.GetTrafficPolicyInstanceCountRequest$ = exports2.GetReusableDelegationSetResponse$ = exports2.GetReusableDelegationSetRequest$ = exports2.GetReusableDelegationSetLimitResponse$ = exports2.GetReusableDelegationSetLimitRequest$ = exports2.GetQueryLoggingConfigResponse$ = exports2.GetQueryLoggingConfigRequest$ = exports2.GetHostedZoneResponse$ = exports2.GetHostedZoneRequest$ = exports2.GetHostedZoneLimitResponse$ = exports2.GetHostedZoneLimitRequest$ = exports2.GetHostedZoneCountResponse$ = exports2.GetHostedZoneCountRequest$ = exports2.GetHealthCheckStatusResponse$ = exports2.GetHealthCheckStatusRequest$ = exports2.GetHealthCheckResponse$ = exports2.GetHealthCheckRequest$ = exports2.GetHealthCheckLastFailureReasonResponse$ = exports2.GetHealthCheckLastFailureReasonRequest$ = exports2.GetHealthCheckCountResponse$ = exports2.GetHealthCheckCountRequest$ = exports2.GetGeoLocationResponse$ = exports2.GetGeoLocationRequest$ = exports2.GetDNSSECResponse$ = exports2.GetDNSSECRequest$ = exports2.GetCheckerIpRangesResponse$ = exports2.GetCheckerIpRangesRequest$ = void 0;
    exports2.UpdateHostedZoneFeaturesRequest$ = exports2.UpdateHostedZoneCommentResponse$ = exports2.UpdateHostedZoneCommentRequest$ = exports2.UpdateHealthCheckResponse$ = exports2.UpdateHealthCheckRequest$ = exports2.TrafficPolicySummary$ = exports2.TrafficPolicyInstance$ = exports2.TrafficPolicy$ = exports2.TestDNSAnswerResponse$ = exports2.TestDNSAnswerRequest$ = exports2.Tag$ = exports2.StatusReport$ = exports2.ReusableDelegationSetLimit$ = exports2.ResourceTagSet$ = exports2.ResourceRecordSet$ = exports2.ResourceRecord$ = exports2.QueryLoggingConfig$ = exports2.LocationSummary$ = exports2.ListVPCAssociationAuthorizationsResponse$ = exports2.ListVPCAssociationAuthorizationsRequest$ = exports2.ListTrafficPolicyVersionsResponse$ = exports2.ListTrafficPolicyVersionsRequest$ = exports2.ListTrafficPolicyInstancesResponse$ = exports2.ListTrafficPolicyInstancesRequest$ = exports2.ListTrafficPolicyInstancesByPolicyResponse$ = exports2.ListTrafficPolicyInstancesByPolicyRequest$ = exports2.ListTrafficPolicyInstancesByHostedZoneResponse$ = exports2.ListTrafficPolicyInstancesByHostedZoneRequest$ = exports2.ListTrafficPoliciesResponse$ = exports2.ListTrafficPoliciesRequest$ = exports2.ListTagsForResourcesResponse$ = exports2.ListTagsForResourcesRequest$ = exports2.ListTagsForResourceResponse$ = exports2.ListTagsForResourceRequest$ = exports2.ListReusableDelegationSetsResponse$ = exports2.ListReusableDelegationSetsRequest$ = exports2.ListResourceRecordSetsResponse$ = exports2.ListResourceRecordSetsRequest$ = exports2.ListQueryLoggingConfigsResponse$ = exports2.ListQueryLoggingConfigsRequest$ = exports2.ListHostedZonesResponse$ = exports2.ListHostedZonesRequest$ = exports2.ListHostedZonesByVPCResponse$ = exports2.ListHostedZonesByVPCRequest$ = exports2.ListHostedZonesByNameResponse$ = exports2.ListHostedZonesByNameRequest$ = exports2.ListHealthChecksResponse$ = exports2.ListHealthChecksRequest$ = exports2.ListGeoLocationsResponse$ = exports2.ListGeoLocationsRequest$ = void 0;
    exports2.GetTrafficPolicy$ = exports2.GetReusableDelegationSetLimit$ = exports2.GetReusableDelegationSet$ = exports2.GetQueryLoggingConfig$ = exports2.GetHostedZoneLimit$ = exports2.GetHostedZoneCount$ = exports2.GetHostedZone$ = exports2.GetHealthCheckStatus$ = exports2.GetHealthCheckLastFailureReason$ = exports2.GetHealthCheckCount$ = exports2.GetHealthCheck$ = exports2.GetGeoLocation$ = exports2.GetDNSSEC$ = exports2.GetCheckerIpRanges$ = exports2.GetChange$ = exports2.GetAccountLimit$ = exports2.EnableHostedZoneDNSSEC$ = exports2.DisassociateVPCFromHostedZone$ = exports2.DisableHostedZoneDNSSEC$ = exports2.DeleteVPCAssociationAuthorization$ = exports2.DeleteTrafficPolicyInstance$ = exports2.DeleteTrafficPolicy$ = exports2.DeleteReusableDelegationSet$ = exports2.DeleteQueryLoggingConfig$ = exports2.DeleteKeySigningKey$ = exports2.DeleteHostedZone$ = exports2.DeleteHealthCheck$ = exports2.DeleteCidrCollection$ = exports2.DeactivateKeySigningKey$ = exports2.CreateVPCAssociationAuthorization$ = exports2.CreateTrafficPolicyVersion$ = exports2.CreateTrafficPolicyInstance$ = exports2.CreateTrafficPolicy$ = exports2.CreateReusableDelegationSet$ = exports2.CreateQueryLoggingConfig$ = exports2.CreateKeySigningKey$ = exports2.CreateHostedZone$ = exports2.CreateHealthCheck$ = exports2.CreateCidrCollection$ = exports2.ChangeTagsForResource$ = exports2.ChangeResourceRecordSets$ = exports2.ChangeCidrCollection$ = exports2.AssociateVPCWithHostedZone$ = exports2.ActivateKeySigningKey$ = exports2.VPC$ = exports2.UpdateTrafficPolicyInstanceResponse$ = exports2.UpdateTrafficPolicyInstanceRequest$ = exports2.UpdateTrafficPolicyCommentResponse$ = exports2.UpdateTrafficPolicyCommentRequest$ = exports2.UpdateHostedZoneFeaturesResponse$ = void 0;
    exports2.UpdateTrafficPolicyInstance$ = exports2.UpdateTrafficPolicyComment$ = exports2.UpdateHostedZoneFeatures$ = exports2.UpdateHostedZoneComment$ = exports2.UpdateHealthCheck$ = exports2.TestDNSAnswer$ = exports2.ListVPCAssociationAuthorizations$ = exports2.ListTrafficPolicyVersions$ = exports2.ListTrafficPolicyInstancesByPolicy$ = exports2.ListTrafficPolicyInstancesByHostedZone$ = exports2.ListTrafficPolicyInstances$ = exports2.ListTrafficPolicies$ = exports2.ListTagsForResources$ = exports2.ListTagsForResource$ = exports2.ListReusableDelegationSets$ = exports2.ListResourceRecordSets$ = exports2.ListQueryLoggingConfigs$ = exports2.ListHostedZonesByVPC$ = exports2.ListHostedZonesByName$ = exports2.ListHostedZones$ = exports2.ListHealthChecks$ = exports2.ListGeoLocations$ = exports2.ListCidrLocations$ = exports2.ListCidrCollections$ = exports2.ListCidrBlocks$ = exports2.GetTrafficPolicyInstanceCount$ = exports2.GetTrafficPolicyInstance$ = void 0;
    var _A10 = "Action";
    var _AI2 = "AlarmIdentifier";
    var _AKSK = "ActivateKeySigningKey";
    var _AKSKR = "ActivateKeySigningKeyRequest";
    var _AKSKRc = "ActivateKeySigningKeyResponse";
    var _AL = "AccountLimit";
    var _AR10 = "AcceleratedRecovery";
    var _ARS = "AcceleratedRecoveryStatus";
    var _AT13 = "AliasTarget";
    var _ATd = "AddTags";
    var _AVPCWHZ = "AssociateVPCWithHostedZone";
    var _AVPCWHZR = "AssociateVPCWithHostedZoneRequest";
    var _AVPCWHZRs = "AssociateVPCWithHostedZoneResponse";
    var _AWSR = "AWSRegion";
    var _Ar = "Arn";
    var _B = "Bias";
    var _C11 = "Comment";
    var _CB = "ChangeBatch";
    var _CBIUE = "CidrBlockInUseException";
    var _CBS = "CidrBlockSummary";
    var _CBSi = "CidrBlockSummaries";
    var _CBi = "CidrBlock";
    var _CBid = "CidrBlocks";
    var _CC = "CidrCollection";
    var _CCAEE = "CidrCollectionAlreadyExistsException";
    var _CCC = "CidrCollectionChange";
    var _CCCR = "ChangeCidrCollectionRequest";
    var _CCCRh = "ChangeCidrCollectionResponse";
    var _CCCRr = "CreateCidrCollectionRequest";
    var _CCCRre = "CreateCidrCollectionResponse";
    var _CCCh = "ChangeCidrCollection";
    var _CCCi = "CidrCollectionChanges";
    var _CCCr = "CreateCidrCollection";
    var _CCIUE = "CidrCollectionInUseException";
    var _CCVME = "CidrCollectionVersionMismatchException";
    var _CCi = "CidrCollections";
    var _CCo = "ContinentCode";
    var _CCou = "CountryCode";
    var _CD = "CreatedDate";
    var _CDE = "ConflictingDomainExists";
    var _CHC = "ChildHealthChecks";
    var _CHCL = "ChildHealthCheckList";
    var _CHCR = "CreateHealthCheckRequest";
    var _CHCRr = "CreateHealthCheckResponse";
    var _CHCh = "ChildHealthCheck";
    var _CHCr = "CreateHealthCheck";
    var _CHZ = "CreateHostedZone";
    var _CHZR = "CreateHostedZoneRequest";
    var _CHZRr = "CreateHostedZoneResponse";
    var _CI = "ChangeInfo";
    var _CIR = "CheckerIpRanges";
    var _CIo = "CollectionId";
    var _CKSK = "CreateKeySigningKey";
    var _CKSKR = "CreateKeySigningKeyRequest";
    var _CKSKRr = "CreateKeySigningKeyResponse";
    var _CL = "CidrList";
    var _CLi = "CidrLocations";
    var _CM = "ConcurrentModification";
    var _CN = "ContinentName";
    var _CNo = "CountryName";
    var _CO = "ComparisonOperator";
    var _CQLC = "CreateQueryLoggingConfig";
    var _CQLCR = "CreateQueryLoggingConfigRequest";
    var _CQLCRr = "CreateQueryLoggingConfigResponse";
    var _CR = "CallerReference";
    var _CRC = "CidrRoutingConfig";
    var _CRDS = "CreateReusableDelegationSet";
    var _CRDSR = "CreateReusableDelegationSetRequest";
    var _CRDSRr = "CreateReusableDelegationSetResponse";
    var _CRRS = "ChangeResourceRecordSets";
    var _CRRSR = "ChangeResourceRecordSetsRequest";
    var _CRRSRh = "ChangeResourceRecordSetsResponse";
    var _CS4 = "CollectionSummary";
    var _CSo = "CollectionSummaries";
    var _CT4 = "ConflictingTypes";
    var _CTFR = "ChangeTagsForResource";
    var _CTFRR = "ChangeTagsForResourceRequest";
    var _CTFRRh = "ChangeTagsForResourceResponse";
    var _CTP = "CreateTrafficPolicy";
    var _CTPI = "CreateTrafficPolicyInstance";
    var _CTPIR = "CreateTrafficPolicyInstanceRequest";
    var _CTPIRr = "CreateTrafficPolicyInstanceResponse";
    var _CTPR = "CreateTrafficPolicyRequest";
    var _CTPRr = "CreateTrafficPolicyResponse";
    var _CTPV = "CreateTrafficPolicyVersion";
    var _CTPVR = "CreateTrafficPolicyVersionRequest";
    var _CTPVRr = "CreateTrafficPolicyVersionResponse";
    var _CTh = "CheckedTime";
    var _CV4 = "CollectionVersion";
    var _CVPCAA = "CreateVPCAssociationAuthorization";
    var _CVPCAAR = "CreateVPCAssociationAuthorizationRequest";
    var _CVPCAARr = "CreateVPCAssociationAuthorizationResponse";
    var _CWAC = "CloudWatchAlarmConfiguration";
    var _CWLLGA = "CloudWatchLogsLogGroupArn";
    var _Ch = "Change";
    var _Cha = "Changes";
    var _Ci = "Cidr";
    var _Co = "Coordinates";
    var _Col = "Collection";
    var _Con = "Config";
    var _Cou = "Count";
    var _D = "Dimensions";
    var _DAM = "DigestAlgorithmMnemonic";
    var _DAT = "DigestAlgorithmType";
    var _DCC = "DeleteCidrCollection";
    var _DCCR = "DeleteCidrCollectionRequest";
    var _DCCRe = "DeleteCidrCollectionResponse";
    var _DHC = "DeleteHealthCheck";
    var _DHCR = "DeleteHealthCheckRequest";
    var _DHCRe = "DeleteHealthCheckResponse";
    var _DHZ = "DeleteHostedZone";
    var _DHZDNSSEC = "DisableHostedZoneDNSSEC";
    var _DHZDNSSECR = "DisableHostedZoneDNSSECRequest";
    var _DHZDNSSECRi = "DisableHostedZoneDNSSECResponse";
    var _DHZR = "DeleteHostedZoneRequest";
    var _DHZRe = "DeleteHostedZoneResponse";
    var _DKSK = "DeactivateKeySigningKey";
    var _DKSKR = "DeactivateKeySigningKeyRequest";
    var _DKSKRe = "DeactivateKeySigningKeyResponse";
    var _DKSKRel = "DeleteKeySigningKeyRequest";
    var _DKSKRele = "DeleteKeySigningKeyResponse";
    var _DKSKe = "DeleteKeySigningKey";
    var _DL = "DimensionList";
    var _DNSKEYR = "DNSKEYRecord";
    var _DNSN = "DNSName";
    var _DNSSECNF = "DNSSECNotFound";
    var _DNSSECS = "DNSSECStatus";
    var _DQLC = "DeleteQueryLoggingConfig";
    var _DQLCR = "DeleteQueryLoggingConfigRequest";
    var _DQLCRe = "DeleteQueryLoggingConfigResponse";
    var _DRDS = "DeleteReusableDelegationSet";
    var _DRDSR = "DeleteReusableDelegationSetRequest";
    var _DRDSRe = "DeleteReusableDelegationSetResponse";
    var _DS10 = "DelegationSet";
    var _DSAC = "DelegationSetAlreadyCreated";
    var _DSAR = "DelegationSetAlreadyReusable";
    var _DSI = "DelegationSetId";
    var _DSIU = "DelegationSetInUse";
    var _DSNA = "DelegationSetNotAvailable";
    var _DSNR = "DelegationSetNotReusable";
    var _DSNS = "DelegationSetNameServers";
    var _DSR = "DSRecord";
    var _DSe = "DelegationSets";
    var _DTP = "DeleteTrafficPolicy";
    var _DTPI = "DeleteTrafficPolicyInstance";
    var _DTPIR = "DeleteTrafficPolicyInstanceRequest";
    var _DTPIRe = "DeleteTrafficPolicyInstanceResponse";
    var _DTPR = "DeleteTrafficPolicyRequest";
    var _DTPRe = "DeleteTrafficPolicyResponse";
    var _DV = "DigestValue";
    var _DVPCAA = "DeleteVPCAssociationAuthorization";
    var _DVPCAAR = "DeleteVPCAssociationAuthorizationRequest";
    var _DVPCAARe = "DeleteVPCAssociationAuthorizationResponse";
    var _DVPCFHZ = "DisassociateVPCFromHostedZone";
    var _DVPCFHZR = "DisassociateVPCFromHostedZoneRequest";
    var _DVPCFHZRi = "DisassociateVPCFromHostedZoneResponse";
    var _De = "Description";
    var _Di = "Dimension";
    var _Dis = "Disabled";
    var _Do = "Document";
    var _EAR = "EnableAcceleratedRecovery";
    var _EDNSCSIP = "EDNS0ClientSubnetIP";
    var _EDNSCSM = "EDNS0ClientSubnetMask";
    var _EHZDNSSEC = "EnableHostedZoneDNSSEC";
    var _EHZDNSSECR = "EnableHostedZoneDNSSECRequest";
    var _EHZDNSSECRn = "EnableHostedZoneDNSSECResponse";
    var _EM = "ErrorMessages";
    var _EP = "EvaluationPeriods";
    var _ESNI = "EnableSNI";
    var _ETH = "EvaluateTargetHealth";
    var _F = "Features";
    var _FQDN = "FullyQualifiedDomainName";
    var _FR = "FailureReasons";
    var _FT = "FailureThreshold";
    var _Fa = "Failover";
    var _Fl = "Flag";
    var _GAL = "GetAccountLimit";
    var _GALR = "GetAccountLimitRequest";
    var _GALRe = "GetAccountLimitResponse";
    var _GC = "GetChange";
    var _GCIR = "GetCheckerIpRanges";
    var _GCIRR = "GetCheckerIpRangesRequest";
    var _GCIRRe = "GetCheckerIpRangesResponse";
    var _GCR = "GetChangeRequest";
    var _GCRe = "GetChangeResponse";
    var _GDNSSEC = "GetDNSSEC";
    var _GDNSSECR = "GetDNSSECRequest";
    var _GDNSSECRe = "GetDNSSECResponse";
    var _GGL = "GetGeoLocation";
    var _GGLR = "GetGeoLocationRequest";
    var _GGLRe = "GetGeoLocationResponse";
    var _GHC = "GetHealthCheck";
    var _GHCC = "GetHealthCheckCount";
    var _GHCCR = "GetHealthCheckCountRequest";
    var _GHCCRe = "GetHealthCheckCountResponse";
    var _GHCLFR = "GetHealthCheckLastFailureReason";
    var _GHCLFRR = "GetHealthCheckLastFailureReasonRequest";
    var _GHCLFRRe = "GetHealthCheckLastFailureReasonResponse";
    var _GHCR = "GetHealthCheckRequest";
    var _GHCRe = "GetHealthCheckResponse";
    var _GHCS = "GetHealthCheckStatus";
    var _GHCSR = "GetHealthCheckStatusRequest";
    var _GHCSRe = "GetHealthCheckStatusResponse";
    var _GHZ = "GetHostedZone";
    var _GHZC = "GetHostedZoneCount";
    var _GHZCR = "GetHostedZoneCountRequest";
    var _GHZCRe = "GetHostedZoneCountResponse";
    var _GHZL = "GetHostedZoneLimit";
    var _GHZLR = "GetHostedZoneLimitRequest";
    var _GHZLRe = "GetHostedZoneLimitResponse";
    var _GHZR = "GetHostedZoneRequest";
    var _GHZRe = "GetHostedZoneResponse";
    var _GL = "GeoLocation";
    var _GLD = "GeoLocationDetails";
    var _GLDL = "GeoLocationDetailsList";
    var _GPL = "GeoProximityLocation";
    var _GQLC = "GetQueryLoggingConfig";
    var _GQLCR = "GetQueryLoggingConfigRequest";
    var _GQLCRe = "GetQueryLoggingConfigResponse";
    var _GRDS = "GetReusableDelegationSet";
    var _GRDSL = "GetReusableDelegationSetLimit";
    var _GRDSLR = "GetReusableDelegationSetLimitRequest";
    var _GRDSLRe = "GetReusableDelegationSetLimitResponse";
    var _GRDSR = "GetReusableDelegationSetRequest";
    var _GRDSRe = "GetReusableDelegationSetResponse";
    var _GTP = "GetTrafficPolicy";
    var _GTPI = "GetTrafficPolicyInstance";
    var _GTPIC = "GetTrafficPolicyInstanceCount";
    var _GTPICR = "GetTrafficPolicyInstanceCountRequest";
    var _GTPICRe = "GetTrafficPolicyInstanceCountResponse";
    var _GTPIR = "GetTrafficPolicyInstanceRequest";
    var _GTPIRe = "GetTrafficPolicyInstanceResponse";
    var _GTPR = "GetTrafficPolicyRequest";
    var _GTPRe = "GetTrafficPolicyResponse";
    var _HC = "HealthCheck";
    var _HCAE = "HealthCheckAlreadyExists";
    var _HCC = "HealthCheckConfig";
    var _HCCe = "HealthCheckCount";
    var _HCI = "HealthCheckId";
    var _HCIU = "HealthCheckInUse";
    var _HCO = "HealthCheckObservations";
    var _HCOe = "HealthCheckObservation";
    var _HCRL = "HealthCheckRegionList";
    var _HCV = "HealthCheckVersion";
    var _HCVM = "HealthCheckVersionMismatch";
    var _HCe = "HealthChecks";
    var _HT = "HealthThreshold";
    var _HZ = "HostedZone";
    var _HZAE = "HostedZoneAlreadyExists";
    var _HZC = "HostedZoneConfig";
    var _HZCo = "HostedZoneCount";
    var _HZF = "HostedZoneFeatures";
    var _HZFR = "HostedZoneFailureReasons";
    var _HZI = "HostedZoneId";
    var _HZIM = "HostedZoneIdMarker";
    var _HZL = "HostedZoneLimit";
    var _HZNE = "HostedZoneNotEmpty";
    var _HZNF = "HostedZoneNotFound";
    var _HZNP = "HostedZoneNotPrivate";
    var _HZO = "HostedZoneOwner";
    var _HZPD = "HostedZonePartiallyDelegated";
    var _HZS = "HostedZoneSummary";
    var _HZSo = "HostedZoneSummaries";
    var _HZT = "HostedZoneType";
    var _HZo = "HostedZones";
    var _I = "Id";
    var _IA = "InvalidArgument";
    var _ICB = "InvalidChangeBatch";
    var _ICWLRP = "InsufficientCloudWatchLogsResourcePolicy";
    var _IDHS = "InsufficientDataHealthStatus";
    var _IDN = "InvalidDomainName";
    var _II2 = "InvalidInput";
    var _IKMSA = "InvalidKMSArn";
    var _IKSKN = "InvalidKeySigningKeyName";
    var _IKSKS = "InvalidKeySigningKeyStatus";
    var _IPA = "IPAddress";
    var _IPT2 = "InvalidPaginationToken";
    var _ISS = "InvalidSigningStatus";
    var _IT4 = "IsTruncated";
    var _ITPD = "InvalidTrafficPolicyDocument";
    var _IV = "IncompatibleVersion";
    var _IVPCI = "InvalidVPCId";
    var _In = "Inverted";
    var _K10 = "Key";
    var _KA = "KmsArn";
    var _KMSA = "KeyManagementServiceArn";
    var _KSK = "KeySigningKey";
    var _KSKAE = "KeySigningKeyAlreadyExists";
    var _KSKIPDSR = "KeySigningKeyInParentDSRecord";
    var _KSKIU = "KeySigningKeyInUse";
    var _KSKWASNF = "KeySigningKeyWithActiveStatusNotFound";
    var _KSKe = "KeySigningKeys";
    var _KT = "KeyTag";
    var _L2 = "Latitude";
    var _LCB = "ListCidrBlocks";
    var _LCBR = "ListCidrBlocksRequest";
    var _LCBRi = "ListCidrBlocksResponse";
    var _LCC = "ListCidrCollections";
    var _LCCR = "ListCidrCollectionsRequest";
    var _LCCRi = "ListCidrCollectionsResponse";
    var _LCL = "ListCidrLocations";
    var _LCLR = "ListCidrLocationsRequest";
    var _LCLRi = "ListCidrLocationsResponse";
    var _LE = "LimitsExceeded";
    var _LGL = "ListGeoLocations";
    var _LGLR = "ListGeoLocationsRequest";
    var _LGLRi = "ListGeoLocationsResponse";
    var _LHC = "ListHealthChecks";
    var _LHCR = "ListHealthChecksRequest";
    var _LHCRi = "ListHealthChecksResponse";
    var _LHZ = "ListHostedZones";
    var _LHZBN = "ListHostedZonesByName";
    var _LHZBNR = "ListHostedZonesByNameRequest";
    var _LHZBNRi = "ListHostedZonesByNameResponse";
    var _LHZBVPC = "ListHostedZonesByVPC";
    var _LHZBVPCR = "ListHostedZonesByVPCRequest";
    var _LHZBVPCRi = "ListHostedZonesByVPCResponse";
    var _LHZR = "ListHostedZonesRequest";
    var _LHZRi = "ListHostedZonesResponse";
    var _LMD = "LastModifiedDate";
    var _LN = "LocationName";
    var _LQLC = "ListQueryLoggingConfigs";
    var _LQLCR = "ListQueryLoggingConfigsRequest";
    var _LQLCRi = "ListQueryLoggingConfigsResponse";
    var _LRDS = "ListReusableDelegationSets";
    var _LRDSR = "ListReusableDelegationSetsRequest";
    var _LRDSRi = "ListReusableDelegationSetsResponse";
    var _LRRS = "ListResourceRecordSets";
    var _LRRSR = "ListResourceRecordSetsRequest";
    var _LRRSRi = "ListResourceRecordSetsResponse";
    var _LS = "LinkedService";
    var _LSo = "LocationSummary";
    var _LSoc = "LocationSummaries";
    var _LTFR = "ListTagsForResource";
    var _LTFRR = "ListTagsForResourceRequest";
    var _LTFRRi = "ListTagsForResourceResponse";
    var _LTFRRis = "ListTagsForResourcesRequest";
    var _LTFRRist = "ListTagsForResourcesResponse";
    var _LTFRi = "ListTagsForResources";
    var _LTP = "ListTrafficPolicies";
    var _LTPI = "ListTrafficPolicyInstances";
    var _LTPIBHZ = "ListTrafficPolicyInstancesByHostedZone";
    var _LTPIBHZR = "ListTrafficPolicyInstancesByHostedZoneRequest";
    var _LTPIBHZRi = "ListTrafficPolicyInstancesByHostedZoneResponse";
    var _LTPIBP = "ListTrafficPolicyInstancesByPolicy";
    var _LTPIBPR = "ListTrafficPolicyInstancesByPolicyRequest";
    var _LTPIBPRi = "ListTrafficPolicyInstancesByPolicyResponse";
    var _LTPIR = "ListTrafficPolicyInstancesRequest";
    var _LTPIRi = "ListTrafficPolicyInstancesResponse";
    var _LTPR = "ListTrafficPoliciesRequest";
    var _LTPRi = "ListTrafficPoliciesResponse";
    var _LTPV = "ListTrafficPolicyVersions";
    var _LTPVR = "ListTrafficPolicyVersionsRequest";
    var _LTPVRi = "ListTrafficPolicyVersionsResponse";
    var _LV = "LatestVersion";
    var _LVPCA = "LastVPCAssociation";
    var _LVPCAA = "ListVPCAssociationAuthorizations";
    var _LVPCAAR = "ListVPCAssociationAuthorizationsRequest";
    var _LVPCAARi = "ListVPCAssociationAuthorizationsResponse";
    var _LZG = "LocalZoneGroup";
    var _Li = "Limit";
    var _Lo = "Longitude";
    var _Loc = "Location";
    var _M = "Message";
    var _MI = "MaxItems";
    var _ML = "MeasureLatency";
    var _MN = "MetricName";
    var _MR = "MaxResults";
    var _MVA = "MultiValueAnswer";
    var _Ma = "Marker";
    var _N = "Name";
    var _NAE2 = "NotAuthorizedException";
    var _NCC = "NextContinentCode";
    var _NCCe = "NextCountryCode";
    var _NDNSN = "NextDNSName";
    var _NHZI = "NextHostedZoneId";
    var _NM = "NextMarker";
    var _NRI = "NextRecordIdentifier";
    var _NRN = "NextRecordName";
    var _NRT = "NextRecordType";
    var _NS = "NameServers";
    var _NSC = "NoSuchChange";
    var _NSCCE = "NoSuchCidrCollectionException";
    var _NSCLE = "NoSuchCidrLocationException";
    var _NSCWLLG = "NoSuchCloudWatchLogsLogGroup";
    var _NSCe = "NextSubdivisionCode";
    var _NSDS = "NoSuchDelegationSet";
    var _NSGL = "NoSuchGeoLocation";
    var _NSHC = "NoSuchHealthCheck";
    var _NSHZ = "NoSuchHostedZone";
    var _NSKSK = "NoSuchKeySigningKey";
    var _NSQLC = "NoSuchQueryLoggingConfig";
    var _NSTP = "NoSuchTrafficPolicy";
    var _NSTPI = "NoSuchTrafficPolicyInstance";
    var _NSa = "NameServer";
    var _NT = "NextToken";
    var _Na = "Namespace";
    var _Nam = "Nameserver";
    var _O = "Owner";
    var _OA = "OwningAccount";
    var _OS = "OwningService";
    var _P10 = "Period";
    var _PK = "PublicKey";
    var _PRNC = "PriorRequestNotComplete";
    var _PZ = "PrivateZone";
    var _PZVPCA = "PublicZoneVPCAssociation";
    var _Po = "Port";
    var _Pr10 = "Protocol";
    var _QLC = "QueryLoggingConfig";
    var _QLCAE = "QueryLoggingConfigAlreadyExists";
    var _QLCu = "QueryLoggingConfigs";
    var _R = "Region";
    var _RC10 = "ResponseCode";
    var _RCA = "RoutingControlArn";
    var _RD = "RecordData";
    var _RDE10 = "RecordDataEntry";
    var _RDSL = "ReusableDelegationSetLimit";
    var _RE = "ResetElements";
    var _REN = "ResettableElementName";
    var _RENL = "ResettableElementNameList";
    var _RI = "ResourceId";
    var _RIP = "ResolverIP";
    var _RIe = "RequestInterval";
    var _RIes = "ResourceIds";
    var _RN = "RecordName";
    var _RP = "ResourcePath";
    var _RR = "ResourceRecord";
    var _RRS = "ResourceRecordSet";
    var _RRSC = "ResourceRecordSetCount";
    var _RRSe = "ResourceRecordSets";
    var _RRe = "ResourceRecords";
    var _RT13 = "ResourceType";
    var _RTK = "RemoveTagKeys";
    var _RTS = "ResourceTagSet";
    var _RTSL = "ResourceTagSetList";
    var _RTSe = "ResourceTagSets";
    var _RTe = "RecordType";
    var _Re = "Regions";
    var _S = "Status";
    var _SA = "SubmittedAt";
    var _SAM = "SigningAlgorithmMnemonic";
    var _SAT = "SigningAlgorithmType";
    var _SC = "SubdivisionCode";
    var _SCC = "StartContinentCode";
    var _SCCt = "StartCountryCode";
    var _SI10 = "SetIdentifier";
    var _SM = "StatusMessage";
    var _SN10 = "SubdivisionName";
    var _SP = "ServicePrincipal";
    var _SR = "StatusReport";
    var _SRI = "StartRecordIdentifier";
    var _SRN = "StartRecordName";
    var _SRT = "StartRecordType";
    var _SS = "ServeSignature";
    var _SSC = "StartSubdivisionCode";
    var _SSe = "SearchString";
    var _St = "Statistic";
    var _Sta = "State";
    var _T10 = "Type";
    var _TDNSA = "TestDNSAnswer";
    var _TDNSAR = "TestDNSAnswerRequest";
    var _TDNSARe = "TestDNSAnswerResponse";
    var _TE = "ThrottlingException";
    var _TKL = "TagKeyList";
    var _TL = "TagList";
    var _TMHC = "TooManyHealthChecks";
    var _TMHZ = "TooManyHostedZones";
    var _TMKSK = "TooManyKeySigningKeys";
    var _TMTP = "TooManyTrafficPolicies";
    var _TMTPI = "TooManyTrafficPolicyInstances";
    var _TMTPVFCP = "TooManyTrafficPolicyVersionsForCurrentPolicy";
    var _TMVPCAA = "TooManyVPCAssociationAuthorizations";
    var _TP = "TrafficPolicy";
    var _TPAE = "TrafficPolicyAlreadyExists";
    var _TPC = "TrafficPolicyCount";
    var _TPI = "TrafficPolicyId";
    var _TPIAE = "TrafficPolicyInstanceAlreadyExists";
    var _TPIC = "TrafficPolicyInstanceCount";
    var _TPII = "TrafficPolicyInstanceId";
    var _TPIM = "TrafficPolicyIdMarker";
    var _TPINM = "TrafficPolicyInstanceNameMarker";
    var _TPITM = "TrafficPolicyInstanceTypeMarker";
    var _TPIU = "TrafficPolicyInUse";
    var _TPIr = "TrafficPolicyInstance";
    var _TPIra = "TrafficPolicyInstances";
    var _TPS = "TrafficPolicySummaries";
    var _TPSr = "TrafficPolicySummary";
    var _TPT = "TrafficPolicyType";
    var _TPV = "TrafficPolicyVersion";
    var _TPVM = "TrafficPolicyVersionMarker";
    var _TPr = "TrafficPolicies";
    var _TRIL = "TagResourceIdList";
    var _TTL = "TTL";
    var _Ta10 = "Tags";
    var _Tag = "Tag";
    var _Th = "Threshold";
    var _UHC = "UpdateHealthCheck";
    var _UHCR = "UpdateHealthCheckRequest";
    var _UHCRp = "UpdateHealthCheckResponse";
    var _UHZC = "UpdateHostedZoneComment";
    var _UHZCR = "UpdateHostedZoneCommentRequest";
    var _UHZCRp = "UpdateHostedZoneCommentResponse";
    var _UHZF = "UpdateHostedZoneFeatures";
    var _UHZFR = "UpdateHostedZoneFeaturesRequest";
    var _UHZFRp = "UpdateHostedZoneFeaturesResponse";
    var _UTPC = "UpdateTrafficPolicyComment";
    var _UTPCR = "UpdateTrafficPolicyCommentRequest";
    var _UTPCRp = "UpdateTrafficPolicyCommentResponse";
    var _UTPI = "UpdateTrafficPolicyInstance";
    var _UTPIR = "UpdateTrafficPolicyInstanceRequest";
    var _UTPIRp = "UpdateTrafficPolicyInstanceResponse";
    var _V10 = "Value";
    var _VPC = "VPC";
    var _VPCAANF = "VPCAssociationAuthorizationNotFound";
    var _VPCANF = "VPCAssociationNotFound";
    var _VPCI = "VPCId";
    var _VPCR = "VPCRegion";
    var _VPCs = "VPCs";
    var _Ve = "Version";
    var _W = "Weight";
    var _c32 = "client";
    var _co13 = "continentcode";
    var _cou = "countrycode";
    var _d = "dnsname";
    var _de = "delegationsetid";
    var _e32 = "error";
    var _ed4 = "edns0clientsubnetip";
    var _edn = "edns0clientsubnetmask";
    var _h22 = "hostedzoneid";
    var _hE32 = "httpError";
    var _hH10 = "httpHeader";
    var _hQ10 = "httpQuery";
    var _ho = "hostedzonetype";
    var _ht = "http";
    var _i = "identifier";
    var _id = "id";
    var _l = "location";
    var _m29 = "message";
    var _ma = "maxresults";
    var _mar = "marker";
    var _max = "maxitems";
    var _me = "messages";
    var _n = "nexttoken";
    var _na = "name";
    var _r4 = "recordname";
    var _re = "recordtype";
    var _res = "resolverip";
    var _s32 = "smithy.ts.sdk.synthetic.com.amazonaws.route53";
    var _st = "startcontinentcode";
    var _sta = "startcountrycode";
    var _star = "startsubdivisioncode";
    var _su = "subdivisioncode";
    var _t = "type";
    var _tr = "trafficpolicyid";
    var _tra = "trafficpolicyinstancename";
    var _traf = "trafficpolicyinstancetype";
    var _traff = "trafficpolicyversion";
    var _v = "vpcid";
    var _ve = "version";
    var _vp = "vpcregion";
    var _xN = "xmlName";
    var n032 = "com.amazonaws.route53";
    var schema_1 = (init_schema4(), __toCommonJS(schema_exports));
    var errors_1 = require_errors16();
    var Route53ServiceException_1 = require_Route53ServiceException();
    var _s_registry32 = schema_1.TypeRegistry.for(_s32);
    exports2.Route53ServiceException$ = [-3, _s32, "Route53ServiceException", 0, [], []];
    _s_registry32.registerError(exports2.Route53ServiceException$, Route53ServiceException_1.Route53ServiceException);
    var n0_registry32 = schema_1.TypeRegistry.for(n032);
    exports2.CidrBlockInUseException$ = [
      -3,
      n032,
      _CBIUE,
      { [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.CidrBlockInUseException$, errors_1.CidrBlockInUseException);
    exports2.CidrCollectionAlreadyExistsException$ = [
      -3,
      n032,
      _CCAEE,
      { [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.CidrCollectionAlreadyExistsException$, errors_1.CidrCollectionAlreadyExistsException);
    exports2.CidrCollectionInUseException$ = [
      -3,
      n032,
      _CCIUE,
      { [_e32]: _c32, [_hE32]: 400 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.CidrCollectionInUseException$, errors_1.CidrCollectionInUseException);
    exports2.CidrCollectionVersionMismatchException$ = [
      -3,
      n032,
      _CCVME,
      { [_e32]: _c32, [_hE32]: 409 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.CidrCollectionVersionMismatchException$, errors_1.CidrCollectionVersionMismatchException);
    exports2.ConcurrentModification$ = [
      -3,
      n032,
      _CM,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ConcurrentModification$, errors_1.ConcurrentModification);
    exports2.ConflictingDomainExists$ = [
      -3,
      n032,
      _CDE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ConflictingDomainExists$, errors_1.ConflictingDomainExists);
    exports2.ConflictingTypes$ = [
      -3,
      n032,
      _CT4,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ConflictingTypes$, errors_1.ConflictingTypes);
    exports2.DelegationSetAlreadyCreated$ = [
      -3,
      n032,
      _DSAC,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.DelegationSetAlreadyCreated$, errors_1.DelegationSetAlreadyCreated);
    exports2.DelegationSetAlreadyReusable$ = [
      -3,
      n032,
      _DSAR,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.DelegationSetAlreadyReusable$, errors_1.DelegationSetAlreadyReusable);
    exports2.DelegationSetInUse$ = [
      -3,
      n032,
      _DSIU,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.DelegationSetInUse$, errors_1.DelegationSetInUse);
    exports2.DelegationSetNotAvailable$ = [
      -3,
      n032,
      _DSNA,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.DelegationSetNotAvailable$, errors_1.DelegationSetNotAvailable);
    exports2.DelegationSetNotReusable$ = [
      -3,
      n032,
      _DSNR,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.DelegationSetNotReusable$, errors_1.DelegationSetNotReusable);
    exports2.DNSSECNotFound$ = [
      -3,
      n032,
      _DNSSECNF,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.DNSSECNotFound$, errors_1.DNSSECNotFound);
    exports2.HealthCheckAlreadyExists$ = [
      -3,
      n032,
      _HCAE,
      { [_e32]: _c32, [_hE32]: 409 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.HealthCheckAlreadyExists$, errors_1.HealthCheckAlreadyExists);
    exports2.HealthCheckInUse$ = [
      -3,
      n032,
      _HCIU,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.HealthCheckInUse$, errors_1.HealthCheckInUse);
    exports2.HealthCheckVersionMismatch$ = [
      -3,
      n032,
      _HCVM,
      { [_e32]: _c32, [_hE32]: 409 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.HealthCheckVersionMismatch$, errors_1.HealthCheckVersionMismatch);
    exports2.HostedZoneAlreadyExists$ = [
      -3,
      n032,
      _HZAE,
      { [_e32]: _c32, [_hE32]: 409 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.HostedZoneAlreadyExists$, errors_1.HostedZoneAlreadyExists);
    exports2.HostedZoneNotEmpty$ = [
      -3,
      n032,
      _HZNE,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.HostedZoneNotEmpty$, errors_1.HostedZoneNotEmpty);
    exports2.HostedZoneNotFound$ = [
      -3,
      n032,
      _HZNF,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.HostedZoneNotFound$, errors_1.HostedZoneNotFound);
    exports2.HostedZoneNotPrivate$ = [
      -3,
      n032,
      _HZNP,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.HostedZoneNotPrivate$, errors_1.HostedZoneNotPrivate);
    exports2.HostedZonePartiallyDelegated$ = [
      -3,
      n032,
      _HZPD,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.HostedZonePartiallyDelegated$, errors_1.HostedZonePartiallyDelegated);
    exports2.IncompatibleVersion$ = [
      -3,
      n032,
      _IV,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.IncompatibleVersion$, errors_1.IncompatibleVersion);
    exports2.InsufficientCloudWatchLogsResourcePolicy$ = [
      -3,
      n032,
      _ICWLRP,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InsufficientCloudWatchLogsResourcePolicy$, errors_1.InsufficientCloudWatchLogsResourcePolicy);
    exports2.InvalidArgument$ = [
      -3,
      n032,
      _IA,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidArgument$, errors_1.InvalidArgument);
    exports2.InvalidChangeBatch$ = [
      -3,
      n032,
      _ICB,
      { [_e32]: _c32 },
      [_me, _m29],
      [[() => ErrorMessages, 0], 0]
    ];
    n0_registry32.registerError(exports2.InvalidChangeBatch$, errors_1.InvalidChangeBatch);
    exports2.InvalidDomainName$ = [
      -3,
      n032,
      _IDN,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidDomainName$, errors_1.InvalidDomainName);
    exports2.InvalidInput$ = [
      -3,
      n032,
      _II2,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidInput$, errors_1.InvalidInput);
    exports2.InvalidKeySigningKeyName$ = [
      -3,
      n032,
      _IKSKN,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidKeySigningKeyName$, errors_1.InvalidKeySigningKeyName);
    exports2.InvalidKeySigningKeyStatus$ = [
      -3,
      n032,
      _IKSKS,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidKeySigningKeyStatus$, errors_1.InvalidKeySigningKeyStatus);
    exports2.InvalidKMSArn$ = [
      -3,
      n032,
      _IKMSA,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidKMSArn$, errors_1.InvalidKMSArn);
    exports2.InvalidPaginationToken$ = [
      -3,
      n032,
      _IPT2,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidPaginationToken$, errors_1.InvalidPaginationToken);
    exports2.InvalidSigningStatus$ = [
      -3,
      n032,
      _ISS,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidSigningStatus$, errors_1.InvalidSigningStatus);
    exports2.InvalidTrafficPolicyDocument$ = [
      -3,
      n032,
      _ITPD,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidTrafficPolicyDocument$, errors_1.InvalidTrafficPolicyDocument);
    exports2.InvalidVPCId$ = [
      -3,
      n032,
      _IVPCI,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidVPCId$, errors_1.InvalidVPCId);
    exports2.KeySigningKeyAlreadyExists$ = [
      -3,
      n032,
      _KSKAE,
      { [_e32]: _c32, [_hE32]: 409 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.KeySigningKeyAlreadyExists$, errors_1.KeySigningKeyAlreadyExists);
    exports2.KeySigningKeyInParentDSRecord$ = [
      -3,
      n032,
      _KSKIPDSR,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.KeySigningKeyInParentDSRecord$, errors_1.KeySigningKeyInParentDSRecord);
    exports2.KeySigningKeyInUse$ = [
      -3,
      n032,
      _KSKIU,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.KeySigningKeyInUse$, errors_1.KeySigningKeyInUse);
    exports2.KeySigningKeyWithActiveStatusNotFound$ = [
      -3,
      n032,
      _KSKWASNF,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.KeySigningKeyWithActiveStatusNotFound$, errors_1.KeySigningKeyWithActiveStatusNotFound);
    exports2.LastVPCAssociation$ = [
      -3,
      n032,
      _LVPCA,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.LastVPCAssociation$, errors_1.LastVPCAssociation);
    exports2.LimitsExceeded$ = [
      -3,
      n032,
      _LE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.LimitsExceeded$, errors_1.LimitsExceeded);
    exports2.NoSuchChange$ = [
      -3,
      n032,
      _NSC,
      { [_e32]: _c32, [_hE32]: 404 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.NoSuchChange$, errors_1.NoSuchChange);
    exports2.NoSuchCidrCollectionException$ = [
      -3,
      n032,
      _NSCCE,
      { [_e32]: _c32, [_hE32]: 404 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.NoSuchCidrCollectionException$, errors_1.NoSuchCidrCollectionException);
    exports2.NoSuchCidrLocationException$ = [
      -3,
      n032,
      _NSCLE,
      { [_e32]: _c32, [_hE32]: 404 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.NoSuchCidrLocationException$, errors_1.NoSuchCidrLocationException);
    exports2.NoSuchCloudWatchLogsLogGroup$ = [
      -3,
      n032,
      _NSCWLLG,
      { [_e32]: _c32, [_hE32]: 404 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.NoSuchCloudWatchLogsLogGroup$, errors_1.NoSuchCloudWatchLogsLogGroup);
    exports2.NoSuchDelegationSet$ = [
      -3,
      n032,
      _NSDS,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.NoSuchDelegationSet$, errors_1.NoSuchDelegationSet);
    exports2.NoSuchGeoLocation$ = [
      -3,
      n032,
      _NSGL,
      { [_e32]: _c32, [_hE32]: 404 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.NoSuchGeoLocation$, errors_1.NoSuchGeoLocation);
    exports2.NoSuchHealthCheck$ = [
      -3,
      n032,
      _NSHC,
      { [_e32]: _c32, [_hE32]: 404 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.NoSuchHealthCheck$, errors_1.NoSuchHealthCheck);
    exports2.NoSuchHostedZone$ = [
      -3,
      n032,
      _NSHZ,
      { [_e32]: _c32, [_hE32]: 404 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.NoSuchHostedZone$, errors_1.NoSuchHostedZone);
    exports2.NoSuchKeySigningKey$ = [
      -3,
      n032,
      _NSKSK,
      { [_e32]: _c32, [_hE32]: 404 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.NoSuchKeySigningKey$, errors_1.NoSuchKeySigningKey);
    exports2.NoSuchQueryLoggingConfig$ = [
      -3,
      n032,
      _NSQLC,
      { [_e32]: _c32, [_hE32]: 404 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.NoSuchQueryLoggingConfig$, errors_1.NoSuchQueryLoggingConfig);
    exports2.NoSuchTrafficPolicy$ = [
      -3,
      n032,
      _NSTP,
      { [_e32]: _c32, [_hE32]: 404 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.NoSuchTrafficPolicy$, errors_1.NoSuchTrafficPolicy);
    exports2.NoSuchTrafficPolicyInstance$ = [
      -3,
      n032,
      _NSTPI,
      { [_e32]: _c32, [_hE32]: 404 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.NoSuchTrafficPolicyInstance$, errors_1.NoSuchTrafficPolicyInstance);
    exports2.NotAuthorizedException$ = [
      -3,
      n032,
      _NAE2,
      { [_e32]: _c32, [_hE32]: 401 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.NotAuthorizedException$, errors_1.NotAuthorizedException);
    exports2.PriorRequestNotComplete$ = [
      -3,
      n032,
      _PRNC,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.PriorRequestNotComplete$, errors_1.PriorRequestNotComplete);
    exports2.PublicZoneVPCAssociation$ = [
      -3,
      n032,
      _PZVPCA,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.PublicZoneVPCAssociation$, errors_1.PublicZoneVPCAssociation);
    exports2.QueryLoggingConfigAlreadyExists$ = [
      -3,
      n032,
      _QLCAE,
      { [_e32]: _c32, [_hE32]: 409 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.QueryLoggingConfigAlreadyExists$, errors_1.QueryLoggingConfigAlreadyExists);
    exports2.ThrottlingException$ = [
      -3,
      n032,
      _TE,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ThrottlingException$, errors_1.ThrottlingException);
    exports2.TooManyHealthChecks$ = [
      -3,
      n032,
      _TMHC,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.TooManyHealthChecks$, errors_1.TooManyHealthChecks);
    exports2.TooManyHostedZones$ = [
      -3,
      n032,
      _TMHZ,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.TooManyHostedZones$, errors_1.TooManyHostedZones);
    exports2.TooManyKeySigningKeys$ = [
      -3,
      n032,
      _TMKSK,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.TooManyKeySigningKeys$, errors_1.TooManyKeySigningKeys);
    exports2.TooManyTrafficPolicies$ = [
      -3,
      n032,
      _TMTP,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.TooManyTrafficPolicies$, errors_1.TooManyTrafficPolicies);
    exports2.TooManyTrafficPolicyInstances$ = [
      -3,
      n032,
      _TMTPI,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.TooManyTrafficPolicyInstances$, errors_1.TooManyTrafficPolicyInstances);
    exports2.TooManyTrafficPolicyVersionsForCurrentPolicy$ = [
      -3,
      n032,
      _TMTPVFCP,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.TooManyTrafficPolicyVersionsForCurrentPolicy$, errors_1.TooManyTrafficPolicyVersionsForCurrentPolicy);
    exports2.TooManyVPCAssociationAuthorizations$ = [
      -3,
      n032,
      _TMVPCAA,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.TooManyVPCAssociationAuthorizations$, errors_1.TooManyVPCAssociationAuthorizations);
    exports2.TrafficPolicyAlreadyExists$ = [
      -3,
      n032,
      _TPAE,
      { [_e32]: _c32, [_hE32]: 409 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.TrafficPolicyAlreadyExists$, errors_1.TrafficPolicyAlreadyExists);
    exports2.TrafficPolicyInstanceAlreadyExists$ = [
      -3,
      n032,
      _TPIAE,
      { [_e32]: _c32, [_hE32]: 409 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.TrafficPolicyInstanceAlreadyExists$, errors_1.TrafficPolicyInstanceAlreadyExists);
    exports2.TrafficPolicyInUse$ = [
      -3,
      n032,
      _TPIU,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.TrafficPolicyInUse$, errors_1.TrafficPolicyInUse);
    exports2.VPCAssociationAuthorizationNotFound$ = [
      -3,
      n032,
      _VPCAANF,
      { [_e32]: _c32, [_hE32]: 404 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.VPCAssociationAuthorizationNotFound$, errors_1.VPCAssociationAuthorizationNotFound);
    exports2.VPCAssociationNotFound$ = [
      -3,
      n032,
      _VPCANF,
      { [_e32]: _c32, [_hE32]: 404 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.VPCAssociationNotFound$, errors_1.VPCAssociationNotFound);
    exports2.errorTypeRegistries = [
      _s_registry32,
      n0_registry32
    ];
    exports2.AccountLimit$ = [
      3,
      n032,
      _AL,
      0,
      [_T10, _V10],
      [0, 1],
      2
    ];
    exports2.ActivateKeySigningKeyRequest$ = [
      3,
      n032,
      _AKSKR,
      0,
      [_HZI, _N],
      [[0, 1], [0, 1]],
      2
    ];
    exports2.ActivateKeySigningKeyResponse$ = [
      3,
      n032,
      _AKSKRc,
      0,
      [_CI],
      [() => exports2.ChangeInfo$],
      1
    ];
    exports2.AlarmIdentifier$ = [
      3,
      n032,
      _AI2,
      0,
      [_R, _N],
      [0, 0],
      2
    ];
    exports2.AliasTarget$ = [
      3,
      n032,
      _AT13,
      0,
      [_HZI, _DNSN, _ETH],
      [0, 0, 2],
      3
    ];
    exports2.AssociateVPCWithHostedZoneRequest$ = [
      3,
      n032,
      _AVPCWHZR,
      0,
      [_HZI, _VPC, _C11],
      [[0, 1], () => exports2.VPC$, 0],
      2
    ];
    exports2.AssociateVPCWithHostedZoneResponse$ = [
      3,
      n032,
      _AVPCWHZRs,
      0,
      [_CI],
      [() => exports2.ChangeInfo$],
      1
    ];
    exports2.Change$ = [
      3,
      n032,
      _Ch,
      0,
      [_A10, _RRS],
      [0, [() => exports2.ResourceRecordSet$, 0]],
      2
    ];
    exports2.ChangeBatch$ = [
      3,
      n032,
      _CB,
      0,
      [_Cha, _C11],
      [[() => Changes, 0], 0],
      1
    ];
    exports2.ChangeCidrCollectionRequest$ = [
      3,
      n032,
      _CCCR,
      0,
      [_I, _Cha, _CV4],
      [[0, 1], [() => CidrCollectionChanges, 0], 1],
      2
    ];
    exports2.ChangeCidrCollectionResponse$ = [
      3,
      n032,
      _CCCRh,
      0,
      [_I],
      [0],
      1
    ];
    exports2.ChangeInfo$ = [
      3,
      n032,
      _CI,
      0,
      [_I, _S, _SA, _C11],
      [0, 0, 4, 0],
      3
    ];
    exports2.ChangeResourceRecordSetsRequest$ = [
      3,
      n032,
      _CRRSR,
      0,
      [_HZI, _CB],
      [[0, 1], [() => exports2.ChangeBatch$, 0]],
      2
    ];
    exports2.ChangeResourceRecordSetsResponse$ = [
      3,
      n032,
      _CRRSRh,
      0,
      [_CI],
      [() => exports2.ChangeInfo$],
      1
    ];
    exports2.ChangeTagsForResourceRequest$ = [
      3,
      n032,
      _CTFRR,
      0,
      [_RT13, _RI, _ATd, _RTK],
      [[0, 1], [0, 1], [() => TagList, 0], [() => TagKeyList, 0]],
      2
    ];
    exports2.ChangeTagsForResourceResponse$ = [
      3,
      n032,
      _CTFRRh,
      0,
      [],
      []
    ];
    exports2.CidrBlockSummary$ = [
      3,
      n032,
      _CBS,
      0,
      [_CBi, _LN],
      [0, 0]
    ];
    exports2.CidrCollection$ = [
      3,
      n032,
      _CC,
      0,
      [_Ar, _I, _N, _Ve],
      [0, 0, 0, 1]
    ];
    exports2.CidrCollectionChange$ = [
      3,
      n032,
      _CCC,
      0,
      [_LN, _A10, _CL],
      [0, 0, [() => CidrList, 0]],
      3
    ];
    exports2.CidrRoutingConfig$ = [
      3,
      n032,
      _CRC,
      0,
      [_CIo, _LN],
      [0, 0],
      2
    ];
    exports2.CloudWatchAlarmConfiguration$ = [
      3,
      n032,
      _CWAC,
      0,
      [_EP, _Th, _CO, _P10, _MN, _Na, _St, _D],
      [1, 1, 0, 1, 0, 0, 0, [() => DimensionList, 0]],
      7
    ];
    exports2.CollectionSummary$ = [
      3,
      n032,
      _CS4,
      0,
      [_Ar, _I, _N, _Ve],
      [0, 0, 0, 1]
    ];
    exports2.Coordinates$ = [
      3,
      n032,
      _Co,
      0,
      [_L2, _Lo],
      [0, 0],
      2
    ];
    exports2.CreateCidrCollectionRequest$ = [
      3,
      n032,
      _CCCRr,
      0,
      [_N, _CR],
      [0, 0],
      2
    ];
    exports2.CreateCidrCollectionResponse$ = [
      3,
      n032,
      _CCCRre,
      0,
      [_Col, _Loc],
      [() => exports2.CidrCollection$, [0, { [_hH10]: _Loc }]]
    ];
    exports2.CreateHealthCheckRequest$ = [
      3,
      n032,
      _CHCR,
      0,
      [_CR, _HCC],
      [0, [() => exports2.HealthCheckConfig$, 0]],
      2
    ];
    exports2.CreateHealthCheckResponse$ = [
      3,
      n032,
      _CHCRr,
      0,
      [_HC, _Loc],
      [[() => exports2.HealthCheck$, 0], [0, { [_hH10]: _Loc }]],
      2
    ];
    exports2.CreateHostedZoneRequest$ = [
      3,
      n032,
      _CHZR,
      0,
      [_N, _CR, _VPC, _HZC, _DSI],
      [0, 0, () => exports2.VPC$, () => exports2.HostedZoneConfig$, 0],
      2
    ];
    exports2.CreateHostedZoneResponse$ = [
      3,
      n032,
      _CHZRr,
      0,
      [_HZ, _CI, _DS10, _Loc, _VPC],
      [() => exports2.HostedZone$, () => exports2.ChangeInfo$, [() => exports2.DelegationSet$, 0], [0, { [_hH10]: _Loc }], () => exports2.VPC$],
      4
    ];
    exports2.CreateKeySigningKeyRequest$ = [
      3,
      n032,
      _CKSKR,
      0,
      [_CR, _HZI, _KMSA, _N, _S],
      [0, 0, 0, 0, 0],
      5
    ];
    exports2.CreateKeySigningKeyResponse$ = [
      3,
      n032,
      _CKSKRr,
      0,
      [_CI, _KSK, _Loc],
      [() => exports2.ChangeInfo$, () => exports2.KeySigningKey$, [0, { [_hH10]: _Loc }]],
      3
    ];
    exports2.CreateQueryLoggingConfigRequest$ = [
      3,
      n032,
      _CQLCR,
      0,
      [_HZI, _CWLLGA],
      [0, 0],
      2
    ];
    exports2.CreateQueryLoggingConfigResponse$ = [
      3,
      n032,
      _CQLCRr,
      0,
      [_QLC, _Loc],
      [() => exports2.QueryLoggingConfig$, [0, { [_hH10]: _Loc }]],
      2
    ];
    exports2.CreateReusableDelegationSetRequest$ = [
      3,
      n032,
      _CRDSR,
      0,
      [_CR, _HZI],
      [0, 0],
      1
    ];
    exports2.CreateReusableDelegationSetResponse$ = [
      3,
      n032,
      _CRDSRr,
      0,
      [_DS10, _Loc],
      [[() => exports2.DelegationSet$, 0], [0, { [_hH10]: _Loc }]],
      2
    ];
    exports2.CreateTrafficPolicyInstanceRequest$ = [
      3,
      n032,
      _CTPIR,
      0,
      [_HZI, _N, _TTL, _TPI, _TPV],
      [0, 0, 1, 0, 1],
      5
    ];
    exports2.CreateTrafficPolicyInstanceResponse$ = [
      3,
      n032,
      _CTPIRr,
      0,
      [_TPIr, _Loc],
      [() => exports2.TrafficPolicyInstance$, [0, { [_hH10]: _Loc }]],
      2
    ];
    exports2.CreateTrafficPolicyRequest$ = [
      3,
      n032,
      _CTPR,
      0,
      [_N, _Do, _C11],
      [0, 0, 0],
      2
    ];
    exports2.CreateTrafficPolicyResponse$ = [
      3,
      n032,
      _CTPRr,
      0,
      [_TP, _Loc],
      [() => exports2.TrafficPolicy$, [0, { [_hH10]: _Loc }]],
      2
    ];
    exports2.CreateTrafficPolicyVersionRequest$ = [
      3,
      n032,
      _CTPVR,
      0,
      [_I, _Do, _C11],
      [[0, 1], 0, 0],
      2
    ];
    exports2.CreateTrafficPolicyVersionResponse$ = [
      3,
      n032,
      _CTPVRr,
      0,
      [_TP, _Loc],
      [() => exports2.TrafficPolicy$, [0, { [_hH10]: _Loc }]],
      2
    ];
    exports2.CreateVPCAssociationAuthorizationRequest$ = [
      3,
      n032,
      _CVPCAAR,
      0,
      [_HZI, _VPC],
      [[0, 1], () => exports2.VPC$],
      2
    ];
    exports2.CreateVPCAssociationAuthorizationResponse$ = [
      3,
      n032,
      _CVPCAARr,
      0,
      [_HZI, _VPC],
      [0, () => exports2.VPC$],
      2
    ];
    exports2.DeactivateKeySigningKeyRequest$ = [
      3,
      n032,
      _DKSKR,
      0,
      [_HZI, _N],
      [[0, 1], [0, 1]],
      2
    ];
    exports2.DeactivateKeySigningKeyResponse$ = [
      3,
      n032,
      _DKSKRe,
      0,
      [_CI],
      [() => exports2.ChangeInfo$],
      1
    ];
    exports2.DelegationSet$ = [
      3,
      n032,
      _DS10,
      0,
      [_NS, _I, _CR],
      [[() => DelegationSetNameServers, 0], 0, 0],
      1
    ];
    exports2.DeleteCidrCollectionRequest$ = [
      3,
      n032,
      _DCCR,
      0,
      [_I],
      [[0, 1]],
      1
    ];
    exports2.DeleteCidrCollectionResponse$ = [
      3,
      n032,
      _DCCRe,
      0,
      [],
      []
    ];
    exports2.DeleteHealthCheckRequest$ = [
      3,
      n032,
      _DHCR,
      0,
      [_HCI],
      [[0, 1]],
      1
    ];
    exports2.DeleteHealthCheckResponse$ = [
      3,
      n032,
      _DHCRe,
      0,
      [],
      []
    ];
    exports2.DeleteHostedZoneRequest$ = [
      3,
      n032,
      _DHZR,
      0,
      [_I],
      [[0, 1]],
      1
    ];
    exports2.DeleteHostedZoneResponse$ = [
      3,
      n032,
      _DHZRe,
      0,
      [_CI],
      [() => exports2.ChangeInfo$],
      1
    ];
    exports2.DeleteKeySigningKeyRequest$ = [
      3,
      n032,
      _DKSKRel,
      0,
      [_HZI, _N],
      [[0, 1], [0, 1]],
      2
    ];
    exports2.DeleteKeySigningKeyResponse$ = [
      3,
      n032,
      _DKSKRele,
      0,
      [_CI],
      [() => exports2.ChangeInfo$],
      1
    ];
    exports2.DeleteQueryLoggingConfigRequest$ = [
      3,
      n032,
      _DQLCR,
      0,
      [_I],
      [[0, 1]],
      1
    ];
    exports2.DeleteQueryLoggingConfigResponse$ = [
      3,
      n032,
      _DQLCRe,
      0,
      [],
      []
    ];
    exports2.DeleteReusableDelegationSetRequest$ = [
      3,
      n032,
      _DRDSR,
      0,
      [_I],
      [[0, 1]],
      1
    ];
    exports2.DeleteReusableDelegationSetResponse$ = [
      3,
      n032,
      _DRDSRe,
      0,
      [],
      []
    ];
    exports2.DeleteTrafficPolicyInstanceRequest$ = [
      3,
      n032,
      _DTPIR,
      0,
      [_I],
      [[0, 1]],
      1
    ];
    exports2.DeleteTrafficPolicyInstanceResponse$ = [
      3,
      n032,
      _DTPIRe,
      0,
      [],
      []
    ];
    exports2.DeleteTrafficPolicyRequest$ = [
      3,
      n032,
      _DTPR,
      0,
      [_I, _Ve],
      [[0, 1], [1, 1]],
      2
    ];
    exports2.DeleteTrafficPolicyResponse$ = [
      3,
      n032,
      _DTPRe,
      0,
      [],
      []
    ];
    exports2.DeleteVPCAssociationAuthorizationRequest$ = [
      3,
      n032,
      _DVPCAAR,
      0,
      [_HZI, _VPC],
      [[0, 1], () => exports2.VPC$],
      2
    ];
    exports2.DeleteVPCAssociationAuthorizationResponse$ = [
      3,
      n032,
      _DVPCAARe,
      0,
      [],
      []
    ];
    exports2.Dimension$ = [
      3,
      n032,
      _Di,
      0,
      [_N, _V10],
      [0, 0],
      2
    ];
    exports2.DisableHostedZoneDNSSECRequest$ = [
      3,
      n032,
      _DHZDNSSECR,
      0,
      [_HZI],
      [[0, 1]],
      1
    ];
    exports2.DisableHostedZoneDNSSECResponse$ = [
      3,
      n032,
      _DHZDNSSECRi,
      0,
      [_CI],
      [() => exports2.ChangeInfo$],
      1
    ];
    exports2.DisassociateVPCFromHostedZoneRequest$ = [
      3,
      n032,
      _DVPCFHZR,
      0,
      [_HZI, _VPC, _C11],
      [[0, 1], () => exports2.VPC$, 0],
      2
    ];
    exports2.DisassociateVPCFromHostedZoneResponse$ = [
      3,
      n032,
      _DVPCFHZRi,
      0,
      [_CI],
      [() => exports2.ChangeInfo$],
      1
    ];
    exports2.DNSSECStatus$ = [
      3,
      n032,
      _DNSSECS,
      0,
      [_SS, _SM],
      [0, 0]
    ];
    exports2.EnableHostedZoneDNSSECRequest$ = [
      3,
      n032,
      _EHZDNSSECR,
      0,
      [_HZI],
      [[0, 1]],
      1
    ];
    exports2.EnableHostedZoneDNSSECResponse$ = [
      3,
      n032,
      _EHZDNSSECRn,
      0,
      [_CI],
      [() => exports2.ChangeInfo$],
      1
    ];
    exports2.GeoLocation$ = [
      3,
      n032,
      _GL,
      0,
      [_CCo, _CCou, _SC],
      [0, 0, 0]
    ];
    exports2.GeoLocationDetails$ = [
      3,
      n032,
      _GLD,
      0,
      [_CCo, _CN, _CCou, _CNo, _SC, _SN10],
      [0, 0, 0, 0, 0, 0]
    ];
    exports2.GeoProximityLocation$ = [
      3,
      n032,
      _GPL,
      0,
      [_AWSR, _LZG, _Co, _B],
      [0, 0, () => exports2.Coordinates$, 1]
    ];
    exports2.GetAccountLimitRequest$ = [
      3,
      n032,
      _GALR,
      0,
      [_T10],
      [[0, 1]],
      1
    ];
    exports2.GetAccountLimitResponse$ = [
      3,
      n032,
      _GALRe,
      0,
      [_Li, _Cou],
      [() => exports2.AccountLimit$, 1],
      2
    ];
    exports2.GetChangeRequest$ = [
      3,
      n032,
      _GCR,
      0,
      [_I],
      [[0, 1]],
      1
    ];
    exports2.GetChangeResponse$ = [
      3,
      n032,
      _GCRe,
      0,
      [_CI],
      [() => exports2.ChangeInfo$],
      1
    ];
    exports2.GetCheckerIpRangesRequest$ = [
      3,
      n032,
      _GCIRR,
      0,
      [],
      []
    ];
    exports2.GetCheckerIpRangesResponse$ = [
      3,
      n032,
      _GCIRRe,
      0,
      [_CIR],
      [64 | 0],
      1
    ];
    exports2.GetDNSSECRequest$ = [
      3,
      n032,
      _GDNSSECR,
      0,
      [_HZI],
      [[0, 1]],
      1
    ];
    exports2.GetDNSSECResponse$ = [
      3,
      n032,
      _GDNSSECRe,
      0,
      [_S, _KSKe],
      [() => exports2.DNSSECStatus$, () => KeySigningKeys],
      2
    ];
    exports2.GetGeoLocationRequest$ = [
      3,
      n032,
      _GGLR,
      0,
      [_CCo, _CCou, _SC],
      [[0, { [_hQ10]: _co13 }], [0, { [_hQ10]: _cou }], [0, { [_hQ10]: _su }]]
    ];
    exports2.GetGeoLocationResponse$ = [
      3,
      n032,
      _GGLRe,
      0,
      [_GLD],
      [() => exports2.GeoLocationDetails$],
      1
    ];
    exports2.GetHealthCheckCountRequest$ = [
      3,
      n032,
      _GHCCR,
      0,
      [],
      []
    ];
    exports2.GetHealthCheckCountResponse$ = [
      3,
      n032,
      _GHCCRe,
      0,
      [_HCCe],
      [1],
      1
    ];
    exports2.GetHealthCheckLastFailureReasonRequest$ = [
      3,
      n032,
      _GHCLFRR,
      0,
      [_HCI],
      [[0, 1]],
      1
    ];
    exports2.GetHealthCheckLastFailureReasonResponse$ = [
      3,
      n032,
      _GHCLFRRe,
      0,
      [_HCO],
      [[() => HealthCheckObservations, 0]],
      1
    ];
    exports2.GetHealthCheckRequest$ = [
      3,
      n032,
      _GHCR,
      0,
      [_HCI],
      [[0, 1]],
      1
    ];
    exports2.GetHealthCheckResponse$ = [
      3,
      n032,
      _GHCRe,
      0,
      [_HC],
      [[() => exports2.HealthCheck$, 0]],
      1
    ];
    exports2.GetHealthCheckStatusRequest$ = [
      3,
      n032,
      _GHCSR,
      0,
      [_HCI],
      [[0, 1]],
      1
    ];
    exports2.GetHealthCheckStatusResponse$ = [
      3,
      n032,
      _GHCSRe,
      0,
      [_HCO],
      [[() => HealthCheckObservations, 0]],
      1
    ];
    exports2.GetHostedZoneCountRequest$ = [
      3,
      n032,
      _GHZCR,
      0,
      [],
      []
    ];
    exports2.GetHostedZoneCountResponse$ = [
      3,
      n032,
      _GHZCRe,
      0,
      [_HZCo],
      [1],
      1
    ];
    exports2.GetHostedZoneLimitRequest$ = [
      3,
      n032,
      _GHZLR,
      0,
      [_T10, _HZI],
      [[0, 1], [0, 1]],
      2
    ];
    exports2.GetHostedZoneLimitResponse$ = [
      3,
      n032,
      _GHZLRe,
      0,
      [_Li, _Cou],
      [() => exports2.HostedZoneLimit$, 1],
      2
    ];
    exports2.GetHostedZoneRequest$ = [
      3,
      n032,
      _GHZR,
      0,
      [_I],
      [[0, 1]],
      1
    ];
    exports2.GetHostedZoneResponse$ = [
      3,
      n032,
      _GHZRe,
      0,
      [_HZ, _DS10, _VPCs],
      [() => exports2.HostedZone$, [() => exports2.DelegationSet$, 0], [() => VPCs, 0]],
      1
    ];
    exports2.GetQueryLoggingConfigRequest$ = [
      3,
      n032,
      _GQLCR,
      0,
      [_I],
      [[0, 1]],
      1
    ];
    exports2.GetQueryLoggingConfigResponse$ = [
      3,
      n032,
      _GQLCRe,
      0,
      [_QLC],
      [() => exports2.QueryLoggingConfig$],
      1
    ];
    exports2.GetReusableDelegationSetLimitRequest$ = [
      3,
      n032,
      _GRDSLR,
      0,
      [_T10, _DSI],
      [[0, 1], [0, 1]],
      2
    ];
    exports2.GetReusableDelegationSetLimitResponse$ = [
      3,
      n032,
      _GRDSLRe,
      0,
      [_Li, _Cou],
      [() => exports2.ReusableDelegationSetLimit$, 1],
      2
    ];
    exports2.GetReusableDelegationSetRequest$ = [
      3,
      n032,
      _GRDSR,
      0,
      [_I],
      [[0, 1]],
      1
    ];
    exports2.GetReusableDelegationSetResponse$ = [
      3,
      n032,
      _GRDSRe,
      0,
      [_DS10],
      [[() => exports2.DelegationSet$, 0]],
      1
    ];
    exports2.GetTrafficPolicyInstanceCountRequest$ = [
      3,
      n032,
      _GTPICR,
      0,
      [],
      []
    ];
    exports2.GetTrafficPolicyInstanceCountResponse$ = [
      3,
      n032,
      _GTPICRe,
      0,
      [_TPIC],
      [1],
      1
    ];
    exports2.GetTrafficPolicyInstanceRequest$ = [
      3,
      n032,
      _GTPIR,
      0,
      [_I],
      [[0, 1]],
      1
    ];
    exports2.GetTrafficPolicyInstanceResponse$ = [
      3,
      n032,
      _GTPIRe,
      0,
      [_TPIr],
      [() => exports2.TrafficPolicyInstance$],
      1
    ];
    exports2.GetTrafficPolicyRequest$ = [
      3,
      n032,
      _GTPR,
      0,
      [_I, _Ve],
      [[0, 1], [1, 1]],
      2
    ];
    exports2.GetTrafficPolicyResponse$ = [
      3,
      n032,
      _GTPRe,
      0,
      [_TP],
      [() => exports2.TrafficPolicy$],
      1
    ];
    exports2.HealthCheck$ = [
      3,
      n032,
      _HC,
      0,
      [_I, _CR, _HCC, _HCV, _LS, _CWAC],
      [0, 0, [() => exports2.HealthCheckConfig$, 0], 1, () => exports2.LinkedService$, [() => exports2.CloudWatchAlarmConfiguration$, 0]],
      4
    ];
    exports2.HealthCheckConfig$ = [
      3,
      n032,
      _HCC,
      0,
      [_T10, _IPA, _Po, _RP, _FQDN, _SSe, _RIe, _FT, _ML, _In, _Dis, _HT, _CHC, _ESNI, _Re, _AI2, _IDHS, _RCA],
      [0, 0, 1, 0, 0, 0, 1, 1, 2, 2, 2, 1, [() => ChildHealthCheckList, 0], 2, [() => HealthCheckRegionList, 0], () => exports2.AlarmIdentifier$, 0, 0],
      1
    ];
    exports2.HealthCheckObservation$ = [
      3,
      n032,
      _HCOe,
      0,
      [_R, _IPA, _SR],
      [0, 0, () => exports2.StatusReport$]
    ];
    exports2.HostedZone$ = [
      3,
      n032,
      _HZ,
      0,
      [_I, _N, _CR, _Con, _RRSC, _LS, _F],
      [0, 0, 0, () => exports2.HostedZoneConfig$, 1, () => exports2.LinkedService$, () => exports2.HostedZoneFeatures$],
      3
    ];
    exports2.HostedZoneConfig$ = [
      3,
      n032,
      _HZC,
      0,
      [_C11, _PZ],
      [0, 2]
    ];
    exports2.HostedZoneFailureReasons$ = [
      3,
      n032,
      _HZFR,
      0,
      [_AR10],
      [0]
    ];
    exports2.HostedZoneFeatures$ = [
      3,
      n032,
      _HZF,
      0,
      [_ARS, _FR],
      [0, () => exports2.HostedZoneFailureReasons$]
    ];
    exports2.HostedZoneLimit$ = [
      3,
      n032,
      _HZL,
      0,
      [_T10, _V10],
      [0, 1],
      2
    ];
    exports2.HostedZoneOwner$ = [
      3,
      n032,
      _HZO,
      0,
      [_OA, _OS],
      [0, 0]
    ];
    exports2.HostedZoneSummary$ = [
      3,
      n032,
      _HZS,
      0,
      [_HZI, _N, _O],
      [0, 0, () => exports2.HostedZoneOwner$],
      3
    ];
    exports2.KeySigningKey$ = [
      3,
      n032,
      _KSK,
      0,
      [_N, _KA, _Fl, _SAM, _SAT, _DAM, _DAT, _KT, _DV, _PK, _DSR, _DNSKEYR, _S, _SM, _CD, _LMD],
      [0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 0, 0, 0, 0, 4, 4]
    ];
    exports2.LinkedService$ = [
      3,
      n032,
      _LS,
      0,
      [_SP, _De],
      [0, 0]
    ];
    exports2.ListCidrBlocksRequest$ = [
      3,
      n032,
      _LCBR,
      0,
      [_CIo, _LN, _NT, _MR],
      [[0, 1], [0, { [_hQ10]: _l }], [0, { [_hQ10]: _n }], [1, { [_hQ10]: _ma }]],
      1
    ];
    exports2.ListCidrBlocksResponse$ = [
      3,
      n032,
      _LCBRi,
      0,
      [_NT, _CBid],
      [0, () => CidrBlockSummaries]
    ];
    exports2.ListCidrCollectionsRequest$ = [
      3,
      n032,
      _LCCR,
      0,
      [_NT, _MR],
      [[0, { [_hQ10]: _n }], [1, { [_hQ10]: _ma }]]
    ];
    exports2.ListCidrCollectionsResponse$ = [
      3,
      n032,
      _LCCRi,
      0,
      [_NT, _CCi],
      [0, () => CollectionSummaries]
    ];
    exports2.ListCidrLocationsRequest$ = [
      3,
      n032,
      _LCLR,
      0,
      [_CIo, _NT, _MR],
      [[0, 1], [0, { [_hQ10]: _n }], [1, { [_hQ10]: _ma }]],
      1
    ];
    exports2.ListCidrLocationsResponse$ = [
      3,
      n032,
      _LCLRi,
      0,
      [_NT, _CLi],
      [0, () => LocationSummaries]
    ];
    exports2.ListGeoLocationsRequest$ = [
      3,
      n032,
      _LGLR,
      0,
      [_SCC, _SCCt, _SSC, _MI],
      [[0, { [_hQ10]: _st }], [0, { [_hQ10]: _sta }], [0, { [_hQ10]: _star }], [1, { [_hQ10]: _max }]]
    ];
    exports2.ListGeoLocationsResponse$ = [
      3,
      n032,
      _LGLRi,
      0,
      [_GLDL, _IT4, _MI, _NCC, _NCCe, _NSCe],
      [[() => GeoLocationDetailsList, 0], 2, 1, 0, 0, 0],
      3
    ];
    exports2.ListHealthChecksRequest$ = [
      3,
      n032,
      _LHCR,
      0,
      [_Ma, _MI],
      [[0, { [_hQ10]: _mar }], [1, { [_hQ10]: _max }]]
    ];
    exports2.ListHealthChecksResponse$ = [
      3,
      n032,
      _LHCRi,
      0,
      [_HCe, _Ma, _IT4, _MI, _NM],
      [[() => HealthChecks, 0], 0, 2, 1, 0],
      4
    ];
    exports2.ListHostedZonesByNameRequest$ = [
      3,
      n032,
      _LHZBNR,
      0,
      [_DNSN, _HZI, _MI],
      [[0, { [_hQ10]: _d }], [0, { [_hQ10]: _h22 }], [1, { [_hQ10]: _max }]]
    ];
    exports2.ListHostedZonesByNameResponse$ = [
      3,
      n032,
      _LHZBNRi,
      0,
      [_HZo, _IT4, _MI, _DNSN, _HZI, _NDNSN, _NHZI],
      [[() => HostedZones, 0], 2, 1, 0, 0, 0, 0],
      3
    ];
    exports2.ListHostedZonesByVPCRequest$ = [
      3,
      n032,
      _LHZBVPCR,
      0,
      [_VPCI, _VPCR, _MI, _NT],
      [[0, { [_hQ10]: _v }], [0, { [_hQ10]: _vp }], [1, { [_hQ10]: _max }], [0, { [_hQ10]: _n }]],
      2
    ];
    exports2.ListHostedZonesByVPCResponse$ = [
      3,
      n032,
      _LHZBVPCRi,
      0,
      [_HZSo, _MI, _NT],
      [[() => HostedZoneSummaries, 0], 1, 0],
      2
    ];
    exports2.ListHostedZonesRequest$ = [
      3,
      n032,
      _LHZR,
      0,
      [_Ma, _MI, _DSI, _HZT],
      [[0, { [_hQ10]: _mar }], [1, { [_hQ10]: _max }], [0, { [_hQ10]: _de }], [0, { [_hQ10]: _ho }]]
    ];
    exports2.ListHostedZonesResponse$ = [
      3,
      n032,
      _LHZRi,
      0,
      [_HZo, _Ma, _IT4, _MI, _NM],
      [[() => HostedZones, 0], 0, 2, 1, 0],
      4
    ];
    exports2.ListQueryLoggingConfigsRequest$ = [
      3,
      n032,
      _LQLCR,
      0,
      [_HZI, _NT, _MR],
      [[0, { [_hQ10]: _h22 }], [0, { [_hQ10]: _n }], [1, { [_hQ10]: _ma }]]
    ];
    exports2.ListQueryLoggingConfigsResponse$ = [
      3,
      n032,
      _LQLCRi,
      0,
      [_QLCu, _NT],
      [[() => QueryLoggingConfigs, 0], 0],
      1
    ];
    exports2.ListResourceRecordSetsRequest$ = [
      3,
      n032,
      _LRRSR,
      0,
      [_HZI, _SRN, _SRT, _SRI, _MI],
      [[0, 1], [0, { [_hQ10]: _na }], [0, { [_hQ10]: _t }], [0, { [_hQ10]: _i }], [1, { [_hQ10]: _max }]],
      1
    ];
    exports2.ListResourceRecordSetsResponse$ = [
      3,
      n032,
      _LRRSRi,
      0,
      [_RRSe, _IT4, _MI, _NRN, _NRT, _NRI],
      [[() => ResourceRecordSets, 0], 2, 1, 0, 0, 0],
      3
    ];
    exports2.ListReusableDelegationSetsRequest$ = [
      3,
      n032,
      _LRDSR,
      0,
      [_Ma, _MI],
      [[0, { [_hQ10]: _mar }], [1, { [_hQ10]: _max }]]
    ];
    exports2.ListReusableDelegationSetsResponse$ = [
      3,
      n032,
      _LRDSRi,
      0,
      [_DSe, _Ma, _IT4, _MI, _NM],
      [[() => DelegationSets, 0], 0, 2, 1, 0],
      4
    ];
    exports2.ListTagsForResourceRequest$ = [
      3,
      n032,
      _LTFRR,
      0,
      [_RT13, _RI],
      [[0, 1], [0, 1]],
      2
    ];
    exports2.ListTagsForResourceResponse$ = [
      3,
      n032,
      _LTFRRi,
      0,
      [_RTS],
      [[() => exports2.ResourceTagSet$, 0]],
      1
    ];
    exports2.ListTagsForResourcesRequest$ = [
      3,
      n032,
      _LTFRRis,
      0,
      [_RT13, _RIes],
      [[0, 1], [() => TagResourceIdList, 0]],
      2
    ];
    exports2.ListTagsForResourcesResponse$ = [
      3,
      n032,
      _LTFRRist,
      0,
      [_RTSe],
      [[() => ResourceTagSetList, 0]],
      1
    ];
    exports2.ListTrafficPoliciesRequest$ = [
      3,
      n032,
      _LTPR,
      0,
      [_TPIM, _MI],
      [[0, { [_hQ10]: _tr }], [1, { [_hQ10]: _max }]]
    ];
    exports2.ListTrafficPoliciesResponse$ = [
      3,
      n032,
      _LTPRi,
      0,
      [_TPS, _IT4, _TPIM, _MI],
      [[() => TrafficPolicySummaries, 0], 2, 0, 1],
      4
    ];
    exports2.ListTrafficPolicyInstancesByHostedZoneRequest$ = [
      3,
      n032,
      _LTPIBHZR,
      0,
      [_HZI, _TPINM, _TPITM, _MI],
      [[0, { [_hQ10]: _id }], [0, { [_hQ10]: _tra }], [0, { [_hQ10]: _traf }], [1, { [_hQ10]: _max }]],
      1
    ];
    exports2.ListTrafficPolicyInstancesByHostedZoneResponse$ = [
      3,
      n032,
      _LTPIBHZRi,
      0,
      [_TPIra, _IT4, _MI, _TPINM, _TPITM],
      [[() => TrafficPolicyInstances, 0], 2, 1, 0, 0],
      3
    ];
    exports2.ListTrafficPolicyInstancesByPolicyRequest$ = [
      3,
      n032,
      _LTPIBPR,
      0,
      [_TPI, _TPV, _HZIM, _TPINM, _TPITM, _MI],
      [[0, { [_hQ10]: _id }], [1, { [_hQ10]: _ve }], [0, { [_hQ10]: _h22 }], [0, { [_hQ10]: _tra }], [0, { [_hQ10]: _traf }], [1, { [_hQ10]: _max }]],
      2
    ];
    exports2.ListTrafficPolicyInstancesByPolicyResponse$ = [
      3,
      n032,
      _LTPIBPRi,
      0,
      [_TPIra, _IT4, _MI, _HZIM, _TPINM, _TPITM],
      [[() => TrafficPolicyInstances, 0], 2, 1, 0, 0, 0],
      3
    ];
    exports2.ListTrafficPolicyInstancesRequest$ = [
      3,
      n032,
      _LTPIR,
      0,
      [_HZIM, _TPINM, _TPITM, _MI],
      [[0, { [_hQ10]: _h22 }], [0, { [_hQ10]: _tra }], [0, { [_hQ10]: _traf }], [1, { [_hQ10]: _max }]]
    ];
    exports2.ListTrafficPolicyInstancesResponse$ = [
      3,
      n032,
      _LTPIRi,
      0,
      [_TPIra, _IT4, _MI, _HZIM, _TPINM, _TPITM],
      [[() => TrafficPolicyInstances, 0], 2, 1, 0, 0, 0],
      3
    ];
    exports2.ListTrafficPolicyVersionsRequest$ = [
      3,
      n032,
      _LTPVR,
      0,
      [_I, _TPVM, _MI],
      [[0, 1], [0, { [_hQ10]: _traff }], [1, { [_hQ10]: _max }]],
      1
    ];
    exports2.ListTrafficPolicyVersionsResponse$ = [
      3,
      n032,
      _LTPVRi,
      0,
      [_TPr, _IT4, _TPVM, _MI],
      [[() => TrafficPolicies, 0], 2, 0, 1],
      4
    ];
    exports2.ListVPCAssociationAuthorizationsRequest$ = [
      3,
      n032,
      _LVPCAAR,
      0,
      [_HZI, _NT, _MR],
      [[0, 1], [0, { [_hQ10]: _n }], [1, { [_hQ10]: _ma }]],
      1
    ];
    exports2.ListVPCAssociationAuthorizationsResponse$ = [
      3,
      n032,
      _LVPCAARi,
      0,
      [_HZI, _VPCs, _NT],
      [0, [() => VPCs, 0], 0],
      2
    ];
    exports2.LocationSummary$ = [
      3,
      n032,
      _LSo,
      0,
      [_LN],
      [0]
    ];
    exports2.QueryLoggingConfig$ = [
      3,
      n032,
      _QLC,
      0,
      [_I, _HZI, _CWLLGA],
      [0, 0, 0],
      3
    ];
    exports2.ResourceRecord$ = [
      3,
      n032,
      _RR,
      0,
      [_V10],
      [0],
      1
    ];
    exports2.ResourceRecordSet$ = [
      3,
      n032,
      _RRS,
      0,
      [_N, _T10, _SI10, _W, _R, _GL, _Fa, _MVA, _TTL, _RRe, _AT13, _HCI, _TPII, _CRC, _GPL],
      [0, 0, 0, 1, 0, () => exports2.GeoLocation$, 0, 2, 1, [() => ResourceRecords, 0], () => exports2.AliasTarget$, 0, 0, () => exports2.CidrRoutingConfig$, () => exports2.GeoProximityLocation$],
      2
    ];
    exports2.ResourceTagSet$ = [
      3,
      n032,
      _RTS,
      0,
      [_RT13, _RI, _Ta10],
      [0, 0, [() => TagList, 0]]
    ];
    exports2.ReusableDelegationSetLimit$ = [
      3,
      n032,
      _RDSL,
      0,
      [_T10, _V10],
      [0, 1],
      2
    ];
    exports2.StatusReport$ = [
      3,
      n032,
      _SR,
      0,
      [_S, _CTh],
      [0, 4]
    ];
    exports2.Tag$ = [
      3,
      n032,
      _Tag,
      0,
      [_K10, _V10],
      [0, 0]
    ];
    exports2.TestDNSAnswerRequest$ = [
      3,
      n032,
      _TDNSAR,
      0,
      [_HZI, _RN, _RTe, _RIP, _EDNSCSIP, _EDNSCSM],
      [[0, { [_hQ10]: _h22 }], [0, { [_hQ10]: _r4 }], [0, { [_hQ10]: _re }], [0, { [_hQ10]: _res }], [0, { [_hQ10]: _ed4 }], [0, { [_hQ10]: _edn }]],
      3
    ];
    exports2.TestDNSAnswerResponse$ = [
      3,
      n032,
      _TDNSARe,
      0,
      [_Nam, _RN, _RTe, _RD, _RC10, _Pr10],
      [0, 0, 0, [() => RecordData, 0], 0, 0],
      6
    ];
    exports2.TrafficPolicy$ = [
      3,
      n032,
      _TP,
      0,
      [_I, _Ve, _N, _T10, _Do, _C11],
      [0, 1, 0, 0, 0, 0],
      5
    ];
    exports2.TrafficPolicyInstance$ = [
      3,
      n032,
      _TPIr,
      0,
      [_I, _HZI, _N, _TTL, _Sta, _M, _TPI, _TPV, _TPT],
      [0, 0, 0, 1, 0, 0, 0, 1, 0],
      9
    ];
    exports2.TrafficPolicySummary$ = [
      3,
      n032,
      _TPSr,
      0,
      [_I, _N, _T10, _LV, _TPC],
      [0, 0, 0, 1, 1],
      5
    ];
    exports2.UpdateHealthCheckRequest$ = [
      3,
      n032,
      _UHCR,
      0,
      [_HCI, _HCV, _IPA, _Po, _RP, _FQDN, _SSe, _FT, _In, _Dis, _HT, _CHC, _ESNI, _Re, _AI2, _IDHS, _RE],
      [[0, 1], 1, 0, 1, 0, 0, 0, 1, 2, 2, 1, [() => ChildHealthCheckList, 0], 2, [() => HealthCheckRegionList, 0], () => exports2.AlarmIdentifier$, 0, [() => ResettableElementNameList, 0]],
      1
    ];
    exports2.UpdateHealthCheckResponse$ = [
      3,
      n032,
      _UHCRp,
      0,
      [_HC],
      [[() => exports2.HealthCheck$, 0]],
      1
    ];
    exports2.UpdateHostedZoneCommentRequest$ = [
      3,
      n032,
      _UHZCR,
      0,
      [_I, _C11],
      [[0, 1], 0],
      1
    ];
    exports2.UpdateHostedZoneCommentResponse$ = [
      3,
      n032,
      _UHZCRp,
      0,
      [_HZ],
      [() => exports2.HostedZone$],
      1
    ];
    exports2.UpdateHostedZoneFeaturesRequest$ = [
      3,
      n032,
      _UHZFR,
      0,
      [_HZI, _EAR],
      [[0, 1], 2],
      1
    ];
    exports2.UpdateHostedZoneFeaturesResponse$ = [
      3,
      n032,
      _UHZFRp,
      0,
      [],
      []
    ];
    exports2.UpdateTrafficPolicyCommentRequest$ = [
      3,
      n032,
      _UTPCR,
      0,
      [_I, _Ve, _C11],
      [[0, 1], [1, 1], 0],
      3
    ];
    exports2.UpdateTrafficPolicyCommentResponse$ = [
      3,
      n032,
      _UTPCRp,
      0,
      [_TP],
      [() => exports2.TrafficPolicy$],
      1
    ];
    exports2.UpdateTrafficPolicyInstanceRequest$ = [
      3,
      n032,
      _UTPIR,
      0,
      [_I, _TTL, _TPI, _TPV],
      [[0, 1], 1, 0, 1],
      4
    ];
    exports2.UpdateTrafficPolicyInstanceResponse$ = [
      3,
      n032,
      _UTPIRp,
      0,
      [_TPIr],
      [() => exports2.TrafficPolicyInstance$],
      1
    ];
    exports2.VPC$ = [
      3,
      n032,
      _VPC,
      0,
      [_VPCR, _VPCI],
      [0, 0]
    ];
    var Changes = [
      1,
      n032,
      _Cha,
      0,
      [
        () => exports2.Change$,
        { [_xN]: _Ch }
      ]
    ];
    var CheckerIpRanges = 64 | 0;
    var ChildHealthCheckList = [
      1,
      n032,
      _CHCL,
      0,
      [
        0,
        { [_xN]: _CHCh }
      ]
    ];
    var CidrBlockSummaries = [
      1,
      n032,
      _CBSi,
      0,
      () => exports2.CidrBlockSummary$
    ];
    var CidrCollectionChanges = [
      1,
      n032,
      _CCCi,
      0,
      [
        () => exports2.CidrCollectionChange$,
        0
      ]
    ];
    var CidrList = [
      1,
      n032,
      _CL,
      0,
      [
        0,
        { [_xN]: _Ci }
      ]
    ];
    var CollectionSummaries = [
      1,
      n032,
      _CSo,
      0,
      () => exports2.CollectionSummary$
    ];
    var DelegationSetNameServers = [
      1,
      n032,
      _DSNS,
      0,
      [
        0,
        { [_xN]: _NSa }
      ]
    ];
    var DelegationSets = [
      1,
      n032,
      _DSe,
      0,
      [
        () => exports2.DelegationSet$,
        { [_xN]: _DS10 }
      ]
    ];
    var DimensionList = [
      1,
      n032,
      _DL,
      0,
      [
        () => exports2.Dimension$,
        { [_xN]: _Di }
      ]
    ];
    var ErrorMessages = [
      1,
      n032,
      _EM,
      0,
      [
        0,
        { [_xN]: _M }
      ]
    ];
    var GeoLocationDetailsList = [
      1,
      n032,
      _GLDL,
      0,
      [
        () => exports2.GeoLocationDetails$,
        { [_xN]: _GLD }
      ]
    ];
    var HealthCheckObservations = [
      1,
      n032,
      _HCO,
      0,
      [
        () => exports2.HealthCheckObservation$,
        { [_xN]: _HCOe }
      ]
    ];
    var HealthCheckRegionList = [
      1,
      n032,
      _HCRL,
      0,
      [
        0,
        { [_xN]: _R }
      ]
    ];
    var HealthChecks = [
      1,
      n032,
      _HCe,
      0,
      [
        () => exports2.HealthCheck$,
        { [_xN]: _HC }
      ]
    ];
    var HostedZones = [
      1,
      n032,
      _HZo,
      0,
      [
        () => exports2.HostedZone$,
        { [_xN]: _HZ }
      ]
    ];
    var HostedZoneSummaries = [
      1,
      n032,
      _HZSo,
      0,
      [
        () => exports2.HostedZoneSummary$,
        { [_xN]: _HZS }
      ]
    ];
    var KeySigningKeys = [
      1,
      n032,
      _KSKe,
      0,
      () => exports2.KeySigningKey$
    ];
    var LocationSummaries = [
      1,
      n032,
      _LSoc,
      0,
      () => exports2.LocationSummary$
    ];
    var QueryLoggingConfigs = [
      1,
      n032,
      _QLCu,
      0,
      [
        () => exports2.QueryLoggingConfig$,
        { [_xN]: _QLC }
      ]
    ];
    var RecordData = [
      1,
      n032,
      _RD,
      0,
      [
        0,
        { [_xN]: _RDE10 }
      ]
    ];
    var ResettableElementNameList = [
      1,
      n032,
      _RENL,
      0,
      [
        0,
        { [_xN]: _REN }
      ]
    ];
    var ResourceRecords = [
      1,
      n032,
      _RRe,
      0,
      [
        () => exports2.ResourceRecord$,
        { [_xN]: _RR }
      ]
    ];
    var ResourceRecordSets = [
      1,
      n032,
      _RRSe,
      0,
      [
        () => exports2.ResourceRecordSet$,
        { [_xN]: _RRS }
      ]
    ];
    var ResourceTagSetList = [
      1,
      n032,
      _RTSL,
      0,
      [
        () => exports2.ResourceTagSet$,
        { [_xN]: _RTS }
      ]
    ];
    var TagKeyList = [
      1,
      n032,
      _TKL,
      0,
      [
        0,
        { [_xN]: _K10 }
      ]
    ];
    var TagList = [
      1,
      n032,
      _TL,
      0,
      [
        () => exports2.Tag$,
        { [_xN]: _Tag }
      ]
    ];
    var TagResourceIdList = [
      1,
      n032,
      _TRIL,
      0,
      [
        0,
        { [_xN]: _RI }
      ]
    ];
    var TrafficPolicies = [
      1,
      n032,
      _TPr,
      0,
      [
        () => exports2.TrafficPolicy$,
        { [_xN]: _TP }
      ]
    ];
    var TrafficPolicyInstances = [
      1,
      n032,
      _TPIra,
      0,
      [
        () => exports2.TrafficPolicyInstance$,
        { [_xN]: _TPIr }
      ]
    ];
    var TrafficPolicySummaries = [
      1,
      n032,
      _TPS,
      0,
      [
        () => exports2.TrafficPolicySummary$,
        { [_xN]: _TPSr }
      ]
    ];
    var VPCs = [
      1,
      n032,
      _VPCs,
      0,
      [
        () => exports2.VPC$,
        { [_xN]: _VPC }
      ]
    ];
    exports2.ActivateKeySigningKey$ = [
      9,
      n032,
      _AKSK,
      { [_ht]: ["POST", "/2013-04-01/keysigningkey/{HostedZoneId}/{Name}/activate", 200] },
      () => exports2.ActivateKeySigningKeyRequest$,
      () => exports2.ActivateKeySigningKeyResponse$
    ];
    exports2.AssociateVPCWithHostedZone$ = [
      9,
      n032,
      _AVPCWHZ,
      { [_ht]: ["POST", "/2013-04-01/hostedzone/{HostedZoneId}/associatevpc", 200] },
      () => exports2.AssociateVPCWithHostedZoneRequest$,
      () => exports2.AssociateVPCWithHostedZoneResponse$
    ];
    exports2.ChangeCidrCollection$ = [
      9,
      n032,
      _CCCh,
      { [_ht]: ["POST", "/2013-04-01/cidrcollection/{Id}", 200] },
      () => exports2.ChangeCidrCollectionRequest$,
      () => exports2.ChangeCidrCollectionResponse$
    ];
    exports2.ChangeResourceRecordSets$ = [
      9,
      n032,
      _CRRS,
      { [_ht]: ["POST", "/2013-04-01/hostedzone/{HostedZoneId}/rrset", 200] },
      () => exports2.ChangeResourceRecordSetsRequest$,
      () => exports2.ChangeResourceRecordSetsResponse$
    ];
    exports2.ChangeTagsForResource$ = [
      9,
      n032,
      _CTFR,
      { [_ht]: ["POST", "/2013-04-01/tags/{ResourceType}/{ResourceId}", 200] },
      () => exports2.ChangeTagsForResourceRequest$,
      () => exports2.ChangeTagsForResourceResponse$
    ];
    exports2.CreateCidrCollection$ = [
      9,
      n032,
      _CCCr,
      { [_ht]: ["POST", "/2013-04-01/cidrcollection", 201] },
      () => exports2.CreateCidrCollectionRequest$,
      () => exports2.CreateCidrCollectionResponse$
    ];
    exports2.CreateHealthCheck$ = [
      9,
      n032,
      _CHCr,
      { [_ht]: ["POST", "/2013-04-01/healthcheck", 201] },
      () => exports2.CreateHealthCheckRequest$,
      () => exports2.CreateHealthCheckResponse$
    ];
    exports2.CreateHostedZone$ = [
      9,
      n032,
      _CHZ,
      { [_ht]: ["POST", "/2013-04-01/hostedzone", 201] },
      () => exports2.CreateHostedZoneRequest$,
      () => exports2.CreateHostedZoneResponse$
    ];
    exports2.CreateKeySigningKey$ = [
      9,
      n032,
      _CKSK,
      { [_ht]: ["POST", "/2013-04-01/keysigningkey", 201] },
      () => exports2.CreateKeySigningKeyRequest$,
      () => exports2.CreateKeySigningKeyResponse$
    ];
    exports2.CreateQueryLoggingConfig$ = [
      9,
      n032,
      _CQLC,
      { [_ht]: ["POST", "/2013-04-01/queryloggingconfig", 201] },
      () => exports2.CreateQueryLoggingConfigRequest$,
      () => exports2.CreateQueryLoggingConfigResponse$
    ];
    exports2.CreateReusableDelegationSet$ = [
      9,
      n032,
      _CRDS,
      { [_ht]: ["POST", "/2013-04-01/delegationset", 201] },
      () => exports2.CreateReusableDelegationSetRequest$,
      () => exports2.CreateReusableDelegationSetResponse$
    ];
    exports2.CreateTrafficPolicy$ = [
      9,
      n032,
      _CTP,
      { [_ht]: ["POST", "/2013-04-01/trafficpolicy", 201] },
      () => exports2.CreateTrafficPolicyRequest$,
      () => exports2.CreateTrafficPolicyResponse$
    ];
    exports2.CreateTrafficPolicyInstance$ = [
      9,
      n032,
      _CTPI,
      { [_ht]: ["POST", "/2013-04-01/trafficpolicyinstance", 201] },
      () => exports2.CreateTrafficPolicyInstanceRequest$,
      () => exports2.CreateTrafficPolicyInstanceResponse$
    ];
    exports2.CreateTrafficPolicyVersion$ = [
      9,
      n032,
      _CTPV,
      { [_ht]: ["POST", "/2013-04-01/trafficpolicy/{Id}", 201] },
      () => exports2.CreateTrafficPolicyVersionRequest$,
      () => exports2.CreateTrafficPolicyVersionResponse$
    ];
    exports2.CreateVPCAssociationAuthorization$ = [
      9,
      n032,
      _CVPCAA,
      { [_ht]: ["POST", "/2013-04-01/hostedzone/{HostedZoneId}/authorizevpcassociation", 200] },
      () => exports2.CreateVPCAssociationAuthorizationRequest$,
      () => exports2.CreateVPCAssociationAuthorizationResponse$
    ];
    exports2.DeactivateKeySigningKey$ = [
      9,
      n032,
      _DKSK,
      { [_ht]: ["POST", "/2013-04-01/keysigningkey/{HostedZoneId}/{Name}/deactivate", 200] },
      () => exports2.DeactivateKeySigningKeyRequest$,
      () => exports2.DeactivateKeySigningKeyResponse$
    ];
    exports2.DeleteCidrCollection$ = [
      9,
      n032,
      _DCC,
      { [_ht]: ["DELETE", "/2013-04-01/cidrcollection/{Id}", 200] },
      () => exports2.DeleteCidrCollectionRequest$,
      () => exports2.DeleteCidrCollectionResponse$
    ];
    exports2.DeleteHealthCheck$ = [
      9,
      n032,
      _DHC,
      { [_ht]: ["DELETE", "/2013-04-01/healthcheck/{HealthCheckId}", 200] },
      () => exports2.DeleteHealthCheckRequest$,
      () => exports2.DeleteHealthCheckResponse$
    ];
    exports2.DeleteHostedZone$ = [
      9,
      n032,
      _DHZ,
      { [_ht]: ["DELETE", "/2013-04-01/hostedzone/{Id}", 200] },
      () => exports2.DeleteHostedZoneRequest$,
      () => exports2.DeleteHostedZoneResponse$
    ];
    exports2.DeleteKeySigningKey$ = [
      9,
      n032,
      _DKSKe,
      { [_ht]: ["DELETE", "/2013-04-01/keysigningkey/{HostedZoneId}/{Name}", 200] },
      () => exports2.DeleteKeySigningKeyRequest$,
      () => exports2.DeleteKeySigningKeyResponse$
    ];
    exports2.DeleteQueryLoggingConfig$ = [
      9,
      n032,
      _DQLC,
      { [_ht]: ["DELETE", "/2013-04-01/queryloggingconfig/{Id}", 200] },
      () => exports2.DeleteQueryLoggingConfigRequest$,
      () => exports2.DeleteQueryLoggingConfigResponse$
    ];
    exports2.DeleteReusableDelegationSet$ = [
      9,
      n032,
      _DRDS,
      { [_ht]: ["DELETE", "/2013-04-01/delegationset/{Id}", 200] },
      () => exports2.DeleteReusableDelegationSetRequest$,
      () => exports2.DeleteReusableDelegationSetResponse$
    ];
    exports2.DeleteTrafficPolicy$ = [
      9,
      n032,
      _DTP,
      { [_ht]: ["DELETE", "/2013-04-01/trafficpolicy/{Id}/{Version}", 200] },
      () => exports2.DeleteTrafficPolicyRequest$,
      () => exports2.DeleteTrafficPolicyResponse$
    ];
    exports2.DeleteTrafficPolicyInstance$ = [
      9,
      n032,
      _DTPI,
      { [_ht]: ["DELETE", "/2013-04-01/trafficpolicyinstance/{Id}", 200] },
      () => exports2.DeleteTrafficPolicyInstanceRequest$,
      () => exports2.DeleteTrafficPolicyInstanceResponse$
    ];
    exports2.DeleteVPCAssociationAuthorization$ = [
      9,
      n032,
      _DVPCAA,
      { [_ht]: ["POST", "/2013-04-01/hostedzone/{HostedZoneId}/deauthorizevpcassociation", 200] },
      () => exports2.DeleteVPCAssociationAuthorizationRequest$,
      () => exports2.DeleteVPCAssociationAuthorizationResponse$
    ];
    exports2.DisableHostedZoneDNSSEC$ = [
      9,
      n032,
      _DHZDNSSEC,
      { [_ht]: ["POST", "/2013-04-01/hostedzone/{HostedZoneId}/disable-dnssec", 200] },
      () => exports2.DisableHostedZoneDNSSECRequest$,
      () => exports2.DisableHostedZoneDNSSECResponse$
    ];
    exports2.DisassociateVPCFromHostedZone$ = [
      9,
      n032,
      _DVPCFHZ,
      { [_ht]: ["POST", "/2013-04-01/hostedzone/{HostedZoneId}/disassociatevpc", 200] },
      () => exports2.DisassociateVPCFromHostedZoneRequest$,
      () => exports2.DisassociateVPCFromHostedZoneResponse$
    ];
    exports2.EnableHostedZoneDNSSEC$ = [
      9,
      n032,
      _EHZDNSSEC,
      { [_ht]: ["POST", "/2013-04-01/hostedzone/{HostedZoneId}/enable-dnssec", 200] },
      () => exports2.EnableHostedZoneDNSSECRequest$,
      () => exports2.EnableHostedZoneDNSSECResponse$
    ];
    exports2.GetAccountLimit$ = [
      9,
      n032,
      _GAL,
      { [_ht]: ["GET", "/2013-04-01/accountlimit/{Type}", 200] },
      () => exports2.GetAccountLimitRequest$,
      () => exports2.GetAccountLimitResponse$
    ];
    exports2.GetChange$ = [
      9,
      n032,
      _GC,
      { [_ht]: ["GET", "/2013-04-01/change/{Id}", 200] },
      () => exports2.GetChangeRequest$,
      () => exports2.GetChangeResponse$
    ];
    exports2.GetCheckerIpRanges$ = [
      9,
      n032,
      _GCIR,
      { [_ht]: ["GET", "/2013-04-01/checkeripranges", 200] },
      () => exports2.GetCheckerIpRangesRequest$,
      () => exports2.GetCheckerIpRangesResponse$
    ];
    exports2.GetDNSSEC$ = [
      9,
      n032,
      _GDNSSEC,
      { [_ht]: ["GET", "/2013-04-01/hostedzone/{HostedZoneId}/dnssec", 200] },
      () => exports2.GetDNSSECRequest$,
      () => exports2.GetDNSSECResponse$
    ];
    exports2.GetGeoLocation$ = [
      9,
      n032,
      _GGL,
      { [_ht]: ["GET", "/2013-04-01/geolocation", 200] },
      () => exports2.GetGeoLocationRequest$,
      () => exports2.GetGeoLocationResponse$
    ];
    exports2.GetHealthCheck$ = [
      9,
      n032,
      _GHC,
      { [_ht]: ["GET", "/2013-04-01/healthcheck/{HealthCheckId}", 200] },
      () => exports2.GetHealthCheckRequest$,
      () => exports2.GetHealthCheckResponse$
    ];
    exports2.GetHealthCheckCount$ = [
      9,
      n032,
      _GHCC,
      { [_ht]: ["GET", "/2013-04-01/healthcheckcount", 200] },
      () => exports2.GetHealthCheckCountRequest$,
      () => exports2.GetHealthCheckCountResponse$
    ];
    exports2.GetHealthCheckLastFailureReason$ = [
      9,
      n032,
      _GHCLFR,
      { [_ht]: ["GET", "/2013-04-01/healthcheck/{HealthCheckId}/lastfailurereason", 200] },
      () => exports2.GetHealthCheckLastFailureReasonRequest$,
      () => exports2.GetHealthCheckLastFailureReasonResponse$
    ];
    exports2.GetHealthCheckStatus$ = [
      9,
      n032,
      _GHCS,
      { [_ht]: ["GET", "/2013-04-01/healthcheck/{HealthCheckId}/status", 200] },
      () => exports2.GetHealthCheckStatusRequest$,
      () => exports2.GetHealthCheckStatusResponse$
    ];
    exports2.GetHostedZone$ = [
      9,
      n032,
      _GHZ,
      { [_ht]: ["GET", "/2013-04-01/hostedzone/{Id}", 200] },
      () => exports2.GetHostedZoneRequest$,
      () => exports2.GetHostedZoneResponse$
    ];
    exports2.GetHostedZoneCount$ = [
      9,
      n032,
      _GHZC,
      { [_ht]: ["GET", "/2013-04-01/hostedzonecount", 200] },
      () => exports2.GetHostedZoneCountRequest$,
      () => exports2.GetHostedZoneCountResponse$
    ];
    exports2.GetHostedZoneLimit$ = [
      9,
      n032,
      _GHZL,
      { [_ht]: ["GET", "/2013-04-01/hostedzonelimit/{HostedZoneId}/{Type}", 200] },
      () => exports2.GetHostedZoneLimitRequest$,
      () => exports2.GetHostedZoneLimitResponse$
    ];
    exports2.GetQueryLoggingConfig$ = [
      9,
      n032,
      _GQLC,
      { [_ht]: ["GET", "/2013-04-01/queryloggingconfig/{Id}", 200] },
      () => exports2.GetQueryLoggingConfigRequest$,
      () => exports2.GetQueryLoggingConfigResponse$
    ];
    exports2.GetReusableDelegationSet$ = [
      9,
      n032,
      _GRDS,
      { [_ht]: ["GET", "/2013-04-01/delegationset/{Id}", 200] },
      () => exports2.GetReusableDelegationSetRequest$,
      () => exports2.GetReusableDelegationSetResponse$
    ];
    exports2.GetReusableDelegationSetLimit$ = [
      9,
      n032,
      _GRDSL,
      { [_ht]: ["GET", "/2013-04-01/reusabledelegationsetlimit/{DelegationSetId}/{Type}", 200] },
      () => exports2.GetReusableDelegationSetLimitRequest$,
      () => exports2.GetReusableDelegationSetLimitResponse$
    ];
    exports2.GetTrafficPolicy$ = [
      9,
      n032,
      _GTP,
      { [_ht]: ["GET", "/2013-04-01/trafficpolicy/{Id}/{Version}", 200] },
      () => exports2.GetTrafficPolicyRequest$,
      () => exports2.GetTrafficPolicyResponse$
    ];
    exports2.GetTrafficPolicyInstance$ = [
      9,
      n032,
      _GTPI,
      { [_ht]: ["GET", "/2013-04-01/trafficpolicyinstance/{Id}", 200] },
      () => exports2.GetTrafficPolicyInstanceRequest$,
      () => exports2.GetTrafficPolicyInstanceResponse$
    ];
    exports2.GetTrafficPolicyInstanceCount$ = [
      9,
      n032,
      _GTPIC,
      { [_ht]: ["GET", "/2013-04-01/trafficpolicyinstancecount", 200] },
      () => exports2.GetTrafficPolicyInstanceCountRequest$,
      () => exports2.GetTrafficPolicyInstanceCountResponse$
    ];
    exports2.ListCidrBlocks$ = [
      9,
      n032,
      _LCB,
      { [_ht]: ["GET", "/2013-04-01/cidrcollection/{CollectionId}/cidrblocks", 200] },
      () => exports2.ListCidrBlocksRequest$,
      () => exports2.ListCidrBlocksResponse$
    ];
    exports2.ListCidrCollections$ = [
      9,
      n032,
      _LCC,
      { [_ht]: ["GET", "/2013-04-01/cidrcollection", 200] },
      () => exports2.ListCidrCollectionsRequest$,
      () => exports2.ListCidrCollectionsResponse$
    ];
    exports2.ListCidrLocations$ = [
      9,
      n032,
      _LCL,
      { [_ht]: ["GET", "/2013-04-01/cidrcollection/{CollectionId}", 200] },
      () => exports2.ListCidrLocationsRequest$,
      () => exports2.ListCidrLocationsResponse$
    ];
    exports2.ListGeoLocations$ = [
      9,
      n032,
      _LGL,
      { [_ht]: ["GET", "/2013-04-01/geolocations", 200] },
      () => exports2.ListGeoLocationsRequest$,
      () => exports2.ListGeoLocationsResponse$
    ];
    exports2.ListHealthChecks$ = [
      9,
      n032,
      _LHC,
      { [_ht]: ["GET", "/2013-04-01/healthcheck", 200] },
      () => exports2.ListHealthChecksRequest$,
      () => exports2.ListHealthChecksResponse$
    ];
    exports2.ListHostedZones$ = [
      9,
      n032,
      _LHZ,
      { [_ht]: ["GET", "/2013-04-01/hostedzone", 200] },
      () => exports2.ListHostedZonesRequest$,
      () => exports2.ListHostedZonesResponse$
    ];
    exports2.ListHostedZonesByName$ = [
      9,
      n032,
      _LHZBN,
      { [_ht]: ["GET", "/2013-04-01/hostedzonesbyname", 200] },
      () => exports2.ListHostedZonesByNameRequest$,
      () => exports2.ListHostedZonesByNameResponse$
    ];
    exports2.ListHostedZonesByVPC$ = [
      9,
      n032,
      _LHZBVPC,
      { [_ht]: ["GET", "/2013-04-01/hostedzonesbyvpc", 200] },
      () => exports2.ListHostedZonesByVPCRequest$,
      () => exports2.ListHostedZonesByVPCResponse$
    ];
    exports2.ListQueryLoggingConfigs$ = [
      9,
      n032,
      _LQLC,
      { [_ht]: ["GET", "/2013-04-01/queryloggingconfig", 200] },
      () => exports2.ListQueryLoggingConfigsRequest$,
      () => exports2.ListQueryLoggingConfigsResponse$
    ];
    exports2.ListResourceRecordSets$ = [
      9,
      n032,
      _LRRS,
      { [_ht]: ["GET", "/2013-04-01/hostedzone/{HostedZoneId}/rrset", 200] },
      () => exports2.ListResourceRecordSetsRequest$,
      () => exports2.ListResourceRecordSetsResponse$
    ];
    exports2.ListReusableDelegationSets$ = [
      9,
      n032,
      _LRDS,
      { [_ht]: ["GET", "/2013-04-01/delegationset", 200] },
      () => exports2.ListReusableDelegationSetsRequest$,
      () => exports2.ListReusableDelegationSetsResponse$
    ];
    exports2.ListTagsForResource$ = [
      9,
      n032,
      _LTFR,
      { [_ht]: ["GET", "/2013-04-01/tags/{ResourceType}/{ResourceId}", 200] },
      () => exports2.ListTagsForResourceRequest$,
      () => exports2.ListTagsForResourceResponse$
    ];
    exports2.ListTagsForResources$ = [
      9,
      n032,
      _LTFRi,
      { [_ht]: ["POST", "/2013-04-01/tags/{ResourceType}", 200] },
      () => exports2.ListTagsForResourcesRequest$,
      () => exports2.ListTagsForResourcesResponse$
    ];
    exports2.ListTrafficPolicies$ = [
      9,
      n032,
      _LTP,
      { [_ht]: ["GET", "/2013-04-01/trafficpolicies", 200] },
      () => exports2.ListTrafficPoliciesRequest$,
      () => exports2.ListTrafficPoliciesResponse$
    ];
    exports2.ListTrafficPolicyInstances$ = [
      9,
      n032,
      _LTPI,
      { [_ht]: ["GET", "/2013-04-01/trafficpolicyinstances", 200] },
      () => exports2.ListTrafficPolicyInstancesRequest$,
      () => exports2.ListTrafficPolicyInstancesResponse$
    ];
    exports2.ListTrafficPolicyInstancesByHostedZone$ = [
      9,
      n032,
      _LTPIBHZ,
      { [_ht]: ["GET", "/2013-04-01/trafficpolicyinstances/hostedzone", 200] },
      () => exports2.ListTrafficPolicyInstancesByHostedZoneRequest$,
      () => exports2.ListTrafficPolicyInstancesByHostedZoneResponse$
    ];
    exports2.ListTrafficPolicyInstancesByPolicy$ = [
      9,
      n032,
      _LTPIBP,
      { [_ht]: ["GET", "/2013-04-01/trafficpolicyinstances/trafficpolicy", 200] },
      () => exports2.ListTrafficPolicyInstancesByPolicyRequest$,
      () => exports2.ListTrafficPolicyInstancesByPolicyResponse$
    ];
    exports2.ListTrafficPolicyVersions$ = [
      9,
      n032,
      _LTPV,
      { [_ht]: ["GET", "/2013-04-01/trafficpolicies/{Id}/versions", 200] },
      () => exports2.ListTrafficPolicyVersionsRequest$,
      () => exports2.ListTrafficPolicyVersionsResponse$
    ];
    exports2.ListVPCAssociationAuthorizations$ = [
      9,
      n032,
      _LVPCAA,
      { [_ht]: ["GET", "/2013-04-01/hostedzone/{HostedZoneId}/authorizevpcassociation", 200] },
      () => exports2.ListVPCAssociationAuthorizationsRequest$,
      () => exports2.ListVPCAssociationAuthorizationsResponse$
    ];
    exports2.TestDNSAnswer$ = [
      9,
      n032,
      _TDNSA,
      { [_ht]: ["GET", "/2013-04-01/testdnsanswer", 200] },
      () => exports2.TestDNSAnswerRequest$,
      () => exports2.TestDNSAnswerResponse$
    ];
    exports2.UpdateHealthCheck$ = [
      9,
      n032,
      _UHC,
      { [_ht]: ["POST", "/2013-04-01/healthcheck/{HealthCheckId}", 200] },
      () => exports2.UpdateHealthCheckRequest$,
      () => exports2.UpdateHealthCheckResponse$
    ];
    exports2.UpdateHostedZoneComment$ = [
      9,
      n032,
      _UHZC,
      { [_ht]: ["POST", "/2013-04-01/hostedzone/{Id}", 200] },
      () => exports2.UpdateHostedZoneCommentRequest$,
      () => exports2.UpdateHostedZoneCommentResponse$
    ];
    exports2.UpdateHostedZoneFeatures$ = [
      9,
      n032,
      _UHZF,
      { [_ht]: ["POST", "/2013-04-01/hostedzone/{HostedZoneId}/features", 200] },
      () => exports2.UpdateHostedZoneFeaturesRequest$,
      () => exports2.UpdateHostedZoneFeaturesResponse$
    ];
    exports2.UpdateTrafficPolicyComment$ = [
      9,
      n032,
      _UTPC,
      { [_ht]: ["POST", "/2013-04-01/trafficpolicy/{Id}/{Version}", 200] },
      () => exports2.UpdateTrafficPolicyCommentRequest$,
      () => exports2.UpdateTrafficPolicyCommentResponse$
    ];
    exports2.UpdateTrafficPolicyInstance$ = [
      9,
      n032,
      _UTPI,
      { [_ht]: ["POST", "/2013-04-01/trafficpolicyinstance/{Id}", 200] },
      () => exports2.UpdateTrafficPolicyInstanceRequest$,
      () => exports2.UpdateTrafficPolicyInstanceResponse$
    ];
  }
});

// ../../node_modules/@aws-sdk/client-route-53/dist-cjs/runtimeConfig.shared.js
var require_runtimeConfig_shared18 = __commonJS({
  "../../node_modules/@aws-sdk/client-route-53/dist-cjs/runtimeConfig.shared.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var protocols_1 = (init_protocols8(), __toCommonJS(protocols_exports5));
    var smithy_client_1 = require_dist_cjs34();
    var url_parser_1 = require_dist_cjs18();
    var util_base64_1 = require_dist_cjs10();
    var util_utf8_1 = require_dist_cjs9();
    var httpAuthSchemeProvider_1 = require_httpAuthSchemeProvider17();
    var endpointResolver_1 = require_endpointResolver17();
    var schemas_0_1 = require_schemas_017();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2013-04-01",
        base64Decoder: config2?.base64Decoder ?? util_base64_1.fromBase64,
        base64Encoder: config2?.base64Encoder ?? util_base64_1.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? endpointResolver_1.defaultEndpointResolver,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? httpAuthSchemeProvider_1.defaultRoute53HttpAuthSchemeProvider,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new httpAuthSchemes_1.AwsSdkSigV4Signer()
          }
        ],
        logger: config2?.logger ?? new smithy_client_1.NoOpLogger(),
        protocol: config2?.protocol ?? protocols_1.AwsRestXmlProtocol,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.route53",
          errorTypeRegistries: schemas_0_1.errorTypeRegistries,
          xmlNamespace: "https://route53.amazonaws.com/doc/2013-04-01/",
          version: "2013-04-01",
          serviceTarget: "AWSDnsV20130401"
        },
        serviceId: config2?.serviceId ?? "Route 53",
        urlParser: config2?.urlParser ?? url_parser_1.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? util_utf8_1.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? util_utf8_1.toUtf8
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-route-53/dist-cjs/runtimeConfig.js
var require_runtimeConfig18 = __commonJS({
  "../../node_modules/@aws-sdk/client-route-53/dist-cjs/runtimeConfig.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var package_json_1 = tslib_1.__importDefault(require_package17());
    var client_1 = (init_client8(), __toCommonJS(client_exports7));
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var credential_provider_node_1 = require_dist_cjs122();
    var util_user_agent_node_1 = require_dist_cjs113();
    var config_resolver_1 = require_dist_cjs25();
    var hash_node_1 = require_dist_cjs44();
    var middleware_retry_1 = require_dist_cjs106();
    var node_config_provider_1 = require_dist_cjs29();
    var node_http_handler_1 = require_dist_cjs13();
    var smithy_client_1 = require_dist_cjs34();
    var util_body_length_node_1 = require_dist_cjs45();
    var util_defaults_mode_node_1 = require_dist_cjs46();
    var util_retry_1 = require_dist_cjs22();
    var runtimeConfig_shared_1 = require_runtimeConfig_shared18();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      (0, smithy_client_1.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, util_defaults_mode_node_1.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(smithy_client_1.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = (0, runtimeConfig_shared_1.getRuntimeConfig)(config2);
      (0, client_1.emitWarningIfUnsupportedVersion)(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, node_config_provider_1.loadConfig)(httpAuthSchemes_1.NODE_AUTH_SCHEME_PREFERENCE_OPTIONS, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? util_body_length_node_1.calculateBodyLength,
        credentialDefaultProvider: config2?.credentialDefaultProvider ?? credential_provider_node_1.defaultProvider,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, util_user_agent_node_1.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_json_1.default.version }),
        maxAttempts: config2?.maxAttempts ?? (0, node_config_provider_1.loadConfig)(middleware_retry_1.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_REGION_CONFIG_OPTIONS, { ...config_resolver_1.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: node_http_handler_1.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, node_config_provider_1.loadConfig)({
          ...middleware_retry_1.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || util_retry_1.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? hash_node_1.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? node_http_handler_1.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, node_config_provider_1.loadConfig)(util_user_agent_node_1.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/middleware-sdk-route53/dist-cjs/index.js
var require_dist_cjs194 = __commonJS({
  "../../node_modules/@aws-sdk/middleware-sdk-route53/dist-cjs/index.js"(exports2) {
    "use strict";
    var IDENTIFIER_PREFIX_PATTERN = /^\/(hostedzone|change|delegationset)\//;
    function changeResourceRecordSetsMiddleware() {
      return (next) => async (args) => {
        const { ChangeBatch } = args.input;
        const Changes = [];
        for (const change of ChangeBatch?.Changes ?? []) {
          const { AliasTarget } = change.ResourceRecordSet ?? {};
          if (AliasTarget) {
            Changes.push({
              ...change,
              ResourceRecordSet: {
                ...change.ResourceRecordSet,
                AliasTarget: {
                  ...AliasTarget,
                  HostedZoneId: AliasTarget.HostedZoneId.replace(IDENTIFIER_PREFIX_PATTERN, "")
                }
              }
            });
          } else {
            Changes.push(change);
          }
        }
        return next({
          ...args,
          input: {
            ...args.input,
            ChangeBatch: {
              ...ChangeBatch,
              Changes
            }
          }
        });
      };
    }
    __name(changeResourceRecordSetsMiddleware, "changeResourceRecordSetsMiddleware");
    var changeResourceRecordSetsMiddlewareOptions = {
      step: "initialize",
      tags: ["ROUTE53_IDS", "CHANGE_RESOURCE_RECORD_SETS"],
      name: "changeResourceRecordSetsMiddleware",
      override: true
    };
    var getChangeResourceRecordSetsPlugin = /* @__PURE__ */ __name((unused) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(changeResourceRecordSetsMiddleware(), changeResourceRecordSetsMiddlewareOptions);
      }, "applyToStack")
    }), "getChangeResourceRecordSetsPlugin");
    var IDENTIFIER_PARAMETERS = ["DelegationSetId", "HostedZoneId", "Id"];
    function idNormalizerMiddleware() {
      return (next) => async (args) => {
        const input = { ...args.input };
        for (const paramName of IDENTIFIER_PARAMETERS) {
          const param = input[paramName];
          if (param) {
            input[paramName] = param.replace(IDENTIFIER_PREFIX_PATTERN, "");
          }
        }
        return next({
          ...args,
          input
        });
      };
    }
    __name(idNormalizerMiddleware, "idNormalizerMiddleware");
    var idNormalizerMiddlewareOptions = {
      step: "initialize",
      tags: ["ROUTE53_IDS"],
      name: "idNormalizerMiddleware",
      override: true
    };
    var getIdNormalizerPlugin = /* @__PURE__ */ __name((unused) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(idNormalizerMiddleware(), idNormalizerMiddlewareOptions);
      }, "applyToStack")
    }), "getIdNormalizerPlugin");
    exports2.changeResourceRecordSetsMiddleware = changeResourceRecordSetsMiddleware;
    exports2.changeResourceRecordSetsMiddlewareOptions = changeResourceRecordSetsMiddlewareOptions;
    exports2.getChangeResourceRecordSetsPlugin = getChangeResourceRecordSetsPlugin;
    exports2.getIdNormalizerPlugin = getIdNormalizerPlugin;
    exports2.idNormalizerMiddleware = idNormalizerMiddleware;
    exports2.idNormalizerMiddlewareOptions = idNormalizerMiddlewareOptions;
  }
});

// ../../node_modules/@aws-sdk/client-route-53/dist-cjs/index.js
var require_dist_cjs195 = __commonJS({
  "../../node_modules/@aws-sdk/client-route-53/dist-cjs/index.js"(exports2) {
    "use strict";
    var middlewareHostHeader = require_dist_cjs3();
    var middlewareLogger = require_dist_cjs4();
    var middlewareRecursionDetection = require_dist_cjs5();
    var middlewareUserAgent = require_dist_cjs104();
    var configResolver = require_dist_cjs25();
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var schema = (init_schema4(), __toCommonJS(schema_exports));
    var middlewareContentLength = require_dist_cjs26();
    var middlewareEndpoint = require_dist_cjs31();
    var middlewareRetry = require_dist_cjs106();
    var smithyClient = require_dist_cjs34();
    var httpAuthSchemeProvider = require_httpAuthSchemeProvider17();
    var runtimeConfig = require_runtimeConfig18();
    var regionConfigResolver = require_dist_cjs48();
    var protocolHttp = require_dist_cjs2();
    var middlewareSdkRoute53 = require_dist_cjs194();
    var schemas_0 = require_schemas_017();
    var utilWaiter = require_dist_cjs156();
    var errors = require_errors16();
    var Route53ServiceException = require_Route53ServiceException();
    var resolveClientEndpointParameters32 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "route53"
      });
    }, "resolveClientEndpointParameters");
    var commonParams32 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
    var getHttpAuthExtensionConfiguration32 = /* @__PURE__ */ __name((runtimeConfig2) => {
      const _httpAuthSchemes = runtimeConfig2.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig2.httpAuthSchemeProvider;
      let _credentials = runtimeConfig2.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider2) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider2;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    var resolveHttpAuthRuntimeConfig32 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
    var resolveRuntimeExtensions32 = /* @__PURE__ */ __name((runtimeConfig2, extensions) => {
      const extensionConfiguration = Object.assign(regionConfigResolver.getAwsRegionExtensionConfiguration(runtimeConfig2), smithyClient.getDefaultExtensionConfiguration(runtimeConfig2), protocolHttp.getHttpHandlerExtensionConfiguration(runtimeConfig2), getHttpAuthExtensionConfiguration32(runtimeConfig2));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig2, regionConfigResolver.resolveAwsRegionExtensionConfiguration(extensionConfiguration), smithyClient.resolveDefaultRuntimeConfig(extensionConfiguration), protocolHttp.resolveHttpHandlerRuntimeConfig(extensionConfiguration), resolveHttpAuthRuntimeConfig32(extensionConfiguration));
    }, "resolveRuntimeExtensions");
    var Route53Client2 = class extends smithyClient.Client {
      static {
        __name(this, "Route53Client");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = runtimeConfig.getRuntimeConfig(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters32(_config_0);
        const _config_2 = middlewareUserAgent.resolveUserAgentConfig(_config_1);
        const _config_3 = middlewareRetry.resolveRetryConfig(_config_2);
        const _config_4 = configResolver.resolveRegionConfig(_config_3);
        const _config_5 = middlewareHostHeader.resolveHostHeaderConfig(_config_4);
        const _config_6 = middlewareEndpoint.resolveEndpointConfig(_config_5);
        const _config_7 = httpAuthSchemeProvider.resolveHttpAuthSchemeConfig(_config_6);
        const _config_8 = resolveRuntimeExtensions32(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(schema.getSchemaSerdePlugin(this.config));
        this.middlewareStack.use(middlewareUserAgent.getUserAgentPlugin(this.config));
        this.middlewareStack.use(middlewareRetry.getRetryPlugin(this.config));
        this.middlewareStack.use(middlewareContentLength.getContentLengthPlugin(this.config));
        this.middlewareStack.use(middlewareHostHeader.getHostHeaderPlugin(this.config));
        this.middlewareStack.use(middlewareLogger.getLoggerPlugin(this.config));
        this.middlewareStack.use(middlewareRecursionDetection.getRecursionDetectionPlugin(this.config));
        this.middlewareStack.use(core.getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: httpAuthSchemeProvider.defaultRoute53HttpAuthSchemeParametersProvider,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new core.DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(core.getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
    var ActivateKeySigningKeyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "ActivateKeySigningKey", {}).n("Route53Client", "ActivateKeySigningKeyCommand").sc(schemas_0.ActivateKeySigningKey$).build() {
      static {
        __name(this, "ActivateKeySigningKeyCommand");
      }
    };
    var AssociateVPCWithHostedZoneCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "AssociateVPCWithHostedZone", {}).n("Route53Client", "AssociateVPCWithHostedZoneCommand").sc(schemas_0.AssociateVPCWithHostedZone$).build() {
      static {
        __name(this, "AssociateVPCWithHostedZoneCommand");
      }
    };
    var ChangeCidrCollectionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "ChangeCidrCollection", {}).n("Route53Client", "ChangeCidrCollectionCommand").sc(schemas_0.ChangeCidrCollection$).build() {
      static {
        __name(this, "ChangeCidrCollectionCommand");
      }
    };
    var ChangeResourceRecordSetsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getChangeResourceRecordSetsPlugin(config2),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "ChangeResourceRecordSets", {}).n("Route53Client", "ChangeResourceRecordSetsCommand").sc(schemas_0.ChangeResourceRecordSets$).build() {
      static {
        __name(this, "ChangeResourceRecordSetsCommand");
      }
    };
    var ChangeTagsForResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSDnsV20130401", "ChangeTagsForResource", {}).n("Route53Client", "ChangeTagsForResourceCommand").sc(schemas_0.ChangeTagsForResource$).build() {
      static {
        __name(this, "ChangeTagsForResourceCommand");
      }
    };
    var CreateCidrCollectionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSDnsV20130401", "CreateCidrCollection", {}).n("Route53Client", "CreateCidrCollectionCommand").sc(schemas_0.CreateCidrCollection$).build() {
      static {
        __name(this, "CreateCidrCollectionCommand");
      }
    };
    var CreateHealthCheckCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSDnsV20130401", "CreateHealthCheck", {}).n("Route53Client", "CreateHealthCheckCommand").sc(schemas_0.CreateHealthCheck$).build() {
      static {
        __name(this, "CreateHealthCheckCommand");
      }
    };
    var CreateHostedZoneCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "CreateHostedZone", {}).n("Route53Client", "CreateHostedZoneCommand").sc(schemas_0.CreateHostedZone$).build() {
      static {
        __name(this, "CreateHostedZoneCommand");
      }
    };
    var CreateKeySigningKeyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "CreateKeySigningKey", {}).n("Route53Client", "CreateKeySigningKeyCommand").sc(schemas_0.CreateKeySigningKey$).build() {
      static {
        __name(this, "CreateKeySigningKeyCommand");
      }
    };
    var CreateQueryLoggingConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "CreateQueryLoggingConfig", {}).n("Route53Client", "CreateQueryLoggingConfigCommand").sc(schemas_0.CreateQueryLoggingConfig$).build() {
      static {
        __name(this, "CreateQueryLoggingConfigCommand");
      }
    };
    var CreateReusableDelegationSetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "CreateReusableDelegationSet", {}).n("Route53Client", "CreateReusableDelegationSetCommand").sc(schemas_0.CreateReusableDelegationSet$).build() {
      static {
        __name(this, "CreateReusableDelegationSetCommand");
      }
    };
    var CreateTrafficPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSDnsV20130401", "CreateTrafficPolicy", {}).n("Route53Client", "CreateTrafficPolicyCommand").sc(schemas_0.CreateTrafficPolicy$).build() {
      static {
        __name(this, "CreateTrafficPolicyCommand");
      }
    };
    var CreateTrafficPolicyInstanceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "CreateTrafficPolicyInstance", {}).n("Route53Client", "CreateTrafficPolicyInstanceCommand").sc(schemas_0.CreateTrafficPolicyInstance$).build() {
      static {
        __name(this, "CreateTrafficPolicyInstanceCommand");
      }
    };
    var CreateTrafficPolicyVersionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "CreateTrafficPolicyVersion", {}).n("Route53Client", "CreateTrafficPolicyVersionCommand").sc(schemas_0.CreateTrafficPolicyVersion$).build() {
      static {
        __name(this, "CreateTrafficPolicyVersionCommand");
      }
    };
    var CreateVPCAssociationAuthorizationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "CreateVPCAssociationAuthorization", {}).n("Route53Client", "CreateVPCAssociationAuthorizationCommand").sc(schemas_0.CreateVPCAssociationAuthorization$).build() {
      static {
        __name(this, "CreateVPCAssociationAuthorizationCommand");
      }
    };
    var DeactivateKeySigningKeyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "DeactivateKeySigningKey", {}).n("Route53Client", "DeactivateKeySigningKeyCommand").sc(schemas_0.DeactivateKeySigningKey$).build() {
      static {
        __name(this, "DeactivateKeySigningKeyCommand");
      }
    };
    var DeleteCidrCollectionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "DeleteCidrCollection", {}).n("Route53Client", "DeleteCidrCollectionCommand").sc(schemas_0.DeleteCidrCollection$).build() {
      static {
        __name(this, "DeleteCidrCollectionCommand");
      }
    };
    var DeleteHealthCheckCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSDnsV20130401", "DeleteHealthCheck", {}).n("Route53Client", "DeleteHealthCheckCommand").sc(schemas_0.DeleteHealthCheck$).build() {
      static {
        __name(this, "DeleteHealthCheckCommand");
      }
    };
    var DeleteHostedZoneCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "DeleteHostedZone", {}).n("Route53Client", "DeleteHostedZoneCommand").sc(schemas_0.DeleteHostedZone$).build() {
      static {
        __name(this, "DeleteHostedZoneCommand");
      }
    };
    var DeleteKeySigningKeyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "DeleteKeySigningKey", {}).n("Route53Client", "DeleteKeySigningKeyCommand").sc(schemas_0.DeleteKeySigningKey$).build() {
      static {
        __name(this, "DeleteKeySigningKeyCommand");
      }
    };
    var DeleteQueryLoggingConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "DeleteQueryLoggingConfig", {}).n("Route53Client", "DeleteQueryLoggingConfigCommand").sc(schemas_0.DeleteQueryLoggingConfig$).build() {
      static {
        __name(this, "DeleteQueryLoggingConfigCommand");
      }
    };
    var DeleteReusableDelegationSetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "DeleteReusableDelegationSet", {}).n("Route53Client", "DeleteReusableDelegationSetCommand").sc(schemas_0.DeleteReusableDelegationSet$).build() {
      static {
        __name(this, "DeleteReusableDelegationSetCommand");
      }
    };
    var DeleteTrafficPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "DeleteTrafficPolicy", {}).n("Route53Client", "DeleteTrafficPolicyCommand").sc(schemas_0.DeleteTrafficPolicy$).build() {
      static {
        __name(this, "DeleteTrafficPolicyCommand");
      }
    };
    var DeleteTrafficPolicyInstanceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "DeleteTrafficPolicyInstance", {}).n("Route53Client", "DeleteTrafficPolicyInstanceCommand").sc(schemas_0.DeleteTrafficPolicyInstance$).build() {
      static {
        __name(this, "DeleteTrafficPolicyInstanceCommand");
      }
    };
    var DeleteVPCAssociationAuthorizationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "DeleteVPCAssociationAuthorization", {}).n("Route53Client", "DeleteVPCAssociationAuthorizationCommand").sc(schemas_0.DeleteVPCAssociationAuthorization$).build() {
      static {
        __name(this, "DeleteVPCAssociationAuthorizationCommand");
      }
    };
    var DisableHostedZoneDNSSECCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "DisableHostedZoneDNSSEC", {}).n("Route53Client", "DisableHostedZoneDNSSECCommand").sc(schemas_0.DisableHostedZoneDNSSEC$).build() {
      static {
        __name(this, "DisableHostedZoneDNSSECCommand");
      }
    };
    var DisassociateVPCFromHostedZoneCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "DisassociateVPCFromHostedZone", {}).n("Route53Client", "DisassociateVPCFromHostedZoneCommand").sc(schemas_0.DisassociateVPCFromHostedZone$).build() {
      static {
        __name(this, "DisassociateVPCFromHostedZoneCommand");
      }
    };
    var EnableHostedZoneDNSSECCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "EnableHostedZoneDNSSEC", {}).n("Route53Client", "EnableHostedZoneDNSSECCommand").sc(schemas_0.EnableHostedZoneDNSSEC$).build() {
      static {
        __name(this, "EnableHostedZoneDNSSECCommand");
      }
    };
    var GetAccountLimitCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSDnsV20130401", "GetAccountLimit", {}).n("Route53Client", "GetAccountLimitCommand").sc(schemas_0.GetAccountLimit$).build() {
      static {
        __name(this, "GetAccountLimitCommand");
      }
    };
    var GetChangeCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "GetChange", {}).n("Route53Client", "GetChangeCommand").sc(schemas_0.GetChange$).build() {
      static {
        __name(this, "GetChangeCommand");
      }
    };
    var GetCheckerIpRangesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSDnsV20130401", "GetCheckerIpRanges", {}).n("Route53Client", "GetCheckerIpRangesCommand").sc(schemas_0.GetCheckerIpRanges$).build() {
      static {
        __name(this, "GetCheckerIpRangesCommand");
      }
    };
    var GetDNSSECCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "GetDNSSEC", {}).n("Route53Client", "GetDNSSECCommand").sc(schemas_0.GetDNSSEC$).build() {
      static {
        __name(this, "GetDNSSECCommand");
      }
    };
    var GetGeoLocationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSDnsV20130401", "GetGeoLocation", {}).n("Route53Client", "GetGeoLocationCommand").sc(schemas_0.GetGeoLocation$).build() {
      static {
        __name(this, "GetGeoLocationCommand");
      }
    };
    var GetHealthCheckCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSDnsV20130401", "GetHealthCheck", {}).n("Route53Client", "GetHealthCheckCommand").sc(schemas_0.GetHealthCheck$).build() {
      static {
        __name(this, "GetHealthCheckCommand");
      }
    };
    var GetHealthCheckCountCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSDnsV20130401", "GetHealthCheckCount", {}).n("Route53Client", "GetHealthCheckCountCommand").sc(schemas_0.GetHealthCheckCount$).build() {
      static {
        __name(this, "GetHealthCheckCountCommand");
      }
    };
    var GetHealthCheckLastFailureReasonCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSDnsV20130401", "GetHealthCheckLastFailureReason", {}).n("Route53Client", "GetHealthCheckLastFailureReasonCommand").sc(schemas_0.GetHealthCheckLastFailureReason$).build() {
      static {
        __name(this, "GetHealthCheckLastFailureReasonCommand");
      }
    };
    var GetHealthCheckStatusCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSDnsV20130401", "GetHealthCheckStatus", {}).n("Route53Client", "GetHealthCheckStatusCommand").sc(schemas_0.GetHealthCheckStatus$).build() {
      static {
        __name(this, "GetHealthCheckStatusCommand");
      }
    };
    var GetHostedZoneCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "GetHostedZone", {}).n("Route53Client", "GetHostedZoneCommand").sc(schemas_0.GetHostedZone$).build() {
      static {
        __name(this, "GetHostedZoneCommand");
      }
    };
    var GetHostedZoneCountCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSDnsV20130401", "GetHostedZoneCount", {}).n("Route53Client", "GetHostedZoneCountCommand").sc(schemas_0.GetHostedZoneCount$).build() {
      static {
        __name(this, "GetHostedZoneCountCommand");
      }
    };
    var GetHostedZoneLimitCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "GetHostedZoneLimit", {}).n("Route53Client", "GetHostedZoneLimitCommand").sc(schemas_0.GetHostedZoneLimit$).build() {
      static {
        __name(this, "GetHostedZoneLimitCommand");
      }
    };
    var GetQueryLoggingConfigCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "GetQueryLoggingConfig", {}).n("Route53Client", "GetQueryLoggingConfigCommand").sc(schemas_0.GetQueryLoggingConfig$).build() {
      static {
        __name(this, "GetQueryLoggingConfigCommand");
      }
    };
    var GetReusableDelegationSetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "GetReusableDelegationSet", {}).n("Route53Client", "GetReusableDelegationSetCommand").sc(schemas_0.GetReusableDelegationSet$).build() {
      static {
        __name(this, "GetReusableDelegationSetCommand");
      }
    };
    var GetReusableDelegationSetLimitCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "GetReusableDelegationSetLimit", {}).n("Route53Client", "GetReusableDelegationSetLimitCommand").sc(schemas_0.GetReusableDelegationSetLimit$).build() {
      static {
        __name(this, "GetReusableDelegationSetLimitCommand");
      }
    };
    var GetTrafficPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "GetTrafficPolicy", {}).n("Route53Client", "GetTrafficPolicyCommand").sc(schemas_0.GetTrafficPolicy$).build() {
      static {
        __name(this, "GetTrafficPolicyCommand");
      }
    };
    var GetTrafficPolicyInstanceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "GetTrafficPolicyInstance", {}).n("Route53Client", "GetTrafficPolicyInstanceCommand").sc(schemas_0.GetTrafficPolicyInstance$).build() {
      static {
        __name(this, "GetTrafficPolicyInstanceCommand");
      }
    };
    var GetTrafficPolicyInstanceCountCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSDnsV20130401", "GetTrafficPolicyInstanceCount", {}).n("Route53Client", "GetTrafficPolicyInstanceCountCommand").sc(schemas_0.GetTrafficPolicyInstanceCount$).build() {
      static {
        __name(this, "GetTrafficPolicyInstanceCountCommand");
      }
    };
    var ListCidrBlocksCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSDnsV20130401", "ListCidrBlocks", {}).n("Route53Client", "ListCidrBlocksCommand").sc(schemas_0.ListCidrBlocks$).build() {
      static {
        __name(this, "ListCidrBlocksCommand");
      }
    };
    var ListCidrCollectionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSDnsV20130401", "ListCidrCollections", {}).n("Route53Client", "ListCidrCollectionsCommand").sc(schemas_0.ListCidrCollections$).build() {
      static {
        __name(this, "ListCidrCollectionsCommand");
      }
    };
    var ListCidrLocationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSDnsV20130401", "ListCidrLocations", {}).n("Route53Client", "ListCidrLocationsCommand").sc(schemas_0.ListCidrLocations$).build() {
      static {
        __name(this, "ListCidrLocationsCommand");
      }
    };
    var ListGeoLocationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSDnsV20130401", "ListGeoLocations", {}).n("Route53Client", "ListGeoLocationsCommand").sc(schemas_0.ListGeoLocations$).build() {
      static {
        __name(this, "ListGeoLocationsCommand");
      }
    };
    var ListHealthChecksCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSDnsV20130401", "ListHealthChecks", {}).n("Route53Client", "ListHealthChecksCommand").sc(schemas_0.ListHealthChecks$).build() {
      static {
        __name(this, "ListHealthChecksCommand");
      }
    };
    var ListHostedZonesByNameCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "ListHostedZonesByName", {}).n("Route53Client", "ListHostedZonesByNameCommand").sc(schemas_0.ListHostedZonesByName$).build() {
      static {
        __name(this, "ListHostedZonesByNameCommand");
      }
    };
    var ListHostedZonesByVPCCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSDnsV20130401", "ListHostedZonesByVPC", {}).n("Route53Client", "ListHostedZonesByVPCCommand").sc(schemas_0.ListHostedZonesByVPC$).build() {
      static {
        __name(this, "ListHostedZonesByVPCCommand");
      }
    };
    var ListHostedZonesCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "ListHostedZones", {}).n("Route53Client", "ListHostedZonesCommand").sc(schemas_0.ListHostedZones$).build() {
      static {
        __name(this, "ListHostedZonesCommand");
      }
    };
    var ListQueryLoggingConfigsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "ListQueryLoggingConfigs", {}).n("Route53Client", "ListQueryLoggingConfigsCommand").sc(schemas_0.ListQueryLoggingConfigs$).build() {
      static {
        __name(this, "ListQueryLoggingConfigsCommand");
      }
    };
    var ListResourceRecordSetsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "ListResourceRecordSets", {}).n("Route53Client", "ListResourceRecordSetsCommand").sc(schemas_0.ListResourceRecordSets$).build() {
      static {
        __name(this, "ListResourceRecordSetsCommand");
      }
    };
    var ListReusableDelegationSetsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSDnsV20130401", "ListReusableDelegationSets", {}).n("Route53Client", "ListReusableDelegationSetsCommand").sc(schemas_0.ListReusableDelegationSets$).build() {
      static {
        __name(this, "ListReusableDelegationSetsCommand");
      }
    };
    var ListTagsForResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSDnsV20130401", "ListTagsForResource", {}).n("Route53Client", "ListTagsForResourceCommand").sc(schemas_0.ListTagsForResource$).build() {
      static {
        __name(this, "ListTagsForResourceCommand");
      }
    };
    var ListTagsForResourcesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSDnsV20130401", "ListTagsForResources", {}).n("Route53Client", "ListTagsForResourcesCommand").sc(schemas_0.ListTagsForResources$).build() {
      static {
        __name(this, "ListTagsForResourcesCommand");
      }
    };
    var ListTrafficPoliciesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSDnsV20130401", "ListTrafficPolicies", {}).n("Route53Client", "ListTrafficPoliciesCommand").sc(schemas_0.ListTrafficPolicies$).build() {
      static {
        __name(this, "ListTrafficPoliciesCommand");
      }
    };
    var ListTrafficPolicyInstancesByHostedZoneCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "ListTrafficPolicyInstancesByHostedZone", {}).n("Route53Client", "ListTrafficPolicyInstancesByHostedZoneCommand").sc(schemas_0.ListTrafficPolicyInstancesByHostedZone$).build() {
      static {
        __name(this, "ListTrafficPolicyInstancesByHostedZoneCommand");
      }
    };
    var ListTrafficPolicyInstancesByPolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSDnsV20130401", "ListTrafficPolicyInstancesByPolicy", {}).n("Route53Client", "ListTrafficPolicyInstancesByPolicyCommand").sc(schemas_0.ListTrafficPolicyInstancesByPolicy$).build() {
      static {
        __name(this, "ListTrafficPolicyInstancesByPolicyCommand");
      }
    };
    var ListTrafficPolicyInstancesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSDnsV20130401", "ListTrafficPolicyInstances", {}).n("Route53Client", "ListTrafficPolicyInstancesCommand").sc(schemas_0.ListTrafficPolicyInstances$).build() {
      static {
        __name(this, "ListTrafficPolicyInstancesCommand");
      }
    };
    var ListTrafficPolicyVersionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "ListTrafficPolicyVersions", {}).n("Route53Client", "ListTrafficPolicyVersionsCommand").sc(schemas_0.ListTrafficPolicyVersions$).build() {
      static {
        __name(this, "ListTrafficPolicyVersionsCommand");
      }
    };
    var ListVPCAssociationAuthorizationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "ListVPCAssociationAuthorizations", {}).n("Route53Client", "ListVPCAssociationAuthorizationsCommand").sc(schemas_0.ListVPCAssociationAuthorizations$).build() {
      static {
        __name(this, "ListVPCAssociationAuthorizationsCommand");
      }
    };
    var TestDNSAnswerCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "TestDNSAnswer", {}).n("Route53Client", "TestDNSAnswerCommand").sc(schemas_0.TestDNSAnswer$).build() {
      static {
        __name(this, "TestDNSAnswerCommand");
      }
    };
    var UpdateHealthCheckCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSDnsV20130401", "UpdateHealthCheck", {}).n("Route53Client", "UpdateHealthCheckCommand").sc(schemas_0.UpdateHealthCheck$).build() {
      static {
        __name(this, "UpdateHealthCheckCommand");
      }
    };
    var UpdateHostedZoneCommentCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "UpdateHostedZoneComment", {}).n("Route53Client", "UpdateHostedZoneCommentCommand").sc(schemas_0.UpdateHostedZoneComment$).build() {
      static {
        __name(this, "UpdateHostedZoneCommentCommand");
      }
    };
    var UpdateHostedZoneFeaturesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "UpdateHostedZoneFeatures", {}).n("Route53Client", "UpdateHostedZoneFeaturesCommand").sc(schemas_0.UpdateHostedZoneFeatures$).build() {
      static {
        __name(this, "UpdateHostedZoneFeaturesCommand");
      }
    };
    var UpdateTrafficPolicyCommentCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "UpdateTrafficPolicyComment", {}).n("Route53Client", "UpdateTrafficPolicyCommentCommand").sc(schemas_0.UpdateTrafficPolicyComment$).build() {
      static {
        __name(this, "UpdateTrafficPolicyCommentCommand");
      }
    };
    var UpdateTrafficPolicyInstanceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        middlewareSdkRoute53.getIdNormalizerPlugin(config2)
      ];
    }).s("AWSDnsV20130401", "UpdateTrafficPolicyInstance", {}).n("Route53Client", "UpdateTrafficPolicyInstanceCommand").sc(schemas_0.UpdateTrafficPolicyInstance$).build() {
      static {
        __name(this, "UpdateTrafficPolicyInstanceCommand");
      }
    };
    var paginateListCidrBlocks = core.createPaginator(Route53Client2, ListCidrBlocksCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListCidrCollections = core.createPaginator(Route53Client2, ListCidrCollectionsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListCidrLocations = core.createPaginator(Route53Client2, ListCidrLocationsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListHealthChecks = core.createPaginator(Route53Client2, ListHealthChecksCommand, "Marker", "NextMarker", "MaxItems");
    var paginateListHostedZones = core.createPaginator(Route53Client2, ListHostedZonesCommand2, "Marker", "NextMarker", "MaxItems");
    var paginateListQueryLoggingConfigs = core.createPaginator(Route53Client2, ListQueryLoggingConfigsCommand, "NextToken", "NextToken", "MaxResults");
    var checkState = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new GetChangeCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.ChangeInfo.Status;
          }, "returnComparator");
          if (returnComparator() === "INSYNC") {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState");
    var waitForResourceRecordSetsChanged = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 30, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState);
    }, "waitForResourceRecordSetsChanged");
    var waitUntilResourceRecordSetsChanged = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 30, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilResourceRecordSetsChanged");
    var commands32 = {
      ActivateKeySigningKeyCommand,
      AssociateVPCWithHostedZoneCommand,
      ChangeCidrCollectionCommand,
      ChangeResourceRecordSetsCommand,
      ChangeTagsForResourceCommand,
      CreateCidrCollectionCommand,
      CreateHealthCheckCommand,
      CreateHostedZoneCommand,
      CreateKeySigningKeyCommand,
      CreateQueryLoggingConfigCommand,
      CreateReusableDelegationSetCommand,
      CreateTrafficPolicyCommand,
      CreateTrafficPolicyInstanceCommand,
      CreateTrafficPolicyVersionCommand,
      CreateVPCAssociationAuthorizationCommand,
      DeactivateKeySigningKeyCommand,
      DeleteCidrCollectionCommand,
      DeleteHealthCheckCommand,
      DeleteHostedZoneCommand,
      DeleteKeySigningKeyCommand,
      DeleteQueryLoggingConfigCommand,
      DeleteReusableDelegationSetCommand,
      DeleteTrafficPolicyCommand,
      DeleteTrafficPolicyInstanceCommand,
      DeleteVPCAssociationAuthorizationCommand,
      DisableHostedZoneDNSSECCommand,
      DisassociateVPCFromHostedZoneCommand,
      EnableHostedZoneDNSSECCommand,
      GetAccountLimitCommand,
      GetChangeCommand,
      GetCheckerIpRangesCommand,
      GetDNSSECCommand,
      GetGeoLocationCommand,
      GetHealthCheckCommand,
      GetHealthCheckCountCommand,
      GetHealthCheckLastFailureReasonCommand,
      GetHealthCheckStatusCommand,
      GetHostedZoneCommand: GetHostedZoneCommand2,
      GetHostedZoneCountCommand,
      GetHostedZoneLimitCommand,
      GetQueryLoggingConfigCommand,
      GetReusableDelegationSetCommand,
      GetReusableDelegationSetLimitCommand,
      GetTrafficPolicyCommand,
      GetTrafficPolicyInstanceCommand,
      GetTrafficPolicyInstanceCountCommand,
      ListCidrBlocksCommand,
      ListCidrCollectionsCommand,
      ListCidrLocationsCommand,
      ListGeoLocationsCommand,
      ListHealthChecksCommand,
      ListHostedZonesCommand: ListHostedZonesCommand2,
      ListHostedZonesByNameCommand: ListHostedZonesByNameCommand2,
      ListHostedZonesByVPCCommand,
      ListQueryLoggingConfigsCommand,
      ListResourceRecordSetsCommand,
      ListReusableDelegationSetsCommand,
      ListTagsForResourceCommand,
      ListTagsForResourcesCommand,
      ListTrafficPoliciesCommand,
      ListTrafficPolicyInstancesCommand,
      ListTrafficPolicyInstancesByHostedZoneCommand,
      ListTrafficPolicyInstancesByPolicyCommand,
      ListTrafficPolicyVersionsCommand,
      ListVPCAssociationAuthorizationsCommand,
      TestDNSAnswerCommand,
      UpdateHealthCheckCommand,
      UpdateHostedZoneCommentCommand,
      UpdateHostedZoneFeaturesCommand,
      UpdateTrafficPolicyCommentCommand,
      UpdateTrafficPolicyInstanceCommand
    };
    var paginators = {
      paginateListCidrBlocks,
      paginateListCidrCollections,
      paginateListCidrLocations,
      paginateListHealthChecks,
      paginateListHostedZones,
      paginateListQueryLoggingConfigs
    };
    var waiters = {
      waitUntilResourceRecordSetsChanged
    };
    var Route53 = class extends Route53Client2 {
      static {
        __name(this, "Route53");
      }
    };
    smithyClient.createAggregatedClient(commands32, Route53, { paginators, waiters });
    var AcceleratedRecoveryStatus = {
      DISABLED: "DISABLED",
      DISABLE_FAILED: "DISABLE_FAILED",
      DISABLING: "DISABLING",
      DISABLING_HOSTED_ZONE_LOCKED: "DISABLING_HOSTED_ZONE_LOCKED",
      ENABLED: "ENABLED",
      ENABLE_FAILED: "ENABLE_FAILED",
      ENABLING: "ENABLING",
      ENABLING_HOSTED_ZONE_LOCKED: "ENABLING_HOSTED_ZONE_LOCKED"
    };
    var AccountLimitType = {
      MAX_HEALTH_CHECKS_BY_OWNER: "MAX_HEALTH_CHECKS_BY_OWNER",
      MAX_HOSTED_ZONES_BY_OWNER: "MAX_HOSTED_ZONES_BY_OWNER",
      MAX_REUSABLE_DELEGATION_SETS_BY_OWNER: "MAX_REUSABLE_DELEGATION_SETS_BY_OWNER",
      MAX_TRAFFIC_POLICIES_BY_OWNER: "MAX_TRAFFIC_POLICIES_BY_OWNER",
      MAX_TRAFFIC_POLICY_INSTANCES_BY_OWNER: "MAX_TRAFFIC_POLICY_INSTANCES_BY_OWNER"
    };
    var ChangeStatus = {
      INSYNC: "INSYNC",
      PENDING: "PENDING"
    };
    var CloudWatchRegion = {
      af_south_1: "af-south-1",
      ap_east_1: "ap-east-1",
      ap_east_2: "ap-east-2",
      ap_northeast_1: "ap-northeast-1",
      ap_northeast_2: "ap-northeast-2",
      ap_northeast_3: "ap-northeast-3",
      ap_south_1: "ap-south-1",
      ap_south_2: "ap-south-2",
      ap_southeast_1: "ap-southeast-1",
      ap_southeast_2: "ap-southeast-2",
      ap_southeast_3: "ap-southeast-3",
      ap_southeast_4: "ap-southeast-4",
      ap_southeast_5: "ap-southeast-5",
      ap_southeast_6: "ap-southeast-6",
      ap_southeast_7: "ap-southeast-7",
      ca_central_1: "ca-central-1",
      ca_west_1: "ca-west-1",
      cn_north_1: "cn-north-1",
      cn_northwest_1: "cn-northwest-1",
      eu_central_1: "eu-central-1",
      eu_central_2: "eu-central-2",
      eu_isoe_west_1: "eu-isoe-west-1",
      eu_north_1: "eu-north-1",
      eu_south_1: "eu-south-1",
      eu_south_2: "eu-south-2",
      eu_west_1: "eu-west-1",
      eu_west_2: "eu-west-2",
      eu_west_3: "eu-west-3",
      eusc_de_east_1: "eusc-de-east-1",
      il_central_1: "il-central-1",
      me_central_1: "me-central-1",
      me_south_1: "me-south-1",
      mx_central_1: "mx-central-1",
      sa_east_1: "sa-east-1",
      us_east_1: "us-east-1",
      us_east_2: "us-east-2",
      us_gov_east_1: "us-gov-east-1",
      us_gov_west_1: "us-gov-west-1",
      us_iso_east_1: "us-iso-east-1",
      us_iso_west_1: "us-iso-west-1",
      us_isob_east_1: "us-isob-east-1",
      us_isob_west_1: "us-isob-west-1",
      us_isof_east_1: "us-isof-east-1",
      us_isof_south_1: "us-isof-south-1",
      us_west_1: "us-west-1",
      us_west_2: "us-west-2"
    };
    var VPCRegion = {
      af_south_1: "af-south-1",
      ap_east_1: "ap-east-1",
      ap_east_2: "ap-east-2",
      ap_northeast_1: "ap-northeast-1",
      ap_northeast_2: "ap-northeast-2",
      ap_northeast_3: "ap-northeast-3",
      ap_south_1: "ap-south-1",
      ap_south_2: "ap-south-2",
      ap_southeast_1: "ap-southeast-1",
      ap_southeast_2: "ap-southeast-2",
      ap_southeast_3: "ap-southeast-3",
      ap_southeast_4: "ap-southeast-4",
      ap_southeast_5: "ap-southeast-5",
      ap_southeast_6: "ap-southeast-6",
      ap_southeast_7: "ap-southeast-7",
      ca_central_1: "ca-central-1",
      ca_west_1: "ca-west-1",
      cn_north_1: "cn-north-1",
      cn_northwest_1: "cn-northwest-1",
      eu_central_1: "eu-central-1",
      eu_central_2: "eu-central-2",
      eu_isoe_west_1: "eu-isoe-west-1",
      eu_north_1: "eu-north-1",
      eu_south_1: "eu-south-1",
      eu_south_2: "eu-south-2",
      eu_west_1: "eu-west-1",
      eu_west_2: "eu-west-2",
      eu_west_3: "eu-west-3",
      eusc_de_east_1: "eusc-de-east-1",
      il_central_1: "il-central-1",
      me_central_1: "me-central-1",
      me_south_1: "me-south-1",
      mx_central_1: "mx-central-1",
      sa_east_1: "sa-east-1",
      us_east_1: "us-east-1",
      us_east_2: "us-east-2",
      us_gov_east_1: "us-gov-east-1",
      us_gov_west_1: "us-gov-west-1",
      us_iso_east_1: "us-iso-east-1",
      us_iso_west_1: "us-iso-west-1",
      us_isob_east_1: "us-isob-east-1",
      us_isob_west_1: "us-isob-west-1",
      us_isof_east_1: "us-isof-east-1",
      us_isof_south_1: "us-isof-south-1",
      us_west_1: "us-west-1",
      us_west_2: "us-west-2"
    };
    var CidrCollectionChangeAction = {
      DELETE_IF_EXISTS: "DELETE_IF_EXISTS",
      PUT: "PUT"
    };
    var ChangeAction = {
      CREATE: "CREATE",
      DELETE: "DELETE",
      UPSERT: "UPSERT"
    };
    var ResourceRecordSetFailover = {
      PRIMARY: "PRIMARY",
      SECONDARY: "SECONDARY"
    };
    var ResourceRecordSetRegion = {
      af_south_1: "af-south-1",
      ap_east_1: "ap-east-1",
      ap_east_2: "ap-east-2",
      ap_northeast_1: "ap-northeast-1",
      ap_northeast_2: "ap-northeast-2",
      ap_northeast_3: "ap-northeast-3",
      ap_south_1: "ap-south-1",
      ap_south_2: "ap-south-2",
      ap_southeast_1: "ap-southeast-1",
      ap_southeast_2: "ap-southeast-2",
      ap_southeast_3: "ap-southeast-3",
      ap_southeast_4: "ap-southeast-4",
      ap_southeast_5: "ap-southeast-5",
      ap_southeast_6: "ap-southeast-6",
      ap_southeast_7: "ap-southeast-7",
      ca_central_1: "ca-central-1",
      ca_west_1: "ca-west-1",
      cn_north_1: "cn-north-1",
      cn_northwest_1: "cn-northwest-1",
      eu_central_1: "eu-central-1",
      eu_central_2: "eu-central-2",
      eu_north_1: "eu-north-1",
      eu_south_1: "eu-south-1",
      eu_south_2: "eu-south-2",
      eu_west_1: "eu-west-1",
      eu_west_2: "eu-west-2",
      eu_west_3: "eu-west-3",
      eusc_de_east_1: "eusc-de-east-1",
      il_central_1: "il-central-1",
      me_central_1: "me-central-1",
      me_south_1: "me-south-1",
      mx_central_1: "mx-central-1",
      sa_east_1: "sa-east-1",
      us_east_1: "us-east-1",
      us_east_2: "us-east-2",
      us_gov_east_1: "us-gov-east-1",
      us_gov_west_1: "us-gov-west-1",
      us_west_1: "us-west-1",
      us_west_2: "us-west-2"
    };
    var RRType = {
      A: "A",
      AAAA: "AAAA",
      CAA: "CAA",
      CNAME: "CNAME",
      DS: "DS",
      HTTPS: "HTTPS",
      MX: "MX",
      NAPTR: "NAPTR",
      NS: "NS",
      PTR: "PTR",
      SOA: "SOA",
      SPF: "SPF",
      SRV: "SRV",
      SSHFP: "SSHFP",
      SVCB: "SVCB",
      TLSA: "TLSA",
      TXT: "TXT"
    };
    var TagResourceType = {
      healthcheck: "healthcheck",
      hostedzone: "hostedzone"
    };
    var InsufficientDataHealthStatus = {
      Healthy: "Healthy",
      LastKnownStatus: "LastKnownStatus",
      Unhealthy: "Unhealthy"
    };
    var HealthCheckRegion = {
      ap_northeast_1: "ap-northeast-1",
      ap_southeast_1: "ap-southeast-1",
      ap_southeast_2: "ap-southeast-2",
      eu_west_1: "eu-west-1",
      sa_east_1: "sa-east-1",
      us_east_1: "us-east-1",
      us_west_1: "us-west-1",
      us_west_2: "us-west-2"
    };
    var HealthCheckType = {
      CALCULATED: "CALCULATED",
      CLOUDWATCH_METRIC: "CLOUDWATCH_METRIC",
      HTTP: "HTTP",
      HTTPS: "HTTPS",
      HTTPS_STR_MATCH: "HTTPS_STR_MATCH",
      HTTP_STR_MATCH: "HTTP_STR_MATCH",
      RECOVERY_CONTROL: "RECOVERY_CONTROL",
      TCP: "TCP"
    };
    var ComparisonOperator = {
      GreaterThanOrEqualToThreshold: "GreaterThanOrEqualToThreshold",
      GreaterThanThreshold: "GreaterThanThreshold",
      LessThanOrEqualToThreshold: "LessThanOrEqualToThreshold",
      LessThanThreshold: "LessThanThreshold"
    };
    var Statistic = {
      Average: "Average",
      Maximum: "Maximum",
      Minimum: "Minimum",
      SampleCount: "SampleCount",
      Sum: "Sum"
    };
    var HostedZoneLimitType = {
      MAX_RRSETS_BY_ZONE: "MAX_RRSETS_BY_ZONE",
      MAX_VPCS_ASSOCIATED_BY_ZONE: "MAX_VPCS_ASSOCIATED_BY_ZONE"
    };
    var ReusableDelegationSetLimitType = {
      MAX_ZONES_BY_REUSABLE_DELEGATION_SET: "MAX_ZONES_BY_REUSABLE_DELEGATION_SET"
    };
    var HostedZoneType = {
      PRIVATE_HOSTED_ZONE: "PrivateHostedZone"
    };
    var ResettableElementName = {
      ChildHealthChecks: "ChildHealthChecks",
      FullyQualifiedDomainName: "FullyQualifiedDomainName",
      Regions: "Regions",
      ResourcePath: "ResourcePath"
    };
    exports2.$Command = smithyClient.Command;
    exports2.__Client = smithyClient.Client;
    exports2.Route53ServiceException = Route53ServiceException.Route53ServiceException;
    exports2.AcceleratedRecoveryStatus = AcceleratedRecoveryStatus;
    exports2.AccountLimitType = AccountLimitType;
    exports2.ActivateKeySigningKeyCommand = ActivateKeySigningKeyCommand;
    exports2.AssociateVPCWithHostedZoneCommand = AssociateVPCWithHostedZoneCommand;
    exports2.ChangeAction = ChangeAction;
    exports2.ChangeCidrCollectionCommand = ChangeCidrCollectionCommand;
    exports2.ChangeResourceRecordSetsCommand = ChangeResourceRecordSetsCommand;
    exports2.ChangeStatus = ChangeStatus;
    exports2.ChangeTagsForResourceCommand = ChangeTagsForResourceCommand;
    exports2.CidrCollectionChangeAction = CidrCollectionChangeAction;
    exports2.CloudWatchRegion = CloudWatchRegion;
    exports2.ComparisonOperator = ComparisonOperator;
    exports2.CreateCidrCollectionCommand = CreateCidrCollectionCommand;
    exports2.CreateHealthCheckCommand = CreateHealthCheckCommand;
    exports2.CreateHostedZoneCommand = CreateHostedZoneCommand;
    exports2.CreateKeySigningKeyCommand = CreateKeySigningKeyCommand;
    exports2.CreateQueryLoggingConfigCommand = CreateQueryLoggingConfigCommand;
    exports2.CreateReusableDelegationSetCommand = CreateReusableDelegationSetCommand;
    exports2.CreateTrafficPolicyCommand = CreateTrafficPolicyCommand;
    exports2.CreateTrafficPolicyInstanceCommand = CreateTrafficPolicyInstanceCommand;
    exports2.CreateTrafficPolicyVersionCommand = CreateTrafficPolicyVersionCommand;
    exports2.CreateVPCAssociationAuthorizationCommand = CreateVPCAssociationAuthorizationCommand;
    exports2.DeactivateKeySigningKeyCommand = DeactivateKeySigningKeyCommand;
    exports2.DeleteCidrCollectionCommand = DeleteCidrCollectionCommand;
    exports2.DeleteHealthCheckCommand = DeleteHealthCheckCommand;
    exports2.DeleteHostedZoneCommand = DeleteHostedZoneCommand;
    exports2.DeleteKeySigningKeyCommand = DeleteKeySigningKeyCommand;
    exports2.DeleteQueryLoggingConfigCommand = DeleteQueryLoggingConfigCommand;
    exports2.DeleteReusableDelegationSetCommand = DeleteReusableDelegationSetCommand;
    exports2.DeleteTrafficPolicyCommand = DeleteTrafficPolicyCommand;
    exports2.DeleteTrafficPolicyInstanceCommand = DeleteTrafficPolicyInstanceCommand;
    exports2.DeleteVPCAssociationAuthorizationCommand = DeleteVPCAssociationAuthorizationCommand;
    exports2.DisableHostedZoneDNSSECCommand = DisableHostedZoneDNSSECCommand;
    exports2.DisassociateVPCFromHostedZoneCommand = DisassociateVPCFromHostedZoneCommand;
    exports2.EnableHostedZoneDNSSECCommand = EnableHostedZoneDNSSECCommand;
    exports2.GetAccountLimitCommand = GetAccountLimitCommand;
    exports2.GetChangeCommand = GetChangeCommand;
    exports2.GetCheckerIpRangesCommand = GetCheckerIpRangesCommand;
    exports2.GetDNSSECCommand = GetDNSSECCommand;
    exports2.GetGeoLocationCommand = GetGeoLocationCommand;
    exports2.GetHealthCheckCommand = GetHealthCheckCommand;
    exports2.GetHealthCheckCountCommand = GetHealthCheckCountCommand;
    exports2.GetHealthCheckLastFailureReasonCommand = GetHealthCheckLastFailureReasonCommand;
    exports2.GetHealthCheckStatusCommand = GetHealthCheckStatusCommand;
    exports2.GetHostedZoneCommand = GetHostedZoneCommand2;
    exports2.GetHostedZoneCountCommand = GetHostedZoneCountCommand;
    exports2.GetHostedZoneLimitCommand = GetHostedZoneLimitCommand;
    exports2.GetQueryLoggingConfigCommand = GetQueryLoggingConfigCommand;
    exports2.GetReusableDelegationSetCommand = GetReusableDelegationSetCommand;
    exports2.GetReusableDelegationSetLimitCommand = GetReusableDelegationSetLimitCommand;
    exports2.GetTrafficPolicyCommand = GetTrafficPolicyCommand;
    exports2.GetTrafficPolicyInstanceCommand = GetTrafficPolicyInstanceCommand;
    exports2.GetTrafficPolicyInstanceCountCommand = GetTrafficPolicyInstanceCountCommand;
    exports2.HealthCheckRegion = HealthCheckRegion;
    exports2.HealthCheckType = HealthCheckType;
    exports2.HostedZoneLimitType = HostedZoneLimitType;
    exports2.HostedZoneType = HostedZoneType;
    exports2.InsufficientDataHealthStatus = InsufficientDataHealthStatus;
    exports2.ListCidrBlocksCommand = ListCidrBlocksCommand;
    exports2.ListCidrCollectionsCommand = ListCidrCollectionsCommand;
    exports2.ListCidrLocationsCommand = ListCidrLocationsCommand;
    exports2.ListGeoLocationsCommand = ListGeoLocationsCommand;
    exports2.ListHealthChecksCommand = ListHealthChecksCommand;
    exports2.ListHostedZonesByNameCommand = ListHostedZonesByNameCommand2;
    exports2.ListHostedZonesByVPCCommand = ListHostedZonesByVPCCommand;
    exports2.ListHostedZonesCommand = ListHostedZonesCommand2;
    exports2.ListQueryLoggingConfigsCommand = ListQueryLoggingConfigsCommand;
    exports2.ListResourceRecordSetsCommand = ListResourceRecordSetsCommand;
    exports2.ListReusableDelegationSetsCommand = ListReusableDelegationSetsCommand;
    exports2.ListTagsForResourceCommand = ListTagsForResourceCommand;
    exports2.ListTagsForResourcesCommand = ListTagsForResourcesCommand;
    exports2.ListTrafficPoliciesCommand = ListTrafficPoliciesCommand;
    exports2.ListTrafficPolicyInstancesByHostedZoneCommand = ListTrafficPolicyInstancesByHostedZoneCommand;
    exports2.ListTrafficPolicyInstancesByPolicyCommand = ListTrafficPolicyInstancesByPolicyCommand;
    exports2.ListTrafficPolicyInstancesCommand = ListTrafficPolicyInstancesCommand;
    exports2.ListTrafficPolicyVersionsCommand = ListTrafficPolicyVersionsCommand;
    exports2.ListVPCAssociationAuthorizationsCommand = ListVPCAssociationAuthorizationsCommand;
    exports2.RRType = RRType;
    exports2.ResettableElementName = ResettableElementName;
    exports2.ResourceRecordSetFailover = ResourceRecordSetFailover;
    exports2.ResourceRecordSetRegion = ResourceRecordSetRegion;
    exports2.ReusableDelegationSetLimitType = ReusableDelegationSetLimitType;
    exports2.Route53 = Route53;
    exports2.Route53Client = Route53Client2;
    exports2.Statistic = Statistic;
    exports2.TagResourceType = TagResourceType;
    exports2.TestDNSAnswerCommand = TestDNSAnswerCommand;
    exports2.UpdateHealthCheckCommand = UpdateHealthCheckCommand;
    exports2.UpdateHostedZoneCommentCommand = UpdateHostedZoneCommentCommand;
    exports2.UpdateHostedZoneFeaturesCommand = UpdateHostedZoneFeaturesCommand;
    exports2.UpdateTrafficPolicyCommentCommand = UpdateTrafficPolicyCommentCommand;
    exports2.UpdateTrafficPolicyInstanceCommand = UpdateTrafficPolicyInstanceCommand;
    exports2.VPCRegion = VPCRegion;
    exports2.paginateListCidrBlocks = paginateListCidrBlocks;
    exports2.paginateListCidrCollections = paginateListCidrCollections;
    exports2.paginateListCidrLocations = paginateListCidrLocations;
    exports2.paginateListHealthChecks = paginateListHealthChecks;
    exports2.paginateListHostedZones = paginateListHostedZones;
    exports2.paginateListQueryLoggingConfigs = paginateListQueryLoggingConfigs;
    exports2.waitForResourceRecordSetsChanged = waitForResourceRecordSetsChanged;
    exports2.waitUntilResourceRecordSetsChanged = waitUntilResourceRecordSetsChanged;
    Object.prototype.hasOwnProperty.call(schemas_0, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: schemas_0["__proto__"]
    });
    Object.keys(schemas_0).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = schemas_0[k32];
    });
    Object.prototype.hasOwnProperty.call(errors, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: errors["__proto__"]
    });
    Object.keys(errors).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = errors[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-sfn/dist-cjs/auth/httpAuthSchemeProvider.js
var require_httpAuthSchemeProvider18 = __commonJS({
  "../../node_modules/@aws-sdk/client-sfn/dist-cjs/auth/httpAuthSchemeProvider.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.resolveHttpAuthSchemeConfig = exports2.defaultSFNHttpAuthSchemeProvider = exports2.defaultSFNHttpAuthSchemeParametersProvider = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var util_middleware_1 = require_dist_cjs6();
    var defaultSFNHttpAuthSchemeParametersProvider = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, util_middleware_1.getSmithyContext)(context).operation,
        region: await (0, util_middleware_1.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultSFNHttpAuthSchemeParametersProvider");
    exports2.defaultSFNHttpAuthSchemeParametersProvider = defaultSFNHttpAuthSchemeParametersProvider;
    function createAwsAuthSigv4HttpAuthOption32(authParameters) {
      return {
        schemeId: "aws.auth#sigv4",
        signingProperties: {
          name: "states",
          region: authParameters.region
        },
        propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
          signingProperties: {
            config: config2,
            context
          }
        }), "propertiesExtractor")
      };
    }
    __name(createAwsAuthSigv4HttpAuthOption32, "createAwsAuthSigv4HttpAuthOption");
    var defaultSFNHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption32(authParameters));
        }
      }
      return options;
    }, "defaultSFNHttpAuthSchemeProvider");
    exports2.defaultSFNHttpAuthSchemeProvider = defaultSFNHttpAuthSchemeProvider;
    var resolveHttpAuthSchemeConfig32 = /* @__PURE__ */ __name((config2) => {
      const config_0 = (0, httpAuthSchemes_1.resolveAwsSdkSigV4Config)(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, util_middleware_1.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
    exports2.resolveHttpAuthSchemeConfig = resolveHttpAuthSchemeConfig32;
  }
});

// ../../node_modules/@aws-sdk/client-sfn/package.json
var require_package18 = __commonJS({
  "../../node_modules/@aws-sdk/client-sfn/package.json"(exports2, module2) {
    module2.exports = {
      name: "@aws-sdk/client-sfn",
      description: "AWS SDK for JavaScript Sfn Client for Node.js, Browser and React Native",
      version: "3.1036.0",
      scripts: {
        build: "concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline client-sfn",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        "extract:docs": "api-extractor run --local",
        "generate:client": "node ../../scripts/generate-clients/single-service --solo sfn",
        "test:index": "tsc --noEmit ./test/index-types.ts && node ./test/index-objects.spec.mjs"
      },
      main: "./dist-cjs/index.js",
      types: "./dist-types/index.d.ts",
      module: "./dist-es/index.js",
      sideEffects: false,
      dependencies: {
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.5",
        "@aws-sdk/credential-provider-node": "^3.972.36",
        "@aws-sdk/middleware-host-header": "^3.972.10",
        "@aws-sdk/middleware-logger": "^3.972.10",
        "@aws-sdk/middleware-recursion-detection": "^3.972.11",
        "@aws-sdk/middleware-user-agent": "^3.972.35",
        "@aws-sdk/region-config-resolver": "^3.972.13",
        "@aws-sdk/types": "^3.973.8",
        "@aws-sdk/util-endpoints": "^3.996.8",
        "@aws-sdk/util-user-agent-browser": "^3.972.10",
        "@aws-sdk/util-user-agent-node": "^3.973.21",
        "@smithy/config-resolver": "^4.4.17",
        "@smithy/core": "^3.23.17",
        "@smithy/fetch-http-handler": "^5.3.17",
        "@smithy/hash-node": "^4.2.14",
        "@smithy/invalid-dependency": "^4.2.14",
        "@smithy/middleware-content-length": "^4.2.14",
        "@smithy/middleware-endpoint": "^4.4.32",
        "@smithy/middleware-retry": "^4.5.5",
        "@smithy/middleware-serde": "^4.2.20",
        "@smithy/middleware-stack": "^4.2.14",
        "@smithy/node-config-provider": "^4.3.14",
        "@smithy/node-http-handler": "^4.6.1",
        "@smithy/protocol-http": "^5.3.14",
        "@smithy/smithy-client": "^4.12.13",
        "@smithy/types": "^4.14.1",
        "@smithy/url-parser": "^4.2.14",
        "@smithy/util-base64": "^4.3.2",
        "@smithy/util-body-length-browser": "^4.2.2",
        "@smithy/util-body-length-node": "^4.2.3",
        "@smithy/util-defaults-mode-browser": "^4.3.49",
        "@smithy/util-defaults-mode-node": "^4.2.54",
        "@smithy/util-endpoints": "^3.4.2",
        "@smithy/util-middleware": "^4.2.14",
        "@smithy/util-retry": "^4.3.4",
        "@smithy/util-utf8": "^4.2.2",
        tslib: "^2.6.2"
      },
      devDependencies: {
        "@tsconfig/node20": "20.1.8",
        "@types/node": "^20.14.8",
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3"
      },
      engines: {
        node: ">=20.0.0"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "dist-*/**"
      ],
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      browser: {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.browser"
      },
      "react-native": {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.native"
      },
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/clients/client-sfn",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "clients/client-sfn"
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-sfn/dist-cjs/endpoint/bdd.js
var require_bdd18 = __commonJS({
  "../../node_modules/@aws-sdk/client-sfn/dist-cjs/endpoint/bdd.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.bdd = void 0;
    var util_endpoints_1 = require_dist_cjs20();
    var l20 = "ref";
    var a32 = -1;
    var b32 = true;
    var c32 = "isSet";
    var d32 = "PartitionResult";
    var e32 = "booleanEquals";
    var f32 = "getAttr";
    var g32 = { [l20]: "Endpoint" };
    var h32 = { [l20]: d32 };
    var i32 = { [l20]: "Region" };
    var j32 = {};
    var k32 = [i32];
    var _data32 = {
      conditions: [
        [c32, [g32]],
        [c32, k32],
        ["aws.partition", k32, d32],
        [e32, [{ [l20]: "UseFIPS" }, b32]],
        [e32, [{ [l20]: "UseDualStack" }, b32]],
        [e32, [{ fn: f32, argv: [h32, "supportsDualStack"] }, b32]],
        [e32, [{ fn: f32, argv: [h32, "supportsFIPS"] }, b32]],
        ["stringEquals", [i32, "us-gov-west-1"]]
      ],
      results: [
        [a32],
        [a32, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a32, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [g32, j32],
        ["https://states-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", j32],
        [a32, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://states.us-gov-west-1.amazonaws.com", j32],
        ["https://states-fips.{Region}.{PartitionResult#dnsSuffix}", j32],
        [a32, "FIPS is enabled but this partition does not support FIPS"],
        ["https://states.{Region}.{PartitionResult#dualStackDnsSuffix}", j32],
        [a32, "DualStack is enabled but this partition does not support DualStack"],
        ["https://states.{Region}.{PartitionResult#dnsSuffix}", j32],
        [a32, "Invalid Configuration: Missing Region"]
      ]
    };
    var root32 = 2;
    var r32 = 1e8;
    var nodes32 = new Int32Array([
      -1,
      1,
      -1,
      0,
      13,
      3,
      1,
      4,
      r32 + 12,
      2,
      5,
      r32 + 12,
      3,
      8,
      6,
      4,
      7,
      r32 + 11,
      5,
      r32 + 9,
      r32 + 10,
      4,
      11,
      9,
      6,
      10,
      r32 + 8,
      7,
      r32 + 6,
      r32 + 7,
      5,
      12,
      r32 + 5,
      6,
      r32 + 4,
      r32 + 5,
      3,
      r32 + 1,
      14,
      4,
      r32 + 2,
      r32 + 3
    ]);
    exports2.bdd = util_endpoints_1.BinaryDecisionDiagram.from(nodes32, root32, _data32.conditions, _data32.results);
  }
});

// ../../node_modules/@aws-sdk/client-sfn/dist-cjs/endpoint/endpointResolver.js
var require_endpointResolver18 = __commonJS({
  "../../node_modules/@aws-sdk/client-sfn/dist-cjs/endpoint/endpointResolver.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.defaultEndpointResolver = void 0;
    var util_endpoints_1 = require_dist_cjs21();
    var util_endpoints_2 = require_dist_cjs20();
    var bdd_1 = require_bdd18();
    var cache32 = new util_endpoints_2.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    var defaultEndpointResolver32 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache32.get(endpointParams, () => (0, util_endpoints_2.decideEndpoint)(bdd_1.bdd, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    exports2.defaultEndpointResolver = defaultEndpointResolver32;
    util_endpoints_2.customEndpointFunctions.aws = util_endpoints_1.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-sfn/dist-cjs/models/SFNServiceException.js
var require_SFNServiceException = __commonJS({
  "../../node_modules/@aws-sdk/client-sfn/dist-cjs/models/SFNServiceException.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.SFNServiceException = exports2.__ServiceException = void 0;
    var smithy_client_1 = require_dist_cjs34();
    Object.defineProperty(exports2, "__ServiceException", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return smithy_client_1.ServiceException;
    }, "get") });
    var SFNServiceException = class _SFNServiceException extends smithy_client_1.ServiceException {
      static {
        __name(this, "SFNServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _SFNServiceException.prototype);
      }
    };
    exports2.SFNServiceException = SFNServiceException;
  }
});

// ../../node_modules/@aws-sdk/client-sfn/dist-cjs/models/errors.js
var require_errors17 = __commonJS({
  "../../node_modules/@aws-sdk/client-sfn/dist-cjs/models/errors.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.MissingRequiredParameter = exports2.InvalidExecutionInput = exports2.ExecutionAlreadyExists = exports2.InvalidOutput = exports2.TaskTimedOut = exports2.TaskDoesNotExist = exports2.ExecutionNotRedrivable = exports2.ExecutionLimitExceeded = exports2.InvalidToken = exports2.StateMachineDoesNotExist = exports2.KmsInvalidStateException = exports2.ExecutionDoesNotExist = exports2.ServiceQuotaExceededException = exports2.ResourceNotFound = exports2.ValidationException = exports2.StateMachineTypeNotSupported = exports2.StateMachineLimitExceeded = exports2.StateMachineDeleting = exports2.StateMachineAlreadyExists = exports2.InvalidTracingConfiguration = exports2.InvalidLoggingConfiguration = exports2.InvalidDefinition = exports2.InvalidArn = exports2.ConflictException = exports2.TooManyTags = exports2.KmsThrottlingException = exports2.KmsAccessDeniedException = exports2.InvalidName = exports2.InvalidEncryptionConfiguration = exports2.ActivityWorkerLimitExceeded = exports2.ActivityLimitExceeded = exports2.ActivityDoesNotExist = exports2.ActivityAlreadyExists = void 0;
    var SFNServiceException_1 = require_SFNServiceException();
    var ActivityAlreadyExists = class _ActivityAlreadyExists extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "ActivityAlreadyExists");
      }
      name = "ActivityAlreadyExists";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ActivityAlreadyExists",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ActivityAlreadyExists.prototype);
      }
    };
    exports2.ActivityAlreadyExists = ActivityAlreadyExists;
    var ActivityDoesNotExist = class _ActivityDoesNotExist extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "ActivityDoesNotExist");
      }
      name = "ActivityDoesNotExist";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ActivityDoesNotExist",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ActivityDoesNotExist.prototype);
      }
    };
    exports2.ActivityDoesNotExist = ActivityDoesNotExist;
    var ActivityLimitExceeded = class _ActivityLimitExceeded extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "ActivityLimitExceeded");
      }
      name = "ActivityLimitExceeded";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ActivityLimitExceeded",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ActivityLimitExceeded.prototype);
      }
    };
    exports2.ActivityLimitExceeded = ActivityLimitExceeded;
    var ActivityWorkerLimitExceeded = class _ActivityWorkerLimitExceeded extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "ActivityWorkerLimitExceeded");
      }
      name = "ActivityWorkerLimitExceeded";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ActivityWorkerLimitExceeded",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ActivityWorkerLimitExceeded.prototype);
      }
    };
    exports2.ActivityWorkerLimitExceeded = ActivityWorkerLimitExceeded;
    var InvalidEncryptionConfiguration = class _InvalidEncryptionConfiguration extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "InvalidEncryptionConfiguration");
      }
      name = "InvalidEncryptionConfiguration";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidEncryptionConfiguration",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidEncryptionConfiguration.prototype);
      }
    };
    exports2.InvalidEncryptionConfiguration = InvalidEncryptionConfiguration;
    var InvalidName = class _InvalidName extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "InvalidName");
      }
      name = "InvalidName";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidName",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidName.prototype);
      }
    };
    exports2.InvalidName = InvalidName;
    var KmsAccessDeniedException = class _KmsAccessDeniedException extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "KmsAccessDeniedException");
      }
      name = "KmsAccessDeniedException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "KmsAccessDeniedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _KmsAccessDeniedException.prototype);
      }
    };
    exports2.KmsAccessDeniedException = KmsAccessDeniedException;
    var KmsThrottlingException = class _KmsThrottlingException extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "KmsThrottlingException");
      }
      name = "KmsThrottlingException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "KmsThrottlingException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _KmsThrottlingException.prototype);
      }
    };
    exports2.KmsThrottlingException = KmsThrottlingException;
    var TooManyTags = class _TooManyTags extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "TooManyTags");
      }
      name = "TooManyTags";
      $fault = "client";
      resourceName;
      constructor(opts) {
        super({
          name: "TooManyTags",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyTags.prototype);
        this.resourceName = opts.resourceName;
      }
    };
    exports2.TooManyTags = TooManyTags;
    var ConflictException = class _ConflictException extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "ConflictException");
      }
      name = "ConflictException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ConflictException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ConflictException.prototype);
      }
    };
    exports2.ConflictException = ConflictException;
    var InvalidArn = class _InvalidArn extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "InvalidArn");
      }
      name = "InvalidArn";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidArn",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidArn.prototype);
      }
    };
    exports2.InvalidArn = InvalidArn;
    var InvalidDefinition = class _InvalidDefinition extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "InvalidDefinition");
      }
      name = "InvalidDefinition";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidDefinition",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidDefinition.prototype);
      }
    };
    exports2.InvalidDefinition = InvalidDefinition;
    var InvalidLoggingConfiguration = class _InvalidLoggingConfiguration extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "InvalidLoggingConfiguration");
      }
      name = "InvalidLoggingConfiguration";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidLoggingConfiguration",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidLoggingConfiguration.prototype);
      }
    };
    exports2.InvalidLoggingConfiguration = InvalidLoggingConfiguration;
    var InvalidTracingConfiguration = class _InvalidTracingConfiguration extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "InvalidTracingConfiguration");
      }
      name = "InvalidTracingConfiguration";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidTracingConfiguration",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidTracingConfiguration.prototype);
      }
    };
    exports2.InvalidTracingConfiguration = InvalidTracingConfiguration;
    var StateMachineAlreadyExists = class _StateMachineAlreadyExists extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "StateMachineAlreadyExists");
      }
      name = "StateMachineAlreadyExists";
      $fault = "client";
      constructor(opts) {
        super({
          name: "StateMachineAlreadyExists",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _StateMachineAlreadyExists.prototype);
      }
    };
    exports2.StateMachineAlreadyExists = StateMachineAlreadyExists;
    var StateMachineDeleting = class _StateMachineDeleting extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "StateMachineDeleting");
      }
      name = "StateMachineDeleting";
      $fault = "client";
      constructor(opts) {
        super({
          name: "StateMachineDeleting",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _StateMachineDeleting.prototype);
      }
    };
    exports2.StateMachineDeleting = StateMachineDeleting;
    var StateMachineLimitExceeded = class _StateMachineLimitExceeded extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "StateMachineLimitExceeded");
      }
      name = "StateMachineLimitExceeded";
      $fault = "client";
      constructor(opts) {
        super({
          name: "StateMachineLimitExceeded",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _StateMachineLimitExceeded.prototype);
      }
    };
    exports2.StateMachineLimitExceeded = StateMachineLimitExceeded;
    var StateMachineTypeNotSupported = class _StateMachineTypeNotSupported extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "StateMachineTypeNotSupported");
      }
      name = "StateMachineTypeNotSupported";
      $fault = "client";
      constructor(opts) {
        super({
          name: "StateMachineTypeNotSupported",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _StateMachineTypeNotSupported.prototype);
      }
    };
    exports2.StateMachineTypeNotSupported = StateMachineTypeNotSupported;
    var ValidationException10 = class _ValidationException extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "ValidationException");
      }
      name = "ValidationException";
      $fault = "client";
      reason;
      constructor(opts) {
        super({
          name: "ValidationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ValidationException.prototype);
        this.reason = opts.reason;
      }
    };
    exports2.ValidationException = ValidationException10;
    var ResourceNotFound = class _ResourceNotFound extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "ResourceNotFound");
      }
      name = "ResourceNotFound";
      $fault = "client";
      resourceName;
      constructor(opts) {
        super({
          name: "ResourceNotFound",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceNotFound.prototype);
        this.resourceName = opts.resourceName;
      }
    };
    exports2.ResourceNotFound = ResourceNotFound;
    var ServiceQuotaExceededException = class _ServiceQuotaExceededException extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "ServiceQuotaExceededException");
      }
      name = "ServiceQuotaExceededException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ServiceQuotaExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ServiceQuotaExceededException.prototype);
      }
    };
    exports2.ServiceQuotaExceededException = ServiceQuotaExceededException;
    var ExecutionDoesNotExist = class _ExecutionDoesNotExist extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "ExecutionDoesNotExist");
      }
      name = "ExecutionDoesNotExist";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ExecutionDoesNotExist",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ExecutionDoesNotExist.prototype);
      }
    };
    exports2.ExecutionDoesNotExist = ExecutionDoesNotExist;
    var KmsInvalidStateException = class _KmsInvalidStateException extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "KmsInvalidStateException");
      }
      name = "KmsInvalidStateException";
      $fault = "client";
      kmsKeyState;
      constructor(opts) {
        super({
          name: "KmsInvalidStateException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _KmsInvalidStateException.prototype);
        this.kmsKeyState = opts.kmsKeyState;
      }
    };
    exports2.KmsInvalidStateException = KmsInvalidStateException;
    var StateMachineDoesNotExist = class _StateMachineDoesNotExist extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "StateMachineDoesNotExist");
      }
      name = "StateMachineDoesNotExist";
      $fault = "client";
      constructor(opts) {
        super({
          name: "StateMachineDoesNotExist",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _StateMachineDoesNotExist.prototype);
      }
    };
    exports2.StateMachineDoesNotExist = StateMachineDoesNotExist;
    var InvalidToken = class _InvalidToken extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "InvalidToken");
      }
      name = "InvalidToken";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidToken",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidToken.prototype);
      }
    };
    exports2.InvalidToken = InvalidToken;
    var ExecutionLimitExceeded = class _ExecutionLimitExceeded extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "ExecutionLimitExceeded");
      }
      name = "ExecutionLimitExceeded";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ExecutionLimitExceeded",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ExecutionLimitExceeded.prototype);
      }
    };
    exports2.ExecutionLimitExceeded = ExecutionLimitExceeded;
    var ExecutionNotRedrivable = class _ExecutionNotRedrivable extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "ExecutionNotRedrivable");
      }
      name = "ExecutionNotRedrivable";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ExecutionNotRedrivable",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ExecutionNotRedrivable.prototype);
      }
    };
    exports2.ExecutionNotRedrivable = ExecutionNotRedrivable;
    var TaskDoesNotExist = class _TaskDoesNotExist extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "TaskDoesNotExist");
      }
      name = "TaskDoesNotExist";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TaskDoesNotExist",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TaskDoesNotExist.prototype);
      }
    };
    exports2.TaskDoesNotExist = TaskDoesNotExist;
    var TaskTimedOut = class _TaskTimedOut extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "TaskTimedOut");
      }
      name = "TaskTimedOut";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TaskTimedOut",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TaskTimedOut.prototype);
      }
    };
    exports2.TaskTimedOut = TaskTimedOut;
    var InvalidOutput = class _InvalidOutput extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "InvalidOutput");
      }
      name = "InvalidOutput";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidOutput",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidOutput.prototype);
      }
    };
    exports2.InvalidOutput = InvalidOutput;
    var ExecutionAlreadyExists = class _ExecutionAlreadyExists extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "ExecutionAlreadyExists");
      }
      name = "ExecutionAlreadyExists";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ExecutionAlreadyExists",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ExecutionAlreadyExists.prototype);
      }
    };
    exports2.ExecutionAlreadyExists = ExecutionAlreadyExists;
    var InvalidExecutionInput = class _InvalidExecutionInput extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "InvalidExecutionInput");
      }
      name = "InvalidExecutionInput";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidExecutionInput",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidExecutionInput.prototype);
      }
    };
    exports2.InvalidExecutionInput = InvalidExecutionInput;
    var MissingRequiredParameter = class _MissingRequiredParameter extends SFNServiceException_1.SFNServiceException {
      static {
        __name(this, "MissingRequiredParameter");
      }
      name = "MissingRequiredParameter";
      $fault = "client";
      constructor(opts) {
        super({
          name: "MissingRequiredParameter",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _MissingRequiredParameter.prototype);
      }
    };
    exports2.MissingRequiredParameter = MissingRequiredParameter;
  }
});

// ../../node_modules/@aws-sdk/client-sfn/dist-cjs/schemas/schemas_0.js
var require_schemas_018 = __commonJS({
  "../../node_modules/@aws-sdk/client-sfn/dist-cjs/schemas/schemas_0.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.CreateStateMachineAliasOutput$ = exports2.CreateStateMachineAliasInput$ = exports2.CreateActivityOutput$ = exports2.CreateActivityInput$ = exports2.CloudWatchLogsLogGroup$ = exports2.CloudWatchEventsExecutionDataDetails$ = exports2.BillingDetails$ = exports2.AssignedVariablesDetails$ = exports2.ActivityTimedOutEventDetails$ = exports2.ActivitySucceededEventDetails$ = exports2.ActivityStartedEventDetails$ = exports2.ActivityScheduleFailedEventDetails$ = exports2.ActivityScheduledEventDetails$ = exports2.ActivityListItem$ = exports2.ActivityFailedEventDetails$ = exports2.errorTypeRegistries = exports2.ValidationException$ = exports2.TooManyTags$ = exports2.TaskTimedOut$ = exports2.TaskDoesNotExist$ = exports2.StateMachineTypeNotSupported$ = exports2.StateMachineLimitExceeded$ = exports2.StateMachineDoesNotExist$ = exports2.StateMachineDeleting$ = exports2.StateMachineAlreadyExists$ = exports2.ServiceQuotaExceededException$ = exports2.ResourceNotFound$ = exports2.MissingRequiredParameter$ = exports2.KmsThrottlingException$ = exports2.KmsInvalidStateException$ = exports2.KmsAccessDeniedException$ = exports2.InvalidTracingConfiguration$ = exports2.InvalidToken$ = exports2.InvalidOutput$ = exports2.InvalidName$ = exports2.InvalidLoggingConfiguration$ = exports2.InvalidExecutionInput$ = exports2.InvalidEncryptionConfiguration$ = exports2.InvalidDefinition$ = exports2.InvalidArn$ = exports2.ExecutionNotRedrivable$ = exports2.ExecutionLimitExceeded$ = exports2.ExecutionDoesNotExist$ = exports2.ExecutionAlreadyExists$ = exports2.ConflictException$ = exports2.ActivityWorkerLimitExceeded$ = exports2.ActivityLimitExceeded$ = exports2.ActivityDoesNotExist$ = exports2.ActivityAlreadyExists$ = exports2.SFNServiceException$ = void 0;
    exports2.ListExecutionsInput$ = exports2.ListActivitiesOutput$ = exports2.ListActivitiesInput$ = exports2.LambdaFunctionTimedOutEventDetails$ = exports2.LambdaFunctionSucceededEventDetails$ = exports2.LambdaFunctionStartFailedEventDetails$ = exports2.LambdaFunctionScheduleFailedEventDetails$ = exports2.LambdaFunctionScheduledEventDetails$ = exports2.LambdaFunctionFailedEventDetails$ = exports2.InspectionErrorDetails$ = exports2.InspectionDataResponse$ = exports2.InspectionDataRequest$ = exports2.InspectionData$ = exports2.HistoryEventExecutionDataDetails$ = exports2.HistoryEvent$ = exports2.GetExecutionHistoryOutput$ = exports2.GetExecutionHistoryInput$ = exports2.GetActivityTaskOutput$ = exports2.GetActivityTaskInput$ = exports2.ExecutionTimedOutEventDetails$ = exports2.ExecutionSucceededEventDetails$ = exports2.ExecutionStartedEventDetails$ = exports2.ExecutionRedrivenEventDetails$ = exports2.ExecutionListItem$ = exports2.ExecutionFailedEventDetails$ = exports2.ExecutionAbortedEventDetails$ = exports2.EvaluationFailedEventDetails$ = exports2.EncryptionConfiguration$ = exports2.DescribeStateMachineOutput$ = exports2.DescribeStateMachineInput$ = exports2.DescribeStateMachineForExecutionOutput$ = exports2.DescribeStateMachineForExecutionInput$ = exports2.DescribeStateMachineAliasOutput$ = exports2.DescribeStateMachineAliasInput$ = exports2.DescribeMapRunOutput$ = exports2.DescribeMapRunInput$ = exports2.DescribeExecutionOutput$ = exports2.DescribeExecutionInput$ = exports2.DescribeActivityOutput$ = exports2.DescribeActivityInput$ = exports2.DeleteStateMachineVersionOutput$ = exports2.DeleteStateMachineVersionInput$ = exports2.DeleteStateMachineOutput$ = exports2.DeleteStateMachineInput$ = exports2.DeleteStateMachineAliasOutput$ = exports2.DeleteStateMachineAliasInput$ = exports2.DeleteActivityOutput$ = exports2.DeleteActivityInput$ = exports2.CreateStateMachineOutput$ = exports2.CreateStateMachineInput$ = void 0;
    exports2.TaskFailedEventDetails$ = exports2.TaskCredentials$ = exports2.TagResourceOutput$ = exports2.TagResourceInput$ = exports2.Tag$ = exports2.StopExecutionOutput$ = exports2.StopExecutionInput$ = exports2.StateMachineVersionListItem$ = exports2.StateMachineListItem$ = exports2.StateMachineAliasListItem$ = exports2.StateExitedEventDetails$ = exports2.StateEnteredEventDetails$ = exports2.StartSyncExecutionOutput$ = exports2.StartSyncExecutionInput$ = exports2.StartExecutionOutput$ = exports2.StartExecutionInput$ = exports2.SendTaskSuccessOutput$ = exports2.SendTaskSuccessInput$ = exports2.SendTaskHeartbeatOutput$ = exports2.SendTaskHeartbeatInput$ = exports2.SendTaskFailureOutput$ = exports2.SendTaskFailureInput$ = exports2.RoutingConfigurationListItem$ = exports2.RedriveExecutionOutput$ = exports2.RedriveExecutionInput$ = exports2.PublishStateMachineVersionOutput$ = exports2.PublishStateMachineVersionInput$ = exports2.MockInput$ = exports2.MockErrorOutput$ = exports2.MapStateStartedEventDetails$ = exports2.MapRunStartedEventDetails$ = exports2.MapRunRedrivenEventDetails$ = exports2.MapRunListItem$ = exports2.MapRunItemCounts$ = exports2.MapRunFailedEventDetails$ = exports2.MapRunExecutionCounts$ = exports2.MapIterationEventDetails$ = exports2.LoggingConfiguration$ = exports2.LogDestination$ = exports2.ListTagsForResourceOutput$ = exports2.ListTagsForResourceInput$ = exports2.ListStateMachineVersionsOutput$ = exports2.ListStateMachineVersionsInput$ = exports2.ListStateMachinesOutput$ = exports2.ListStateMachinesInput$ = exports2.ListStateMachineAliasesOutput$ = exports2.ListStateMachineAliasesInput$ = exports2.ListMapRunsOutput$ = exports2.ListMapRunsInput$ = exports2.ListExecutionsOutput$ = void 0;
    exports2.StartExecution$ = exports2.SendTaskSuccess$ = exports2.SendTaskHeartbeat$ = exports2.SendTaskFailure$ = exports2.RedriveExecution$ = exports2.PublishStateMachineVersion$ = exports2.ListTagsForResource$ = exports2.ListStateMachineVersions$ = exports2.ListStateMachines$ = exports2.ListStateMachineAliases$ = exports2.ListMapRuns$ = exports2.ListExecutions$ = exports2.ListActivities$ = exports2.GetExecutionHistory$ = exports2.GetActivityTask$ = exports2.DescribeStateMachineForExecution$ = exports2.DescribeStateMachineAlias$ = exports2.DescribeStateMachine$ = exports2.DescribeMapRun$ = exports2.DescribeExecution$ = exports2.DescribeActivity$ = exports2.DeleteStateMachineVersion$ = exports2.DeleteStateMachineAlias$ = exports2.DeleteStateMachine$ = exports2.DeleteActivity$ = exports2.CreateStateMachineAlias$ = exports2.CreateStateMachine$ = exports2.CreateActivity$ = exports2.ValidateStateMachineDefinitionOutput$ = exports2.ValidateStateMachineDefinitionInput$ = exports2.ValidateStateMachineDefinitionDiagnostic$ = exports2.UpdateStateMachineOutput$ = exports2.UpdateStateMachineInput$ = exports2.UpdateStateMachineAliasOutput$ = exports2.UpdateStateMachineAliasInput$ = exports2.UpdateMapRunOutput$ = exports2.UpdateMapRunInput$ = exports2.UntagResourceOutput$ = exports2.UntagResourceInput$ = exports2.TracingConfiguration$ = exports2.TestStateOutput$ = exports2.TestStateInput$ = exports2.TestStateConfiguration$ = exports2.TaskTimedOutEventDetails$ = exports2.TaskSucceededEventDetails$ = exports2.TaskSubmittedEventDetails$ = exports2.TaskSubmitFailedEventDetails$ = exports2.TaskStartFailedEventDetails$ = exports2.TaskStartedEventDetails$ = exports2.TaskScheduledEventDetails$ = void 0;
    exports2.ValidateStateMachineDefinition$ = exports2.UpdateStateMachineAlias$ = exports2.UpdateStateMachine$ = exports2.UpdateMapRun$ = exports2.UntagResource$ = exports2.TestState$ = exports2.TagResource$ = exports2.StopExecution$ = exports2.StartSyncExecution$ = void 0;
    var _AAE = "ActivityAlreadyExists";
    var _AD = "AliasDescription";
    var _ADNE = "ActivityDoesNotExist";
    var _AFED = "ActivityFailedEventDetails";
    var _AL = "ActivityList";
    var _ALE = "ActivityLimitExceeded";
    var _ALI = "ActivityListItem";
    var _ASED = "ActivityScheduledEventDetails";
    var _ASEDc = "ActivityStartedEventDetails";
    var _ASEDct = "ActivitySucceededEventDetails";
    var _ASFED = "ActivityScheduleFailedEventDetails";
    var _ATOED = "ActivityTimedOutEventDetails";
    var _AV = "AssignedVariables";
    var _AVD = "AssignedVariablesDetails";
    var _AWLE = "ActivityWorkerLimitExceeded";
    var _BD = "BillingDetails";
    var _CA10 = "CreateActivity";
    var _CAI = "CreateActivityInput";
    var _CAO = "CreateActivityOutput";
    var _CE = "ConflictException";
    var _CP = "ConnectorParameters";
    var _CSM = "CreateStateMachine";
    var _CSMA = "CreateStateMachineAlias";
    var _CSMAI = "CreateStateMachineAliasInput";
    var _CSMAO = "CreateStateMachineAliasOutput";
    var _CSMI = "CreateStateMachineInput";
    var _CSMO = "CreateStateMachineOutput";
    var _CWEEDD = "CloudWatchEventsExecutionDataDetails";
    var _CWLLG = "CloudWatchLogsLogGroup";
    var _D = "Definition";
    var _DA = "DeleteActivity";
    var _DAI = "DeleteActivityInput";
    var _DAIe = "DescribeActivityInput";
    var _DAO = "DeleteActivityOutput";
    var _DAOe = "DescribeActivityOutput";
    var _DAe = "DescribeActivity";
    var _DE = "DescribeExecution";
    var _DEI = "DescribeExecutionInput";
    var _DEO = "DescribeExecutionOutput";
    var _DMR = "DescribeMapRun";
    var _DMRI = "DescribeMapRunInput";
    var _DMRO = "DescribeMapRunOutput";
    var _DSM = "DeleteStateMachine";
    var _DSMA = "DeleteStateMachineAlias";
    var _DSMAI = "DeleteStateMachineAliasInput";
    var _DSMAIe = "DescribeStateMachineAliasInput";
    var _DSMAO = "DeleteStateMachineAliasOutput";
    var _DSMAOe = "DescribeStateMachineAliasOutput";
    var _DSMAe = "DescribeStateMachineAlias";
    var _DSMFE = "DescribeStateMachineForExecution";
    var _DSMFEI = "DescribeStateMachineForExecutionInput";
    var _DSMFEO = "DescribeStateMachineForExecutionOutput";
    var _DSMI = "DeleteStateMachineInput";
    var _DSMIe = "DescribeStateMachineInput";
    var _DSMO = "DeleteStateMachineOutput";
    var _DSMOe = "DescribeStateMachineOutput";
    var _DSMV = "DeleteStateMachineVersion";
    var _DSMVI = "DeleteStateMachineVersionInput";
    var _DSMVO = "DeleteStateMachineVersionOutput";
    var _DSMe = "DescribeStateMachine";
    var _EAE = "ExecutionAlreadyExists";
    var _EAED = "ExecutionAbortedEventDetails";
    var _EC = "EncryptionConfiguration";
    var _EDNE = "ExecutionDoesNotExist";
    var _EFED = "EvaluationFailedEventDetails";
    var _EFEDx = "ExecutionFailedEventDetails";
    var _EFL = "EvaluationFailureLocation";
    var _EHI = "ExceptionHandlerIndex";
    var _EL = "ExecutionList";
    var _ELE = "ExecutionLimitExceeded";
    var _ELI = "ExecutionListItem";
    var _ENR = "ExecutionNotRedrivable";
    var _ERED = "ExecutionRedrivenEventDetails";
    var _ESED = "ExecutionStartedEventDetails";
    var _ESEDx = "ExecutionSucceededEventDetails";
    var _ETOED = "ExecutionTimedOutEventDetails";
    var _GAT = "GetActivityTask";
    var _GATI = "GetActivityTaskInput";
    var _GATO = "GetActivityTaskOutput";
    var _GEH = "GetExecutionHistory";
    var _GEHI = "GetExecutionHistoryInput";
    var _GEHO = "GetExecutionHistoryOutput";
    var _HE = "HistoryEvent";
    var _HEEDD = "HistoryEventExecutionDataDetails";
    var _HEL = "HistoryEventList";
    var _IA = "InvalidArn";
    var _ID = "InvalidDefinition";
    var _IDR = "InspectionDataRequest";
    var _IDRn = "InspectionDataResponse";
    var _IDn = "InspectionData";
    var _IEC = "InvalidEncryptionConfiguration";
    var _IED = "InspectionErrorDetails";
    var _IEI = "InvalidExecutionInput";
    var _ILC = "InvalidLoggingConfiguration";
    var _IMC = "InspectionMaxConcurrency";
    var _IN = "InvalidName";
    var _IO = "InvalidOutput";
    var _IT4 = "InvalidToken";
    var _ITC = "InvalidTracingConfiguration";
    var _ITFC = "InspectionToleratedFailureCount";
    var _ITFP = "InspectionToleratedFailurePercentage";
    var _KADE = "KmsAccessDeniedException";
    var _KISE = "KmsInvalidStateException";
    var _KTE = "KmsThrottlingException";
    var _LA = "ListActivities";
    var _LAI = "ListActivitiesInput";
    var _LAO = "ListActivitiesOutput";
    var _LC = "LoggingConfiguration";
    var _LD = "LogDestination";
    var _LDL = "LogDestinationList";
    var _LE = "ListExecutions";
    var _LEI = "ListExecutionsInput";
    var _LEO = "ListExecutionsOutput";
    var _LFFED = "LambdaFunctionFailedEventDetails";
    var _LFSED = "LambdaFunctionScheduledEventDetails";
    var _LFSEDa = "LambdaFunctionSucceededEventDetails";
    var _LFSFED = "LambdaFunctionScheduleFailedEventDetails";
    var _LFSFEDa = "LambdaFunctionStartFailedEventDetails";
    var _LFTOED = "LambdaFunctionTimedOutEventDetails";
    var _LMR = "ListMapRuns";
    var _LMRI = "ListMapRunsInput";
    var _LMRO = "ListMapRunsOutput";
    var _LSM = "ListStateMachines";
    var _LSMA = "ListStateMachineAliases";
    var _LSMAI = "ListStateMachineAliasesInput";
    var _LSMAO = "ListStateMachineAliasesOutput";
    var _LSMI = "ListStateMachinesInput";
    var _LSMO = "ListStateMachinesOutput";
    var _LSMV = "ListStateMachineVersions";
    var _LSMVI = "ListStateMachineVersionsInput";
    var _LSMVO = "ListStateMachineVersionsOutput";
    var _LTFR = "ListTagsForResource";
    var _LTFRI = "ListTagsForResourceInput";
    var _LTFRO = "ListTagsForResourceOutput";
    var _MEO = "MockErrorOutput";
    var _MI = "MockInput";
    var _MIED = "MapIterationEventDetails";
    var _MREC = "MapRunExecutionCounts";
    var _MRFED = "MapRunFailedEventDetails";
    var _MRIC = "MapRunItemCounts";
    var _MRL = "MapRunList";
    var _MRLI = "MapRunListItem";
    var _MRP = "MissingRequiredParameter";
    var _MRRED = "MapRunRedrivenEventDetails";
    var _MRSED = "MapRunStartedEventDetails";
    var _MSSED = "MapStateStartedEventDetails";
    var _PSMV = "PublishStateMachineVersion";
    var _PSMVI = "PublishStateMachineVersionInput";
    var _PSMVO = "PublishStateMachineVersionOutput";
    var _RBIS = "RetryBackoffIntervalSeconds";
    var _RCL = "RoutingConfigurationList";
    var _RCLI = "RoutingConfigurationListItem";
    var _RE = "RedriveExecution";
    var _REI = "RedriveExecutionInput";
    var _REO = "RedriveExecutionOutput";
    var _RNF = "ResourceNotFound";
    var _SC = "SensitiveCause";
    var _SD = "SensitiveData";
    var _SDJI = "SensitiveDataJobInput";
    var _SE = "SensitiveError";
    var _SEED = "StateEnteredEventDetails";
    var _SEEDt = "StateExitedEventDetails";
    var _SEI = "StartExecutionInput";
    var _SEIt = "StopExecutionInput";
    var _SEO = "StartExecutionOutput";
    var _SEOt = "StopExecutionOutput";
    var _SEt = "StartExecution";
    var _SEto = "StopExecution";
    var _SMAE = "StateMachineAlreadyExists";
    var _SMAL = "StateMachineAliasList";
    var _SMALI = "StateMachineAliasListItem";
    var _SMD = "StateMachineDeleting";
    var _SMDNE = "StateMachineDoesNotExist";
    var _SML = "StateMachineList";
    var _SMLE = "StateMachineLimitExceeded";
    var _SMLI = "StateMachineListItem";
    var _SMTNS = "StateMachineTypeNotSupported";
    var _SMVL = "StateMachineVersionList";
    var _SMVLI = "StateMachineVersionListItem";
    var _SQEE = "ServiceQuotaExceededException";
    var _SSE = "StartSyncExecution";
    var _SSEI = "StartSyncExecutionInput";
    var _SSEO = "StartSyncExecutionOutput";
    var _STF = "SendTaskFailure";
    var _STFI = "SendTaskFailureInput";
    var _STFO = "SendTaskFailureOutput";
    var _STH = "SendTaskHeartbeat";
    var _STHI = "SendTaskHeartbeatInput";
    var _STHO = "SendTaskHeartbeatOutput";
    var _STS = "SendTaskSuccess";
    var _STSI = "SendTaskSuccessInput";
    var _STSO = "SendTaskSuccessOutput";
    var _T10 = "Tag";
    var _TC10 = "TaskCredentials";
    var _TCr = "TracingConfiguration";
    var _TDNE = "TaskDoesNotExist";
    var _TFED = "TaskFailedEventDetails";
    var _TL = "TagList";
    var _TMT = "TooManyTags";
    var _TR = "TagResource";
    var _TRI = "TagResourceInput";
    var _TRO = "TagResourceOutput";
    var _TS = "TestState";
    var _TSC = "TestStateConfiguration";
    var _TSED = "TaskScheduledEventDetails";
    var _TSEDa = "TaskStartedEventDetails";
    var _TSEDas = "TaskSubmittedEventDetails";
    var _TSEDask = "TaskSucceededEventDetails";
    var _TSFED = "TaskStartFailedEventDetails";
    var _TSFEDa = "TaskSubmitFailedEventDetails";
    var _TSI = "TestStateInput";
    var _TSO = "TestStateOutput";
    var _TSSN = "TestStateStateName";
    var _TTO = "TaskTimedOut";
    var _TTOED = "TaskTimedOutEventDetails";
    var _UMR = "UpdateMapRun";
    var _UMRI = "UpdateMapRunInput";
    var _UMRO = "UpdateMapRunOutput";
    var _UR = "UntagResource";
    var _URI = "UntagResourceInput";
    var _URO = "UntagResourceOutput";
    var _USM = "UpdateStateMachine";
    var _USMA = "UpdateStateMachineAlias";
    var _USMAI = "UpdateStateMachineAliasInput";
    var _USMAO = "UpdateStateMachineAliasOutput";
    var _USMI = "UpdateStateMachineInput";
    var _USMO = "UpdateStateMachineOutput";
    var _VD = "VersionDescription";
    var _VE10 = "ValidationException";
    var _VN = "VariableName";
    var _VNL = "VariableNameList";
    var _VR = "VariableReferences";
    var _VSMD = "ValidateStateMachineDefinition";
    var _VSMDC = "ValidateStateMachineDefinitionCode";
    var _VSMDD = "ValidateStateMachineDefinitionDiagnostic";
    var _VSMDDL = "ValidateStateMachineDefinitionDiagnosticList";
    var _VSMDI = "ValidateStateMachineDefinitionInput";
    var _VSMDL = "ValidateStateMachineDefinitionLocation";
    var _VSMDM = "ValidateStateMachineDefinitionMessage";
    var _VSMDO = "ValidateStateMachineDefinitionOutput";
    var _VV = "VariableValue";
    var _a10 = "activities";
    var _aA = "activityArn";
    var _aAf = "afterArguments";
    var _aFED = "activityFailedEventDetails";
    var _aIB = "afterItemBatcher";
    var _aIP = "afterInputPath";
    var _aIPf = "afterItemsPath";
    var _aIPft = "afterItemsPointer";
    var _aIS = "afterItemSelector";
    var _aP = "afterParameters";
    var _aRP = "afterResultPath";
    var _aRS = "afterResultSelector";
    var _aSED = "activityScheduledEventDetails";
    var _aSEDc = "activityStartedEventDetails";
    var _aSEDct = "activitySucceededEventDetails";
    var _aSFED = "activityScheduleFailedEventDetails";
    var _aTOED = "activityTimedOutEventDetails";
    var _aV = "assignedVariables";
    var _aVD = "assignedVariablesDetails";
    var _ab = "aborted";
    var _b = "body";
    var _bD = "billingDetails";
    var _bDIM = "billedDurationInMilliseconds";
    var _bMUIMB = "billedMemoryUsedInMB";
    var _c32 = "client";
    var _cD = "creationDate";
    var _cI13 = "catchIndex";
    var _cT = "clientToken";
    var _cWLLG = "cloudWatchLogsLogGroup";
    var _ca = "cause";
    var _co13 = "context";
    var _cod = "code";
    var _d = "description";
    var _de = "definition";
    var _des = "destinations";
    var _di = "diagnostics";
    var _e32 = "error";
    var _eA = "executionArn";
    var _eAED = "executionAbortedEventDetails";
    var _eC = "encryptionConfiguration";
    var _eCBS = "errorCausedByState";
    var _eCx = "executionCounts";
    var _eD = "errorDetails";
    var _eFED = "executionFailedEventDetails";
    var _eFEDv = "evaluationFailedEventDetails";
    var _eO = "errorOutput";
    var _eRED = "executionRedrivenEventDetails";
    var _eSED = "executionStartedEventDetails";
    var _eSEDx = "executionSucceededEventDetails";
    var _eTOED = "executionTimedOutEventDetails";
    var _en = "enabled";
    var _end = "endpoint";
    var _ev = "events";
    var _ex10 = "executions";
    var _f = "failed";
    var _fNR = "failuresNotRedrivable";
    var _fVM = "fieldValidationMode";
    var _h22 = "headers";
    var _hE32 = "httpError";
    var _hIS = "heartbeatInSeconds";
    var _i = "input";
    var _iC = "itemCounts";
    var _iCt = "itemCount";
    var _iD = "inputDetails";
    var _iDn = "includedData";
    var _iDns = "inspectionData";
    var _iED = "includeExecutionData";
    var _iL = "inspectionLevel";
    var _id = "id";
    var _in = "included";
    var _ind = "index";
    var _k = "key";
    var _kDKRPS = "kmsDataKeyReusePeriodSeconds";
    var _kKI = "kmsKeyId";
    var _kKS = "kmsKeyState";
    var _l = "label";
    var _lC = "loggingConfiguration";
    var _lFFED = "lambdaFunctionFailedEventDetails";
    var _lFSED = "lambdaFunctionScheduledEventDetails";
    var _lFSEDa = "lambdaFunctionSucceededEventDetails";
    var _lFSFED = "lambdaFunctionScheduleFailedEventDetails";
    var _lFSFEDa = "lambdaFunctionStartFailedEventDetails";
    var _lFTOED = "lambdaFunctionTimedOutEventDetails";
    var _lGA = "logGroupArn";
    var _le = "level";
    var _len = "length";
    var _lo = "location";
    var _m29 = "message";
    var _mC = "maxConcurrency";
    var _mIAED = "mapIterationAbortedEventDetails";
    var _mIFC = "mapIterationFailureCount";
    var _mIFED = "mapIterationFailedEventDetails";
    var _mIRD = "mapItemReaderData";
    var _mISED = "mapIterationStartedEventDetails";
    var _mISEDa = "mapIterationSucceededEventDetails";
    var _mR = "maxResults";
    var _mRA = "mapRunArn";
    var _mRFED = "mapRunFailedEventDetails";
    var _mRRED = "mapRunRedrivenEventDetails";
    var _mRSED = "mapRunStartedEventDetails";
    var _mRa = "mapRuns";
    var _mSSED = "mapStateStartedEventDetails";
    var _me = "method";
    var _mo = "mock";
    var _n = "name";
    var _nS = "nextState";
    var _nT = "nextToken";
    var _o = "output";
    var _oD = "outputDetails";
    var _p = "publish";
    var _pEI = "previousEventId";
    var _pR = "pendingRedrive";
    var _pa = "parameters";
    var _pe = "pending";
    var _pr = "protocol";
    var _r4 = "reason";
    var _rA = "roleArn";
    var _rAe = "resourceArn";
    var _rBIS = "retryBackoffIntervalSeconds";
    var _rC10 = "routingConfiguration";
    var _rCe = "redriveCount";
    var _rD = "redriveDate";
    var _rF = "redriveFilter";
    var _rI = "revisionId";
    var _rIe = "retryIndex";
    var _rN10 = "resourceName";
    var _rO = "reverseOrder";
    var _rRC = "retrierRetryCount";
    var _rS = "redriveStatus";
    var _rSR = "redriveStatusReason";
    var _rSe = "revealSecrets";
    var _rT13 = "resourceType";
    var _rW = "resultsWritten";
    var _re = "resource";
    var _reg = "region";
    var _req = "request";
    var _res = "result";
    var _resp = "response";
    var _ru = "running";
    var _s32 = "smithy.ts.sdk.synthetic.com.amazonaws.sfn";
    var _sC = "statusCode";
    var _sCt = "stateConfiguration";
    var _sD = "startDate";
    var _sDt = "stopDate";
    var _sEED = "stateEnteredEventDetails";
    var _sEEDt = "stateExitedEventDetails";
    var _sF = "statusFilter";
    var _sM = "statusMessage";
    var _sMA = "stateMachineArn";
    var _sMAA = "stateMachineAliasArn";
    var _sMAt = "stateMachineAliases";
    var _sMV = "stateMachineVersions";
    var _sMVA = "stateMachineVersionArn";
    var _sMt = "stateMachines";
    var _sN = "stateName";
    var _se14 = "severity";
    var _st = "status";
    var _sta = "state";
    var _su = "succeeded";
    var _t = "truncated";
    var _tC = "tracingConfiguration";
    var _tCa = "taskCredentials";
    var _tFC = "toleratedFailureCount";
    var _tFED = "taskFailedEventDetails";
    var _tFP = "toleratedFailurePercentage";
    var _tH = "traceHeader";
    var _tIS = "timeoutInSeconds";
    var _tK = "tagKeys";
    var _tO10 = "timedOut";
    var _tSED = "taskScheduledEventDetails";
    var _tSEDa = "taskStartedEventDetails";
    var _tSEDas = "taskSubmittedEventDetails";
    var _tSEDask = "taskSucceededEventDetails";
    var _tSFED = "taskStartFailedEventDetails";
    var _tSFEDa = "taskSubmitFailedEventDetails";
    var _tT13 = "taskToken";
    var _tTOED = "taskTimedOutEventDetails";
    var _ta = "tags";
    var _ti = "timestamp";
    var _to = "total";
    var _ty = "type";
    var _u = "url";
    var _uD = "updateDate";
    var _v = "variables";
    var _vD = "versionDescription";
    var _vR = "variableReferences";
    var _va = "value";
    var _w = "weight";
    var _wN = "workerName";
    var n032 = "com.amazonaws.sfn";
    var schema_1 = (init_schema4(), __toCommonJS(schema_exports));
    var errors_1 = require_errors17();
    var SFNServiceException_1 = require_SFNServiceException();
    var _s_registry32 = schema_1.TypeRegistry.for(_s32);
    exports2.SFNServiceException$ = [-3, _s32, "SFNServiceException", 0, [], []];
    _s_registry32.registerError(exports2.SFNServiceException$, SFNServiceException_1.SFNServiceException);
    var n0_registry32 = schema_1.TypeRegistry.for(n032);
    exports2.ActivityAlreadyExists$ = [
      -3,
      n032,
      _AAE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ActivityAlreadyExists$, errors_1.ActivityAlreadyExists);
    exports2.ActivityDoesNotExist$ = [
      -3,
      n032,
      _ADNE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ActivityDoesNotExist$, errors_1.ActivityDoesNotExist);
    exports2.ActivityLimitExceeded$ = [
      -3,
      n032,
      _ALE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ActivityLimitExceeded$, errors_1.ActivityLimitExceeded);
    exports2.ActivityWorkerLimitExceeded$ = [
      -3,
      n032,
      _AWLE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ActivityWorkerLimitExceeded$, errors_1.ActivityWorkerLimitExceeded);
    exports2.ConflictException$ = [
      -3,
      n032,
      _CE,
      { [_e32]: _c32, [_hE32]: 409 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ConflictException$, errors_1.ConflictException);
    exports2.ExecutionAlreadyExists$ = [
      -3,
      n032,
      _EAE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ExecutionAlreadyExists$, errors_1.ExecutionAlreadyExists);
    exports2.ExecutionDoesNotExist$ = [
      -3,
      n032,
      _EDNE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ExecutionDoesNotExist$, errors_1.ExecutionDoesNotExist);
    exports2.ExecutionLimitExceeded$ = [
      -3,
      n032,
      _ELE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ExecutionLimitExceeded$, errors_1.ExecutionLimitExceeded);
    exports2.ExecutionNotRedrivable$ = [
      -3,
      n032,
      _ENR,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ExecutionNotRedrivable$, errors_1.ExecutionNotRedrivable);
    exports2.InvalidArn$ = [
      -3,
      n032,
      _IA,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidArn$, errors_1.InvalidArn);
    exports2.InvalidDefinition$ = [
      -3,
      n032,
      _ID,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidDefinition$, errors_1.InvalidDefinition);
    exports2.InvalidEncryptionConfiguration$ = [
      -3,
      n032,
      _IEC,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidEncryptionConfiguration$, errors_1.InvalidEncryptionConfiguration);
    exports2.InvalidExecutionInput$ = [
      -3,
      n032,
      _IEI,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidExecutionInput$, errors_1.InvalidExecutionInput);
    exports2.InvalidLoggingConfiguration$ = [
      -3,
      n032,
      _ILC,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidLoggingConfiguration$, errors_1.InvalidLoggingConfiguration);
    exports2.InvalidName$ = [
      -3,
      n032,
      _IN,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidName$, errors_1.InvalidName);
    exports2.InvalidOutput$ = [
      -3,
      n032,
      _IO,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidOutput$, errors_1.InvalidOutput);
    exports2.InvalidToken$ = [
      -3,
      n032,
      _IT4,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidToken$, errors_1.InvalidToken);
    exports2.InvalidTracingConfiguration$ = [
      -3,
      n032,
      _ITC,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidTracingConfiguration$, errors_1.InvalidTracingConfiguration);
    exports2.KmsAccessDeniedException$ = [
      -3,
      n032,
      _KADE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.KmsAccessDeniedException$, errors_1.KmsAccessDeniedException);
    exports2.KmsInvalidStateException$ = [
      -3,
      n032,
      _KISE,
      { [_e32]: _c32 },
      [_kKS, _m29],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.KmsInvalidStateException$, errors_1.KmsInvalidStateException);
    exports2.KmsThrottlingException$ = [
      -3,
      n032,
      _KTE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.KmsThrottlingException$, errors_1.KmsThrottlingException);
    exports2.MissingRequiredParameter$ = [
      -3,
      n032,
      _MRP,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.MissingRequiredParameter$, errors_1.MissingRequiredParameter);
    exports2.ResourceNotFound$ = [
      -3,
      n032,
      _RNF,
      { [_e32]: _c32, [_hE32]: 404 },
      [_m29, _rN10],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.ResourceNotFound$, errors_1.ResourceNotFound);
    exports2.ServiceQuotaExceededException$ = [
      -3,
      n032,
      _SQEE,
      { [_e32]: _c32, [_hE32]: 402 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ServiceQuotaExceededException$, errors_1.ServiceQuotaExceededException);
    exports2.StateMachineAlreadyExists$ = [
      -3,
      n032,
      _SMAE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.StateMachineAlreadyExists$, errors_1.StateMachineAlreadyExists);
    exports2.StateMachineDeleting$ = [
      -3,
      n032,
      _SMD,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.StateMachineDeleting$, errors_1.StateMachineDeleting);
    exports2.StateMachineDoesNotExist$ = [
      -3,
      n032,
      _SMDNE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.StateMachineDoesNotExist$, errors_1.StateMachineDoesNotExist);
    exports2.StateMachineLimitExceeded$ = [
      -3,
      n032,
      _SMLE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.StateMachineLimitExceeded$, errors_1.StateMachineLimitExceeded);
    exports2.StateMachineTypeNotSupported$ = [
      -3,
      n032,
      _SMTNS,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.StateMachineTypeNotSupported$, errors_1.StateMachineTypeNotSupported);
    exports2.TaskDoesNotExist$ = [
      -3,
      n032,
      _TDNE,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.TaskDoesNotExist$, errors_1.TaskDoesNotExist);
    exports2.TaskTimedOut$ = [
      -3,
      n032,
      _TTO,
      { [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.TaskTimedOut$, errors_1.TaskTimedOut);
    exports2.TooManyTags$ = [
      -3,
      n032,
      _TMT,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29, _rN10],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.TooManyTags$, errors_1.TooManyTags);
    exports2.ValidationException$ = [
      -3,
      n032,
      _VE10,
      { [_e32]: _c32, [_hE32]: 400 },
      [_m29, _r4],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.ValidationException$, errors_1.ValidationException);
    exports2.errorTypeRegistries = [
      _s_registry32,
      n0_registry32
    ];
    var AliasDescription = [0, n032, _AD, 8, 0];
    var ConnectorParameters = [0, n032, _CP, 8, 0];
    var Definition = [0, n032, _D, 8, 0];
    var EvaluationFailureLocation = [0, n032, _EFL, 8, 0];
    var ExceptionHandlerIndex = [0, n032, _EHI, 8, 1];
    var InspectionMaxConcurrency = [0, n032, _IMC, 8, 1];
    var InspectionToleratedFailureCount = [0, n032, _ITFC, 8, 1];
    var InspectionToleratedFailurePercentage = [0, n032, _ITFP, 8, 1];
    var RetryBackoffIntervalSeconds = [0, n032, _RBIS, 8, 1];
    var SensitiveCause = [0, n032, _SC, 8, 0];
    var SensitiveData = [0, n032, _SD, 8, 0];
    var SensitiveDataJobInput = [0, n032, _SDJI, 8, 0];
    var SensitiveError = [0, n032, _SE, 8, 0];
    var TestStateStateName = [0, n032, _TSSN, 8, 0];
    var ValidateStateMachineDefinitionCode = [0, n032, _VSMDC, 8, 0];
    var ValidateStateMachineDefinitionLocation = [0, n032, _VSMDL, 8, 0];
    var ValidateStateMachineDefinitionMessage = [0, n032, _VSMDM, 8, 0];
    var VariableName = [0, n032, _VN, 8, 0];
    var VariableValue = [0, n032, _VV, 8, 0];
    var VersionDescription = [0, n032, _VD, 8, 0];
    exports2.ActivityFailedEventDetails$ = [
      3,
      n032,
      _AFED,
      0,
      [_e32, _ca],
      [[() => SensitiveError, 0], [() => SensitiveCause, 0]]
    ];
    exports2.ActivityListItem$ = [
      3,
      n032,
      _ALI,
      0,
      [_aA, _n, _cD],
      [0, 0, 4],
      3
    ];
    exports2.ActivityScheduledEventDetails$ = [
      3,
      n032,
      _ASED,
      0,
      [_re, _i, _iD, _tIS, _hIS],
      [0, [() => SensitiveData, 0], () => exports2.HistoryEventExecutionDataDetails$, 1, 1],
      1
    ];
    exports2.ActivityScheduleFailedEventDetails$ = [
      3,
      n032,
      _ASFED,
      0,
      [_e32, _ca],
      [[() => SensitiveError, 0], [() => SensitiveCause, 0]]
    ];
    exports2.ActivityStartedEventDetails$ = [
      3,
      n032,
      _ASEDc,
      0,
      [_wN],
      [0]
    ];
    exports2.ActivitySucceededEventDetails$ = [
      3,
      n032,
      _ASEDct,
      0,
      [_o, _oD],
      [[() => SensitiveData, 0], () => exports2.HistoryEventExecutionDataDetails$]
    ];
    exports2.ActivityTimedOutEventDetails$ = [
      3,
      n032,
      _ATOED,
      0,
      [_e32, _ca],
      [[() => SensitiveError, 0], [() => SensitiveCause, 0]]
    ];
    exports2.AssignedVariablesDetails$ = [
      3,
      n032,
      _AVD,
      0,
      [_t],
      [2]
    ];
    exports2.BillingDetails$ = [
      3,
      n032,
      _BD,
      0,
      [_bMUIMB, _bDIM],
      [1, 1]
    ];
    exports2.CloudWatchEventsExecutionDataDetails$ = [
      3,
      n032,
      _CWEEDD,
      0,
      [_in],
      [2]
    ];
    exports2.CloudWatchLogsLogGroup$ = [
      3,
      n032,
      _CWLLG,
      0,
      [_lGA],
      [0]
    ];
    exports2.CreateActivityInput$ = [
      3,
      n032,
      _CAI,
      0,
      [_n, _ta, _eC],
      [0, () => TagList, () => exports2.EncryptionConfiguration$],
      1
    ];
    exports2.CreateActivityOutput$ = [
      3,
      n032,
      _CAO,
      0,
      [_aA, _cD],
      [0, 4],
      2
    ];
    exports2.CreateStateMachineAliasInput$ = [
      3,
      n032,
      _CSMAI,
      0,
      [_n, _rC10, _d],
      [0, () => RoutingConfigurationList, [() => AliasDescription, 0]],
      2
    ];
    exports2.CreateStateMachineAliasOutput$ = [
      3,
      n032,
      _CSMAO,
      0,
      [_sMAA, _cD],
      [0, 4],
      2
    ];
    exports2.CreateStateMachineInput$ = [
      3,
      n032,
      _CSMI,
      0,
      [_n, _de, _rA, _ty, _lC, _ta, _tC, _p, _vD, _eC],
      [0, [() => Definition, 0], 0, 0, () => exports2.LoggingConfiguration$, () => TagList, () => exports2.TracingConfiguration$, 2, [() => VersionDescription, 0], () => exports2.EncryptionConfiguration$],
      3
    ];
    exports2.CreateStateMachineOutput$ = [
      3,
      n032,
      _CSMO,
      0,
      [_sMA, _cD, _sMVA],
      [0, 4, 0],
      2
    ];
    exports2.DeleteActivityInput$ = [
      3,
      n032,
      _DAI,
      0,
      [_aA],
      [0],
      1
    ];
    exports2.DeleteActivityOutput$ = [
      3,
      n032,
      _DAO,
      0,
      [],
      []
    ];
    exports2.DeleteStateMachineAliasInput$ = [
      3,
      n032,
      _DSMAI,
      0,
      [_sMAA],
      [0],
      1
    ];
    exports2.DeleteStateMachineAliasOutput$ = [
      3,
      n032,
      _DSMAO,
      0,
      [],
      []
    ];
    exports2.DeleteStateMachineInput$ = [
      3,
      n032,
      _DSMI,
      0,
      [_sMA],
      [0],
      1
    ];
    exports2.DeleteStateMachineOutput$ = [
      3,
      n032,
      _DSMO,
      0,
      [],
      []
    ];
    exports2.DeleteStateMachineVersionInput$ = [
      3,
      n032,
      _DSMVI,
      0,
      [_sMVA],
      [0],
      1
    ];
    exports2.DeleteStateMachineVersionOutput$ = [
      3,
      n032,
      _DSMVO,
      0,
      [],
      []
    ];
    exports2.DescribeActivityInput$ = [
      3,
      n032,
      _DAIe,
      0,
      [_aA],
      [0],
      1
    ];
    exports2.DescribeActivityOutput$ = [
      3,
      n032,
      _DAOe,
      0,
      [_aA, _n, _cD, _eC],
      [0, 0, 4, () => exports2.EncryptionConfiguration$],
      3
    ];
    exports2.DescribeExecutionInput$ = [
      3,
      n032,
      _DEI,
      0,
      [_eA, _iDn],
      [0, 0],
      1
    ];
    exports2.DescribeExecutionOutput$ = [
      3,
      n032,
      _DEO,
      0,
      [_eA, _sMA, _st, _sD, _n, _sDt, _i, _iD, _o, _oD, _tH, _mRA, _e32, _ca, _sMVA, _sMAA, _rCe, _rD, _rS, _rSR],
      [0, 0, 0, 4, 0, 4, [() => SensitiveData, 0], () => exports2.CloudWatchEventsExecutionDataDetails$, [() => SensitiveData, 0], () => exports2.CloudWatchEventsExecutionDataDetails$, 0, 0, [() => SensitiveError, 0], [() => SensitiveCause, 0], 0, 0, 1, 4, 0, [() => SensitiveData, 0]],
      4
    ];
    exports2.DescribeMapRunInput$ = [
      3,
      n032,
      _DMRI,
      0,
      [_mRA],
      [0],
      1
    ];
    exports2.DescribeMapRunOutput$ = [
      3,
      n032,
      _DMRO,
      0,
      [_mRA, _eA, _st, _sD, _mC, _tFP, _tFC, _iC, _eCx, _sDt, _rCe, _rD],
      [0, 0, 0, 4, 1, 1, 1, () => exports2.MapRunItemCounts$, () => exports2.MapRunExecutionCounts$, 4, 1, 4],
      9
    ];
    exports2.DescribeStateMachineAliasInput$ = [
      3,
      n032,
      _DSMAIe,
      0,
      [_sMAA],
      [0],
      1
    ];
    exports2.DescribeStateMachineAliasOutput$ = [
      3,
      n032,
      _DSMAOe,
      0,
      [_sMAA, _n, _d, _rC10, _cD, _uD],
      [0, 0, [() => AliasDescription, 0], () => RoutingConfigurationList, 4, 4]
    ];
    exports2.DescribeStateMachineForExecutionInput$ = [
      3,
      n032,
      _DSMFEI,
      0,
      [_eA, _iDn],
      [0, 0],
      1
    ];
    exports2.DescribeStateMachineForExecutionOutput$ = [
      3,
      n032,
      _DSMFEO,
      0,
      [_sMA, _n, _de, _rA, _uD, _lC, _tC, _mRA, _l, _rI, _eC, _vR],
      [0, 0, [() => Definition, 0], 0, 4, () => exports2.LoggingConfiguration$, () => exports2.TracingConfiguration$, 0, 0, 0, () => exports2.EncryptionConfiguration$, [() => VariableReferences, 0]],
      5
    ];
    exports2.DescribeStateMachineInput$ = [
      3,
      n032,
      _DSMIe,
      0,
      [_sMA, _iDn],
      [0, 0],
      1
    ];
    exports2.DescribeStateMachineOutput$ = [
      3,
      n032,
      _DSMOe,
      0,
      [_sMA, _n, _de, _rA, _ty, _cD, _st, _lC, _tC, _l, _rI, _d, _eC, _vR],
      [0, 0, [() => Definition, 0], 0, 0, 4, 0, () => exports2.LoggingConfiguration$, () => exports2.TracingConfiguration$, 0, 0, [() => VersionDescription, 0], () => exports2.EncryptionConfiguration$, [() => VariableReferences, 0]],
      6
    ];
    exports2.EncryptionConfiguration$ = [
      3,
      n032,
      _EC,
      0,
      [_ty, _kKI, _kDKRPS],
      [0, 0, 1],
      1
    ];
    exports2.EvaluationFailedEventDetails$ = [
      3,
      n032,
      _EFED,
      0,
      [_sta, _e32, _ca, _lo],
      [0, [() => SensitiveError, 0], [() => SensitiveCause, 0], [() => EvaluationFailureLocation, 0]],
      1
    ];
    exports2.ExecutionAbortedEventDetails$ = [
      3,
      n032,
      _EAED,
      0,
      [_e32, _ca],
      [[() => SensitiveError, 0], [() => SensitiveCause, 0]]
    ];
    exports2.ExecutionFailedEventDetails$ = [
      3,
      n032,
      _EFEDx,
      0,
      [_e32, _ca],
      [[() => SensitiveError, 0], [() => SensitiveCause, 0]]
    ];
    exports2.ExecutionListItem$ = [
      3,
      n032,
      _ELI,
      0,
      [_eA, _sMA, _n, _st, _sD, _sDt, _mRA, _iCt, _sMVA, _sMAA, _rCe, _rD],
      [0, 0, 0, 0, 4, 4, 0, 1, 0, 0, 1, 4],
      5
    ];
    exports2.ExecutionRedrivenEventDetails$ = [
      3,
      n032,
      _ERED,
      0,
      [_rCe],
      [1]
    ];
    exports2.ExecutionStartedEventDetails$ = [
      3,
      n032,
      _ESED,
      0,
      [_i, _iD, _rA, _sMAA, _sMVA],
      [[() => SensitiveData, 0], () => exports2.HistoryEventExecutionDataDetails$, 0, 0, 0]
    ];
    exports2.ExecutionSucceededEventDetails$ = [
      3,
      n032,
      _ESEDx,
      0,
      [_o, _oD],
      [[() => SensitiveData, 0], () => exports2.HistoryEventExecutionDataDetails$]
    ];
    exports2.ExecutionTimedOutEventDetails$ = [
      3,
      n032,
      _ETOED,
      0,
      [_e32, _ca],
      [[() => SensitiveError, 0], [() => SensitiveCause, 0]]
    ];
    exports2.GetActivityTaskInput$ = [
      3,
      n032,
      _GATI,
      0,
      [_aA, _wN],
      [0, 0],
      1
    ];
    exports2.GetActivityTaskOutput$ = [
      3,
      n032,
      _GATO,
      0,
      [_tT13, _i],
      [0, [() => SensitiveDataJobInput, 0]]
    ];
    exports2.GetExecutionHistoryInput$ = [
      3,
      n032,
      _GEHI,
      0,
      [_eA, _mR, _rO, _nT, _iED],
      [0, 1, 2, 0, 2],
      1
    ];
    exports2.GetExecutionHistoryOutput$ = [
      3,
      n032,
      _GEHO,
      0,
      [_ev, _nT],
      [[() => HistoryEventList, 0], 0],
      1
    ];
    exports2.HistoryEvent$ = [
      3,
      n032,
      _HE,
      0,
      [_ti, _ty, _id, _pEI, _aFED, _aSFED, _aSED, _aSEDc, _aSEDct, _aTOED, _tFED, _tSED, _tSFED, _tSEDa, _tSFEDa, _tSEDas, _tSEDask, _tTOED, _eFED, _eSED, _eSEDx, _eAED, _eTOED, _eRED, _mSSED, _mISED, _mISEDa, _mIFED, _mIAED, _lFFED, _lFSFED, _lFSED, _lFSFEDa, _lFSEDa, _lFTOED, _sEED, _sEEDt, _mRSED, _mRFED, _mRRED, _eFEDv],
      [4, 0, 1, 1, [() => exports2.ActivityFailedEventDetails$, 0], [() => exports2.ActivityScheduleFailedEventDetails$, 0], [() => exports2.ActivityScheduledEventDetails$, 0], () => exports2.ActivityStartedEventDetails$, [() => exports2.ActivitySucceededEventDetails$, 0], [() => exports2.ActivityTimedOutEventDetails$, 0], [() => exports2.TaskFailedEventDetails$, 0], [() => exports2.TaskScheduledEventDetails$, 0], [() => exports2.TaskStartFailedEventDetails$, 0], () => exports2.TaskStartedEventDetails$, [() => exports2.TaskSubmitFailedEventDetails$, 0], [() => exports2.TaskSubmittedEventDetails$, 0], [() => exports2.TaskSucceededEventDetails$, 0], [() => exports2.TaskTimedOutEventDetails$, 0], [() => exports2.ExecutionFailedEventDetails$, 0], [() => exports2.ExecutionStartedEventDetails$, 0], [() => exports2.ExecutionSucceededEventDetails$, 0], [() => exports2.ExecutionAbortedEventDetails$, 0], [() => exports2.ExecutionTimedOutEventDetails$, 0], () => exports2.ExecutionRedrivenEventDetails$, () => exports2.MapStateStartedEventDetails$, () => exports2.MapIterationEventDetails$, () => exports2.MapIterationEventDetails$, () => exports2.MapIterationEventDetails$, () => exports2.MapIterationEventDetails$, [() => exports2.LambdaFunctionFailedEventDetails$, 0], [() => exports2.LambdaFunctionScheduleFailedEventDetails$, 0], [() => exports2.LambdaFunctionScheduledEventDetails$, 0], [() => exports2.LambdaFunctionStartFailedEventDetails$, 0], [() => exports2.LambdaFunctionSucceededEventDetails$, 0], [() => exports2.LambdaFunctionTimedOutEventDetails$, 0], [() => exports2.StateEnteredEventDetails$, 0], [() => exports2.StateExitedEventDetails$, 0], () => exports2.MapRunStartedEventDetails$, [() => exports2.MapRunFailedEventDetails$, 0], () => exports2.MapRunRedrivenEventDetails$, [() => exports2.EvaluationFailedEventDetails$, 0]],
      3
    ];
    exports2.HistoryEventExecutionDataDetails$ = [
      3,
      n032,
      _HEEDD,
      0,
      [_t],
      [2]
    ];
    exports2.InspectionData$ = [
      3,
      n032,
      _IDn,
      8,
      [_i, _aAf, _aIP, _aP, _res, _aRS, _aRP, _req, _resp, _v, _eD, _aIPf, _aIS, _aIB, _aIPft, _tFC, _tFP, _mC],
      [[() => SensitiveData, 0], [() => SensitiveData, 0], [() => SensitiveData, 0], [() => SensitiveData, 0], [() => SensitiveData, 0], [() => SensitiveData, 0], [() => SensitiveData, 0], () => exports2.InspectionDataRequest$, () => exports2.InspectionDataResponse$, [() => SensitiveData, 0], [() => exports2.InspectionErrorDetails$, 0], [() => SensitiveData, 0], [() => SensitiveData, 0], [() => SensitiveData, 0], [() => SensitiveData, 0], [() => InspectionToleratedFailureCount, 0], [() => InspectionToleratedFailurePercentage, 0], [() => InspectionMaxConcurrency, 0]]
    ];
    exports2.InspectionDataRequest$ = [
      3,
      n032,
      _IDR,
      0,
      [_pr, _me, _u, _h22, _b],
      [0, 0, 0, 0, 0]
    ];
    exports2.InspectionDataResponse$ = [
      3,
      n032,
      _IDRn,
      0,
      [_pr, _sC, _sM, _h22, _b],
      [0, 0, 0, 0, 0]
    ];
    exports2.InspectionErrorDetails$ = [
      3,
      n032,
      _IED,
      0,
      [_cI13, _rIe, _rBIS],
      [[() => ExceptionHandlerIndex, 0], [() => ExceptionHandlerIndex, 0], [() => RetryBackoffIntervalSeconds, 0]]
    ];
    exports2.LambdaFunctionFailedEventDetails$ = [
      3,
      n032,
      _LFFED,
      0,
      [_e32, _ca],
      [[() => SensitiveError, 0], [() => SensitiveCause, 0]]
    ];
    exports2.LambdaFunctionScheduledEventDetails$ = [
      3,
      n032,
      _LFSED,
      0,
      [_re, _i, _iD, _tIS, _tCa],
      [0, [() => SensitiveData, 0], () => exports2.HistoryEventExecutionDataDetails$, 1, () => exports2.TaskCredentials$],
      1
    ];
    exports2.LambdaFunctionScheduleFailedEventDetails$ = [
      3,
      n032,
      _LFSFED,
      0,
      [_e32, _ca],
      [[() => SensitiveError, 0], [() => SensitiveCause, 0]]
    ];
    exports2.LambdaFunctionStartFailedEventDetails$ = [
      3,
      n032,
      _LFSFEDa,
      0,
      [_e32, _ca],
      [[() => SensitiveError, 0], [() => SensitiveCause, 0]]
    ];
    exports2.LambdaFunctionSucceededEventDetails$ = [
      3,
      n032,
      _LFSEDa,
      0,
      [_o, _oD],
      [[() => SensitiveData, 0], () => exports2.HistoryEventExecutionDataDetails$]
    ];
    exports2.LambdaFunctionTimedOutEventDetails$ = [
      3,
      n032,
      _LFTOED,
      0,
      [_e32, _ca],
      [[() => SensitiveError, 0], [() => SensitiveCause, 0]]
    ];
    exports2.ListActivitiesInput$ = [
      3,
      n032,
      _LAI,
      0,
      [_mR, _nT],
      [1, 0]
    ];
    exports2.ListActivitiesOutput$ = [
      3,
      n032,
      _LAO,
      0,
      [_a10, _nT],
      [() => ActivityList, 0],
      1
    ];
    exports2.ListExecutionsInput$ = [
      3,
      n032,
      _LEI,
      0,
      [_sMA, _sF, _mR, _nT, _mRA, _rF],
      [0, 0, 1, 0, 0, 0]
    ];
    exports2.ListExecutionsOutput$ = [
      3,
      n032,
      _LEO,
      0,
      [_ex10, _nT],
      [() => ExecutionList, 0],
      1
    ];
    exports2.ListMapRunsInput$ = [
      3,
      n032,
      _LMRI,
      0,
      [_eA, _mR, _nT],
      [0, 1, 0],
      1
    ];
    exports2.ListMapRunsOutput$ = [
      3,
      n032,
      _LMRO,
      0,
      [_mRa, _nT],
      [() => MapRunList, 0],
      1
    ];
    exports2.ListStateMachineAliasesInput$ = [
      3,
      n032,
      _LSMAI,
      0,
      [_sMA, _nT, _mR],
      [0, 0, 1],
      1
    ];
    exports2.ListStateMachineAliasesOutput$ = [
      3,
      n032,
      _LSMAO,
      0,
      [_sMAt, _nT],
      [() => StateMachineAliasList, 0],
      1
    ];
    exports2.ListStateMachinesInput$ = [
      3,
      n032,
      _LSMI,
      0,
      [_mR, _nT],
      [1, 0]
    ];
    exports2.ListStateMachinesOutput$ = [
      3,
      n032,
      _LSMO,
      0,
      [_sMt, _nT],
      [() => StateMachineList, 0],
      1
    ];
    exports2.ListStateMachineVersionsInput$ = [
      3,
      n032,
      _LSMVI,
      0,
      [_sMA, _nT, _mR],
      [0, 0, 1],
      1
    ];
    exports2.ListStateMachineVersionsOutput$ = [
      3,
      n032,
      _LSMVO,
      0,
      [_sMV, _nT],
      [() => StateMachineVersionList, 0],
      1
    ];
    exports2.ListTagsForResourceInput$ = [
      3,
      n032,
      _LTFRI,
      0,
      [_rAe],
      [0],
      1
    ];
    exports2.ListTagsForResourceOutput$ = [
      3,
      n032,
      _LTFRO,
      0,
      [_ta],
      [() => TagList]
    ];
    exports2.LogDestination$ = [
      3,
      n032,
      _LD,
      0,
      [_cWLLG],
      [() => exports2.CloudWatchLogsLogGroup$]
    ];
    exports2.LoggingConfiguration$ = [
      3,
      n032,
      _LC,
      0,
      [_le, _iED, _des],
      [0, 2, () => LogDestinationList]
    ];
    exports2.MapIterationEventDetails$ = [
      3,
      n032,
      _MIED,
      0,
      [_n, _ind],
      [0, 1]
    ];
    exports2.MapRunExecutionCounts$ = [
      3,
      n032,
      _MREC,
      0,
      [_pe, _ru, _su, _f, _tO10, _ab, _to, _rW, _fNR, _pR],
      [1, 1, 1, 1, 1, 1, 1, 1, 1, 1],
      8
    ];
    exports2.MapRunFailedEventDetails$ = [
      3,
      n032,
      _MRFED,
      0,
      [_e32, _ca],
      [[() => SensitiveError, 0], [() => SensitiveCause, 0]]
    ];
    exports2.MapRunItemCounts$ = [
      3,
      n032,
      _MRIC,
      0,
      [_pe, _ru, _su, _f, _tO10, _ab, _to, _rW, _fNR, _pR],
      [1, 1, 1, 1, 1, 1, 1, 1, 1, 1],
      8
    ];
    exports2.MapRunListItem$ = [
      3,
      n032,
      _MRLI,
      0,
      [_eA, _mRA, _sMA, _sD, _sDt],
      [0, 0, 0, 4, 4],
      4
    ];
    exports2.MapRunRedrivenEventDetails$ = [
      3,
      n032,
      _MRRED,
      0,
      [_mRA, _rCe],
      [0, 1]
    ];
    exports2.MapRunStartedEventDetails$ = [
      3,
      n032,
      _MRSED,
      0,
      [_mRA],
      [0]
    ];
    exports2.MapStateStartedEventDetails$ = [
      3,
      n032,
      _MSSED,
      0,
      [_len],
      [1]
    ];
    exports2.MockErrorOutput$ = [
      3,
      n032,
      _MEO,
      0,
      [_e32, _ca],
      [[() => SensitiveError, 0], [() => SensitiveCause, 0]]
    ];
    exports2.MockInput$ = [
      3,
      n032,
      _MI,
      0,
      [_res, _eO, _fVM],
      [[() => SensitiveData, 0], [() => exports2.MockErrorOutput$, 0], 0]
    ];
    exports2.PublishStateMachineVersionInput$ = [
      3,
      n032,
      _PSMVI,
      0,
      [_sMA, _rI, _d],
      [0, 0, [() => VersionDescription, 0]],
      1
    ];
    exports2.PublishStateMachineVersionOutput$ = [
      3,
      n032,
      _PSMVO,
      0,
      [_cD, _sMVA],
      [4, 0],
      2
    ];
    exports2.RedriveExecutionInput$ = [
      3,
      n032,
      _REI,
      0,
      [_eA, _cT],
      [0, [0, 4]],
      1
    ];
    exports2.RedriveExecutionOutput$ = [
      3,
      n032,
      _REO,
      0,
      [_rD],
      [4],
      1
    ];
    exports2.RoutingConfigurationListItem$ = [
      3,
      n032,
      _RCLI,
      0,
      [_sMVA, _w],
      [0, 1],
      2
    ];
    exports2.SendTaskFailureInput$ = [
      3,
      n032,
      _STFI,
      0,
      [_tT13, _e32, _ca],
      [0, [() => SensitiveError, 0], [() => SensitiveCause, 0]],
      1
    ];
    exports2.SendTaskFailureOutput$ = [
      3,
      n032,
      _STFO,
      0,
      [],
      []
    ];
    exports2.SendTaskHeartbeatInput$ = [
      3,
      n032,
      _STHI,
      0,
      [_tT13],
      [0],
      1
    ];
    exports2.SendTaskHeartbeatOutput$ = [
      3,
      n032,
      _STHO,
      0,
      [],
      []
    ];
    exports2.SendTaskSuccessInput$ = [
      3,
      n032,
      _STSI,
      0,
      [_tT13, _o],
      [0, [() => SensitiveData, 0]],
      2
    ];
    exports2.SendTaskSuccessOutput$ = [
      3,
      n032,
      _STSO,
      0,
      [],
      []
    ];
    exports2.StartExecutionInput$ = [
      3,
      n032,
      _SEI,
      0,
      [_sMA, _n, _i, _tH],
      [0, 0, [() => SensitiveData, 0], 0],
      1
    ];
    exports2.StartExecutionOutput$ = [
      3,
      n032,
      _SEO,
      0,
      [_eA, _sD],
      [0, 4],
      2
    ];
    exports2.StartSyncExecutionInput$ = [
      3,
      n032,
      _SSEI,
      0,
      [_sMA, _n, _i, _tH, _iDn],
      [0, 0, [() => SensitiveData, 0], 0, 0],
      1
    ];
    exports2.StartSyncExecutionOutput$ = [
      3,
      n032,
      _SSEO,
      0,
      [_eA, _sD, _sDt, _st, _sMA, _n, _e32, _ca, _i, _iD, _o, _oD, _tH, _bD],
      [0, 4, 4, 0, 0, 0, [() => SensitiveError, 0], [() => SensitiveCause, 0], [() => SensitiveData, 0], () => exports2.CloudWatchEventsExecutionDataDetails$, [() => SensitiveData, 0], () => exports2.CloudWatchEventsExecutionDataDetails$, 0, () => exports2.BillingDetails$],
      4
    ];
    exports2.StateEnteredEventDetails$ = [
      3,
      n032,
      _SEED,
      0,
      [_n, _i, _iD],
      [0, [() => SensitiveData, 0], () => exports2.HistoryEventExecutionDataDetails$],
      1
    ];
    exports2.StateExitedEventDetails$ = [
      3,
      n032,
      _SEEDt,
      0,
      [_n, _o, _oD, _aV, _aVD],
      [0, [() => SensitiveData, 0], () => exports2.HistoryEventExecutionDataDetails$, [() => AssignedVariables, 0], () => exports2.AssignedVariablesDetails$],
      1
    ];
    exports2.StateMachineAliasListItem$ = [
      3,
      n032,
      _SMALI,
      0,
      [_sMAA, _cD],
      [0, 4],
      2
    ];
    exports2.StateMachineListItem$ = [
      3,
      n032,
      _SMLI,
      0,
      [_sMA, _n, _ty, _cD],
      [0, 0, 0, 4],
      4
    ];
    exports2.StateMachineVersionListItem$ = [
      3,
      n032,
      _SMVLI,
      0,
      [_sMVA, _cD],
      [0, 4],
      2
    ];
    exports2.StopExecutionInput$ = [
      3,
      n032,
      _SEIt,
      0,
      [_eA, _e32, _ca],
      [0, [() => SensitiveError, 0], [() => SensitiveCause, 0]],
      1
    ];
    exports2.StopExecutionOutput$ = [
      3,
      n032,
      _SEOt,
      0,
      [_sDt],
      [4],
      1
    ];
    exports2.Tag$ = [
      3,
      n032,
      _T10,
      0,
      [_k, _va],
      [0, 0]
    ];
    exports2.TagResourceInput$ = [
      3,
      n032,
      _TRI,
      0,
      [_rAe, _ta],
      [0, () => TagList],
      2
    ];
    exports2.TagResourceOutput$ = [
      3,
      n032,
      _TRO,
      0,
      [],
      []
    ];
    exports2.TaskCredentials$ = [
      3,
      n032,
      _TC10,
      0,
      [_rA],
      [0]
    ];
    exports2.TaskFailedEventDetails$ = [
      3,
      n032,
      _TFED,
      0,
      [_rT13, _re, _e32, _ca],
      [0, 0, [() => SensitiveError, 0], [() => SensitiveCause, 0]],
      2
    ];
    exports2.TaskScheduledEventDetails$ = [
      3,
      n032,
      _TSED,
      0,
      [_rT13, _re, _reg, _pa, _tIS, _hIS, _tCa],
      [0, 0, 0, [() => ConnectorParameters, 0], 1, 1, () => exports2.TaskCredentials$],
      4
    ];
    exports2.TaskStartedEventDetails$ = [
      3,
      n032,
      _TSEDa,
      0,
      [_rT13, _re],
      [0, 0],
      2
    ];
    exports2.TaskStartFailedEventDetails$ = [
      3,
      n032,
      _TSFED,
      0,
      [_rT13, _re, _e32, _ca],
      [0, 0, [() => SensitiveError, 0], [() => SensitiveCause, 0]],
      2
    ];
    exports2.TaskSubmitFailedEventDetails$ = [
      3,
      n032,
      _TSFEDa,
      0,
      [_rT13, _re, _e32, _ca],
      [0, 0, [() => SensitiveError, 0], [() => SensitiveCause, 0]],
      2
    ];
    exports2.TaskSubmittedEventDetails$ = [
      3,
      n032,
      _TSEDas,
      0,
      [_rT13, _re, _o, _oD],
      [0, 0, [() => SensitiveData, 0], () => exports2.HistoryEventExecutionDataDetails$],
      2
    ];
    exports2.TaskSucceededEventDetails$ = [
      3,
      n032,
      _TSEDask,
      0,
      [_rT13, _re, _o, _oD],
      [0, 0, [() => SensitiveData, 0], () => exports2.HistoryEventExecutionDataDetails$],
      2
    ];
    exports2.TaskTimedOutEventDetails$ = [
      3,
      n032,
      _TTOED,
      0,
      [_rT13, _re, _e32, _ca],
      [0, 0, [() => SensitiveError, 0], [() => SensitiveCause, 0]],
      2
    ];
    exports2.TestStateConfiguration$ = [
      3,
      n032,
      _TSC,
      0,
      [_rRC, _eCBS, _mIFC, _mIRD],
      [1, [() => TestStateStateName, 0], 1, [() => SensitiveData, 0]]
    ];
    exports2.TestStateInput$ = [
      3,
      n032,
      _TSI,
      0,
      [_de, _rA, _i, _iL, _rSe, _v, _sN, _mo, _co13, _sCt],
      [[() => Definition, 0], 0, [() => SensitiveData, 0], 0, 2, [() => SensitiveData, 0], [() => TestStateStateName, 0], [() => exports2.MockInput$, 0], [() => SensitiveData, 0], [() => exports2.TestStateConfiguration$, 0]],
      1
    ];
    exports2.TestStateOutput$ = [
      3,
      n032,
      _TSO,
      0,
      [_o, _e32, _ca, _iDns, _nS, _st],
      [[() => SensitiveData, 0], [() => SensitiveError, 0], [() => SensitiveCause, 0], [() => exports2.InspectionData$, 0], 0, 0]
    ];
    exports2.TracingConfiguration$ = [
      3,
      n032,
      _TCr,
      0,
      [_en],
      [2]
    ];
    exports2.UntagResourceInput$ = [
      3,
      n032,
      _URI,
      0,
      [_rAe, _tK],
      [0, 64 | 0],
      2
    ];
    exports2.UntagResourceOutput$ = [
      3,
      n032,
      _URO,
      0,
      [],
      []
    ];
    exports2.UpdateMapRunInput$ = [
      3,
      n032,
      _UMRI,
      0,
      [_mRA, _mC, _tFP, _tFC],
      [0, 1, 1, 1],
      1
    ];
    exports2.UpdateMapRunOutput$ = [
      3,
      n032,
      _UMRO,
      0,
      [],
      []
    ];
    exports2.UpdateStateMachineAliasInput$ = [
      3,
      n032,
      _USMAI,
      0,
      [_sMAA, _d, _rC10],
      [0, [() => AliasDescription, 0], () => RoutingConfigurationList],
      1
    ];
    exports2.UpdateStateMachineAliasOutput$ = [
      3,
      n032,
      _USMAO,
      0,
      [_uD],
      [4],
      1
    ];
    exports2.UpdateStateMachineInput$ = [
      3,
      n032,
      _USMI,
      0,
      [_sMA, _de, _rA, _lC, _tC, _p, _vD, _eC],
      [0, [() => Definition, 0], 0, () => exports2.LoggingConfiguration$, () => exports2.TracingConfiguration$, 2, [() => VersionDescription, 0], () => exports2.EncryptionConfiguration$],
      1
    ];
    exports2.UpdateStateMachineOutput$ = [
      3,
      n032,
      _USMO,
      0,
      [_uD, _rI, _sMVA],
      [4, 0, 0],
      1
    ];
    exports2.ValidateStateMachineDefinitionDiagnostic$ = [
      3,
      n032,
      _VSMDD,
      0,
      [_se14, _cod, _m29, _lo],
      [0, [() => ValidateStateMachineDefinitionCode, 0], [() => ValidateStateMachineDefinitionMessage, 0], [() => ValidateStateMachineDefinitionLocation, 0]],
      3
    ];
    exports2.ValidateStateMachineDefinitionInput$ = [
      3,
      n032,
      _VSMDI,
      0,
      [_de, _ty, _se14, _mR],
      [[() => Definition, 0], 0, 0, 1],
      1
    ];
    exports2.ValidateStateMachineDefinitionOutput$ = [
      3,
      n032,
      _VSMDO,
      0,
      [_res, _di, _t],
      [0, [() => ValidateStateMachineDefinitionDiagnosticList, 0], 2],
      2
    ];
    var ActivityList = [
      1,
      n032,
      _AL,
      0,
      () => exports2.ActivityListItem$
    ];
    var ExecutionList = [
      1,
      n032,
      _EL,
      0,
      () => exports2.ExecutionListItem$
    ];
    var HistoryEventList = [
      1,
      n032,
      _HEL,
      0,
      [
        () => exports2.HistoryEvent$,
        0
      ]
    ];
    var LogDestinationList = [
      1,
      n032,
      _LDL,
      0,
      () => exports2.LogDestination$
    ];
    var MapRunList = [
      1,
      n032,
      _MRL,
      0,
      () => exports2.MapRunListItem$
    ];
    var RoutingConfigurationList = [
      1,
      n032,
      _RCL,
      0,
      () => exports2.RoutingConfigurationListItem$
    ];
    var StateMachineAliasList = [
      1,
      n032,
      _SMAL,
      0,
      () => exports2.StateMachineAliasListItem$
    ];
    var StateMachineList = [
      1,
      n032,
      _SML,
      0,
      () => exports2.StateMachineListItem$
    ];
    var StateMachineVersionList = [
      1,
      n032,
      _SMVL,
      0,
      () => exports2.StateMachineVersionListItem$
    ];
    var TagKeyList = 64 | 0;
    var TagList = [
      1,
      n032,
      _TL,
      0,
      () => exports2.Tag$
    ];
    var ValidateStateMachineDefinitionDiagnosticList = [
      1,
      n032,
      _VSMDDL,
      0,
      [
        () => exports2.ValidateStateMachineDefinitionDiagnostic$,
        0
      ]
    ];
    var VariableNameList = [
      1,
      n032,
      _VNL,
      0,
      [
        () => VariableName,
        0
      ]
    ];
    var AssignedVariables = [
      2,
      n032,
      _AV,
      0,
      [
        () => VariableName,
        0
      ],
      [
        () => VariableValue,
        0
      ]
    ];
    var VariableReferences = [
      2,
      n032,
      _VR,
      8,
      [
        0,
        0
      ],
      [
        () => VariableNameList,
        0
      ]
    ];
    exports2.CreateActivity$ = [
      9,
      n032,
      _CA10,
      2,
      () => exports2.CreateActivityInput$,
      () => exports2.CreateActivityOutput$
    ];
    exports2.CreateStateMachine$ = [
      9,
      n032,
      _CSM,
      2,
      () => exports2.CreateStateMachineInput$,
      () => exports2.CreateStateMachineOutput$
    ];
    exports2.CreateStateMachineAlias$ = [
      9,
      n032,
      _CSMA,
      0,
      () => exports2.CreateStateMachineAliasInput$,
      () => exports2.CreateStateMachineAliasOutput$
    ];
    exports2.DeleteActivity$ = [
      9,
      n032,
      _DA,
      0,
      () => exports2.DeleteActivityInput$,
      () => exports2.DeleteActivityOutput$
    ];
    exports2.DeleteStateMachine$ = [
      9,
      n032,
      _DSM,
      0,
      () => exports2.DeleteStateMachineInput$,
      () => exports2.DeleteStateMachineOutput$
    ];
    exports2.DeleteStateMachineAlias$ = [
      9,
      n032,
      _DSMA,
      0,
      () => exports2.DeleteStateMachineAliasInput$,
      () => exports2.DeleteStateMachineAliasOutput$
    ];
    exports2.DeleteStateMachineVersion$ = [
      9,
      n032,
      _DSMV,
      0,
      () => exports2.DeleteStateMachineVersionInput$,
      () => exports2.DeleteStateMachineVersionOutput$
    ];
    exports2.DescribeActivity$ = [
      9,
      n032,
      _DAe,
      0,
      () => exports2.DescribeActivityInput$,
      () => exports2.DescribeActivityOutput$
    ];
    exports2.DescribeExecution$ = [
      9,
      n032,
      _DE,
      0,
      () => exports2.DescribeExecutionInput$,
      () => exports2.DescribeExecutionOutput$
    ];
    exports2.DescribeMapRun$ = [
      9,
      n032,
      _DMR,
      0,
      () => exports2.DescribeMapRunInput$,
      () => exports2.DescribeMapRunOutput$
    ];
    exports2.DescribeStateMachine$ = [
      9,
      n032,
      _DSMe,
      0,
      () => exports2.DescribeStateMachineInput$,
      () => exports2.DescribeStateMachineOutput$
    ];
    exports2.DescribeStateMachineAlias$ = [
      9,
      n032,
      _DSMAe,
      0,
      () => exports2.DescribeStateMachineAliasInput$,
      () => exports2.DescribeStateMachineAliasOutput$
    ];
    exports2.DescribeStateMachineForExecution$ = [
      9,
      n032,
      _DSMFE,
      0,
      () => exports2.DescribeStateMachineForExecutionInput$,
      () => exports2.DescribeStateMachineForExecutionOutput$
    ];
    exports2.GetActivityTask$ = [
      9,
      n032,
      _GAT,
      0,
      () => exports2.GetActivityTaskInput$,
      () => exports2.GetActivityTaskOutput$
    ];
    exports2.GetExecutionHistory$ = [
      9,
      n032,
      _GEH,
      0,
      () => exports2.GetExecutionHistoryInput$,
      () => exports2.GetExecutionHistoryOutput$
    ];
    exports2.ListActivities$ = [
      9,
      n032,
      _LA,
      0,
      () => exports2.ListActivitiesInput$,
      () => exports2.ListActivitiesOutput$
    ];
    exports2.ListExecutions$ = [
      9,
      n032,
      _LE,
      0,
      () => exports2.ListExecutionsInput$,
      () => exports2.ListExecutionsOutput$
    ];
    exports2.ListMapRuns$ = [
      9,
      n032,
      _LMR,
      0,
      () => exports2.ListMapRunsInput$,
      () => exports2.ListMapRunsOutput$
    ];
    exports2.ListStateMachineAliases$ = [
      9,
      n032,
      _LSMA,
      0,
      () => exports2.ListStateMachineAliasesInput$,
      () => exports2.ListStateMachineAliasesOutput$
    ];
    exports2.ListStateMachines$ = [
      9,
      n032,
      _LSM,
      0,
      () => exports2.ListStateMachinesInput$,
      () => exports2.ListStateMachinesOutput$
    ];
    exports2.ListStateMachineVersions$ = [
      9,
      n032,
      _LSMV,
      0,
      () => exports2.ListStateMachineVersionsInput$,
      () => exports2.ListStateMachineVersionsOutput$
    ];
    exports2.ListTagsForResource$ = [
      9,
      n032,
      _LTFR,
      0,
      () => exports2.ListTagsForResourceInput$,
      () => exports2.ListTagsForResourceOutput$
    ];
    exports2.PublishStateMachineVersion$ = [
      9,
      n032,
      _PSMV,
      2,
      () => exports2.PublishStateMachineVersionInput$,
      () => exports2.PublishStateMachineVersionOutput$
    ];
    exports2.RedriveExecution$ = [
      9,
      n032,
      _RE,
      2,
      () => exports2.RedriveExecutionInput$,
      () => exports2.RedriveExecutionOutput$
    ];
    exports2.SendTaskFailure$ = [
      9,
      n032,
      _STF,
      0,
      () => exports2.SendTaskFailureInput$,
      () => exports2.SendTaskFailureOutput$
    ];
    exports2.SendTaskHeartbeat$ = [
      9,
      n032,
      _STH,
      0,
      () => exports2.SendTaskHeartbeatInput$,
      () => exports2.SendTaskHeartbeatOutput$
    ];
    exports2.SendTaskSuccess$ = [
      9,
      n032,
      _STS,
      0,
      () => exports2.SendTaskSuccessInput$,
      () => exports2.SendTaskSuccessOutput$
    ];
    exports2.StartExecution$ = [
      9,
      n032,
      _SEt,
      2,
      () => exports2.StartExecutionInput$,
      () => exports2.StartExecutionOutput$
    ];
    exports2.StartSyncExecution$ = [
      9,
      n032,
      _SSE,
      { [_end]: ["sync-"] },
      () => exports2.StartSyncExecutionInput$,
      () => exports2.StartSyncExecutionOutput$
    ];
    exports2.StopExecution$ = [
      9,
      n032,
      _SEto,
      0,
      () => exports2.StopExecutionInput$,
      () => exports2.StopExecutionOutput$
    ];
    exports2.TagResource$ = [
      9,
      n032,
      _TR,
      0,
      () => exports2.TagResourceInput$,
      () => exports2.TagResourceOutput$
    ];
    exports2.TestState$ = [
      9,
      n032,
      _TS,
      { [_end]: ["sync-"] },
      () => exports2.TestStateInput$,
      () => exports2.TestStateOutput$
    ];
    exports2.UntagResource$ = [
      9,
      n032,
      _UR,
      0,
      () => exports2.UntagResourceInput$,
      () => exports2.UntagResourceOutput$
    ];
    exports2.UpdateMapRun$ = [
      9,
      n032,
      _UMR,
      0,
      () => exports2.UpdateMapRunInput$,
      () => exports2.UpdateMapRunOutput$
    ];
    exports2.UpdateStateMachine$ = [
      9,
      n032,
      _USM,
      2,
      () => exports2.UpdateStateMachineInput$,
      () => exports2.UpdateStateMachineOutput$
    ];
    exports2.UpdateStateMachineAlias$ = [
      9,
      n032,
      _USMA,
      0,
      () => exports2.UpdateStateMachineAliasInput$,
      () => exports2.UpdateStateMachineAliasOutput$
    ];
    exports2.ValidateStateMachineDefinition$ = [
      9,
      n032,
      _VSMD,
      0,
      () => exports2.ValidateStateMachineDefinitionInput$,
      () => exports2.ValidateStateMachineDefinitionOutput$
    ];
  }
});

// ../../node_modules/@aws-sdk/client-sfn/dist-cjs/runtimeConfig.shared.js
var require_runtimeConfig_shared19 = __commonJS({
  "../../node_modules/@aws-sdk/client-sfn/dist-cjs/runtimeConfig.shared.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var protocols_1 = (init_protocols8(), __toCommonJS(protocols_exports5));
    var smithy_client_1 = require_dist_cjs34();
    var url_parser_1 = require_dist_cjs18();
    var util_base64_1 = require_dist_cjs10();
    var util_utf8_1 = require_dist_cjs9();
    var httpAuthSchemeProvider_1 = require_httpAuthSchemeProvider18();
    var endpointResolver_1 = require_endpointResolver18();
    var schemas_0_1 = require_schemas_018();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2016-11-23",
        base64Decoder: config2?.base64Decoder ?? util_base64_1.fromBase64,
        base64Encoder: config2?.base64Encoder ?? util_base64_1.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? endpointResolver_1.defaultEndpointResolver,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? httpAuthSchemeProvider_1.defaultSFNHttpAuthSchemeProvider,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new httpAuthSchemes_1.AwsSdkSigV4Signer()
          }
        ],
        logger: config2?.logger ?? new smithy_client_1.NoOpLogger(),
        protocol: config2?.protocol ?? protocols_1.AwsJson1_0Protocol,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.sfn",
          errorTypeRegistries: schemas_0_1.errorTypeRegistries,
          xmlNamespace: "http://swf.amazonaws.com/doc/2015-07-20/",
          version: "2016-11-23",
          serviceTarget: "AWSStepFunctions"
        },
        serviceId: config2?.serviceId ?? "SFN",
        urlParser: config2?.urlParser ?? url_parser_1.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? util_utf8_1.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? util_utf8_1.toUtf8
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-sfn/dist-cjs/runtimeConfig.js
var require_runtimeConfig19 = __commonJS({
  "../../node_modules/@aws-sdk/client-sfn/dist-cjs/runtimeConfig.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var package_json_1 = tslib_1.__importDefault(require_package18());
    var client_1 = (init_client8(), __toCommonJS(client_exports7));
    var httpAuthSchemes_1 = (init_httpAuthSchemes6(), __toCommonJS(httpAuthSchemes_exports5));
    var credential_provider_node_1 = require_dist_cjs122();
    var util_user_agent_node_1 = require_dist_cjs113();
    var config_resolver_1 = require_dist_cjs25();
    var hash_node_1 = require_dist_cjs44();
    var middleware_retry_1 = require_dist_cjs106();
    var node_config_provider_1 = require_dist_cjs29();
    var node_http_handler_1 = require_dist_cjs13();
    var smithy_client_1 = require_dist_cjs34();
    var util_body_length_node_1 = require_dist_cjs45();
    var util_defaults_mode_node_1 = require_dist_cjs46();
    var util_retry_1 = require_dist_cjs22();
    var runtimeConfig_shared_1 = require_runtimeConfig_shared19();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      (0, smithy_client_1.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, util_defaults_mode_node_1.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(smithy_client_1.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = (0, runtimeConfig_shared_1.getRuntimeConfig)(config2);
      (0, client_1.emitWarningIfUnsupportedVersion)(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, node_config_provider_1.loadConfig)(httpAuthSchemes_1.NODE_AUTH_SCHEME_PREFERENCE_OPTIONS, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? util_body_length_node_1.calculateBodyLength,
        credentialDefaultProvider: config2?.credentialDefaultProvider ?? credential_provider_node_1.defaultProvider,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, util_user_agent_node_1.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_json_1.default.version }),
        maxAttempts: config2?.maxAttempts ?? (0, node_config_provider_1.loadConfig)(middleware_retry_1.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_REGION_CONFIG_OPTIONS, { ...config_resolver_1.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: node_http_handler_1.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, node_config_provider_1.loadConfig)({
          ...middleware_retry_1.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || util_retry_1.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? hash_node_1.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? node_http_handler_1.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, node_config_provider_1.loadConfig)(util_user_agent_node_1.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-sfn/dist-cjs/index.js
var require_dist_cjs196 = __commonJS({
  "../../node_modules/@aws-sdk/client-sfn/dist-cjs/index.js"(exports2) {
    "use strict";
    var middlewareHostHeader = require_dist_cjs3();
    var middlewareLogger = require_dist_cjs4();
    var middlewareRecursionDetection = require_dist_cjs5();
    var middlewareUserAgent = require_dist_cjs104();
    var configResolver = require_dist_cjs25();
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var schema = (init_schema4(), __toCommonJS(schema_exports));
    var middlewareContentLength = require_dist_cjs26();
    var middlewareEndpoint = require_dist_cjs31();
    var middlewareRetry = require_dist_cjs106();
    var smithyClient = require_dist_cjs34();
    var httpAuthSchemeProvider = require_httpAuthSchemeProvider18();
    var runtimeConfig = require_runtimeConfig19();
    var regionConfigResolver = require_dist_cjs48();
    var protocolHttp = require_dist_cjs2();
    var schemas_0 = require_schemas_018();
    var client = (init_client8(), __toCommonJS(client_exports7));
    var errors = require_errors17();
    var SFNServiceException = require_SFNServiceException();
    var resolveClientEndpointParameters32 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "states"
      });
    }, "resolveClientEndpointParameters");
    var commonParams32 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
    var getHttpAuthExtensionConfiguration32 = /* @__PURE__ */ __name((runtimeConfig2) => {
      const _httpAuthSchemes = runtimeConfig2.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig2.httpAuthSchemeProvider;
      let _credentials = runtimeConfig2.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider2) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider2;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    var resolveHttpAuthRuntimeConfig32 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
    var resolveRuntimeExtensions32 = /* @__PURE__ */ __name((runtimeConfig2, extensions) => {
      const extensionConfiguration = Object.assign(regionConfigResolver.getAwsRegionExtensionConfiguration(runtimeConfig2), smithyClient.getDefaultExtensionConfiguration(runtimeConfig2), protocolHttp.getHttpHandlerExtensionConfiguration(runtimeConfig2), getHttpAuthExtensionConfiguration32(runtimeConfig2));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig2, regionConfigResolver.resolveAwsRegionExtensionConfiguration(extensionConfiguration), smithyClient.resolveDefaultRuntimeConfig(extensionConfiguration), protocolHttp.resolveHttpHandlerRuntimeConfig(extensionConfiguration), resolveHttpAuthRuntimeConfig32(extensionConfiguration));
    }, "resolveRuntimeExtensions");
    var SFNClient2 = class extends smithyClient.Client {
      static {
        __name(this, "SFNClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = runtimeConfig.getRuntimeConfig(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters32(_config_0);
        const _config_2 = middlewareUserAgent.resolveUserAgentConfig(_config_1);
        const _config_3 = middlewareRetry.resolveRetryConfig(_config_2);
        const _config_4 = configResolver.resolveRegionConfig(_config_3);
        const _config_5 = middlewareHostHeader.resolveHostHeaderConfig(_config_4);
        const _config_6 = middlewareEndpoint.resolveEndpointConfig(_config_5);
        const _config_7 = httpAuthSchemeProvider.resolveHttpAuthSchemeConfig(_config_6);
        const _config_8 = resolveRuntimeExtensions32(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(schema.getSchemaSerdePlugin(this.config));
        this.middlewareStack.use(middlewareUserAgent.getUserAgentPlugin(this.config));
        this.middlewareStack.use(middlewareRetry.getRetryPlugin(this.config));
        this.middlewareStack.use(middlewareContentLength.getContentLengthPlugin(this.config));
        this.middlewareStack.use(middlewareHostHeader.getHostHeaderPlugin(this.config));
        this.middlewareStack.use(middlewareLogger.getLoggerPlugin(this.config));
        this.middlewareStack.use(middlewareRecursionDetection.getRecursionDetectionPlugin(this.config));
        this.middlewareStack.use(core.getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: httpAuthSchemeProvider.defaultSFNHttpAuthSchemeParametersProvider,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new core.DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(core.getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
    var CreateActivityCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "CreateActivity", {}).n("SFNClient", "CreateActivityCommand").sc(schemas_0.CreateActivity$).build() {
      static {
        __name(this, "CreateActivityCommand");
      }
    };
    var CreateStateMachineAliasCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "CreateStateMachineAlias", {}).n("SFNClient", "CreateStateMachineAliasCommand").sc(schemas_0.CreateStateMachineAlias$).build() {
      static {
        __name(this, "CreateStateMachineAliasCommand");
      }
    };
    var CreateStateMachineCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "CreateStateMachine", {}).n("SFNClient", "CreateStateMachineCommand").sc(schemas_0.CreateStateMachine$).build() {
      static {
        __name(this, "CreateStateMachineCommand");
      }
    };
    var DeleteActivityCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "DeleteActivity", {}).n("SFNClient", "DeleteActivityCommand").sc(schemas_0.DeleteActivity$).build() {
      static {
        __name(this, "DeleteActivityCommand");
      }
    };
    var DeleteStateMachineAliasCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "DeleteStateMachineAlias", {}).n("SFNClient", "DeleteStateMachineAliasCommand").sc(schemas_0.DeleteStateMachineAlias$).build() {
      static {
        __name(this, "DeleteStateMachineAliasCommand");
      }
    };
    var DeleteStateMachineCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "DeleteStateMachine", {}).n("SFNClient", "DeleteStateMachineCommand").sc(schemas_0.DeleteStateMachine$).build() {
      static {
        __name(this, "DeleteStateMachineCommand");
      }
    };
    var DeleteStateMachineVersionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "DeleteStateMachineVersion", {}).n("SFNClient", "DeleteStateMachineVersionCommand").sc(schemas_0.DeleteStateMachineVersion$).build() {
      static {
        __name(this, "DeleteStateMachineVersionCommand");
      }
    };
    var DescribeActivityCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "DescribeActivity", {}).n("SFNClient", "DescribeActivityCommand").sc(schemas_0.DescribeActivity$).build() {
      static {
        __name(this, "DescribeActivityCommand");
      }
    };
    var DescribeExecutionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "DescribeExecution", {}).n("SFNClient", "DescribeExecutionCommand").sc(schemas_0.DescribeExecution$).build() {
      static {
        __name(this, "DescribeExecutionCommand");
      }
    };
    var DescribeMapRunCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "DescribeMapRun", {}).n("SFNClient", "DescribeMapRunCommand").sc(schemas_0.DescribeMapRun$).build() {
      static {
        __name(this, "DescribeMapRunCommand");
      }
    };
    var DescribeStateMachineAliasCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "DescribeStateMachineAlias", {}).n("SFNClient", "DescribeStateMachineAliasCommand").sc(schemas_0.DescribeStateMachineAlias$).build() {
      static {
        __name(this, "DescribeStateMachineAliasCommand");
      }
    };
    var DescribeStateMachineCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "DescribeStateMachine", {}).n("SFNClient", "DescribeStateMachineCommand").sc(schemas_0.DescribeStateMachine$).build() {
      static {
        __name(this, "DescribeStateMachineCommand");
      }
    };
    var DescribeStateMachineForExecutionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "DescribeStateMachineForExecution", {}).n("SFNClient", "DescribeStateMachineForExecutionCommand").sc(schemas_0.DescribeStateMachineForExecution$).build() {
      static {
        __name(this, "DescribeStateMachineForExecutionCommand");
      }
    };
    var GetActivityTaskCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [
        middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions()),
        client.getLongPollPlugin(config2)
      ];
    }).s("AWSStepFunctions", "GetActivityTask", {}).n("SFNClient", "GetActivityTaskCommand").sc(schemas_0.GetActivityTask$).build() {
      static {
        __name(this, "GetActivityTaskCommand");
      }
    };
    var GetExecutionHistoryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "GetExecutionHistory", {}).n("SFNClient", "GetExecutionHistoryCommand").sc(schemas_0.GetExecutionHistory$).build() {
      static {
        __name(this, "GetExecutionHistoryCommand");
      }
    };
    var ListActivitiesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "ListActivities", {}).n("SFNClient", "ListActivitiesCommand").sc(schemas_0.ListActivities$).build() {
      static {
        __name(this, "ListActivitiesCommand");
      }
    };
    var ListExecutionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "ListExecutions", {}).n("SFNClient", "ListExecutionsCommand").sc(schemas_0.ListExecutions$).build() {
      static {
        __name(this, "ListExecutionsCommand");
      }
    };
    var ListMapRunsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "ListMapRuns", {}).n("SFNClient", "ListMapRunsCommand").sc(schemas_0.ListMapRuns$).build() {
      static {
        __name(this, "ListMapRunsCommand");
      }
    };
    var ListStateMachineAliasesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "ListStateMachineAliases", {}).n("SFNClient", "ListStateMachineAliasesCommand").sc(schemas_0.ListStateMachineAliases$).build() {
      static {
        __name(this, "ListStateMachineAliasesCommand");
      }
    };
    var ListStateMachinesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "ListStateMachines", {}).n("SFNClient", "ListStateMachinesCommand").sc(schemas_0.ListStateMachines$).build() {
      static {
        __name(this, "ListStateMachinesCommand");
      }
    };
    var ListStateMachineVersionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "ListStateMachineVersions", {}).n("SFNClient", "ListStateMachineVersionsCommand").sc(schemas_0.ListStateMachineVersions$).build() {
      static {
        __name(this, "ListStateMachineVersionsCommand");
      }
    };
    var ListTagsForResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "ListTagsForResource", {}).n("SFNClient", "ListTagsForResourceCommand").sc(schemas_0.ListTagsForResource$).build() {
      static {
        __name(this, "ListTagsForResourceCommand");
      }
    };
    var PublishStateMachineVersionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "PublishStateMachineVersion", {}).n("SFNClient", "PublishStateMachineVersionCommand").sc(schemas_0.PublishStateMachineVersion$).build() {
      static {
        __name(this, "PublishStateMachineVersionCommand");
      }
    };
    var RedriveExecutionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "RedriveExecution", {}).n("SFNClient", "RedriveExecutionCommand").sc(schemas_0.RedriveExecution$).build() {
      static {
        __name(this, "RedriveExecutionCommand");
      }
    };
    var SendTaskFailureCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "SendTaskFailure", {}).n("SFNClient", "SendTaskFailureCommand").sc(schemas_0.SendTaskFailure$).build() {
      static {
        __name(this, "SendTaskFailureCommand");
      }
    };
    var SendTaskHeartbeatCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "SendTaskHeartbeat", {}).n("SFNClient", "SendTaskHeartbeatCommand").sc(schemas_0.SendTaskHeartbeat$).build() {
      static {
        __name(this, "SendTaskHeartbeatCommand");
      }
    };
    var SendTaskSuccessCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "SendTaskSuccess", {}).n("SFNClient", "SendTaskSuccessCommand").sc(schemas_0.SendTaskSuccess$).build() {
      static {
        __name(this, "SendTaskSuccessCommand");
      }
    };
    var StartExecutionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "StartExecution", {}).n("SFNClient", "StartExecutionCommand").sc(schemas_0.StartExecution$).build() {
      static {
        __name(this, "StartExecutionCommand");
      }
    };
    var StartSyncExecutionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "StartSyncExecution", {}).n("SFNClient", "StartSyncExecutionCommand").sc(schemas_0.StartSyncExecution$).build() {
      static {
        __name(this, "StartSyncExecutionCommand");
      }
    };
    var StopExecutionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "StopExecution", {}).n("SFNClient", "StopExecutionCommand").sc(schemas_0.StopExecution$).build() {
      static {
        __name(this, "StopExecutionCommand");
      }
    };
    var TagResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "TagResource", {}).n("SFNClient", "TagResourceCommand").sc(schemas_0.TagResource$).build() {
      static {
        __name(this, "TagResourceCommand");
      }
    };
    var TestStateCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "TestState", {}).n("SFNClient", "TestStateCommand").sc(schemas_0.TestState$).build() {
      static {
        __name(this, "TestStateCommand");
      }
    };
    var UntagResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "UntagResource", {}).n("SFNClient", "UntagResourceCommand").sc(schemas_0.UntagResource$).build() {
      static {
        __name(this, "UntagResourceCommand");
      }
    };
    var UpdateMapRunCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "UpdateMapRun", {}).n("SFNClient", "UpdateMapRunCommand").sc(schemas_0.UpdateMapRun$).build() {
      static {
        __name(this, "UpdateMapRunCommand");
      }
    };
    var UpdateStateMachineAliasCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "UpdateStateMachineAlias", {}).n("SFNClient", "UpdateStateMachineAliasCommand").sc(schemas_0.UpdateStateMachineAlias$).build() {
      static {
        __name(this, "UpdateStateMachineAliasCommand");
      }
    };
    var UpdateStateMachineCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "UpdateStateMachine", {}).n("SFNClient", "UpdateStateMachineCommand").sc(schemas_0.UpdateStateMachine$).build() {
      static {
        __name(this, "UpdateStateMachineCommand");
      }
    };
    var ValidateStateMachineDefinitionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSStepFunctions", "ValidateStateMachineDefinition", {}).n("SFNClient", "ValidateStateMachineDefinitionCommand").sc(schemas_0.ValidateStateMachineDefinition$).build() {
      static {
        __name(this, "ValidateStateMachineDefinitionCommand");
      }
    };
    var paginateGetExecutionHistory = core.createPaginator(SFNClient2, GetExecutionHistoryCommand, "nextToken", "nextToken", "maxResults");
    var paginateListActivities = core.createPaginator(SFNClient2, ListActivitiesCommand, "nextToken", "nextToken", "maxResults");
    var paginateListExecutions = core.createPaginator(SFNClient2, ListExecutionsCommand, "nextToken", "nextToken", "maxResults");
    var paginateListMapRuns = core.createPaginator(SFNClient2, ListMapRunsCommand, "nextToken", "nextToken", "maxResults");
    var paginateListStateMachines = core.createPaginator(SFNClient2, ListStateMachinesCommand, "nextToken", "nextToken", "maxResults");
    var commands32 = {
      CreateActivityCommand,
      CreateStateMachineCommand,
      CreateStateMachineAliasCommand,
      DeleteActivityCommand,
      DeleteStateMachineCommand,
      DeleteStateMachineAliasCommand,
      DeleteStateMachineVersionCommand,
      DescribeActivityCommand,
      DescribeExecutionCommand,
      DescribeMapRunCommand,
      DescribeStateMachineCommand,
      DescribeStateMachineAliasCommand,
      DescribeStateMachineForExecutionCommand,
      GetActivityTaskCommand,
      GetExecutionHistoryCommand,
      ListActivitiesCommand,
      ListExecutionsCommand,
      ListMapRunsCommand,
      ListStateMachineAliasesCommand,
      ListStateMachinesCommand,
      ListStateMachineVersionsCommand,
      ListTagsForResourceCommand,
      PublishStateMachineVersionCommand,
      RedriveExecutionCommand,
      SendTaskFailureCommand,
      SendTaskHeartbeatCommand,
      SendTaskSuccessCommand,
      StartExecutionCommand,
      StartSyncExecutionCommand,
      StopExecutionCommand,
      TagResourceCommand,
      TestStateCommand,
      UntagResourceCommand,
      UpdateMapRunCommand,
      UpdateStateMachineCommand: UpdateStateMachineCommand2,
      UpdateStateMachineAliasCommand,
      ValidateStateMachineDefinitionCommand
    };
    var paginators = {
      paginateGetExecutionHistory,
      paginateListActivities,
      paginateListExecutions,
      paginateListMapRuns,
      paginateListStateMachines
    };
    var SFN = class extends SFNClient2 {
      static {
        __name(this, "SFN");
      }
    };
    smithyClient.createAggregatedClient(commands32, SFN, { paginators });
    var EncryptionType = {
      AWS_OWNED_KEY: "AWS_OWNED_KEY",
      CUSTOMER_MANAGED_KMS_KEY: "CUSTOMER_MANAGED_KMS_KEY"
    };
    var LogLevel = {
      ALL: "ALL",
      ERROR: "ERROR",
      FATAL: "FATAL",
      OFF: "OFF"
    };
    var StateMachineType = {
      EXPRESS: "EXPRESS",
      STANDARD: "STANDARD"
    };
    var ValidationExceptionReason = {
      API_DOES_NOT_SUPPORT_LABELED_ARNS: "API_DOES_NOT_SUPPORT_LABELED_ARNS",
      CANNOT_UPDATE_COMPLETED_MAP_RUN: "CANNOT_UPDATE_COMPLETED_MAP_RUN",
      INVALID_ROUTING_CONFIGURATION: "INVALID_ROUTING_CONFIGURATION",
      MISSING_REQUIRED_PARAMETER: "MISSING_REQUIRED_PARAMETER"
    };
    var IncludedData = {
      ALL_DATA: "ALL_DATA",
      METADATA_ONLY: "METADATA_ONLY"
    };
    var ExecutionRedriveStatus = {
      NOT_REDRIVABLE: "NOT_REDRIVABLE",
      REDRIVABLE: "REDRIVABLE",
      REDRIVABLE_BY_MAP_RUN: "REDRIVABLE_BY_MAP_RUN"
    };
    var ExecutionStatus = {
      ABORTED: "ABORTED",
      FAILED: "FAILED",
      PENDING_REDRIVE: "PENDING_REDRIVE",
      RUNNING: "RUNNING",
      SUCCEEDED: "SUCCEEDED",
      TIMED_OUT: "TIMED_OUT"
    };
    var KmsKeyState = {
      CREATING: "CREATING",
      DISABLED: "DISABLED",
      PENDING_DELETION: "PENDING_DELETION",
      PENDING_IMPORT: "PENDING_IMPORT",
      UNAVAILABLE: "UNAVAILABLE"
    };
    var MapRunStatus = {
      ABORTED: "ABORTED",
      FAILED: "FAILED",
      RUNNING: "RUNNING",
      SUCCEEDED: "SUCCEEDED"
    };
    var StateMachineStatus = {
      ACTIVE: "ACTIVE",
      DELETING: "DELETING"
    };
    var HistoryEventType = {
      ActivityFailed: "ActivityFailed",
      ActivityScheduleFailed: "ActivityScheduleFailed",
      ActivityScheduled: "ActivityScheduled",
      ActivityStarted: "ActivityStarted",
      ActivitySucceeded: "ActivitySucceeded",
      ActivityTimedOut: "ActivityTimedOut",
      ChoiceStateEntered: "ChoiceStateEntered",
      ChoiceStateExited: "ChoiceStateExited",
      EvaluationFailed: "EvaluationFailed",
      ExecutionAborted: "ExecutionAborted",
      ExecutionFailed: "ExecutionFailed",
      ExecutionRedriven: "ExecutionRedriven",
      ExecutionStarted: "ExecutionStarted",
      ExecutionSucceeded: "ExecutionSucceeded",
      ExecutionTimedOut: "ExecutionTimedOut",
      FailStateEntered: "FailStateEntered",
      LambdaFunctionFailed: "LambdaFunctionFailed",
      LambdaFunctionScheduleFailed: "LambdaFunctionScheduleFailed",
      LambdaFunctionScheduled: "LambdaFunctionScheduled",
      LambdaFunctionStartFailed: "LambdaFunctionStartFailed",
      LambdaFunctionStarted: "LambdaFunctionStarted",
      LambdaFunctionSucceeded: "LambdaFunctionSucceeded",
      LambdaFunctionTimedOut: "LambdaFunctionTimedOut",
      MapIterationAborted: "MapIterationAborted",
      MapIterationFailed: "MapIterationFailed",
      MapIterationStarted: "MapIterationStarted",
      MapIterationSucceeded: "MapIterationSucceeded",
      MapRunAborted: "MapRunAborted",
      MapRunFailed: "MapRunFailed",
      MapRunRedriven: "MapRunRedriven",
      MapRunStarted: "MapRunStarted",
      MapRunSucceeded: "MapRunSucceeded",
      MapStateAborted: "MapStateAborted",
      MapStateEntered: "MapStateEntered",
      MapStateExited: "MapStateExited",
      MapStateFailed: "MapStateFailed",
      MapStateStarted: "MapStateStarted",
      MapStateSucceeded: "MapStateSucceeded",
      ParallelStateAborted: "ParallelStateAborted",
      ParallelStateEntered: "ParallelStateEntered",
      ParallelStateExited: "ParallelStateExited",
      ParallelStateFailed: "ParallelStateFailed",
      ParallelStateStarted: "ParallelStateStarted",
      ParallelStateSucceeded: "ParallelStateSucceeded",
      PassStateEntered: "PassStateEntered",
      PassStateExited: "PassStateExited",
      SucceedStateEntered: "SucceedStateEntered",
      SucceedStateExited: "SucceedStateExited",
      TaskFailed: "TaskFailed",
      TaskScheduled: "TaskScheduled",
      TaskStartFailed: "TaskStartFailed",
      TaskStarted: "TaskStarted",
      TaskStateAborted: "TaskStateAborted",
      TaskStateEntered: "TaskStateEntered",
      TaskStateExited: "TaskStateExited",
      TaskSubmitFailed: "TaskSubmitFailed",
      TaskSubmitted: "TaskSubmitted",
      TaskSucceeded: "TaskSucceeded",
      TaskTimedOut: "TaskTimedOut",
      WaitStateAborted: "WaitStateAborted",
      WaitStateEntered: "WaitStateEntered",
      WaitStateExited: "WaitStateExited"
    };
    var ExecutionRedriveFilter = {
      NOT_REDRIVEN: "NOT_REDRIVEN",
      REDRIVEN: "REDRIVEN"
    };
    var SyncExecutionStatus = {
      FAILED: "FAILED",
      SUCCEEDED: "SUCCEEDED",
      TIMED_OUT: "TIMED_OUT"
    };
    var InspectionLevel = {
      DEBUG: "DEBUG",
      INFO: "INFO",
      TRACE: "TRACE"
    };
    var MockResponseValidationMode = {
      NONE: "NONE",
      PRESENT: "PRESENT",
      STRICT: "STRICT"
    };
    var TestExecutionStatus = {
      CAUGHT_ERROR: "CAUGHT_ERROR",
      FAILED: "FAILED",
      RETRIABLE: "RETRIABLE",
      SUCCEEDED: "SUCCEEDED"
    };
    var ValidateStateMachineDefinitionSeverity = {
      ERROR: "ERROR",
      WARNING: "WARNING"
    };
    var ValidateStateMachineDefinitionResultCode = {
      FAIL: "FAIL",
      OK: "OK"
    };
    exports2.$Command = smithyClient.Command;
    exports2.__Client = smithyClient.Client;
    exports2.SFNServiceException = SFNServiceException.SFNServiceException;
    exports2.CreateActivityCommand = CreateActivityCommand;
    exports2.CreateStateMachineAliasCommand = CreateStateMachineAliasCommand;
    exports2.CreateStateMachineCommand = CreateStateMachineCommand;
    exports2.DeleteActivityCommand = DeleteActivityCommand;
    exports2.DeleteStateMachineAliasCommand = DeleteStateMachineAliasCommand;
    exports2.DeleteStateMachineCommand = DeleteStateMachineCommand;
    exports2.DeleteStateMachineVersionCommand = DeleteStateMachineVersionCommand;
    exports2.DescribeActivityCommand = DescribeActivityCommand;
    exports2.DescribeExecutionCommand = DescribeExecutionCommand;
    exports2.DescribeMapRunCommand = DescribeMapRunCommand;
    exports2.DescribeStateMachineAliasCommand = DescribeStateMachineAliasCommand;
    exports2.DescribeStateMachineCommand = DescribeStateMachineCommand;
    exports2.DescribeStateMachineForExecutionCommand = DescribeStateMachineForExecutionCommand;
    exports2.EncryptionType = EncryptionType;
    exports2.ExecutionRedriveFilter = ExecutionRedriveFilter;
    exports2.ExecutionRedriveStatus = ExecutionRedriveStatus;
    exports2.ExecutionStatus = ExecutionStatus;
    exports2.GetActivityTaskCommand = GetActivityTaskCommand;
    exports2.GetExecutionHistoryCommand = GetExecutionHistoryCommand;
    exports2.HistoryEventType = HistoryEventType;
    exports2.IncludedData = IncludedData;
    exports2.InspectionLevel = InspectionLevel;
    exports2.KmsKeyState = KmsKeyState;
    exports2.ListActivitiesCommand = ListActivitiesCommand;
    exports2.ListExecutionsCommand = ListExecutionsCommand;
    exports2.ListMapRunsCommand = ListMapRunsCommand;
    exports2.ListStateMachineAliasesCommand = ListStateMachineAliasesCommand;
    exports2.ListStateMachineVersionsCommand = ListStateMachineVersionsCommand;
    exports2.ListStateMachinesCommand = ListStateMachinesCommand;
    exports2.ListTagsForResourceCommand = ListTagsForResourceCommand;
    exports2.LogLevel = LogLevel;
    exports2.MapRunStatus = MapRunStatus;
    exports2.MockResponseValidationMode = MockResponseValidationMode;
    exports2.PublishStateMachineVersionCommand = PublishStateMachineVersionCommand;
    exports2.RedriveExecutionCommand = RedriveExecutionCommand;
    exports2.SFN = SFN;
    exports2.SFNClient = SFNClient2;
    exports2.SendTaskFailureCommand = SendTaskFailureCommand;
    exports2.SendTaskHeartbeatCommand = SendTaskHeartbeatCommand;
    exports2.SendTaskSuccessCommand = SendTaskSuccessCommand;
    exports2.StartExecutionCommand = StartExecutionCommand;
    exports2.StartSyncExecutionCommand = StartSyncExecutionCommand;
    exports2.StateMachineStatus = StateMachineStatus;
    exports2.StateMachineType = StateMachineType;
    exports2.StopExecutionCommand = StopExecutionCommand;
    exports2.SyncExecutionStatus = SyncExecutionStatus;
    exports2.TagResourceCommand = TagResourceCommand;
    exports2.TestExecutionStatus = TestExecutionStatus;
    exports2.TestStateCommand = TestStateCommand;
    exports2.UntagResourceCommand = UntagResourceCommand;
    exports2.UpdateMapRunCommand = UpdateMapRunCommand;
    exports2.UpdateStateMachineAliasCommand = UpdateStateMachineAliasCommand;
    exports2.UpdateStateMachineCommand = UpdateStateMachineCommand2;
    exports2.ValidateStateMachineDefinitionCommand = ValidateStateMachineDefinitionCommand;
    exports2.ValidateStateMachineDefinitionResultCode = ValidateStateMachineDefinitionResultCode;
    exports2.ValidateStateMachineDefinitionSeverity = ValidateStateMachineDefinitionSeverity;
    exports2.ValidationExceptionReason = ValidationExceptionReason;
    exports2.paginateGetExecutionHistory = paginateGetExecutionHistory;
    exports2.paginateListActivities = paginateListActivities;
    exports2.paginateListExecutions = paginateListExecutions;
    exports2.paginateListMapRuns = paginateListMapRuns;
    exports2.paginateListStateMachines = paginateListStateMachines;
    Object.prototype.hasOwnProperty.call(schemas_0, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: schemas_0["__proto__"]
    });
    Object.keys(schemas_0).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = schemas_0[k32];
    });
    Object.prototype.hasOwnProperty.call(errors, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: errors["__proto__"]
    });
    Object.keys(errors).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = errors[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/client/emitWarningIfUnsupportedVersion.js
var state12, emitWarningIfUnsupportedVersion38;
var init_emitWarningIfUnsupportedVersion14 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/client/emitWarningIfUnsupportedVersion.js"() {
    state12 = {
      warningEmitted: false
    };
    emitWarningIfUnsupportedVersion38 = /* @__PURE__ */ __name((version) => {
      if (version && !state12.warningEmitted) {
        if (process.env.AWS_SDK_JS_NODE_VERSION_SUPPORT_WARNING_DISABLED === "true") {
          state12.warningEmitted = true;
          return;
        }
        const userMajorVersion = parseInt(version.substring(1, version.indexOf(".")));
        const vv = 22;
        if (userMajorVersion < vv) {
          state12.warningEmitted = true;
          process.emitWarning(`NodeVersionSupportWarning: The AWS SDK for JavaScript (v3)
versions published after the first week of January 2027
will require node >=${vv}. You are running node ${version}.

To continue receiving updates to AWS services, bug fixes,
and security updates please upgrade to node >=${vv}.

More information can be found at: https://a.co/c895JFp`);
        }
      }
    }, "emitWarningIfUnsupportedVersion");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/client/longPollMiddleware.js
var longPollMiddleware12, longPollMiddlewareOptions12, getLongPollPlugin12;
var init_longPollMiddleware12 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/client/longPollMiddleware.js"() {
    longPollMiddleware12 = /* @__PURE__ */ __name(() => (next, context) => async (args) => {
      context.__retryLongPoll = true;
      return next(args);
    }, "longPollMiddleware");
    longPollMiddlewareOptions12 = {
      name: "longPollMiddleware",
      tags: ["RETRY"],
      step: "initialize",
      override: true
    };
    getLongPollPlugin12 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(longPollMiddleware12(), longPollMiddlewareOptions12);
      }, "applyToStack")
    }), "getLongPollPlugin");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/client/setCredentialFeature.js
function setCredentialFeature12(credentials, feature, value) {
  if (!credentials.$source) {
    credentials.$source = {};
  }
  credentials.$source[feature] = value;
  return credentials;
}
var init_setCredentialFeature12 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/client/setCredentialFeature.js"() {
    __name(setCredentialFeature12, "setCredentialFeature");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/client/setFeature.js
function setFeature18(context, feature, value) {
  if (!context.__aws_sdk_context) {
    context.__aws_sdk_context = {
      features: {}
    };
  } else if (!context.__aws_sdk_context.features) {
    context.__aws_sdk_context.features = {};
  }
  context.__aws_sdk_context.features[feature] = value;
}
var import_util_retry35;
var init_setFeature14 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/client/setFeature.js"() {
    import_util_retry35 = __toESM(require_dist_cjs22());
    import_util_retry35.Retry.v2026 ||= typeof process === "object" && process.env?.AWS_NEW_RETRIES_2026 === "true";
    __name(setFeature18, "setFeature");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/client/setTokenFeature.js
function setTokenFeature12(token, feature, value) {
  if (!token.$source) {
    token.$source = {};
  }
  token.$source[feature] = value;
  return token;
}
var init_setTokenFeature12 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/client/setTokenFeature.js"() {
    __name(setTokenFeature12, "setTokenFeature");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/client/index.js
var client_exports14 = {};
__export(client_exports14, {
  emitWarningIfUnsupportedVersion: () => emitWarningIfUnsupportedVersion38,
  getLongPollPlugin: () => getLongPollPlugin12,
  setCredentialFeature: () => setCredentialFeature12,
  setFeature: () => setFeature18,
  setTokenFeature: () => setTokenFeature12,
  state: () => state12
});
var init_client19 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/client/index.js"() {
    init_emitWarningIfUnsupportedVersion14();
    init_longPollMiddleware12();
    init_setCredentialFeature12();
    init_setFeature14();
    init_setTokenFeature12();
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/middleware-user-agent/dist-cjs/index.js
var require_dist_cjs197 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/middleware-user-agent/dist-cjs/index.js"(exports2) {
    "use strict";
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var utilEndpoints = require_dist_cjs21();
    var protocolHttp = require_dist_cjs2();
    var client = (init_client19(), __toCommonJS(client_exports14));
    var utilRetry = require_dist_cjs22();
    var DEFAULT_UA_APP_ID2 = void 0;
    function isValidUserAgentAppId2(appId) {
      if (appId === void 0) {
        return true;
      }
      return typeof appId === "string" && appId.length <= 50;
    }
    __name(isValidUserAgentAppId2, "isValidUserAgentAppId");
    function resolveUserAgentConfig29(input) {
      const normalizedAppIdProvider = core.normalizeProvider(input.userAgentAppId ?? DEFAULT_UA_APP_ID2);
      const { customUserAgent } = input;
      return Object.assign(input, {
        customUserAgent: typeof customUserAgent === "string" ? [[customUserAgent]] : customUserAgent,
        userAgentAppId: /* @__PURE__ */ __name(async () => {
          const appId = await normalizedAppIdProvider();
          if (!isValidUserAgentAppId2(appId)) {
            const logger5 = input.logger?.constructor?.name === "NoOpLogger" || !input.logger ? console : input.logger;
            if (typeof appId !== "string") {
              logger5?.warn("userAgentAppId must be a string or undefined.");
            } else if (appId.length > 50) {
              logger5?.warn("The provided userAgentAppId exceeds the maximum length of 50 characters.");
            }
          }
          return appId;
        }, "userAgentAppId")
      });
    }
    __name(resolveUserAgentConfig29, "resolveUserAgentConfig");
    var ACCOUNT_ID_ENDPOINT_REGEX2 = /\d{12}\.ddb/;
    async function checkFeatures2(context, config2, args) {
      const request4 = args.request;
      if (request4?.headers?.["smithy-protocol"] === "rpc-v2-cbor") {
        client.setFeature(context, "PROTOCOL_RPC_V2_CBOR", "M");
      }
      if (typeof config2.retryStrategy === "function") {
        const retryStrategy = await config2.retryStrategy();
        if (typeof retryStrategy.mode === "string") {
          switch (retryStrategy.mode) {
            case utilRetry.RETRY_MODES.ADAPTIVE:
              client.setFeature(context, "RETRY_MODE_ADAPTIVE", "F");
              break;
            case utilRetry.RETRY_MODES.STANDARD:
              client.setFeature(context, "RETRY_MODE_STANDARD", "E");
              break;
          }
        }
      }
      if (typeof config2.accountIdEndpointMode === "function") {
        const endpointV2 = context.endpointV2;
        if (String(endpointV2?.url?.hostname).match(ACCOUNT_ID_ENDPOINT_REGEX2)) {
          client.setFeature(context, "ACCOUNT_ID_ENDPOINT", "O");
        }
        switch (await config2.accountIdEndpointMode?.()) {
          case "disabled":
            client.setFeature(context, "ACCOUNT_ID_MODE_DISABLED", "Q");
            break;
          case "preferred":
            client.setFeature(context, "ACCOUNT_ID_MODE_PREFERRED", "P");
            break;
          case "required":
            client.setFeature(context, "ACCOUNT_ID_MODE_REQUIRED", "R");
            break;
        }
      }
      const identity = context.__smithy_context?.selectedHttpAuthScheme?.identity;
      if (identity?.$source) {
        const credentials = identity;
        if (credentials.accountId) {
          client.setFeature(context, "RESOLVED_ACCOUNT_ID", "T");
        }
        for (const [key, value] of Object.entries(credentials.$source ?? {})) {
          client.setFeature(context, key, value);
        }
      }
    }
    __name(checkFeatures2, "checkFeatures");
    var USER_AGENT3 = "user-agent";
    var X_AMZ_USER_AGENT2 = "x-amz-user-agent";
    var SPACE2 = " ";
    var UA_NAME_SEPARATOR2 = "/";
    var UA_NAME_ESCAPE_REGEX2 = /[^!$%&'*+\-.^_`|~\w]/g;
    var UA_VALUE_ESCAPE_REGEX2 = /[^!$%&'*+\-.^_`|~\w#]/g;
    var UA_ESCAPE_CHAR2 = "-";
    var BYTE_LIMIT2 = 1024;
    function encodeFeatures2(features) {
      let buffer = "";
      for (const key in features) {
        const val = features[key];
        if (buffer.length + val.length + 1 <= BYTE_LIMIT2) {
          if (buffer.length) {
            buffer += "," + val;
          } else {
            buffer += val;
          }
          continue;
        }
        break;
      }
      return buffer;
    }
    __name(encodeFeatures2, "encodeFeatures");
    var userAgentMiddleware2 = /* @__PURE__ */ __name((options) => (next, context) => async (args) => {
      const { request: request4 } = args;
      if (!protocolHttp.HttpRequest.isInstance(request4)) {
        return next(args);
      }
      const { headers } = request4;
      const userAgent = context?.userAgent?.map(escapeUserAgent2) || [];
      const defaultUserAgent2 = (await options.defaultUserAgentProvider()).map(escapeUserAgent2);
      await checkFeatures2(context, options, args);
      const awsContext = context;
      defaultUserAgent2.push(`m/${encodeFeatures2(Object.assign({}, context.__smithy_context?.features, awsContext.__aws_sdk_context?.features))}`);
      const customUserAgent = options?.customUserAgent?.map(escapeUserAgent2) || [];
      const appId = await options.userAgentAppId();
      if (appId) {
        defaultUserAgent2.push(escapeUserAgent2([`app`, `${appId}`]));
      }
      const prefix = utilEndpoints.getUserAgentPrefix();
      const sdkUserAgentValue = (prefix ? [prefix] : []).concat([...defaultUserAgent2, ...userAgent, ...customUserAgent]).join(SPACE2);
      const normalUAValue = [
        ...defaultUserAgent2.filter((section) => section.startsWith("aws-sdk-")),
        ...customUserAgent
      ].join(SPACE2);
      if (options.runtime !== "browser") {
        if (normalUAValue) {
          headers[X_AMZ_USER_AGENT2] = headers[X_AMZ_USER_AGENT2] ? `${headers[USER_AGENT3]} ${normalUAValue}` : normalUAValue;
        }
        headers[USER_AGENT3] = sdkUserAgentValue;
      } else {
        headers[X_AMZ_USER_AGENT2] = sdkUserAgentValue;
      }
      return next({
        ...args,
        request: request4
      });
    }, "userAgentMiddleware");
    var escapeUserAgent2 = /* @__PURE__ */ __name((userAgentPair) => {
      const name = userAgentPair[0].split(UA_NAME_SEPARATOR2).map((part) => part.replace(UA_NAME_ESCAPE_REGEX2, UA_ESCAPE_CHAR2)).join(UA_NAME_SEPARATOR2);
      const version = userAgentPair[1]?.replace(UA_VALUE_ESCAPE_REGEX2, UA_ESCAPE_CHAR2);
      const prefixSeparatorIndex = name.indexOf(UA_NAME_SEPARATOR2);
      const prefix = name.substring(0, prefixSeparatorIndex);
      let uaName = name.substring(prefixSeparatorIndex + 1);
      if (prefix === "api") {
        uaName = uaName.toLowerCase();
      }
      return [prefix, uaName, version].filter((item) => item && item.length > 0).reduce((acc, item, index) => {
        switch (index) {
          case 0:
            return item;
          case 1:
            return `${acc}/${item}`;
          default:
            return `${acc}#${item}`;
        }
      }, "");
    }, "escapeUserAgent");
    var getUserAgentMiddlewareOptions2 = {
      name: "getUserAgentMiddleware",
      step: "build",
      priority: "low",
      tags: ["SET_USER_AGENT", "USER_AGENT"],
      override: true
    };
    var getUserAgentPlugin29 = /* @__PURE__ */ __name((config2) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(userAgentMiddleware2(config2), getUserAgentMiddlewareOptions2);
      }, "applyToStack")
    }), "getUserAgentPlugin");
    exports2.DEFAULT_UA_APP_ID = DEFAULT_UA_APP_ID2;
    exports2.getUserAgentMiddlewareOptions = getUserAgentMiddlewareOptions2;
    exports2.getUserAgentPlugin = getUserAgentPlugin29;
    exports2.resolveUserAgentConfig = resolveUserAgentConfig29;
    exports2.userAgentMiddleware = userAgentMiddleware2;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/middleware-retry/dist-cjs/isStreamingPayload/isStreamingPayload.js
var require_isStreamingPayload9 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/middleware-retry/dist-cjs/isStreamingPayload/isStreamingPayload.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isStreamingPayload = void 0;
    var stream_1 = require("stream");
    var isStreamingPayload3 = /* @__PURE__ */ __name((request4) => request4?.body instanceof stream_1.Readable || typeof ReadableStream !== "undefined" && request4?.body instanceof ReadableStream, "isStreamingPayload");
    exports2.isStreamingPayload = isStreamingPayload3;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/middleware-retry/dist-cjs/index.js
var require_dist_cjs198 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/middleware-retry/dist-cjs/index.js"(exports2) {
    "use strict";
    var utilRetry = require_dist_cjs22();
    var protocolHttp = require_dist_cjs2();
    var serviceErrorClassification = require_dist_cjs32();
    var uuid = require_dist_cjs19();
    var utilMiddleware = require_dist_cjs6();
    var smithyClient = require_dist_cjs34();
    var isStreamingPayload3 = require_isStreamingPayload9();
    var serde = (init_serde(), __toCommonJS(serde_exports));
    var asSdkError3 = /* @__PURE__ */ __name((error4) => {
      if (error4 instanceof Error)
        return error4;
      if (error4 instanceof Object)
        return Object.assign(new Error(), error4);
      if (typeof error4 === "string")
        return new Error(error4);
      return new Error(`AWS SDK error wrapper for ${error4}`);
    }, "asSdkError");
    var getDefaultRetryQuota3 = /* @__PURE__ */ __name((initialRetryTokens, options) => {
      const MAX_CAPACITY = initialRetryTokens;
      const noRetryIncrement = utilRetry.NO_RETRY_INCREMENT;
      const retryCost = utilRetry.RETRY_COST;
      const timeoutRetryCost = utilRetry.TIMEOUT_RETRY_COST;
      let availableCapacity = initialRetryTokens;
      const getCapacityAmount = /* @__PURE__ */ __name((error4) => error4.name === "TimeoutError" ? timeoutRetryCost : retryCost, "getCapacityAmount");
      const hasRetryTokens = /* @__PURE__ */ __name((error4) => getCapacityAmount(error4) <= availableCapacity, "hasRetryTokens");
      const retrieveRetryTokens = /* @__PURE__ */ __name((error4) => {
        if (!hasRetryTokens(error4)) {
          throw new Error("No retry token available");
        }
        const capacityAmount = getCapacityAmount(error4);
        availableCapacity -= capacityAmount;
        return capacityAmount;
      }, "retrieveRetryTokens");
      const releaseRetryTokens = /* @__PURE__ */ __name((capacityReleaseAmount) => {
        availableCapacity += capacityReleaseAmount ?? noRetryIncrement;
        availableCapacity = Math.min(availableCapacity, MAX_CAPACITY);
      }, "releaseRetryTokens");
      return Object.freeze({
        hasRetryTokens,
        retrieveRetryTokens,
        releaseRetryTokens
      });
    }, "getDefaultRetryQuota");
    var defaultDelayDecider3 = /* @__PURE__ */ __name((delayBase, attempts) => Math.floor(Math.min(utilRetry.MAXIMUM_RETRY_DELAY, Math.random() * 2 ** attempts * delayBase)), "defaultDelayDecider");
    var defaultRetryDecider3 = /* @__PURE__ */ __name((error4) => {
      if (!error4) {
        return false;
      }
      return serviceErrorClassification.isRetryableByTrait(error4) || serviceErrorClassification.isClockSkewError(error4) || serviceErrorClassification.isThrottlingError(error4) || serviceErrorClassification.isTransientError(error4);
    }, "defaultRetryDecider");
    var StandardRetryStrategy5 = class {
      static {
        __name(this, "StandardRetryStrategy");
      }
      maxAttemptsProvider;
      retryDecider;
      delayDecider;
      retryQuota;
      mode = utilRetry.RETRY_MODES.STANDARD;
      constructor(maxAttemptsProvider, options) {
        this.maxAttemptsProvider = maxAttemptsProvider;
        this.retryDecider = options?.retryDecider ?? defaultRetryDecider3;
        this.delayDecider = options?.delayDecider ?? defaultDelayDecider3;
        this.retryQuota = options?.retryQuota ?? getDefaultRetryQuota3(utilRetry.INITIAL_RETRY_TOKENS);
      }
      shouldRetry(error4, attempts, maxAttempts) {
        return attempts < maxAttempts && this.retryDecider(error4) && this.retryQuota.hasRetryTokens(error4);
      }
      async getMaxAttempts() {
        let maxAttempts;
        try {
          maxAttempts = await this.maxAttemptsProvider();
        } catch (error4) {
          maxAttempts = utilRetry.DEFAULT_MAX_ATTEMPTS;
        }
        return maxAttempts;
      }
      async retry(next, args, options) {
        let retryTokenAmount;
        let attempts = 0;
        let totalDelay = 0;
        const maxAttempts = await this.getMaxAttempts();
        const { request: request4 } = args;
        if (protocolHttp.HttpRequest.isInstance(request4)) {
          request4.headers[utilRetry.INVOCATION_ID_HEADER] = uuid.v4();
        }
        while (true) {
          try {
            if (protocolHttp.HttpRequest.isInstance(request4)) {
              request4.headers[utilRetry.REQUEST_HEADER] = `attempt=${attempts + 1}; max=${maxAttempts}`;
            }
            if (options?.beforeRequest) {
              await options.beforeRequest();
            }
            const { response, output } = await next(args);
            if (options?.afterRequest) {
              options.afterRequest(response);
            }
            this.retryQuota.releaseRetryTokens(retryTokenAmount);
            output.$metadata.attempts = attempts + 1;
            output.$metadata.totalRetryDelay = totalDelay;
            return { response, output };
          } catch (e32) {
            const err = asSdkError3(e32);
            attempts++;
            if (this.shouldRetry(err, attempts, maxAttempts)) {
              retryTokenAmount = this.retryQuota.retrieveRetryTokens(err);
              const delayFromDecider = this.delayDecider(serviceErrorClassification.isThrottlingError(err) ? utilRetry.THROTTLING_RETRY_DELAY_BASE : utilRetry.DEFAULT_RETRY_DELAY_BASE, attempts);
              const delayFromResponse = getDelayFromRetryAfterHeader3(err.$response);
              const delay = Math.max(delayFromResponse || 0, delayFromDecider);
              totalDelay += delay;
              await new Promise((resolve13) => setTimeout(resolve13, delay));
              continue;
            }
            if (!err.$metadata) {
              err.$metadata = {};
            }
            err.$metadata.attempts = attempts;
            err.$metadata.totalRetryDelay = totalDelay;
            throw err;
          }
        }
      }
    };
    var getDelayFromRetryAfterHeader3 = /* @__PURE__ */ __name((response) => {
      if (!protocolHttp.HttpResponse.isInstance(response))
        return;
      const retryAfterHeaderName = Object.keys(response.headers).find((key) => key.toLowerCase() === "retry-after");
      if (!retryAfterHeaderName)
        return;
      const retryAfter = response.headers[retryAfterHeaderName];
      const retryAfterSeconds = Number(retryAfter);
      if (!Number.isNaN(retryAfterSeconds))
        return retryAfterSeconds * 1e3;
      const retryAfterDate = new Date(retryAfter);
      return retryAfterDate.getTime() - Date.now();
    }, "getDelayFromRetryAfterHeader");
    var AdaptiveRetryStrategy5 = class extends StandardRetryStrategy5 {
      static {
        __name(this, "AdaptiveRetryStrategy");
      }
      rateLimiter;
      constructor(maxAttemptsProvider, options) {
        const { rateLimiter, ...superOptions } = options ?? {};
        super(maxAttemptsProvider, superOptions);
        this.rateLimiter = rateLimiter ?? new utilRetry.DefaultRateLimiter();
        this.mode = utilRetry.RETRY_MODES.ADAPTIVE;
      }
      async retry(next, args) {
        return super.retry(next, args, {
          beforeRequest: /* @__PURE__ */ __name(async () => {
            return this.rateLimiter.getSendToken();
          }, "beforeRequest"),
          afterRequest: /* @__PURE__ */ __name((response) => {
            this.rateLimiter.updateClientSendingRate(response);
          }, "afterRequest")
        });
      }
    };
    var ENV_MAX_ATTEMPTS3 = "AWS_MAX_ATTEMPTS";
    var CONFIG_MAX_ATTEMPTS3 = "max_attempts";
    var NODE_MAX_ATTEMPT_CONFIG_OPTIONS30 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => {
        const value = env3[ENV_MAX_ATTEMPTS3];
        if (!value)
          return void 0;
        const maxAttempt = parseInt(value);
        if (Number.isNaN(maxAttempt)) {
          throw new Error(`Environment variable ${ENV_MAX_ATTEMPTS3} mast be a number, got "${value}"`);
        }
        return maxAttempt;
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => {
        const value = profile[CONFIG_MAX_ATTEMPTS3];
        if (!value)
          return void 0;
        const maxAttempt = parseInt(value);
        if (Number.isNaN(maxAttempt)) {
          throw new Error(`Shared config file entry ${CONFIG_MAX_ATTEMPTS3} mast be a number, got "${value}"`);
        }
        return maxAttempt;
      }, "configFileSelector"),
      default: utilRetry.DEFAULT_MAX_ATTEMPTS
    };
    var resolveRetryConfig30 = /* @__PURE__ */ __name((input) => {
      const { retryStrategy, retryMode } = input;
      const maxAttempts = utilMiddleware.normalizeProvider(input.maxAttempts ?? utilRetry.DEFAULT_MAX_ATTEMPTS);
      let controller = retryStrategy ? Promise.resolve(retryStrategy) : void 0;
      const getDefault = /* @__PURE__ */ __name(async () => await utilMiddleware.normalizeProvider(retryMode)() === utilRetry.RETRY_MODES.ADAPTIVE ? new utilRetry.AdaptiveRetryStrategy(maxAttempts) : new utilRetry.StandardRetryStrategy(maxAttempts), "getDefault");
      return Object.assign(input, {
        maxAttempts,
        retryStrategy: /* @__PURE__ */ __name(() => controller ??= getDefault(), "retryStrategy")
      });
    }, "resolveRetryConfig");
    var ENV_RETRY_MODE3 = "AWS_RETRY_MODE";
    var CONFIG_RETRY_MODE3 = "retry_mode";
    var NODE_RETRY_MODE_CONFIG_OPTIONS30 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[ENV_RETRY_MODE3], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[CONFIG_RETRY_MODE3], "configFileSelector"),
      default: utilRetry.DEFAULT_RETRY_MODE
    };
    var omitRetryHeadersMiddleware3 = /* @__PURE__ */ __name(() => (next) => async (args) => {
      const { request: request4 } = args;
      if (protocolHttp.HttpRequest.isInstance(request4)) {
        delete request4.headers[utilRetry.INVOCATION_ID_HEADER];
        delete request4.headers[utilRetry.REQUEST_HEADER];
      }
      return next(args);
    }, "omitRetryHeadersMiddleware");
    var omitRetryHeadersMiddlewareOptions3 = {
      name: "omitRetryHeadersMiddleware",
      tags: ["RETRY", "HEADERS", "OMIT_RETRY_HEADERS"],
      relation: "before",
      toMiddleware: "awsAuthMiddleware",
      override: true
    };
    var getOmitRetryHeadersPlugin3 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.addRelativeTo(omitRetryHeadersMiddleware3(), omitRetryHeadersMiddlewareOptions3);
      }, "applyToStack")
    }), "getOmitRetryHeadersPlugin");
    function parseRetryAfterHeader3(response, logger5) {
      if (!protocolHttp.HttpResponse.isInstance(response)) {
        return;
      }
      for (const header of Object.keys(response.headers)) {
        const h32 = header.toLowerCase();
        if (h32 === "retry-after") {
          const retryAfter = response.headers[header];
          let retryAfterSeconds = NaN;
          if (retryAfter.endsWith("GMT")) {
            try {
              const date7 = serde.parseRfc7231DateTime(retryAfter);
              retryAfterSeconds = (date7.getTime() - Date.now()) / 1e3;
            } catch (e32) {
              logger5?.trace?.("Failed to parse retry-after header");
              logger5?.trace?.(e32);
            }
          } else if (retryAfter.match(/ GMT, ((\d+)|(\d+\.\d+))$/)) {
            retryAfterSeconds = Number(retryAfter.match(/ GMT, ([\d.]+)$/)?.[1]);
          } else if (retryAfter.match(/^((\d+)|(\d+\.\d+))$/)) {
            retryAfterSeconds = Number(retryAfter);
          } else if (Date.parse(retryAfter) >= Date.now()) {
            retryAfterSeconds = (Date.parse(retryAfter) - Date.now()) / 1e3;
          }
          if (isNaN(retryAfterSeconds)) {
            return;
          }
          return new Date(Date.now() + retryAfterSeconds * 1e3);
        } else if (h32 === "x-amz-retry-after") {
          const v = response.headers[header];
          const backoffMilliseconds = Number(v);
          if (isNaN(backoffMilliseconds)) {
            logger5?.trace?.(`Failed to parse x-amz-retry-after=${v}`);
            return;
          }
          return new Date(Date.now() + backoffMilliseconds);
        }
      }
    }
    __name(parseRetryAfterHeader3, "parseRetryAfterHeader");
    function getRetryAfterHint3(response, logger5) {
      return parseRetryAfterHeader3(response, logger5);
    }
    __name(getRetryAfterHint3, "getRetryAfterHint");
    var retryMiddleware3 = /* @__PURE__ */ __name((options) => (next, context) => async (args) => {
      let retryStrategy = await options.retryStrategy();
      const maxAttempts = await options.maxAttempts();
      if (isRetryStrategyV23(retryStrategy)) {
        retryStrategy = retryStrategy;
        let retryToken = await retryStrategy.acquireInitialRetryToken((context["partition_id"] ?? "") + (context.__retryLongPoll ? ":longpoll" : ""));
        let lastError = new Error();
        let attempts = 0;
        let totalRetryDelay = 0;
        const { request: request4 } = args;
        const isRequest = protocolHttp.HttpRequest.isInstance(request4);
        if (isRequest) {
          request4.headers[utilRetry.INVOCATION_ID_HEADER] = uuid.v4();
        }
        while (true) {
          try {
            if (isRequest) {
              request4.headers[utilRetry.REQUEST_HEADER] = `attempt=${attempts + 1}; max=${maxAttempts}`;
            }
            const { response, output } = await next(args);
            retryStrategy.recordSuccess(retryToken);
            output.$metadata.attempts = attempts + 1;
            output.$metadata.totalRetryDelay = totalRetryDelay;
            return { response, output };
          } catch (e32) {
            const retryErrorInfo = getRetryErrorInfo3(e32, options.logger);
            lastError = asSdkError3(e32);
            if (isRequest && isStreamingPayload3.isStreamingPayload(request4)) {
              (context.logger instanceof smithyClient.NoOpLogger ? console : context.logger)?.warn("An error was encountered in a non-retryable streaming request.");
              throw lastError;
            }
            try {
              retryToken = await retryStrategy.refreshRetryTokenForRetry(retryToken, retryErrorInfo);
            } catch (refreshError) {
              if (typeof refreshError.$backoff === "number") {
                await cooldown3(refreshError.$backoff);
              }
              if (!lastError.$metadata) {
                lastError.$metadata = {};
              }
              lastError.$metadata.attempts = attempts + 1;
              lastError.$metadata.totalRetryDelay = totalRetryDelay;
              throw lastError;
            }
            attempts = retryToken.getRetryCount();
            const delay = retryToken.getRetryDelay();
            totalRetryDelay += delay;
            await cooldown3(delay);
          }
        }
      } else {
        retryStrategy = retryStrategy;
        if (retryStrategy?.mode) {
          context.userAgent = [...context.userAgent || [], ["cfg/retry-mode", retryStrategy.mode]];
        }
        return retryStrategy.retry(next, args);
      }
    }, "retryMiddleware");
    var cooldown3 = /* @__PURE__ */ __name((ms) => new Promise((resolve13) => setTimeout(resolve13, ms)), "cooldown");
    var isRetryStrategyV23 = /* @__PURE__ */ __name((retryStrategy) => typeof retryStrategy.acquireInitialRetryToken !== "undefined" && typeof retryStrategy.refreshRetryTokenForRetry !== "undefined" && typeof retryStrategy.recordSuccess !== "undefined", "isRetryStrategyV2");
    var getRetryErrorInfo3 = /* @__PURE__ */ __name((error4, logger5) => {
      const errorInfo = {
        error: error4,
        errorType: getRetryErrorType3(error4)
      };
      const retryAfterHint = parseRetryAfterHeader3(error4.$response, logger5);
      if (retryAfterHint) {
        errorInfo.retryAfterHint = retryAfterHint;
      }
      return errorInfo;
    }, "getRetryErrorInfo");
    var getRetryErrorType3 = /* @__PURE__ */ __name((error4) => {
      if (serviceErrorClassification.isThrottlingError(error4))
        return "THROTTLING";
      if (serviceErrorClassification.isTransientError(error4))
        return "TRANSIENT";
      if (serviceErrorClassification.isServerError(error4))
        return "SERVER_ERROR";
      return "CLIENT_ERROR";
    }, "getRetryErrorType");
    var retryMiddlewareOptions3 = {
      name: "retryMiddleware",
      tags: ["RETRY"],
      step: "finalizeRequest",
      priority: "high",
      override: true
    };
    var getRetryPlugin30 = /* @__PURE__ */ __name((options) => ({
      applyToStack: /* @__PURE__ */ __name((clientStack) => {
        clientStack.add(retryMiddleware3(options), retryMiddlewareOptions3);
      }, "applyToStack")
    }), "getRetryPlugin");
    exports2.AdaptiveRetryStrategy = AdaptiveRetryStrategy5;
    exports2.CONFIG_MAX_ATTEMPTS = CONFIG_MAX_ATTEMPTS3;
    exports2.CONFIG_RETRY_MODE = CONFIG_RETRY_MODE3;
    exports2.ENV_MAX_ATTEMPTS = ENV_MAX_ATTEMPTS3;
    exports2.ENV_RETRY_MODE = ENV_RETRY_MODE3;
    exports2.NODE_MAX_ATTEMPT_CONFIG_OPTIONS = NODE_MAX_ATTEMPT_CONFIG_OPTIONS30;
    exports2.NODE_RETRY_MODE_CONFIG_OPTIONS = NODE_RETRY_MODE_CONFIG_OPTIONS30;
    exports2.StandardRetryStrategy = StandardRetryStrategy5;
    exports2.defaultDelayDecider = defaultDelayDecider3;
    exports2.defaultRetryDecider = defaultRetryDecider3;
    exports2.getOmitRetryHeadersPlugin = getOmitRetryHeadersPlugin3;
    exports2.getRetryAfterHint = getRetryAfterHint3;
    exports2.getRetryPlugin = getRetryPlugin30;
    exports2.omitRetryHeadersMiddleware = omitRetryHeadersMiddleware3;
    exports2.omitRetryHeadersMiddlewareOptions = omitRetryHeadersMiddlewareOptions3;
    exports2.resolveRetryConfig = resolveRetryConfig30;
    exports2.retryMiddleware = retryMiddleware3;
    exports2.retryMiddlewareOptions = retryMiddlewareOptions3;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getDateHeader.js
var import_protocol_http57, getDateHeader10;
var init_getDateHeader10 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getDateHeader.js"() {
    import_protocol_http57 = __toESM(require_dist_cjs2());
    getDateHeader10 = /* @__PURE__ */ __name((response) => import_protocol_http57.HttpResponse.isInstance(response) ? response.headers?.date ?? response.headers?.Date : void 0, "getDateHeader");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getSkewCorrectedDate.js
var getSkewCorrectedDate10;
var init_getSkewCorrectedDate10 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getSkewCorrectedDate.js"() {
    getSkewCorrectedDate10 = /* @__PURE__ */ __name((systemClockOffset) => new Date(Date.now() + systemClockOffset), "getSkewCorrectedDate");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/isClockSkewed.js
var isClockSkewed10;
var init_isClockSkewed10 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/isClockSkewed.js"() {
    init_getSkewCorrectedDate10();
    isClockSkewed10 = /* @__PURE__ */ __name((clockTime, systemClockOffset) => Math.abs(getSkewCorrectedDate10(systemClockOffset).getTime() - clockTime) >= 3e5, "isClockSkewed");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getUpdatedSystemClockOffset.js
var getUpdatedSystemClockOffset10;
var init_getUpdatedSystemClockOffset10 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getUpdatedSystemClockOffset.js"() {
    init_isClockSkewed10();
    getUpdatedSystemClockOffset10 = /* @__PURE__ */ __name((clockTime, currentSystemClockOffset) => {
      const clockTimeInMs = Date.parse(clockTime);
      if (isClockSkewed10(clockTimeInMs, currentSystemClockOffset)) {
        return clockTimeInMs - Date.now();
      }
      return currentSystemClockOffset;
    }, "getUpdatedSystemClockOffset");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/index.js
var init_utils17 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/index.js"() {
    init_getDateHeader10();
    init_getSkewCorrectedDate10();
    init_getUpdatedSystemClockOffset10();
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4Signer.js
var import_protocol_http58, throwSigningPropertyError10, validateSigningProperties10, AwsSdkSigV4Signer10, AWSSDKSigV4Signer10;
var init_AwsSdkSigV4Signer10 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4Signer.js"() {
    import_protocol_http58 = __toESM(require_dist_cjs2());
    init_utils17();
    throwSigningPropertyError10 = /* @__PURE__ */ __name((name, property) => {
      if (!property) {
        throw new Error(`Property \`${name}\` is not resolved for AWS SDK SigV4Auth`);
      }
      return property;
    }, "throwSigningPropertyError");
    validateSigningProperties10 = /* @__PURE__ */ __name(async (signingProperties) => {
      const context = throwSigningPropertyError10("context", signingProperties.context);
      const config2 = throwSigningPropertyError10("config", signingProperties.config);
      const authScheme = context.endpointV2?.properties?.authSchemes?.[0];
      const signerFunction = throwSigningPropertyError10("signer", config2.signer);
      const signer = await signerFunction(authScheme);
      const signingRegion = signingProperties?.signingRegion;
      const signingRegionSet = signingProperties?.signingRegionSet;
      const signingName = signingProperties?.signingName;
      return {
        config: config2,
        signer,
        signingRegion,
        signingRegionSet,
        signingName
      };
    }, "validateSigningProperties");
    AwsSdkSigV4Signer10 = class {
      static {
        __name(this, "AwsSdkSigV4Signer");
      }
      async sign(httpRequest, identity, signingProperties) {
        if (!import_protocol_http58.HttpRequest.isInstance(httpRequest)) {
          throw new Error("The request is not an instance of `HttpRequest` and cannot be signed");
        }
        const validatedProps = await validateSigningProperties10(signingProperties);
        const { config: config2, signer } = validatedProps;
        let { signingRegion, signingName } = validatedProps;
        const handlerExecutionContext = signingProperties.context;
        if (handlerExecutionContext?.authSchemes?.length ?? 0 > 1) {
          const [first, second] = handlerExecutionContext.authSchemes;
          if (first?.name === "sigv4a" && second?.name === "sigv4") {
            signingRegion = second?.signingRegion ?? signingRegion;
            signingName = second?.signingName ?? signingName;
          }
        }
        const signedRequest = await signer.sign(httpRequest, {
          signingDate: getSkewCorrectedDate10(config2.systemClockOffset),
          signingRegion,
          signingService: signingName
        });
        return signedRequest;
      }
      errorHandler(signingProperties) {
        return (error4) => {
          const serverTime = error4.ServerTime ?? getDateHeader10(error4.$response);
          if (serverTime) {
            const config2 = throwSigningPropertyError10("config", signingProperties.config);
            const initialSystemClockOffset = config2.systemClockOffset;
            config2.systemClockOffset = getUpdatedSystemClockOffset10(serverTime, config2.systemClockOffset);
            const clockSkewCorrected = config2.systemClockOffset !== initialSystemClockOffset;
            if (clockSkewCorrected && error4.$metadata) {
              error4.$metadata.clockSkewCorrected = true;
            }
          }
          throw error4;
        };
      }
      successHandler(httpResponse, signingProperties) {
        const dateHeader = getDateHeader10(httpResponse);
        if (dateHeader) {
          const config2 = throwSigningPropertyError10("config", signingProperties.config);
          config2.systemClockOffset = getUpdatedSystemClockOffset10(dateHeader, config2.systemClockOffset);
        }
      }
    };
    AWSSDKSigV4Signer10 = AwsSdkSigV4Signer10;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4ASigner.js
var import_protocol_http59, AwsSdkSigV4ASigner10;
var init_AwsSdkSigV4ASigner10 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/AwsSdkSigV4ASigner.js"() {
    import_protocol_http59 = __toESM(require_dist_cjs2());
    init_utils17();
    init_AwsSdkSigV4Signer10();
    AwsSdkSigV4ASigner10 = class extends AwsSdkSigV4Signer10 {
      static {
        __name(this, "AwsSdkSigV4ASigner");
      }
      async sign(httpRequest, identity, signingProperties) {
        if (!import_protocol_http59.HttpRequest.isInstance(httpRequest)) {
          throw new Error("The request is not an instance of `HttpRequest` and cannot be signed");
        }
        const { config: config2, signer, signingRegion, signingRegionSet, signingName } = await validateSigningProperties10(signingProperties);
        const configResolvedSigningRegionSet = await config2.sigv4aSigningRegionSet?.();
        const multiRegionOverride = (configResolvedSigningRegionSet ?? signingRegionSet ?? [signingRegion]).join(",");
        const signedRequest = await signer.sign(httpRequest, {
          signingDate: getSkewCorrectedDate10(config2.systemClockOffset),
          signingRegion: multiRegionOverride,
          signingService: signingName
        });
        return signedRequest;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getArrayForCommaSeparatedString.js
var getArrayForCommaSeparatedString10;
var init_getArrayForCommaSeparatedString10 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getArrayForCommaSeparatedString.js"() {
    getArrayForCommaSeparatedString10 = /* @__PURE__ */ __name((str) => typeof str === "string" && str.length > 0 ? str.split(",").map((item) => item.trim()) : [], "getArrayForCommaSeparatedString");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getBearerTokenEnvKey.js
var getBearerTokenEnvKey10;
var init_getBearerTokenEnvKey10 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/utils/getBearerTokenEnvKey.js"() {
    getBearerTokenEnvKey10 = /* @__PURE__ */ __name((signingName) => `AWS_BEARER_TOKEN_${signingName.replace(/[\s-]/g, "_").toUpperCase()}`, "getBearerTokenEnvKey");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/NODE_AUTH_SCHEME_PREFERENCE_OPTIONS.js
var NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY10, NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY10, NODE_AUTH_SCHEME_PREFERENCE_OPTIONS10;
var init_NODE_AUTH_SCHEME_PREFERENCE_OPTIONS10 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/NODE_AUTH_SCHEME_PREFERENCE_OPTIONS.js"() {
    init_getArrayForCommaSeparatedString10();
    init_getBearerTokenEnvKey10();
    NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY10 = "AWS_AUTH_SCHEME_PREFERENCE";
    NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY10 = "auth_scheme_preference";
    NODE_AUTH_SCHEME_PREFERENCE_OPTIONS10 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3, options) => {
        if (options?.signingName) {
          const bearerTokenKey = getBearerTokenEnvKey10(options.signingName);
          if (bearerTokenKey in env3)
            return ["httpBearerAuth"];
        }
        if (!(NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY10 in env3))
          return void 0;
        return getArrayForCommaSeparatedString10(env3[NODE_AUTH_SCHEME_PREFERENCE_ENV_KEY10]);
      }, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => {
        if (!(NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY10 in profile))
          return void 0;
        return getArrayForCommaSeparatedString10(profile[NODE_AUTH_SCHEME_PREFERENCE_CONFIG_KEY10]);
      }, "configFileSelector"),
      default: []
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4AConfig.js
var import_property_provider9, resolveAwsSdkSigV4AConfig10, NODE_SIGV4A_CONFIG_OPTIONS10;
var init_resolveAwsSdkSigV4AConfig10 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4AConfig.js"() {
    init_dist_es();
    import_property_provider9 = __toESM(require_dist_cjs27());
    resolveAwsSdkSigV4AConfig10 = /* @__PURE__ */ __name((config2) => {
      config2.sigv4aSigningRegionSet = normalizeProvider(config2.sigv4aSigningRegionSet);
      return config2;
    }, "resolveAwsSdkSigV4AConfig");
    NODE_SIGV4A_CONFIG_OPTIONS10 = {
      environmentVariableSelector(env3) {
        if (env3.AWS_SIGV4A_SIGNING_REGION_SET) {
          return env3.AWS_SIGV4A_SIGNING_REGION_SET.split(",").map((_) => _.trim());
        }
        throw new import_property_provider9.ProviderError("AWS_SIGV4A_SIGNING_REGION_SET not set in env.", {
          tryNextLink: true
        });
      },
      configFileSelector(profile) {
        if (profile.sigv4a_signing_region_set) {
          return (profile.sigv4a_signing_region_set ?? "").split(",").map((_) => _.trim());
        }
        throw new import_property_provider9.ProviderError("sigv4a_signing_region_set not set in profile.", {
          tryNextLink: true
        });
      },
      default: void 0
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4Config.js
function normalizeCredentialProvider10(config2, { credentials, credentialDefaultProvider }) {
  let credentialsProvider;
  if (credentials) {
    if (!credentials?.memoized) {
      credentialsProvider = memoizeIdentityProvider(credentials, isIdentityExpired, doesIdentityRequireRefresh);
    } else {
      credentialsProvider = credentials;
    }
  } else {
    if (credentialDefaultProvider) {
      credentialsProvider = normalizeProvider(credentialDefaultProvider(Object.assign({}, config2, {
        parentClientConfig: config2
      })));
    } else {
      credentialsProvider = /* @__PURE__ */ __name(async () => {
        throw new Error("@aws-sdk/core::resolveAwsSdkSigV4Config - `credentials` not provided and no credentialDefaultProvider was configured.");
      }, "credentialsProvider");
    }
  }
  credentialsProvider.memoized = true;
  return credentialsProvider;
}
function bindCallerConfig10(config2, credentialsProvider) {
  if (credentialsProvider.configBound) {
    return credentialsProvider;
  }
  const fn = /* @__PURE__ */ __name(async (options) => credentialsProvider({ ...options, callerClientConfig: config2 }), "fn");
  fn.memoized = credentialsProvider.memoized;
  fn.configBound = true;
  return fn;
}
var import_signature_v410, resolveAwsSdkSigV4Config10, resolveAWSSDKSigV4Config10;
var init_resolveAwsSdkSigV4Config10 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/resolveAwsSdkSigV4Config.js"() {
    init_client19();
    init_dist_es();
    import_signature_v410 = __toESM(require_dist_cjs36());
    resolveAwsSdkSigV4Config10 = /* @__PURE__ */ __name((config2) => {
      let inputCredentials = config2.credentials;
      let isUserSupplied = !!config2.credentials;
      let resolvedCredentials = void 0;
      Object.defineProperty(config2, "credentials", {
        set(credentials) {
          if (credentials && credentials !== inputCredentials && credentials !== resolvedCredentials) {
            isUserSupplied = true;
          }
          inputCredentials = credentials;
          const memoizedProvider = normalizeCredentialProvider10(config2, {
            credentials: inputCredentials,
            credentialDefaultProvider: config2.credentialDefaultProvider
          });
          const boundProvider = bindCallerConfig10(config2, memoizedProvider);
          if (isUserSupplied && !boundProvider.attributed) {
            const isCredentialObject = typeof inputCredentials === "object" && inputCredentials !== null;
            resolvedCredentials = /* @__PURE__ */ __name(async (options) => {
              const creds = await boundProvider(options);
              const attributedCreds = creds;
              if (isCredentialObject && (!attributedCreds.$source || Object.keys(attributedCreds.$source).length === 0)) {
                return setCredentialFeature12(attributedCreds, "CREDENTIALS_CODE", "e");
              }
              return attributedCreds;
            }, "resolvedCredentials");
            resolvedCredentials.memoized = boundProvider.memoized;
            resolvedCredentials.configBound = boundProvider.configBound;
            resolvedCredentials.attributed = true;
          } else {
            resolvedCredentials = boundProvider;
          }
        },
        get() {
          return resolvedCredentials;
        },
        enumerable: true,
        configurable: true
      });
      config2.credentials = inputCredentials;
      const { signingEscapePath = true, systemClockOffset = config2.systemClockOffset || 0, sha256 } = config2;
      let signer;
      if (config2.signer) {
        signer = normalizeProvider(config2.signer);
      } else if (config2.regionInfoProvider) {
        signer = /* @__PURE__ */ __name(() => normalizeProvider(config2.region)().then(async (region) => [
          await config2.regionInfoProvider(region, {
            useFipsEndpoint: await config2.useFipsEndpoint(),
            useDualstackEndpoint: await config2.useDualstackEndpoint()
          }) || {},
          region
        ]).then(([regionInfo, region]) => {
          const { signingRegion, signingService } = regionInfo;
          config2.signingRegion = config2.signingRegion || signingRegion || region;
          config2.signingName = config2.signingName || signingService || config2.serviceId;
          const params = {
            ...config2,
            credentials: config2.credentials,
            region: config2.signingRegion,
            service: config2.signingName,
            sha256,
            uriEscapePath: signingEscapePath
          };
          const SignerCtor = config2.signerConstructor || import_signature_v410.SignatureV4;
          return new SignerCtor(params);
        }), "signer");
      } else {
        signer = /* @__PURE__ */ __name(async (authScheme) => {
          authScheme = Object.assign({}, {
            name: "sigv4",
            signingName: config2.signingName || config2.defaultSigningName,
            signingRegion: await normalizeProvider(config2.region)(),
            properties: {}
          }, authScheme);
          const signingRegion = authScheme.signingRegion;
          const signingService = authScheme.signingName;
          config2.signingRegion = config2.signingRegion || signingRegion;
          config2.signingName = config2.signingName || signingService || config2.serviceId;
          const params = {
            ...config2,
            credentials: config2.credentials,
            region: config2.signingRegion,
            service: config2.signingName,
            sha256,
            uriEscapePath: signingEscapePath
          };
          const SignerCtor = config2.signerConstructor || import_signature_v410.SignatureV4;
          return new SignerCtor(params);
        }, "signer");
      }
      const resolvedConfig = Object.assign(config2, {
        systemClockOffset,
        signingEscapePath,
        signer
      });
      return resolvedConfig;
    }, "resolveAwsSdkSigV4Config");
    resolveAWSSDKSigV4Config10 = resolveAwsSdkSigV4Config10;
    __name(normalizeCredentialProvider10, "normalizeCredentialProvider");
    __name(bindCallerConfig10, "bindCallerConfig");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/index.js
var init_aws_sdk10 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/aws_sdk/index.js"() {
    init_AwsSdkSigV4Signer10();
    init_AwsSdkSigV4ASigner10();
    init_NODE_AUTH_SCHEME_PREFERENCE_OPTIONS10();
    init_resolveAwsSdkSigV4AConfig10();
    init_resolveAwsSdkSigV4Config10();
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/index.js
var httpAuthSchemes_exports10 = {};
__export(httpAuthSchemes_exports10, {
  AWSSDKSigV4Signer: () => AWSSDKSigV4Signer10,
  AwsSdkSigV4ASigner: () => AwsSdkSigV4ASigner10,
  AwsSdkSigV4Signer: () => AwsSdkSigV4Signer10,
  NODE_AUTH_SCHEME_PREFERENCE_OPTIONS: () => NODE_AUTH_SCHEME_PREFERENCE_OPTIONS10,
  NODE_SIGV4A_CONFIG_OPTIONS: () => NODE_SIGV4A_CONFIG_OPTIONS10,
  getBearerTokenEnvKey: () => getBearerTokenEnvKey10,
  resolveAWSSDKSigV4Config: () => resolveAWSSDKSigV4Config10,
  resolveAwsSdkSigV4AConfig: () => resolveAwsSdkSigV4AConfig10,
  resolveAwsSdkSigV4Config: () => resolveAwsSdkSigV4Config10,
  validateSigningProperties: () => validateSigningProperties10
});
var init_httpAuthSchemes12 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/httpAuthSchemes/index.js"() {
    init_aws_sdk10();
    init_getBearerTokenEnvKey10();
  }
});

// ../../node_modules/@aws-sdk/client-ssm/dist-cjs/auth/httpAuthSchemeProvider.js
var require_httpAuthSchemeProvider19 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/dist-cjs/auth/httpAuthSchemeProvider.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.resolveHttpAuthSchemeConfig = exports2.defaultSSMHttpAuthSchemeProvider = exports2.defaultSSMHttpAuthSchemeParametersProvider = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes12(), __toCommonJS(httpAuthSchemes_exports10));
    var util_middleware_1 = require_dist_cjs6();
    var defaultSSMHttpAuthSchemeParametersProvider = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, util_middleware_1.getSmithyContext)(context).operation,
        region: await (0, util_middleware_1.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultSSMHttpAuthSchemeParametersProvider");
    exports2.defaultSSMHttpAuthSchemeParametersProvider = defaultSSMHttpAuthSchemeParametersProvider;
    function createAwsAuthSigv4HttpAuthOption32(authParameters) {
      return {
        schemeId: "aws.auth#sigv4",
        signingProperties: {
          name: "ssm",
          region: authParameters.region
        },
        propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
          signingProperties: {
            config: config2,
            context
          }
        }), "propertiesExtractor")
      };
    }
    __name(createAwsAuthSigv4HttpAuthOption32, "createAwsAuthSigv4HttpAuthOption");
    var defaultSSMHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption32(authParameters));
        }
      }
      return options;
    }, "defaultSSMHttpAuthSchemeProvider");
    exports2.defaultSSMHttpAuthSchemeProvider = defaultSSMHttpAuthSchemeProvider;
    var resolveHttpAuthSchemeConfig32 = /* @__PURE__ */ __name((config2) => {
      const config_0 = (0, httpAuthSchemes_1.resolveAwsSdkSigV4Config)(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, util_middleware_1.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
    exports2.resolveHttpAuthSchemeConfig = resolveHttpAuthSchemeConfig32;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/package.json
var require_package19 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/package.json"(exports2, module2) {
    module2.exports = {
      name: "@aws-sdk/client-ssm",
      description: "AWS SDK for JavaScript Ssm Client for Node.js, Browser and React Native",
      version: "3.1041.0",
      scripts: {
        build: "concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline client-ssm",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        "extract:docs": "api-extractor run --local",
        "generate:client": "node ../../scripts/generate-clients/single-service --solo ssm",
        "test:e2e": "yarn g:vitest run -c vitest.config.e2e.mts --mode development",
        "test:e2e:watch": "yarn g:vitest watch -c vitest.config.e2e.mts",
        "test:index": "tsc --noEmit ./test/index-types.ts && node ./test/index-objects.spec.mjs"
      },
      main: "./dist-cjs/index.js",
      types: "./dist-types/index.d.ts",
      module: "./dist-es/index.js",
      sideEffects: false,
      dependencies: {
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.8",
        "@aws-sdk/credential-provider-node": "^3.972.39",
        "@aws-sdk/middleware-host-header": "^3.972.10",
        "@aws-sdk/middleware-logger": "^3.972.10",
        "@aws-sdk/middleware-recursion-detection": "^3.972.11",
        "@aws-sdk/middleware-user-agent": "^3.972.38",
        "@aws-sdk/region-config-resolver": "^3.972.13",
        "@aws-sdk/types": "^3.973.8",
        "@aws-sdk/util-endpoints": "^3.996.8",
        "@aws-sdk/util-user-agent-browser": "^3.972.10",
        "@aws-sdk/util-user-agent-node": "^3.973.24",
        "@smithy/config-resolver": "^4.4.17",
        "@smithy/core": "^3.23.17",
        "@smithy/fetch-http-handler": "^5.3.17",
        "@smithy/hash-node": "^4.2.14",
        "@smithy/invalid-dependency": "^4.2.14",
        "@smithy/middleware-content-length": "^4.2.14",
        "@smithy/middleware-endpoint": "^4.4.32",
        "@smithy/middleware-retry": "^4.5.7",
        "@smithy/middleware-serde": "^4.2.20",
        "@smithy/middleware-stack": "^4.2.14",
        "@smithy/node-config-provider": "^4.3.14",
        "@smithy/node-http-handler": "^4.6.1",
        "@smithy/protocol-http": "^5.3.14",
        "@smithy/smithy-client": "^4.12.13",
        "@smithy/types": "^4.14.1",
        "@smithy/url-parser": "^4.2.14",
        "@smithy/util-base64": "^4.3.2",
        "@smithy/util-body-length-browser": "^4.2.2",
        "@smithy/util-body-length-node": "^4.2.3",
        "@smithy/util-defaults-mode-browser": "^4.3.49",
        "@smithy/util-defaults-mode-node": "^4.2.54",
        "@smithy/util-endpoints": "^3.4.2",
        "@smithy/util-middleware": "^4.2.14",
        "@smithy/util-retry": "^4.3.6",
        "@smithy/util-utf8": "^4.2.2",
        "@smithy/util-waiter": "^4.3.0",
        tslib: "^2.6.2"
      },
      devDependencies: {
        "@tsconfig/node20": "20.1.8",
        "@types/node": "^20.14.8",
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3"
      },
      engines: {
        node: ">=20.0.0"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "dist-*/**"
      ],
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      browser: {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.browser"
      },
      "react-native": {
        "./dist-es/runtimeConfig": "./dist-es/runtimeConfig.native"
      },
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/clients/client-ssm",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "clients/client-ssm"
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-env/dist-cjs/index.js
var require_dist_cjs199 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-env/dist-cjs/index.js"(exports2) {
    "use strict";
    var client = (init_client19(), __toCommonJS(client_exports14));
    var propertyProvider = require_dist_cjs27();
    var ENV_KEY = "AWS_ACCESS_KEY_ID";
    var ENV_SECRET = "AWS_SECRET_ACCESS_KEY";
    var ENV_SESSION = "AWS_SESSION_TOKEN";
    var ENV_EXPIRATION = "AWS_CREDENTIAL_EXPIRATION";
    var ENV_CREDENTIAL_SCOPE = "AWS_CREDENTIAL_SCOPE";
    var ENV_ACCOUNT_ID = "AWS_ACCOUNT_ID";
    var fromEnv6 = /* @__PURE__ */ __name((init) => async () => {
      init?.logger?.debug("@aws-sdk/credential-provider-env - fromEnv");
      const accessKeyId = process.env[ENV_KEY];
      const secretAccessKey = process.env[ENV_SECRET];
      const sessionToken = process.env[ENV_SESSION];
      const expiry = process.env[ENV_EXPIRATION];
      const credentialScope = process.env[ENV_CREDENTIAL_SCOPE];
      const accountId = process.env[ENV_ACCOUNT_ID];
      if (accessKeyId && secretAccessKey) {
        const credentials = {
          accessKeyId,
          secretAccessKey,
          ...sessionToken && { sessionToken },
          ...expiry && { expiration: new Date(expiry) },
          ...credentialScope && { credentialScope },
          ...accountId && { accountId }
        };
        client.setCredentialFeature(credentials, "CREDENTIALS_ENV_VARS", "g");
        return credentials;
      }
      throw new propertyProvider.CredentialsProviderError("Unable to find environment variable credentials.", { logger: init?.logger });
    }, "fromEnv");
    exports2.ENV_ACCOUNT_ID = ENV_ACCOUNT_ID;
    exports2.ENV_CREDENTIAL_SCOPE = ENV_CREDENTIAL_SCOPE;
    exports2.ENV_EXPIRATION = ENV_EXPIRATION;
    exports2.ENV_KEY = ENV_KEY;
    exports2.ENV_SECRET = ENV_SECRET;
    exports2.ENV_SESSION = ENV_SESSION;
    exports2.fromEnv = fromEnv6;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/checkUrl.js
var require_checkUrl9 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/checkUrl.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.checkUrl = void 0;
    var property_provider_1 = require_dist_cjs27();
    var ECS_CONTAINER_HOST = "169.254.170.2";
    var EKS_CONTAINER_HOST_IPv4 = "169.254.170.23";
    var EKS_CONTAINER_HOST_IPv6 = "[fd00:ec2::23]";
    var checkUrl = /* @__PURE__ */ __name((url, logger5) => {
      if (url.protocol === "https:") {
        return;
      }
      if (url.hostname === ECS_CONTAINER_HOST || url.hostname === EKS_CONTAINER_HOST_IPv4 || url.hostname === EKS_CONTAINER_HOST_IPv6) {
        return;
      }
      if (url.hostname.includes("[")) {
        if (url.hostname === "[::1]" || url.hostname === "[0000:0000:0000:0000:0000:0000:0000:0001]") {
          return;
        }
      } else {
        if (url.hostname === "localhost") {
          return;
        }
        const ipComponents = url.hostname.split(".");
        const inRange = /* @__PURE__ */ __name((component) => {
          const num = parseInt(component, 10);
          return 0 <= num && num <= 255;
        }, "inRange");
        if (ipComponents[0] === "127" && inRange(ipComponents[1]) && inRange(ipComponents[2]) && inRange(ipComponents[3]) && ipComponents.length === 4) {
          return;
        }
      }
      throw new property_provider_1.CredentialsProviderError(`URL not accepted. It must either be HTTPS or match one of the following:
  - loopback CIDR 127.0.0.0/8 or [::1/128]
  - ECS container host 169.254.170.2
  - EKS container host 169.254.170.23 or [fd00:ec2::23]`, { logger: logger5 });
    }, "checkUrl");
    exports2.checkUrl = checkUrl;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.js
var require_ChecksumStream10 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ChecksumStream = void 0;
    var util_base64_1 = require_dist_cjs10();
    var stream_1 = require("stream");
    var ChecksumStream5 = class extends stream_1.Duplex {
      static {
        __name(this, "ChecksumStream");
      }
      expectedChecksum;
      checksumSourceLocation;
      checksum;
      source;
      base64Encoder;
      pendingCallback = null;
      constructor({ expectedChecksum, checksum, source, checksumSourceLocation, base64Encoder }) {
        super();
        if (typeof source.pipe === "function") {
          this.source = source;
        } else {
          throw new Error(`@smithy/util-stream: unsupported source type ${source?.constructor?.name ?? source} in ChecksumStream.`);
        }
        this.base64Encoder = base64Encoder ?? util_base64_1.toBase64;
        this.expectedChecksum = expectedChecksum;
        this.checksum = checksum;
        this.checksumSourceLocation = checksumSourceLocation;
        this.source.pipe(this);
      }
      _read(size) {
        if (this.pendingCallback) {
          const callback = this.pendingCallback;
          this.pendingCallback = null;
          callback();
        }
      }
      _write(chunk, encoding, callback) {
        try {
          this.checksum.update(chunk);
          const canPushMore = this.push(chunk);
          if (!canPushMore) {
            this.pendingCallback = callback;
            return;
          }
        } catch (e32) {
          return callback(e32);
        }
        return callback();
      }
      async _final(callback) {
        try {
          const digest = await this.checksum.digest();
          const received = this.base64Encoder(digest);
          if (this.expectedChecksum !== received) {
            return callback(new Error(`Checksum mismatch: expected "${this.expectedChecksum}" but received "${received}" in response header "${this.checksumSourceLocation}".`));
          }
        } catch (e32) {
          return callback(e32);
        }
        this.push(null);
        return callback();
      }
    };
    exports2.ChecksumStream = ChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/stream-type-check.js
var require_stream_type_check10 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/stream-type-check.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isBlob = exports2.isReadableStream = void 0;
    var isReadableStream6 = /* @__PURE__ */ __name((stream) => typeof ReadableStream === "function" && (stream?.constructor?.name === ReadableStream.name || stream instanceof ReadableStream), "isReadableStream");
    exports2.isReadableStream = isReadableStream6;
    var isBlob3 = /* @__PURE__ */ __name((blob) => {
      return typeof Blob === "function" && (blob?.constructor?.name === Blob.name || blob instanceof Blob);
    }, "isBlob");
    exports2.isBlob = isBlob3;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.browser.js
var require_ChecksumStream_browser10 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ChecksumStream = void 0;
    var ReadableStreamRef3 = typeof ReadableStream === "function" ? ReadableStream : function() {
    };
    var ChecksumStream5 = class extends ReadableStreamRef3 {
      static {
        __name(this, "ChecksumStream");
      }
    };
    exports2.ChecksumStream = ChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.browser.js
var require_createChecksumStream_browser10 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createChecksumStream = void 0;
    var util_base64_1 = require_dist_cjs10();
    var stream_type_check_1 = require_stream_type_check10();
    var ChecksumStream_browser_1 = require_ChecksumStream_browser10();
    var createChecksumStream5 = /* @__PURE__ */ __name(({ expectedChecksum, checksum, source, checksumSourceLocation, base64Encoder }) => {
      if (!(0, stream_type_check_1.isReadableStream)(source)) {
        throw new Error(`@smithy/util-stream: unsupported source type ${source?.constructor?.name ?? source} in ChecksumStream.`);
      }
      const encoder = base64Encoder ?? util_base64_1.toBase64;
      if (typeof TransformStream !== "function") {
        throw new Error("@smithy/util-stream: unable to instantiate ChecksumStream because API unavailable: ReadableStream/TransformStream.");
      }
      const transform = new TransformStream({
        start() {
        },
        async transform(chunk, controller) {
          checksum.update(chunk);
          controller.enqueue(chunk);
        },
        async flush(controller) {
          const digest = await checksum.digest();
          const received = encoder(digest);
          if (expectedChecksum !== received) {
            const error4 = new Error(`Checksum mismatch: expected "${expectedChecksum}" but received "${received}" in response header "${checksumSourceLocation}".`);
            controller.error(error4);
          } else {
            controller.terminate();
          }
        }
      });
      source.pipeThrough(transform);
      const readable = transform.readable;
      Object.setPrototypeOf(readable, ChecksumStream_browser_1.ChecksumStream.prototype);
      return readable;
    }, "createChecksumStream");
    exports2.createChecksumStream = createChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.js
var require_createChecksumStream10 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createChecksumStream = createChecksumStream5;
    var stream_type_check_1 = require_stream_type_check10();
    var ChecksumStream_1 = require_ChecksumStream10();
    var createChecksumStream_browser_1 = require_createChecksumStream_browser10();
    function createChecksumStream5(init) {
      if (typeof ReadableStream === "function" && (0, stream_type_check_1.isReadableStream)(init.source)) {
        return (0, createChecksumStream_browser_1.createChecksumStream)(init);
      }
      return new ChecksumStream_1.ChecksumStream(init);
    }
    __name(createChecksumStream5, "createChecksumStream");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/ByteArrayCollector.js
var require_ByteArrayCollector10 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/ByteArrayCollector.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ByteArrayCollector = void 0;
    var ByteArrayCollector3 = class {
      static {
        __name(this, "ByteArrayCollector");
      }
      allocByteArray;
      byteLength = 0;
      byteArrays = [];
      constructor(allocByteArray) {
        this.allocByteArray = allocByteArray;
      }
      push(byteArray) {
        this.byteArrays.push(byteArray);
        this.byteLength += byteArray.byteLength;
      }
      flush() {
        if (this.byteArrays.length === 1) {
          const bytes = this.byteArrays[0];
          this.reset();
          return bytes;
        }
        const aggregation = this.allocByteArray(this.byteLength);
        let cursor3 = 0;
        for (let i32 = 0; i32 < this.byteArrays.length; ++i32) {
          const bytes = this.byteArrays[i32];
          aggregation.set(bytes, cursor3);
          cursor3 += bytes.byteLength;
        }
        this.reset();
        return aggregation;
      }
      reset() {
        this.byteArrays = [];
        this.byteLength = 0;
      }
    };
    exports2.ByteArrayCollector = ByteArrayCollector3;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadableStream.js
var require_createBufferedReadableStream10 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadableStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createBufferedReadable = void 0;
    exports2.createBufferedReadableStream = createBufferedReadableStream3;
    exports2.merge = merge3;
    exports2.flush = flush3;
    exports2.sizeOf = sizeOf3;
    exports2.modeOf = modeOf3;
    var ByteArrayCollector_1 = require_ByteArrayCollector10();
    function createBufferedReadableStream3(upstream, size, logger5) {
      const reader = upstream.getReader();
      let streamBufferingLoggedWarning = false;
      let bytesSeen = 0;
      const buffers = ["", new ByteArrayCollector_1.ByteArrayCollector((size2) => new Uint8Array(size2))];
      let mode = -1;
      const pull = /* @__PURE__ */ __name(async (controller) => {
        const { value, done } = await reader.read();
        const chunk = value;
        if (done) {
          if (mode !== -1) {
            const remainder = flush3(buffers, mode);
            if (sizeOf3(remainder) > 0) {
              controller.enqueue(remainder);
            }
          }
          controller.close();
        } else {
          const chunkMode = modeOf3(chunk, false);
          if (mode !== chunkMode) {
            if (mode >= 0) {
              controller.enqueue(flush3(buffers, mode));
            }
            mode = chunkMode;
          }
          if (mode === -1) {
            controller.enqueue(chunk);
            return;
          }
          const chunkSize = sizeOf3(chunk);
          bytesSeen += chunkSize;
          const bufferSize = sizeOf3(buffers[mode]);
          if (chunkSize >= size && bufferSize === 0) {
            controller.enqueue(chunk);
          } else {
            const newSize = merge3(buffers, mode, chunk);
            if (!streamBufferingLoggedWarning && bytesSeen > size * 2) {
              streamBufferingLoggedWarning = true;
              logger5?.warn(`@smithy/util-stream - stream chunk size ${chunkSize} is below threshold of ${size}, automatically buffering.`);
            }
            if (newSize >= size) {
              controller.enqueue(flush3(buffers, mode));
            } else {
              await pull(controller);
            }
          }
        }
      }, "pull");
      return new ReadableStream({
        pull
      });
    }
    __name(createBufferedReadableStream3, "createBufferedReadableStream");
    exports2.createBufferedReadable = createBufferedReadableStream3;
    function merge3(buffers, mode, chunk) {
      switch (mode) {
        case 0:
          buffers[0] += chunk;
          return sizeOf3(buffers[0]);
        case 1:
        case 2:
          buffers[mode].push(chunk);
          return sizeOf3(buffers[mode]);
      }
    }
    __name(merge3, "merge");
    function flush3(buffers, mode) {
      switch (mode) {
        case 0:
          const s = buffers[0];
          buffers[0] = "";
          return s;
        case 1:
        case 2:
          return buffers[mode].flush();
      }
      throw new Error(`@smithy/util-stream - invalid index ${mode} given to flush()`);
    }
    __name(flush3, "flush");
    function sizeOf3(chunk) {
      return chunk?.byteLength ?? chunk?.length ?? 0;
    }
    __name(sizeOf3, "sizeOf");
    function modeOf3(chunk, allowBuffer = true) {
      if (allowBuffer && typeof Buffer !== "undefined" && chunk instanceof Buffer) {
        return 2;
      }
      if (chunk instanceof Uint8Array) {
        return 1;
      }
      if (typeof chunk === "string") {
        return 0;
      }
      return -1;
    }
    __name(modeOf3, "modeOf");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadable.js
var require_createBufferedReadable10 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadable.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createBufferedReadable = createBufferedReadable3;
    var node_stream_1 = require("node:stream");
    var ByteArrayCollector_1 = require_ByteArrayCollector10();
    var createBufferedReadableStream_1 = require_createBufferedReadableStream10();
    var stream_type_check_1 = require_stream_type_check10();
    function createBufferedReadable3(upstream, size, logger5) {
      if ((0, stream_type_check_1.isReadableStream)(upstream)) {
        return (0, createBufferedReadableStream_1.createBufferedReadableStream)(upstream, size, logger5);
      }
      const downstream = new node_stream_1.Readable({ read() {
      } });
      let streamBufferingLoggedWarning = false;
      let bytesSeen = 0;
      const buffers = [
        "",
        new ByteArrayCollector_1.ByteArrayCollector((size2) => new Uint8Array(size2)),
        new ByteArrayCollector_1.ByteArrayCollector((size2) => Buffer.from(new Uint8Array(size2)))
      ];
      let mode = -1;
      upstream.on("data", (chunk) => {
        const chunkMode = (0, createBufferedReadableStream_1.modeOf)(chunk, true);
        if (mode !== chunkMode) {
          if (mode >= 0) {
            downstream.push((0, createBufferedReadableStream_1.flush)(buffers, mode));
          }
          mode = chunkMode;
        }
        if (mode === -1) {
          downstream.push(chunk);
          return;
        }
        const chunkSize = (0, createBufferedReadableStream_1.sizeOf)(chunk);
        bytesSeen += chunkSize;
        const bufferSize = (0, createBufferedReadableStream_1.sizeOf)(buffers[mode]);
        if (chunkSize >= size && bufferSize === 0) {
          downstream.push(chunk);
        } else {
          const newSize = (0, createBufferedReadableStream_1.merge)(buffers, mode, chunk);
          if (!streamBufferingLoggedWarning && bytesSeen > size * 2) {
            streamBufferingLoggedWarning = true;
            logger5?.warn(`@smithy/util-stream - stream chunk size ${chunkSize} is below threshold of ${size}, automatically buffering.`);
          }
          if (newSize >= size) {
            downstream.push((0, createBufferedReadableStream_1.flush)(buffers, mode));
          }
        }
      });
      upstream.on("end", () => {
        if (mode !== -1) {
          const remainder = (0, createBufferedReadableStream_1.flush)(buffers, mode);
          if ((0, createBufferedReadableStream_1.sizeOf)(remainder) > 0) {
            downstream.push(remainder);
          }
        }
        downstream.push(null);
      });
      return downstream;
    }
    __name(createBufferedReadable3, "createBufferedReadable");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.browser.js
var require_getAwsChunkedEncodingStream_browser10 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getAwsChunkedEncodingStream = void 0;
    var getAwsChunkedEncodingStream5 = /* @__PURE__ */ __name((readableStream, options) => {
      const { base64Encoder, bodyLengthChecker, checksumAlgorithmFn, checksumLocationName, streamHasher } = options;
      const checksumRequired = base64Encoder !== void 0 && bodyLengthChecker !== void 0 && checksumAlgorithmFn !== void 0 && checksumLocationName !== void 0 && streamHasher !== void 0;
      const digest = checksumRequired ? streamHasher(checksumAlgorithmFn, readableStream) : void 0;
      const reader = readableStream.getReader();
      return new ReadableStream({
        async pull(controller) {
          const { value, done } = await reader.read();
          if (done) {
            controller.enqueue(`0\r
`);
            if (checksumRequired) {
              const checksum = base64Encoder(await digest);
              controller.enqueue(`${checksumLocationName}:${checksum}\r
`);
              controller.enqueue(`\r
`);
            }
            controller.close();
          } else {
            controller.enqueue(`${(bodyLengthChecker(value) || 0).toString(16)}\r
${value}\r
`);
          }
        }
      });
    }, "getAwsChunkedEncodingStream");
    exports2.getAwsChunkedEncodingStream = getAwsChunkedEncodingStream5;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.js
var require_getAwsChunkedEncodingStream10 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getAwsChunkedEncodingStream = getAwsChunkedEncodingStream5;
    var node_stream_1 = require("node:stream");
    var getAwsChunkedEncodingStream_browser_1 = require_getAwsChunkedEncodingStream_browser10();
    var stream_type_check_1 = require_stream_type_check10();
    function getAwsChunkedEncodingStream5(stream, options) {
      const readable = stream;
      const readableStream = stream;
      if ((0, stream_type_check_1.isReadableStream)(readableStream)) {
        return (0, getAwsChunkedEncodingStream_browser_1.getAwsChunkedEncodingStream)(readableStream, options);
      }
      const { base64Encoder, bodyLengthChecker, checksumAlgorithmFn, checksumLocationName, streamHasher } = options;
      const checksumRequired = base64Encoder !== void 0 && checksumAlgorithmFn !== void 0 && checksumLocationName !== void 0 && streamHasher !== void 0;
      const digest = checksumRequired ? streamHasher(checksumAlgorithmFn, readable) : void 0;
      const awsChunkedEncodingStream = new node_stream_1.Readable({
        read: /* @__PURE__ */ __name(() => {
        }, "read")
      });
      readable.on("data", (data3) => {
        const length = bodyLengthChecker(data3) || 0;
        if (length === 0) {
          return;
        }
        awsChunkedEncodingStream.push(`${length.toString(16)}\r
`);
        awsChunkedEncodingStream.push(data3);
        awsChunkedEncodingStream.push("\r\n");
      });
      readable.on("end", async () => {
        awsChunkedEncodingStream.push(`0\r
`);
        if (checksumRequired) {
          const checksum = base64Encoder(await digest);
          awsChunkedEncodingStream.push(`${checksumLocationName}:${checksum}\r
`);
          awsChunkedEncodingStream.push(`\r
`);
        }
        awsChunkedEncodingStream.push(null);
      });
      return awsChunkedEncodingStream;
    }
    __name(getAwsChunkedEncodingStream5, "getAwsChunkedEncodingStream");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/headStream.browser.js
var require_headStream_browser10 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/headStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.headStream = headStream5;
    async function headStream5(stream, bytes) {
      let byteLengthCounter = 0;
      const chunks2 = [];
      const reader = stream.getReader();
      let isDone = false;
      while (!isDone) {
        const { done, value } = await reader.read();
        if (value) {
          chunks2.push(value);
          byteLengthCounter += value?.byteLength ?? 0;
        }
        if (byteLengthCounter >= bytes) {
          break;
        }
        isDone = done;
      }
      reader.releaseLock();
      const collected = new Uint8Array(Math.min(bytes, byteLengthCounter));
      let offset = 0;
      for (const chunk of chunks2) {
        if (chunk.byteLength > collected.byteLength - offset) {
          collected.set(chunk.subarray(0, collected.byteLength - offset), offset);
          break;
        } else {
          collected.set(chunk, offset);
        }
        offset += chunk.length;
      }
      return collected;
    }
    __name(headStream5, "headStream");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/headStream.js
var require_headStream10 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/headStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.headStream = void 0;
    var stream_1 = require("stream");
    var headStream_browser_1 = require_headStream_browser10();
    var stream_type_check_1 = require_stream_type_check10();
    var headStream5 = /* @__PURE__ */ __name((stream, bytes) => {
      if ((0, stream_type_check_1.isReadableStream)(stream)) {
        return (0, headStream_browser_1.headStream)(stream, bytes);
      }
      return new Promise((resolve13, reject) => {
        const collector = new Collector8();
        collector.limit = bytes;
        stream.pipe(collector);
        stream.on("error", (err) => {
          collector.end();
          reject(err);
        });
        collector.on("error", reject);
        collector.on("finish", function() {
          const bytes2 = new Uint8Array(Buffer.concat(this.buffers));
          resolve13(bytes2);
        });
      });
    }, "headStream");
    exports2.headStream = headStream5;
    var Collector8 = class extends stream_1.Writable {
      static {
        __name(this, "Collector");
      }
      buffers = [];
      limit = Infinity;
      bytesBuffered = 0;
      _write(chunk, encoding, callback) {
        this.buffers.push(chunk);
        this.bytesBuffered += chunk.byteLength ?? 0;
        if (this.bytesBuffered >= this.limit) {
          const excess = this.bytesBuffered - this.limit;
          const tailBuffer = this.buffers[this.buffers.length - 1];
          this.buffers[this.buffers.length - 1] = tailBuffer.subarray(0, tailBuffer.byteLength - excess);
          this.emit("finish");
        }
        callback();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.browser.js
var require_sdk_stream_mixin_browser10 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.sdkStreamMixin = void 0;
    var fetch_http_handler_1 = require_dist_cjs14();
    var util_base64_1 = require_dist_cjs10();
    var util_hex_encoding_1 = require_dist_cjs15();
    var util_utf8_1 = require_dist_cjs9();
    var stream_type_check_1 = require_stream_type_check10();
    var ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11 = "The stream has already been transformed.";
    var sdkStreamMixin12 = /* @__PURE__ */ __name((stream) => {
      if (!isBlobInstance6(stream) && !(0, stream_type_check_1.isReadableStream)(stream)) {
        const name = stream?.__proto__?.constructor?.name || stream;
        throw new Error(`Unexpected stream implementation, expect Blob or ReadableStream, got ${name}`);
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
        }
        transformed = true;
        return await (0, fetch_http_handler_1.streamCollector)(stream);
      }, "transformToByteArray");
      const blobToWebStream = /* @__PURE__ */ __name((blob) => {
        if (typeof blob.stream !== "function") {
          throw new Error("Cannot transform payload Blob to web stream. Please make sure the Blob.stream() is polyfilled.\nIf you are using React Native, this API is not yet supported, see: https://react-native.canny.io/feature-requests/p/fetch-streaming-body");
        }
        return blob.stream();
      }, "blobToWebStream");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === "base64") {
            return (0, util_base64_1.toBase64)(buf);
          } else if (encoding === "hex") {
            return (0, util_hex_encoding_1.toHex)(buf);
          } else if (encoding === void 0 || encoding === "utf8" || encoding === "utf-8") {
            return (0, util_utf8_1.toUtf8)(buf);
          } else if (typeof TextDecoder === "function") {
            return new TextDecoder(encoding).decode(buf);
          } else {
            throw new Error("TextDecoder is not available, please make sure polyfill is provided.");
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
          }
          transformed = true;
          if (isBlobInstance6(stream)) {
            return blobToWebStream(stream);
          } else if ((0, stream_type_check_1.isReadableStream)(stream)) {
            return stream;
          } else {
            throw new Error(`Cannot transform payload to web stream, got ${stream}`);
          }
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
    exports2.sdkStreamMixin = sdkStreamMixin12;
    var isBlobInstance6 = /* @__PURE__ */ __name((stream) => typeof Blob === "function" && stream instanceof Blob, "isBlobInstance");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.js
var require_sdk_stream_mixin10 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.sdkStreamMixin = void 0;
    var node_http_handler_1 = require_dist_cjs13();
    var util_buffer_from_1 = require_dist_cjs8();
    var stream_1 = require("stream");
    var sdk_stream_mixin_browser_1 = require_sdk_stream_mixin_browser10();
    var ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11 = "The stream has already been transformed.";
    var sdkStreamMixin12 = /* @__PURE__ */ __name((stream) => {
      if (!(stream instanceof stream_1.Readable)) {
        try {
          return (0, sdk_stream_mixin_browser_1.sdkStreamMixin)(stream);
        } catch (e32) {
          const name = stream?.__proto__?.constructor?.name || stream;
          throw new Error(`Unexpected stream implementation, expect Stream.Readable instance, got ${name}`);
        }
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
        }
        transformed = true;
        return await (0, node_http_handler_1.streamCollector)(stream);
      }, "transformToByteArray");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === void 0 || Buffer.isEncoding(encoding)) {
            return (0, util_buffer_from_1.fromArrayBuffer)(buf.buffer, buf.byteOffset, buf.byteLength).toString(encoding);
          } else {
            const decoder = new TextDecoder(encoding);
            return decoder.decode(buf);
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
          }
          if (stream.readableFlowing !== null) {
            throw new Error("The stream has been consumed by other callbacks.");
          }
          if (typeof stream_1.Readable.toWeb !== "function") {
            throw new Error("Readable.toWeb() is not supported. Please ensure a polyfill is available.");
          }
          transformed = true;
          return stream_1.Readable.toWeb(stream);
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
    exports2.sdkStreamMixin = sdkStreamMixin12;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/splitStream.browser.js
var require_splitStream_browser10 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/splitStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.splitStream = splitStream5;
    async function splitStream5(stream) {
      if (typeof stream.stream === "function") {
        stream = stream.stream();
      }
      const readableStream = stream;
      return readableStream.tee();
    }
    __name(splitStream5, "splitStream");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/splitStream.js
var require_splitStream10 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/splitStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.splitStream = splitStream5;
    var stream_1 = require("stream");
    var splitStream_browser_1 = require_splitStream_browser10();
    var stream_type_check_1 = require_stream_type_check10();
    async function splitStream5(stream) {
      if ((0, stream_type_check_1.isReadableStream)(stream) || (0, stream_type_check_1.isBlob)(stream)) {
        return (0, splitStream_browser_1.splitStream)(stream);
      }
      const stream1 = new stream_1.PassThrough();
      const stream2 = new stream_1.PassThrough();
      stream.pipe(stream1);
      stream.pipe(stream2);
      return [stream1, stream2];
    }
    __name(splitStream5, "splitStream");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/index.js
var require_dist_cjs200 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-stream/dist-cjs/index.js"(exports2) {
    "use strict";
    var utilBase64 = require_dist_cjs10();
    var utilUtf8 = require_dist_cjs9();
    var ChecksumStream5 = require_ChecksumStream10();
    var createChecksumStream5 = require_createChecksumStream10();
    var createBufferedReadable3 = require_createBufferedReadable10();
    var getAwsChunkedEncodingStream5 = require_getAwsChunkedEncodingStream10();
    var headStream5 = require_headStream10();
    var sdkStreamMixin12 = require_sdk_stream_mixin10();
    var splitStream5 = require_splitStream10();
    var streamTypeCheck = require_stream_type_check10();
    var Uint8ArrayBlobAdapter8 = class _Uint8ArrayBlobAdapter extends Uint8Array {
      static {
        __name(this, "Uint8ArrayBlobAdapter");
      }
      static fromString(source, encoding = "utf-8") {
        if (typeof source === "string") {
          if (encoding === "base64") {
            return _Uint8ArrayBlobAdapter.mutate(utilBase64.fromBase64(source));
          }
          return _Uint8ArrayBlobAdapter.mutate(utilUtf8.fromUtf8(source));
        }
        throw new Error(`Unsupported conversion from ${typeof source} to Uint8ArrayBlobAdapter.`);
      }
      static mutate(source) {
        Object.setPrototypeOf(source, _Uint8ArrayBlobAdapter.prototype);
        return source;
      }
      transformToString(encoding = "utf-8") {
        if (encoding === "base64") {
          return utilBase64.toBase64(this);
        }
        return utilUtf8.toUtf8(this);
      }
    };
    exports2.isBlob = streamTypeCheck.isBlob;
    exports2.isReadableStream = streamTypeCheck.isReadableStream;
    exports2.Uint8ArrayBlobAdapter = Uint8ArrayBlobAdapter8;
    Object.prototype.hasOwnProperty.call(ChecksumStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: ChecksumStream5["__proto__"]
    });
    Object.keys(ChecksumStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = ChecksumStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(createChecksumStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: createChecksumStream5["__proto__"]
    });
    Object.keys(createChecksumStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = createChecksumStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(createBufferedReadable3, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: createBufferedReadable3["__proto__"]
    });
    Object.keys(createBufferedReadable3).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = createBufferedReadable3[k32];
    });
    Object.prototype.hasOwnProperty.call(getAwsChunkedEncodingStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: getAwsChunkedEncodingStream5["__proto__"]
    });
    Object.keys(getAwsChunkedEncodingStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = getAwsChunkedEncodingStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(headStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: headStream5["__proto__"]
    });
    Object.keys(headStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = headStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(sdkStreamMixin12, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: sdkStreamMixin12["__proto__"]
    });
    Object.keys(sdkStreamMixin12).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = sdkStreamMixin12[k32];
    });
    Object.prototype.hasOwnProperty.call(splitStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: splitStream5["__proto__"]
    });
    Object.keys(splitStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = splitStream5[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/requestHelpers.js
var require_requestHelpers9 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/requestHelpers.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createGetRequest = createGetRequest;
    exports2.getCredentials = getCredentials;
    var property_provider_1 = require_dist_cjs27();
    var protocol_http_1 = require_dist_cjs2();
    var smithy_client_1 = require_dist_cjs34();
    var util_stream_1 = require_dist_cjs200();
    function createGetRequest(url) {
      return new protocol_http_1.HttpRequest({
        protocol: url.protocol,
        hostname: url.hostname,
        port: Number(url.port),
        path: url.pathname,
        query: Array.from(url.searchParams.entries()).reduce((acc, [k32, v]) => {
          acc[k32] = v;
          return acc;
        }, {}),
        fragment: url.hash
      });
    }
    __name(createGetRequest, "createGetRequest");
    async function getCredentials(response, logger5) {
      const stream = (0, util_stream_1.sdkStreamMixin)(response.body);
      const str = await stream.transformToString();
      if (response.statusCode === 200) {
        const parsed = JSON.parse(str);
        if (typeof parsed.AccessKeyId !== "string" || typeof parsed.SecretAccessKey !== "string" || typeof parsed.Token !== "string" || typeof parsed.Expiration !== "string") {
          throw new property_provider_1.CredentialsProviderError("HTTP credential provider response not of the required format, an object matching: { AccessKeyId: string, SecretAccessKey: string, Token: string, Expiration: string(rfc3339) }", { logger: logger5 });
        }
        return {
          accessKeyId: parsed.AccessKeyId,
          secretAccessKey: parsed.SecretAccessKey,
          sessionToken: parsed.Token,
          expiration: (0, smithy_client_1.parseRfc3339DateTime)(parsed.Expiration)
        };
      }
      if (response.statusCode >= 400 && response.statusCode < 500) {
        let parsedBody = {};
        try {
          parsedBody = JSON.parse(str);
        } catch (e32) {
        }
        throw Object.assign(new property_provider_1.CredentialsProviderError(`Server responded with status: ${response.statusCode}`, { logger: logger5 }), {
          Code: parsedBody.Code,
          Message: parsedBody.Message
        });
      }
      throw new property_provider_1.CredentialsProviderError(`Server responded with status: ${response.statusCode}`, { logger: logger5 });
    }
    __name(getCredentials, "getCredentials");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/retry-wrapper.js
var require_retry_wrapper9 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/retry-wrapper.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.retryWrapper = void 0;
    var retryWrapper = /* @__PURE__ */ __name((toRetry, maxRetries, delayMs) => {
      return async () => {
        for (let i32 = 0; i32 < maxRetries; ++i32) {
          try {
            return await toRetry();
          } catch (e32) {
            await new Promise((resolve13) => setTimeout(resolve13, delayMs));
          }
        }
        return await toRetry();
      };
    }, "retryWrapper");
    exports2.retryWrapper = retryWrapper;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/fromHttp.js
var require_fromHttp9 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-http/dist-cjs/fromHttp/fromHttp.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromHttp = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var client_1 = (init_client19(), __toCommonJS(client_exports14));
    var node_http_handler_1 = require_dist_cjs13();
    var property_provider_1 = require_dist_cjs27();
    var promises_1 = tslib_1.__importDefault(require("node:fs/promises"));
    var checkUrl_1 = require_checkUrl9();
    var requestHelpers_1 = require_requestHelpers9();
    var retry_wrapper_1 = require_retry_wrapper9();
    var AWS_CONTAINER_CREDENTIALS_RELATIVE_URI = "AWS_CONTAINER_CREDENTIALS_RELATIVE_URI";
    var DEFAULT_LINK_LOCAL_HOST = "http://169.254.170.2";
    var AWS_CONTAINER_CREDENTIALS_FULL_URI = "AWS_CONTAINER_CREDENTIALS_FULL_URI";
    var AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE = "AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE";
    var AWS_CONTAINER_AUTHORIZATION_TOKEN = "AWS_CONTAINER_AUTHORIZATION_TOKEN";
    var fromHttp = /* @__PURE__ */ __name((options = {}) => {
      options.logger?.debug("@aws-sdk/credential-provider-http - fromHttp");
      let host;
      const relative5 = options.awsContainerCredentialsRelativeUri ?? process.env[AWS_CONTAINER_CREDENTIALS_RELATIVE_URI];
      const full = options.awsContainerCredentialsFullUri ?? process.env[AWS_CONTAINER_CREDENTIALS_FULL_URI];
      const token = options.awsContainerAuthorizationToken ?? process.env[AWS_CONTAINER_AUTHORIZATION_TOKEN];
      const tokenFile = options.awsContainerAuthorizationTokenFile ?? process.env[AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE];
      const warn2 = options.logger?.constructor?.name === "NoOpLogger" || !options.logger?.warn ? console.warn : options.logger.warn.bind(options.logger);
      if (relative5 && full) {
        warn2("@aws-sdk/credential-provider-http: you have set both awsContainerCredentialsRelativeUri and awsContainerCredentialsFullUri.");
        warn2("awsContainerCredentialsFullUri will take precedence.");
      }
      if (token && tokenFile) {
        warn2("@aws-sdk/credential-provider-http: you have set both awsContainerAuthorizationToken and awsContainerAuthorizationTokenFile.");
        warn2("awsContainerAuthorizationToken will take precedence.");
      }
      if (full) {
        host = full;
      } else if (relative5) {
        host = `${DEFAULT_LINK_LOCAL_HOST}${relative5}`;
      } else {
        throw new property_provider_1.CredentialsProviderError(`No HTTP credential provider host provided.
Set AWS_CONTAINER_CREDENTIALS_FULL_URI or AWS_CONTAINER_CREDENTIALS_RELATIVE_URI.`, { logger: options.logger });
      }
      const url = new URL(host);
      (0, checkUrl_1.checkUrl)(url, options.logger);
      const requestHandler = node_http_handler_1.NodeHttpHandler.create({
        requestTimeout: options.timeout ?? 1e3,
        connectionTimeout: options.timeout ?? 1e3
      });
      return (0, retry_wrapper_1.retryWrapper)(async () => {
        const request4 = (0, requestHelpers_1.createGetRequest)(url);
        if (token) {
          request4.headers.Authorization = token;
        } else if (tokenFile) {
          request4.headers.Authorization = (await promises_1.default.readFile(tokenFile)).toString();
        }
        try {
          const result2 = await requestHandler.handle(request4);
          return (0, requestHelpers_1.getCredentials)(result2.response).then((creds) => (0, client_1.setCredentialFeature)(creds, "CREDENTIALS_HTTP", "z"));
        } catch (e32) {
          throw new property_provider_1.CredentialsProviderError(String(e32), { logger: options.logger });
        }
      }, options.maxRetries ?? 3, options.timeout ?? 1e3);
    }, "fromHttp");
    exports2.fromHttp = fromHttp;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-http/dist-cjs/index.js
var require_dist_cjs201 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-http/dist-cjs/index.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromHttp = void 0;
    var fromHttp_1 = require_fromHttp9();
    Object.defineProperty(exports2, "fromHttp", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return fromHttp_1.fromHttp;
    }, "get") });
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption29(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "awsssoportal",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption29(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var import_util_middleware30, defaultSSOHttpAuthSchemeParametersProvider9, defaultSSOHttpAuthSchemeProvider9, resolveHttpAuthSchemeConfig29;
var init_httpAuthSchemeProvider29 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes12();
    import_util_middleware30 = __toESM(require_dist_cjs6());
    defaultSSOHttpAuthSchemeParametersProvider9 = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, import_util_middleware30.getSmithyContext)(context).operation,
        region: await (0, import_util_middleware30.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultSSOHttpAuthSchemeParametersProvider");
    __name(createAwsAuthSigv4HttpAuthOption29, "createAwsAuthSigv4HttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption29, "createSmithyApiNoAuthHttpAuthOption");
    defaultSSOHttpAuthSchemeProvider9 = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "GetRoleCredentials": {
          options.push(createSmithyApiNoAuthHttpAuthOption29(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption29(authParameters));
        }
      }
      return options;
    }, "defaultSSOHttpAuthSchemeProvider");
    resolveHttpAuthSchemeConfig29 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveAwsSdkSigV4Config10(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, import_util_middleware30.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/EndpointParameters.js
var resolveClientEndpointParameters29, commonParams29;
var init_EndpointParameters29 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters29 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "awsssoportal"
      });
    }, "resolveClientEndpointParameters");
    commonParams29 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/package.json
var package_default10;
var init_package10 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/package.json"() {
    package_default10 = {
      name: "@aws-sdk/nested-clients",
      version: "3.997.6",
      description: "Nested clients for AWS SDK packages.",
      main: "./dist-cjs/index.js",
      module: "./dist-es/index.js",
      types: "./dist-types/index.d.ts",
      scripts: {
        build: "yarn lint && concurrently 'yarn:build:types' 'yarn:build:es' && yarn build:cjs",
        "build:cjs": "node ../../scripts/compilation/inline nested-clients",
        "build:es": "tsc -p tsconfig.es.json",
        "build:include:deps": 'yarn g:turbo run build -F="$npm_package_name"',
        "build:types": "tsc -p tsconfig.types.json",
        "build:types:downlevel": "downlevel-dts dist-types dist-types/ts3.4",
        clean: "premove dist-cjs dist-es dist-types tsconfig.cjs.tsbuildinfo tsconfig.es.tsbuildinfo tsconfig.types.tsbuildinfo",
        lint: "node ../../scripts/validation/submodules-linter.js --pkg nested-clients",
        test: "yarn g:vitest run",
        "test:watch": "yarn g:vitest watch"
      },
      engines: {
        node: ">=20.0.0"
      },
      sideEffects: false,
      author: {
        name: "AWS SDK for JavaScript Team",
        url: "https://aws.amazon.com/javascript/"
      },
      license: "Apache-2.0",
      dependencies: {
        "@aws-crypto/sha256-browser": "5.2.0",
        "@aws-crypto/sha256-js": "5.2.0",
        "@aws-sdk/core": "^3.974.8",
        "@aws-sdk/middleware-host-header": "^3.972.10",
        "@aws-sdk/middleware-logger": "^3.972.10",
        "@aws-sdk/middleware-recursion-detection": "^3.972.11",
        "@aws-sdk/middleware-user-agent": "^3.972.38",
        "@aws-sdk/region-config-resolver": "^3.972.13",
        "@aws-sdk/signature-v4-multi-region": "^3.996.25",
        "@aws-sdk/types": "^3.973.8",
        "@aws-sdk/util-endpoints": "^3.996.8",
        "@aws-sdk/util-user-agent-browser": "^3.972.10",
        "@aws-sdk/util-user-agent-node": "^3.973.24",
        "@smithy/config-resolver": "^4.4.17",
        "@smithy/core": "^3.23.17",
        "@smithy/fetch-http-handler": "^5.3.17",
        "@smithy/hash-node": "^4.2.14",
        "@smithy/invalid-dependency": "^4.2.14",
        "@smithy/middleware-content-length": "^4.2.14",
        "@smithy/middleware-endpoint": "^4.4.32",
        "@smithy/middleware-retry": "^4.5.7",
        "@smithy/middleware-serde": "^4.2.20",
        "@smithy/middleware-stack": "^4.2.14",
        "@smithy/node-config-provider": "^4.3.14",
        "@smithy/node-http-handler": "^4.6.1",
        "@smithy/protocol-http": "^5.3.14",
        "@smithy/smithy-client": "^4.12.13",
        "@smithy/types": "^4.14.1",
        "@smithy/url-parser": "^4.2.14",
        "@smithy/util-base64": "^4.3.2",
        "@smithy/util-body-length-browser": "^4.2.2",
        "@smithy/util-body-length-node": "^4.2.3",
        "@smithy/util-defaults-mode-browser": "^4.3.49",
        "@smithy/util-defaults-mode-node": "^4.2.54",
        "@smithy/util-endpoints": "^3.4.2",
        "@smithy/util-middleware": "^4.2.14",
        "@smithy/util-retry": "^4.3.6",
        "@smithy/util-utf8": "^4.2.2",
        tslib: "^2.6.2"
      },
      devDependencies: {
        concurrently: "7.0.0",
        "downlevel-dts": "0.10.1",
        premove: "4.0.0",
        typescript: "~5.8.3"
      },
      typesVersions: {
        "<4.5": {
          "dist-types/*": [
            "dist-types/ts3.4/*"
          ]
        }
      },
      files: [
        "./cognito-identity.d.ts",
        "./cognito-identity.js",
        "./signin.d.ts",
        "./signin.js",
        "./sso-oidc.d.ts",
        "./sso-oidc.js",
        "./sso.d.ts",
        "./sso.js",
        "./sts.d.ts",
        "./sts.js",
        "dist-*/**"
      ],
      browser: {
        "./dist-es/submodules/cognito-identity/runtimeConfig": "./dist-es/submodules/cognito-identity/runtimeConfig.browser",
        "./dist-es/submodules/signin/runtimeConfig": "./dist-es/submodules/signin/runtimeConfig.browser",
        "./dist-es/submodules/sso-oidc/runtimeConfig": "./dist-es/submodules/sso-oidc/runtimeConfig.browser",
        "./dist-es/submodules/sso/runtimeConfig": "./dist-es/submodules/sso/runtimeConfig.browser",
        "./dist-es/submodules/sts/runtimeConfig": "./dist-es/submodules/sts/runtimeConfig.browser"
      },
      "react-native": {},
      homepage: "https://github.com/aws/aws-sdk-js-v3/tree/main/packages/nested-clients",
      repository: {
        type: "git",
        url: "https://github.com/aws/aws-sdk-js-v3.git",
        directory: "packages/nested-clients"
      },
      exports: {
        "./package.json": "./package.json",
        "./sso-oidc": {
          types: "./dist-types/submodules/sso-oidc/index.d.ts",
          module: "./dist-es/submodules/sso-oidc/index.js",
          node: "./dist-cjs/submodules/sso-oidc/index.js",
          import: "./dist-es/submodules/sso-oidc/index.js",
          require: "./dist-cjs/submodules/sso-oidc/index.js"
        },
        "./sts": {
          types: "./dist-types/submodules/sts/index.d.ts",
          module: "./dist-es/submodules/sts/index.js",
          node: "./dist-cjs/submodules/sts/index.js",
          import: "./dist-es/submodules/sts/index.js",
          require: "./dist-cjs/submodules/sts/index.js"
        },
        "./signin": {
          types: "./dist-types/submodules/signin/index.d.ts",
          module: "./dist-es/submodules/signin/index.js",
          node: "./dist-cjs/submodules/signin/index.js",
          import: "./dist-es/submodules/signin/index.js",
          require: "./dist-cjs/submodules/signin/index.js"
        },
        "./cognito-identity": {
          types: "./dist-types/submodules/cognito-identity/index.d.ts",
          module: "./dist-es/submodules/cognito-identity/index.js",
          node: "./dist-cjs/submodules/cognito-identity/index.js",
          import: "./dist-es/submodules/cognito-identity/index.js",
          require: "./dist-cjs/submodules/cognito-identity/index.js"
        },
        "./sso": {
          types: "./dist-types/submodules/sso/index.d.ts",
          module: "./dist-es/submodules/sso/index.js",
          node: "./dist-cjs/submodules/sso/index.js",
          import: "./dist-es/submodules/sso/index.js",
          require: "./dist-cjs/submodules/sso/index.js"
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/util-user-agent-node/dist-cjs/index.js
var require_dist_cjs202 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/util-user-agent-node/dist-cjs/index.js"(exports2) {
    "use strict";
    var node_os = require("node:os");
    var node_process = require("node:process");
    var utilConfigProvider = require_dist_cjs24();
    var promises5 = require("node:fs/promises");
    var node_path = require("node:path");
    var middlewareUserAgent = require_dist_cjs197();
    var getRuntimeUserAgentPair2 = /* @__PURE__ */ __name(() => {
      const runtimesToCheck = ["deno", "bun", "llrt"];
      for (const runtime of runtimesToCheck) {
        if (node_process.versions[runtime]) {
          return [`md/${runtime}`, node_process.versions[runtime]];
        }
      }
      return ["md/nodejs", node_process.versions.node];
    }, "getRuntimeUserAgentPair");
    var getNodeModulesParentDirs2 = /* @__PURE__ */ __name((dirname14) => {
      const cwd = process.cwd();
      if (!dirname14) {
        return [cwd];
      }
      const normalizedPath = node_path.normalize(dirname14);
      const parts = normalizedPath.split(node_path.sep);
      const nodeModulesIndex = parts.indexOf("node_modules");
      const parentDir = nodeModulesIndex !== -1 ? parts.slice(0, nodeModulesIndex).join(node_path.sep) : normalizedPath;
      if (cwd === parentDir) {
        return [cwd];
      }
      return [parentDir, cwd];
    }, "getNodeModulesParentDirs");
    var SEMVER_REGEX2 = /^(0|[1-9]\d*)\.(0|[1-9]\d*)\.(0|[1-9]\d*)(?:-((?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*)(?:\.(?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*))*))?(?:\+[0-9a-zA-Z-]+(?:\.[0-9a-zA-Z-]+)*)?$/;
    var getSanitizedTypeScriptVersion2 = /* @__PURE__ */ __name((version = "") => {
      const match = version.match(SEMVER_REGEX2);
      if (!match) {
        return void 0;
      }
      const [major6, minor, patch, prerelease] = [match[1], match[2], match[3], match[4]];
      return prerelease ? `${major6}.${minor}.${patch}-${prerelease}` : `${major6}.${minor}.${patch}`;
    }, "getSanitizedTypeScriptVersion");
    var ALLOWED_PREFIXES2 = ["^", "~", ">=", "<=", ">", "<"];
    var ALLOWED_DIST_TAGS2 = ["latest", "beta", "dev", "rc", "insiders", "next"];
    var getSanitizedDevTypeScriptVersion2 = /* @__PURE__ */ __name((version = "") => {
      if (ALLOWED_DIST_TAGS2.includes(version)) {
        return version;
      }
      const prefix = ALLOWED_PREFIXES2.find((p10) => version.startsWith(p10)) ?? "";
      const sanitizedTypeScriptVersion = getSanitizedTypeScriptVersion2(version.slice(prefix.length));
      if (!sanitizedTypeScriptVersion) {
        return void 0;
      }
      return `${prefix}${sanitizedTypeScriptVersion}`;
    }, "getSanitizedDevTypeScriptVersion");
    var tscVersion2;
    var TS_PACKAGE_JSON2 = node_path.join("node_modules", "typescript", "package.json");
    var getTypeScriptUserAgentPair2 = /* @__PURE__ */ __name(async () => {
      if (tscVersion2 === null) {
        return void 0;
      } else if (typeof tscVersion2 === "string") {
        return ["md/tsc", tscVersion2];
      }
      let isTypeScriptDetectionDisabled = false;
      try {
        isTypeScriptDetectionDisabled = utilConfigProvider.booleanSelector(process.env, "AWS_SDK_JS_TYPESCRIPT_DETECTION_DISABLED", utilConfigProvider.SelectorType.ENV) || false;
      } catch {
      }
      if (isTypeScriptDetectionDisabled) {
        tscVersion2 = null;
        return void 0;
      }
      const dirname14 = typeof __dirname !== "undefined" ? __dirname : void 0;
      const nodeModulesParentDirs = getNodeModulesParentDirs2(dirname14);
      let versionFromApp;
      for (const nodeModulesParentDir of nodeModulesParentDirs) {
        try {
          const appPackageJsonPath = node_path.join(nodeModulesParentDir, "package.json");
          const packageJson = await promises5.readFile(appPackageJsonPath, "utf-8");
          const { dependencies, devDependencies } = JSON.parse(packageJson);
          const version = devDependencies?.typescript ?? dependencies?.typescript;
          if (typeof version !== "string") {
            continue;
          }
          versionFromApp = version;
          break;
        } catch {
        }
      }
      if (!versionFromApp) {
        tscVersion2 = null;
        return void 0;
      }
      let versionFromNodeModules;
      for (const nodeModulesParentDir of nodeModulesParentDirs) {
        try {
          const tsPackageJsonPath = node_path.join(nodeModulesParentDir, TS_PACKAGE_JSON2);
          const packageJson = await promises5.readFile(tsPackageJsonPath, "utf-8");
          const { version } = JSON.parse(packageJson);
          const sanitizedVersion2 = getSanitizedTypeScriptVersion2(version);
          if (typeof sanitizedVersion2 !== "string") {
            continue;
          }
          versionFromNodeModules = sanitizedVersion2;
          break;
        } catch {
        }
      }
      if (versionFromNodeModules) {
        tscVersion2 = versionFromNodeModules;
        return ["md/tsc", tscVersion2];
      }
      const sanitizedVersion = getSanitizedDevTypeScriptVersion2(versionFromApp);
      if (typeof sanitizedVersion !== "string") {
        tscVersion2 = null;
        return void 0;
      }
      tscVersion2 = `dev_${sanitizedVersion}`;
      return ["md/tsc", tscVersion2];
    }, "getTypeScriptUserAgentPair");
    var crtAvailability2 = {
      isCrtAvailable: false
    };
    var isCrtAvailable2 = /* @__PURE__ */ __name(() => {
      if (crtAvailability2.isCrtAvailable) {
        return ["md/crt-avail"];
      }
      return null;
    }, "isCrtAvailable");
    var createDefaultUserAgentProvider29 = /* @__PURE__ */ __name(({ serviceId, clientVersion }) => {
      const runtimeUserAgentPair = getRuntimeUserAgentPair2();
      return async (config2) => {
        const sections = [
          ["aws-sdk-js", clientVersion],
          ["ua", "2.1"],
          [`os/${node_os.platform()}`, node_os.release()],
          ["lang/js"],
          runtimeUserAgentPair
        ];
        const typescriptUserAgentPair = await getTypeScriptUserAgentPair2();
        if (typescriptUserAgentPair) {
          sections.push(typescriptUserAgentPair);
        }
        const crtAvailable = isCrtAvailable2();
        if (crtAvailable) {
          sections.push(crtAvailable);
        }
        if (serviceId) {
          sections.push([`api/${serviceId}`, clientVersion]);
        }
        if (node_process.env.AWS_EXECUTION_ENV) {
          sections.push([`exec-env/${node_process.env.AWS_EXECUTION_ENV}`]);
        }
        const appId = await config2?.userAgentAppId?.();
        const resolvedUserAgent = appId ? [...sections, [`app/${appId}`]] : [...sections];
        return resolvedUserAgent;
      };
    }, "createDefaultUserAgentProvider");
    var defaultUserAgent2 = createDefaultUserAgentProvider29;
    var UA_APP_ID_ENV_NAME2 = "AWS_SDK_UA_APP_ID";
    var UA_APP_ID_INI_NAME2 = "sdk_ua_app_id";
    var UA_APP_ID_INI_NAME_DEPRECATED2 = "sdk-ua-app-id";
    var NODE_APP_ID_CONFIG_OPTIONS29 = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[UA_APP_ID_ENV_NAME2], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[UA_APP_ID_INI_NAME2] ?? profile[UA_APP_ID_INI_NAME_DEPRECATED2], "configFileSelector"),
      default: middlewareUserAgent.DEFAULT_UA_APP_ID
    };
    exports2.NODE_APP_ID_CONFIG_OPTIONS = NODE_APP_ID_CONFIG_OPTIONS29;
    exports2.UA_APP_ID_ENV_NAME = UA_APP_ID_ENV_NAME2;
    exports2.UA_APP_ID_INI_NAME = UA_APP_ID_INI_NAME2;
    exports2.createDefaultUserAgentProvider = createDefaultUserAgentProvider29;
    exports2.crtAvailability = crtAvailability2;
    exports2.defaultUserAgent = defaultUserAgent2;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ProtocolLib.js
var import_smithy_client232, ProtocolLib11;
var init_ProtocolLib11 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ProtocolLib.js"() {
    init_schema4();
    import_smithy_client232 = __toESM(require_dist_cjs34());
    ProtocolLib11 = class {
      static {
        __name(this, "ProtocolLib");
      }
      queryCompat;
      errorRegistry;
      constructor(queryCompat = false) {
        this.queryCompat = queryCompat;
      }
      resolveRestContentType(defaultContentType, inputSchema) {
        const members = inputSchema.getMemberSchemas();
        const httpPayloadMember = Object.values(members).find((m20) => {
          return !!m20.getMergedTraits().httpPayload;
        });
        if (httpPayloadMember) {
          const mediaType = httpPayloadMember.getMergedTraits().mediaType;
          if (mediaType) {
            return mediaType;
          } else if (httpPayloadMember.isStringSchema()) {
            return "text/plain";
          } else if (httpPayloadMember.isBlobSchema()) {
            return "application/octet-stream";
          } else {
            return defaultContentType;
          }
        } else if (!inputSchema.isUnitSchema()) {
          const hasBody = Object.values(members).find((m20) => {
            const { httpQuery, httpQueryParams, httpHeader, httpLabel, httpPrefixHeaders } = m20.getMergedTraits();
            const noPrefixHeaders = httpPrefixHeaders === void 0;
            return !httpQuery && !httpQueryParams && !httpHeader && !httpLabel && noPrefixHeaders;
          });
          if (hasBody) {
            return defaultContentType;
          }
        }
      }
      async getErrorSchemaOrThrowBaseException(errorIdentifier, defaultNamespace, response, dataObject, metadata, getErrorSchema) {
        let errorName = errorIdentifier;
        if (errorIdentifier.includes("#")) {
          [, errorName] = errorIdentifier.split("#");
        }
        const errorMetadata = {
          $metadata: metadata,
          $fault: response.statusCode < 500 ? "client" : "server"
        };
        if (!this.errorRegistry) {
          throw new Error("@aws-sdk/core/protocols - error handler not initialized.");
        }
        try {
          const errorSchema = getErrorSchema?.(this.errorRegistry, errorName) ?? this.errorRegistry.getSchema(errorIdentifier);
          return { errorSchema, errorMetadata };
        } catch (e32) {
          dataObject.message = dataObject.message ?? dataObject.Message ?? "UnknownError";
          const synthetic = this.errorRegistry;
          const baseExceptionSchema = synthetic.getBaseException();
          if (baseExceptionSchema) {
            const ErrorCtor = synthetic.getErrorCtor(baseExceptionSchema) ?? Error;
            throw this.decorateServiceException(Object.assign(new ErrorCtor({ name: errorName }), errorMetadata), dataObject);
          }
          const d32 = dataObject;
          const message2 = d32?.message ?? d32?.Message ?? d32?.Error?.Message ?? d32?.Error?.message;
          throw this.decorateServiceException(Object.assign(new Error(message2), {
            name: errorName
          }, errorMetadata), dataObject);
        }
      }
      compose(composite, errorIdentifier, defaultNamespace) {
        let namespace = defaultNamespace;
        if (errorIdentifier.includes("#")) {
          [namespace] = errorIdentifier.split("#");
        }
        const staticRegistry = TypeRegistry.for(namespace);
        const defaultSyntheticRegistry = TypeRegistry.for("smithy.ts.sdk.synthetic." + defaultNamespace);
        composite.copyFrom(staticRegistry);
        composite.copyFrom(defaultSyntheticRegistry);
        this.errorRegistry = composite;
      }
      decorateServiceException(exception, additions = {}) {
        if (this.queryCompat) {
          const msg = exception.Message ?? additions.Message;
          const error4 = (0, import_smithy_client232.decorateServiceException)(exception, additions);
          if (msg) {
            error4.message = msg;
          }
          const errorObj = error4.Error ?? {};
          errorObj.Type = error4.Error?.Type;
          errorObj.Code = error4.Error?.Code;
          errorObj.Message = error4.Error?.message ?? error4.Error?.Message ?? msg;
          error4.Error = errorObj;
          const reqId = error4.$metadata.requestId;
          if (reqId) {
            error4.RequestId = reqId;
          }
          return error4;
        }
        return (0, import_smithy_client232.decorateServiceException)(exception, additions);
      }
      setQueryCompatError(output, response) {
        const queryErrorHeader = response.headers?.["x-amzn-query-error"];
        if (output !== void 0 && queryErrorHeader != null) {
          const [Code, Type] = queryErrorHeader.split(";");
          const keys = Object.keys(output);
          const Error2 = {
            Code,
            Type
          };
          output.Code = Code;
          output.Type = Type;
          for (let i32 = 0; i32 < keys.length; i32++) {
            const k32 = keys[i32];
            Error2[k32 === "message" ? "Message" : k32] = output[k32];
          }
          delete Error2.__type;
          output.Error = Error2;
        }
      }
      queryCompatOutput(queryCompatErrorData, errorData) {
        if (queryCompatErrorData.Error) {
          errorData.Error = queryCompatErrorData.Error;
        }
        if (queryCompatErrorData.Type) {
          errorData.Type = queryCompatErrorData.Type;
        }
        if (queryCompatErrorData.Code) {
          errorData.Code = queryCompatErrorData.Code;
        }
      }
      findQueryCompatibleError(registry, errorName) {
        try {
          return registry.getSchema(errorName);
        } catch (e32) {
          return registry.find((schema) => NormalizedSchema.of(schema).getMergedTraits().awsQueryError?.[0] === errorName);
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/cbor/AwsSmithyRpcV2CborProtocol.js
var AwsSmithyRpcV2CborProtocol9;
var init_AwsSmithyRpcV2CborProtocol11 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/cbor/AwsSmithyRpcV2CborProtocol.js"() {
    init_cbor2();
    init_schema4();
    init_ProtocolLib11();
    AwsSmithyRpcV2CborProtocol9 = class extends SmithyRpcV2CborProtocol {
      static {
        __name(this, "AwsSmithyRpcV2CborProtocol");
      }
      awsQueryCompatible;
      mixin;
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, awsQueryCompatible }) {
        super({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32 });
        this.awsQueryCompatible = !!awsQueryCompatible;
        this.mixin = new ProtocolLib11(this.awsQueryCompatible);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        if (this.awsQueryCompatible) {
          request4.headers["x-amzn-query-mode"] = "true";
        }
        return request4;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        if (this.awsQueryCompatible) {
          this.mixin.setQueryCompatError(dataObject, response);
        }
        const errorName = (() => {
          const compatHeader = response.headers["x-amzn-query-error"];
          if (compatHeader && this.awsQueryCompatible) {
            return compatHeader.split(";")[0];
          }
          return loadSmithyRpcV2CborErrorCode(response, dataObject) ?? "Unknown";
        })();
        this.mixin.compose(this.compositeErrorRegistry, errorName, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorName, this.options.defaultNamespace, response, dataObject, metadata, this.awsQueryCompatible ? this.mixin.findQueryCompatibleError : void 0);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        const output = {};
        for (const [name, member7] of ns.structIterator()) {
          if (dataObject[name] != null) {
            output[name] = this.deserializer.readValue(member7, dataObject[name]);
          }
        }
        if (this.awsQueryCompatible) {
          this.mixin.queryCompatOutput(dataObject, output);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/coercing-serializers.js
var _toStr9, _toBool9, _toNum9;
var init_coercing_serializers11 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/coercing-serializers.js"() {
    _toStr9 = /* @__PURE__ */ __name((val) => {
      if (val == null) {
        return val;
      }
      if (typeof val === "number" || typeof val === "bigint") {
        const warning2 = new Error(`Received number ${val} where a string was expected.`);
        warning2.name = "Warning";
        console.warn(warning2);
        return String(val);
      }
      if (typeof val === "boolean") {
        const warning2 = new Error(`Received boolean ${val} where a string was expected.`);
        warning2.name = "Warning";
        console.warn(warning2);
        return String(val);
      }
      return val;
    }, "_toStr");
    _toBool9 = /* @__PURE__ */ __name((val) => {
      if (val == null) {
        return val;
      }
      if (typeof val === "number") {
      }
      if (typeof val === "string") {
        const lowercase = val.toLowerCase();
        if (val !== "" && lowercase !== "false" && lowercase !== "true") {
          const warning2 = new Error(`Received string "${val}" where a boolean was expected.`);
          warning2.name = "Warning";
          console.warn(warning2);
        }
        return val !== "" && lowercase !== "false";
      }
      return val;
    }, "_toBool");
    _toNum9 = /* @__PURE__ */ __name((val) => {
      if (val == null) {
        return val;
      }
      if (typeof val === "boolean") {
      }
      if (typeof val === "string") {
        const num = Number(val);
        if (num.toString() !== val) {
          const warning2 = new Error(`Received string "${val}" where a number was expected.`);
          warning2.name = "Warning";
          console.warn(warning2);
          return val;
        }
        return num;
      }
      return val;
    }, "_toNum");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ConfigurableSerdeContext.js
var SerdeContextConfig11;
var init_ConfigurableSerdeContext11 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/ConfigurableSerdeContext.js"() {
    SerdeContextConfig11 = class {
      static {
        __name(this, "SerdeContextConfig");
      }
      serdeContext;
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/UnionSerde.js
var UnionSerde11;
var init_UnionSerde11 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/UnionSerde.js"() {
    UnionSerde11 = class {
      static {
        __name(this, "UnionSerde");
      }
      from;
      to;
      keys;
      constructor(from, to) {
        this.from = from;
        this.to = to;
        const keys = Object.keys(this.from);
        const set = new Set(keys);
        set.delete("__type");
        this.keys = set;
      }
      mark(key) {
        this.keys.delete(key);
      }
      hasUnknown() {
        return this.keys.size === 1 && Object.keys(this.to).length === 0;
      }
      writeUnknown() {
        if (this.hasUnknown()) {
          const k32 = this.keys.values().next().value;
          const v = this.from[k32];
          this.to.$unknown = [k32, v];
        }
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReviver.js
function jsonReviver11(key, value, context) {
  if (context?.source) {
    const numericString = context.source;
    if (typeof value === "number") {
      if (value > Number.MAX_SAFE_INTEGER || value < Number.MIN_SAFE_INTEGER || numericString !== String(value)) {
        const isFractional = numericString.includes(".");
        if (isFractional) {
          return new NumericValue(numericString, "bigDecimal");
        } else {
          return BigInt(numericString);
        }
      }
    }
  }
  return value;
}
var init_jsonReviver11 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReviver.js"() {
    init_serde();
    __name(jsonReviver11, "jsonReviver");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/common.js
var import_smithy_client233, import_util_utf847, collectBodyString11;
var init_common13 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/common.js"() {
    import_smithy_client233 = __toESM(require_dist_cjs34());
    import_util_utf847 = __toESM(require_dist_cjs9());
    collectBodyString11 = /* @__PURE__ */ __name((streamBody, context) => (0, import_smithy_client233.collectBody)(streamBody, context).then((body) => (context?.utf8Encoder ?? import_util_utf847.toUtf8)(body)), "collectBodyString");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/parseJsonBody.js
var parseJsonBody11, parseJsonErrorBody9, findKey11, sanitizeErrorCode11, loadRestJsonErrorCode11;
var init_parseJsonBody11 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/parseJsonBody.js"() {
    init_common13();
    parseJsonBody11 = /* @__PURE__ */ __name((streamBody, context) => collectBodyString11(streamBody, context).then((encoded) => {
      if (encoded.length) {
        try {
          return JSON.parse(encoded);
        } catch (e32) {
          if (e32?.name === "SyntaxError") {
            Object.defineProperty(e32, "$responseBodyText", {
              value: encoded
            });
          }
          throw e32;
        }
      }
      return {};
    }), "parseJsonBody");
    parseJsonErrorBody9 = /* @__PURE__ */ __name(async (errorBody, context) => {
      const value = await parseJsonBody11(errorBody, context);
      value.message = value.message ?? value.Message;
      return value;
    }, "parseJsonErrorBody");
    findKey11 = /* @__PURE__ */ __name((object, key) => Object.keys(object).find((k32) => k32.toLowerCase() === key.toLowerCase()), "findKey");
    sanitizeErrorCode11 = /* @__PURE__ */ __name((rawValue) => {
      let cleanValue = rawValue;
      if (typeof cleanValue === "number") {
        cleanValue = cleanValue.toString();
      }
      if (cleanValue.indexOf(",") >= 0) {
        cleanValue = cleanValue.split(",")[0];
      }
      if (cleanValue.indexOf(":") >= 0) {
        cleanValue = cleanValue.split(":")[0];
      }
      if (cleanValue.indexOf("#") >= 0) {
        cleanValue = cleanValue.split("#")[1];
      }
      return cleanValue;
    }, "sanitizeErrorCode");
    loadRestJsonErrorCode11 = /* @__PURE__ */ __name((output, data3) => {
      const headerKey = findKey11(output.headers, "x-amzn-errortype");
      if (headerKey !== void 0) {
        return sanitizeErrorCode11(output.headers[headerKey]);
      }
      if (data3 && typeof data3 === "object") {
        const codeKey = findKey11(data3, "code");
        if (codeKey && data3[codeKey] !== void 0) {
          return sanitizeErrorCode11(data3[codeKey]);
        }
        if (data3["__type"] !== void 0) {
          return sanitizeErrorCode11(data3["__type"]);
        }
      }
    }, "loadRestJsonErrorCode");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeDeserializer.js
var import_util_base6461, JsonShapeDeserializer11;
var init_JsonShapeDeserializer11 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeDeserializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_util_base6461 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext11();
    init_UnionSerde11();
    init_jsonReviver11();
    init_parseJsonBody11();
    JsonShapeDeserializer11 = class extends SerdeContextConfig11 {
      static {
        __name(this, "JsonShapeDeserializer");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      async read(schema, data3) {
        return this._read(schema, typeof data3 === "string" ? JSON.parse(data3, jsonReviver11) : await parseJsonBody11(data3, this.serdeContext));
      }
      readObject(schema, data3) {
        return this._read(schema, data3);
      }
      _read(schema, value) {
        const isObject3 = value !== null && typeof value === "object";
        const ns = NormalizedSchema.of(schema);
        if (isObject3) {
          if (ns.isStructSchema()) {
            const record = value;
            const union = ns.isUnionSchema();
            const out = {};
            let nameMap = void 0;
            const { jsonName } = this.settings;
            if (jsonName) {
              nameMap = {};
            }
            let unionSerde;
            if (union) {
              unionSerde = new UnionSerde11(record, out);
            }
            for (const [memberName, memberSchema] of ns.structIterator()) {
              let fromKey = memberName;
              if (jsonName) {
                fromKey = memberSchema.getMergedTraits().jsonName ?? fromKey;
                nameMap[fromKey] = memberName;
              }
              if (union) {
                unionSerde.mark(fromKey);
              }
              if (record[fromKey] != null) {
                out[memberName] = this._read(memberSchema, record[fromKey]);
              }
            }
            if (union) {
              unionSerde.writeUnknown();
            } else if (typeof record.__type === "string") {
              for (const k32 in record) {
                const v = record[k32];
                const t = jsonName ? nameMap[k32] ?? k32 : k32;
                if (!(t in out)) {
                  out[t] = v;
                }
              }
            }
            return out;
          }
          if (Array.isArray(value) && ns.isListSchema()) {
            const listMember = ns.getValueSchema();
            const out = [];
            for (const item of value) {
              out.push(this._read(listMember, item));
            }
            return out;
          }
          if (ns.isMapSchema()) {
            const mapMember = ns.getValueSchema();
            const out = {};
            for (const _k in value) {
              out[_k] = this._read(mapMember, value[_k]);
            }
            return out;
          }
        }
        if (ns.isBlobSchema() && typeof value === "string") {
          return (0, import_util_base6461.fromBase64)(value);
        }
        const mediaType = ns.getMergedTraits().mediaType;
        if (ns.isStringSchema() && typeof value === "string" && mediaType) {
          const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
          if (isJson) {
            return LazyJsonString.from(value);
          }
          return value;
        }
        if (ns.isTimestampSchema() && value != null) {
          const format32 = determineTimestampFormat(ns, this.settings);
          switch (format32) {
            case 5:
              return parseRfc3339DateTimeWithOffset(value);
            case 6:
              return parseRfc7231DateTime(value);
            case 7:
              return parseEpochTimestamp(value);
            default:
              console.warn("Missing timestamp format, parsing value with Date constructor:", value);
              return new Date(value);
          }
        }
        if (ns.isBigIntegerSchema() && (typeof value === "number" || typeof value === "string")) {
          return BigInt(value);
        }
        if (ns.isBigDecimalSchema() && value != void 0) {
          if (value instanceof NumericValue) {
            return value;
          }
          const untyped = value;
          if (untyped.type === "bigDecimal" && "string" in untyped) {
            return new NumericValue(untyped.string, untyped.type);
          }
          return new NumericValue(String(value), "bigDecimal");
        }
        if (ns.isNumericSchema() && typeof value === "string") {
          switch (value) {
            case "Infinity":
              return Infinity;
            case "-Infinity":
              return -Infinity;
            case "NaN":
              return NaN;
          }
          return value;
        }
        if (ns.isDocumentSchema()) {
          if (isObject3) {
            const out = Array.isArray(value) ? [] : {};
            for (const k32 in value) {
              const v = value[k32];
              if (v instanceof NumericValue) {
                out[k32] = v;
              } else {
                out[k32] = this._read(ns, v);
              }
            }
            return out;
          } else {
            return structuredClone(value);
          }
        }
        return value;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReplacer.js
var NUMERIC_CONTROL_CHAR11, JsonReplacer11;
var init_jsonReplacer11 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/jsonReplacer.js"() {
    init_serde();
    NUMERIC_CONTROL_CHAR11 = String.fromCharCode(925);
    JsonReplacer11 = class {
      static {
        __name(this, "JsonReplacer");
      }
      values = /* @__PURE__ */ new Map();
      counter = 0;
      stage = 0;
      createReplacer() {
        if (this.stage === 1) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer already created.");
        }
        if (this.stage === 2) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer exhausted.");
        }
        this.stage = 1;
        return (key, value) => {
          if (value instanceof NumericValue) {
            const v = `${NUMERIC_CONTROL_CHAR11 + "nv" + this.counter++}_` + value.string;
            this.values.set(`"${v}"`, value.string);
            return v;
          }
          if (typeof value === "bigint") {
            const s = value.toString();
            const v = `${NUMERIC_CONTROL_CHAR11 + "b" + this.counter++}_` + s;
            this.values.set(`"${v}"`, s);
            return v;
          }
          return value;
        };
      }
      replaceInJson(json) {
        if (this.stage === 0) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer not created yet.");
        }
        if (this.stage === 2) {
          throw new Error("@aws-sdk/core/protocols - JsonReplacer exhausted.");
        }
        this.stage = 2;
        if (this.counter === 0) {
          return json;
        }
        for (const [key, value] of this.values) {
          json = json.replace(key, value);
        }
        return json;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeSerializer.js
var import_util_base6462, JsonShapeSerializer11;
var init_JsonShapeSerializer11 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonShapeSerializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_util_base6462 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext11();
    init_jsonReplacer11();
    JsonShapeSerializer11 = class extends SerdeContextConfig11 {
      static {
        __name(this, "JsonShapeSerializer");
      }
      settings;
      buffer;
      useReplacer = false;
      rootSchema;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value) {
        this.rootSchema = NormalizedSchema.of(schema);
        this.buffer = this._write(this.rootSchema, value);
      }
      flush() {
        const { rootSchema, useReplacer } = this;
        this.rootSchema = void 0;
        this.useReplacer = false;
        if (rootSchema?.isStructSchema() || rootSchema?.isDocumentSchema()) {
          if (!useReplacer) {
            return JSON.stringify(this.buffer);
          }
          const replacer = new JsonReplacer11();
          return replacer.replaceInJson(JSON.stringify(this.buffer, replacer.createReplacer(), 0));
        }
        return this.buffer;
      }
      writeDiscriminatedDocument(schema, value) {
        this.write(schema, value);
        if (typeof this.buffer === "object") {
          this.buffer.__type = NormalizedSchema.of(schema).getName(true);
        }
      }
      _write(schema, value, container) {
        const isObject3 = value !== null && typeof value === "object";
        const ns = NormalizedSchema.of(schema);
        if (isObject3) {
          if (ns.isStructSchema()) {
            const record = value;
            const out = {};
            const { jsonName } = this.settings;
            let nameMap = void 0;
            if (jsonName) {
              nameMap = {};
            }
            let outCount = 0;
            for (const [memberName, memberSchema] of ns.structIterator()) {
              const serializableValue = this._write(memberSchema, record[memberName], ns);
              if (serializableValue !== void 0) {
                let targetKey = memberName;
                if (jsonName) {
                  targetKey = memberSchema.getMergedTraits().jsonName ?? memberName;
                  nameMap[memberName] = targetKey;
                }
                out[targetKey] = serializableValue;
                outCount++;
              }
            }
            if (ns.isUnionSchema() && outCount === 0) {
              const { $unknown } = record;
              if (Array.isArray($unknown)) {
                const [k32, v] = $unknown;
                out[k32] = this._write(15, v);
              }
            } else if (typeof record.__type === "string") {
              for (const k32 in record) {
                const v = record[k32];
                const targetKey = jsonName ? nameMap[k32] ?? k32 : k32;
                if (!(targetKey in out)) {
                  out[targetKey] = this._write(15, v);
                }
              }
            }
            return out;
          }
          if (Array.isArray(value) && ns.isListSchema()) {
            const listMember = ns.getValueSchema();
            const out = [];
            const sparse = !!ns.getMergedTraits().sparse;
            for (const item of value) {
              if (sparse || item != null) {
                out.push(this._write(listMember, item));
              }
            }
            return out;
          }
          if (ns.isMapSchema()) {
            const mapMember = ns.getValueSchema();
            const out = {};
            const sparse = !!ns.getMergedTraits().sparse;
            for (const _k in value) {
              const _v = value[_k];
              if (sparse || _v != null) {
                out[_k] = this._write(mapMember, _v);
              }
            }
            return out;
          }
          if (value instanceof Uint8Array && (ns.isBlobSchema() || ns.isDocumentSchema())) {
            if (ns === this.rootSchema) {
              return value;
            }
            return (this.serdeContext?.base64Encoder ?? import_util_base6462.toBase64)(value);
          }
          if (value instanceof Date && (ns.isTimestampSchema() || ns.isDocumentSchema())) {
            const format32 = determineTimestampFormat(ns, this.settings);
            switch (format32) {
              case 5:
                return value.toISOString().replace(".000Z", "Z");
              case 6:
                return dateToUtcString(value);
              case 7:
                return value.getTime() / 1e3;
              default:
                console.warn("Missing timestamp format, using epoch seconds", value);
                return value.getTime() / 1e3;
            }
          }
          if (value instanceof NumericValue) {
            this.useReplacer = true;
          }
        }
        if (value === null && container?.isStructSchema()) {
          return void 0;
        }
        if (ns.isStringSchema()) {
          if (typeof value === "undefined" && ns.isIdempotencyToken()) {
            return (0, import_uuid.v4)();
          }
          const mediaType = ns.getMergedTraits().mediaType;
          if (value != null && mediaType) {
            const isJson = mediaType === "application/json" || mediaType.endsWith("+json");
            if (isJson) {
              return LazyJsonString.from(value);
            }
          }
          return value;
        }
        if (typeof value === "number" && ns.isNumericSchema()) {
          if (Math.abs(value) === Infinity || isNaN(value)) {
            return String(value);
          }
          return value;
        }
        if (typeof value === "string" && ns.isBlobSchema()) {
          if (ns === this.rootSchema) {
            return value;
          }
          return (this.serdeContext?.base64Encoder ?? import_util_base6462.toBase64)(value);
        }
        if (typeof value === "bigint") {
          this.useReplacer = true;
        }
        if (ns.isDocumentSchema()) {
          if (isObject3) {
            const out = Array.isArray(value) ? [] : {};
            for (const k32 in value) {
              const v = value[k32];
              if (v instanceof NumericValue) {
                this.useReplacer = true;
                out[k32] = v;
              } else {
                out[k32] = this._write(ns, v);
              }
            }
            return out;
          } else {
            return structuredClone(value);
          }
        }
        return value;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonCodec.js
var JsonCodec11;
var init_JsonCodec11 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/JsonCodec.js"() {
    init_ConfigurableSerdeContext11();
    init_JsonShapeDeserializer11();
    init_JsonShapeSerializer11();
    JsonCodec11 = class extends SerdeContextConfig11 {
      static {
        __name(this, "JsonCodec");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      createSerializer() {
        const serializer = new JsonShapeSerializer11(this.settings);
        serializer.setSerdeContext(this.serdeContext);
        return serializer;
      }
      createDeserializer() {
        const deserializer = new JsonShapeDeserializer11(this.settings);
        deserializer.setSerdeContext(this.serdeContext);
        return deserializer;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJsonRpcProtocol.js
var AwsJsonRpcProtocol9;
var init_AwsJsonRpcProtocol11 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJsonRpcProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib11();
    init_JsonCodec11();
    init_parseJsonBody11();
    AwsJsonRpcProtocol9 = class extends RpcProtocol {
      static {
        __name(this, "AwsJsonRpcProtocol");
      }
      serializer;
      deserializer;
      serviceTarget;
      codec;
      mixin;
      awsQueryCompatible;
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, serviceTarget, awsQueryCompatible, jsonCodec }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32
        });
        this.serviceTarget = serviceTarget;
        this.codec = jsonCodec ?? new JsonCodec11({
          timestampFormat: {
            useTrait: true,
            default: 7
          },
          jsonName: false
        });
        this.serializer = this.codec.createSerializer();
        this.deserializer = this.codec.createDeserializer();
        this.awsQueryCompatible = !!awsQueryCompatible;
        this.mixin = new ProtocolLib11(this.awsQueryCompatible);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        if (!request4.path.endsWith("/")) {
          request4.path += "/";
        }
        request4.headers["content-type"] = `application/x-amz-json-${this.getJsonRpcVersion()}`;
        request4.headers["x-amz-target"] = `${this.serviceTarget}.${operationSchema.name}`;
        if (this.awsQueryCompatible) {
          request4.headers["x-amzn-query-mode"] = "true";
        }
        if (deref(operationSchema.input) === "unit" || !request4.body) {
          request4.body = "{}";
        }
        return request4;
      }
      getPayloadCodec() {
        return this.codec;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        if (this.awsQueryCompatible) {
          this.mixin.setQueryCompatError(dataObject, response);
        }
        const errorIdentifier = loadRestJsonErrorCode11(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata, this.awsQueryCompatible ? this.mixin.findQueryCompatibleError : void 0);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          if (dataObject[name] != null) {
            output[name] = errorDeserializer.readObject(member7, dataObject[name]);
          }
        }
        if (this.awsQueryCompatible) {
          this.mixin.queryCompatOutput(dataObject, output);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_0Protocol.js
var AwsJson1_0Protocol9;
var init_AwsJson1_0Protocol11 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_0Protocol.js"() {
    init_AwsJsonRpcProtocol11();
    AwsJson1_0Protocol9 = class extends AwsJsonRpcProtocol9 {
      static {
        __name(this, "AwsJson1_0Protocol");
      }
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, serviceTarget, awsQueryCompatible, jsonCodec }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32,
          serviceTarget,
          awsQueryCompatible,
          jsonCodec
        });
      }
      getShapeId() {
        return "aws.protocols#awsJson1_0";
      }
      getJsonRpcVersion() {
        return "1.0";
      }
      getDefaultContentType() {
        return "application/x-amz-json-1.0";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_1Protocol.js
var AwsJson1_1Protocol9;
var init_AwsJson1_1Protocol11 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsJson1_1Protocol.js"() {
    init_AwsJsonRpcProtocol11();
    AwsJson1_1Protocol9 = class extends AwsJsonRpcProtocol9 {
      static {
        __name(this, "AwsJson1_1Protocol");
      }
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32, serviceTarget, awsQueryCompatible, jsonCodec }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32,
          serviceTarget,
          awsQueryCompatible,
          jsonCodec
        });
      }
      getShapeId() {
        return "aws.protocols#awsJson1_1";
      }
      getJsonRpcVersion() {
        return "1.1";
      }
      getDefaultContentType() {
        return "application/x-amz-json-1.1";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsRestJsonProtocol.js
var AwsRestJsonProtocol11;
var init_AwsRestJsonProtocol11 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/AwsRestJsonProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib11();
    init_JsonCodec11();
    init_parseJsonBody11();
    AwsRestJsonProtocol11 = class extends HttpBindingProtocol {
      static {
        __name(this, "AwsRestJsonProtocol");
      }
      serializer;
      deserializer;
      codec;
      mixin = new ProtocolLib11();
      constructor({ defaultNamespace, errorTypeRegistries: errorTypeRegistries32 }) {
        super({
          defaultNamespace,
          errorTypeRegistries: errorTypeRegistries32
        });
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 7
          },
          httpBindings: true,
          jsonName: true
        };
        this.codec = new JsonCodec11(settings);
        this.serializer = new HttpInterceptingShapeSerializer(this.codec.createSerializer(), settings);
        this.deserializer = new HttpInterceptingShapeDeserializer(this.codec.createDeserializer(), settings);
      }
      getShapeId() {
        return "aws.protocols#restJson1";
      }
      getPayloadCodec() {
        return this.codec;
      }
      setSerdeContext(serdeContext) {
        this.codec.setSerdeContext(serdeContext);
        super.setSerdeContext(serdeContext);
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        const inputSchema = NormalizedSchema.of(operationSchema.input);
        if (!request4.headers["content-type"]) {
          const contentType = this.mixin.resolveRestContentType(this.getDefaultContentType(), inputSchema);
          if (contentType) {
            request4.headers["content-type"] = contentType;
          }
        }
        if (request4.body == null && request4.headers["content-type"] === this.getDefaultContentType()) {
          request4.body = "{}";
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        const output = await super.deserializeResponse(operationSchema, context, response);
        const outputSchema = NormalizedSchema.of(operationSchema.output);
        for (const [name, member7] of outputSchema.structIterator()) {
          if (member7.getMemberTraits().httpPayload && !(name in output)) {
            output[name] = null;
          }
        }
        return output;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = loadRestJsonErrorCode11(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        await this.deserializeHttpMessage(errorSchema, context, response, dataObject);
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().jsonName ?? name;
          output[name] = errorDeserializer.readObject(member7, dataObject[target]);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      getDefaultContentType() {
        return "application/json";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/awsExpectUnion.js
var import_smithy_client234, awsExpectUnion9;
var init_awsExpectUnion11 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/json/awsExpectUnion.js"() {
    import_smithy_client234 = __toESM(require_dist_cjs34());
    awsExpectUnion9 = /* @__PURE__ */ __name((value) => {
      if (value == null) {
        return void 0;
      }
      if (typeof value === "object" && "__type" in value) {
        delete value.__type;
      }
      return (0, import_smithy_client234.expectUnion)(value);
    }, "awsExpectUnion");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeDeserializer.js
var import_xml_builder26, import_smithy_client235, import_util_utf848, XmlShapeDeserializer10;
var init_XmlShapeDeserializer11 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeDeserializer.js"() {
    import_xml_builder26 = __toESM(require_dist_cjs47());
    init_protocols();
    init_schema4();
    import_smithy_client235 = __toESM(require_dist_cjs34());
    import_util_utf848 = __toESM(require_dist_cjs9());
    init_ConfigurableSerdeContext11();
    init_UnionSerde11();
    XmlShapeDeserializer10 = class extends SerdeContextConfig11 {
      static {
        __name(this, "XmlShapeDeserializer");
      }
      settings;
      stringDeserializer;
      constructor(settings) {
        super();
        this.settings = settings;
        this.stringDeserializer = new FromStringShapeDeserializer(settings);
      }
      setSerdeContext(serdeContext) {
        this.serdeContext = serdeContext;
        this.stringDeserializer.setSerdeContext(serdeContext);
      }
      read(schema, bytes, key) {
        const ns = NormalizedSchema.of(schema);
        const memberSchemas = ns.getMemberSchemas();
        const isEventPayload = ns.isStructSchema() && ns.isMemberSchema() && !!Object.values(memberSchemas).find((memberNs) => {
          return !!memberNs.getMemberTraits().eventPayload;
        });
        if (isEventPayload) {
          const output = {};
          const memberName = Object.keys(memberSchemas)[0];
          const eventMemberSchema = memberSchemas[memberName];
          if (eventMemberSchema.isBlobSchema()) {
            output[memberName] = bytes;
          } else {
            output[memberName] = this.read(memberSchemas[memberName], bytes);
          }
          return output;
        }
        const xmlString = (this.serdeContext?.utf8Encoder ?? import_util_utf848.toUtf8)(bytes);
        const parsedObject = this.parseXml(xmlString);
        return this.readSchema(schema, key ? parsedObject[key] : parsedObject);
      }
      readSchema(_schema, value) {
        const ns = NormalizedSchema.of(_schema);
        if (ns.isUnitSchema()) {
          return;
        }
        const traits = ns.getMergedTraits();
        if (ns.isListSchema() && !Array.isArray(value)) {
          return this.readSchema(ns, [value]);
        }
        if (value == null) {
          return value;
        }
        if (typeof value === "object") {
          const flat = !!traits.xmlFlattened;
          if (ns.isListSchema()) {
            const listValue = ns.getValueSchema();
            const buffer2 = [];
            const sourceKey = listValue.getMergedTraits().xmlName ?? "member";
            const source = flat ? value : (value[0] ?? value)[sourceKey];
            if (source == null) {
              return buffer2;
            }
            const sourceArray = Array.isArray(source) ? source : [source];
            for (const v of sourceArray) {
              buffer2.push(this.readSchema(listValue, v));
            }
            return buffer2;
          }
          const buffer = {};
          if (ns.isMapSchema()) {
            const keyNs = ns.getKeySchema();
            const memberNs = ns.getValueSchema();
            let entries;
            if (flat) {
              entries = Array.isArray(value) ? value : [value];
            } else {
              entries = Array.isArray(value.entry) ? value.entry : [value.entry];
            }
            const keyProperty = keyNs.getMergedTraits().xmlName ?? "key";
            const valueProperty = memberNs.getMergedTraits().xmlName ?? "value";
            for (const entry of entries) {
              const key = entry[keyProperty];
              const value2 = entry[valueProperty];
              buffer[key] = this.readSchema(memberNs, value2);
            }
            return buffer;
          }
          if (ns.isStructSchema()) {
            const union = ns.isUnionSchema();
            let unionSerde;
            if (union) {
              unionSerde = new UnionSerde11(value, buffer);
            }
            for (const [memberName, memberSchema] of ns.structIterator()) {
              const memberTraits = memberSchema.getMergedTraits();
              const xmlObjectKey = !memberTraits.httpPayload ? memberSchema.getMemberTraits().xmlName ?? memberName : memberTraits.xmlName ?? memberSchema.getName();
              if (union) {
                unionSerde.mark(xmlObjectKey);
              }
              if (value[xmlObjectKey] != null) {
                buffer[memberName] = this.readSchema(memberSchema, value[xmlObjectKey]);
              }
            }
            if (union) {
              unionSerde.writeUnknown();
            }
            return buffer;
          }
          if (ns.isDocumentSchema()) {
            return value;
          }
          throw new Error(`@aws-sdk/core/protocols - xml deserializer unhandled schema type for ${ns.getName(true)}`);
        }
        if (ns.isListSchema()) {
          return [];
        }
        if (ns.isMapSchema() || ns.isStructSchema()) {
          return {};
        }
        return this.stringDeserializer.read(ns, value);
      }
      parseXml(xml) {
        if (xml.length) {
          let parsedObj;
          try {
            parsedObj = (0, import_xml_builder26.parseXML)(xml);
          } catch (e32) {
            if (e32 && typeof e32 === "object") {
              Object.defineProperty(e32, "$responseBodyText", {
                value: xml
              });
            }
            throw e32;
          }
          const textNodeName = "#text";
          const key = Object.keys(parsedObj)[0];
          const parsedObjToReturn = parsedObj[key];
          if (parsedObjToReturn[textNodeName]) {
            parsedObjToReturn[key] = parsedObjToReturn[textNodeName];
            delete parsedObjToReturn[textNodeName];
          }
          return (0, import_smithy_client235.getValueFromTextNode)(parsedObjToReturn);
        }
        return {};
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QueryShapeSerializer.js
var import_smithy_client236, import_util_base6463, QueryShapeSerializer10;
var init_QueryShapeSerializer11 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QueryShapeSerializer.js"() {
    init_protocols();
    init_schema4();
    init_serde();
    import_smithy_client236 = __toESM(require_dist_cjs34());
    import_util_base6463 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext11();
    QueryShapeSerializer10 = class extends SerdeContextConfig11 {
      static {
        __name(this, "QueryShapeSerializer");
      }
      settings;
      buffer;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value, prefix = "") {
        if (this.buffer === void 0) {
          this.buffer = "";
        }
        const ns = NormalizedSchema.of(schema);
        if (prefix && !prefix.endsWith(".")) {
          prefix += ".";
        }
        if (ns.isBlobSchema()) {
          if (typeof value === "string" || value instanceof Uint8Array) {
            this.writeKey(prefix);
            this.writeValue((this.serdeContext?.base64Encoder ?? import_util_base6463.toBase64)(value));
          }
        } else if (ns.isBooleanSchema() || ns.isNumericSchema() || ns.isStringSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(String(value));
          } else if (ns.isIdempotencyToken()) {
            this.writeKey(prefix);
            this.writeValue((0, import_uuid.v4)());
          }
        } else if (ns.isBigIntegerSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(String(value));
          }
        } else if (ns.isBigDecimalSchema()) {
          if (value != null) {
            this.writeKey(prefix);
            this.writeValue(value instanceof NumericValue ? value.string : String(value));
          }
        } else if (ns.isTimestampSchema()) {
          if (value instanceof Date) {
            this.writeKey(prefix);
            const format32 = determineTimestampFormat(ns, this.settings);
            switch (format32) {
              case 5:
                this.writeValue(value.toISOString().replace(".000Z", "Z"));
                break;
              case 6:
                this.writeValue((0, import_smithy_client236.dateToUtcString)(value));
                break;
              case 7:
                this.writeValue(String(value.getTime() / 1e3));
                break;
            }
          }
        } else if (ns.isDocumentSchema()) {
          if (Array.isArray(value)) {
            this.write(64 | 15, value, prefix);
          } else if (value instanceof Date) {
            this.write(4, value, prefix);
          } else if (value instanceof Uint8Array) {
            this.write(21, value, prefix);
          } else if (value && typeof value === "object") {
            this.write(128 | 15, value, prefix);
          } else {
            this.writeKey(prefix);
            this.writeValue(String(value));
          }
        } else if (ns.isListSchema()) {
          if (Array.isArray(value)) {
            if (value.length === 0) {
              if (this.settings.serializeEmptyLists) {
                this.writeKey(prefix);
                this.writeValue("");
              }
            } else {
              const member7 = ns.getValueSchema();
              const flat = this.settings.flattenLists || ns.getMergedTraits().xmlFlattened;
              let i32 = 1;
              for (const item of value) {
                if (item == null) {
                  continue;
                }
                const traits = member7.getMergedTraits();
                const suffix = this.getKey("member", traits.xmlName, traits.ec2QueryName);
                const key = flat ? `${prefix}${i32}` : `${prefix}${suffix}.${i32}`;
                this.write(member7, item, key);
                ++i32;
              }
            }
          }
        } else if (ns.isMapSchema()) {
          if (value && typeof value === "object") {
            const keySchema = ns.getKeySchema();
            const memberSchema = ns.getValueSchema();
            const flat = ns.getMergedTraits().xmlFlattened;
            let i32 = 1;
            for (const k32 in value) {
              const v = value[k32];
              if (v == null) {
                continue;
              }
              const keyTraits = keySchema.getMergedTraits();
              const keySuffix = this.getKey("key", keyTraits.xmlName, keyTraits.ec2QueryName);
              const key = flat ? `${prefix}${i32}.${keySuffix}` : `${prefix}entry.${i32}.${keySuffix}`;
              const valTraits = memberSchema.getMergedTraits();
              const valueSuffix = this.getKey("value", valTraits.xmlName, valTraits.ec2QueryName);
              const valueKey = flat ? `${prefix}${i32}.${valueSuffix}` : `${prefix}entry.${i32}.${valueSuffix}`;
              this.write(keySchema, k32, key);
              this.write(memberSchema, v, valueKey);
              ++i32;
            }
          }
        } else if (ns.isStructSchema()) {
          if (value && typeof value === "object") {
            let didWriteMember = false;
            for (const [memberName, member7] of ns.structIterator()) {
              if (value[memberName] == null && !member7.isIdempotencyToken()) {
                continue;
              }
              const traits = member7.getMergedTraits();
              const suffix = this.getKey(memberName, traits.xmlName, traits.ec2QueryName, "struct");
              const key = `${prefix}${suffix}`;
              this.write(member7, value[memberName], key);
              didWriteMember = true;
            }
            if (!didWriteMember && ns.isUnionSchema()) {
              const { $unknown } = value;
              if (Array.isArray($unknown)) {
                const [k32, v] = $unknown;
                const key = `${prefix}${k32}`;
                this.write(15, v, key);
              }
            }
          }
        } else if (ns.isUnitSchema()) {
        } else {
          throw new Error(`@aws-sdk/core/protocols - QuerySerializer unrecognized schema type ${ns.getName(true)}`);
        }
      }
      flush() {
        if (this.buffer === void 0) {
          throw new Error("@aws-sdk/core/protocols - QuerySerializer cannot flush with nothing written to buffer.");
        }
        const str = this.buffer;
        delete this.buffer;
        return str;
      }
      getKey(memberName, xmlName, ec2QueryName, keySource) {
        const { ec2, capitalizeKeys } = this.settings;
        if (ec2 && ec2QueryName) {
          return ec2QueryName;
        }
        const key = xmlName ?? memberName;
        if (capitalizeKeys && keySource === "struct") {
          return key[0].toUpperCase() + key.slice(1);
        }
        return key;
      }
      writeKey(key) {
        if (key.endsWith(".")) {
          key = key.slice(0, key.length - 1);
        }
        this.buffer += `&${extendedEncodeURIComponent(key)}=`;
      }
      writeValue(value) {
        this.buffer += extendedEncodeURIComponent(value);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsQueryProtocol.js
var AwsQueryProtocol10;
var init_AwsQueryProtocol11 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsQueryProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib11();
    init_XmlShapeDeserializer11();
    init_QueryShapeSerializer11();
    AwsQueryProtocol10 = class extends RpcProtocol {
      static {
        __name(this, "AwsQueryProtocol");
      }
      options;
      serializer;
      deserializer;
      mixin = new ProtocolLib11();
      constructor(options) {
        super({
          defaultNamespace: options.defaultNamespace,
          errorTypeRegistries: options.errorTypeRegistries
        });
        this.options = options;
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 5
          },
          httpBindings: false,
          xmlNamespace: options.xmlNamespace,
          serviceNamespace: options.defaultNamespace,
          serializeEmptyLists: true
        };
        this.serializer = new QueryShapeSerializer10(settings);
        this.deserializer = new XmlShapeDeserializer10(settings);
      }
      getShapeId() {
        return "aws.protocols#awsQuery";
      }
      setSerdeContext(serdeContext) {
        this.serializer.setSerdeContext(serdeContext);
        this.deserializer.setSerdeContext(serdeContext);
      }
      getPayloadCodec() {
        throw new Error("AWSQuery protocol has no payload codec.");
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        if (!request4.path.endsWith("/")) {
          request4.path += "/";
        }
        request4.headers["content-type"] = "application/x-www-form-urlencoded";
        if (deref(operationSchema.input) === "unit" || !request4.body) {
          request4.body = "";
        }
        const action = operationSchema.name.split("#")[1] ?? operationSchema.name;
        request4.body = `Action=${action}&Version=${this.options.version}` + request4.body;
        if (request4.body.endsWith("&")) {
          request4.body = request4.body.slice(-1);
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        const deserializer = this.deserializer;
        const ns = NormalizedSchema.of(operationSchema.output);
        const dataObject = {};
        if (response.statusCode >= 300) {
          const bytes2 = await collectBody(response.body, context);
          if (bytes2.byteLength > 0) {
            Object.assign(dataObject, await deserializer.read(15, bytes2));
          }
          await this.handleError(operationSchema, context, response, dataObject, this.deserializeMetadata(response));
        }
        for (const header in response.headers) {
          const value = response.headers[header];
          delete response.headers[header];
          response.headers[header.toLowerCase()] = value;
        }
        const shortName = operationSchema.name.split("#")[1] ?? operationSchema.name;
        const awsQueryResultKey = ns.isStructSchema() && this.useNestedResult() ? shortName + "Result" : void 0;
        const bytes = await collectBody(response.body, context);
        if (bytes.byteLength > 0) {
          Object.assign(dataObject, await deserializer.read(ns, bytes, awsQueryResultKey));
        }
        dataObject.$metadata = this.deserializeMetadata(response);
        return dataObject;
      }
      useNestedResult() {
        return true;
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = this.loadQueryErrorCode(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        const errorData = this.loadQueryError(dataObject) ?? {};
        const message2 = this.loadQueryErrorMessage(dataObject);
        errorData.message = message2;
        errorData.Error = {
          Type: errorData.Type,
          Code: errorData.Code,
          Message: message2
        };
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, errorData, metadata, this.mixin.findQueryCompatibleError);
        const ns = NormalizedSchema.of(errorSchema);
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        const output = {
          Type: errorData.Error.Type,
          Code: errorData.Error.Code,
          Error: errorData.Error
        };
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().xmlName ?? name;
          const value = errorData[target] ?? dataObject[target];
          output[name] = this.deserializer.readSchema(member7, value);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      loadQueryErrorCode(output, data3) {
        const code = (data3.Errors?.[0]?.Error ?? data3.Errors?.Error ?? data3.Error)?.Code;
        if (code !== void 0) {
          return code;
        }
        if (output.statusCode == 404) {
          return "NotFound";
        }
      }
      loadQueryError(data3) {
        return data3.Errors?.[0]?.Error ?? data3.Errors?.Error ?? data3.Error;
      }
      loadQueryErrorMessage(data3) {
        const errorData = this.loadQueryError(data3);
        return errorData?.message ?? errorData?.Message ?? data3.message ?? data3.Message ?? "Unknown";
      }
      getDefaultContentType() {
        return "application/x-www-form-urlencoded";
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsEc2QueryProtocol.js
var AwsEc2QueryProtocol9;
var init_AwsEc2QueryProtocol11 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/AwsEc2QueryProtocol.js"() {
    init_AwsQueryProtocol11();
    AwsEc2QueryProtocol9 = class extends AwsQueryProtocol10 {
      static {
        __name(this, "AwsEc2QueryProtocol");
      }
      options;
      constructor(options) {
        super(options);
        this.options = options;
        const ec2Settings = {
          capitalizeKeys: true,
          flattenLists: true,
          serializeEmptyLists: false,
          ec2: true
        };
        Object.assign(this.serializer.settings, ec2Settings);
      }
      getShapeId() {
        return "aws.protocols#ec2Query";
      }
      useNestedResult() {
        return false;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QuerySerializerSettings.js
var init_QuerySerializerSettings11 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/query/QuerySerializerSettings.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/parseXmlBody.js
var import_xml_builder27, import_smithy_client237, parseXmlBody9, parseXmlErrorBody9, loadRestXmlErrorCode9;
var init_parseXmlBody11 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/parseXmlBody.js"() {
    import_xml_builder27 = __toESM(require_dist_cjs47());
    import_smithy_client237 = __toESM(require_dist_cjs34());
    init_common13();
    parseXmlBody9 = /* @__PURE__ */ __name((streamBody, context) => collectBodyString11(streamBody, context).then((encoded) => {
      if (encoded.length) {
        let parsedObj;
        try {
          parsedObj = (0, import_xml_builder27.parseXML)(encoded);
        } catch (e32) {
          if (e32 && typeof e32 === "object") {
            Object.defineProperty(e32, "$responseBodyText", {
              value: encoded
            });
          }
          throw e32;
        }
        const textNodeName = "#text";
        const key = Object.keys(parsedObj)[0];
        const parsedObjToReturn = parsedObj[key];
        if (parsedObjToReturn[textNodeName]) {
          parsedObjToReturn[key] = parsedObjToReturn[textNodeName];
          delete parsedObjToReturn[textNodeName];
        }
        return (0, import_smithy_client237.getValueFromTextNode)(parsedObjToReturn);
      }
      return {};
    }), "parseXmlBody");
    parseXmlErrorBody9 = /* @__PURE__ */ __name(async (errorBody, context) => {
      const value = await parseXmlBody9(errorBody, context);
      if (value.Error) {
        value.Error.message = value.Error.message ?? value.Error.Message;
      }
      return value;
    }, "parseXmlErrorBody");
    loadRestXmlErrorCode9 = /* @__PURE__ */ __name((output, data3) => {
      if (data3?.Error?.Code !== void 0) {
        return data3.Error.Code;
      }
      if (data3?.Code !== void 0) {
        return data3.Code;
      }
      if (output.statusCode == 404) {
        return "NotFound";
      }
    }, "loadRestXmlErrorCode");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeSerializer.js
var import_xml_builder28, import_smithy_client238, import_util_base6464, XmlShapeSerializer9;
var init_XmlShapeSerializer11 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlShapeSerializer.js"() {
    import_xml_builder28 = __toESM(require_dist_cjs47());
    init_protocols();
    init_schema4();
    init_serde();
    import_smithy_client238 = __toESM(require_dist_cjs34());
    import_util_base6464 = __toESM(require_dist_cjs10());
    init_ConfigurableSerdeContext11();
    XmlShapeSerializer9 = class extends SerdeContextConfig11 {
      static {
        __name(this, "XmlShapeSerializer");
      }
      settings;
      stringBuffer;
      byteBuffer;
      buffer;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      write(schema, value) {
        const ns = NormalizedSchema.of(schema);
        if (ns.isStringSchema() && typeof value === "string") {
          this.stringBuffer = value;
        } else if (ns.isBlobSchema()) {
          this.byteBuffer = "byteLength" in value ? value : (this.serdeContext?.base64Decoder ?? import_util_base6464.fromBase64)(value);
        } else {
          this.buffer = this.writeStruct(ns, value, void 0);
          const traits = ns.getMergedTraits();
          if (traits.httpPayload && !traits.xmlName) {
            this.buffer.withName(ns.getName());
          }
        }
      }
      flush() {
        if (this.byteBuffer !== void 0) {
          const bytes = this.byteBuffer;
          delete this.byteBuffer;
          return bytes;
        }
        if (this.stringBuffer !== void 0) {
          const str = this.stringBuffer;
          delete this.stringBuffer;
          return str;
        }
        const buffer = this.buffer;
        if (this.settings.xmlNamespace) {
          if (!buffer?.attributes?.["xmlns"]) {
            buffer.addAttribute("xmlns", this.settings.xmlNamespace);
          }
        }
        delete this.buffer;
        return buffer.toString();
      }
      writeStruct(ns, value, parentXmlns) {
        const traits = ns.getMergedTraits();
        const name = ns.isMemberSchema() && !traits.httpPayload ? ns.getMemberTraits().xmlName ?? ns.getMemberName() : traits.xmlName ?? ns.getName();
        if (!name || !ns.isStructSchema()) {
          throw new Error(`@aws-sdk/core/protocols - xml serializer, cannot write struct with empty name or non-struct, schema=${ns.getName(true)}.`);
        }
        const structXmlNode = import_xml_builder28.XmlNode.of(name);
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(ns, parentXmlns);
        for (const [memberName, memberSchema] of ns.structIterator()) {
          const val = value[memberName];
          if (val != null || memberSchema.isIdempotencyToken()) {
            if (memberSchema.getMergedTraits().xmlAttribute) {
              structXmlNode.addAttribute(memberSchema.getMergedTraits().xmlName ?? memberName, this.writeSimple(memberSchema, val));
              continue;
            }
            if (memberSchema.isListSchema()) {
              this.writeList(memberSchema, val, structXmlNode, xmlns);
            } else if (memberSchema.isMapSchema()) {
              this.writeMap(memberSchema, val, structXmlNode, xmlns);
            } else if (memberSchema.isStructSchema()) {
              structXmlNode.addChildNode(this.writeStruct(memberSchema, val, xmlns));
            } else {
              const memberNode = import_xml_builder28.XmlNode.of(memberSchema.getMergedTraits().xmlName ?? memberSchema.getMemberName());
              this.writeSimpleInto(memberSchema, val, memberNode, xmlns);
              structXmlNode.addChildNode(memberNode);
            }
          }
        }
        const { $unknown } = value;
        if ($unknown && ns.isUnionSchema() && Array.isArray($unknown) && Object.keys(value).length === 1) {
          const [k32, v] = $unknown;
          const node = import_xml_builder28.XmlNode.of(k32);
          if (typeof v !== "string") {
            if (value instanceof import_xml_builder28.XmlNode || value instanceof import_xml_builder28.XmlText) {
              structXmlNode.addChildNode(value);
            } else {
              throw new Error(`@aws-sdk - $unknown union member in XML requires value of type string, @aws-sdk/xml-builder::XmlNode or XmlText.`);
            }
          }
          this.writeSimpleInto(0, v, node, xmlns);
          structXmlNode.addChildNode(node);
        }
        if (xmlns) {
          structXmlNode.addAttribute(xmlnsAttr, xmlns);
        }
        return structXmlNode;
      }
      writeList(listMember, array, container, parentXmlns) {
        if (!listMember.isMemberSchema()) {
          throw new Error(`@aws-sdk/core/protocols - xml serializer, cannot write non-member list: ${listMember.getName(true)}`);
        }
        const listTraits = listMember.getMergedTraits();
        const listValueSchema = listMember.getValueSchema();
        const listValueTraits = listValueSchema.getMergedTraits();
        const sparse = !!listValueTraits.sparse;
        const flat = !!listTraits.xmlFlattened;
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(listMember, parentXmlns);
        const writeItem = /* @__PURE__ */ __name((container2, value) => {
          if (listValueSchema.isListSchema()) {
            this.writeList(listValueSchema, Array.isArray(value) ? value : [value], container2, xmlns);
          } else if (listValueSchema.isMapSchema()) {
            this.writeMap(listValueSchema, value, container2, xmlns);
          } else if (listValueSchema.isStructSchema()) {
            const struct3 = this.writeStruct(listValueSchema, value, xmlns);
            container2.addChildNode(struct3.withName(flat ? listTraits.xmlName ?? listMember.getMemberName() : listValueTraits.xmlName ?? "member"));
          } else {
            const listItemNode = import_xml_builder28.XmlNode.of(flat ? listTraits.xmlName ?? listMember.getMemberName() : listValueTraits.xmlName ?? "member");
            this.writeSimpleInto(listValueSchema, value, listItemNode, xmlns);
            container2.addChildNode(listItemNode);
          }
        }, "writeItem");
        if (flat) {
          for (const value of array) {
            if (sparse || value != null) {
              writeItem(container, value);
            }
          }
        } else {
          const listNode = import_xml_builder28.XmlNode.of(listTraits.xmlName ?? listMember.getMemberName());
          if (xmlns) {
            listNode.addAttribute(xmlnsAttr, xmlns);
          }
          for (const value of array) {
            if (sparse || value != null) {
              writeItem(listNode, value);
            }
          }
          container.addChildNode(listNode);
        }
      }
      writeMap(mapMember, map5, container, parentXmlns, containerIsMap = false) {
        if (!mapMember.isMemberSchema()) {
          throw new Error(`@aws-sdk/core/protocols - xml serializer, cannot write non-member map: ${mapMember.getName(true)}`);
        }
        const mapTraits = mapMember.getMergedTraits();
        const mapKeySchema = mapMember.getKeySchema();
        const mapKeyTraits = mapKeySchema.getMergedTraits();
        const keyTag = mapKeyTraits.xmlName ?? "key";
        const mapValueSchema = mapMember.getValueSchema();
        const mapValueTraits = mapValueSchema.getMergedTraits();
        const valueTag = mapValueTraits.xmlName ?? "value";
        const sparse = !!mapValueTraits.sparse;
        const flat = !!mapTraits.xmlFlattened;
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(mapMember, parentXmlns);
        const addKeyValue = /* @__PURE__ */ __name((entry, key, val) => {
          const keyNode = import_xml_builder28.XmlNode.of(keyTag, key);
          const [keyXmlnsAttr, keyXmlns] = this.getXmlnsAttribute(mapKeySchema, xmlns);
          if (keyXmlns) {
            keyNode.addAttribute(keyXmlnsAttr, keyXmlns);
          }
          entry.addChildNode(keyNode);
          let valueNode = import_xml_builder28.XmlNode.of(valueTag);
          if (mapValueSchema.isListSchema()) {
            this.writeList(mapValueSchema, val, valueNode, xmlns);
          } else if (mapValueSchema.isMapSchema()) {
            this.writeMap(mapValueSchema, val, valueNode, xmlns, true);
          } else if (mapValueSchema.isStructSchema()) {
            valueNode = this.writeStruct(mapValueSchema, val, xmlns);
          } else {
            this.writeSimpleInto(mapValueSchema, val, valueNode, xmlns);
          }
          entry.addChildNode(valueNode);
        }, "addKeyValue");
        if (flat) {
          for (const key in map5) {
            const val = map5[key];
            if (sparse || val != null) {
              const entry = import_xml_builder28.XmlNode.of(mapTraits.xmlName ?? mapMember.getMemberName());
              addKeyValue(entry, key, val);
              container.addChildNode(entry);
            }
          }
        } else {
          let mapNode;
          if (!containerIsMap) {
            mapNode = import_xml_builder28.XmlNode.of(mapTraits.xmlName ?? mapMember.getMemberName());
            if (xmlns) {
              mapNode.addAttribute(xmlnsAttr, xmlns);
            }
            container.addChildNode(mapNode);
          }
          for (const key in map5) {
            const val = map5[key];
            if (sparse || val != null) {
              const entry = import_xml_builder28.XmlNode.of("entry");
              addKeyValue(entry, key, val);
              (containerIsMap ? container : mapNode).addChildNode(entry);
            }
          }
        }
      }
      writeSimple(_schema, value) {
        if (null === value) {
          throw new Error("@aws-sdk/core/protocols - (XML serializer) cannot write null value.");
        }
        const ns = NormalizedSchema.of(_schema);
        let nodeContents = null;
        if (value && typeof value === "object") {
          if (ns.isBlobSchema()) {
            nodeContents = (this.serdeContext?.base64Encoder ?? import_util_base6464.toBase64)(value);
          } else if (ns.isTimestampSchema() && value instanceof Date) {
            const format32 = determineTimestampFormat(ns, this.settings);
            switch (format32) {
              case 5:
                nodeContents = value.toISOString().replace(".000Z", "Z");
                break;
              case 6:
                nodeContents = (0, import_smithy_client238.dateToUtcString)(value);
                break;
              case 7:
                nodeContents = String(value.getTime() / 1e3);
                break;
              default:
                console.warn("Missing timestamp format, using http date", value);
                nodeContents = (0, import_smithy_client238.dateToUtcString)(value);
                break;
            }
          } else if (ns.isBigDecimalSchema() && value) {
            if (value instanceof NumericValue) {
              return value.string;
            }
            return String(value);
          } else if (ns.isMapSchema() || ns.isListSchema()) {
            throw new Error("@aws-sdk/core/protocols - xml serializer, cannot call _write() on List/Map schema, call writeList or writeMap() instead.");
          } else {
            throw new Error(`@aws-sdk/core/protocols - xml serializer, unhandled schema type for object value and schema: ${ns.getName(true)}`);
          }
        }
        if (ns.isBooleanSchema() || ns.isNumericSchema() || ns.isBigIntegerSchema() || ns.isBigDecimalSchema()) {
          nodeContents = String(value);
        }
        if (ns.isStringSchema()) {
          if (value === void 0 && ns.isIdempotencyToken()) {
            nodeContents = (0, import_uuid.v4)();
          } else {
            nodeContents = String(value);
          }
        }
        if (nodeContents === null) {
          throw new Error(`Unhandled schema-value pair ${ns.getName(true)}=${value}`);
        }
        return nodeContents;
      }
      writeSimpleInto(_schema, value, into, parentXmlns) {
        const nodeContents = this.writeSimple(_schema, value);
        const ns = NormalizedSchema.of(_schema);
        const content = new import_xml_builder28.XmlText(nodeContents);
        const [xmlnsAttr, xmlns] = this.getXmlnsAttribute(ns, parentXmlns);
        if (xmlns) {
          into.addAttribute(xmlnsAttr, xmlns);
        }
        into.addChildNode(content);
      }
      getXmlnsAttribute(ns, parentXmlns) {
        const traits = ns.getMergedTraits();
        const [prefix, xmlns] = traits.xmlNamespace ?? [];
        if (xmlns && xmlns !== parentXmlns) {
          return [prefix ? `xmlns:${prefix}` : "xmlns", xmlns];
        }
        return [void 0, void 0];
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlCodec.js
var XmlCodec9;
var init_XmlCodec11 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/XmlCodec.js"() {
    init_ConfigurableSerdeContext11();
    init_XmlShapeDeserializer11();
    init_XmlShapeSerializer11();
    XmlCodec9 = class extends SerdeContextConfig11 {
      static {
        __name(this, "XmlCodec");
      }
      settings;
      constructor(settings) {
        super();
        this.settings = settings;
      }
      createSerializer() {
        const serializer = new XmlShapeSerializer9(this.settings);
        serializer.setSerdeContext(this.serdeContext);
        return serializer;
      }
      createDeserializer() {
        const deserializer = new XmlShapeDeserializer10(this.settings);
        deserializer.setSerdeContext(this.serdeContext);
        return deserializer;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/AwsRestXmlProtocol.js
var AwsRestXmlProtocol9;
var init_AwsRestXmlProtocol11 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/xml/AwsRestXmlProtocol.js"() {
    init_protocols();
    init_schema4();
    init_ProtocolLib11();
    init_parseXmlBody11();
    init_XmlCodec11();
    AwsRestXmlProtocol9 = class extends HttpBindingProtocol {
      static {
        __name(this, "AwsRestXmlProtocol");
      }
      codec;
      serializer;
      deserializer;
      mixin = new ProtocolLib11();
      constructor(options) {
        super(options);
        const settings = {
          timestampFormat: {
            useTrait: true,
            default: 5
          },
          httpBindings: true,
          xmlNamespace: options.xmlNamespace,
          serviceNamespace: options.defaultNamespace
        };
        this.codec = new XmlCodec9(settings);
        this.serializer = new HttpInterceptingShapeSerializer(this.codec.createSerializer(), settings);
        this.deserializer = new HttpInterceptingShapeDeserializer(this.codec.createDeserializer(), settings);
      }
      getPayloadCodec() {
        return this.codec;
      }
      getShapeId() {
        return "aws.protocols#restXml";
      }
      async serializeRequest(operationSchema, input, context) {
        const request4 = await super.serializeRequest(operationSchema, input, context);
        const inputSchema = NormalizedSchema.of(operationSchema.input);
        if (!request4.headers["content-type"]) {
          const contentType = this.mixin.resolveRestContentType(this.getDefaultContentType(), inputSchema);
          if (contentType) {
            request4.headers["content-type"] = contentType;
          }
        }
        if (typeof request4.body === "string" && request4.headers["content-type"] === this.getDefaultContentType() && !request4.body.startsWith("<?xml ") && !this.hasUnstructuredPayloadBinding(inputSchema)) {
          request4.body = '<?xml version="1.0" encoding="UTF-8"?>' + request4.body;
        }
        return request4;
      }
      async deserializeResponse(operationSchema, context, response) {
        return super.deserializeResponse(operationSchema, context, response);
      }
      async handleError(operationSchema, context, response, dataObject, metadata) {
        const errorIdentifier = loadRestXmlErrorCode9(response, dataObject) ?? "Unknown";
        this.mixin.compose(this.compositeErrorRegistry, errorIdentifier, this.options.defaultNamespace);
        if (dataObject.Error && typeof dataObject.Error === "object") {
          for (const key of Object.keys(dataObject.Error)) {
            dataObject[key] = dataObject.Error[key];
            if (key.toLowerCase() === "message") {
              dataObject.message = dataObject.Error[key];
            }
          }
        }
        if (dataObject.RequestId && !metadata.requestId) {
          metadata.requestId = dataObject.RequestId;
        }
        const { errorSchema, errorMetadata } = await this.mixin.getErrorSchemaOrThrowBaseException(errorIdentifier, this.options.defaultNamespace, response, dataObject, metadata);
        const ns = NormalizedSchema.of(errorSchema);
        const message2 = dataObject.Error?.message ?? dataObject.Error?.Message ?? dataObject.message ?? dataObject.Message ?? "UnknownError";
        const ErrorCtor = this.compositeErrorRegistry.getErrorCtor(errorSchema) ?? Error;
        const exception = new ErrorCtor(message2);
        await this.deserializeHttpMessage(errorSchema, context, response, dataObject);
        const output = {};
        const errorDeserializer = this.codec.createDeserializer();
        for (const [name, member7] of ns.structIterator()) {
          const target = member7.getMergedTraits().xmlName ?? name;
          const value = dataObject.Error?.[target] ?? dataObject[target];
          output[name] = errorDeserializer.readSchema(member7, value);
        }
        throw this.mixin.decorateServiceException(Object.assign(exception, errorMetadata, {
          $fault: ns.getMergedTraits().error,
          message: message2
        }, output), dataObject);
      }
      getDefaultContentType() {
        return "application/xml";
      }
      hasUnstructuredPayloadBinding(ns) {
        for (const [, member7] of ns.structIterator()) {
          if (member7.getMergedTraits().httpPayload) {
            return !(member7.isStructSchema() || member7.isMapSchema() || member7.isListSchema());
          }
        }
        return false;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/index.js
var protocols_exports15 = {};
__export(protocols_exports15, {
  AwsEc2QueryProtocol: () => AwsEc2QueryProtocol9,
  AwsJson1_0Protocol: () => AwsJson1_0Protocol9,
  AwsJson1_1Protocol: () => AwsJson1_1Protocol9,
  AwsJsonRpcProtocol: () => AwsJsonRpcProtocol9,
  AwsQueryProtocol: () => AwsQueryProtocol10,
  AwsRestJsonProtocol: () => AwsRestJsonProtocol11,
  AwsRestXmlProtocol: () => AwsRestXmlProtocol9,
  AwsSmithyRpcV2CborProtocol: () => AwsSmithyRpcV2CborProtocol9,
  JsonCodec: () => JsonCodec11,
  JsonShapeDeserializer: () => JsonShapeDeserializer11,
  JsonShapeSerializer: () => JsonShapeSerializer11,
  QueryShapeSerializer: () => QueryShapeSerializer10,
  XmlCodec: () => XmlCodec9,
  XmlShapeDeserializer: () => XmlShapeDeserializer10,
  XmlShapeSerializer: () => XmlShapeSerializer9,
  _toBool: () => _toBool9,
  _toNum: () => _toNum9,
  _toStr: () => _toStr9,
  awsExpectUnion: () => awsExpectUnion9,
  loadRestJsonErrorCode: () => loadRestJsonErrorCode11,
  loadRestXmlErrorCode: () => loadRestXmlErrorCode9,
  parseJsonBody: () => parseJsonBody11,
  parseJsonErrorBody: () => parseJsonErrorBody9,
  parseXmlBody: () => parseXmlBody9,
  parseXmlErrorBody: () => parseXmlErrorBody9
});
var init_protocols18 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/core/dist-es/submodules/protocols/index.js"() {
    init_AwsSmithyRpcV2CborProtocol11();
    init_coercing_serializers11();
    init_AwsJson1_0Protocol11();
    init_AwsJson1_1Protocol11();
    init_AwsJsonRpcProtocol11();
    init_AwsRestJsonProtocol11();
    init_JsonCodec11();
    init_JsonShapeDeserializer11();
    init_JsonShapeSerializer11();
    init_awsExpectUnion11();
    init_parseJsonBody11();
    init_AwsEc2QueryProtocol11();
    init_AwsQueryProtocol11();
    init_QuerySerializerSettings11();
    init_QueryShapeSerializer11();
    init_AwsRestXmlProtocol11();
    init_XmlCodec11();
    init_XmlShapeDeserializer11();
    init_XmlShapeSerializer11();
    init_parseXmlBody11();
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/bdd.js
var import_util_endpoints73, k29, a29, b29, c29, d29, e29, f29, g29, h29, i29, j29, _data29, root29, r29, nodes29, bdd29;
var init_bdd29 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/bdd.js"() {
    import_util_endpoints73 = __toESM(require_dist_cjs20());
    k29 = "ref";
    a29 = -1;
    b29 = true;
    c29 = "isSet";
    d29 = "PartitionResult";
    e29 = "booleanEquals";
    f29 = "getAttr";
    g29 = { [k29]: "Endpoint" };
    h29 = { [k29]: d29 };
    i29 = {};
    j29 = [{ [k29]: "Region" }];
    _data29 = {
      conditions: [
        [c29, [g29]],
        [c29, j29],
        ["aws.partition", j29, d29],
        [e29, [{ [k29]: "UseFIPS" }, b29]],
        [e29, [{ [k29]: "UseDualStack" }, b29]],
        [e29, [{ fn: f29, argv: [h29, "supportsDualStack"] }, b29]],
        [e29, [{ fn: f29, argv: [h29, "supportsFIPS"] }, b29]],
        ["stringEquals", [{ fn: f29, argv: [h29, "name"] }, "aws-us-gov"]]
      ],
      results: [
        [a29],
        [a29, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a29, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [g29, i29],
        ["https://portal.sso-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", i29],
        [a29, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://portal.sso.{Region}.amazonaws.com", i29],
        ["https://portal.sso-fips.{Region}.{PartitionResult#dnsSuffix}", i29],
        [a29, "FIPS is enabled but this partition does not support FIPS"],
        ["https://portal.sso.{Region}.{PartitionResult#dualStackDnsSuffix}", i29],
        [a29, "DualStack is enabled but this partition does not support DualStack"],
        ["https://portal.sso.{Region}.{PartitionResult#dnsSuffix}", i29],
        [a29, "Invalid Configuration: Missing Region"]
      ]
    };
    root29 = 2;
    r29 = 1e8;
    nodes29 = new Int32Array([
      -1,
      1,
      -1,
      0,
      13,
      3,
      1,
      4,
      r29 + 12,
      2,
      5,
      r29 + 12,
      3,
      8,
      6,
      4,
      7,
      r29 + 11,
      5,
      r29 + 9,
      r29 + 10,
      4,
      11,
      9,
      6,
      10,
      r29 + 8,
      7,
      r29 + 6,
      r29 + 7,
      5,
      12,
      r29 + 5,
      6,
      r29 + 4,
      r29 + 5,
      3,
      r29 + 1,
      14,
      4,
      r29 + 2,
      r29 + 3
    ]);
    bdd29 = import_util_endpoints73.BinaryDecisionDiagram.from(nodes29, root29, _data29.conditions, _data29.results);
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/endpointResolver.js
var import_util_endpoints74, import_util_endpoints75, cache29, defaultEndpointResolver29;
var init_endpointResolver29 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/endpoint/endpointResolver.js"() {
    import_util_endpoints74 = __toESM(require_dist_cjs21());
    import_util_endpoints75 = __toESM(require_dist_cjs20());
    init_bdd29();
    cache29 = new import_util_endpoints75.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    defaultEndpointResolver29 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache29.get(endpointParams, () => (0, import_util_endpoints75.decideEndpoint)(bdd29, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    import_util_endpoints75.customEndpointFunctions.aws = import_util_endpoints74.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/SSOServiceException.js
var import_smithy_client239, SSOServiceException9;
var init_SSOServiceException9 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/SSOServiceException.js"() {
    import_smithy_client239 = __toESM(require_dist_cjs34());
    SSOServiceException9 = class _SSOServiceException extends import_smithy_client239.ServiceException {
      static {
        __name(this, "SSOServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _SSOServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/errors.js
var InvalidRequestException12, ResourceNotFoundException10, TooManyRequestsException10, UnauthorizedException9;
var init_errors29 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/errors.js"() {
    init_SSOServiceException9();
    InvalidRequestException12 = class _InvalidRequestException extends SSOServiceException9 {
      static {
        __name(this, "InvalidRequestException");
      }
      name = "InvalidRequestException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidRequestException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidRequestException.prototype);
      }
    };
    ResourceNotFoundException10 = class _ResourceNotFoundException extends SSOServiceException9 {
      static {
        __name(this, "ResourceNotFoundException");
      }
      name = "ResourceNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ResourceNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceNotFoundException.prototype);
      }
    };
    TooManyRequestsException10 = class _TooManyRequestsException extends SSOServiceException9 {
      static {
        __name(this, "TooManyRequestsException");
      }
      name = "TooManyRequestsException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TooManyRequestsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyRequestsException.prototype);
      }
    };
    UnauthorizedException9 = class _UnauthorizedException extends SSOServiceException9 {
      static {
        __name(this, "UnauthorizedException");
      }
      name = "UnauthorizedException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "UnauthorizedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnauthorizedException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/schemas/schemas_0.js
var _ATT9, _GRC9, _GRCR9, _GRCRe9, _IRE12, _RC9, _RNFE10, _SAKT9, _STT9, _TMRE18, _UE9, _aI9, _aKI17, _aT20, _ai9, _c29, _e29, _ex9, _h20, _hE29, _hH9, _hQ9, _m26, _rC9, _rN9, _rn9, _s29, _sAK17, _sT17, _xasbt9, n029, _s_registry29, SSOServiceException$9, n0_registry29, InvalidRequestException$12, ResourceNotFoundException$10, TooManyRequestsException$10, UnauthorizedException$9, errorTypeRegistries29, AccessTokenType9, SecretAccessKeyType9, SessionTokenType9, GetRoleCredentialsRequest$9, GetRoleCredentialsResponse$9, RoleCredentials$9, GetRoleCredentials$9;
var init_schemas_029 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/schemas/schemas_0.js"() {
    init_schema4();
    init_errors29();
    init_SSOServiceException9();
    _ATT9 = "AccessTokenType";
    _GRC9 = "GetRoleCredentials";
    _GRCR9 = "GetRoleCredentialsRequest";
    _GRCRe9 = "GetRoleCredentialsResponse";
    _IRE12 = "InvalidRequestException";
    _RC9 = "RoleCredentials";
    _RNFE10 = "ResourceNotFoundException";
    _SAKT9 = "SecretAccessKeyType";
    _STT9 = "SessionTokenType";
    _TMRE18 = "TooManyRequestsException";
    _UE9 = "UnauthorizedException";
    _aI9 = "accountId";
    _aKI17 = "accessKeyId";
    _aT20 = "accessToken";
    _ai9 = "account_id";
    _c29 = "client";
    _e29 = "error";
    _ex9 = "expiration";
    _h20 = "http";
    _hE29 = "httpError";
    _hH9 = "httpHeader";
    _hQ9 = "httpQuery";
    _m26 = "message";
    _rC9 = "roleCredentials";
    _rN9 = "roleName";
    _rn9 = "role_name";
    _s29 = "smithy.ts.sdk.synthetic.com.amazonaws.sso";
    _sAK17 = "secretAccessKey";
    _sT17 = "sessionToken";
    _xasbt9 = "x-amz-sso_bearer_token";
    n029 = "com.amazonaws.sso";
    _s_registry29 = TypeRegistry.for(_s29);
    SSOServiceException$9 = [-3, _s29, "SSOServiceException", 0, [], []];
    _s_registry29.registerError(SSOServiceException$9, SSOServiceException9);
    n0_registry29 = TypeRegistry.for(n029);
    InvalidRequestException$12 = [-3, n029, _IRE12, { [_e29]: _c29, [_hE29]: 400 }, [_m26], [0]];
    n0_registry29.registerError(InvalidRequestException$12, InvalidRequestException12);
    ResourceNotFoundException$10 = [-3, n029, _RNFE10, { [_e29]: _c29, [_hE29]: 404 }, [_m26], [0]];
    n0_registry29.registerError(ResourceNotFoundException$10, ResourceNotFoundException10);
    TooManyRequestsException$10 = [-3, n029, _TMRE18, { [_e29]: _c29, [_hE29]: 429 }, [_m26], [0]];
    n0_registry29.registerError(TooManyRequestsException$10, TooManyRequestsException10);
    UnauthorizedException$9 = [-3, n029, _UE9, { [_e29]: _c29, [_hE29]: 401 }, [_m26], [0]];
    n0_registry29.registerError(UnauthorizedException$9, UnauthorizedException9);
    errorTypeRegistries29 = [_s_registry29, n0_registry29];
    AccessTokenType9 = [0, n029, _ATT9, 8, 0];
    SecretAccessKeyType9 = [0, n029, _SAKT9, 8, 0];
    SessionTokenType9 = [0, n029, _STT9, 8, 0];
    GetRoleCredentialsRequest$9 = [
      3,
      n029,
      _GRCR9,
      0,
      [_rN9, _aI9, _aT20],
      [
        [0, { [_hQ9]: _rn9 }],
        [0, { [_hQ9]: _ai9 }],
        [() => AccessTokenType9, { [_hH9]: _xasbt9 }]
      ],
      3
    ];
    GetRoleCredentialsResponse$9 = [
      3,
      n029,
      _GRCRe9,
      0,
      [_rC9],
      [[() => RoleCredentials$9, 0]]
    ];
    RoleCredentials$9 = [
      3,
      n029,
      _RC9,
      0,
      [_aKI17, _sAK17, _sT17, _ex9],
      [0, [() => SecretAccessKeyType9, 0], [() => SessionTokenType9, 0], 1]
    ];
    GetRoleCredentials$9 = [
      9,
      n029,
      _GRC9,
      { [_h20]: ["GET", "/federation/credentials", 200] },
      () => GetRoleCredentialsRequest$9,
      () => GetRoleCredentialsResponse$9
    ];
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.shared.js
var import_smithy_client240, import_url_parser26, import_util_base6465, import_util_utf849, getRuntimeConfig57;
var init_runtimeConfig_shared29 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.shared.js"() {
    init_httpAuthSchemes12();
    init_protocols18();
    init_dist_es();
    import_smithy_client240 = __toESM(require_dist_cjs34());
    import_url_parser26 = __toESM(require_dist_cjs18());
    import_util_base6465 = __toESM(require_dist_cjs10());
    import_util_utf849 = __toESM(require_dist_cjs9());
    init_httpAuthSchemeProvider29();
    init_endpointResolver29();
    init_schemas_029();
    getRuntimeConfig57 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2019-06-10",
        base64Decoder: config2?.base64Decoder ?? import_util_base6465.fromBase64,
        base64Encoder: config2?.base64Encoder ?? import_util_base6465.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver29,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSSOHttpAuthSchemeProvider9,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer10()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        logger: config2?.logger ?? new import_smithy_client240.NoOpLogger(),
        protocol: config2?.protocol ?? AwsRestJsonProtocol11,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.sso",
          errorTypeRegistries: errorTypeRegistries29,
          version: "2019-06-10",
          serviceTarget: "SWBPortalService"
        },
        serviceId: config2?.serviceId ?? "SSO",
        urlParser: config2?.urlParser ?? import_url_parser26.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? import_util_utf849.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? import_util_utf849.toUtf8
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.js
var import_util_user_agent_node25, import_config_resolver50, import_hash_node27, import_middleware_retry49, import_node_config_provider26, import_node_http_handler29, import_smithy_client241, import_util_body_length_node25, import_util_defaults_mode_node25, import_util_retry36, getRuntimeConfig58;
var init_runtimeConfig29 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeConfig.js"() {
    init_package10();
    init_client19();
    init_httpAuthSchemes12();
    import_util_user_agent_node25 = __toESM(require_dist_cjs202());
    import_config_resolver50 = __toESM(require_dist_cjs25());
    import_hash_node27 = __toESM(require_dist_cjs44());
    import_middleware_retry49 = __toESM(require_dist_cjs198());
    import_node_config_provider26 = __toESM(require_dist_cjs29());
    import_node_http_handler29 = __toESM(require_dist_cjs13());
    import_smithy_client241 = __toESM(require_dist_cjs34());
    import_util_body_length_node25 = __toESM(require_dist_cjs45());
    import_util_defaults_mode_node25 = __toESM(require_dist_cjs46());
    import_util_retry36 = __toESM(require_dist_cjs22());
    init_runtimeConfig_shared29();
    getRuntimeConfig58 = /* @__PURE__ */ __name((config2) => {
      (0, import_smithy_client241.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, import_util_defaults_mode_node25.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(import_smithy_client241.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig57(config2);
      emitWarningIfUnsupportedVersion38(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, import_node_config_provider26.loadConfig)(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS10, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? import_util_body_length_node25.calculateBodyLength,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, import_util_user_agent_node25.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_default10.version }),
        maxAttempts: config2?.maxAttempts ?? (0, import_node_config_provider26.loadConfig)(import_middleware_retry49.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, import_node_config_provider26.loadConfig)(import_config_resolver50.NODE_REGION_CONFIG_OPTIONS, { ...import_config_resolver50.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: import_node_http_handler29.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, import_node_config_provider26.loadConfig)({
          ...import_middleware_retry49.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || import_util_retry36.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? import_hash_node27.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? import_node_http_handler29.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, import_node_config_provider26.loadConfig)(import_config_resolver50.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, import_node_config_provider26.loadConfig)(import_config_resolver50.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, import_node_config_provider26.loadConfig)(import_util_user_agent_node25.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration29, resolveHttpAuthRuntimeConfig29;
var init_httpAuthExtensionConfiguration29 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration29 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig29 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeExtensions.js
var import_region_config_resolver32, import_protocol_http60, import_smithy_client242, resolveRuntimeExtensions29;
var init_runtimeExtensions29 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/runtimeExtensions.js"() {
    import_region_config_resolver32 = __toESM(require_dist_cjs48());
    import_protocol_http60 = __toESM(require_dist_cjs2());
    import_smithy_client242 = __toESM(require_dist_cjs34());
    init_httpAuthExtensionConfiguration29();
    resolveRuntimeExtensions29 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign((0, import_region_config_resolver32.getAwsRegionExtensionConfiguration)(runtimeConfig), (0, import_smithy_client242.getDefaultExtensionConfiguration)(runtimeConfig), (0, import_protocol_http60.getHttpHandlerExtensionConfiguration)(runtimeConfig), getHttpAuthExtensionConfiguration29(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, (0, import_region_config_resolver32.resolveAwsRegionExtensionConfiguration)(extensionConfiguration), (0, import_smithy_client242.resolveDefaultRuntimeConfig)(extensionConfiguration), (0, import_protocol_http60.resolveHttpHandlerRuntimeConfig)(extensionConfiguration), resolveHttpAuthRuntimeConfig29(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSOClient.js
var import_middleware_host_header25, import_middleware_logger25, import_middleware_recursion_detection25, import_middleware_user_agent25, import_config_resolver51, import_middleware_content_length25, import_middleware_endpoint65, import_middleware_retry50, import_smithy_client243, SSOClient9;
var init_SSOClient9 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSOClient.js"() {
    import_middleware_host_header25 = __toESM(require_dist_cjs3());
    import_middleware_logger25 = __toESM(require_dist_cjs4());
    import_middleware_recursion_detection25 = __toESM(require_dist_cjs5());
    import_middleware_user_agent25 = __toESM(require_dist_cjs197());
    import_config_resolver51 = __toESM(require_dist_cjs25());
    init_dist_es();
    init_schema4();
    import_middleware_content_length25 = __toESM(require_dist_cjs26());
    import_middleware_endpoint65 = __toESM(require_dist_cjs31());
    import_middleware_retry50 = __toESM(require_dist_cjs198());
    import_smithy_client243 = __toESM(require_dist_cjs34());
    init_httpAuthSchemeProvider29();
    init_EndpointParameters29();
    init_runtimeConfig29();
    init_runtimeExtensions29();
    SSOClient9 = class extends import_smithy_client243.Client {
      static {
        __name(this, "SSOClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig58(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters29(_config_0);
        const _config_2 = (0, import_middleware_user_agent25.resolveUserAgentConfig)(_config_1);
        const _config_3 = (0, import_middleware_retry50.resolveRetryConfig)(_config_2);
        const _config_4 = (0, import_config_resolver51.resolveRegionConfig)(_config_3);
        const _config_5 = (0, import_middleware_host_header25.resolveHostHeaderConfig)(_config_4);
        const _config_6 = (0, import_middleware_endpoint65.resolveEndpointConfig)(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig29(_config_6);
        const _config_8 = resolveRuntimeExtensions29(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin(this.config));
        this.middlewareStack.use((0, import_middleware_user_agent25.getUserAgentPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_retry50.getRetryPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_content_length25.getContentLengthPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_host_header25.getHostHeaderPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_logger25.getLoggerPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_recursion_detection25.getRecursionDetectionPlugin)(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: defaultSSOHttpAuthSchemeParametersProvider9,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/GetRoleCredentialsCommand.js
var import_middleware_endpoint66, import_smithy_client244, GetRoleCredentialsCommand9;
var init_GetRoleCredentialsCommand9 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/GetRoleCredentialsCommand.js"() {
    import_middleware_endpoint66 = __toESM(require_dist_cjs31());
    import_smithy_client244 = __toESM(require_dist_cjs34());
    init_EndpointParameters29();
    init_schemas_029();
    GetRoleCredentialsCommand9 = class extends import_smithy_client244.Command.classBuilder().ep(commonParams29).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint66.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("SWBPortalService", "GetRoleCredentials", {}).n("SSOClient", "GetRoleCredentialsCommand").sc(GetRoleCredentials$9).build() {
      static {
        __name(this, "GetRoleCredentialsCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSO.js
var import_smithy_client245, commands29, SSO9;
var init_SSO9 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/SSO.js"() {
    import_smithy_client245 = __toESM(require_dist_cjs34());
    init_GetRoleCredentialsCommand9();
    init_SSOClient9();
    commands29 = {
      GetRoleCredentialsCommand: GetRoleCredentialsCommand9
    };
    SSO9 = class extends SSOClient9 {
      static {
        __name(this, "SSO");
      }
    };
    (0, import_smithy_client245.createAggregatedClient)(commands29, SSO9);
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/index.js
var init_commands30 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/commands/index.js"() {
    init_GetRoleCredentialsCommand9();
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/models_0.js
var init_models_029 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/index.js
var sso_exports9 = {};
__export(sso_exports9, {
  $Command: () => import_smithy_client244.Command,
  GetRoleCredentials$: () => GetRoleCredentials$9,
  GetRoleCredentialsCommand: () => GetRoleCredentialsCommand9,
  GetRoleCredentialsRequest$: () => GetRoleCredentialsRequest$9,
  GetRoleCredentialsResponse$: () => GetRoleCredentialsResponse$9,
  InvalidRequestException: () => InvalidRequestException12,
  InvalidRequestException$: () => InvalidRequestException$12,
  ResourceNotFoundException: () => ResourceNotFoundException10,
  ResourceNotFoundException$: () => ResourceNotFoundException$10,
  RoleCredentials$: () => RoleCredentials$9,
  SSO: () => SSO9,
  SSOClient: () => SSOClient9,
  SSOServiceException: () => SSOServiceException9,
  SSOServiceException$: () => SSOServiceException$9,
  TooManyRequestsException: () => TooManyRequestsException10,
  TooManyRequestsException$: () => TooManyRequestsException$10,
  UnauthorizedException: () => UnauthorizedException9,
  UnauthorizedException$: () => UnauthorizedException$9,
  __Client: () => import_smithy_client243.Client,
  errorTypeRegistries: () => errorTypeRegistries29
});
var init_sso9 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sso/index.js"() {
    init_SSOClient9();
    init_SSO9();
    init_commands30();
    init_schemas_029();
    init_errors29();
    init_models_029();
    init_SSOServiceException9();
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/loadSso-BKDNrsal.js
var require_loadSso_BKDNrsal9 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/loadSso-BKDNrsal.js"(exports2) {
    "use strict";
    var sso = (init_sso9(), __toCommonJS(sso_exports9));
    exports2.GetRoleCredentialsCommand = sso.GetRoleCredentialsCommand;
    exports2.SSOClient = sso.SSOClient;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/index.js
var require_dist_cjs203 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-sso/dist-cjs/index.js"(exports2) {
    "use strict";
    var propertyProvider = require_dist_cjs27();
    var sharedIniFileLoader = require_dist_cjs28();
    var client = (init_client19(), __toCommonJS(client_exports14));
    var tokenProviders = require_dist_cjs49();
    var isSsoProfile = /* @__PURE__ */ __name((arg) => arg && (typeof arg.sso_start_url === "string" || typeof arg.sso_account_id === "string" || typeof arg.sso_session === "string" || typeof arg.sso_region === "string" || typeof arg.sso_role_name === "string"), "isSsoProfile");
    var SHOULD_FAIL_CREDENTIAL_CHAIN = false;
    var resolveSSOCredentials = /* @__PURE__ */ __name(async ({ ssoStartUrl, ssoSession, ssoAccountId, ssoRegion, ssoRoleName, ssoClient, clientConfig, parentClientConfig, callerClientConfig, profile, filepath, configFilepath, ignoreCache, logger: logger5 }) => {
      let token;
      const refreshMessage = `To refresh this SSO session run aws sso login with the corresponding profile.`;
      if (ssoSession) {
        try {
          const _token = await tokenProviders.fromSso({
            profile,
            filepath,
            configFilepath,
            ignoreCache
          })();
          token = {
            accessToken: _token.token,
            expiresAt: new Date(_token.expiration).toISOString()
          };
        } catch (e32) {
          throw new propertyProvider.CredentialsProviderError(e32.message, {
            tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
            logger: logger5
          });
        }
      } else {
        try {
          token = await sharedIniFileLoader.getSSOTokenFromFile(ssoStartUrl);
        } catch (e32) {
          throw new propertyProvider.CredentialsProviderError(`The SSO session associated with this profile is invalid. ${refreshMessage}`, {
            tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
            logger: logger5
          });
        }
      }
      if (new Date(token.expiresAt).getTime() - Date.now() <= 0) {
        throw new propertyProvider.CredentialsProviderError(`The SSO session associated with this profile has expired. ${refreshMessage}`, {
          tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
          logger: logger5
        });
      }
      const { accessToken } = token;
      const { SSOClient: SSOClient10, GetRoleCredentialsCommand: GetRoleCredentialsCommand10 } = await Promise.resolve().then(function() {
        return require_loadSso_BKDNrsal9();
      });
      const sso = ssoClient || new SSOClient10(Object.assign({}, clientConfig ?? {}, {
        logger: clientConfig?.logger ?? callerClientConfig?.logger ?? parentClientConfig?.logger,
        region: clientConfig?.region ?? ssoRegion,
        userAgentAppId: clientConfig?.userAgentAppId ?? callerClientConfig?.userAgentAppId ?? parentClientConfig?.userAgentAppId
      }));
      let ssoResp;
      try {
        ssoResp = await sso.send(new GetRoleCredentialsCommand10({
          accountId: ssoAccountId,
          roleName: ssoRoleName,
          accessToken
        }));
      } catch (e32) {
        throw new propertyProvider.CredentialsProviderError(e32, {
          tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
          logger: logger5
        });
      }
      const { roleCredentials: { accessKeyId, secretAccessKey, sessionToken, expiration, credentialScope, accountId } = {} } = ssoResp;
      if (!accessKeyId || !secretAccessKey || !sessionToken || !expiration) {
        throw new propertyProvider.CredentialsProviderError("SSO returns an invalid temporary credential.", {
          tryNextLink: SHOULD_FAIL_CREDENTIAL_CHAIN,
          logger: logger5
        });
      }
      const credentials = {
        accessKeyId,
        secretAccessKey,
        sessionToken,
        expiration: new Date(expiration),
        ...credentialScope && { credentialScope },
        ...accountId && { accountId }
      };
      if (ssoSession) {
        client.setCredentialFeature(credentials, "CREDENTIALS_SSO", "s");
      } else {
        client.setCredentialFeature(credentials, "CREDENTIALS_SSO_LEGACY", "u");
      }
      return credentials;
    }, "resolveSSOCredentials");
    var validateSsoProfile = /* @__PURE__ */ __name((profile, logger5) => {
      const { sso_start_url, sso_account_id, sso_region, sso_role_name } = profile;
      if (!sso_start_url || !sso_account_id || !sso_region || !sso_role_name) {
        throw new propertyProvider.CredentialsProviderError(`Profile is configured with invalid SSO credentials. Required parameters "sso_account_id", "sso_region", "sso_role_name", "sso_start_url". Got ${Object.keys(profile).join(", ")}
Reference: https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-sso.html`, { tryNextLink: false, logger: logger5 });
      }
      return profile;
    }, "validateSsoProfile");
    var fromSSO = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/credential-provider-sso - fromSSO");
      const { ssoStartUrl, ssoAccountId, ssoRegion, ssoRoleName, ssoSession } = init;
      const { ssoClient } = init;
      const profileName = sharedIniFileLoader.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      });
      if (!ssoStartUrl && !ssoAccountId && !ssoRegion && !ssoRoleName && !ssoSession) {
        const profiles = await sharedIniFileLoader.parseKnownFiles(init);
        const profile = profiles[profileName];
        if (!profile) {
          throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} was not found.`, { logger: init.logger });
        }
        if (!isSsoProfile(profile)) {
          throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} is not configured with SSO credentials.`, {
            logger: init.logger
          });
        }
        if (profile?.sso_session) {
          const ssoSessions = await sharedIniFileLoader.loadSsoSessionData(init);
          const session = ssoSessions[profile.sso_session];
          const conflictMsg = ` configurations in profile ${profileName} and sso-session ${profile.sso_session}`;
          if (ssoRegion && ssoRegion !== session.sso_region) {
            throw new propertyProvider.CredentialsProviderError(`Conflicting SSO region` + conflictMsg, {
              tryNextLink: false,
              logger: init.logger
            });
          }
          if (ssoStartUrl && ssoStartUrl !== session.sso_start_url) {
            throw new propertyProvider.CredentialsProviderError(`Conflicting SSO start_url` + conflictMsg, {
              tryNextLink: false,
              logger: init.logger
            });
          }
          profile.sso_region = session.sso_region;
          profile.sso_start_url = session.sso_start_url;
        }
        const { sso_start_url, sso_account_id, sso_region, sso_role_name, sso_session } = validateSsoProfile(profile, init.logger);
        return resolveSSOCredentials({
          ssoStartUrl: sso_start_url,
          ssoSession: sso_session,
          ssoAccountId: sso_account_id,
          ssoRegion: sso_region,
          ssoRoleName: sso_role_name,
          ssoClient,
          clientConfig: init.clientConfig,
          parentClientConfig: init.parentClientConfig,
          callerClientConfig: init.callerClientConfig,
          profile: profileName,
          filepath: init.filepath,
          configFilepath: init.configFilepath,
          ignoreCache: init.ignoreCache,
          logger: init.logger
        });
      } else if (!ssoStartUrl || !ssoAccountId || !ssoRegion || !ssoRoleName) {
        throw new propertyProvider.CredentialsProviderError('Incomplete configuration. The fromSSO() argument hash must include "ssoStartUrl", "ssoAccountId", "ssoRegion", "ssoRoleName"', { tryNextLink: false, logger: init.logger });
      } else {
        return resolveSSOCredentials({
          ssoStartUrl,
          ssoSession,
          ssoAccountId,
          ssoRegion,
          ssoRoleName,
          ssoClient,
          clientConfig: init.clientConfig,
          parentClientConfig: init.parentClientConfig,
          callerClientConfig: init.callerClientConfig,
          profile: profileName,
          filepath: init.filepath,
          configFilepath: init.configFilepath,
          ignoreCache: init.ignoreCache,
          logger: init.logger
        });
      }
    }, "fromSSO");
    exports2.fromSSO = fromSSO;
    exports2.isSsoProfile = isSsoProfile;
    exports2.validateSsoProfile = validateSsoProfile;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption30(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "signin",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption30(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var import_util_middleware31, defaultSigninHttpAuthSchemeParametersProvider9, defaultSigninHttpAuthSchemeProvider9, resolveHttpAuthSchemeConfig30;
var init_httpAuthSchemeProvider30 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes12();
    import_util_middleware31 = __toESM(require_dist_cjs6());
    defaultSigninHttpAuthSchemeParametersProvider9 = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, import_util_middleware31.getSmithyContext)(context).operation,
        region: await (0, import_util_middleware31.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "defaultSigninHttpAuthSchemeParametersProvider");
    __name(createAwsAuthSigv4HttpAuthOption30, "createAwsAuthSigv4HttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption30, "createSmithyApiNoAuthHttpAuthOption");
    defaultSigninHttpAuthSchemeProvider9 = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "CreateOAuth2Token": {
          options.push(createSmithyApiNoAuthHttpAuthOption30(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption30(authParameters));
        }
      }
      return options;
    }, "defaultSigninHttpAuthSchemeProvider");
    resolveHttpAuthSchemeConfig30 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveAwsSdkSigV4Config10(config2);
      return Object.assign(config_0, {
        authSchemePreference: (0, import_util_middleware31.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/EndpointParameters.js
var resolveClientEndpointParameters30, commonParams30;
var init_EndpointParameters30 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters30 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "signin"
      });
    }, "resolveClientEndpointParameters");
    commonParams30 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/bdd.js
var import_util_endpoints76, m18, a30, b30, c30, d30, e30, f30, g30, h30, i30, j30, k30, l18, _data30, root30, r30, nodes30, bdd30;
var init_bdd30 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/bdd.js"() {
    import_util_endpoints76 = __toESM(require_dist_cjs20());
    m18 = "ref";
    a30 = -1;
    b30 = true;
    c30 = "isSet";
    d30 = "PartitionResult";
    e30 = "booleanEquals";
    f30 = "getAttr";
    g30 = "stringEquals";
    h30 = { [m18]: "Endpoint" };
    i30 = { [m18]: d30 };
    j30 = { fn: f30, argv: [i30, "name"] };
    k30 = {};
    l18 = [{ [m18]: "Region" }];
    _data30 = {
      conditions: [
        [c30, [h30]],
        [c30, l18],
        ["aws.partition", l18, d30],
        [e30, [{ [m18]: "UseFIPS" }, b30]],
        [e30, [{ [m18]: "UseDualStack" }, b30]],
        [e30, [{ fn: f30, argv: [i30, "supportsDualStack"] }, b30]],
        [e30, [{ fn: f30, argv: [i30, "supportsFIPS"] }, b30]],
        [g30, [j30, "aws"]],
        [g30, [j30, "aws-cn"]],
        [g30, [j30, "aws-us-gov"]]
      ],
      results: [
        [a30],
        [a30, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a30, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [h30, k30],
        ["https://{Region}.signin.aws.amazon.com", k30],
        ["https://{Region}.signin.amazonaws.cn", k30],
        ["https://{Region}.signin.amazonaws-us-gov.com", k30],
        ["https://signin-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", k30],
        [a30, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://signin-fips.{Region}.{PartitionResult#dnsSuffix}", k30],
        [a30, "FIPS is enabled but this partition does not support FIPS"],
        ["https://signin.{Region}.{PartitionResult#dualStackDnsSuffix}", k30],
        [a30, "DualStack is enabled but this partition does not support DualStack"],
        ["https://signin.{Region}.{PartitionResult#dnsSuffix}", k30],
        [a30, "Invalid Configuration: Missing Region"]
      ]
    };
    root30 = 2;
    r30 = 1e8;
    nodes30 = new Int32Array([
      -1,
      1,
      -1,
      0,
      15,
      3,
      1,
      4,
      r30 + 14,
      2,
      5,
      r30 + 14,
      3,
      11,
      6,
      4,
      10,
      7,
      7,
      r30 + 4,
      8,
      8,
      r30 + 5,
      9,
      9,
      r30 + 6,
      r30 + 13,
      5,
      r30 + 11,
      r30 + 12,
      4,
      13,
      12,
      6,
      r30 + 9,
      r30 + 10,
      5,
      14,
      r30 + 8,
      6,
      r30 + 7,
      r30 + 8,
      3,
      r30 + 1,
      16,
      4,
      r30 + 2,
      r30 + 3
    ]);
    bdd30 = import_util_endpoints76.BinaryDecisionDiagram.from(nodes30, root30, _data30.conditions, _data30.results);
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/endpointResolver.js
var import_util_endpoints77, import_util_endpoints78, cache30, defaultEndpointResolver30;
var init_endpointResolver30 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/endpoint/endpointResolver.js"() {
    import_util_endpoints77 = __toESM(require_dist_cjs21());
    import_util_endpoints78 = __toESM(require_dist_cjs20());
    init_bdd30();
    cache30 = new import_util_endpoints78.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    defaultEndpointResolver30 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache30.get(endpointParams, () => (0, import_util_endpoints78.decideEndpoint)(bdd30, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    import_util_endpoints78.customEndpointFunctions.aws = import_util_endpoints77.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/SigninServiceException.js
var import_smithy_client246, SigninServiceException9;
var init_SigninServiceException9 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/SigninServiceException.js"() {
    import_smithy_client246 = __toESM(require_dist_cjs34());
    SigninServiceException9 = class _SigninServiceException extends import_smithy_client246.ServiceException {
      static {
        __name(this, "SigninServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _SigninServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/errors.js
var AccessDeniedException12, InternalServerException12, TooManyRequestsError9, ValidationException9;
var init_errors30 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/errors.js"() {
    init_SigninServiceException9();
    AccessDeniedException12 = class _AccessDeniedException extends SigninServiceException9 {
      static {
        __name(this, "AccessDeniedException");
      }
      name = "AccessDeniedException";
      $fault = "client";
      error;
      constructor(opts) {
        super({
          name: "AccessDeniedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AccessDeniedException.prototype);
        this.error = opts.error;
      }
    };
    InternalServerException12 = class _InternalServerException extends SigninServiceException9 {
      static {
        __name(this, "InternalServerException");
      }
      name = "InternalServerException";
      $fault = "server";
      error;
      constructor(opts) {
        super({
          name: "InternalServerException",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _InternalServerException.prototype);
        this.error = opts.error;
      }
    };
    TooManyRequestsError9 = class _TooManyRequestsError extends SigninServiceException9 {
      static {
        __name(this, "TooManyRequestsError");
      }
      name = "TooManyRequestsError";
      $fault = "client";
      error;
      constructor(opts) {
        super({
          name: "TooManyRequestsError",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyRequestsError.prototype);
        this.error = opts.error;
      }
    };
    ValidationException9 = class _ValidationException extends SigninServiceException9 {
      static {
        __name(this, "ValidationException");
      }
      name = "ValidationException";
      $fault = "client";
      error;
      constructor(opts) {
        super({
          name: "ValidationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ValidationException.prototype);
        this.error = opts.error;
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/schemas/schemas_0.js
var _ADE12, _AT12, _COAT9, _COATR9, _COATRB9, _COATRBr9, _COATRr9, _ISE12, _RT12, _TMRE19, _VE9, _aKI18, _aT21, _c30, _cI12, _cV12, _co12, _e30, _eI12, _gT12, _h21, _hE30, _iT12, _jN9, _m27, _rT12, _rU12, _s30, _sAK18, _sT18, _se13, _tI9, _tO9, _tT12, n030, _s_registry30, SigninServiceException$9, n0_registry30, AccessDeniedException$12, InternalServerException$12, TooManyRequestsError$9, ValidationException$9, errorTypeRegistries30, RefreshToken12, AccessToken$9, CreateOAuth2TokenRequest$9, CreateOAuth2TokenRequestBody$9, CreateOAuth2TokenResponse$9, CreateOAuth2TokenResponseBody$9, CreateOAuth2Token$9;
var init_schemas_030 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/schemas/schemas_0.js"() {
    init_schema4();
    init_errors30();
    init_SigninServiceException9();
    _ADE12 = "AccessDeniedException";
    _AT12 = "AccessToken";
    _COAT9 = "CreateOAuth2Token";
    _COATR9 = "CreateOAuth2TokenRequest";
    _COATRB9 = "CreateOAuth2TokenRequestBody";
    _COATRBr9 = "CreateOAuth2TokenResponseBody";
    _COATRr9 = "CreateOAuth2TokenResponse";
    _ISE12 = "InternalServerException";
    _RT12 = "RefreshToken";
    _TMRE19 = "TooManyRequestsError";
    _VE9 = "ValidationException";
    _aKI18 = "accessKeyId";
    _aT21 = "accessToken";
    _c30 = "client";
    _cI12 = "clientId";
    _cV12 = "codeVerifier";
    _co12 = "code";
    _e30 = "error";
    _eI12 = "expiresIn";
    _gT12 = "grantType";
    _h21 = "http";
    _hE30 = "httpError";
    _iT12 = "idToken";
    _jN9 = "jsonName";
    _m27 = "message";
    _rT12 = "refreshToken";
    _rU12 = "redirectUri";
    _s30 = "smithy.ts.sdk.synthetic.com.amazonaws.signin";
    _sAK18 = "secretAccessKey";
    _sT18 = "sessionToken";
    _se13 = "server";
    _tI9 = "tokenInput";
    _tO9 = "tokenOutput";
    _tT12 = "tokenType";
    n030 = "com.amazonaws.signin";
    _s_registry30 = TypeRegistry.for(_s30);
    SigninServiceException$9 = [-3, _s30, "SigninServiceException", 0, [], []];
    _s_registry30.registerError(SigninServiceException$9, SigninServiceException9);
    n0_registry30 = TypeRegistry.for(n030);
    AccessDeniedException$12 = [-3, n030, _ADE12, { [_e30]: _c30 }, [_e30, _m27], [0, 0], 2];
    n0_registry30.registerError(AccessDeniedException$12, AccessDeniedException12);
    InternalServerException$12 = [-3, n030, _ISE12, { [_e30]: _se13, [_hE30]: 500 }, [_e30, _m27], [0, 0], 2];
    n0_registry30.registerError(InternalServerException$12, InternalServerException12);
    TooManyRequestsError$9 = [-3, n030, _TMRE19, { [_e30]: _c30, [_hE30]: 429 }, [_e30, _m27], [0, 0], 2];
    n0_registry30.registerError(TooManyRequestsError$9, TooManyRequestsError9);
    ValidationException$9 = [-3, n030, _VE9, { [_e30]: _c30, [_hE30]: 400 }, [_e30, _m27], [0, 0], 2];
    n0_registry30.registerError(ValidationException$9, ValidationException9);
    errorTypeRegistries30 = [_s_registry30, n0_registry30];
    RefreshToken12 = [0, n030, _RT12, 8, 0];
    AccessToken$9 = [
      3,
      n030,
      _AT12,
      8,
      [_aKI18, _sAK18, _sT18],
      [
        [0, { [_jN9]: _aKI18 }],
        [0, { [_jN9]: _sAK18 }],
        [0, { [_jN9]: _sT18 }]
      ],
      3
    ];
    CreateOAuth2TokenRequest$9 = [
      3,
      n030,
      _COATR9,
      0,
      [_tI9],
      [[() => CreateOAuth2TokenRequestBody$9, 16]],
      1
    ];
    CreateOAuth2TokenRequestBody$9 = [
      3,
      n030,
      _COATRB9,
      0,
      [_cI12, _gT12, _co12, _rU12, _cV12, _rT12],
      [
        [0, { [_jN9]: _cI12 }],
        [0, { [_jN9]: _gT12 }],
        0,
        [0, { [_jN9]: _rU12 }],
        [0, { [_jN9]: _cV12 }],
        [() => RefreshToken12, { [_jN9]: _rT12 }]
      ],
      2
    ];
    CreateOAuth2TokenResponse$9 = [
      3,
      n030,
      _COATRr9,
      0,
      [_tO9],
      [[() => CreateOAuth2TokenResponseBody$9, 16]],
      1
    ];
    CreateOAuth2TokenResponseBody$9 = [
      3,
      n030,
      _COATRBr9,
      0,
      [_aT21, _tT12, _eI12, _rT12, _iT12],
      [
        [() => AccessToken$9, { [_jN9]: _aT21 }],
        [0, { [_jN9]: _tT12 }],
        [1, { [_jN9]: _eI12 }],
        [() => RefreshToken12, { [_jN9]: _rT12 }],
        [0, { [_jN9]: _iT12 }]
      ],
      4
    ];
    CreateOAuth2Token$9 = [
      9,
      n030,
      _COAT9,
      { [_h21]: ["POST", "/v1/token", 200] },
      () => CreateOAuth2TokenRequest$9,
      () => CreateOAuth2TokenResponse$9
    ];
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.shared.js
var import_smithy_client247, import_url_parser27, import_util_base6466, import_util_utf850, getRuntimeConfig59;
var init_runtimeConfig_shared30 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.shared.js"() {
    init_httpAuthSchemes12();
    init_protocols18();
    init_dist_es();
    import_smithy_client247 = __toESM(require_dist_cjs34());
    import_url_parser27 = __toESM(require_dist_cjs18());
    import_util_base6466 = __toESM(require_dist_cjs10());
    import_util_utf850 = __toESM(require_dist_cjs9());
    init_httpAuthSchemeProvider30();
    init_endpointResolver30();
    init_schemas_030();
    getRuntimeConfig59 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2023-01-01",
        base64Decoder: config2?.base64Decoder ?? import_util_base6466.fromBase64,
        base64Encoder: config2?.base64Encoder ?? import_util_base6466.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver30,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSigninHttpAuthSchemeProvider9,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer10()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        logger: config2?.logger ?? new import_smithy_client247.NoOpLogger(),
        protocol: config2?.protocol ?? AwsRestJsonProtocol11,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.signin",
          errorTypeRegistries: errorTypeRegistries30,
          version: "2023-01-01",
          serviceTarget: "Signin"
        },
        serviceId: config2?.serviceId ?? "Signin",
        urlParser: config2?.urlParser ?? import_url_parser27.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? import_util_utf850.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? import_util_utf850.toUtf8
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.js
var import_util_user_agent_node26, import_config_resolver52, import_hash_node28, import_middleware_retry51, import_node_config_provider27, import_node_http_handler30, import_smithy_client248, import_util_body_length_node26, import_util_defaults_mode_node26, import_util_retry37, getRuntimeConfig60;
var init_runtimeConfig30 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeConfig.js"() {
    init_package10();
    init_client19();
    init_httpAuthSchemes12();
    import_util_user_agent_node26 = __toESM(require_dist_cjs202());
    import_config_resolver52 = __toESM(require_dist_cjs25());
    import_hash_node28 = __toESM(require_dist_cjs44());
    import_middleware_retry51 = __toESM(require_dist_cjs198());
    import_node_config_provider27 = __toESM(require_dist_cjs29());
    import_node_http_handler30 = __toESM(require_dist_cjs13());
    import_smithy_client248 = __toESM(require_dist_cjs34());
    import_util_body_length_node26 = __toESM(require_dist_cjs45());
    import_util_defaults_mode_node26 = __toESM(require_dist_cjs46());
    import_util_retry37 = __toESM(require_dist_cjs22());
    init_runtimeConfig_shared30();
    getRuntimeConfig60 = /* @__PURE__ */ __name((config2) => {
      (0, import_smithy_client248.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, import_util_defaults_mode_node26.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(import_smithy_client248.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig59(config2);
      emitWarningIfUnsupportedVersion38(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, import_node_config_provider27.loadConfig)(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS10, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? import_util_body_length_node26.calculateBodyLength,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, import_util_user_agent_node26.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_default10.version }),
        maxAttempts: config2?.maxAttempts ?? (0, import_node_config_provider27.loadConfig)(import_middleware_retry51.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, import_node_config_provider27.loadConfig)(import_config_resolver52.NODE_REGION_CONFIG_OPTIONS, { ...import_config_resolver52.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: import_node_http_handler30.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, import_node_config_provider27.loadConfig)({
          ...import_middleware_retry51.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || import_util_retry37.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? import_hash_node28.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? import_node_http_handler30.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, import_node_config_provider27.loadConfig)(import_config_resolver52.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, import_node_config_provider27.loadConfig)(import_config_resolver52.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, import_node_config_provider27.loadConfig)(import_util_user_agent_node26.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration30, resolveHttpAuthRuntimeConfig30;
var init_httpAuthExtensionConfiguration30 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration30 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig30 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeExtensions.js
var import_region_config_resolver33, import_protocol_http61, import_smithy_client249, resolveRuntimeExtensions30;
var init_runtimeExtensions30 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/runtimeExtensions.js"() {
    import_region_config_resolver33 = __toESM(require_dist_cjs48());
    import_protocol_http61 = __toESM(require_dist_cjs2());
    import_smithy_client249 = __toESM(require_dist_cjs34());
    init_httpAuthExtensionConfiguration30();
    resolveRuntimeExtensions30 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign((0, import_region_config_resolver33.getAwsRegionExtensionConfiguration)(runtimeConfig), (0, import_smithy_client249.getDefaultExtensionConfiguration)(runtimeConfig), (0, import_protocol_http61.getHttpHandlerExtensionConfiguration)(runtimeConfig), getHttpAuthExtensionConfiguration30(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, (0, import_region_config_resolver33.resolveAwsRegionExtensionConfiguration)(extensionConfiguration), (0, import_smithy_client249.resolveDefaultRuntimeConfig)(extensionConfiguration), (0, import_protocol_http61.resolveHttpHandlerRuntimeConfig)(extensionConfiguration), resolveHttpAuthRuntimeConfig30(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/SigninClient.js
var import_middleware_host_header26, import_middleware_logger26, import_middleware_recursion_detection26, import_middleware_user_agent26, import_config_resolver53, import_middleware_content_length26, import_middleware_endpoint67, import_middleware_retry52, import_smithy_client250, SigninClient9;
var init_SigninClient9 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/SigninClient.js"() {
    import_middleware_host_header26 = __toESM(require_dist_cjs3());
    import_middleware_logger26 = __toESM(require_dist_cjs4());
    import_middleware_recursion_detection26 = __toESM(require_dist_cjs5());
    import_middleware_user_agent26 = __toESM(require_dist_cjs197());
    import_config_resolver53 = __toESM(require_dist_cjs25());
    init_dist_es();
    init_schema4();
    import_middleware_content_length26 = __toESM(require_dist_cjs26());
    import_middleware_endpoint67 = __toESM(require_dist_cjs31());
    import_middleware_retry52 = __toESM(require_dist_cjs198());
    import_smithy_client250 = __toESM(require_dist_cjs34());
    init_httpAuthSchemeProvider30();
    init_EndpointParameters30();
    init_runtimeConfig30();
    init_runtimeExtensions30();
    SigninClient9 = class extends import_smithy_client250.Client {
      static {
        __name(this, "SigninClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig60(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters30(_config_0);
        const _config_2 = (0, import_middleware_user_agent26.resolveUserAgentConfig)(_config_1);
        const _config_3 = (0, import_middleware_retry52.resolveRetryConfig)(_config_2);
        const _config_4 = (0, import_config_resolver53.resolveRegionConfig)(_config_3);
        const _config_5 = (0, import_middleware_host_header26.resolveHostHeaderConfig)(_config_4);
        const _config_6 = (0, import_middleware_endpoint67.resolveEndpointConfig)(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig30(_config_6);
        const _config_8 = resolveRuntimeExtensions30(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin(this.config));
        this.middlewareStack.use((0, import_middleware_user_agent26.getUserAgentPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_retry52.getRetryPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_content_length26.getContentLengthPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_host_header26.getHostHeaderPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_logger26.getLoggerPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_recursion_detection26.getRecursionDetectionPlugin)(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: defaultSigninHttpAuthSchemeParametersProvider9,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/CreateOAuth2TokenCommand.js
var import_middleware_endpoint68, import_smithy_client251, CreateOAuth2TokenCommand9;
var init_CreateOAuth2TokenCommand9 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/CreateOAuth2TokenCommand.js"() {
    import_middleware_endpoint68 = __toESM(require_dist_cjs31());
    import_smithy_client251 = __toESM(require_dist_cjs34());
    init_EndpointParameters30();
    init_schemas_030();
    CreateOAuth2TokenCommand9 = class extends import_smithy_client251.Command.classBuilder().ep(commonParams30).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint68.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("Signin", "CreateOAuth2Token", {}).n("SigninClient", "CreateOAuth2TokenCommand").sc(CreateOAuth2Token$9).build() {
      static {
        __name(this, "CreateOAuth2TokenCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/Signin.js
var import_smithy_client252, commands30, Signin9;
var init_Signin9 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/Signin.js"() {
    import_smithy_client252 = __toESM(require_dist_cjs34());
    init_CreateOAuth2TokenCommand9();
    init_SigninClient9();
    commands30 = {
      CreateOAuth2TokenCommand: CreateOAuth2TokenCommand9
    };
    Signin9 = class extends SigninClient9 {
      static {
        __name(this, "Signin");
      }
    };
    (0, import_smithy_client252.createAggregatedClient)(commands30, Signin9);
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/index.js
var init_commands31 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/commands/index.js"() {
    init_CreateOAuth2TokenCommand9();
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/enums.js
var OAuth2ErrorCode9;
var init_enums12 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/enums.js"() {
    OAuth2ErrorCode9 = {
      AUTHCODE_EXPIRED: "AUTHCODE_EXPIRED",
      INSUFFICIENT_PERMISSIONS: "INSUFFICIENT_PERMISSIONS",
      INVALID_REQUEST: "INVALID_REQUEST",
      SERVER_ERROR: "server_error",
      TOKEN_EXPIRED: "TOKEN_EXPIRED",
      USER_CREDENTIALS_CHANGED: "USER_CREDENTIALS_CHANGED"
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/models_0.js
var init_models_030 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/index.js
var signin_exports9 = {};
__export(signin_exports9, {
  $Command: () => import_smithy_client251.Command,
  AccessDeniedException: () => AccessDeniedException12,
  AccessDeniedException$: () => AccessDeniedException$12,
  AccessToken$: () => AccessToken$9,
  CreateOAuth2Token$: () => CreateOAuth2Token$9,
  CreateOAuth2TokenCommand: () => CreateOAuth2TokenCommand9,
  CreateOAuth2TokenRequest$: () => CreateOAuth2TokenRequest$9,
  CreateOAuth2TokenRequestBody$: () => CreateOAuth2TokenRequestBody$9,
  CreateOAuth2TokenResponse$: () => CreateOAuth2TokenResponse$9,
  CreateOAuth2TokenResponseBody$: () => CreateOAuth2TokenResponseBody$9,
  InternalServerException: () => InternalServerException12,
  InternalServerException$: () => InternalServerException$12,
  OAuth2ErrorCode: () => OAuth2ErrorCode9,
  Signin: () => Signin9,
  SigninClient: () => SigninClient9,
  SigninServiceException: () => SigninServiceException9,
  SigninServiceException$: () => SigninServiceException$9,
  TooManyRequestsError: () => TooManyRequestsError9,
  TooManyRequestsError$: () => TooManyRequestsError$9,
  ValidationException: () => ValidationException9,
  ValidationException$: () => ValidationException$9,
  __Client: () => import_smithy_client250.Client,
  errorTypeRegistries: () => errorTypeRegistries30
});
var init_signin9 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/signin/index.js"() {
    init_SigninClient9();
    init_Signin9();
    init_commands31();
    init_schemas_030();
    init_enums12();
    init_errors30();
    init_models_030();
    init_SigninServiceException9();
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-login/dist-cjs/index.js
var require_dist_cjs204 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-login/dist-cjs/index.js"(exports2) {
    "use strict";
    var client = (init_client19(), __toCommonJS(client_exports14));
    var propertyProvider = require_dist_cjs27();
    var sharedIniFileLoader = require_dist_cjs28();
    var protocolHttp = require_dist_cjs2();
    var node_crypto = require("node:crypto");
    var node_fs = require("node:fs");
    var node_os = require("node:os");
    var node_path = require("node:path");
    var LoginCredentialsFetcher = class _LoginCredentialsFetcher {
      static {
        __name(this, "LoginCredentialsFetcher");
      }
      profileData;
      init;
      callerClientConfig;
      static REFRESH_THRESHOLD = 5 * 60 * 1e3;
      constructor(profileData, init, callerClientConfig) {
        this.profileData = profileData;
        this.init = init;
        this.callerClientConfig = callerClientConfig;
      }
      async loadCredentials() {
        const token = await this.loadToken();
        if (!token) {
          throw new propertyProvider.CredentialsProviderError(`Failed to load a token for session ${this.loginSession}, please re-authenticate using aws login`, { tryNextLink: false, logger: this.logger });
        }
        const accessToken = token.accessToken;
        const now = Date.now();
        const expiryTime = new Date(accessToken.expiresAt).getTime();
        const timeUntilExpiry = expiryTime - now;
        if (timeUntilExpiry <= _LoginCredentialsFetcher.REFRESH_THRESHOLD) {
          return this.refresh(token);
        }
        return {
          accessKeyId: accessToken.accessKeyId,
          secretAccessKey: accessToken.secretAccessKey,
          sessionToken: accessToken.sessionToken,
          accountId: accessToken.accountId,
          expiration: new Date(accessToken.expiresAt)
        };
      }
      get logger() {
        return this.init?.logger;
      }
      get loginSession() {
        return this.profileData.login_session;
      }
      async refresh(token) {
        const { SigninClient: SigninClient10, CreateOAuth2TokenCommand: CreateOAuth2TokenCommand10 } = await Promise.resolve().then(() => (init_signin9(), signin_exports9));
        const { logger: logger5, userAgentAppId } = this.callerClientConfig ?? {};
        const isH210 = /* @__PURE__ */ __name((requestHandler2) => {
          return requestHandler2?.metadata?.handlerProtocol === "h2";
        }, "isH2");
        const requestHandler = isH210(this.callerClientConfig?.requestHandler) ? void 0 : this.callerClientConfig?.requestHandler;
        const region = this.profileData.region ?? await this.callerClientConfig?.region?.() ?? process.env.AWS_REGION;
        const client2 = new SigninClient10({
          credentials: {
            accessKeyId: "",
            secretAccessKey: ""
          },
          region,
          requestHandler,
          logger: logger5,
          userAgentAppId,
          ...this.init?.clientConfig
        });
        this.createDPoPInterceptor(client2.middlewareStack);
        const commandInput = {
          tokenInput: {
            clientId: token.clientId,
            refreshToken: token.refreshToken,
            grantType: "refresh_token"
          }
        };
        try {
          const response = await client2.send(new CreateOAuth2TokenCommand10(commandInput));
          const { accessKeyId, secretAccessKey, sessionToken } = response.tokenOutput?.accessToken ?? {};
          const { refreshToken, expiresIn } = response.tokenOutput ?? {};
          if (!accessKeyId || !secretAccessKey || !sessionToken || !refreshToken) {
            throw new propertyProvider.CredentialsProviderError("Token refresh response missing required fields", {
              logger: this.logger,
              tryNextLink: false
            });
          }
          const expiresInMs = (expiresIn ?? 900) * 1e3;
          const expiration = new Date(Date.now() + expiresInMs);
          const updatedToken = {
            ...token,
            accessToken: {
              ...token.accessToken,
              accessKeyId,
              secretAccessKey,
              sessionToken,
              expiresAt: expiration.toISOString()
            },
            refreshToken
          };
          await this.saveToken(updatedToken);
          const newAccessToken = updatedToken.accessToken;
          return {
            accessKeyId: newAccessToken.accessKeyId,
            secretAccessKey: newAccessToken.secretAccessKey,
            sessionToken: newAccessToken.sessionToken,
            accountId: newAccessToken.accountId,
            expiration
          };
        } catch (error4) {
          if (error4.name === "AccessDeniedException") {
            const errorType = error4.error;
            let message2;
            switch (errorType) {
              case "TOKEN_EXPIRED":
                message2 = "Your session has expired. Please reauthenticate.";
                break;
              case "USER_CREDENTIALS_CHANGED":
                message2 = "Unable to refresh credentials because of a change in your password. Please reauthenticate with your new password.";
                break;
              case "INSUFFICIENT_PERMISSIONS":
                message2 = "Unable to refresh credentials due to insufficient permissions. You may be missing permission for the 'CreateOAuth2Token' action.";
                break;
              default:
                message2 = `Failed to refresh token: ${String(error4)}. Please re-authenticate using \`aws login\``;
            }
            throw new propertyProvider.CredentialsProviderError(message2, { logger: this.logger, tryNextLink: false });
          }
          throw new propertyProvider.CredentialsProviderError(`Failed to refresh token: ${String(error4)}. Please re-authenticate using aws login`, { logger: this.logger });
        }
      }
      async loadToken() {
        const tokenFilePath = this.getTokenFilePath();
        try {
          let tokenData;
          try {
            tokenData = await sharedIniFileLoader.readFile(tokenFilePath, { ignoreCache: this.init?.ignoreCache });
          } catch {
            tokenData = await node_fs.promises.readFile(tokenFilePath, "utf8");
          }
          const token = JSON.parse(tokenData);
          const missingFields = ["accessToken", "clientId", "refreshToken", "dpopKey"].filter((k32) => !token[k32]);
          if (!token.accessToken?.accountId) {
            missingFields.push("accountId");
          }
          if (missingFields.length > 0) {
            throw new propertyProvider.CredentialsProviderError(`Token validation failed, missing fields: ${missingFields.join(", ")}`, {
              logger: this.logger,
              tryNextLink: false
            });
          }
          return token;
        } catch (error4) {
          throw new propertyProvider.CredentialsProviderError(`Failed to load token from ${tokenFilePath}: ${String(error4)}`, {
            logger: this.logger,
            tryNextLink: false
          });
        }
      }
      async saveToken(token) {
        const tokenFilePath = this.getTokenFilePath();
        const directory = node_path.dirname(tokenFilePath);
        try {
          await node_fs.promises.mkdir(directory, { recursive: true });
        } catch (error4) {
        }
        await node_fs.promises.writeFile(tokenFilePath, JSON.stringify(token, null, 2), "utf8");
      }
      getTokenFilePath() {
        const directory = process.env.AWS_LOGIN_CACHE_DIRECTORY ?? node_path.join(node_os.homedir(), ".aws", "login", "cache");
        const loginSessionBytes = Buffer.from(this.loginSession, "utf8");
        const loginSessionSha256 = node_crypto.createHash("sha256").update(loginSessionBytes).digest("hex");
        return node_path.join(directory, `${loginSessionSha256}.json`);
      }
      derToRawSignature(derSignature) {
        let offset = 2;
        if (derSignature[offset] !== 2) {
          throw new Error("Invalid DER signature");
        }
        offset++;
        const rLength = derSignature[offset++];
        let r32 = derSignature.subarray(offset, offset + rLength);
        offset += rLength;
        if (derSignature[offset] !== 2) {
          throw new Error("Invalid DER signature");
        }
        offset++;
        const sLength = derSignature[offset++];
        let s = derSignature.subarray(offset, offset + sLength);
        r32 = r32[0] === 0 ? r32.subarray(1) : r32;
        s = s[0] === 0 ? s.subarray(1) : s;
        const rPadded = Buffer.concat([Buffer.alloc(32 - r32.length), r32]);
        const sPadded = Buffer.concat([Buffer.alloc(32 - s.length), s]);
        return Buffer.concat([rPadded, sPadded]);
      }
      createDPoPInterceptor(middlewareStack) {
        middlewareStack.add((next) => async (args) => {
          if (protocolHttp.HttpRequest.isInstance(args.request)) {
            const request4 = args.request;
            const actualEndpoint = `${request4.protocol}//${request4.hostname}${request4.port ? `:${request4.port}` : ""}${request4.path}`;
            const dpop = await this.generateDpop(request4.method, actualEndpoint);
            request4.headers = {
              ...request4.headers,
              DPoP: dpop
            };
          }
          return next(args);
        }, {
          step: "finalizeRequest",
          name: "dpopInterceptor",
          override: true
        });
      }
      async generateDpop(method = "POST", endpoint) {
        const token = await this.loadToken();
        try {
          const privateKey = node_crypto.createPrivateKey({
            key: token.dpopKey,
            format: "pem",
            type: "sec1"
          });
          const publicKey = node_crypto.createPublicKey(privateKey);
          const publicDer = publicKey.export({ format: "der", type: "spki" });
          let pointStart = -1;
          for (let i32 = 0; i32 < publicDer.length; i32++) {
            if (publicDer[i32] === 4) {
              pointStart = i32;
              break;
            }
          }
          const x = publicDer.slice(pointStart + 1, pointStart + 33);
          const y = publicDer.slice(pointStart + 33, pointStart + 65);
          const header = {
            alg: "ES256",
            typ: "dpop+jwt",
            jwk: {
              kty: "EC",
              crv: "P-256",
              x: x.toString("base64url"),
              y: y.toString("base64url")
            }
          };
          const payload3 = {
            jti: crypto.randomUUID(),
            htm: method,
            htu: endpoint,
            iat: Math.floor(Date.now() / 1e3)
          };
          const headerB64 = Buffer.from(JSON.stringify(header)).toString("base64url");
          const payloadB64 = Buffer.from(JSON.stringify(payload3)).toString("base64url");
          const message2 = `${headerB64}.${payloadB64}`;
          const asn1Signature = node_crypto.sign("sha256", Buffer.from(message2), privateKey);
          const rawSignature = this.derToRawSignature(asn1Signature);
          const signatureB64 = rawSignature.toString("base64url");
          return `${message2}.${signatureB64}`;
        } catch (error4) {
          throw new propertyProvider.CredentialsProviderError(`Failed to generate Dpop proof: ${error4 instanceof Error ? error4.message : String(error4)}`, { logger: this.logger, tryNextLink: false });
        }
      }
    };
    var fromLoginCredentials = /* @__PURE__ */ __name((init) => async ({ callerClientConfig } = {}) => {
      init?.logger?.debug?.("@aws-sdk/credential-providers - fromLoginCredentials");
      const profiles = await sharedIniFileLoader.parseKnownFiles(init || {});
      const profileName = sharedIniFileLoader.getProfileName({
        profile: init?.profile ?? callerClientConfig?.profile
      });
      const profile = profiles[profileName];
      if (!profile?.login_session) {
        throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} does not contain login_session.`, {
          tryNextLink: true,
          logger: init?.logger
        });
      }
      const fetcher = new LoginCredentialsFetcher(profile, init, callerClientConfig);
      const credentials = await fetcher.loadCredentials();
      return client.setCredentialFeature(credentials, "CREDENTIALS_LOGIN", "AD");
    }, "fromLoginCredentials");
    exports2.fromLoginCredentials = fromLoginCredentials;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/bdd.js
var import_util_endpoints79, q9, a31, b31, c31, d31, e31, f31, g31, h31, i31, j31, k31, l19, m19, n9, o9, p9, _data31, root31, r31, nodes31, bdd31;
var init_bdd31 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/bdd.js"() {
    import_util_endpoints79 = __toESM(require_dist_cjs20());
    q9 = "ref";
    a31 = -1;
    b31 = true;
    c31 = "isSet";
    d31 = "PartitionResult";
    e31 = "booleanEquals";
    f31 = "stringEquals";
    g31 = "getAttr";
    h31 = "us-east-1";
    i31 = "sigv4";
    j31 = "sts";
    k31 = "https://sts.{Region}.{PartitionResult#dnsSuffix}";
    l19 = { [q9]: "Endpoint" };
    m19 = { [q9]: "Region" };
    n9 = { [q9]: d31 };
    o9 = {};
    p9 = [m19];
    _data31 = {
      conditions: [
        [c31, [l19]],
        [c31, p9],
        ["aws.partition", p9, d31],
        [e31, [{ [q9]: "UseFIPS" }, b31]],
        [e31, [{ [q9]: "UseDualStack" }, b31]],
        [f31, [m19, "aws-global"]],
        [e31, [{ [q9]: "UseGlobalEndpoint" }, b31]],
        [f31, [m19, "eu-central-1"]],
        [e31, [{ fn: g31, argv: [n9, "supportsDualStack"] }, b31]],
        [e31, [{ fn: g31, argv: [n9, "supportsFIPS"] }, b31]],
        [f31, [m19, "ap-south-1"]],
        [f31, [m19, "eu-north-1"]],
        [f31, [m19, "eu-west-1"]],
        [f31, [m19, "eu-west-2"]],
        [f31, [m19, "eu-west-3"]],
        [f31, [m19, "sa-east-1"]],
        [f31, [m19, h31]],
        [f31, [m19, "us-east-2"]],
        [f31, [m19, "us-west-2"]],
        [f31, [m19, "us-west-1"]],
        [f31, [m19, "ca-central-1"]],
        [f31, [m19, "ap-southeast-1"]],
        [f31, [m19, "ap-northeast-1"]],
        [f31, [m19, "ap-southeast-2"]],
        [f31, [{ fn: g31, argv: [n9, "name"] }, "aws-us-gov"]]
      ],
      results: [
        [a31],
        ["https://sts.amazonaws.com", { authSchemes: [{ name: i31, signingName: j31, signingRegion: h31 }] }],
        [k31, { authSchemes: [{ name: i31, signingName: j31, signingRegion: "{Region}" }] }],
        [a31, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a31, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [l19, o9],
        ["https://sts-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", o9],
        [a31, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://sts.{Region}.amazonaws.com", o9],
        ["https://sts-fips.{Region}.{PartitionResult#dnsSuffix}", o9],
        [a31, "FIPS is enabled but this partition does not support FIPS"],
        ["https://sts.{Region}.{PartitionResult#dualStackDnsSuffix}", o9],
        [a31, "DualStack is enabled but this partition does not support DualStack"],
        [k31, o9],
        [a31, "Invalid Configuration: Missing Region"]
      ]
    };
    root31 = 2;
    r31 = 1e8;
    nodes31 = new Int32Array([
      -1,
      1,
      -1,
      0,
      30,
      3,
      1,
      4,
      r31 + 14,
      2,
      5,
      r31 + 14,
      3,
      25,
      6,
      4,
      24,
      7,
      5,
      r31 + 1,
      8,
      6,
      9,
      r31 + 13,
      7,
      r31 + 1,
      10,
      10,
      r31 + 1,
      11,
      11,
      r31 + 1,
      12,
      12,
      r31 + 1,
      13,
      13,
      r31 + 1,
      14,
      14,
      r31 + 1,
      15,
      15,
      r31 + 1,
      16,
      16,
      r31 + 1,
      17,
      17,
      r31 + 1,
      18,
      18,
      r31 + 1,
      19,
      19,
      r31 + 1,
      20,
      20,
      r31 + 1,
      21,
      21,
      r31 + 1,
      22,
      22,
      r31 + 1,
      23,
      23,
      r31 + 1,
      r31 + 2,
      8,
      r31 + 11,
      r31 + 12,
      4,
      28,
      26,
      9,
      27,
      r31 + 10,
      24,
      r31 + 8,
      r31 + 9,
      8,
      29,
      r31 + 7,
      9,
      r31 + 6,
      r31 + 7,
      3,
      r31 + 3,
      31,
      4,
      r31 + 4,
      r31 + 5
    ]);
    bdd31 = import_util_endpoints79.BinaryDecisionDiagram.from(nodes31, root31, _data31.conditions, _data31.results);
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/endpointResolver.js
var import_util_endpoints80, import_util_endpoints81, cache31, defaultEndpointResolver31;
var init_endpointResolver31 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/endpointResolver.js"() {
    import_util_endpoints80 = __toESM(require_dist_cjs21());
    import_util_endpoints81 = __toESM(require_dist_cjs20());
    init_bdd31();
    cache31 = new import_util_endpoints81.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS", "UseGlobalEndpoint"]
    });
    defaultEndpointResolver31 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache31.get(endpointParams, () => (0, import_util_endpoints81.decideEndpoint)(bdd31, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    import_util_endpoints81.customEndpointFunctions.aws = import_util_endpoints80.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthSchemeProvider.js
function createAwsAuthSigv4HttpAuthOption31(authParameters) {
  return {
    schemeId: "aws.auth#sigv4",
    signingProperties: {
      name: "sts",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createAwsAuthSigv4aHttpAuthOption9(authParameters) {
  return {
    schemeId: "aws.auth#sigv4a",
    signingProperties: {
      name: "sts",
      region: authParameters.region
    },
    propertiesExtractor: /* @__PURE__ */ __name((config2, context) => ({
      signingProperties: {
        config: config2,
        context
      }
    }), "propertiesExtractor")
  };
}
function createSmithyApiNoAuthHttpAuthOption31(authParameters) {
  return {
    schemeId: "smithy.api#noAuth"
  };
}
var import_signature_v4_multi_region17, import_middleware_endpoint69, import_util_middleware32, createEndpointRuleSetHttpAuthSchemeParametersProvider9, _defaultSTSHttpAuthSchemeParametersProvider9, defaultSTSHttpAuthSchemeParametersProvider9, createEndpointRuleSetHttpAuthSchemeProvider9, _defaultSTSHttpAuthSchemeProvider9, defaultSTSHttpAuthSchemeProvider9, resolveStsAuthConfig8, resolveHttpAuthSchemeConfig31;
var init_httpAuthSchemeProvider31 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthSchemeProvider.js"() {
    init_httpAuthSchemes12();
    import_signature_v4_multi_region17 = __toESM(require_dist_cjs55());
    import_middleware_endpoint69 = __toESM(require_dist_cjs31());
    import_util_middleware32 = __toESM(require_dist_cjs6());
    init_endpointResolver31();
    init_STSClient9();
    createEndpointRuleSetHttpAuthSchemeParametersProvider9 = /* @__PURE__ */ __name((defaultHttpAuthSchemeParametersProvider) => async (config2, context, input) => {
      if (!input) {
        throw new Error("Could not find `input` for `defaultEndpointRuleSetHttpAuthSchemeParametersProvider`");
      }
      const defaultParameters = await defaultHttpAuthSchemeParametersProvider(config2, context, input);
      const instructionsFn = (0, import_util_middleware32.getSmithyContext)(context)?.commandInstance?.constructor?.getEndpointParameterInstructions;
      if (!instructionsFn) {
        throw new Error(`getEndpointParameterInstructions() is not defined on '${context.commandName}'`);
      }
      const endpointParameters = await (0, import_middleware_endpoint69.resolveParams)(input, { getEndpointParameterInstructions: instructionsFn }, config2);
      return Object.assign(defaultParameters, endpointParameters);
    }, "createEndpointRuleSetHttpAuthSchemeParametersProvider");
    _defaultSTSHttpAuthSchemeParametersProvider9 = /* @__PURE__ */ __name(async (config2, context, input) => {
      return {
        operation: (0, import_util_middleware32.getSmithyContext)(context).operation,
        region: await (0, import_util_middleware32.normalizeProvider)(config2.region)() || (() => {
          throw new Error("expected `region` to be configured for `aws.auth#sigv4`");
        })()
      };
    }, "_defaultSTSHttpAuthSchemeParametersProvider");
    defaultSTSHttpAuthSchemeParametersProvider9 = createEndpointRuleSetHttpAuthSchemeParametersProvider9(_defaultSTSHttpAuthSchemeParametersProvider9);
    __name(createAwsAuthSigv4HttpAuthOption31, "createAwsAuthSigv4HttpAuthOption");
    __name(createAwsAuthSigv4aHttpAuthOption9, "createAwsAuthSigv4aHttpAuthOption");
    __name(createSmithyApiNoAuthHttpAuthOption31, "createSmithyApiNoAuthHttpAuthOption");
    createEndpointRuleSetHttpAuthSchemeProvider9 = /* @__PURE__ */ __name((defaultEndpointResolver32, defaultHttpAuthSchemeResolver, createHttpAuthOptionFunctions) => {
      const endpointRuleSetHttpAuthSchemeProvider = /* @__PURE__ */ __name((authParameters) => {
        const endpoint = defaultEndpointResolver32(authParameters);
        const authSchemes = endpoint.properties?.authSchemes;
        if (!authSchemes) {
          return defaultHttpAuthSchemeResolver(authParameters);
        }
        const options = [];
        for (const scheme of authSchemes) {
          const { name: resolvedName, properties = {}, ...rest } = scheme;
          const name = resolvedName.toLowerCase();
          if (resolvedName !== name) {
            console.warn(`HttpAuthScheme has been normalized with lowercasing: '${resolvedName}' to '${name}'`);
          }
          let schemeId;
          if (name === "sigv4a") {
            schemeId = "aws.auth#sigv4a";
            const sigv4Present = authSchemes.find((s) => {
              const name2 = s.name.toLowerCase();
              return name2 !== "sigv4a" && name2.startsWith("sigv4");
            });
            if (import_signature_v4_multi_region17.SignatureV4MultiRegion.sigv4aDependency() === "none" && sigv4Present) {
              continue;
            }
          } else if (name.startsWith("sigv4")) {
            schemeId = "aws.auth#sigv4";
          } else {
            throw new Error(`Unknown HttpAuthScheme found in '@smithy.rules#endpointRuleSet': '${name}'`);
          }
          const createOption = createHttpAuthOptionFunctions[schemeId];
          if (!createOption) {
            throw new Error(`Could not find HttpAuthOption create function for '${schemeId}'`);
          }
          const option = createOption(authParameters);
          option.schemeId = schemeId;
          option.signingProperties = { ...option.signingProperties || {}, ...rest, ...properties };
          options.push(option);
        }
        return options;
      }, "endpointRuleSetHttpAuthSchemeProvider");
      return endpointRuleSetHttpAuthSchemeProvider;
    }, "createEndpointRuleSetHttpAuthSchemeProvider");
    _defaultSTSHttpAuthSchemeProvider9 = /* @__PURE__ */ __name((authParameters) => {
      const options = [];
      switch (authParameters.operation) {
        case "AssumeRoleWithWebIdentity": {
          options.push(createSmithyApiNoAuthHttpAuthOption31(authParameters));
          options.push(createAwsAuthSigv4aHttpAuthOption9(authParameters));
          break;
        }
        default: {
          options.push(createAwsAuthSigv4HttpAuthOption31(authParameters));
          options.push(createAwsAuthSigv4aHttpAuthOption9(authParameters));
        }
      }
      return options;
    }, "_defaultSTSHttpAuthSchemeProvider");
    defaultSTSHttpAuthSchemeProvider9 = createEndpointRuleSetHttpAuthSchemeProvider9(defaultEndpointResolver31, _defaultSTSHttpAuthSchemeProvider9, {
      "aws.auth#sigv4": createAwsAuthSigv4HttpAuthOption31,
      "aws.auth#sigv4a": createAwsAuthSigv4aHttpAuthOption9,
      "smithy.api#noAuth": createSmithyApiNoAuthHttpAuthOption31
    });
    resolveStsAuthConfig8 = /* @__PURE__ */ __name((input) => Object.assign(input, {
      stsClientCtor: STSClient10
    }), "resolveStsAuthConfig");
    resolveHttpAuthSchemeConfig31 = /* @__PURE__ */ __name((config2) => {
      const config_0 = resolveStsAuthConfig8(config2);
      const config_1 = resolveAwsSdkSigV4Config10(config_0);
      const config_2 = resolveAwsSdkSigV4AConfig10(config_1);
      return Object.assign(config_2, {
        authSchemePreference: (0, import_util_middleware32.normalizeProvider)(config2.authSchemePreference ?? [])
      });
    }, "resolveHttpAuthSchemeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/EndpointParameters.js
var resolveClientEndpointParameters31, commonParams31;
var init_EndpointParameters31 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/endpoint/EndpointParameters.js"() {
    resolveClientEndpointParameters31 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        useGlobalEndpoint: options.useGlobalEndpoint ?? false,
        defaultSigningName: "sts"
      });
    }, "resolveClientEndpointParameters");
    commonParams31 = {
      UseGlobalEndpoint: { type: "builtInParams", name: "useGlobalEndpoint" },
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/STSServiceException.js
var import_smithy_client253, STSServiceException9;
var init_STSServiceException9 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/STSServiceException.js"() {
    import_smithy_client253 = __toESM(require_dist_cjs34());
    STSServiceException9 = class _STSServiceException extends import_smithy_client253.ServiceException {
      static {
        __name(this, "STSServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _STSServiceException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/errors.js
var ExpiredTokenException12, MalformedPolicyDocumentException9, PackedPolicyTooLargeException9, RegionDisabledException9, IDPRejectedClaimException9, InvalidIdentityTokenException9, IDPCommunicationErrorException9;
var init_errors31 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/errors.js"() {
    init_STSServiceException9();
    ExpiredTokenException12 = class _ExpiredTokenException extends STSServiceException9 {
      static {
        __name(this, "ExpiredTokenException");
      }
      name = "ExpiredTokenException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ExpiredTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ExpiredTokenException.prototype);
      }
    };
    MalformedPolicyDocumentException9 = class _MalformedPolicyDocumentException extends STSServiceException9 {
      static {
        __name(this, "MalformedPolicyDocumentException");
      }
      name = "MalformedPolicyDocumentException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "MalformedPolicyDocumentException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _MalformedPolicyDocumentException.prototype);
      }
    };
    PackedPolicyTooLargeException9 = class _PackedPolicyTooLargeException extends STSServiceException9 {
      static {
        __name(this, "PackedPolicyTooLargeException");
      }
      name = "PackedPolicyTooLargeException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "PackedPolicyTooLargeException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _PackedPolicyTooLargeException.prototype);
      }
    };
    RegionDisabledException9 = class _RegionDisabledException extends STSServiceException9 {
      static {
        __name(this, "RegionDisabledException");
      }
      name = "RegionDisabledException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "RegionDisabledException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _RegionDisabledException.prototype);
      }
    };
    IDPRejectedClaimException9 = class _IDPRejectedClaimException extends STSServiceException9 {
      static {
        __name(this, "IDPRejectedClaimException");
      }
      name = "IDPRejectedClaimException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "IDPRejectedClaimException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _IDPRejectedClaimException.prototype);
      }
    };
    InvalidIdentityTokenException9 = class _InvalidIdentityTokenException extends STSServiceException9 {
      static {
        __name(this, "InvalidIdentityTokenException");
      }
      name = "InvalidIdentityTokenException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidIdentityTokenException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidIdentityTokenException.prototype);
      }
    };
    IDPCommunicationErrorException9 = class _IDPCommunicationErrorException extends STSServiceException9 {
      static {
        __name(this, "IDPCommunicationErrorException");
      }
      name = "IDPCommunicationErrorException";
      $fault = "client";
      $retryable = {};
      constructor(opts) {
        super({
          name: "IDPCommunicationErrorException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _IDPCommunicationErrorException.prototype);
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/schemas/schemas_0.js
var _A9, _AKI10, _AR9, _ARI9, _ARR9, _ARRs9, _ARU9, _ARWWI9, _ARWWIR9, _ARWWIRs9, _Au9, _C10, _CA9, _DS9, _E10, _EI9, _ETE12, _IDPCEE9, _IDPRCE9, _IITE9, _K9, _MPDE9, _P9, _PA9, _PAr9, _PC9, _PCLT9, _PCr9, _PDT9, _PI9, _PPS9, _PPTLE9, _Pr9, _RA9, _RDE9, _RSN9, _SAK9, _SFWIT9, _SI9, _SN9, _ST10, _T9, _TC9, _TTK9, _Ta9, _V9, _WIT9, _a9, _aKST9, _aQE9, _c31, _cTT9, _e31, _hE31, _m28, _pDLT9, _s31, _tLT9, n031, _s_registry31, STSServiceException$9, n0_registry31, ExpiredTokenException$12, IDPCommunicationErrorException$9, IDPRejectedClaimException$9, InvalidIdentityTokenException$9, MalformedPolicyDocumentException$9, PackedPolicyTooLargeException$9, RegionDisabledException$9, errorTypeRegistries31, accessKeySecretType9, clientTokenType9, AssumedRoleUser$9, AssumeRoleRequest$9, AssumeRoleResponse$9, AssumeRoleWithWebIdentityRequest$9, AssumeRoleWithWebIdentityResponse$9, Credentials$10, PolicyDescriptorType$9, ProvidedContext$9, Tag$9, policyDescriptorListType9, ProvidedContextsListType9, tagKeyListType9, tagListType9, AssumeRole$9, AssumeRoleWithWebIdentity$9;
var init_schemas_031 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/schemas/schemas_0.js"() {
    init_schema4();
    init_errors31();
    init_STSServiceException9();
    _A9 = "Arn";
    _AKI10 = "AccessKeyId";
    _AR9 = "AssumeRole";
    _ARI9 = "AssumedRoleId";
    _ARR9 = "AssumeRoleRequest";
    _ARRs9 = "AssumeRoleResponse";
    _ARU9 = "AssumedRoleUser";
    _ARWWI9 = "AssumeRoleWithWebIdentity";
    _ARWWIR9 = "AssumeRoleWithWebIdentityRequest";
    _ARWWIRs9 = "AssumeRoleWithWebIdentityResponse";
    _Au9 = "Audience";
    _C10 = "Credentials";
    _CA9 = "ContextAssertion";
    _DS9 = "DurationSeconds";
    _E10 = "Expiration";
    _EI9 = "ExternalId";
    _ETE12 = "ExpiredTokenException";
    _IDPCEE9 = "IDPCommunicationErrorException";
    _IDPRCE9 = "IDPRejectedClaimException";
    _IITE9 = "InvalidIdentityTokenException";
    _K9 = "Key";
    _MPDE9 = "MalformedPolicyDocumentException";
    _P9 = "Policy";
    _PA9 = "PolicyArns";
    _PAr9 = "ProviderArn";
    _PC9 = "ProvidedContexts";
    _PCLT9 = "ProvidedContextsListType";
    _PCr9 = "ProvidedContext";
    _PDT9 = "PolicyDescriptorType";
    _PI9 = "ProviderId";
    _PPS9 = "PackedPolicySize";
    _PPTLE9 = "PackedPolicyTooLargeException";
    _Pr9 = "Provider";
    _RA9 = "RoleArn";
    _RDE9 = "RegionDisabledException";
    _RSN9 = "RoleSessionName";
    _SAK9 = "SecretAccessKey";
    _SFWIT9 = "SubjectFromWebIdentityToken";
    _SI9 = "SourceIdentity";
    _SN9 = "SerialNumber";
    _ST10 = "SessionToken";
    _T9 = "Tags";
    _TC9 = "TokenCode";
    _TTK9 = "TransitiveTagKeys";
    _Ta9 = "Tag";
    _V9 = "Value";
    _WIT9 = "WebIdentityToken";
    _a9 = "arn";
    _aKST9 = "accessKeySecretType";
    _aQE9 = "awsQueryError";
    _c31 = "client";
    _cTT9 = "clientTokenType";
    _e31 = "error";
    _hE31 = "httpError";
    _m28 = "message";
    _pDLT9 = "policyDescriptorListType";
    _s31 = "smithy.ts.sdk.synthetic.com.amazonaws.sts";
    _tLT9 = "tagListType";
    n031 = "com.amazonaws.sts";
    _s_registry31 = TypeRegistry.for(_s31);
    STSServiceException$9 = [-3, _s31, "STSServiceException", 0, [], []];
    _s_registry31.registerError(STSServiceException$9, STSServiceException9);
    n0_registry31 = TypeRegistry.for(n031);
    ExpiredTokenException$12 = [
      -3,
      n031,
      _ETE12,
      { [_aQE9]: [`ExpiredTokenException`, 400], [_e31]: _c31, [_hE31]: 400 },
      [_m28],
      [0]
    ];
    n0_registry31.registerError(ExpiredTokenException$12, ExpiredTokenException12);
    IDPCommunicationErrorException$9 = [
      -3,
      n031,
      _IDPCEE9,
      { [_aQE9]: [`IDPCommunicationError`, 400], [_e31]: _c31, [_hE31]: 400 },
      [_m28],
      [0]
    ];
    n0_registry31.registerError(IDPCommunicationErrorException$9, IDPCommunicationErrorException9);
    IDPRejectedClaimException$9 = [
      -3,
      n031,
      _IDPRCE9,
      { [_aQE9]: [`IDPRejectedClaim`, 403], [_e31]: _c31, [_hE31]: 403 },
      [_m28],
      [0]
    ];
    n0_registry31.registerError(IDPRejectedClaimException$9, IDPRejectedClaimException9);
    InvalidIdentityTokenException$9 = [
      -3,
      n031,
      _IITE9,
      { [_aQE9]: [`InvalidIdentityToken`, 400], [_e31]: _c31, [_hE31]: 400 },
      [_m28],
      [0]
    ];
    n0_registry31.registerError(InvalidIdentityTokenException$9, InvalidIdentityTokenException9);
    MalformedPolicyDocumentException$9 = [
      -3,
      n031,
      _MPDE9,
      { [_aQE9]: [`MalformedPolicyDocument`, 400], [_e31]: _c31, [_hE31]: 400 },
      [_m28],
      [0]
    ];
    n0_registry31.registerError(MalformedPolicyDocumentException$9, MalformedPolicyDocumentException9);
    PackedPolicyTooLargeException$9 = [
      -3,
      n031,
      _PPTLE9,
      { [_aQE9]: [`PackedPolicyTooLarge`, 400], [_e31]: _c31, [_hE31]: 400 },
      [_m28],
      [0]
    ];
    n0_registry31.registerError(PackedPolicyTooLargeException$9, PackedPolicyTooLargeException9);
    RegionDisabledException$9 = [
      -3,
      n031,
      _RDE9,
      { [_aQE9]: [`RegionDisabledException`, 403], [_e31]: _c31, [_hE31]: 403 },
      [_m28],
      [0]
    ];
    n0_registry31.registerError(RegionDisabledException$9, RegionDisabledException9);
    errorTypeRegistries31 = [_s_registry31, n0_registry31];
    accessKeySecretType9 = [0, n031, _aKST9, 8, 0];
    clientTokenType9 = [0, n031, _cTT9, 8, 0];
    AssumedRoleUser$9 = [3, n031, _ARU9, 0, [_ARI9, _A9], [0, 0], 2];
    AssumeRoleRequest$9 = [
      3,
      n031,
      _ARR9,
      0,
      [_RA9, _RSN9, _PA9, _P9, _DS9, _T9, _TTK9, _EI9, _SN9, _TC9, _SI9, _PC9],
      [0, 0, () => policyDescriptorListType9, 0, 1, () => tagListType9, 64 | 0, 0, 0, 0, 0, () => ProvidedContextsListType9],
      2
    ];
    AssumeRoleResponse$9 = [
      3,
      n031,
      _ARRs9,
      0,
      [_C10, _ARU9, _PPS9, _SI9],
      [[() => Credentials$10, 0], () => AssumedRoleUser$9, 1, 0]
    ];
    AssumeRoleWithWebIdentityRequest$9 = [
      3,
      n031,
      _ARWWIR9,
      0,
      [_RA9, _RSN9, _WIT9, _PI9, _PA9, _P9, _DS9],
      [0, 0, [() => clientTokenType9, 0], 0, () => policyDescriptorListType9, 0, 1],
      3
    ];
    AssumeRoleWithWebIdentityResponse$9 = [
      3,
      n031,
      _ARWWIRs9,
      0,
      [_C10, _SFWIT9, _ARU9, _PPS9, _Pr9, _Au9, _SI9],
      [[() => Credentials$10, 0], 0, () => AssumedRoleUser$9, 1, 0, 0, 0]
    ];
    Credentials$10 = [
      3,
      n031,
      _C10,
      0,
      [_AKI10, _SAK9, _ST10, _E10],
      [0, [() => accessKeySecretType9, 0], 0, 4],
      4
    ];
    PolicyDescriptorType$9 = [3, n031, _PDT9, 0, [_a9], [0]];
    ProvidedContext$9 = [3, n031, _PCr9, 0, [_PAr9, _CA9], [0, 0]];
    Tag$9 = [3, n031, _Ta9, 0, [_K9, _V9], [0, 0], 2];
    policyDescriptorListType9 = [1, n031, _pDLT9, 0, () => PolicyDescriptorType$9];
    ProvidedContextsListType9 = [1, n031, _PCLT9, 0, () => ProvidedContext$9];
    tagKeyListType9 = 64 | 0;
    tagListType9 = [1, n031, _tLT9, 0, () => Tag$9];
    AssumeRole$9 = [9, n031, _AR9, 0, () => AssumeRoleRequest$9, () => AssumeRoleResponse$9];
    AssumeRoleWithWebIdentity$9 = [
      9,
      n031,
      _ARWWI9,
      0,
      () => AssumeRoleWithWebIdentityRequest$9,
      () => AssumeRoleWithWebIdentityResponse$9
    ];
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.shared.js
var import_signature_v4_multi_region18, import_smithy_client254, import_url_parser28, import_util_base6467, import_util_utf851, getRuntimeConfig61;
var init_runtimeConfig_shared31 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.shared.js"() {
    init_httpAuthSchemes12();
    init_protocols18();
    import_signature_v4_multi_region18 = __toESM(require_dist_cjs55());
    init_dist_es();
    import_smithy_client254 = __toESM(require_dist_cjs34());
    import_url_parser28 = __toESM(require_dist_cjs18());
    import_util_base6467 = __toESM(require_dist_cjs10());
    import_util_utf851 = __toESM(require_dist_cjs9());
    init_httpAuthSchemeProvider31();
    init_endpointResolver31();
    init_schemas_031();
    getRuntimeConfig61 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2011-06-15",
        base64Decoder: config2?.base64Decoder ?? import_util_base6467.fromBase64,
        base64Encoder: config2?.base64Encoder ?? import_util_base6467.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? defaultEndpointResolver31,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? defaultSTSHttpAuthSchemeProvider9,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new AwsSdkSigV4Signer10()
          },
          {
            schemeId: "aws.auth#sigv4a",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4a"), "identityProvider"),
            signer: new AwsSdkSigV4ASigner10()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        logger: config2?.logger ?? new import_smithy_client254.NoOpLogger(),
        protocol: config2?.protocol ?? AwsQueryProtocol10,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.sts",
          errorTypeRegistries: errorTypeRegistries31,
          xmlNamespace: "https://sts.amazonaws.com/doc/2011-06-15/",
          version: "2011-06-15",
          serviceTarget: "AWSSecurityTokenServiceV20110615"
        },
        serviceId: config2?.serviceId ?? "STS",
        signerConstructor: config2?.signerConstructor ?? import_signature_v4_multi_region18.SignatureV4MultiRegion,
        urlParser: config2?.urlParser ?? import_url_parser28.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? import_util_utf851.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? import_util_utf851.toUtf8
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.js
var import_util_user_agent_node27, import_config_resolver54, import_hash_node29, import_middleware_retry53, import_node_config_provider28, import_node_http_handler31, import_smithy_client255, import_util_body_length_node27, import_util_defaults_mode_node27, import_util_retry38, getRuntimeConfig62;
var init_runtimeConfig31 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeConfig.js"() {
    init_package10();
    init_client19();
    init_httpAuthSchemes12();
    import_util_user_agent_node27 = __toESM(require_dist_cjs202());
    import_config_resolver54 = __toESM(require_dist_cjs25());
    init_dist_es();
    import_hash_node29 = __toESM(require_dist_cjs44());
    import_middleware_retry53 = __toESM(require_dist_cjs198());
    import_node_config_provider28 = __toESM(require_dist_cjs29());
    import_node_http_handler31 = __toESM(require_dist_cjs13());
    import_smithy_client255 = __toESM(require_dist_cjs34());
    import_util_body_length_node27 = __toESM(require_dist_cjs45());
    import_util_defaults_mode_node27 = __toESM(require_dist_cjs46());
    import_util_retry38 = __toESM(require_dist_cjs22());
    init_runtimeConfig_shared31();
    getRuntimeConfig62 = /* @__PURE__ */ __name((config2) => {
      (0, import_smithy_client255.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, import_util_defaults_mode_node27.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(import_smithy_client255.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = getRuntimeConfig61(config2);
      emitWarningIfUnsupportedVersion38(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, import_node_config_provider28.loadConfig)(NODE_AUTH_SCHEME_PREFERENCE_OPTIONS10, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? import_util_body_length_node27.calculateBodyLength,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, import_util_user_agent_node27.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_default10.version }),
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4") || (async (idProps) => await config2.credentialDefaultProvider(idProps?.__config || {})()), "identityProvider"),
            signer: new AwsSdkSigV4Signer10()
          },
          {
            schemeId: "aws.auth#sigv4a",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4a"), "identityProvider"),
            signer: new AwsSdkSigV4ASigner10()
          },
          {
            schemeId: "smithy.api#noAuth",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("smithy.api#noAuth") || (async () => ({})), "identityProvider"),
            signer: new NoAuthSigner()
          }
        ],
        maxAttempts: config2?.maxAttempts ?? (0, import_node_config_provider28.loadConfig)(import_middleware_retry53.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, import_node_config_provider28.loadConfig)(import_config_resolver54.NODE_REGION_CONFIG_OPTIONS, { ...import_config_resolver54.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: import_node_http_handler31.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, import_node_config_provider28.loadConfig)({
          ...import_middleware_retry53.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || import_util_retry38.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? import_hash_node29.Hash.bind(null, "sha256"),
        sigv4aSigningRegionSet: config2?.sigv4aSigningRegionSet ?? (0, import_node_config_provider28.loadConfig)(NODE_SIGV4A_CONFIG_OPTIONS10, loaderConfig),
        streamCollector: config2?.streamCollector ?? import_node_http_handler31.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, import_node_config_provider28.loadConfig)(import_config_resolver54.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, import_node_config_provider28.loadConfig)(import_config_resolver54.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, import_node_config_provider28.loadConfig)(import_util_user_agent_node27.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthExtensionConfiguration.js
var getHttpAuthExtensionConfiguration31, resolveHttpAuthRuntimeConfig31;
var init_httpAuthExtensionConfiguration31 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/auth/httpAuthExtensionConfiguration.js"() {
    getHttpAuthExtensionConfiguration31 = /* @__PURE__ */ __name((runtimeConfig) => {
      const _httpAuthSchemes = runtimeConfig.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig.httpAuthSchemeProvider;
      let _credentials = runtimeConfig.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    resolveHttpAuthRuntimeConfig31 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeExtensions.js
var import_region_config_resolver34, import_protocol_http62, import_smithy_client256, resolveRuntimeExtensions31;
var init_runtimeExtensions31 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/runtimeExtensions.js"() {
    import_region_config_resolver34 = __toESM(require_dist_cjs48());
    import_protocol_http62 = __toESM(require_dist_cjs2());
    import_smithy_client256 = __toESM(require_dist_cjs34());
    init_httpAuthExtensionConfiguration31();
    resolveRuntimeExtensions31 = /* @__PURE__ */ __name((runtimeConfig, extensions) => {
      const extensionConfiguration = Object.assign((0, import_region_config_resolver34.getAwsRegionExtensionConfiguration)(runtimeConfig), (0, import_smithy_client256.getDefaultExtensionConfiguration)(runtimeConfig), (0, import_protocol_http62.getHttpHandlerExtensionConfiguration)(runtimeConfig), getHttpAuthExtensionConfiguration31(runtimeConfig));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig, (0, import_region_config_resolver34.resolveAwsRegionExtensionConfiguration)(extensionConfiguration), (0, import_smithy_client256.resolveDefaultRuntimeConfig)(extensionConfiguration), (0, import_protocol_http62.resolveHttpHandlerRuntimeConfig)(extensionConfiguration), resolveHttpAuthRuntimeConfig31(extensionConfiguration));
    }, "resolveRuntimeExtensions");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STSClient.js
var import_middleware_host_header27, import_middleware_logger27, import_middleware_recursion_detection27, import_middleware_user_agent27, import_config_resolver55, import_middleware_content_length27, import_middleware_endpoint70, import_middleware_retry54, import_smithy_client257, STSClient10;
var init_STSClient9 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STSClient.js"() {
    import_middleware_host_header27 = __toESM(require_dist_cjs3());
    import_middleware_logger27 = __toESM(require_dist_cjs4());
    import_middleware_recursion_detection27 = __toESM(require_dist_cjs5());
    import_middleware_user_agent27 = __toESM(require_dist_cjs197());
    import_config_resolver55 = __toESM(require_dist_cjs25());
    init_dist_es();
    init_schema4();
    import_middleware_content_length27 = __toESM(require_dist_cjs26());
    import_middleware_endpoint70 = __toESM(require_dist_cjs31());
    import_middleware_retry54 = __toESM(require_dist_cjs198());
    import_smithy_client257 = __toESM(require_dist_cjs34());
    init_httpAuthSchemeProvider31();
    init_EndpointParameters31();
    init_runtimeConfig31();
    init_runtimeExtensions31();
    STSClient10 = class extends import_smithy_client257.Client {
      static {
        __name(this, "STSClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = getRuntimeConfig62(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters31(_config_0);
        const _config_2 = (0, import_middleware_user_agent27.resolveUserAgentConfig)(_config_1);
        const _config_3 = (0, import_middleware_retry54.resolveRetryConfig)(_config_2);
        const _config_4 = (0, import_config_resolver55.resolveRegionConfig)(_config_3);
        const _config_5 = (0, import_middleware_host_header27.resolveHostHeaderConfig)(_config_4);
        const _config_6 = (0, import_middleware_endpoint70.resolveEndpointConfig)(_config_5);
        const _config_7 = resolveHttpAuthSchemeConfig31(_config_6);
        const _config_8 = resolveRuntimeExtensions31(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(getSchemaSerdePlugin(this.config));
        this.middlewareStack.use((0, import_middleware_user_agent27.getUserAgentPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_retry54.getRetryPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_content_length27.getContentLengthPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_host_header27.getHostHeaderPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_logger27.getLoggerPlugin)(this.config));
        this.middlewareStack.use((0, import_middleware_recursion_detection27.getRecursionDetectionPlugin)(this.config));
        this.middlewareStack.use(getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: defaultSTSHttpAuthSchemeParametersProvider9,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials,
            "aws.auth#sigv4a": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleCommand.js
var import_middleware_endpoint71, import_smithy_client258, AssumeRoleCommand9;
var init_AssumeRoleCommand9 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleCommand.js"() {
    import_middleware_endpoint71 = __toESM(require_dist_cjs31());
    import_smithy_client258 = __toESM(require_dist_cjs34());
    init_EndpointParameters31();
    init_schemas_031();
    AssumeRoleCommand9 = class extends import_smithy_client258.Command.classBuilder().ep(commonParams31).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint71.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "AssumeRole", {}).n("STSClient", "AssumeRoleCommand").sc(AssumeRole$9).build() {
      static {
        __name(this, "AssumeRoleCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleWithWebIdentityCommand.js
var import_middleware_endpoint72, import_smithy_client259, AssumeRoleWithWebIdentityCommand9;
var init_AssumeRoleWithWebIdentityCommand9 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/AssumeRoleWithWebIdentityCommand.js"() {
    import_middleware_endpoint72 = __toESM(require_dist_cjs31());
    import_smithy_client259 = __toESM(require_dist_cjs34());
    init_EndpointParameters31();
    init_schemas_031();
    AssumeRoleWithWebIdentityCommand9 = class extends import_smithy_client259.Command.classBuilder().ep(commonParams31).m(function(Command3, cs, config2, o10) {
      return [(0, import_middleware_endpoint72.getEndpointPlugin)(config2, Command3.getEndpointParameterInstructions())];
    }).s("AWSSecurityTokenServiceV20110615", "AssumeRoleWithWebIdentity", {}).n("STSClient", "AssumeRoleWithWebIdentityCommand").sc(AssumeRoleWithWebIdentity$9).build() {
      static {
        __name(this, "AssumeRoleWithWebIdentityCommand");
      }
    };
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STS.js
var import_smithy_client260, commands31, STS9;
var init_STS9 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/STS.js"() {
    import_smithy_client260 = __toESM(require_dist_cjs34());
    init_AssumeRoleCommand9();
    init_AssumeRoleWithWebIdentityCommand9();
    init_STSClient9();
    commands31 = {
      AssumeRoleCommand: AssumeRoleCommand9,
      AssumeRoleWithWebIdentityCommand: AssumeRoleWithWebIdentityCommand9
    };
    STS9 = class extends STSClient10 {
      static {
        __name(this, "STS");
      }
    };
    (0, import_smithy_client260.createAggregatedClient)(commands31, STS9);
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/index.js
var init_commands32 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/commands/index.js"() {
    init_AssumeRoleCommand9();
    init_AssumeRoleWithWebIdentityCommand9();
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/models_0.js
var init_models_031 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/models/models_0.js"() {
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultStsRoleAssumers.js
var import_region_config_resolver35, getAccountIdFromAssumedRoleUser9, resolveRegion9, getDefaultRoleAssumer17, getDefaultRoleAssumerWithWebIdentity17, isH29;
var init_defaultStsRoleAssumers9 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultStsRoleAssumers.js"() {
    init_client19();
    import_region_config_resolver35 = __toESM(require_dist_cjs48());
    init_AssumeRoleCommand9();
    init_AssumeRoleWithWebIdentityCommand9();
    getAccountIdFromAssumedRoleUser9 = /* @__PURE__ */ __name((assumedRoleUser) => {
      if (typeof assumedRoleUser?.Arn === "string") {
        const arnComponents = assumedRoleUser.Arn.split(":");
        if (arnComponents.length > 4 && arnComponents[4] !== "") {
          return arnComponents[4];
        }
      }
      return void 0;
    }, "getAccountIdFromAssumedRoleUser");
    resolveRegion9 = /* @__PURE__ */ __name(async (_region, _parentRegion, credentialProviderLogger, loaderConfig = {}) => {
      const region = typeof _region === "function" ? await _region() : _region;
      const parentRegion = typeof _parentRegion === "function" ? await _parentRegion() : _parentRegion;
      let stsDefaultRegion = "";
      const resolvedRegion = region ?? parentRegion ?? (stsDefaultRegion = await (0, import_region_config_resolver35.stsRegionDefaultResolver)(loaderConfig)());
      credentialProviderLogger?.debug?.("@aws-sdk/client-sts::resolveRegion", "accepting first of:", `${region} (credential provider clientConfig)`, `${parentRegion} (contextual client)`, `${stsDefaultRegion} (STS default: AWS_REGION, profile region, or us-east-1)`);
      return resolvedRegion;
    }, "resolveRegion");
    getDefaultRoleAssumer17 = /* @__PURE__ */ __name((stsOptions, STSClient12) => {
      let stsClient;
      let closureSourceCreds;
      return async (sourceCreds, params) => {
        closureSourceCreds = sourceCreds;
        if (!stsClient) {
          const { logger: logger5 = stsOptions?.parentClientConfig?.logger, profile = stsOptions?.parentClientConfig?.profile, region, requestHandler = stsOptions?.parentClientConfig?.requestHandler, credentialProviderLogger, userAgentAppId = stsOptions?.parentClientConfig?.userAgentAppId } = stsOptions;
          const resolvedRegion = await resolveRegion9(region, stsOptions?.parentClientConfig?.region, credentialProviderLogger, {
            logger: logger5,
            profile
          });
          const isCompatibleRequestHandler = !isH29(requestHandler);
          stsClient = new STSClient12({
            ...stsOptions,
            userAgentAppId,
            profile,
            credentialDefaultProvider: /* @__PURE__ */ __name(() => async () => closureSourceCreds, "credentialDefaultProvider"),
            region: resolvedRegion,
            requestHandler: isCompatibleRequestHandler ? requestHandler : void 0,
            logger: logger5
          });
        }
        const { Credentials, AssumedRoleUser } = await stsClient.send(new AssumeRoleCommand9(params));
        if (!Credentials || !Credentials.AccessKeyId || !Credentials.SecretAccessKey) {
          throw new Error(`Invalid response from STS.assumeRole call with role ${params.RoleArn}`);
        }
        const accountId = getAccountIdFromAssumedRoleUser9(AssumedRoleUser);
        const credentials = {
          accessKeyId: Credentials.AccessKeyId,
          secretAccessKey: Credentials.SecretAccessKey,
          sessionToken: Credentials.SessionToken,
          expiration: Credentials.Expiration,
          ...Credentials.CredentialScope && { credentialScope: Credentials.CredentialScope },
          ...accountId && { accountId }
        };
        setCredentialFeature12(credentials, "CREDENTIALS_STS_ASSUME_ROLE", "i");
        return credentials;
      };
    }, "getDefaultRoleAssumer");
    getDefaultRoleAssumerWithWebIdentity17 = /* @__PURE__ */ __name((stsOptions, STSClient12) => {
      let stsClient;
      return async (params) => {
        if (!stsClient) {
          const { logger: logger5 = stsOptions?.parentClientConfig?.logger, profile = stsOptions?.parentClientConfig?.profile, region, requestHandler = stsOptions?.parentClientConfig?.requestHandler, credentialProviderLogger, userAgentAppId = stsOptions?.parentClientConfig?.userAgentAppId } = stsOptions;
          const resolvedRegion = await resolveRegion9(region, stsOptions?.parentClientConfig?.region, credentialProviderLogger, {
            logger: logger5,
            profile
          });
          const isCompatibleRequestHandler = !isH29(requestHandler);
          stsClient = new STSClient12({
            ...stsOptions,
            userAgentAppId,
            profile,
            region: resolvedRegion,
            requestHandler: isCompatibleRequestHandler ? requestHandler : void 0,
            logger: logger5
          });
        }
        const { Credentials, AssumedRoleUser } = await stsClient.send(new AssumeRoleWithWebIdentityCommand9(params));
        if (!Credentials || !Credentials.AccessKeyId || !Credentials.SecretAccessKey) {
          throw new Error(`Invalid response from STS.assumeRoleWithWebIdentity call with role ${params.RoleArn}`);
        }
        const accountId = getAccountIdFromAssumedRoleUser9(AssumedRoleUser);
        const credentials = {
          accessKeyId: Credentials.AccessKeyId,
          secretAccessKey: Credentials.SecretAccessKey,
          sessionToken: Credentials.SessionToken,
          expiration: Credentials.Expiration,
          ...Credentials.CredentialScope && { credentialScope: Credentials.CredentialScope },
          ...accountId && { accountId }
        };
        if (accountId) {
          setCredentialFeature12(credentials, "RESOLVED_ACCOUNT_ID", "T");
        }
        setCredentialFeature12(credentials, "CREDENTIALS_STS_ASSUME_ROLE_WEB_ID", "k");
        return credentials;
      };
    }, "getDefaultRoleAssumerWithWebIdentity");
    isH29 = /* @__PURE__ */ __name((requestHandler) => {
      return requestHandler?.metadata?.handlerProtocol === "h2";
    }, "isH2");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultRoleAssumers.js
var getCustomizableStsClientCtor9, getDefaultRoleAssumer18, getDefaultRoleAssumerWithWebIdentity18, decorateDefaultCredentialProvider9;
var init_defaultRoleAssumers9 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/defaultRoleAssumers.js"() {
    init_defaultStsRoleAssumers9();
    init_STSClient9();
    getCustomizableStsClientCtor9 = /* @__PURE__ */ __name((baseCtor, customizations) => {
      if (!customizations)
        return baseCtor;
      else
        return class CustomizableSTSClient extends baseCtor {
          static {
            __name(this, "CustomizableSTSClient");
          }
          constructor(config2) {
            super(config2);
            for (const customization of customizations) {
              this.middlewareStack.use(customization);
            }
          }
        };
    }, "getCustomizableStsClientCtor");
    getDefaultRoleAssumer18 = /* @__PURE__ */ __name((stsOptions = {}, stsPlugins) => getDefaultRoleAssumer17(stsOptions, getCustomizableStsClientCtor9(STSClient10, stsPlugins)), "getDefaultRoleAssumer");
    getDefaultRoleAssumerWithWebIdentity18 = /* @__PURE__ */ __name((stsOptions = {}, stsPlugins) => getDefaultRoleAssumerWithWebIdentity17(stsOptions, getCustomizableStsClientCtor9(STSClient10, stsPlugins)), "getDefaultRoleAssumerWithWebIdentity");
    decorateDefaultCredentialProvider9 = /* @__PURE__ */ __name((provider) => (input) => provider({
      roleAssumer: getDefaultRoleAssumer18(input),
      roleAssumerWithWebIdentity: getDefaultRoleAssumerWithWebIdentity18(input),
      ...input
    }), "decorateDefaultCredentialProvider");
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/index.js
var sts_exports9 = {};
__export(sts_exports9, {
  AssumeRole$: () => AssumeRole$9,
  AssumeRoleCommand: () => AssumeRoleCommand9,
  AssumeRoleRequest$: () => AssumeRoleRequest$9,
  AssumeRoleResponse$: () => AssumeRoleResponse$9,
  AssumeRoleWithWebIdentity$: () => AssumeRoleWithWebIdentity$9,
  AssumeRoleWithWebIdentityCommand: () => AssumeRoleWithWebIdentityCommand9,
  AssumeRoleWithWebIdentityRequest$: () => AssumeRoleWithWebIdentityRequest$9,
  AssumeRoleWithWebIdentityResponse$: () => AssumeRoleWithWebIdentityResponse$9,
  AssumedRoleUser$: () => AssumedRoleUser$9,
  Credentials$: () => Credentials$10,
  ExpiredTokenException: () => ExpiredTokenException12,
  ExpiredTokenException$: () => ExpiredTokenException$12,
  IDPCommunicationErrorException: () => IDPCommunicationErrorException9,
  IDPCommunicationErrorException$: () => IDPCommunicationErrorException$9,
  IDPRejectedClaimException: () => IDPRejectedClaimException9,
  IDPRejectedClaimException$: () => IDPRejectedClaimException$9,
  InvalidIdentityTokenException: () => InvalidIdentityTokenException9,
  InvalidIdentityTokenException$: () => InvalidIdentityTokenException$9,
  MalformedPolicyDocumentException: () => MalformedPolicyDocumentException9,
  MalformedPolicyDocumentException$: () => MalformedPolicyDocumentException$9,
  PackedPolicyTooLargeException: () => PackedPolicyTooLargeException9,
  PackedPolicyTooLargeException$: () => PackedPolicyTooLargeException$9,
  PolicyDescriptorType$: () => PolicyDescriptorType$9,
  ProvidedContext$: () => ProvidedContext$9,
  RegionDisabledException: () => RegionDisabledException9,
  RegionDisabledException$: () => RegionDisabledException$9,
  STS: () => STS9,
  STSClient: () => STSClient10,
  STSServiceException: () => STSServiceException9,
  STSServiceException$: () => STSServiceException$9,
  Tag$: () => Tag$9,
  __Client: () => import_smithy_client257.Client,
  decorateDefaultCredentialProvider: () => decorateDefaultCredentialProvider9,
  errorTypeRegistries: () => errorTypeRegistries31,
  getDefaultRoleAssumer: () => getDefaultRoleAssumer18,
  getDefaultRoleAssumerWithWebIdentity: () => getDefaultRoleAssumerWithWebIdentity18
});
var init_sts9 = __esm({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/nested-clients/dist-es/submodules/sts/index.js"() {
    init_STSClient9();
    init_STS9();
    init_commands32();
    init_schemas_031();
    init_errors31();
    init_models_031();
    init_defaultRoleAssumers9();
    init_STSServiceException9();
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-process/dist-cjs/index.js
var require_dist_cjs205 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-process/dist-cjs/index.js"(exports2) {
    "use strict";
    var sharedIniFileLoader = require_dist_cjs28();
    var propertyProvider = require_dist_cjs27();
    var node_child_process = require("node:child_process");
    var node_util = require("node:util");
    var client = (init_client19(), __toCommonJS(client_exports14));
    var getValidatedProcessCredentials = /* @__PURE__ */ __name((profileName, data3, profiles) => {
      if (data3.Version !== 1) {
        throw Error(`Profile ${profileName} credential_process did not return Version 1.`);
      }
      if (data3.AccessKeyId === void 0 || data3.SecretAccessKey === void 0) {
        throw Error(`Profile ${profileName} credential_process returned invalid credentials.`);
      }
      if (data3.Expiration) {
        const currentTime = /* @__PURE__ */ new Date();
        const expireTime = new Date(data3.Expiration);
        if (expireTime < currentTime) {
          throw Error(`Profile ${profileName} credential_process returned expired credentials.`);
        }
      }
      let accountId = data3.AccountId;
      if (!accountId && profiles?.[profileName]?.aws_account_id) {
        accountId = profiles[profileName].aws_account_id;
      }
      const credentials = {
        accessKeyId: data3.AccessKeyId,
        secretAccessKey: data3.SecretAccessKey,
        ...data3.SessionToken && { sessionToken: data3.SessionToken },
        ...data3.Expiration && { expiration: new Date(data3.Expiration) },
        ...data3.CredentialScope && { credentialScope: data3.CredentialScope },
        ...accountId && { accountId }
      };
      client.setCredentialFeature(credentials, "CREDENTIALS_PROCESS", "w");
      return credentials;
    }, "getValidatedProcessCredentials");
    var resolveProcessCredentials = /* @__PURE__ */ __name(async (profileName, profiles, logger5) => {
      const profile = profiles[profileName];
      if (profiles[profileName]) {
        const credentialProcess = profile["credential_process"];
        if (credentialProcess !== void 0) {
          const execPromise = node_util.promisify(sharedIniFileLoader.externalDataInterceptor?.getTokenRecord?.().exec ?? node_child_process.exec);
          try {
            const { stdout } = await execPromise(credentialProcess);
            let data3;
            try {
              data3 = JSON.parse(stdout.trim());
            } catch {
              throw Error(`Profile ${profileName} credential_process returned invalid JSON.`);
            }
            return getValidatedProcessCredentials(profileName, data3, profiles);
          } catch (error4) {
            throw new propertyProvider.CredentialsProviderError(error4.message, { logger: logger5 });
          }
        } else {
          throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} did not contain credential_process.`, { logger: logger5 });
        }
      } else {
        throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} could not be found in shared credentials file.`, {
          logger: logger5
        });
      }
    }, "resolveProcessCredentials");
    var fromProcess = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/credential-provider-process - fromProcess");
      const profiles = await sharedIniFileLoader.parseKnownFiles(init);
      return resolveProcessCredentials(sharedIniFileLoader.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      }), profiles, init.logger);
    }, "fromProcess");
    exports2.fromProcess = fromProcess;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromWebToken.js
var require_fromWebToken10 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromWebToken.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __setModuleDefault2 = exports2 && exports2.__setModuleDefault || (Object.create ? (function(o10, v) {
      Object.defineProperty(o10, "default", { enumerable: true, value: v });
    }) : function(o10, v) {
      o10["default"] = v;
    });
    var __importStar2 = exports2 && exports2.__importStar || /* @__PURE__ */ (function() {
      var ownKeys2 = /* @__PURE__ */ __name(function(o10) {
        ownKeys2 = Object.getOwnPropertyNames || function(o11) {
          var ar = [];
          for (var k32 in o11) if (Object.prototype.hasOwnProperty.call(o11, k32)) ar[ar.length] = k32;
          return ar;
        };
        return ownKeys2(o10);
      }, "ownKeys");
      return function(mod) {
        if (mod && mod.__esModule) return mod;
        var result2 = {};
        if (mod != null) {
          for (var k32 = ownKeys2(mod), i32 = 0; i32 < k32.length; i32++) if (k32[i32] !== "default") __createBinding3(result2, mod, k32[i32]);
        }
        __setModuleDefault2(result2, mod);
        return result2;
      };
    })();
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromWebToken = void 0;
    var fromWebToken = /* @__PURE__ */ __name((init) => async (awsIdentityProperties) => {
      init.logger?.debug("@aws-sdk/credential-provider-web-identity - fromWebToken");
      const { roleArn, roleSessionName, webIdentityToken, providerId, policyArns, policy, durationSeconds } = init;
      let { roleAssumerWithWebIdentity } = init;
      if (!roleAssumerWithWebIdentity) {
        const { getDefaultRoleAssumerWithWebIdentity: getDefaultRoleAssumerWithWebIdentity19 } = await Promise.resolve().then(() => __importStar2((init_sts9(), __toCommonJS(sts_exports9))));
        roleAssumerWithWebIdentity = getDefaultRoleAssumerWithWebIdentity19({
          ...init.clientConfig,
          credentialProviderLogger: init.logger,
          parentClientConfig: {
            ...awsIdentityProperties?.callerClientConfig,
            ...init.parentClientConfig
          }
        }, init.clientPlugins);
      }
      return roleAssumerWithWebIdentity({
        RoleArn: roleArn,
        RoleSessionName: roleSessionName ?? `aws-sdk-js-session-${Date.now()}`,
        WebIdentityToken: webIdentityToken,
        ProviderId: providerId,
        PolicyArns: policyArns,
        Policy: policy,
        DurationSeconds: durationSeconds
      });
    }, "fromWebToken");
    exports2.fromWebToken = fromWebToken;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromTokenFile.js
var require_fromTokenFile10 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/fromTokenFile.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.fromTokenFile = void 0;
    var client_1 = (init_client19(), __toCommonJS(client_exports14));
    var property_provider_1 = require_dist_cjs27();
    var shared_ini_file_loader_1 = require_dist_cjs28();
    var node_fs_1 = require("node:fs");
    var fromWebToken_1 = require_fromWebToken10();
    var ENV_TOKEN_FILE = "AWS_WEB_IDENTITY_TOKEN_FILE";
    var ENV_ROLE_ARN = "AWS_ROLE_ARN";
    var ENV_ROLE_SESSION_NAME = "AWS_ROLE_SESSION_NAME";
    var fromTokenFile = /* @__PURE__ */ __name((init = {}) => async (awsIdentityProperties) => {
      init.logger?.debug("@aws-sdk/credential-provider-web-identity - fromTokenFile");
      const webIdentityTokenFile = init?.webIdentityTokenFile ?? process.env[ENV_TOKEN_FILE];
      const roleArn = init?.roleArn ?? process.env[ENV_ROLE_ARN];
      const roleSessionName = init?.roleSessionName ?? process.env[ENV_ROLE_SESSION_NAME];
      if (!webIdentityTokenFile || !roleArn) {
        throw new property_provider_1.CredentialsProviderError("Web identity configuration not specified", {
          logger: init.logger
        });
      }
      const credentials = await (0, fromWebToken_1.fromWebToken)({
        ...init,
        webIdentityToken: shared_ini_file_loader_1.externalDataInterceptor?.getTokenRecord?.()[webIdentityTokenFile] ?? (0, node_fs_1.readFileSync)(webIdentityTokenFile, { encoding: "ascii" }),
        roleArn,
        roleSessionName
      })(awsIdentityProperties);
      if (webIdentityTokenFile === process.env[ENV_TOKEN_FILE]) {
        (0, client_1.setCredentialFeature)(credentials, "CREDENTIALS_ENV_VARS_STS_WEB_ID_TOKEN", "h");
      }
      return credentials;
    }, "fromTokenFile");
    exports2.fromTokenFile = fromTokenFile;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/index.js
var require_dist_cjs206 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-web-identity/dist-cjs/index.js"(exports2) {
    "use strict";
    var fromTokenFile = require_fromTokenFile10();
    var fromWebToken = require_fromWebToken10();
    Object.prototype.hasOwnProperty.call(fromTokenFile, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: fromTokenFile["__proto__"]
    });
    Object.keys(fromTokenFile).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = fromTokenFile[k32];
    });
    Object.prototype.hasOwnProperty.call(fromWebToken, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: fromWebToken["__proto__"]
    });
    Object.keys(fromWebToken).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = fromWebToken[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-ini/dist-cjs/index.js
var require_dist_cjs207 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-ini/dist-cjs/index.js"(exports2) {
    "use strict";
    var sharedIniFileLoader = require_dist_cjs28();
    var propertyProvider = require_dist_cjs27();
    var client = (init_client19(), __toCommonJS(client_exports14));
    var credentialProviderLogin = require_dist_cjs204();
    var resolveCredentialSource = /* @__PURE__ */ __name((credentialSource, profileName, logger5) => {
      const sourceProvidersMap = {
        EcsContainer: /* @__PURE__ */ __name(async (options) => {
          const { fromHttp } = await Promise.resolve().then(() => __toESM(require_dist_cjs201()));
          const { fromContainerMetadata } = await Promise.resolve().then(() => __toESM(require_dist_cjs38()));
          logger5?.debug("@aws-sdk/credential-provider-ini - credential_source is EcsContainer");
          return async () => propertyProvider.chain(fromHttp(options ?? {}), fromContainerMetadata(options))().then(setNamedProvider);
        }, "EcsContainer"),
        Ec2InstanceMetadata: /* @__PURE__ */ __name(async (options) => {
          logger5?.debug("@aws-sdk/credential-provider-ini - credential_source is Ec2InstanceMetadata");
          const { fromInstanceMetadata } = await Promise.resolve().then(() => __toESM(require_dist_cjs38()));
          return async () => fromInstanceMetadata(options)().then(setNamedProvider);
        }, "Ec2InstanceMetadata"),
        Environment: /* @__PURE__ */ __name(async (options) => {
          logger5?.debug("@aws-sdk/credential-provider-ini - credential_source is Environment");
          const { fromEnv: fromEnv6 } = await Promise.resolve().then(() => __toESM(require_dist_cjs199()));
          return async () => fromEnv6(options)().then(setNamedProvider);
        }, "Environment")
      };
      if (credentialSource in sourceProvidersMap) {
        return sourceProvidersMap[credentialSource];
      } else {
        throw new propertyProvider.CredentialsProviderError(`Unsupported credential source in profile ${profileName}. Got ${credentialSource}, expected EcsContainer or Ec2InstanceMetadata or Environment.`, { logger: logger5 });
      }
    }, "resolveCredentialSource");
    var setNamedProvider = /* @__PURE__ */ __name((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_NAMED_PROVIDER", "p"), "setNamedProvider");
    var isAssumeRoleProfile = /* @__PURE__ */ __name((arg, { profile = "default", logger: logger5 } = {}) => {
      return Boolean(arg) && typeof arg === "object" && typeof arg.role_arn === "string" && ["undefined", "string"].indexOf(typeof arg.role_session_name) > -1 && ["undefined", "string"].indexOf(typeof arg.external_id) > -1 && ["undefined", "string"].indexOf(typeof arg.mfa_serial) > -1 && (isAssumeRoleWithSourceProfile(arg, { profile, logger: logger5 }) || isCredentialSourceProfile(arg, { profile, logger: logger5 }));
    }, "isAssumeRoleProfile");
    var isAssumeRoleWithSourceProfile = /* @__PURE__ */ __name((arg, { profile, logger: logger5 }) => {
      const withSourceProfile = typeof arg.source_profile === "string" && typeof arg.credential_source === "undefined";
      if (withSourceProfile) {
        logger5?.debug?.(`    ${profile} isAssumeRoleWithSourceProfile source_profile=${arg.source_profile}`);
      }
      return withSourceProfile;
    }, "isAssumeRoleWithSourceProfile");
    var isCredentialSourceProfile = /* @__PURE__ */ __name((arg, { profile, logger: logger5 }) => {
      const withProviderProfile = typeof arg.credential_source === "string" && typeof arg.source_profile === "undefined";
      if (withProviderProfile) {
        logger5?.debug?.(`    ${profile} isCredentialSourceProfile credential_source=${arg.credential_source}`);
      }
      return withProviderProfile;
    }, "isCredentialSourceProfile");
    var resolveAssumeRoleCredentials = /* @__PURE__ */ __name(async (profileName, profiles, options, callerClientConfig, visitedProfiles = {}, resolveProfileData2) => {
      options.logger?.debug("@aws-sdk/credential-provider-ini - resolveAssumeRoleCredentials (STS)");
      const profileData = profiles[profileName];
      const { source_profile, region } = profileData;
      if (!options.roleAssumer) {
        const { getDefaultRoleAssumer: getDefaultRoleAssumer19 } = await Promise.resolve().then(() => (init_sts9(), sts_exports9));
        options.roleAssumer = getDefaultRoleAssumer19({
          ...options.clientConfig,
          credentialProviderLogger: options.logger,
          parentClientConfig: {
            ...callerClientConfig,
            ...options?.parentClientConfig,
            region: region ?? options?.parentClientConfig?.region ?? callerClientConfig?.region
          }
        }, options.clientPlugins);
      }
      if (source_profile && source_profile in visitedProfiles) {
        throw new propertyProvider.CredentialsProviderError(`Detected a cycle attempting to resolve credentials for profile ${sharedIniFileLoader.getProfileName(options)}. Profiles visited: ` + Object.keys(visitedProfiles).join(", "), { logger: options.logger });
      }
      options.logger?.debug(`@aws-sdk/credential-provider-ini - finding credential resolver using ${source_profile ? `source_profile=[${source_profile}]` : `profile=[${profileName}]`}`);
      const sourceCredsProvider = source_profile ? resolveProfileData2(source_profile, profiles, options, callerClientConfig, {
        ...visitedProfiles,
        [source_profile]: true
      }, isCredentialSourceWithoutRoleArn(profiles[source_profile] ?? {})) : (await resolveCredentialSource(profileData.credential_source, profileName, options.logger)(options))();
      if (isCredentialSourceWithoutRoleArn(profileData)) {
        return sourceCredsProvider.then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SOURCE_PROFILE", "o"));
      } else {
        const params = {
          RoleArn: profileData.role_arn,
          RoleSessionName: profileData.role_session_name || `aws-sdk-js-${Date.now()}`,
          ExternalId: profileData.external_id,
          DurationSeconds: parseInt(profileData.duration_seconds || "3600", 10)
        };
        const { mfa_serial } = profileData;
        if (mfa_serial) {
          if (!options.mfaCodeProvider) {
            throw new propertyProvider.CredentialsProviderError(`Profile ${profileName} requires multi-factor authentication, but no MFA code callback was provided.`, { logger: options.logger, tryNextLink: false });
          }
          params.SerialNumber = mfa_serial;
          params.TokenCode = await options.mfaCodeProvider(mfa_serial);
        }
        const sourceCreds = await sourceCredsProvider;
        return options.roleAssumer(sourceCreds, params).then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SOURCE_PROFILE", "o"));
      }
    }, "resolveAssumeRoleCredentials");
    var isCredentialSourceWithoutRoleArn = /* @__PURE__ */ __name((section) => {
      return !section.role_arn && !!section.credential_source;
    }, "isCredentialSourceWithoutRoleArn");
    var isLoginProfile = /* @__PURE__ */ __name((data3) => {
      return Boolean(data3 && data3.login_session);
    }, "isLoginProfile");
    var resolveLoginCredentials = /* @__PURE__ */ __name(async (profileName, options, callerClientConfig) => {
      const credentials = await credentialProviderLogin.fromLoginCredentials({
        ...options,
        profile: profileName
      })({ callerClientConfig });
      return client.setCredentialFeature(credentials, "CREDENTIALS_PROFILE_LOGIN", "AC");
    }, "resolveLoginCredentials");
    var isProcessProfile = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.credential_process === "string", "isProcessProfile");
    var resolveProcessCredentials = /* @__PURE__ */ __name(async (options, profile) => Promise.resolve().then(() => __toESM(require_dist_cjs205())).then(({ fromProcess }) => fromProcess({
      ...options,
      profile
    })().then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_PROCESS", "v"))), "resolveProcessCredentials");
    var resolveSsoCredentials = /* @__PURE__ */ __name(async (profile, profileData, options = {}, callerClientConfig) => {
      const { fromSSO } = await Promise.resolve().then(() => __toESM(require_dist_cjs203()));
      return fromSSO({
        profile,
        logger: options.logger,
        parentClientConfig: options.parentClientConfig,
        clientConfig: options.clientConfig
      })({
        callerClientConfig
      }).then((creds) => {
        if (profileData.sso_session) {
          return client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SSO", "r");
        } else {
          return client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_SSO_LEGACY", "t");
        }
      });
    }, "resolveSsoCredentials");
    var isSsoProfile = /* @__PURE__ */ __name((arg) => arg && (typeof arg.sso_start_url === "string" || typeof arg.sso_account_id === "string" || typeof arg.sso_session === "string" || typeof arg.sso_region === "string" || typeof arg.sso_role_name === "string"), "isSsoProfile");
    var isStaticCredsProfile = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.aws_access_key_id === "string" && typeof arg.aws_secret_access_key === "string" && ["undefined", "string"].indexOf(typeof arg.aws_session_token) > -1 && ["undefined", "string"].indexOf(typeof arg.aws_account_id) > -1, "isStaticCredsProfile");
    var resolveStaticCredentials = /* @__PURE__ */ __name(async (profile, options) => {
      options?.logger?.debug("@aws-sdk/credential-provider-ini - resolveStaticCredentials");
      const credentials = {
        accessKeyId: profile.aws_access_key_id,
        secretAccessKey: profile.aws_secret_access_key,
        sessionToken: profile.aws_session_token,
        ...profile.aws_credential_scope && { credentialScope: profile.aws_credential_scope },
        ...profile.aws_account_id && { accountId: profile.aws_account_id }
      };
      return client.setCredentialFeature(credentials, "CREDENTIALS_PROFILE", "n");
    }, "resolveStaticCredentials");
    var isWebIdentityProfile = /* @__PURE__ */ __name((arg) => Boolean(arg) && typeof arg === "object" && typeof arg.web_identity_token_file === "string" && typeof arg.role_arn === "string" && ["undefined", "string"].indexOf(typeof arg.role_session_name) > -1, "isWebIdentityProfile");
    var resolveWebIdentityCredentials = /* @__PURE__ */ __name(async (profile, options, callerClientConfig) => Promise.resolve().then(() => __toESM(require_dist_cjs206())).then(({ fromTokenFile }) => fromTokenFile({
      webIdentityTokenFile: profile.web_identity_token_file,
      roleArn: profile.role_arn,
      roleSessionName: profile.role_session_name,
      roleAssumerWithWebIdentity: options.roleAssumerWithWebIdentity,
      logger: options.logger,
      parentClientConfig: options.parentClientConfig
    })({
      callerClientConfig
    }).then((creds) => client.setCredentialFeature(creds, "CREDENTIALS_PROFILE_STS_WEB_ID_TOKEN", "q"))), "resolveWebIdentityCredentials");
    var resolveProfileData = /* @__PURE__ */ __name(async (profileName, profiles, options, callerClientConfig, visitedProfiles = {}, isAssumeRoleRecursiveCall = false) => {
      const data3 = profiles[profileName];
      if (Object.keys(visitedProfiles).length > 0 && isStaticCredsProfile(data3)) {
        return resolveStaticCredentials(data3, options);
      }
      if (isAssumeRoleRecursiveCall || isAssumeRoleProfile(data3, { profile: profileName, logger: options.logger })) {
        return resolveAssumeRoleCredentials(profileName, profiles, options, callerClientConfig, visitedProfiles, resolveProfileData);
      }
      if (isStaticCredsProfile(data3)) {
        return resolveStaticCredentials(data3, options);
      }
      if (isWebIdentityProfile(data3)) {
        return resolveWebIdentityCredentials(data3, options, callerClientConfig);
      }
      if (isProcessProfile(data3)) {
        return resolveProcessCredentials(options, profileName);
      }
      if (isSsoProfile(data3)) {
        return await resolveSsoCredentials(profileName, data3, options, callerClientConfig);
      }
      if (isLoginProfile(data3)) {
        return resolveLoginCredentials(profileName, options, callerClientConfig);
      }
      throw new propertyProvider.CredentialsProviderError(`Could not resolve credentials using profile: [${profileName}] in configuration/credentials file(s).`, { logger: options.logger });
    }, "resolveProfileData");
    var fromIni2 = /* @__PURE__ */ __name((init = {}) => async ({ callerClientConfig } = {}) => {
      init.logger?.debug("@aws-sdk/credential-provider-ini - fromIni");
      const profiles = await sharedIniFileLoader.parseKnownFiles(init);
      return resolveProfileData(sharedIniFileLoader.getProfileName({
        profile: init.profile ?? callerClientConfig?.profile
      }), profiles, init, callerClientConfig);
    }, "fromIni");
    exports2.fromIni = fromIni2;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-node/dist-cjs/index.js
var require_dist_cjs208 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@aws-sdk/credential-provider-node/dist-cjs/index.js"(exports2) {
    "use strict";
    var credentialProviderEnv = require_dist_cjs199();
    var propertyProvider = require_dist_cjs27();
    var sharedIniFileLoader = require_dist_cjs28();
    var ENV_IMDS_DISABLED3 = "AWS_EC2_METADATA_DISABLED";
    var remoteProvider = /* @__PURE__ */ __name(async (init) => {
      const { ENV_CMDS_FULL_URI, ENV_CMDS_RELATIVE_URI, fromContainerMetadata, fromInstanceMetadata } = await Promise.resolve().then(() => __toESM(require_dist_cjs38()));
      if (process.env[ENV_CMDS_RELATIVE_URI] || process.env[ENV_CMDS_FULL_URI]) {
        init.logger?.debug("@aws-sdk/credential-provider-node - remoteProvider::fromHttp/fromContainerMetadata");
        const { fromHttp } = await Promise.resolve().then(() => __toESM(require_dist_cjs201()));
        return propertyProvider.chain(fromHttp(init), fromContainerMetadata(init));
      }
      if (process.env[ENV_IMDS_DISABLED3] && process.env[ENV_IMDS_DISABLED3] !== "false") {
        return async () => {
          throw new propertyProvider.CredentialsProviderError("EC2 Instance Metadata Service access disabled", { logger: init.logger });
        };
      }
      init.logger?.debug("@aws-sdk/credential-provider-node - remoteProvider::fromInstanceMetadata");
      return fromInstanceMetadata(init);
    }, "remoteProvider");
    function memoizeChain(providers, treatAsExpired) {
      const chain5 = internalCreateChain(providers);
      let activeLock;
      let passiveLock;
      let credentials;
      const provider = /* @__PURE__ */ __name(async (options) => {
        if (options?.forceRefresh) {
          return await chain5(options);
        }
        if (credentials?.expiration) {
          if (credentials?.expiration?.getTime() < Date.now()) {
            credentials = void 0;
          }
        }
        if (activeLock) {
          await activeLock;
        } else if (!credentials || treatAsExpired?.(credentials)) {
          if (credentials) {
            if (!passiveLock) {
              passiveLock = chain5(options).then((c32) => {
                credentials = c32;
              }).finally(() => {
                passiveLock = void 0;
              });
            }
          } else {
            activeLock = chain5(options).then((c32) => {
              credentials = c32;
            }).finally(() => {
              activeLock = void 0;
            });
            return provider(options);
          }
        }
        return credentials;
      }, "provider");
      return provider;
    }
    __name(memoizeChain, "memoizeChain");
    var internalCreateChain = /* @__PURE__ */ __name((providers) => async (awsIdentityProperties) => {
      let lastProviderError;
      for (const provider of providers) {
        try {
          return await provider(awsIdentityProperties);
        } catch (err) {
          lastProviderError = err;
          if (err?.tryNextLink) {
            continue;
          }
          throw err;
        }
      }
      throw lastProviderError;
    }, "internalCreateChain");
    var multipleCredentialSourceWarningEmitted = false;
    var defaultProvider = /* @__PURE__ */ __name((init = {}) => memoizeChain([
      async () => {
        const profile = init.profile ?? process.env[sharedIniFileLoader.ENV_PROFILE];
        if (profile) {
          const envStaticCredentialsAreSet = process.env[credentialProviderEnv.ENV_KEY] && process.env[credentialProviderEnv.ENV_SECRET];
          if (envStaticCredentialsAreSet) {
            if (!multipleCredentialSourceWarningEmitted) {
              const warnFn = init.logger?.warn && init.logger?.constructor?.name !== "NoOpLogger" ? init.logger.warn.bind(init.logger) : console.warn;
              warnFn(`@aws-sdk/credential-provider-node - defaultProvider::fromEnv WARNING:
    Multiple credential sources detected: 
    Both AWS_PROFILE and the pair AWS_ACCESS_KEY_ID/AWS_SECRET_ACCESS_KEY static credentials are set.
    This SDK will proceed with the AWS_PROFILE value.
    
    However, a future version may change this behavior to prefer the ENV static credentials.
    Please ensure that your environment only sets either the AWS_PROFILE or the
    AWS_ACCESS_KEY_ID/AWS_SECRET_ACCESS_KEY pair.
`);
              multipleCredentialSourceWarningEmitted = true;
            }
          }
          throw new propertyProvider.CredentialsProviderError("AWS_PROFILE is set, skipping fromEnv provider.", {
            logger: init.logger,
            tryNextLink: true
          });
        }
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromEnv");
        return credentialProviderEnv.fromEnv(init)();
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromSSO");
        const { ssoStartUrl, ssoAccountId, ssoRegion, ssoRoleName, ssoSession } = init;
        if (!ssoStartUrl && !ssoAccountId && !ssoRegion && !ssoRoleName && !ssoSession) {
          throw new propertyProvider.CredentialsProviderError("Skipping SSO provider in default chain (inputs do not include SSO fields).", { logger: init.logger });
        }
        const { fromSSO } = await Promise.resolve().then(() => __toESM(require_dist_cjs203()));
        return fromSSO(init)(awsIdentityProperties);
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromIni");
        const { fromIni: fromIni2 } = await Promise.resolve().then(() => __toESM(require_dist_cjs207()));
        return fromIni2(init)(awsIdentityProperties);
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromProcess");
        const { fromProcess } = await Promise.resolve().then(() => __toESM(require_dist_cjs205()));
        return fromProcess(init)(awsIdentityProperties);
      },
      async (awsIdentityProperties) => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::fromTokenFile");
        const { fromTokenFile } = await Promise.resolve().then(() => __toESM(require_dist_cjs206()));
        return fromTokenFile(init)(awsIdentityProperties);
      },
      async () => {
        init.logger?.debug("@aws-sdk/credential-provider-node - defaultProvider::remoteProvider");
        return (await remoteProvider(init))();
      },
      async () => {
        throw new propertyProvider.CredentialsProviderError("Could not load credentials from any providers", {
          tryNextLink: false,
          logger: init.logger
        });
      }
    ], credentialsTreatedAsExpired), "defaultProvider");
    var credentialsWillNeedRefresh = /* @__PURE__ */ __name((credentials) => credentials?.expiration !== void 0, "credentialsWillNeedRefresh");
    var credentialsTreatedAsExpired = /* @__PURE__ */ __name((credentials) => credentials?.expiration !== void 0 && credentials.expiration.getTime() - Date.now() < 3e5, "credentialsTreatedAsExpired");
    exports2.credentialsTreatedAsExpired = credentialsTreatedAsExpired;
    exports2.credentialsWillNeedRefresh = credentialsWillNeedRefresh;
    exports2.defaultProvider = defaultProvider;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/dist-cjs/endpoint/bdd.js
var require_bdd19 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/dist-cjs/endpoint/bdd.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.bdd = void 0;
    var util_endpoints_1 = require_dist_cjs20();
    var k32 = "ref";
    var a32 = -1;
    var b32 = true;
    var c32 = "isSet";
    var d32 = "PartitionResult";
    var e32 = "booleanEquals";
    var f32 = "getAttr";
    var g32 = { [k32]: "Endpoint" };
    var h32 = { [k32]: d32 };
    var i32 = {};
    var j32 = [{ [k32]: "Region" }];
    var _data32 = {
      conditions: [
        [c32, [g32]],
        [c32, j32],
        ["aws.partition", j32, d32],
        [e32, [{ [k32]: "UseFIPS" }, b32]],
        [e32, [{ [k32]: "UseDualStack" }, b32]],
        [e32, [{ fn: f32, argv: [h32, "supportsDualStack"] }, b32]],
        [e32, [{ fn: f32, argv: [h32, "supportsFIPS"] }, b32]],
        ["stringEquals", [{ fn: f32, argv: [h32, "name"] }, "aws-us-gov"]]
      ],
      results: [
        [a32],
        [a32, "Invalid Configuration: FIPS and custom endpoint are not supported"],
        [a32, "Invalid Configuration: Dualstack and custom endpoint are not supported"],
        [g32, i32],
        ["https://ssm-fips.{Region}.{PartitionResult#dualStackDnsSuffix}", i32],
        [a32, "FIPS and DualStack are enabled, but this partition does not support one or both"],
        ["https://ssm.{Region}.amazonaws.com", i32],
        ["https://ssm-fips.{Region}.{PartitionResult#dnsSuffix}", i32],
        [a32, "FIPS is enabled but this partition does not support FIPS"],
        ["https://ssm.{Region}.{PartitionResult#dualStackDnsSuffix}", i32],
        [a32, "DualStack is enabled but this partition does not support DualStack"],
        ["https://ssm.{Region}.{PartitionResult#dnsSuffix}", i32],
        [a32, "Invalid Configuration: Missing Region"]
      ]
    };
    var root32 = 2;
    var r32 = 1e8;
    var nodes32 = new Int32Array([
      -1,
      1,
      -1,
      0,
      13,
      3,
      1,
      4,
      r32 + 12,
      2,
      5,
      r32 + 12,
      3,
      8,
      6,
      4,
      7,
      r32 + 11,
      5,
      r32 + 9,
      r32 + 10,
      4,
      11,
      9,
      6,
      10,
      r32 + 8,
      7,
      r32 + 6,
      r32 + 7,
      5,
      12,
      r32 + 5,
      6,
      r32 + 4,
      r32 + 5,
      3,
      r32 + 1,
      14,
      4,
      r32 + 2,
      r32 + 3
    ]);
    exports2.bdd = util_endpoints_1.BinaryDecisionDiagram.from(nodes32, root32, _data32.conditions, _data32.results);
  }
});

// ../../node_modules/@aws-sdk/client-ssm/dist-cjs/endpoint/endpointResolver.js
var require_endpointResolver19 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/dist-cjs/endpoint/endpointResolver.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.defaultEndpointResolver = void 0;
    var util_endpoints_1 = require_dist_cjs21();
    var util_endpoints_2 = require_dist_cjs20();
    var bdd_1 = require_bdd19();
    var cache32 = new util_endpoints_2.EndpointCache({
      size: 50,
      params: ["Endpoint", "Region", "UseDualStack", "UseFIPS"]
    });
    var defaultEndpointResolver32 = /* @__PURE__ */ __name((endpointParams, context = {}) => {
      return cache32.get(endpointParams, () => (0, util_endpoints_2.decideEndpoint)(bdd_1.bdd, {
        endpointParams,
        logger: context.logger
      }));
    }, "defaultEndpointResolver");
    exports2.defaultEndpointResolver = defaultEndpointResolver32;
    util_endpoints_2.customEndpointFunctions.aws = util_endpoints_1.awsEndpointFunctions;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/dist-cjs/models/SSMServiceException.js
var require_SSMServiceException = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/dist-cjs/models/SSMServiceException.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.SSMServiceException = exports2.__ServiceException = void 0;
    var smithy_client_1 = require_dist_cjs34();
    Object.defineProperty(exports2, "__ServiceException", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return smithy_client_1.ServiceException;
    }, "get") });
    var SSMServiceException = class _SSMServiceException extends smithy_client_1.ServiceException {
      static {
        __name(this, "SSMServiceException");
      }
      constructor(options) {
        super(options);
        Object.setPrototypeOf(this, _SSMServiceException.prototype);
      }
    };
    exports2.SSMServiceException = SSMServiceException;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/dist-cjs/models/errors.js
var require_errors18 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/dist-cjs/models/errors.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.InvalidDeleteInventoryParametersException = exports2.InvalidDocumentOperation = exports2.AssociatedInstances = exports2.AssociationDoesNotExist = exports2.InvalidActivationId = exports2.InvalidActivation = exports2.ResourceDataSyncInvalidConfigurationException = exports2.ResourceDataSyncCountExceededException = exports2.ResourceDataSyncAlreadyExistsException = exports2.OpsMetadataTooManyUpdatesException = exports2.OpsMetadataLimitExceededException = exports2.OpsMetadataInvalidArgumentException = exports2.OpsMetadataAlreadyExistsException = exports2.OpsItemAlreadyExistsException = exports2.OpsItemAccessDeniedException = exports2.ResourceLimitExceededException = exports2.IdempotentParameterMismatch = exports2.NoLongerSupportedException = exports2.MaxDocumentSizeExceeded = exports2.InvalidDocumentSchemaVersion = exports2.InvalidDocumentContent = exports2.DocumentLimitExceeded = exports2.DocumentAlreadyExists = exports2.UnsupportedPlatformType = exports2.InvalidTargetMaps = exports2.InvalidTarget = exports2.InvalidTag = exports2.InvalidSchedule = exports2.InvalidOutputLocation = exports2.InvalidDocumentVersion = exports2.InvalidDocument = exports2.AssociationLimitExceeded = exports2.AssociationAlreadyExists = exports2.InvalidParameters = exports2.DoesNotExistException = exports2.InvalidInstanceId = exports2.InvalidCommandId = exports2.DuplicateInstanceId = exports2.OpsItemRelatedItemAlreadyExistsException = exports2.OpsItemNotFoundException = exports2.OpsItemLimitExceededException = exports2.OpsItemInvalidParameterException = exports2.OpsItemConflictException = exports2.AlreadyExistsException = exports2.TooManyUpdates = exports2.TooManyTagsError = exports2.InvalidResourceType = exports2.InvalidResourceId = exports2.InternalServerError = exports2.AccessDeniedException = void 0;
    exports2.ItemContentMismatchException = exports2.InvalidInventoryItemContextException = exports2.CustomSchemaCountLimitExceededException = exports2.TotalSizeLimitExceededException = exports2.ItemSizeLimitExceededException = exports2.InvalidItemContentException = exports2.ComplianceTypeCountLimitExceededException = exports2.DocumentPermissionLimit = exports2.UnsupportedOperationException = exports2.ParameterVersionLabelLimitExceeded = exports2.ServiceSettingNotFound = exports2.ParameterVersionNotFound = exports2.InvalidKeyId = exports2.InvalidResultAttributeException = exports2.InvalidInventoryGroupException = exports2.InvalidAggregatorException = exports2.UnsupportedFeatureRequiredException = exports2.InvocationDoesNotExist = exports2.InvalidPluginName = exports2.UnsupportedCalendarException = exports2.InvalidDocumentType = exports2.ValidationException = exports2.ThrottlingException = exports2.OpsItemRelatedItemAssociationNotFoundException = exports2.InvalidFilterOption = exports2.InvalidDeletionIdException = exports2.InvalidInstancePropertyFilterValue = exports2.InvalidInstanceInformationFilterValue = exports2.UnsupportedOperatingSystem = exports2.InvalidPermissionType = exports2.AutomationExecutionNotFoundException = exports2.InvalidFilterValue = exports2.InvalidFilterKey = exports2.AssociationExecutionDoesNotExist = exports2.InvalidAssociationVersion = exports2.InvalidNextToken = exports2.InvalidFilter = exports2.TargetInUseException = exports2.ResourcePolicyNotFoundException = exports2.ResourcePolicyInvalidParameterException = exports2.ResourcePolicyConflictException = exports2.ResourceNotFoundException = exports2.MalformedResourcePolicyDocumentException = exports2.ResourceDataSyncNotFoundException = exports2.ResourceInUseException = exports2.ParameterNotFound = exports2.OpsMetadataNotFoundException = exports2.InvalidTypeNameException = exports2.InvalidOptionException = exports2.InvalidInventoryRequestException = void 0;
    exports2.ResourceDataSyncConflictException = exports2.OpsMetadataKeyLimitExceededException = exports2.DuplicateDocumentVersionName = exports2.DuplicateDocumentContent = exports2.DocumentVersionLimitExceeded = exports2.StatusUnchanged = exports2.InvalidUpdate = exports2.AssociationVersionLimitExceeded = exports2.InvalidAutomationStatusUpdateException = exports2.TargetNotConnected = exports2.AutomationDefinitionNotApprovedException = exports2.InvalidAutomationExecutionParametersException = exports2.AutomationExecutionLimitExceededException = exports2.AutomationDefinitionVersionNotFoundException = exports2.AutomationDefinitionNotFoundException = exports2.InvalidAssociation = exports2.ServiceQuotaExceededException = exports2.InvalidRole = exports2.InvalidOutputFolder = exports2.InvalidNotificationConfig = exports2.InvalidAutomationSignalException = exports2.AutomationStepNotFoundException = exports2.FeatureNotAvailableException = exports2.ResourcePolicyLimitExceededException = exports2.UnsupportedParameterType = exports2.PoliciesLimitExceededException = exports2.ParameterPatternMismatchException = exports2.ParameterMaxVersionLimitExceeded = exports2.ParameterLimitExceeded = exports2.ParameterAlreadyExists = exports2.InvalidPolicyTypeException = exports2.InvalidPolicyAttributeException = exports2.InvalidAllowedPatternException = exports2.IncompatiblePolicyException = exports2.HierarchyTypeMismatchException = exports2.HierarchyLevelLimitExceededException = exports2.UnsupportedInventorySchemaVersionException = exports2.UnsupportedInventoryItemContextException = exports2.SubTypeCountLimitExceededException = void 0;
    var SSMServiceException_1 = require_SSMServiceException();
    var AccessDeniedException13 = class _AccessDeniedException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "AccessDeniedException");
      }
      name = "AccessDeniedException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "AccessDeniedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AccessDeniedException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.AccessDeniedException = AccessDeniedException13;
    var InternalServerError = class _InternalServerError extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InternalServerError");
      }
      name = "InternalServerError";
      $fault = "server";
      Message;
      constructor(opts) {
        super({
          name: "InternalServerError",
          $fault: "server",
          ...opts
        });
        Object.setPrototypeOf(this, _InternalServerError.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InternalServerError = InternalServerError;
    var InvalidResourceId = class _InvalidResourceId extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidResourceId");
      }
      name = "InvalidResourceId";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidResourceId",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidResourceId.prototype);
      }
    };
    exports2.InvalidResourceId = InvalidResourceId;
    var InvalidResourceType = class _InvalidResourceType extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidResourceType");
      }
      name = "InvalidResourceType";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidResourceType",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidResourceType.prototype);
      }
    };
    exports2.InvalidResourceType = InvalidResourceType;
    var TooManyTagsError = class _TooManyTagsError extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "TooManyTagsError");
      }
      name = "TooManyTagsError";
      $fault = "client";
      constructor(opts) {
        super({
          name: "TooManyTagsError",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyTagsError.prototype);
      }
    };
    exports2.TooManyTagsError = TooManyTagsError;
    var TooManyUpdates = class _TooManyUpdates extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "TooManyUpdates");
      }
      name = "TooManyUpdates";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "TooManyUpdates",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TooManyUpdates.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.TooManyUpdates = TooManyUpdates;
    var AlreadyExistsException = class _AlreadyExistsException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "AlreadyExistsException");
      }
      name = "AlreadyExistsException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "AlreadyExistsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AlreadyExistsException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.AlreadyExistsException = AlreadyExistsException;
    var OpsItemConflictException = class _OpsItemConflictException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "OpsItemConflictException");
      }
      name = "OpsItemConflictException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "OpsItemConflictException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _OpsItemConflictException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.OpsItemConflictException = OpsItemConflictException;
    var OpsItemInvalidParameterException = class _OpsItemInvalidParameterException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "OpsItemInvalidParameterException");
      }
      name = "OpsItemInvalidParameterException";
      $fault = "client";
      ParameterNames;
      Message;
      constructor(opts) {
        super({
          name: "OpsItemInvalidParameterException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _OpsItemInvalidParameterException.prototype);
        this.ParameterNames = opts.ParameterNames;
        this.Message = opts.Message;
      }
    };
    exports2.OpsItemInvalidParameterException = OpsItemInvalidParameterException;
    var OpsItemLimitExceededException = class _OpsItemLimitExceededException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "OpsItemLimitExceededException");
      }
      name = "OpsItemLimitExceededException";
      $fault = "client";
      ResourceTypes;
      Limit;
      LimitType;
      Message;
      constructor(opts) {
        super({
          name: "OpsItemLimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _OpsItemLimitExceededException.prototype);
        this.ResourceTypes = opts.ResourceTypes;
        this.Limit = opts.Limit;
        this.LimitType = opts.LimitType;
        this.Message = opts.Message;
      }
    };
    exports2.OpsItemLimitExceededException = OpsItemLimitExceededException;
    var OpsItemNotFoundException = class _OpsItemNotFoundException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "OpsItemNotFoundException");
      }
      name = "OpsItemNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "OpsItemNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _OpsItemNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.OpsItemNotFoundException = OpsItemNotFoundException;
    var OpsItemRelatedItemAlreadyExistsException = class _OpsItemRelatedItemAlreadyExistsException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "OpsItemRelatedItemAlreadyExistsException");
      }
      name = "OpsItemRelatedItemAlreadyExistsException";
      $fault = "client";
      Message;
      ResourceUri;
      OpsItemId;
      constructor(opts) {
        super({
          name: "OpsItemRelatedItemAlreadyExistsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _OpsItemRelatedItemAlreadyExistsException.prototype);
        this.Message = opts.Message;
        this.ResourceUri = opts.ResourceUri;
        this.OpsItemId = opts.OpsItemId;
      }
    };
    exports2.OpsItemRelatedItemAlreadyExistsException = OpsItemRelatedItemAlreadyExistsException;
    var DuplicateInstanceId = class _DuplicateInstanceId extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "DuplicateInstanceId");
      }
      name = "DuplicateInstanceId";
      $fault = "client";
      constructor(opts) {
        super({
          name: "DuplicateInstanceId",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DuplicateInstanceId.prototype);
      }
    };
    exports2.DuplicateInstanceId = DuplicateInstanceId;
    var InvalidCommandId = class _InvalidCommandId extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidCommandId");
      }
      name = "InvalidCommandId";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidCommandId",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidCommandId.prototype);
      }
    };
    exports2.InvalidCommandId = InvalidCommandId;
    var InvalidInstanceId = class _InvalidInstanceId extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidInstanceId");
      }
      name = "InvalidInstanceId";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidInstanceId",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidInstanceId.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidInstanceId = InvalidInstanceId;
    var DoesNotExistException = class _DoesNotExistException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "DoesNotExistException");
      }
      name = "DoesNotExistException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "DoesNotExistException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DoesNotExistException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.DoesNotExistException = DoesNotExistException;
    var InvalidParameters = class _InvalidParameters extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidParameters");
      }
      name = "InvalidParameters";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidParameters",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidParameters.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidParameters = InvalidParameters;
    var AssociationAlreadyExists = class _AssociationAlreadyExists extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "AssociationAlreadyExists");
      }
      name = "AssociationAlreadyExists";
      $fault = "client";
      constructor(opts) {
        super({
          name: "AssociationAlreadyExists",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AssociationAlreadyExists.prototype);
      }
    };
    exports2.AssociationAlreadyExists = AssociationAlreadyExists;
    var AssociationLimitExceeded = class _AssociationLimitExceeded extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "AssociationLimitExceeded");
      }
      name = "AssociationLimitExceeded";
      $fault = "client";
      constructor(opts) {
        super({
          name: "AssociationLimitExceeded",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AssociationLimitExceeded.prototype);
      }
    };
    exports2.AssociationLimitExceeded = AssociationLimitExceeded;
    var InvalidDocument = class _InvalidDocument extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidDocument");
      }
      name = "InvalidDocument";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidDocument",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidDocument.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidDocument = InvalidDocument;
    var InvalidDocumentVersion = class _InvalidDocumentVersion extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidDocumentVersion");
      }
      name = "InvalidDocumentVersion";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidDocumentVersion",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidDocumentVersion.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidDocumentVersion = InvalidDocumentVersion;
    var InvalidOutputLocation = class _InvalidOutputLocation extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidOutputLocation");
      }
      name = "InvalidOutputLocation";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidOutputLocation",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidOutputLocation.prototype);
      }
    };
    exports2.InvalidOutputLocation = InvalidOutputLocation;
    var InvalidSchedule = class _InvalidSchedule extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidSchedule");
      }
      name = "InvalidSchedule";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidSchedule",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidSchedule.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidSchedule = InvalidSchedule;
    var InvalidTag = class _InvalidTag extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidTag");
      }
      name = "InvalidTag";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidTag",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidTag.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidTag = InvalidTag;
    var InvalidTarget = class _InvalidTarget extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidTarget");
      }
      name = "InvalidTarget";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidTarget",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidTarget.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidTarget = InvalidTarget;
    var InvalidTargetMaps = class _InvalidTargetMaps extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidTargetMaps");
      }
      name = "InvalidTargetMaps";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidTargetMaps",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidTargetMaps.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidTargetMaps = InvalidTargetMaps;
    var UnsupportedPlatformType = class _UnsupportedPlatformType extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "UnsupportedPlatformType");
      }
      name = "UnsupportedPlatformType";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "UnsupportedPlatformType",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnsupportedPlatformType.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.UnsupportedPlatformType = UnsupportedPlatformType;
    var DocumentAlreadyExists = class _DocumentAlreadyExists extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "DocumentAlreadyExists");
      }
      name = "DocumentAlreadyExists";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "DocumentAlreadyExists",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DocumentAlreadyExists.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.DocumentAlreadyExists = DocumentAlreadyExists;
    var DocumentLimitExceeded = class _DocumentLimitExceeded extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "DocumentLimitExceeded");
      }
      name = "DocumentLimitExceeded";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "DocumentLimitExceeded",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DocumentLimitExceeded.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.DocumentLimitExceeded = DocumentLimitExceeded;
    var InvalidDocumentContent = class _InvalidDocumentContent extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidDocumentContent");
      }
      name = "InvalidDocumentContent";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidDocumentContent",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidDocumentContent.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidDocumentContent = InvalidDocumentContent;
    var InvalidDocumentSchemaVersion = class _InvalidDocumentSchemaVersion extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidDocumentSchemaVersion");
      }
      name = "InvalidDocumentSchemaVersion";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidDocumentSchemaVersion",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidDocumentSchemaVersion.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidDocumentSchemaVersion = InvalidDocumentSchemaVersion;
    var MaxDocumentSizeExceeded = class _MaxDocumentSizeExceeded extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "MaxDocumentSizeExceeded");
      }
      name = "MaxDocumentSizeExceeded";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "MaxDocumentSizeExceeded",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _MaxDocumentSizeExceeded.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.MaxDocumentSizeExceeded = MaxDocumentSizeExceeded;
    var NoLongerSupportedException = class _NoLongerSupportedException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "NoLongerSupportedException");
      }
      name = "NoLongerSupportedException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "NoLongerSupportedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _NoLongerSupportedException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.NoLongerSupportedException = NoLongerSupportedException;
    var IdempotentParameterMismatch = class _IdempotentParameterMismatch extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "IdempotentParameterMismatch");
      }
      name = "IdempotentParameterMismatch";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "IdempotentParameterMismatch",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _IdempotentParameterMismatch.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.IdempotentParameterMismatch = IdempotentParameterMismatch;
    var ResourceLimitExceededException = class _ResourceLimitExceededException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "ResourceLimitExceededException");
      }
      name = "ResourceLimitExceededException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "ResourceLimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceLimitExceededException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ResourceLimitExceededException = ResourceLimitExceededException;
    var OpsItemAccessDeniedException = class _OpsItemAccessDeniedException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "OpsItemAccessDeniedException");
      }
      name = "OpsItemAccessDeniedException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "OpsItemAccessDeniedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _OpsItemAccessDeniedException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.OpsItemAccessDeniedException = OpsItemAccessDeniedException;
    var OpsItemAlreadyExistsException = class _OpsItemAlreadyExistsException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "OpsItemAlreadyExistsException");
      }
      name = "OpsItemAlreadyExistsException";
      $fault = "client";
      Message;
      OpsItemId;
      constructor(opts) {
        super({
          name: "OpsItemAlreadyExistsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _OpsItemAlreadyExistsException.prototype);
        this.Message = opts.Message;
        this.OpsItemId = opts.OpsItemId;
      }
    };
    exports2.OpsItemAlreadyExistsException = OpsItemAlreadyExistsException;
    var OpsMetadataAlreadyExistsException = class _OpsMetadataAlreadyExistsException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "OpsMetadataAlreadyExistsException");
      }
      name = "OpsMetadataAlreadyExistsException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "OpsMetadataAlreadyExistsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _OpsMetadataAlreadyExistsException.prototype);
      }
    };
    exports2.OpsMetadataAlreadyExistsException = OpsMetadataAlreadyExistsException;
    var OpsMetadataInvalidArgumentException = class _OpsMetadataInvalidArgumentException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "OpsMetadataInvalidArgumentException");
      }
      name = "OpsMetadataInvalidArgumentException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "OpsMetadataInvalidArgumentException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _OpsMetadataInvalidArgumentException.prototype);
      }
    };
    exports2.OpsMetadataInvalidArgumentException = OpsMetadataInvalidArgumentException;
    var OpsMetadataLimitExceededException = class _OpsMetadataLimitExceededException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "OpsMetadataLimitExceededException");
      }
      name = "OpsMetadataLimitExceededException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "OpsMetadataLimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _OpsMetadataLimitExceededException.prototype);
      }
    };
    exports2.OpsMetadataLimitExceededException = OpsMetadataLimitExceededException;
    var OpsMetadataTooManyUpdatesException = class _OpsMetadataTooManyUpdatesException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "OpsMetadataTooManyUpdatesException");
      }
      name = "OpsMetadataTooManyUpdatesException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "OpsMetadataTooManyUpdatesException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _OpsMetadataTooManyUpdatesException.prototype);
      }
    };
    exports2.OpsMetadataTooManyUpdatesException = OpsMetadataTooManyUpdatesException;
    var ResourceDataSyncAlreadyExistsException = class _ResourceDataSyncAlreadyExistsException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "ResourceDataSyncAlreadyExistsException");
      }
      name = "ResourceDataSyncAlreadyExistsException";
      $fault = "client";
      SyncName;
      constructor(opts) {
        super({
          name: "ResourceDataSyncAlreadyExistsException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceDataSyncAlreadyExistsException.prototype);
        this.SyncName = opts.SyncName;
      }
    };
    exports2.ResourceDataSyncAlreadyExistsException = ResourceDataSyncAlreadyExistsException;
    var ResourceDataSyncCountExceededException = class _ResourceDataSyncCountExceededException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "ResourceDataSyncCountExceededException");
      }
      name = "ResourceDataSyncCountExceededException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "ResourceDataSyncCountExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceDataSyncCountExceededException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ResourceDataSyncCountExceededException = ResourceDataSyncCountExceededException;
    var ResourceDataSyncInvalidConfigurationException = class _ResourceDataSyncInvalidConfigurationException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "ResourceDataSyncInvalidConfigurationException");
      }
      name = "ResourceDataSyncInvalidConfigurationException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "ResourceDataSyncInvalidConfigurationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceDataSyncInvalidConfigurationException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ResourceDataSyncInvalidConfigurationException = ResourceDataSyncInvalidConfigurationException;
    var InvalidActivation = class _InvalidActivation extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidActivation");
      }
      name = "InvalidActivation";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidActivation",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidActivation.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidActivation = InvalidActivation;
    var InvalidActivationId = class _InvalidActivationId extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidActivationId");
      }
      name = "InvalidActivationId";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidActivationId",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidActivationId.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidActivationId = InvalidActivationId;
    var AssociationDoesNotExist = class _AssociationDoesNotExist extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "AssociationDoesNotExist");
      }
      name = "AssociationDoesNotExist";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "AssociationDoesNotExist",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AssociationDoesNotExist.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.AssociationDoesNotExist = AssociationDoesNotExist;
    var AssociatedInstances = class _AssociatedInstances extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "AssociatedInstances");
      }
      name = "AssociatedInstances";
      $fault = "client";
      constructor(opts) {
        super({
          name: "AssociatedInstances",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AssociatedInstances.prototype);
      }
    };
    exports2.AssociatedInstances = AssociatedInstances;
    var InvalidDocumentOperation = class _InvalidDocumentOperation extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidDocumentOperation");
      }
      name = "InvalidDocumentOperation";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidDocumentOperation",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidDocumentOperation.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidDocumentOperation = InvalidDocumentOperation;
    var InvalidDeleteInventoryParametersException = class _InvalidDeleteInventoryParametersException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidDeleteInventoryParametersException");
      }
      name = "InvalidDeleteInventoryParametersException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidDeleteInventoryParametersException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidDeleteInventoryParametersException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidDeleteInventoryParametersException = InvalidDeleteInventoryParametersException;
    var InvalidInventoryRequestException = class _InvalidInventoryRequestException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidInventoryRequestException");
      }
      name = "InvalidInventoryRequestException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidInventoryRequestException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidInventoryRequestException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidInventoryRequestException = InvalidInventoryRequestException;
    var InvalidOptionException = class _InvalidOptionException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidOptionException");
      }
      name = "InvalidOptionException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidOptionException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidOptionException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidOptionException = InvalidOptionException;
    var InvalidTypeNameException = class _InvalidTypeNameException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidTypeNameException");
      }
      name = "InvalidTypeNameException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidTypeNameException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidTypeNameException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidTypeNameException = InvalidTypeNameException;
    var OpsMetadataNotFoundException = class _OpsMetadataNotFoundException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "OpsMetadataNotFoundException");
      }
      name = "OpsMetadataNotFoundException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "OpsMetadataNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _OpsMetadataNotFoundException.prototype);
      }
    };
    exports2.OpsMetadataNotFoundException = OpsMetadataNotFoundException;
    var ParameterNotFound = class _ParameterNotFound extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "ParameterNotFound");
      }
      name = "ParameterNotFound";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ParameterNotFound",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ParameterNotFound.prototype);
      }
    };
    exports2.ParameterNotFound = ParameterNotFound;
    var ResourceInUseException = class _ResourceInUseException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "ResourceInUseException");
      }
      name = "ResourceInUseException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "ResourceInUseException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceInUseException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ResourceInUseException = ResourceInUseException;
    var ResourceDataSyncNotFoundException = class _ResourceDataSyncNotFoundException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "ResourceDataSyncNotFoundException");
      }
      name = "ResourceDataSyncNotFoundException";
      $fault = "client";
      SyncName;
      SyncType;
      Message;
      constructor(opts) {
        super({
          name: "ResourceDataSyncNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceDataSyncNotFoundException.prototype);
        this.SyncName = opts.SyncName;
        this.SyncType = opts.SyncType;
        this.Message = opts.Message;
      }
    };
    exports2.ResourceDataSyncNotFoundException = ResourceDataSyncNotFoundException;
    var MalformedResourcePolicyDocumentException = class _MalformedResourcePolicyDocumentException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "MalformedResourcePolicyDocumentException");
      }
      name = "MalformedResourcePolicyDocumentException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "MalformedResourcePolicyDocumentException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _MalformedResourcePolicyDocumentException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.MalformedResourcePolicyDocumentException = MalformedResourcePolicyDocumentException;
    var ResourceNotFoundException12 = class _ResourceNotFoundException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "ResourceNotFoundException");
      }
      name = "ResourceNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "ResourceNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ResourceNotFoundException = ResourceNotFoundException12;
    var ResourcePolicyConflictException = class _ResourcePolicyConflictException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "ResourcePolicyConflictException");
      }
      name = "ResourcePolicyConflictException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "ResourcePolicyConflictException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourcePolicyConflictException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ResourcePolicyConflictException = ResourcePolicyConflictException;
    var ResourcePolicyInvalidParameterException = class _ResourcePolicyInvalidParameterException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "ResourcePolicyInvalidParameterException");
      }
      name = "ResourcePolicyInvalidParameterException";
      $fault = "client";
      ParameterNames;
      Message;
      constructor(opts) {
        super({
          name: "ResourcePolicyInvalidParameterException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourcePolicyInvalidParameterException.prototype);
        this.ParameterNames = opts.ParameterNames;
        this.Message = opts.Message;
      }
    };
    exports2.ResourcePolicyInvalidParameterException = ResourcePolicyInvalidParameterException;
    var ResourcePolicyNotFoundException = class _ResourcePolicyNotFoundException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "ResourcePolicyNotFoundException");
      }
      name = "ResourcePolicyNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "ResourcePolicyNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourcePolicyNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ResourcePolicyNotFoundException = ResourcePolicyNotFoundException;
    var TargetInUseException = class _TargetInUseException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "TargetInUseException");
      }
      name = "TargetInUseException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "TargetInUseException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TargetInUseException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.TargetInUseException = TargetInUseException;
    var InvalidFilter = class _InvalidFilter extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidFilter");
      }
      name = "InvalidFilter";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidFilter",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidFilter.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidFilter = InvalidFilter;
    var InvalidNextToken = class _InvalidNextToken extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidNextToken");
      }
      name = "InvalidNextToken";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidNextToken",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidNextToken.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidNextToken = InvalidNextToken;
    var InvalidAssociationVersion = class _InvalidAssociationVersion extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidAssociationVersion");
      }
      name = "InvalidAssociationVersion";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidAssociationVersion",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidAssociationVersion.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidAssociationVersion = InvalidAssociationVersion;
    var AssociationExecutionDoesNotExist = class _AssociationExecutionDoesNotExist extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "AssociationExecutionDoesNotExist");
      }
      name = "AssociationExecutionDoesNotExist";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "AssociationExecutionDoesNotExist",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AssociationExecutionDoesNotExist.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.AssociationExecutionDoesNotExist = AssociationExecutionDoesNotExist;
    var InvalidFilterKey = class _InvalidFilterKey extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidFilterKey");
      }
      name = "InvalidFilterKey";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidFilterKey",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidFilterKey.prototype);
      }
    };
    exports2.InvalidFilterKey = InvalidFilterKey;
    var InvalidFilterValue = class _InvalidFilterValue extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidFilterValue");
      }
      name = "InvalidFilterValue";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidFilterValue",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidFilterValue.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidFilterValue = InvalidFilterValue;
    var AutomationExecutionNotFoundException = class _AutomationExecutionNotFoundException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "AutomationExecutionNotFoundException");
      }
      name = "AutomationExecutionNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "AutomationExecutionNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AutomationExecutionNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.AutomationExecutionNotFoundException = AutomationExecutionNotFoundException;
    var InvalidPermissionType = class _InvalidPermissionType extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidPermissionType");
      }
      name = "InvalidPermissionType";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidPermissionType",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidPermissionType.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidPermissionType = InvalidPermissionType;
    var UnsupportedOperatingSystem = class _UnsupportedOperatingSystem extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "UnsupportedOperatingSystem");
      }
      name = "UnsupportedOperatingSystem";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "UnsupportedOperatingSystem",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnsupportedOperatingSystem.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.UnsupportedOperatingSystem = UnsupportedOperatingSystem;
    var InvalidInstanceInformationFilterValue = class _InvalidInstanceInformationFilterValue extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidInstanceInformationFilterValue");
      }
      name = "InvalidInstanceInformationFilterValue";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidInstanceInformationFilterValue",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidInstanceInformationFilterValue.prototype);
      }
    };
    exports2.InvalidInstanceInformationFilterValue = InvalidInstanceInformationFilterValue;
    var InvalidInstancePropertyFilterValue = class _InvalidInstancePropertyFilterValue extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidInstancePropertyFilterValue");
      }
      name = "InvalidInstancePropertyFilterValue";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidInstancePropertyFilterValue",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidInstancePropertyFilterValue.prototype);
      }
    };
    exports2.InvalidInstancePropertyFilterValue = InvalidInstancePropertyFilterValue;
    var InvalidDeletionIdException = class _InvalidDeletionIdException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidDeletionIdException");
      }
      name = "InvalidDeletionIdException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidDeletionIdException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidDeletionIdException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidDeletionIdException = InvalidDeletionIdException;
    var InvalidFilterOption = class _InvalidFilterOption extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidFilterOption");
      }
      name = "InvalidFilterOption";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidFilterOption",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidFilterOption.prototype);
      }
    };
    exports2.InvalidFilterOption = InvalidFilterOption;
    var OpsItemRelatedItemAssociationNotFoundException = class _OpsItemRelatedItemAssociationNotFoundException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "OpsItemRelatedItemAssociationNotFoundException");
      }
      name = "OpsItemRelatedItemAssociationNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "OpsItemRelatedItemAssociationNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _OpsItemRelatedItemAssociationNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.OpsItemRelatedItemAssociationNotFoundException = OpsItemRelatedItemAssociationNotFoundException;
    var ThrottlingException = class _ThrottlingException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "ThrottlingException");
      }
      name = "ThrottlingException";
      $fault = "client";
      Message;
      QuotaCode;
      ServiceCode;
      constructor(opts) {
        super({
          name: "ThrottlingException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ThrottlingException.prototype);
        this.Message = opts.Message;
        this.QuotaCode = opts.QuotaCode;
        this.ServiceCode = opts.ServiceCode;
      }
    };
    exports2.ThrottlingException = ThrottlingException;
    var ValidationException10 = class _ValidationException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "ValidationException");
      }
      name = "ValidationException";
      $fault = "client";
      Message;
      ReasonCode;
      constructor(opts) {
        super({
          name: "ValidationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ValidationException.prototype);
        this.Message = opts.Message;
        this.ReasonCode = opts.ReasonCode;
      }
    };
    exports2.ValidationException = ValidationException10;
    var InvalidDocumentType = class _InvalidDocumentType extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidDocumentType");
      }
      name = "InvalidDocumentType";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidDocumentType",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidDocumentType.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidDocumentType = InvalidDocumentType;
    var UnsupportedCalendarException = class _UnsupportedCalendarException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "UnsupportedCalendarException");
      }
      name = "UnsupportedCalendarException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "UnsupportedCalendarException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnsupportedCalendarException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.UnsupportedCalendarException = UnsupportedCalendarException;
    var InvalidPluginName = class _InvalidPluginName extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidPluginName");
      }
      name = "InvalidPluginName";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidPluginName",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidPluginName.prototype);
      }
    };
    exports2.InvalidPluginName = InvalidPluginName;
    var InvocationDoesNotExist = class _InvocationDoesNotExist extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvocationDoesNotExist");
      }
      name = "InvocationDoesNotExist";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvocationDoesNotExist",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvocationDoesNotExist.prototype);
      }
    };
    exports2.InvocationDoesNotExist = InvocationDoesNotExist;
    var UnsupportedFeatureRequiredException = class _UnsupportedFeatureRequiredException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "UnsupportedFeatureRequiredException");
      }
      name = "UnsupportedFeatureRequiredException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "UnsupportedFeatureRequiredException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnsupportedFeatureRequiredException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.UnsupportedFeatureRequiredException = UnsupportedFeatureRequiredException;
    var InvalidAggregatorException = class _InvalidAggregatorException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidAggregatorException");
      }
      name = "InvalidAggregatorException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidAggregatorException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidAggregatorException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidAggregatorException = InvalidAggregatorException;
    var InvalidInventoryGroupException = class _InvalidInventoryGroupException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidInventoryGroupException");
      }
      name = "InvalidInventoryGroupException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidInventoryGroupException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidInventoryGroupException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidInventoryGroupException = InvalidInventoryGroupException;
    var InvalidResultAttributeException = class _InvalidResultAttributeException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidResultAttributeException");
      }
      name = "InvalidResultAttributeException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidResultAttributeException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidResultAttributeException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidResultAttributeException = InvalidResultAttributeException;
    var InvalidKeyId = class _InvalidKeyId extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidKeyId");
      }
      name = "InvalidKeyId";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidKeyId",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidKeyId.prototype);
      }
    };
    exports2.InvalidKeyId = InvalidKeyId;
    var ParameterVersionNotFound = class _ParameterVersionNotFound extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "ParameterVersionNotFound");
      }
      name = "ParameterVersionNotFound";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ParameterVersionNotFound",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ParameterVersionNotFound.prototype);
      }
    };
    exports2.ParameterVersionNotFound = ParameterVersionNotFound;
    var ServiceSettingNotFound = class _ServiceSettingNotFound extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "ServiceSettingNotFound");
      }
      name = "ServiceSettingNotFound";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "ServiceSettingNotFound",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ServiceSettingNotFound.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ServiceSettingNotFound = ServiceSettingNotFound;
    var ParameterVersionLabelLimitExceeded = class _ParameterVersionLabelLimitExceeded extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "ParameterVersionLabelLimitExceeded");
      }
      name = "ParameterVersionLabelLimitExceeded";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ParameterVersionLabelLimitExceeded",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ParameterVersionLabelLimitExceeded.prototype);
      }
    };
    exports2.ParameterVersionLabelLimitExceeded = ParameterVersionLabelLimitExceeded;
    var UnsupportedOperationException = class _UnsupportedOperationException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "UnsupportedOperationException");
      }
      name = "UnsupportedOperationException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "UnsupportedOperationException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnsupportedOperationException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.UnsupportedOperationException = UnsupportedOperationException;
    var DocumentPermissionLimit = class _DocumentPermissionLimit extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "DocumentPermissionLimit");
      }
      name = "DocumentPermissionLimit";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "DocumentPermissionLimit",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DocumentPermissionLimit.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.DocumentPermissionLimit = DocumentPermissionLimit;
    var ComplianceTypeCountLimitExceededException = class _ComplianceTypeCountLimitExceededException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "ComplianceTypeCountLimitExceededException");
      }
      name = "ComplianceTypeCountLimitExceededException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "ComplianceTypeCountLimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ComplianceTypeCountLimitExceededException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ComplianceTypeCountLimitExceededException = ComplianceTypeCountLimitExceededException;
    var InvalidItemContentException = class _InvalidItemContentException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidItemContentException");
      }
      name = "InvalidItemContentException";
      $fault = "client";
      TypeName;
      Message;
      constructor(opts) {
        super({
          name: "InvalidItemContentException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidItemContentException.prototype);
        this.TypeName = opts.TypeName;
        this.Message = opts.Message;
      }
    };
    exports2.InvalidItemContentException = InvalidItemContentException;
    var ItemSizeLimitExceededException = class _ItemSizeLimitExceededException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "ItemSizeLimitExceededException");
      }
      name = "ItemSizeLimitExceededException";
      $fault = "client";
      TypeName;
      Message;
      constructor(opts) {
        super({
          name: "ItemSizeLimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ItemSizeLimitExceededException.prototype);
        this.TypeName = opts.TypeName;
        this.Message = opts.Message;
      }
    };
    exports2.ItemSizeLimitExceededException = ItemSizeLimitExceededException;
    var TotalSizeLimitExceededException = class _TotalSizeLimitExceededException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "TotalSizeLimitExceededException");
      }
      name = "TotalSizeLimitExceededException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "TotalSizeLimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TotalSizeLimitExceededException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.TotalSizeLimitExceededException = TotalSizeLimitExceededException;
    var CustomSchemaCountLimitExceededException = class _CustomSchemaCountLimitExceededException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "CustomSchemaCountLimitExceededException");
      }
      name = "CustomSchemaCountLimitExceededException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "CustomSchemaCountLimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _CustomSchemaCountLimitExceededException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.CustomSchemaCountLimitExceededException = CustomSchemaCountLimitExceededException;
    var InvalidInventoryItemContextException = class _InvalidInventoryItemContextException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidInventoryItemContextException");
      }
      name = "InvalidInventoryItemContextException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidInventoryItemContextException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidInventoryItemContextException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidInventoryItemContextException = InvalidInventoryItemContextException;
    var ItemContentMismatchException = class _ItemContentMismatchException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "ItemContentMismatchException");
      }
      name = "ItemContentMismatchException";
      $fault = "client";
      TypeName;
      Message;
      constructor(opts) {
        super({
          name: "ItemContentMismatchException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ItemContentMismatchException.prototype);
        this.TypeName = opts.TypeName;
        this.Message = opts.Message;
      }
    };
    exports2.ItemContentMismatchException = ItemContentMismatchException;
    var SubTypeCountLimitExceededException = class _SubTypeCountLimitExceededException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "SubTypeCountLimitExceededException");
      }
      name = "SubTypeCountLimitExceededException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "SubTypeCountLimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _SubTypeCountLimitExceededException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.SubTypeCountLimitExceededException = SubTypeCountLimitExceededException;
    var UnsupportedInventoryItemContextException = class _UnsupportedInventoryItemContextException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "UnsupportedInventoryItemContextException");
      }
      name = "UnsupportedInventoryItemContextException";
      $fault = "client";
      TypeName;
      Message;
      constructor(opts) {
        super({
          name: "UnsupportedInventoryItemContextException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnsupportedInventoryItemContextException.prototype);
        this.TypeName = opts.TypeName;
        this.Message = opts.Message;
      }
    };
    exports2.UnsupportedInventoryItemContextException = UnsupportedInventoryItemContextException;
    var UnsupportedInventorySchemaVersionException = class _UnsupportedInventorySchemaVersionException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "UnsupportedInventorySchemaVersionException");
      }
      name = "UnsupportedInventorySchemaVersionException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "UnsupportedInventorySchemaVersionException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnsupportedInventorySchemaVersionException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.UnsupportedInventorySchemaVersionException = UnsupportedInventorySchemaVersionException;
    var HierarchyLevelLimitExceededException = class _HierarchyLevelLimitExceededException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "HierarchyLevelLimitExceededException");
      }
      name = "HierarchyLevelLimitExceededException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "HierarchyLevelLimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _HierarchyLevelLimitExceededException.prototype);
      }
    };
    exports2.HierarchyLevelLimitExceededException = HierarchyLevelLimitExceededException;
    var HierarchyTypeMismatchException = class _HierarchyTypeMismatchException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "HierarchyTypeMismatchException");
      }
      name = "HierarchyTypeMismatchException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "HierarchyTypeMismatchException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _HierarchyTypeMismatchException.prototype);
      }
    };
    exports2.HierarchyTypeMismatchException = HierarchyTypeMismatchException;
    var IncompatiblePolicyException = class _IncompatiblePolicyException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "IncompatiblePolicyException");
      }
      name = "IncompatiblePolicyException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "IncompatiblePolicyException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _IncompatiblePolicyException.prototype);
      }
    };
    exports2.IncompatiblePolicyException = IncompatiblePolicyException;
    var InvalidAllowedPatternException = class _InvalidAllowedPatternException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidAllowedPatternException");
      }
      name = "InvalidAllowedPatternException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidAllowedPatternException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidAllowedPatternException.prototype);
      }
    };
    exports2.InvalidAllowedPatternException = InvalidAllowedPatternException;
    var InvalidPolicyAttributeException = class _InvalidPolicyAttributeException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidPolicyAttributeException");
      }
      name = "InvalidPolicyAttributeException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidPolicyAttributeException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidPolicyAttributeException.prototype);
      }
    };
    exports2.InvalidPolicyAttributeException = InvalidPolicyAttributeException;
    var InvalidPolicyTypeException = class _InvalidPolicyTypeException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidPolicyTypeException");
      }
      name = "InvalidPolicyTypeException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidPolicyTypeException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidPolicyTypeException.prototype);
      }
    };
    exports2.InvalidPolicyTypeException = InvalidPolicyTypeException;
    var ParameterAlreadyExists = class _ParameterAlreadyExists extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "ParameterAlreadyExists");
      }
      name = "ParameterAlreadyExists";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ParameterAlreadyExists",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ParameterAlreadyExists.prototype);
      }
    };
    exports2.ParameterAlreadyExists = ParameterAlreadyExists;
    var ParameterLimitExceeded = class _ParameterLimitExceeded extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "ParameterLimitExceeded");
      }
      name = "ParameterLimitExceeded";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ParameterLimitExceeded",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ParameterLimitExceeded.prototype);
      }
    };
    exports2.ParameterLimitExceeded = ParameterLimitExceeded;
    var ParameterMaxVersionLimitExceeded = class _ParameterMaxVersionLimitExceeded extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "ParameterMaxVersionLimitExceeded");
      }
      name = "ParameterMaxVersionLimitExceeded";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ParameterMaxVersionLimitExceeded",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ParameterMaxVersionLimitExceeded.prototype);
      }
    };
    exports2.ParameterMaxVersionLimitExceeded = ParameterMaxVersionLimitExceeded;
    var ParameterPatternMismatchException = class _ParameterPatternMismatchException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "ParameterPatternMismatchException");
      }
      name = "ParameterPatternMismatchException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "ParameterPatternMismatchException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ParameterPatternMismatchException.prototype);
      }
    };
    exports2.ParameterPatternMismatchException = ParameterPatternMismatchException;
    var PoliciesLimitExceededException = class _PoliciesLimitExceededException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "PoliciesLimitExceededException");
      }
      name = "PoliciesLimitExceededException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "PoliciesLimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _PoliciesLimitExceededException.prototype);
      }
    };
    exports2.PoliciesLimitExceededException = PoliciesLimitExceededException;
    var UnsupportedParameterType = class _UnsupportedParameterType extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "UnsupportedParameterType");
      }
      name = "UnsupportedParameterType";
      $fault = "client";
      constructor(opts) {
        super({
          name: "UnsupportedParameterType",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _UnsupportedParameterType.prototype);
      }
    };
    exports2.UnsupportedParameterType = UnsupportedParameterType;
    var ResourcePolicyLimitExceededException = class _ResourcePolicyLimitExceededException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "ResourcePolicyLimitExceededException");
      }
      name = "ResourcePolicyLimitExceededException";
      $fault = "client";
      Limit;
      LimitType;
      Message;
      constructor(opts) {
        super({
          name: "ResourcePolicyLimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourcePolicyLimitExceededException.prototype);
        this.Limit = opts.Limit;
        this.LimitType = opts.LimitType;
        this.Message = opts.Message;
      }
    };
    exports2.ResourcePolicyLimitExceededException = ResourcePolicyLimitExceededException;
    var FeatureNotAvailableException = class _FeatureNotAvailableException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "FeatureNotAvailableException");
      }
      name = "FeatureNotAvailableException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "FeatureNotAvailableException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _FeatureNotAvailableException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.FeatureNotAvailableException = FeatureNotAvailableException;
    var AutomationStepNotFoundException = class _AutomationStepNotFoundException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "AutomationStepNotFoundException");
      }
      name = "AutomationStepNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "AutomationStepNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AutomationStepNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.AutomationStepNotFoundException = AutomationStepNotFoundException;
    var InvalidAutomationSignalException = class _InvalidAutomationSignalException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidAutomationSignalException");
      }
      name = "InvalidAutomationSignalException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidAutomationSignalException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidAutomationSignalException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidAutomationSignalException = InvalidAutomationSignalException;
    var InvalidNotificationConfig = class _InvalidNotificationConfig extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidNotificationConfig");
      }
      name = "InvalidNotificationConfig";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidNotificationConfig",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidNotificationConfig.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidNotificationConfig = InvalidNotificationConfig;
    var InvalidOutputFolder = class _InvalidOutputFolder extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidOutputFolder");
      }
      name = "InvalidOutputFolder";
      $fault = "client";
      constructor(opts) {
        super({
          name: "InvalidOutputFolder",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidOutputFolder.prototype);
      }
    };
    exports2.InvalidOutputFolder = InvalidOutputFolder;
    var InvalidRole = class _InvalidRole extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidRole");
      }
      name = "InvalidRole";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidRole",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidRole.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidRole = InvalidRole;
    var ServiceQuotaExceededException = class _ServiceQuotaExceededException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "ServiceQuotaExceededException");
      }
      name = "ServiceQuotaExceededException";
      $fault = "client";
      Message;
      ResourceId;
      ResourceType;
      QuotaCode;
      ServiceCode;
      constructor(opts) {
        super({
          name: "ServiceQuotaExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ServiceQuotaExceededException.prototype);
        this.Message = opts.Message;
        this.ResourceId = opts.ResourceId;
        this.ResourceType = opts.ResourceType;
        this.QuotaCode = opts.QuotaCode;
        this.ServiceCode = opts.ServiceCode;
      }
    };
    exports2.ServiceQuotaExceededException = ServiceQuotaExceededException;
    var InvalidAssociation = class _InvalidAssociation extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidAssociation");
      }
      name = "InvalidAssociation";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidAssociation",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidAssociation.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidAssociation = InvalidAssociation;
    var AutomationDefinitionNotFoundException = class _AutomationDefinitionNotFoundException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "AutomationDefinitionNotFoundException");
      }
      name = "AutomationDefinitionNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "AutomationDefinitionNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AutomationDefinitionNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.AutomationDefinitionNotFoundException = AutomationDefinitionNotFoundException;
    var AutomationDefinitionVersionNotFoundException = class _AutomationDefinitionVersionNotFoundException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "AutomationDefinitionVersionNotFoundException");
      }
      name = "AutomationDefinitionVersionNotFoundException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "AutomationDefinitionVersionNotFoundException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AutomationDefinitionVersionNotFoundException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.AutomationDefinitionVersionNotFoundException = AutomationDefinitionVersionNotFoundException;
    var AutomationExecutionLimitExceededException = class _AutomationExecutionLimitExceededException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "AutomationExecutionLimitExceededException");
      }
      name = "AutomationExecutionLimitExceededException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "AutomationExecutionLimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AutomationExecutionLimitExceededException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.AutomationExecutionLimitExceededException = AutomationExecutionLimitExceededException;
    var InvalidAutomationExecutionParametersException = class _InvalidAutomationExecutionParametersException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidAutomationExecutionParametersException");
      }
      name = "InvalidAutomationExecutionParametersException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidAutomationExecutionParametersException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidAutomationExecutionParametersException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidAutomationExecutionParametersException = InvalidAutomationExecutionParametersException;
    var AutomationDefinitionNotApprovedException = class _AutomationDefinitionNotApprovedException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "AutomationDefinitionNotApprovedException");
      }
      name = "AutomationDefinitionNotApprovedException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "AutomationDefinitionNotApprovedException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AutomationDefinitionNotApprovedException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.AutomationDefinitionNotApprovedException = AutomationDefinitionNotApprovedException;
    var TargetNotConnected = class _TargetNotConnected extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "TargetNotConnected");
      }
      name = "TargetNotConnected";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "TargetNotConnected",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _TargetNotConnected.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.TargetNotConnected = TargetNotConnected;
    var InvalidAutomationStatusUpdateException = class _InvalidAutomationStatusUpdateException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidAutomationStatusUpdateException");
      }
      name = "InvalidAutomationStatusUpdateException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidAutomationStatusUpdateException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidAutomationStatusUpdateException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidAutomationStatusUpdateException = InvalidAutomationStatusUpdateException;
    var AssociationVersionLimitExceeded = class _AssociationVersionLimitExceeded extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "AssociationVersionLimitExceeded");
      }
      name = "AssociationVersionLimitExceeded";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "AssociationVersionLimitExceeded",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _AssociationVersionLimitExceeded.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.AssociationVersionLimitExceeded = AssociationVersionLimitExceeded;
    var InvalidUpdate = class _InvalidUpdate extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "InvalidUpdate");
      }
      name = "InvalidUpdate";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "InvalidUpdate",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _InvalidUpdate.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.InvalidUpdate = InvalidUpdate;
    var StatusUnchanged = class _StatusUnchanged extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "StatusUnchanged");
      }
      name = "StatusUnchanged";
      $fault = "client";
      constructor(opts) {
        super({
          name: "StatusUnchanged",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _StatusUnchanged.prototype);
      }
    };
    exports2.StatusUnchanged = StatusUnchanged;
    var DocumentVersionLimitExceeded = class _DocumentVersionLimitExceeded extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "DocumentVersionLimitExceeded");
      }
      name = "DocumentVersionLimitExceeded";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "DocumentVersionLimitExceeded",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DocumentVersionLimitExceeded.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.DocumentVersionLimitExceeded = DocumentVersionLimitExceeded;
    var DuplicateDocumentContent = class _DuplicateDocumentContent extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "DuplicateDocumentContent");
      }
      name = "DuplicateDocumentContent";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "DuplicateDocumentContent",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DuplicateDocumentContent.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.DuplicateDocumentContent = DuplicateDocumentContent;
    var DuplicateDocumentVersionName = class _DuplicateDocumentVersionName extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "DuplicateDocumentVersionName");
      }
      name = "DuplicateDocumentVersionName";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "DuplicateDocumentVersionName",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _DuplicateDocumentVersionName.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.DuplicateDocumentVersionName = DuplicateDocumentVersionName;
    var OpsMetadataKeyLimitExceededException = class _OpsMetadataKeyLimitExceededException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "OpsMetadataKeyLimitExceededException");
      }
      name = "OpsMetadataKeyLimitExceededException";
      $fault = "client";
      constructor(opts) {
        super({
          name: "OpsMetadataKeyLimitExceededException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _OpsMetadataKeyLimitExceededException.prototype);
      }
    };
    exports2.OpsMetadataKeyLimitExceededException = OpsMetadataKeyLimitExceededException;
    var ResourceDataSyncConflictException = class _ResourceDataSyncConflictException extends SSMServiceException_1.SSMServiceException {
      static {
        __name(this, "ResourceDataSyncConflictException");
      }
      name = "ResourceDataSyncConflictException";
      $fault = "client";
      Message;
      constructor(opts) {
        super({
          name: "ResourceDataSyncConflictException",
          $fault: "client",
          ...opts
        });
        Object.setPrototypeOf(this, _ResourceDataSyncConflictException.prototype);
        this.Message = opts.Message;
      }
    };
    exports2.ResourceDataSyncConflictException = ResourceDataSyncConflictException;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/dist-cjs/schemas/schemas_0.js
var require_schemas_019 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/dist-cjs/schemas/schemas_0.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.InvalidFilter$ = exports2.InvalidDocumentVersion$ = exports2.InvalidDocumentType$ = exports2.InvalidDocumentSchemaVersion$ = exports2.InvalidDocumentOperation$ = exports2.InvalidDocumentContent$ = exports2.InvalidDocument$ = exports2.InvalidDeletionIdException$ = exports2.InvalidDeleteInventoryParametersException$ = exports2.InvalidCommandId$ = exports2.InvalidAutomationStatusUpdateException$ = exports2.InvalidAutomationSignalException$ = exports2.InvalidAutomationExecutionParametersException$ = exports2.InvalidAssociationVersion$ = exports2.InvalidAssociation$ = exports2.InvalidAllowedPatternException$ = exports2.InvalidAggregatorException$ = exports2.InvalidActivationId$ = exports2.InvalidActivation$ = exports2.InternalServerError$ = exports2.IncompatiblePolicyException$ = exports2.IdempotentParameterMismatch$ = exports2.HierarchyTypeMismatchException$ = exports2.HierarchyLevelLimitExceededException$ = exports2.FeatureNotAvailableException$ = exports2.DuplicateInstanceId$ = exports2.DuplicateDocumentVersionName$ = exports2.DuplicateDocumentContent$ = exports2.DoesNotExistException$ = exports2.DocumentVersionLimitExceeded$ = exports2.DocumentPermissionLimit$ = exports2.DocumentLimitExceeded$ = exports2.DocumentAlreadyExists$ = exports2.CustomSchemaCountLimitExceededException$ = exports2.ComplianceTypeCountLimitExceededException$ = exports2.AutomationStepNotFoundException$ = exports2.AutomationExecutionNotFoundException$ = exports2.AutomationExecutionLimitExceededException$ = exports2.AutomationDefinitionVersionNotFoundException$ = exports2.AutomationDefinitionNotFoundException$ = exports2.AutomationDefinitionNotApprovedException$ = exports2.AssociationVersionLimitExceeded$ = exports2.AssociationLimitExceeded$ = exports2.AssociationExecutionDoesNotExist$ = exports2.AssociationDoesNotExist$ = exports2.AssociationAlreadyExists$ = exports2.AssociatedInstances$ = exports2.AlreadyExistsException$ = exports2.AccessDeniedException$ = exports2.SSMServiceException$ = void 0;
    exports2.OpsMetadataNotFoundException$ = exports2.OpsMetadataLimitExceededException$ = exports2.OpsMetadataKeyLimitExceededException$ = exports2.OpsMetadataInvalidArgumentException$ = exports2.OpsMetadataAlreadyExistsException$ = exports2.OpsItemRelatedItemAssociationNotFoundException$ = exports2.OpsItemRelatedItemAlreadyExistsException$ = exports2.OpsItemNotFoundException$ = exports2.OpsItemLimitExceededException$ = exports2.OpsItemInvalidParameterException$ = exports2.OpsItemConflictException$ = exports2.OpsItemAlreadyExistsException$ = exports2.OpsItemAccessDeniedException$ = exports2.NoLongerSupportedException$ = exports2.MaxDocumentSizeExceeded$ = exports2.MalformedResourcePolicyDocumentException$ = exports2.ItemSizeLimitExceededException$ = exports2.ItemContentMismatchException$ = exports2.InvocationDoesNotExist$ = exports2.InvalidUpdate$ = exports2.InvalidTypeNameException$ = exports2.InvalidTargetMaps$ = exports2.InvalidTarget$ = exports2.InvalidTag$ = exports2.InvalidSchedule$ = exports2.InvalidRole$ = exports2.InvalidResultAttributeException$ = exports2.InvalidResourceType$ = exports2.InvalidResourceId$ = exports2.InvalidPolicyTypeException$ = exports2.InvalidPolicyAttributeException$ = exports2.InvalidPluginName$ = exports2.InvalidPermissionType$ = exports2.InvalidParameters$ = exports2.InvalidOutputLocation$ = exports2.InvalidOutputFolder$ = exports2.InvalidOptionException$ = exports2.InvalidNotificationConfig$ = exports2.InvalidNextToken$ = exports2.InvalidKeyId$ = exports2.InvalidItemContentException$ = exports2.InvalidInventoryRequestException$ = exports2.InvalidInventoryItemContextException$ = exports2.InvalidInventoryGroupException$ = exports2.InvalidInstancePropertyFilterValue$ = exports2.InvalidInstanceInformationFilterValue$ = exports2.InvalidInstanceId$ = exports2.InvalidFilterValue$ = exports2.InvalidFilterOption$ = exports2.InvalidFilterKey$ = void 0;
    exports2.AssociateOpsItemRelatedItemResponse$ = exports2.AssociateOpsItemRelatedItemRequest$ = exports2.AlarmStateInformation$ = exports2.AlarmConfiguration$ = exports2.Alarm$ = exports2.AddTagsToResourceResult$ = exports2.AddTagsToResourceRequest$ = exports2.Activation$ = exports2.AccountSharingInfo$ = exports2.errorTypeRegistries = exports2.ValidationException$ = exports2.UnsupportedPlatformType$ = exports2.UnsupportedParameterType$ = exports2.UnsupportedOperationException$ = exports2.UnsupportedOperatingSystem$ = exports2.UnsupportedInventorySchemaVersionException$ = exports2.UnsupportedInventoryItemContextException$ = exports2.UnsupportedFeatureRequiredException$ = exports2.UnsupportedCalendarException$ = exports2.TotalSizeLimitExceededException$ = exports2.TooManyUpdates$ = exports2.TooManyTagsError$ = exports2.ThrottlingException$ = exports2.TargetNotConnected$ = exports2.TargetInUseException$ = exports2.SubTypeCountLimitExceededException$ = exports2.StatusUnchanged$ = exports2.ServiceSettingNotFound$ = exports2.ServiceQuotaExceededException$ = exports2.ResourcePolicyNotFoundException$ = exports2.ResourcePolicyLimitExceededException$ = exports2.ResourcePolicyInvalidParameterException$ = exports2.ResourcePolicyConflictException$ = exports2.ResourceNotFoundException$ = exports2.ResourceLimitExceededException$ = exports2.ResourceInUseException$ = exports2.ResourceDataSyncNotFoundException$ = exports2.ResourceDataSyncInvalidConfigurationException$ = exports2.ResourceDataSyncCountExceededException$ = exports2.ResourceDataSyncConflictException$ = exports2.ResourceDataSyncAlreadyExistsException$ = exports2.PoliciesLimitExceededException$ = exports2.ParameterVersionNotFound$ = exports2.ParameterVersionLabelLimitExceeded$ = exports2.ParameterPatternMismatchException$ = exports2.ParameterNotFound$ = exports2.ParameterMaxVersionLimitExceeded$ = exports2.ParameterLimitExceeded$ = exports2.ParameterAlreadyExists$ = exports2.OpsMetadataTooManyUpdatesException$ = void 0;
    exports2.CreatePatchBaselineRequest$ = exports2.CreateOpsMetadataResult$ = exports2.CreateOpsMetadataRequest$ = exports2.CreateOpsItemResponse$ = exports2.CreateOpsItemRequest$ = exports2.CreateMaintenanceWindowResult$ = exports2.CreateMaintenanceWindowRequest$ = exports2.CreateDocumentResult$ = exports2.CreateDocumentRequest$ = exports2.CreateAssociationResult$ = exports2.CreateAssociationRequest$ = exports2.CreateAssociationBatchResult$ = exports2.CreateAssociationBatchRequestEntry$ = exports2.CreateAssociationBatchRequest$ = exports2.CreateActivationResult$ = exports2.CreateActivationRequest$ = exports2.CompliantSummary$ = exports2.ComplianceSummaryItem$ = exports2.ComplianceStringFilter$ = exports2.ComplianceItemEntry$ = exports2.ComplianceItem$ = exports2.ComplianceExecutionSummary$ = exports2.CommandPlugin$ = exports2.CommandInvocation$ = exports2.CommandFilter$ = exports2.Command$ = exports2.CloudWatchOutputConfig$ = exports2.CancelMaintenanceWindowExecutionResult$ = exports2.CancelMaintenanceWindowExecutionRequest$ = exports2.CancelCommandResult$ = exports2.CancelCommandRequest$ = exports2.BaselineOverride$ = exports2.AutomationExecutionPreview$ = exports2.AutomationExecutionMetadata$ = exports2.AutomationExecutionInputs$ = exports2.AutomationExecutionFilter$ = exports2.AutomationExecution$ = exports2.AttachmentsSource$ = exports2.AttachmentInformation$ = exports2.AttachmentContent$ = exports2.AssociationVersionInfo$ = exports2.AssociationStatus$ = exports2.AssociationOverview$ = exports2.AssociationFilter$ = exports2.AssociationExecutionTargetsFilter$ = exports2.AssociationExecutionTarget$ = exports2.AssociationExecutionFilter$ = exports2.AssociationExecution$ = exports2.AssociationDescription$ = exports2.Association$ = void 0;
    exports2.DescribeAvailablePatchesRequest$ = exports2.DescribeAutomationStepExecutionsResult$ = exports2.DescribeAutomationStepExecutionsRequest$ = exports2.DescribeAutomationExecutionsResult$ = exports2.DescribeAutomationExecutionsRequest$ = exports2.DescribeAssociationResult$ = exports2.DescribeAssociationRequest$ = exports2.DescribeAssociationExecutionTargetsResult$ = exports2.DescribeAssociationExecutionTargetsRequest$ = exports2.DescribeAssociationExecutionsResult$ = exports2.DescribeAssociationExecutionsRequest$ = exports2.DescribeActivationsResult$ = exports2.DescribeActivationsRequest$ = exports2.DescribeActivationsFilter$ = exports2.DeregisterTaskFromMaintenanceWindowResult$ = exports2.DeregisterTaskFromMaintenanceWindowRequest$ = exports2.DeregisterTargetFromMaintenanceWindowResult$ = exports2.DeregisterTargetFromMaintenanceWindowRequest$ = exports2.DeregisterPatchBaselineForPatchGroupResult$ = exports2.DeregisterPatchBaselineForPatchGroupRequest$ = exports2.DeregisterManagedInstanceResult$ = exports2.DeregisterManagedInstanceRequest$ = exports2.DeleteResourcePolicyResponse$ = exports2.DeleteResourcePolicyRequest$ = exports2.DeleteResourceDataSyncResult$ = exports2.DeleteResourceDataSyncRequest$ = exports2.DeletePatchBaselineResult$ = exports2.DeletePatchBaselineRequest$ = exports2.DeleteParametersResult$ = exports2.DeleteParametersRequest$ = exports2.DeleteParameterResult$ = exports2.DeleteParameterRequest$ = exports2.DeleteOpsMetadataResult$ = exports2.DeleteOpsMetadataRequest$ = exports2.DeleteOpsItemResponse$ = exports2.DeleteOpsItemRequest$ = exports2.DeleteMaintenanceWindowResult$ = exports2.DeleteMaintenanceWindowRequest$ = exports2.DeleteInventoryResult$ = exports2.DeleteInventoryRequest$ = exports2.DeleteDocumentResult$ = exports2.DeleteDocumentRequest$ = exports2.DeleteAssociationResult$ = exports2.DeleteAssociationRequest$ = exports2.DeleteActivationResult$ = exports2.DeleteActivationRequest$ = exports2.Credentials$ = exports2.CreateResourceDataSyncResult$ = exports2.CreateResourceDataSyncRequest$ = exports2.CreatePatchBaselineResult$ = void 0;
    exports2.DescribePatchPropertiesRequest$ = exports2.DescribePatchGroupStateResult$ = exports2.DescribePatchGroupStateRequest$ = exports2.DescribePatchGroupsResult$ = exports2.DescribePatchGroupsRequest$ = exports2.DescribePatchBaselinesResult$ = exports2.DescribePatchBaselinesRequest$ = exports2.DescribeParametersResult$ = exports2.DescribeParametersRequest$ = exports2.DescribeOpsItemsResponse$ = exports2.DescribeOpsItemsRequest$ = exports2.DescribeMaintenanceWindowTasksResult$ = exports2.DescribeMaintenanceWindowTasksRequest$ = exports2.DescribeMaintenanceWindowTargetsResult$ = exports2.DescribeMaintenanceWindowTargetsRequest$ = exports2.DescribeMaintenanceWindowsResult$ = exports2.DescribeMaintenanceWindowsRequest$ = exports2.DescribeMaintenanceWindowsForTargetResult$ = exports2.DescribeMaintenanceWindowsForTargetRequest$ = exports2.DescribeMaintenanceWindowScheduleResult$ = exports2.DescribeMaintenanceWindowScheduleRequest$ = exports2.DescribeMaintenanceWindowExecutionTasksResult$ = exports2.DescribeMaintenanceWindowExecutionTasksRequest$ = exports2.DescribeMaintenanceWindowExecutionTaskInvocationsResult$ = exports2.DescribeMaintenanceWindowExecutionTaskInvocationsRequest$ = exports2.DescribeMaintenanceWindowExecutionsResult$ = exports2.DescribeMaintenanceWindowExecutionsRequest$ = exports2.DescribeInventoryDeletionsResult$ = exports2.DescribeInventoryDeletionsRequest$ = exports2.DescribeInstancePropertiesResult$ = exports2.DescribeInstancePropertiesRequest$ = exports2.DescribeInstancePatchStatesResult$ = exports2.DescribeInstancePatchStatesRequest$ = exports2.DescribeInstancePatchStatesForPatchGroupResult$ = exports2.DescribeInstancePatchStatesForPatchGroupRequest$ = exports2.DescribeInstancePatchesResult$ = exports2.DescribeInstancePatchesRequest$ = exports2.DescribeInstanceInformationResult$ = exports2.DescribeInstanceInformationRequest$ = exports2.DescribeInstanceAssociationsStatusResult$ = exports2.DescribeInstanceAssociationsStatusRequest$ = exports2.DescribeEffectivePatchesForPatchBaselineResult$ = exports2.DescribeEffectivePatchesForPatchBaselineRequest$ = exports2.DescribeEffectiveInstanceAssociationsResult$ = exports2.DescribeEffectiveInstanceAssociationsRequest$ = exports2.DescribeDocumentResult$ = exports2.DescribeDocumentRequest$ = exports2.DescribeDocumentPermissionResponse$ = exports2.DescribeDocumentPermissionRequest$ = exports2.DescribeAvailablePatchesResult$ = void 0;
    exports2.GetMaintenanceWindowResult$ = exports2.GetMaintenanceWindowRequest$ = exports2.GetMaintenanceWindowExecutionTaskResult$ = exports2.GetMaintenanceWindowExecutionTaskRequest$ = exports2.GetMaintenanceWindowExecutionTaskInvocationResult$ = exports2.GetMaintenanceWindowExecutionTaskInvocationRequest$ = exports2.GetMaintenanceWindowExecutionResult$ = exports2.GetMaintenanceWindowExecutionRequest$ = exports2.GetInventorySchemaResult$ = exports2.GetInventorySchemaRequest$ = exports2.GetInventoryResult$ = exports2.GetInventoryRequest$ = exports2.GetExecutionPreviewResponse$ = exports2.GetExecutionPreviewRequest$ = exports2.GetDocumentResult$ = exports2.GetDocumentRequest$ = exports2.GetDeployablePatchSnapshotForInstanceResult$ = exports2.GetDeployablePatchSnapshotForInstanceRequest$ = exports2.GetDefaultPatchBaselineResult$ = exports2.GetDefaultPatchBaselineRequest$ = exports2.GetConnectionStatusResponse$ = exports2.GetConnectionStatusRequest$ = exports2.GetCommandInvocationResult$ = exports2.GetCommandInvocationRequest$ = exports2.GetCalendarStateResponse$ = exports2.GetCalendarStateRequest$ = exports2.GetAutomationExecutionResult$ = exports2.GetAutomationExecutionRequest$ = exports2.GetAccessTokenResponse$ = exports2.GetAccessTokenRequest$ = exports2.FailureDetails$ = exports2.FailedCreateAssociation$ = exports2.EffectivePatch$ = exports2.DocumentVersionInfo$ = exports2.DocumentReviews$ = exports2.DocumentReviewerResponseSource$ = exports2.DocumentReviewCommentSource$ = exports2.DocumentRequires$ = exports2.DocumentParameter$ = exports2.DocumentMetadataResponseInfo$ = exports2.DocumentKeyValuesFilter$ = exports2.DocumentIdentifier$ = exports2.DocumentFilter$ = exports2.DocumentDescription$ = exports2.DocumentDefaultVersionDescription$ = exports2.DisassociateOpsItemRelatedItemResponse$ = exports2.DisassociateOpsItemRelatedItemRequest$ = exports2.DescribeSessionsResponse$ = exports2.DescribeSessionsRequest$ = exports2.DescribePatchPropertiesResult$ = void 0;
    exports2.InventoryResultItem$ = exports2.InventoryResultEntity$ = exports2.InventoryItemSchema$ = exports2.InventoryItemAttribute$ = exports2.InventoryItem$ = exports2.InventoryGroup$ = exports2.InventoryFilter$ = exports2.InventoryDeletionSummaryItem$ = exports2.InventoryDeletionSummary$ = exports2.InventoryDeletionStatusItem$ = exports2.InventoryAggregator$ = exports2.InstancePropertyStringFilter$ = exports2.InstancePropertyFilter$ = exports2.InstanceProperty$ = exports2.InstancePatchStateFilter$ = exports2.InstancePatchState$ = exports2.InstanceInformationStringFilter$ = exports2.InstanceInformationFilter$ = exports2.InstanceInformation$ = exports2.InstanceInfo$ = exports2.InstanceAssociationStatusInfo$ = exports2.InstanceAssociationOutputUrl$ = exports2.InstanceAssociationOutputLocation$ = exports2.InstanceAssociation$ = exports2.InstanceAggregatedAssociationOverview$ = exports2.GetServiceSettingResult$ = exports2.GetServiceSettingRequest$ = exports2.GetResourcePoliciesResponseEntry$ = exports2.GetResourcePoliciesResponse$ = exports2.GetResourcePoliciesRequest$ = exports2.GetPatchBaselineResult$ = exports2.GetPatchBaselineRequest$ = exports2.GetPatchBaselineForPatchGroupResult$ = exports2.GetPatchBaselineForPatchGroupRequest$ = exports2.GetParametersResult$ = exports2.GetParametersRequest$ = exports2.GetParametersByPathResult$ = exports2.GetParametersByPathRequest$ = exports2.GetParameterResult$ = exports2.GetParameterRequest$ = exports2.GetParameterHistoryResult$ = exports2.GetParameterHistoryRequest$ = exports2.GetOpsSummaryResult$ = exports2.GetOpsSummaryRequest$ = exports2.GetOpsMetadataResult$ = exports2.GetOpsMetadataRequest$ = exports2.GetOpsItemResponse$ = exports2.GetOpsItemRequest$ = exports2.GetMaintenanceWindowTaskResult$ = exports2.GetMaintenanceWindowTaskRequest$ = void 0;
    exports2.MaintenanceWindowTarget$ = exports2.MaintenanceWindowStepFunctionsParameters$ = exports2.MaintenanceWindowRunCommandParameters$ = exports2.MaintenanceWindowLambdaParameters$ = exports2.MaintenanceWindowIdentityForTarget$ = exports2.MaintenanceWindowIdentity$ = exports2.MaintenanceWindowFilter$ = exports2.MaintenanceWindowExecutionTaskInvocationIdentity$ = exports2.MaintenanceWindowExecutionTaskIdentity$ = exports2.MaintenanceWindowExecution$ = exports2.MaintenanceWindowAutomationParameters$ = exports2.LoggingInfo$ = exports2.ListTagsForResourceResult$ = exports2.ListTagsForResourceRequest$ = exports2.ListResourceDataSyncResult$ = exports2.ListResourceDataSyncRequest$ = exports2.ListResourceComplianceSummariesResult$ = exports2.ListResourceComplianceSummariesRequest$ = exports2.ListOpsMetadataResult$ = exports2.ListOpsMetadataRequest$ = exports2.ListOpsItemRelatedItemsResponse$ = exports2.ListOpsItemRelatedItemsRequest$ = exports2.ListOpsItemEventsResponse$ = exports2.ListOpsItemEventsRequest$ = exports2.ListNodesSummaryResult$ = exports2.ListNodesSummaryRequest$ = exports2.ListNodesResult$ = exports2.ListNodesRequest$ = exports2.ListInventoryEntriesResult$ = exports2.ListInventoryEntriesRequest$ = exports2.ListDocumentVersionsResult$ = exports2.ListDocumentVersionsRequest$ = exports2.ListDocumentsResult$ = exports2.ListDocumentsRequest$ = exports2.ListDocumentMetadataHistoryResponse$ = exports2.ListDocumentMetadataHistoryRequest$ = exports2.ListComplianceSummariesResult$ = exports2.ListComplianceSummariesRequest$ = exports2.ListComplianceItemsResult$ = exports2.ListComplianceItemsRequest$ = exports2.ListCommandsResult$ = exports2.ListCommandsRequest$ = exports2.ListCommandInvocationsResult$ = exports2.ListCommandInvocationsRequest$ = exports2.ListAssociationVersionsResult$ = exports2.ListAssociationVersionsRequest$ = exports2.ListAssociationsResult$ = exports2.ListAssociationsRequest$ = exports2.LabelParameterVersionResult$ = exports2.LabelParameterVersionRequest$ = void 0;
    exports2.PutComplianceItemsRequest$ = exports2.ProgressCounters$ = exports2.PatchStatus$ = exports2.PatchSource$ = exports2.PatchRuleGroup$ = exports2.PatchRule$ = exports2.PatchOrchestratorFilter$ = exports2.PatchGroupPatchBaselineMapping$ = exports2.PatchFilterGroup$ = exports2.PatchFilter$ = exports2.PatchComplianceData$ = exports2.PatchBaselineIdentity$ = exports2.Patch$ = exports2.ParentStepDetails$ = exports2.ParameterStringFilter$ = exports2.ParametersFilter$ = exports2.ParameterMetadata$ = exports2.ParameterInlinePolicy$ = exports2.ParameterHistory$ = exports2.Parameter$ = exports2.OutputSource$ = exports2.OpsResultAttribute$ = exports2.OpsMetadataFilter$ = exports2.OpsMetadata$ = exports2.OpsItemSummary$ = exports2.OpsItemRelatedItemSummary$ = exports2.OpsItemRelatedItemsFilter$ = exports2.OpsItemNotification$ = exports2.OpsItemIdentity$ = exports2.OpsItemFilter$ = exports2.OpsItemEventSummary$ = exports2.OpsItemEventFilter$ = exports2.OpsItemDataValue$ = exports2.OpsItem$ = exports2.OpsFilter$ = exports2.OpsEntityItem$ = exports2.OpsEntity$ = exports2.OpsAggregator$ = exports2.NotificationConfig$ = exports2.NonCompliantSummary$ = exports2.NodeOwnerInfo$ = exports2.NodeFilter$ = exports2.NodeAggregator$ = exports2.Node$ = exports2.ModifyDocumentPermissionResponse$ = exports2.ModifyDocumentPermissionRequest$ = exports2.MetadataValue$ = exports2.MaintenanceWindowTaskParameterValueExpression$ = exports2.MaintenanceWindowTaskInvocationParameters$ = exports2.MaintenanceWindowTask$ = void 0;
    exports2.StartAssociationsOnceRequest$ = exports2.StartAccessRequestResponse$ = exports2.StartAccessRequestRequest$ = exports2.SeveritySummary$ = exports2.SessionManagerOutputUrl$ = exports2.SessionFilter$ = exports2.Session$ = exports2.ServiceSetting$ = exports2.SendCommandResult$ = exports2.SendCommandRequest$ = exports2.SendAutomationSignalResult$ = exports2.SendAutomationSignalRequest$ = exports2.ScheduledWindowExecution$ = exports2.S3OutputUrl$ = exports2.S3OutputLocation$ = exports2.Runbook$ = exports2.ReviewInformation$ = exports2.ResumeSessionResponse$ = exports2.ResumeSessionRequest$ = exports2.ResultAttribute$ = exports2.ResourceDataSyncSourceWithState$ = exports2.ResourceDataSyncSource$ = exports2.ResourceDataSyncS3Destination$ = exports2.ResourceDataSyncOrganizationalUnit$ = exports2.ResourceDataSyncItem$ = exports2.ResourceDataSyncDestinationDataSharing$ = exports2.ResourceDataSyncAwsOrganizationsSource$ = exports2.ResourceComplianceSummaryItem$ = exports2.ResolvedTargets$ = exports2.ResetServiceSettingResult$ = exports2.ResetServiceSettingRequest$ = exports2.RemoveTagsFromResourceResult$ = exports2.RemoveTagsFromResourceRequest$ = exports2.RelatedOpsItem$ = exports2.RegistrationMetadataItem$ = exports2.RegisterTaskWithMaintenanceWindowResult$ = exports2.RegisterTaskWithMaintenanceWindowRequest$ = exports2.RegisterTargetWithMaintenanceWindowResult$ = exports2.RegisterTargetWithMaintenanceWindowRequest$ = exports2.RegisterPatchBaselineForPatchGroupResult$ = exports2.RegisterPatchBaselineForPatchGroupRequest$ = exports2.RegisterDefaultPatchBaselineResult$ = exports2.RegisterDefaultPatchBaselineRequest$ = exports2.PutResourcePolicyResponse$ = exports2.PutResourcePolicyRequest$ = exports2.PutParameterResult$ = exports2.PutParameterRequest$ = exports2.PutInventoryResult$ = exports2.PutInventoryRequest$ = exports2.PutComplianceItemsResult$ = void 0;
    exports2.ExecutionInputs$ = exports2.UpdateServiceSettingResult$ = exports2.UpdateServiceSettingRequest$ = exports2.UpdateResourceDataSyncResult$ = exports2.UpdateResourceDataSyncRequest$ = exports2.UpdatePatchBaselineResult$ = exports2.UpdatePatchBaselineRequest$ = exports2.UpdateOpsMetadataResult$ = exports2.UpdateOpsMetadataRequest$ = exports2.UpdateOpsItemResponse$ = exports2.UpdateOpsItemRequest$ = exports2.UpdateManagedInstanceRoleResult$ = exports2.UpdateManagedInstanceRoleRequest$ = exports2.UpdateMaintenanceWindowTaskResult$ = exports2.UpdateMaintenanceWindowTaskRequest$ = exports2.UpdateMaintenanceWindowTargetResult$ = exports2.UpdateMaintenanceWindowTargetRequest$ = exports2.UpdateMaintenanceWindowResult$ = exports2.UpdateMaintenanceWindowRequest$ = exports2.UpdateDocumentResult$ = exports2.UpdateDocumentRequest$ = exports2.UpdateDocumentMetadataResponse$ = exports2.UpdateDocumentMetadataRequest$ = exports2.UpdateDocumentDefaultVersionResult$ = exports2.UpdateDocumentDefaultVersionRequest$ = exports2.UpdateAssociationStatusResult$ = exports2.UpdateAssociationStatusRequest$ = exports2.UpdateAssociationResult$ = exports2.UpdateAssociationRequest$ = exports2.UnlabelParameterVersionResult$ = exports2.UnlabelParameterVersionRequest$ = exports2.TerminateSessionResponse$ = exports2.TerminateSessionRequest$ = exports2.TargetPreview$ = exports2.TargetLocation$ = exports2.Target$ = exports2.Tag$ = exports2.StopAutomationExecutionResult$ = exports2.StopAutomationExecutionRequest$ = exports2.StepExecutionFilter$ = exports2.StepExecution$ = exports2.StartSessionResponse$ = exports2.StartSessionRequest$ = exports2.StartExecutionPreviewResponse$ = exports2.StartExecutionPreviewRequest$ = exports2.StartChangeRequestExecutionResult$ = exports2.StartChangeRequestExecutionRequest$ = exports2.StartAutomationExecutionResult$ = exports2.StartAutomationExecutionRequest$ = exports2.StartAssociationsOnceResult$ = void 0;
    exports2.DescribeMaintenanceWindowExecutions$ = exports2.DescribeInventoryDeletions$ = exports2.DescribeInstanceProperties$ = exports2.DescribeInstancePatchStatesForPatchGroup$ = exports2.DescribeInstancePatchStates$ = exports2.DescribeInstancePatches$ = exports2.DescribeInstanceInformation$ = exports2.DescribeInstanceAssociationsStatus$ = exports2.DescribeEffectivePatchesForPatchBaseline$ = exports2.DescribeEffectiveInstanceAssociations$ = exports2.DescribeDocumentPermission$ = exports2.DescribeDocument$ = exports2.DescribeAvailablePatches$ = exports2.DescribeAutomationStepExecutions$ = exports2.DescribeAutomationExecutions$ = exports2.DescribeAssociationExecutionTargets$ = exports2.DescribeAssociationExecutions$ = exports2.DescribeAssociation$ = exports2.DescribeActivations$ = exports2.DeregisterTaskFromMaintenanceWindow$ = exports2.DeregisterTargetFromMaintenanceWindow$ = exports2.DeregisterPatchBaselineForPatchGroup$ = exports2.DeregisterManagedInstance$ = exports2.DeleteResourcePolicy$ = exports2.DeleteResourceDataSync$ = exports2.DeletePatchBaseline$ = exports2.DeleteParameters$ = exports2.DeleteParameter$ = exports2.DeleteOpsMetadata$ = exports2.DeleteOpsItem$ = exports2.DeleteMaintenanceWindow$ = exports2.DeleteInventory$ = exports2.DeleteDocument$ = exports2.DeleteAssociation$ = exports2.DeleteActivation$ = exports2.CreateResourceDataSync$ = exports2.CreatePatchBaseline$ = exports2.CreateOpsMetadata$ = exports2.CreateOpsItem$ = exports2.CreateMaintenanceWindow$ = exports2.CreateDocument$ = exports2.CreateAssociationBatch$ = exports2.CreateAssociation$ = exports2.CreateActivation$ = exports2.CancelMaintenanceWindowExecution$ = exports2.CancelCommand$ = exports2.AssociateOpsItemRelatedItem$ = exports2.AddTagsToResource$ = exports2.NodeType$ = exports2.ExecutionPreview$ = void 0;
    exports2.ListDocumentMetadataHistory$ = exports2.ListComplianceSummaries$ = exports2.ListComplianceItems$ = exports2.ListCommands$ = exports2.ListCommandInvocations$ = exports2.ListAssociationVersions$ = exports2.ListAssociations$ = exports2.LabelParameterVersion$ = exports2.GetServiceSetting$ = exports2.GetResourcePolicies$ = exports2.GetPatchBaselineForPatchGroup$ = exports2.GetPatchBaseline$ = exports2.GetParametersByPath$ = exports2.GetParameters$ = exports2.GetParameterHistory$ = exports2.GetParameter$ = exports2.GetOpsSummary$ = exports2.GetOpsMetadata$ = exports2.GetOpsItem$ = exports2.GetMaintenanceWindowTask$ = exports2.GetMaintenanceWindowExecutionTaskInvocation$ = exports2.GetMaintenanceWindowExecutionTask$ = exports2.GetMaintenanceWindowExecution$ = exports2.GetMaintenanceWindow$ = exports2.GetInventorySchema$ = exports2.GetInventory$ = exports2.GetExecutionPreview$ = exports2.GetDocument$ = exports2.GetDeployablePatchSnapshotForInstance$ = exports2.GetDefaultPatchBaseline$ = exports2.GetConnectionStatus$ = exports2.GetCommandInvocation$ = exports2.GetCalendarState$ = exports2.GetAutomationExecution$ = exports2.GetAccessToken$ = exports2.DisassociateOpsItemRelatedItem$ = exports2.DescribeSessions$ = exports2.DescribePatchProperties$ = exports2.DescribePatchGroupState$ = exports2.DescribePatchGroups$ = exports2.DescribePatchBaselines$ = exports2.DescribeParameters$ = exports2.DescribeOpsItems$ = exports2.DescribeMaintenanceWindowTasks$ = exports2.DescribeMaintenanceWindowTargets$ = exports2.DescribeMaintenanceWindowsForTarget$ = exports2.DescribeMaintenanceWindowSchedule$ = exports2.DescribeMaintenanceWindows$ = exports2.DescribeMaintenanceWindowExecutionTasks$ = exports2.DescribeMaintenanceWindowExecutionTaskInvocations$ = void 0;
    exports2.UpdateServiceSetting$ = exports2.UpdateResourceDataSync$ = exports2.UpdatePatchBaseline$ = exports2.UpdateOpsMetadata$ = exports2.UpdateOpsItem$ = exports2.UpdateManagedInstanceRole$ = exports2.UpdateMaintenanceWindowTask$ = exports2.UpdateMaintenanceWindowTarget$ = exports2.UpdateMaintenanceWindow$ = exports2.UpdateDocumentMetadata$ = exports2.UpdateDocumentDefaultVersion$ = exports2.UpdateDocument$ = exports2.UpdateAssociationStatus$ = exports2.UpdateAssociation$ = exports2.UnlabelParameterVersion$ = exports2.TerminateSession$ = exports2.StopAutomationExecution$ = exports2.StartSession$ = exports2.StartExecutionPreview$ = exports2.StartChangeRequestExecution$ = exports2.StartAutomationExecution$ = exports2.StartAssociationsOnce$ = exports2.StartAccessRequest$ = exports2.SendCommand$ = exports2.SendAutomationSignal$ = exports2.ResumeSession$ = exports2.ResetServiceSetting$ = exports2.RemoveTagsFromResource$ = exports2.RegisterTaskWithMaintenanceWindow$ = exports2.RegisterTargetWithMaintenanceWindow$ = exports2.RegisterPatchBaselineForPatchGroup$ = exports2.RegisterDefaultPatchBaseline$ = exports2.PutResourcePolicy$ = exports2.PutParameter$ = exports2.PutInventory$ = exports2.PutComplianceItems$ = exports2.ModifyDocumentPermission$ = exports2.ListTagsForResource$ = exports2.ListResourceDataSync$ = exports2.ListResourceComplianceSummaries$ = exports2.ListOpsMetadata$ = exports2.ListOpsItemRelatedItems$ = exports2.ListOpsItemEvents$ = exports2.ListNodesSummary$ = exports2.ListNodes$ = exports2.ListInventoryEntries$ = exports2.ListDocumentVersions$ = exports2.ListDocuments$ = void 0;
    var _A10 = "Activation";
    var _AA = "AutoApprove";
    var _AAD = "ApproveAfterDays";
    var _AAE = "AssociationAlreadyExists";
    var _AC = "AlarmConfiguration";
    var _ACL = "AttachmentContentList";
    var _ACc = "ActivationCode";
    var _ACt = "AttachmentContent";
    var _ACtt = "AttachmentsContent";
    var _AD = "AssociationDescription";
    var _ADAR = "AssociationDispatchAssumeRole";
    var _ADE13 = "AccessDeniedException";
    var _ADL = "AssociationDescriptionList";
    var _ADNAE = "AutomationDefinitionNotApprovedException";
    var _ADNE = "AssociationDoesNotExist";
    var _ADNFE = "AutomationDefinitionNotFoundException";
    var _ADVNFE = "AutomationDefinitionVersionNotFoundException";
    var _ADp = "ApprovalDate";
    var _AE = "AssociationExecution";
    var _AEDNE = "AssociationExecutionDoesNotExist";
    var _AEE = "AlreadyExistsException";
    var _AEF = "AssociationExecutionFilter";
    var _AEFL = "AssociationExecutionFilterList";
    var _AEFLu = "AutomationExecutionFilterList";
    var _AEFu = "AutomationExecutionFilter";
    var _AEI = "AutomationExecutionId";
    var _AEIu = "AutomationExecutionInputs";
    var _AEL = "AssociationExecutionsList";
    var _AELEE = "AutomationExecutionLimitExceededException";
    var _AEM = "AutomationExecutionMetadata";
    var _AEML = "AutomationExecutionMetadataList";
    var _AENFE = "AutomationExecutionNotFoundException";
    var _AEP = "AutomationExecutionPreview";
    var _AES = "AutomationExecutionStatus";
    var _AET = "AssociationExecutionTarget";
    var _AETF = "AssociationExecutionTargetsFilter";
    var _AETFL = "AssociationExecutionTargetsFilterList";
    var _AETL = "AssociationExecutionTargetsList";
    var _AETc = "ActualEndTime";
    var _AETs = "AssociationExecutionTargets";
    var _AEs = "AssociationExecutions";
    var _AEu = "AutomationExecution";
    var _AF = "AssociationFilter";
    var _AFL = "AssociationFilterList";
    var _AI2 = "AssociatedInstances";
    var _AIL = "AccountIdList";
    var _AILt = "AttachmentInformationList";
    var _AITA = "AccountIdsToAdd";
    var _AITR = "AccountIdsToRemove";
    var _AIc = "AccountId";
    var _AIcc = "AccountIds";
    var _AIct = "ActivationId";
    var _AId = "AdditionalInfo";
    var _AIdv = "AdvisoryIds";
    var _AIs = "AssociationId";
    var _AIss = "AssociationIds";
    var _AIt = "AttachmentInformation";
    var _AItt = "AttachmentsInformation";
    var _AKI11 = "AccessKeyId";
    var _AKST = "AccessKeySecretType";
    var _AL = "ActivationList";
    var _ALE = "AssociationLimitExceeded";
    var _ALl = "AlarmList";
    var _ALs = "AssociationList";
    var _AN = "AssociationName";
    var _ANt = "AttributeName";
    var _AO = "AssociationOverview";
    var _AOACI = "ApplyOnlyAtCronInterval";
    var _AOIRI = "AssociateOpsItemRelatedItem";
    var _AOIRIR = "AssociateOpsItemRelatedItemRequest";
    var _AOIRIRs = "AssociateOpsItemRelatedItemResponse";
    var _AOS = "AwsOrganizationsSource";
    var _AP = "ApprovedPatches";
    var _APCL = "ApprovedPatchesComplianceLevel";
    var _APENS = "ApprovedPatchesEnableNonSecurity";
    var _APM = "AutomationParameterMap";
    var _APl = "AllowedPattern";
    var _AR10 = "ApprovalRules";
    var _ARI10 = "AccessRequestId";
    var _ARN = "ARN";
    var _ARS = "AccessRequestStatus";
    var _AS = "AssociationStatus";
    var _ASAC = "AssociationStatusAggregatedCount";
    var _ASI = "AccountSharingInfo";
    var _ASIL = "AccountSharingInfoList";
    var _ASILl = "AlarmStateInformationList";
    var _ASIl = "AlarmStateInformation";
    var _ASL = "AttachmentsSourceList";
    var _ASNFE = "AutomationStepNotFoundException";
    var _AST = "ActualStartTime";
    var _ASUC = "AvailableSecurityUpdateCount";
    var _ASUCS = "AvailableSecurityUpdatesComplianceStatus";
    var _ASt = "AttachmentsSource";
    var _ASu = "AutomationSubtype";
    var _AT13 = "AssociationType";
    var _ATPN = "AutomationTargetParameterName";
    var _ATTR = "AddTagsToResource";
    var _ATTRR = "AddTagsToResourceRequest";
    var _ATTRRd = "AddTagsToResourceResult";
    var _ATc = "AccessType";
    var _ATg = "AgentType";
    var _ATgg = "AggregatorType";
    var _ATt = "AtTime";
    var _ATu = "AutomationType";
    var _AUD = "ApproveUntilDate";
    var _AUT = "AllowUnassociatedTargets";
    var _AV = "AssociationVersion";
    var _AVI = "AssociationVersionInfo";
    var _AVL = "AssociationVersionList";
    var _AVLE = "AssociationVersionLimitExceeded";
    var _AVg = "AgentVersion";
    var _AVp = "ApprovedVersion";
    var _AVs = "AssociationVersions";
    var _AWSKMSKARN = "AWSKMSKeyARN";
    var _Ac = "Action";
    var _Acc = "Accounts";
    var _Ag = "Aggregators";
    var _Agg = "Aggregator";
    var _Al = "Alarm";
    var _Ala = "Alarms";
    var _Ar = "Architecture";
    var _Arc = "Arch";
    var _Arn = "Arn";
    var _As = "Association";
    var _Ass = "Associations";
    var _At = "Attachments";
    var _Att = "Attributes";
    var _Attr = "Attribute";
    var _Au10 = "Author";
    var _Aut = "Automation";
    var _BD = "BaselineDescription";
    var _BI = "BaselineId";
    var _BIa = "BaselineIdentities";
    var _BIas = "BaselineIdentity";
    var _BIu = "BugzillaIds";
    var _BN = "BaselineName";
    var _BNu = "BucketName";
    var _BO = "BaselineOverride";
    var _C11 = "Command";
    var _CA10 = "CurrentAction";
    var _CAB = "CreateAssociationBatch";
    var _CABR = "CreateAssociationBatchRequest";
    var _CABRE = "CreateAssociationBatchRequestEntry";
    var _CABREr = "CreateAssociationBatchRequestEntries";
    var _CABRr = "CreateAssociationBatchResult";
    var _CAR = "CreateActivationRequest";
    var _CARr = "CreateActivationResult";
    var _CARre = "CreateAssociationRequest";
    var _CARrea = "CreateAssociationResult";
    var _CAr = "CreateActivation";
    var _CAre = "CreateAssociation";
    var _CB = "CutoffBehavior";
    var _CBr = "CreatedBy";
    var _CC = "CompletedCount";
    var _CCR = "CancelCommandRequest";
    var _CCRa = "CancelCommandResult";
    var _CCa = "CancelCommand";
    var _CCl = "ClientContext";
    var _CCo = "CompliantCount";
    var _CCr = "CriticalCount";
    var _CD = "CreatedDate";
    var _CDR = "CreateDocumentRequest";
    var _CDRr = "CreateDocumentResult";
    var _CDh = "ChangeDetails";
    var _CDr = "CreationDate";
    var _CDre = "CreateDocument";
    var _CE = "CategoryEnum";
    var _CES = "ComplianceExecutionSummary";
    var _CF = "CommandFilter";
    var _CFL = "CommandFilterList";
    var _CFo = "ComplianceFilter";
    var _CH = "ContentHash";
    var _CI = "CommandId";
    var _CIE = "ComplianceItemEntry";
    var _CIEL = "ComplianceItemEntryList";
    var _CIL = "CommandInvocationList";
    var _CILo = "ComplianceItemList";
    var _CIo = "CommandInvocation";
    var _CIom = "ComplianceItem";
    var _CIomm = "CommandInvocations";
    var _CIomp = "ComplianceItems";
    var _CL = "ComplianceLevel";
    var _CLo = "CommandList";
    var _CMW = "CreateMaintenanceWindow";
    var _CMWE = "CancelMaintenanceWindowExecution";
    var _CMWER = "CancelMaintenanceWindowExecutionRequest";
    var _CMWERa = "CancelMaintenanceWindowExecutionResult";
    var _CMWR = "CreateMaintenanceWindowRequest";
    var _CMWRr = "CreateMaintenanceWindowResult";
    var _CN = "CalendarNames";
    var _CNCC = "CriticalNonCompliantCount";
    var _CNo = "ComputerName";
    var _COI = "CreateOpsItem";
    var _COIR = "CreateOpsItemRequest";
    var _COIRr = "CreateOpsItemResponse";
    var _COM = "CreateOpsMetadata";
    var _COMR = "CreateOpsMetadataRequest";
    var _COMRr = "CreateOpsMetadataResult";
    var _CP = "CommandPlugins";
    var _CPB = "CreatePatchBaseline";
    var _CPBR = "CreatePatchBaselineRequest";
    var _CPBRr = "CreatePatchBaselineResult";
    var _CPL = "CommandPluginList";
    var _CPo = "CommandPlugin";
    var _CRDS = "CreateResourceDataSync";
    var _CRDSR = "CreateResourceDataSyncRequest";
    var _CRDSRr = "CreateResourceDataSyncResult";
    var _CRN = "ChangeRequestName";
    var _CS4 = "ComplianceSeverity";
    var _CSCLEE = "CustomSchemaCountLimitExceededException";
    var _CSF = "ComplianceStringFilter";
    var _CSFL = "ComplianceStringFilterList";
    var _CSFVL = "ComplianceStringFilterValueList";
    var _CSI = "ComplianceSummaryItem";
    var _CSIL = "ComplianceSummaryItemList";
    var _CSIo = "ComplianceSummaryItems";
    var _CSN = "CurrentStepName";
    var _CSa = "CancelledSteps";
    var _CSo = "CompliantSummary";
    var _CT4 = "CreatedTime";
    var _CTCLEE = "ComplianceTypeCountLimitExceededException";
    var _CTa = "CaptureTime";
    var _CTl = "ClientToken";
    var _CTo = "ComplianceType";
    var _CTr = "CreateTime";
    var _CU = "ContentUrl";
    var _CVEI = "CVEIds";
    var _CWLGN = "CloudWatchLogGroupName";
    var _CWOC = "CloudWatchOutputConfig";
    var _CWOE = "CloudWatchOutputEnabled";
    var _CWOU = "CloudWatchOutputUrl";
    var _Ca = "Category";
    var _Cl = "Classification";
    var _Co = "Comment";
    var _Com = "Commands";
    var _Con = "Content";
    var _Conf = "Configuration";
    var _Cont = "Context";
    var _Cou = "Count";
    var _Cr = "Credentials";
    var _Cu = "Cutoff";
    var _D = "Description";
    var _DA = "DeleteActivation";
    var _DAE = "DocumentAlreadyExists";
    var _DAER = "DescribeAssociationExecutionsRequest";
    var _DAERe = "DescribeAssociationExecutionsResult";
    var _DAERes = "DescribeAutomationExecutionsRequest";
    var _DAEResc = "DescribeAutomationExecutionsResult";
    var _DAET = "DescribeAssociationExecutionTargets";
    var _DAETR = "DescribeAssociationExecutionTargetsRequest";
    var _DAETRe = "DescribeAssociationExecutionTargetsResult";
    var _DAEe = "DescribeAssociationExecutions";
    var _DAEes = "DescribeAutomationExecutions";
    var _DAF = "DescribeActivationsFilter";
    var _DAFL = "DescribeActivationsFilterList";
    var _DAP = "DescribeAvailablePatches";
    var _DAPR = "DescribeAvailablePatchesRequest";
    var _DAPRe = "DescribeAvailablePatchesResult";
    var _DAR = "DeleteActivationRequest";
    var _DARe = "DeleteActivationResult";
    var _DARel = "DeleteAssociationRequest";
    var _DARele = "DeleteAssociationResult";
    var _DARes = "DescribeActivationsRequest";
    var _DAResc = "DescribeActivationsResult";
    var _DARescr = "DescribeAssociationRequest";
    var _DARescri = "DescribeAssociationResult";
    var _DASE = "DescribeAutomationStepExecutions";
    var _DASER = "DescribeAutomationStepExecutionsRequest";
    var _DASERe = "DescribeAutomationStepExecutionsResult";
    var _DAe = "DeleteAssociation";
    var _DAes = "DescribeActivations";
    var _DAesc = "DescribeAssociation";
    var _DB = "DefaultBaseline";
    var _DD = "DocumentDescription";
    var _DDC = "DuplicateDocumentContent";
    var _DDP = "DescribeDocumentPermission";
    var _DDPR = "DescribeDocumentPermissionRequest";
    var _DDPRe = "DescribeDocumentPermissionResponse";
    var _DDR = "DeleteDocumentRequest";
    var _DDRe = "DeleteDocumentResult";
    var _DDRes = "DescribeDocumentRequest";
    var _DDResc = "DescribeDocumentResult";
    var _DDS = "DestinationDataSharing";
    var _DDST = "DestinationDataSharingType";
    var _DDVD = "DocumentDefaultVersionDescription";
    var _DDVN = "DuplicateDocumentVersionName";
    var _DDe = "DeleteDocument";
    var _DDes = "DescribeDocument";
    var _DEIA = "DescribeEffectiveInstanceAssociations";
    var _DEIAR = "DescribeEffectiveInstanceAssociationsRequest";
    var _DEIARe = "DescribeEffectiveInstanceAssociationsResult";
    var _DEPFPB = "DescribeEffectivePatchesForPatchBaseline";
    var _DEPFPBR = "DescribeEffectivePatchesForPatchBaselineRequest";
    var _DEPFPBRe = "DescribeEffectivePatchesForPatchBaselineResult";
    var _DF = "DocumentFormat";
    var _DFL = "DocumentFilterList";
    var _DFo = "DocumentFilter";
    var _DH = "DocumentHash";
    var _DHT = "DocumentHashType";
    var _DI = "DeletionId";
    var _DIAS = "DescribeInstanceAssociationsStatus";
    var _DIASR = "DescribeInstanceAssociationsStatusRequest";
    var _DIASRe = "DescribeInstanceAssociationsStatusResult";
    var _DID = "DescribeInventoryDeletions";
    var _DIDR = "DescribeInventoryDeletionsRequest";
    var _DIDRe = "DescribeInventoryDeletionsResult";
    var _DII = "DuplicateInstanceId";
    var _DIIR = "DescribeInstanceInformationRequest";
    var _DIIRe = "DescribeInstanceInformationResult";
    var _DIIe = "DescribeInstanceInformation";
    var _DIL = "DocumentIdentifierList";
    var _DIN = "DefaultInstanceName";
    var _DIP = "DescribeInstancePatches";
    var _DIPR = "DescribeInstancePatchesRequest";
    var _DIPRe = "DescribeInstancePatchesResult";
    var _DIPRes = "DescribeInstancePropertiesRequest";
    var _DIPResc = "DescribeInstancePropertiesResult";
    var _DIPS = "DescribeInstancePatchStates";
    var _DIPSFPG = "DescribeInstancePatchStatesForPatchGroup";
    var _DIPSFPGR = "DescribeInstancePatchStatesForPatchGroupRequest";
    var _DIPSFPGRe = "DescribeInstancePatchStatesForPatchGroupResult";
    var _DIPSR = "DescribeInstancePatchStatesRequest";
    var _DIPSRe = "DescribeInstancePatchStatesResult";
    var _DIPe = "DescribeInstanceProperties";
    var _DIR = "DeleteInventoryRequest";
    var _DIRe = "DeleteInventoryResult";
    var _DIe = "DeleteInventory";
    var _DIo = "DocumentIdentifier";
    var _DIoc = "DocumentIdentifiers";
    var _DKVF = "DocumentKeyValuesFilter";
    var _DKVFL = "DocumentKeyValuesFilterList";
    var _DLE = "DocumentLimitExceeded";
    var _DMI = "DeregisterManagedInstance";
    var _DMIR = "DeregisterManagedInstanceRequest";
    var _DMIRe = "DeregisterManagedInstanceResult";
    var _DMRI = "DocumentMetadataResponseInfo";
    var _DMW = "DeleteMaintenanceWindow";
    var _DMWE = "DescribeMaintenanceWindowExecutions";
    var _DMWER = "DescribeMaintenanceWindowExecutionsRequest";
    var _DMWERe = "DescribeMaintenanceWindowExecutionsResult";
    var _DMWET = "DescribeMaintenanceWindowExecutionTasks";
    var _DMWETI = "DescribeMaintenanceWindowExecutionTaskInvocations";
    var _DMWETIR = "DescribeMaintenanceWindowExecutionTaskInvocationsRequest";
    var _DMWETIRe = "DescribeMaintenanceWindowExecutionTaskInvocationsResult";
    var _DMWETR = "DescribeMaintenanceWindowExecutionTasksRequest";
    var _DMWETRe = "DescribeMaintenanceWindowExecutionTasksResult";
    var _DMWFT = "DescribeMaintenanceWindowsForTarget";
    var _DMWFTR = "DescribeMaintenanceWindowsForTargetRequest";
    var _DMWFTRe = "DescribeMaintenanceWindowsForTargetResult";
    var _DMWR = "DeleteMaintenanceWindowRequest";
    var _DMWRe = "DeleteMaintenanceWindowResult";
    var _DMWRes = "DescribeMaintenanceWindowsRequest";
    var _DMWResc = "DescribeMaintenanceWindowsResult";
    var _DMWS = "DescribeMaintenanceWindowSchedule";
    var _DMWSR = "DescribeMaintenanceWindowScheduleRequest";
    var _DMWSRe = "DescribeMaintenanceWindowScheduleResult";
    var _DMWT = "DescribeMaintenanceWindowTargets";
    var _DMWTR = "DescribeMaintenanceWindowTargetsRequest";
    var _DMWTRe = "DescribeMaintenanceWindowTargetsResult";
    var _DMWTRes = "DescribeMaintenanceWindowTasksRequest";
    var _DMWTResc = "DescribeMaintenanceWindowTasksResult";
    var _DMWTe = "DescribeMaintenanceWindowTasks";
    var _DMWe = "DescribeMaintenanceWindows";
    var _DN = "DocumentName";
    var _DNEE = "DoesNotExistException";
    var _DNi = "DisplayName";
    var _DOI = "DeleteOpsItem";
    var _DOIR = "DeleteOpsItemRequest";
    var _DOIRI = "DisassociateOpsItemRelatedItem";
    var _DOIRIR = "DisassociateOpsItemRelatedItemRequest";
    var _DOIRIRi = "DisassociateOpsItemRelatedItemResponse";
    var _DOIRe = "DeleteOpsItemResponse";
    var _DOIRes = "DescribeOpsItemsRequest";
    var _DOIResc = "DescribeOpsItemsResponse";
    var _DOIe = "DescribeOpsItems";
    var _DOM = "DeleteOpsMetadata";
    var _DOMR = "DeleteOpsMetadataRequest";
    var _DOMRe = "DeleteOpsMetadataResult";
    var _DP = "DeletedParameters";
    var _DPB = "DeletePatchBaseline";
    var _DPBFPG = "DeregisterPatchBaselineForPatchGroup";
    var _DPBFPGR = "DeregisterPatchBaselineForPatchGroupRequest";
    var _DPBFPGRe = "DeregisterPatchBaselineForPatchGroupResult";
    var _DPBR = "DeletePatchBaselineRequest";
    var _DPBRe = "DeletePatchBaselineResult";
    var _DPBRes = "DescribePatchBaselinesRequest";
    var _DPBResc = "DescribePatchBaselinesResult";
    var _DPBe = "DescribePatchBaselines";
    var _DPG = "DescribePatchGroups";
    var _DPGR = "DescribePatchGroupsRequest";
    var _DPGRe = "DescribePatchGroupsResult";
    var _DPGS = "DescribePatchGroupState";
    var _DPGSR = "DescribePatchGroupStateRequest";
    var _DPGSRe = "DescribePatchGroupStateResult";
    var _DPL = "DocumentPermissionLimit";
    var _DPLo = "DocumentParameterList";
    var _DPP = "DescribePatchProperties";
    var _DPPR = "DescribePatchPropertiesRequest";
    var _DPPRe = "DescribePatchPropertiesResult";
    var _DPR = "DeleteParameterRequest";
    var _DPRe = "DeleteParameterResult";
    var _DPRel = "DeleteParametersRequest";
    var _DPRele = "DeleteParametersResult";
    var _DPRes = "DescribeParametersRequest";
    var _DPResc = "DescribeParametersResult";
    var _DPe = "DeleteParameter";
    var _DPel = "DeleteParameters";
    var _DPes = "DescribeParameters";
    var _DPo = "DocumentParameter";
    var _DR = "DryRun";
    var _DRCL = "DocumentReviewCommentList";
    var _DRCS = "DocumentReviewCommentSource";
    var _DRDS = "DeleteResourceDataSync";
    var _DRDSR = "DeleteResourceDataSyncRequest";
    var _DRDSRe = "DeleteResourceDataSyncResult";
    var _DRL = "DocumentRequiresList";
    var _DRP = "DeleteResourcePolicy";
    var _DRPR = "DeleteResourcePolicyRequest";
    var _DRPRe = "DeleteResourcePolicyResponse";
    var _DRRL = "DocumentReviewerResponseList";
    var _DRRS = "DocumentReviewerResponseSource";
    var _DRo = "DocumentRequires";
    var _DRoc = "DocumentReviews";
    var _DS10 = "DetailedStatus";
    var _DSR = "DescribeSessionsRequest";
    var _DSRe = "DescribeSessionsResponse";
    var _DST = "DeletionStartTime";
    var _DSe = "DeletionSummary";
    var _DSep = "DeploymentStatus";
    var _DSes = "DescribeSessions";
    var _DT = "DocumentType";
    var _DTFMW = "DeregisterTargetFromMaintenanceWindow";
    var _DTFMWR = "DeregisterTargetFromMaintenanceWindowRequest";
    var _DTFMWRe = "DeregisterTargetFromMaintenanceWindowResult";
    var _DTFMWRer = "DeregisterTaskFromMaintenanceWindowRequest";
    var _DTFMWRere = "DeregisterTaskFromMaintenanceWindowResult";
    var _DTFMWe = "DeregisterTaskFromMaintenanceWindow";
    var _DTOC = "DeliveryTimedOutCount";
    var _DTa = "DataType";
    var _DTe = "DetailType";
    var _DV = "DocumentVersion";
    var _DVI = "DocumentVersionInfo";
    var _DVL = "DocumentVersionList";
    var _DVLE = "DocumentVersionLimitExceeded";
    var _DVN = "DefaultVersionName";
    var _DVe = "DefaultVersion";
    var _DVef = "DefaultValue";
    var _DVo = "DocumentVersions";
    var _Da = "Date";
    var _Dat = "Data";
    var _De = "Details";
    var _Det = "Detail";
    var _Do = "Document";
    var _Du = "Duration";
    var _E11 = "Expired";
    var _EA = "ExpiresAfter";
    var _EAODS = "EnableAllOpsDataSources";
    var _EAn = "EndedAt";
    var _EAx = "ExcludeAccounts";
    var _EB = "ExecutedBy";
    var _EC = "ErrorCount";
    var _ECr = "ErrorCode";
    var _ED = "ExpirationDate";
    var _EDn = "EndDate";
    var _EDx = "ExecutionDate";
    var _EEDT = "ExecutionEndDateTime";
    var _EET = "ExecutionEndTime";
    var _EETx = "ExecutionElapsedTime";
    var _EI10 = "ExecutionId";
    var _EIv = "EventId";
    var _EIx = "ExecutionInputs";
    var _ENS = "EnableNonSecurity";
    var _EP = "EffectivePatches";
    var _EPI = "ExecutionPreviewId";
    var _EPL = "EffectivePatchList";
    var _EPf = "EffectivePatch";
    var _EPx = "ExecutionPreview";
    var _ERN = "ExecutionRoleName";
    var _ES = "ExecutionSummary";
    var _ESDT = "ExecutionStartDateTime";
    var _EST = "ExecutionStartTime";
    var _ET = "ExecutionTime";
    var _ETn = "EndTime";
    var _ETx = "ExecutionType";
    var _ETxp = "ExpirationTime";
    var _En = "Entries";
    var _Ena = "Enabled";
    var _Ent = "Entry";
    var _Enti = "Entities";
    var _Entit = "Entity";
    var _Ep = "Epoch";
    var _Ex = "Expression";
    var _F = "Failed";
    var _FC = "FailedCount";
    var _FCA = "FailedCreateAssociation";
    var _FCAE = "FailedCreateAssociationEntry";
    var _FCAL = "FailedCreateAssociationList";
    var _FD = "FailureDetails";
    var _FK = "FilterKey";
    var _FM = "FailureMessage";
    var _FNAE = "FeatureNotAvailableException";
    var _FS = "FailureStage";
    var _FSa = "FailedSteps";
    var _FT = "FailureType";
    var _FV = "FilterValues";
    var _FVi = "FilterValue";
    var _FWO = "FiltersWithOperator";
    var _Fa = "Fault";
    var _Fi = "Filters";
    var _Fo = "Force";
    var _G = "Groups";
    var _GAE = "GetAutomationExecution";
    var _GAER = "GetAutomationExecutionRequest";
    var _GAERe = "GetAutomationExecutionResult";
    var _GAT = "GetAccessToken";
    var _GATR = "GetAccessTokenRequest";
    var _GATRe = "GetAccessTokenResponse";
    var _GCI = "GetCommandInvocation";
    var _GCIR = "GetCommandInvocationRequest";
    var _GCIRe = "GetCommandInvocationResult";
    var _GCS = "GetCalendarState";
    var _GCSR = "GetCalendarStateRequest";
    var _GCSRe = "GetCalendarStateResponse";
    var _GCSRet = "GetConnectionStatusRequest";
    var _GCSReto = "GetConnectionStatusResponse";
    var _GCSe = "GetConnectionStatus";
    var _GD = "GetDocument";
    var _GDPB = "GetDefaultPatchBaseline";
    var _GDPBR = "GetDefaultPatchBaselineRequest";
    var _GDPBRe = "GetDefaultPatchBaselineResult";
    var _GDPSFI = "GetDeployablePatchSnapshotForInstance";
    var _GDPSFIR = "GetDeployablePatchSnapshotForInstanceRequest";
    var _GDPSFIRe = "GetDeployablePatchSnapshotForInstanceResult";
    var _GDR = "GetDocumentRequest";
    var _GDRe = "GetDocumentResult";
    var _GEP = "GetExecutionPreview";
    var _GEPR = "GetExecutionPreviewRequest";
    var _GEPRe = "GetExecutionPreviewResponse";
    var _GF = "GlobalFilters";
    var _GI2 = "GetInventory";
    var _GIR2 = "GetInventoryRequest";
    var _GIRe = "GetInventoryResult";
    var _GIS = "GetInventorySchema";
    var _GISR = "GetInventorySchemaRequest";
    var _GISRe = "GetInventorySchemaResult";
    var _GMW = "GetMaintenanceWindow";
    var _GMWE = "GetMaintenanceWindowExecution";
    var _GMWER = "GetMaintenanceWindowExecutionRequest";
    var _GMWERe = "GetMaintenanceWindowExecutionResult";
    var _GMWET = "GetMaintenanceWindowExecutionTask";
    var _GMWETI = "GetMaintenanceWindowExecutionTaskInvocation";
    var _GMWETIR = "GetMaintenanceWindowExecutionTaskInvocationRequest";
    var _GMWETIRe = "GetMaintenanceWindowExecutionTaskInvocationResult";
    var _GMWETR = "GetMaintenanceWindowExecutionTaskRequest";
    var _GMWETRe = "GetMaintenanceWindowExecutionTaskResult";
    var _GMWR = "GetMaintenanceWindowRequest";
    var _GMWRe = "GetMaintenanceWindowResult";
    var _GMWT = "GetMaintenanceWindowTask";
    var _GMWTR = "GetMaintenanceWindowTaskRequest";
    var _GMWTRe = "GetMaintenanceWindowTaskResult";
    var _GOI = "GetOpsItem";
    var _GOIR = "GetOpsItemRequest";
    var _GOIRe = "GetOpsItemResponse";
    var _GOM = "GetOpsMetadata";
    var _GOMR = "GetOpsMetadataRequest";
    var _GOMRe = "GetOpsMetadataResult";
    var _GOS = "GetOpsSummary";
    var _GOSR = "GetOpsSummaryRequest";
    var _GOSRe = "GetOpsSummaryResult";
    var _GP = "GetParameter";
    var _GPB = "GetPatchBaseline";
    var _GPBFPG = "GetPatchBaselineForPatchGroup";
    var _GPBFPGR = "GetPatchBaselineForPatchGroupRequest";
    var _GPBFPGRe = "GetPatchBaselineForPatchGroupResult";
    var _GPBP = "GetParametersByPath";
    var _GPBPR = "GetParametersByPathRequest";
    var _GPBPRe = "GetParametersByPathResult";
    var _GPBR = "GetPatchBaselineRequest";
    var _GPBRe = "GetPatchBaselineResult";
    var _GPH = "GetParameterHistory";
    var _GPHR = "GetParameterHistoryRequest";
    var _GPHRe = "GetParameterHistoryResult";
    var _GPR = "GetParameterRequest";
    var _GPRe = "GetParameterResult";
    var _GPRet = "GetParametersRequest";
    var _GPReta = "GetParametersResult";
    var _GPe = "GetParameters";
    var _GRP = "GetResourcePolicies";
    var _GRPR = "GetResourcePoliciesRequest";
    var _GRPRE = "GetResourcePoliciesResponseEntry";
    var _GRPREe = "GetResourcePoliciesResponseEntries";
    var _GRPRe = "GetResourcePoliciesResponse";
    var _GSS = "GetServiceSetting";
    var _GSSR = "GetServiceSettingRequest";
    var _GSSRe = "GetServiceSettingResult";
    var _H = "Hash";
    var _HC = "HighCount";
    var _HLLEE = "HierarchyLevelLimitExceededException";
    var _HT = "HashType";
    var _HTME = "HierarchyTypeMismatchException";
    var _I = "Id";
    var _IA = "InvalidActivation";
    var _IAAO = "InstanceAggregatedAssociationOverview";
    var _IAE = "InvalidAggregatorException";
    var _IAEPE = "InvalidAutomationExecutionParametersException";
    var _IAI = "InvalidActivationId";
    var _IAL = "InstanceAssociationList";
    var _IALn = "InventoryAggregatorList";
    var _IAOL = "InstanceAssociationOutputLocation";
    var _IAOU = "InstanceAssociationOutputUrl";
    var _IAPE = "InvalidAllowedPatternException";
    var _IASAC = "InstanceAssociationStatusAggregatedCount";
    var _IASE = "InvalidAutomationSignalException";
    var _IASI = "InstanceAssociationStatusInfos";
    var _IASIn = "InstanceAssociationStatusInfo";
    var _IASUE = "InvalidAutomationStatusUpdateException";
    var _IAV = "InvalidAssociationVersion";
    var _IAn = "InvalidAssociation";
    var _IAns = "InstanceAssociation";
    var _IAnv = "InventoryAggregator";
    var _IAp = "IpAddress";
    var _IC = "InstalledCount";
    var _ICH = "ItemContentHash";
    var _ICI = "InvalidCommandId";
    var _ICME = "ItemContentMismatchException";
    var _ICOU = "IncludeChildOrganizationUnits";
    var _ICn = "InformationalCount";
    var _ICs = "IsCritical";
    var _ID = "InvalidDocument";
    var _IDC = "InvalidDocumentContent";
    var _IDIE = "InvalidDeletionIdException";
    var _IDIPE = "InvalidDeleteInventoryParametersException";
    var _IDL = "InventoryDeletionsList";
    var _IDNE = "InvocationDoesNotExist";
    var _IDO = "InvalidDocumentOperation";
    var _IDS = "InventoryDeletionSummary";
    var _IDSI = "InventoryDeletionStatusItem";
    var _IDSIn = "InventoryDeletionSummaryItem";
    var _IDSInv = "InventoryDeletionSummaryItems";
    var _IDSV = "InvalidDocumentSchemaVersion";
    var _IDT = "InvalidDocumentType";
    var _IDV = "InvalidDocumentVersion";
    var _IDVs = "IsDefaultVersion";
    var _IDn = "InventoryDeletions";
    var _IE = "IsEnd";
    var _IF = "InvalidFilter";
    var _IFK = "InvalidFilterKey";
    var _IFL = "InventoryFilterList";
    var _IFO = "InvalidFilterOption";
    var _IFR = "IncludeFutureRegions";
    var _IFV = "InvalidFilterValue";
    var _IFVL = "InventoryFilterValueList";
    var _IFn = "InventoryFilter";
    var _IG = "InventoryGroup";
    var _IGL = "InventoryGroupList";
    var _II2 = "InstanceId";
    var _IIA = "InventoryItemAttribute";
    var _IIAL = "InventoryItemAttributeList";
    var _IICE = "InvalidItemContentException";
    var _IIEL = "InventoryItemEntryList";
    var _IIF = "InstanceInformationFilter";
    var _IIFL = "InstanceInformationFilterList";
    var _IIFV = "InstanceInformationFilterValue";
    var _IIFVS = "InstanceInformationFilterValueSet";
    var _IIGE = "InvalidInventoryGroupException";
    var _III = "InvalidInstanceId";
    var _IIICE = "InvalidInventoryItemContextException";
    var _IIIFV = "InvalidInstanceInformationFilterValue";
    var _IIL = "InstanceInformationList";
    var _IILn = "InventoryItemList";
    var _IIPFV = "InvalidInstancePropertyFilterValue";
    var _IIRE = "InvalidInventoryRequestException";
    var _IIS = "InventoryItemSchema";
    var _IISF = "InstanceInformationStringFilter";
    var _IISFL = "InstanceInformationStringFilterList";
    var _IISRL = "InventoryItemSchemaResultList";
    var _IIn = "InstanceIds";
    var _IIns = "InstanceInfo";
    var _IInst = "InstanceInformation";
    var _IInv = "InvocationId";
    var _IInve = "InventoryItem";
    var _IKI = "InvalidKeyId";
    var _IL = "InvalidLabels";
    var _ILV = "IsLatestVersion";
    var _IN = "InstanceName";
    var _INC = "InvalidNotificationConfig";
    var _INT = "InvalidNextToken";
    var _IOC = "InstalledOtherCount";
    var _IOE = "InvalidOptionException";
    var _IOF = "InvalidOutputFolder";
    var _IOL = "InvalidOutputLocation";
    var _IOLn = "InstallOverrideList";
    var _IP = "InvalidParameters";
    var _IPA = "IPAddress";
    var _IPAE = "InvalidPolicyAttributeException";
    var _IPAF = "IgnorePollAlarmFailure";
    var _IPE2 = "IncompatiblePolicyException";
    var _IPF = "InstancePropertyFilter";
    var _IPFL = "InstancePropertyFilterList";
    var _IPFV = "InstancePropertyFilterValue";
    var _IPFVS = "InstancePropertyFilterValueSet";
    var _IPM = "IdempotentParameterMismatch";
    var _IPN = "InvalidPluginName";
    var _IPRC = "InstalledPendingRebootCount";
    var _IPS = "InstancePatchStates";
    var _IPSF = "InstancePatchStateFilter";
    var _IPSFL = "InstancePatchStateFilterList";
    var _IPSFLn = "InstancePropertyStringFilterList";
    var _IPSFn = "InstancePropertyStringFilter";
    var _IPSL = "InstancePatchStateList";
    var _IPSLn = "InstancePatchStatesList";
    var _IPSn = "InstancePatchState";
    var _IPT2 = "InvalidPermissionType";
    var _IPTE = "InvalidPolicyTypeException";
    var _IPn = "InstanceProperties";
    var _IPns = "InstanceProperty";
    var _IR = "InvalidRole";
    var _IRAE = "InvalidResultAttributeException";
    var _IRC = "InstalledRejectedCount";
    var _IRE13 = "InventoryResultEntity";
    var _IREL = "InventoryResultEntityList";
    var _IRI = "InvalidResourceId";
    var _IRIM = "InventoryResultItemMap";
    var _IRIn = "InventoryResultItem";
    var _IRT = "InvalidResourceType";
    var _IRa = "IamRole";
    var _IRn = "InstanceRole";
    var _IS = "InvalidSchedule";
    var _ISE13 = "InternalServerError";
    var _ISLEE = "ItemSizeLimitExceededException";
    var _ISn = "InstanceStatus";
    var _ISns = "InstanceState";
    var _IT4 = "InvalidTag";
    var _ITM = "InvalidTargetMaps";
    var _ITNE = "InvalidTypeNameException";
    var _ITn = "InvalidTarget";
    var _ITns = "InstanceType";
    var _ITnst = "InstalledTime";
    var _IU = "InvalidUpdate";
    var _IV = "IteratorValue";
    var _IWASU = "InstancesWithAvailableSecurityUpdates";
    var _IWCNCP = "InstancesWithCriticalNonCompliantPatches";
    var _IWFP = "InstancesWithFailedPatches";
    var _IWIOP = "InstancesWithInstalledOtherPatches";
    var _IWIP = "InstancesWithInstalledPatches";
    var _IWIPRP = "InstancesWithInstalledPendingRebootPatches";
    var _IWIRP = "InstancesWithInstalledRejectedPatches";
    var _IWMP = "InstancesWithMissingPatches";
    var _IWNAP = "InstancesWithNotApplicablePatches";
    var _IWONCP = "InstancesWithOtherNonCompliantPatches";
    var _IWSNCP = "InstancesWithSecurityNonCompliantPatches";
    var _IWUNAP = "InstancesWithUnreportedNotApplicablePatches";
    var _In = "Instances";
    var _Inp = "Input";
    var _Inpu = "Inputs";
    var _Ins = "Instance";
    var _It = "Iteration";
    var _Ite = "Items";
    var _Item = "Item";
    var _K10 = "Key";
    var _KBI = "KBId";
    var _KI = "KeyId";
    var _KN = "KeyName";
    var _KNb = "KbNumber";
    var _KTD = "KeysToDelete";
    var _L2 = "Limit";
    var _LA = "ListAssociations";
    var _LAED = "LastAssociationExecutionDate";
    var _LAR = "ListAssociationsRequest";
    var _LARi = "ListAssociationsResult";
    var _LAV = "ListAssociationVersions";
    var _LAVR = "ListAssociationVersionsRequest";
    var _LAVRi = "ListAssociationVersionsResult";
    var _LC = "LowCount";
    var _LCI = "ListCommandInvocations";
    var _LCIR = "ListCommandInvocationsRequest";
    var _LCIRi = "ListCommandInvocationsResult";
    var _LCIRis = "ListComplianceItemsRequest";
    var _LCIRist = "ListComplianceItemsResult";
    var _LCIi = "ListComplianceItems";
    var _LCR = "ListCommandsRequest";
    var _LCRi = "ListCommandsResult";
    var _LCS = "ListComplianceSummaries";
    var _LCSR = "ListComplianceSummariesRequest";
    var _LCSRi = "ListComplianceSummariesResult";
    var _LCi = "ListCommands";
    var _LD = "ListDocuments";
    var _LDMH = "ListDocumentMetadataHistory";
    var _LDMHR = "ListDocumentMetadataHistoryRequest";
    var _LDMHRi = "ListDocumentMetadataHistoryResponse";
    var _LDR = "ListDocumentsRequest";
    var _LDRi = "ListDocumentsResult";
    var _LDV = "ListDocumentVersions";
    var _LDVR = "ListDocumentVersionsRequest";
    var _LDVRi = "ListDocumentVersionsResult";
    var _LED = "LastExecutionDate";
    var _LF = "LogFile";
    var _LI = "LoggingInfo";
    var _LIE = "ListInventoryEntries";
    var _LIER = "ListInventoryEntriesRequest";
    var _LIERi = "ListInventoryEntriesResult";
    var _LMB = "LastModifiedBy";
    var _LMD = "LastModifiedDate";
    var _LMT = "LastModifiedTime";
    var _LMU = "LastModifiedUser";
    var _LN = "ListNodes";
    var _LNR = "ListNodesRequest";
    var _LNRIOT = "LastNoRebootInstallOperationTime";
    var _LNRi = "ListNodesResult";
    var _LNS = "ListNodesSummary";
    var _LNSR = "ListNodesSummaryRequest";
    var _LNSRi = "ListNodesSummaryResult";
    var _LOIE = "ListOpsItemEvents";
    var _LOIER = "ListOpsItemEventsRequest";
    var _LOIERi = "ListOpsItemEventsResponse";
    var _LOIRI = "ListOpsItemRelatedItems";
    var _LOIRIR = "ListOpsItemRelatedItemsRequest";
    var _LOIRIRi = "ListOpsItemRelatedItemsResponse";
    var _LOM = "ListOpsMetadata";
    var _LOMR = "ListOpsMetadataRequest";
    var _LOMRi = "ListOpsMetadataResult";
    var _LPDT = "LastPingDateTime";
    var _LPV = "LabelParameterVersion";
    var _LPVR = "LabelParameterVersionRequest";
    var _LPVRa = "LabelParameterVersionResult";
    var _LRCS = "ListResourceComplianceSummaries";
    var _LRCSR = "ListResourceComplianceSummariesRequest";
    var _LRCSRi = "ListResourceComplianceSummariesResult";
    var _LRDS = "ListResourceDataSync";
    var _LRDSR = "ListResourceDataSyncRequest";
    var _LRDSRi = "ListResourceDataSyncResult";
    var _LS = "LastStatus";
    var _LSAED = "LastSuccessfulAssociationExecutionDate";
    var _LSED = "LastSuccessfulExecutionDate";
    var _LSM = "LastStatusMessage";
    var _LSSM = "LastSyncStatusMessage";
    var _LSST = "LastSuccessfulSyncTime";
    var _LST = "LastSyncTime";
    var _LSUT = "LastStatusUpdateTime";
    var _LT = "LimitType";
    var _LTFR = "ListTagsForResource";
    var _LTFRR = "ListTagsForResourceRequest";
    var _LTFRRi = "ListTagsForResourceResult";
    var _LTa = "LaunchTime";
    var _LUAD = "LastUpdateAssociationDate";
    var _LV = "LatestVersion";
    var _La = "Labels";
    var _Lam = "Lambda";
    var _Lan = "Language";
    var _M = "Message";
    var _MA = "MaxAttempts";
    var _MC = "MaxConcurrency";
    var _MCe = "MediumCount";
    var _MCi = "MissingCount";
    var _MD = "ModifiedDate";
    var _MDP = "ModifyDocumentPermission";
    var _MDPR = "ModifyDocumentPermissionRequest";
    var _MDPRo = "ModifyDocumentPermissionResponse";
    var _MDSE = "MaxDocumentSizeExceeded";
    var _ME = "MaxErrors";
    var _MM = "MetadataMap";
    var _MN = "MsrcNumber";
    var _MR = "MaxResults";
    var _MRPDE = "MalformedResourcePolicyDocumentException";
    var _MS = "ManagedStatus";
    var _MSD = "MaxSessionDuration";
    var _MSs = "MsrcSeverity";
    var _MTU = "MetadataToUpdate";
    var _MV = "MetadataValue";
    var _MWAP = "MaintenanceWindowAutomationParameters";
    var _MWD = "MaintenanceWindowDescription";
    var _MWE = "MaintenanceWindowExecution";
    var _MWEL = "MaintenanceWindowExecutionList";
    var _MWETI = "MaintenanceWindowExecutionTaskIdentity";
    var _MWETII = "MaintenanceWindowExecutionTaskInvocationIdentity";
    var _MWETIIL = "MaintenanceWindowExecutionTaskInvocationIdentityList";
    var _MWETIL = "MaintenanceWindowExecutionTaskIdentityList";
    var _MWETIP = "MaintenanceWindowExecutionTaskInvocationParameters";
    var _MWF = "MaintenanceWindowFilter";
    var _MWFL = "MaintenanceWindowFilterList";
    var _MWFTL = "MaintenanceWindowsForTargetList";
    var _MWI = "MaintenanceWindowIdentity";
    var _MWIFT = "MaintenanceWindowIdentityForTarget";
    var _MWIL = "MaintenanceWindowIdentityList";
    var _MWLP = "MaintenanceWindowLambdaPayload";
    var _MWLPa = "MaintenanceWindowLambdaParameters";
    var _MWRCP = "MaintenanceWindowRunCommandParameters";
    var _MWSFI = "MaintenanceWindowStepFunctionsInput";
    var _MWSFP = "MaintenanceWindowStepFunctionsParameters";
    var _MWT = "MaintenanceWindowTarget";
    var _MWTIP = "MaintenanceWindowTaskInvocationParameters";
    var _MWTL = "MaintenanceWindowTargetList";
    var _MWTLa = "MaintenanceWindowTaskList";
    var _MWTP = "MaintenanceWindowTaskParameters";
    var _MWTPL = "MaintenanceWindowTaskParametersList";
    var _MWTPV = "MaintenanceWindowTaskParameterValue";
    var _MWTPVE = "MaintenanceWindowTaskParameterValueExpression";
    var _MWTPVL = "MaintenanceWindowTaskParameterValueList";
    var _MWTa = "MaintenanceWindowTask";
    var _Ma = "Mappings";
    var _Me = "Metadata";
    var _Mo = "Mode";
    var _N = "Name";
    var _NA = "NodeAggregator";
    var _NAC = "NotApplicableCount";
    var _NAL = "NodeAggregatorList";
    var _NAo = "NotificationArn";
    var _NC = "NotificationConfig";
    var _NCC = "NonCompliantCount";
    var _NCS = "NonCompliantSummary";
    var _NE = "NotificationEvents";
    var _NET = "NextExecutionTime";
    var _NF = "NodeFilter";
    var _NFL = "NodeFilterList";
    var _NFVL = "NodeFilterValueList";
    var _NL = "NodeList";
    var _NLSE = "NoLongerSupportedException";
    var _NOI = "NodeOwnerInfo";
    var _NS = "NextStep";
    var _NSL = "NodeSummaryList";
    var _NT = "NextToken";
    var _NTT = "NextTransitionTime";
    var _NTo = "NodeType";
    var _NTot = "NotificationType";
    var _Na = "Names";
    var _No = "Notifications";
    var _Nod = "Nodes";
    var _Node = "Node";
    var _O = "Overview";
    var _OA = "OpsAggregator";
    var _OAL = "OpsAggregatorList";
    var _OD = "OperationalData";
    var _ODTD = "OperationalDataToDelete";
    var _OE = "OpsEntity";
    var _OEI = "OpsEntityItem";
    var _OEIEL = "OpsEntityItemEntryList";
    var _OEIM = "OpsEntityItemMap";
    var _OEL = "OpsEntityList";
    var _OET = "OperationEndTime";
    var _OF = "OpsFilter";
    var _OFL = "OpsFilterList";
    var _OFVL = "OpsFilterValueList";
    var _OFn = "OnFailure";
    var _OI = "OwnerInformation";
    var _OIA = "OpsItemArn";
    var _OIADE = "OpsItemAccessDeniedException";
    var _OIAEE = "OpsItemAlreadyExistsException";
    var _OICE = "OpsItemConflictException";
    var _OIDV = "OpsItemDataValue";
    var _OIEF = "OpsItemEventFilter";
    var _OIEFp = "OpsItemEventFilters";
    var _OIES = "OpsItemEventSummary";
    var _OIESp = "OpsItemEventSummaries";
    var _OIF = "OpsItemFilters";
    var _OIFp = "OpsItemFilter";
    var _OII = "OpsItemId";
    var _OIIPE = "OpsItemInvalidParameterException";
    var _OIIp = "OpsItemIdentity";
    var _OILEE = "OpsItemLimitExceededException";
    var _OIN = "OpsItemNotification";
    var _OINFE = "OpsItemNotFoundException";
    var _OINp = "OpsItemNotifications";
    var _OIOD = "OpsItemOperationalData";
    var _OIRIAEE = "OpsItemRelatedItemAlreadyExistsException";
    var _OIRIANFE = "OpsItemRelatedItemAssociationNotFoundException";
    var _OIRIF = "OpsItemRelatedItemsFilter";
    var _OIRIFp = "OpsItemRelatedItemsFilters";
    var _OIRIS = "OpsItemRelatedItemSummary";
    var _OIRISp = "OpsItemRelatedItemSummaries";
    var _OIS = "OpsItemSummaries";
    var _OISp = "OpsItemSummary";
    var _OIT = "OpsItemType";
    var _OIp = "OpsItem";
    var _OL = "OutputLocation";
    var _OM = "OpsMetadata";
    var _OMA = "OpsMetadataArn";
    var _OMAEE = "OpsMetadataAlreadyExistsException";
    var _OMF = "OpsMetadataFilter";
    var _OMFL = "OpsMetadataFilterList";
    var _OMIAE = "OpsMetadataInvalidArgumentException";
    var _OMKLEE = "OpsMetadataKeyLimitExceededException";
    var _OML = "OpsMetadataList";
    var _OMLEE = "OpsMetadataLimitExceededException";
    var _OMNFE = "OpsMetadataNotFoundException";
    var _OMTMUE = "OpsMetadataTooManyUpdatesException";
    var _ONCC = "OtherNonCompliantCount";
    var _OP = "OverriddenParameters";
    var _ORA = "OpsResultAttribute";
    var _ORAL = "OpsResultAttributeList";
    var _OS = "OutputSource";
    var _OSBN = "OutputS3BucketName";
    var _OSI = "OutputSourceId";
    var _OSKP = "OutputS3KeyPrefix";
    var _OSR = "OutputS3Region";
    var _OST = "OperationStartTime";
    var _OSTr = "OrganizationSourceType";
    var _OSTu = "OutputSourceType";
    var _OSp = "OperatingSystem";
    var _OSv = "OverallSeverity";
    var _OU = "OutputUrl";
    var _OUI = "OrganizationalUnitId";
    var _OUP = "OrganizationalUnitPath";
    var _OUr = "OrganizationalUnits";
    var _Op = "Operation";
    var _Ope = "Operator";
    var _Opt = "Option";
    var _Ou = "Outputs";
    var _Out = "Output";
    var _Ov = "Overwrite";
    var _Ow = "Owner";
    var _P10 = "Parameters";
    var _PAE = "ParameterAlreadyExists";
    var _PAEI = "ParentAutomationExecutionId";
    var _PBI = "PatchBaselineIdentity";
    var _PBIL = "PatchBaselineIdentityList";
    var _PC10 = "ProgressCounters";
    var _PCD = "PatchComplianceData";
    var _PCDL = "PatchComplianceDataList";
    var _PCI = "PutComplianceItems";
    var _PCIR = "PutComplianceItemsRequest";
    var _PCIRu = "PutComplianceItemsResult";
    var _PET = "PlannedEndTime";
    var _PF = "ParameterFilters";
    var _PFG = "PatchFilterGroup";
    var _PFL = "ParametersFilterList";
    var _PFLa = "PatchFilterList";
    var _PFa = "ParametersFilter";
    var _PFat = "PatchFilter";
    var _PFatc = "PatchFilters";
    var _PFr = "ProductFamily";
    var _PG = "PatchGroup";
    var _PGPBM = "PatchGroupPatchBaselineMapping";
    var _PGPBML = "PatchGroupPatchBaselineMappingList";
    var _PGa = "PatchGroups";
    var _PH = "PolicyHash";
    var _PHL = "ParameterHistoryList";
    var _PHa = "ParameterHistory";
    var _PI10 = "PolicyId";
    var _PIP = "ParameterInlinePolicy";
    var _PIR = "PutInventoryRequest";
    var _PIRu = "PutInventoryResult";
    var _PIu = "PutInventory";
    var _PL = "ParameterList";
    var _PLE = "ParameterLimitExceeded";
    var _PLEE = "PoliciesLimitExceededException";
    var _PLa = "PatchList";
    var _PM = "ParameterMetadata";
    var _PML = "ParameterMetadataList";
    var _PMVLE = "ParameterMaxVersionLimitExceeded";
    var _PN = "ParameterNames";
    var _PNF = "ParameterNotFound";
    var _PNl = "PluginName";
    var _PNla = "PlatformName";
    var _POF = "PatchOrchestratorFilter";
    var _POFL = "PatchOrchestratorFilterList";
    var _PP = "PutParameter";
    var _PPL = "PatchPropertiesList";
    var _PPLa = "ParameterPolicyList";
    var _PPME = "ParameterPatternMismatchException";
    var _PPR = "PutParameterRequest";
    var _PPRu = "PutParameterResult";
    var _PR = "PatchRule";
    var _PRG = "PatchRuleGroup";
    var _PRL = "PatchRuleList";
    var _PRP = "PutResourcePolicy";
    var _PRPR = "PutResourcePolicyRequest";
    var _PRPRu = "PutResourcePolicyResponse";
    var _PRV = "PendingReviewVersion";
    var _PRa = "PatchRules";
    var _PS = "PatchSet";
    var _PSC = "PatchSourceConfiguration";
    var _PSD = "ParentStepDetails";
    var _PSF = "ParameterStringFilter";
    var _PSFL = "ParameterStringFilterList";
    var _PSL = "PatchSourceList";
    var _PSPV = "PSParameterValue";
    var _PST = "PlannedStartTime";
    var _PSa = "PatchStatus";
    var _PSat = "PatchSource";
    var _PSi = "PingStatus";
    var _PSo = "PolicyStatus";
    var _PT = "PermissionType";
    var _PTL = "PlatformTypeList";
    var _PTl = "PlatformTypes";
    var _PTla = "PlatformType";
    var _PTo = "PolicyText";
    var _PTol = "PolicyType";
    var _PV = "PlatformVersion";
    var _PVLLE = "ParameterVersionLabelLimitExceeded";
    var _PVNF = "ParameterVersionNotFound";
    var _PVa = "ParameterVersion";
    var _PVar = "ParameterValues";
    var _Pa = "Patches";
    var _Par = "Parameter";
    var _Pat = "Patch";
    var _Path = "Path";
    var _Pay = "Payload";
    var _Po = "Policies";
    var _Pol = "Policy";
    var _Pr10 = "Priority";
    var _Pre = "Prefix";
    var _Pro = "Property";
    var _Prod = "Product";
    var _Produ = "Products";
    var _Prop = "Properties";
    var _Q = "Qualifier";
    var _QC = "QuotaCode";
    var _R = "Runbooks";
    var _RA10 = "ResourceArn";
    var _RAL = "ResultAttributeList";
    var _RAe = "ResultAttributes";
    var _RAes = "ResultAttribute";
    var _RC10 = "ReasonCode";
    var _RCBS = "ResourceCountByStatus";
    var _RCSI = "ResourceComplianceSummaryItems";
    var _RCSIL = "ResourceComplianceSummaryItemList";
    var _RCSIe = "ResourceComplianceSummaryItem";
    var _RCe = "RegistrationsCount";
    var _RCem = "RemainingCount";
    var _RCes = "ResponseCode";
    var _RCu = "RunCommand";
    var _RD = "RegistrationDate";
    var _RDPB = "RegisterDefaultPatchBaseline";
    var _RDPBR = "RegisterDefaultPatchBaselineRequest";
    var _RDPBRe = "RegisterDefaultPatchBaselineResult";
    var _RDSAEE = "ResourceDataSyncAlreadyExistsException";
    var _RDSAOS = "ResourceDataSyncAwsOrganizationsSource";
    var _RDSCE = "ResourceDataSyncConflictException";
    var _RDSCEE = "ResourceDataSyncCountExceededException";
    var _RDSDDS = "ResourceDataSyncDestinationDataSharing";
    var _RDSI = "ResourceDataSyncItems";
    var _RDSICE = "ResourceDataSyncInvalidConfigurationException";
    var _RDSIL = "ResourceDataSyncItemList";
    var _RDSIe = "ResourceDataSyncItem";
    var _RDSNFE = "ResourceDataSyncNotFoundException";
    var _RDSOU = "ResourceDataSyncOrganizationalUnit";
    var _RDSOUL = "ResourceDataSyncOrganizationalUnitList";
    var _RDSS = "ResourceDataSyncSource";
    var _RDSSD = "ResourceDataSyncS3Destination";
    var _RDSSWS = "ResourceDataSyncSourceWithState";
    var _RDT = "RequestedDateTime";
    var _RDe = "ReleaseDate";
    var _RFDT = "ResponseFinishDateTime";
    var _RI = "ResourceId";
    var _RIL = "ReviewInformationList";
    var _RIUE = "ResourceInUseException";
    var _RIe = "ReviewInformation";
    var _RIes = "ResourceIds";
    var _RL = "RegistrationLimit";
    var _RLEE = "ResourceLimitExceededException";
    var _RLe = "RemovedLabels";
    var _RM = "RegistrationMetadata";
    var _RMI = "RegistrationMetadataItem";
    var _RML = "RegistrationMetadataList";
    var _RNFE11 = "ResourceNotFoundException";
    var _RO = "ReverseOrder";
    var _ROI = "RelatedOpsItems";
    var _ROIe = "RelatedOpsItem";
    var _ROe = "RebootOption";
    var _RP = "RejectedPatches";
    var _RPA = "RejectedPatchesAction";
    var _RPBFPG = "RegisterPatchBaselineForPatchGroup";
    var _RPBFPGR = "RegisterPatchBaselineForPatchGroupRequest";
    var _RPBFPGRe = "RegisterPatchBaselineForPatchGroupResult";
    var _RPCE = "ResourcePolicyConflictException";
    var _RPIPE = "ResourcePolicyInvalidParameterException";
    var _RPLEE = "ResourcePolicyLimitExceededException";
    var _RPNFE = "ResourcePolicyNotFoundException";
    var _RR = "ReviewerResponse";
    var _RS = "ReviewStatus";
    var _RSDT = "ResponseStartDateTime";
    var _RSR = "ResumeSessionRequest";
    var _RSRe = "ResumeSessionResponse";
    var _RSS = "ResetServiceSetting";
    var _RSSR = "ResetServiceSettingRequest";
    var _RSSRe = "ResetServiceSettingResult";
    var _RSe = "ResumeSession";
    var _RT13 = "ResourceTypes";
    var _RTFR = "RemoveTagsFromResource";
    var _RTFRR = "RemoveTagsFromResourceRequest";
    var _RTFRRe = "RemoveTagsFromResourceResult";
    var _RTWMW = "RegisterTargetWithMaintenanceWindow";
    var _RTWMWR = "RegisterTargetWithMaintenanceWindowRequest";
    var _RTWMWRe = "RegisterTargetWithMaintenanceWindowResult";
    var _RTWMWReg = "RegisterTaskWithMaintenanceWindowRequest";
    var _RTWMWRegi = "RegisterTaskWithMaintenanceWindowResult";
    var _RTWMWe = "RegisterTaskWithMaintenanceWindow";
    var _RTe = "ResourceType";
    var _RTeq = "RequireType";
    var _RTes = "ResolvedTargets";
    var _RTev = "ReviewedTime";
    var _RU = "ResourceUri";
    var _Re = "Regions";
    var _Rea = "Reason";
    var _Rec = "Recursive";
    var _Reg = "Region";
    var _Rel = "Release";
    var _Rep = "Repository";
    var _Repl = "Replace";
    var _Req = "Requires";
    var _Res = "Response";
    var _Rev = "Reviewer";
    var _Ru = "Runbook";
    var _S = "State";
    var _SAE = "StartAutomationExecution";
    var _SAER = "StartAutomationExecutionRequest";
    var _SAERt = "StartAutomationExecutionResult";
    var _SAERto = "StopAutomationExecutionRequest";
    var _SAERtop = "StopAutomationExecutionResult";
    var _SAEt = "StopAutomationExecution";
    var _SAK10 = "SecretAccessKey";
    var _SAO = "StartAssociationsOnce";
    var _SAOR = "StartAssociationsOnceRequest";
    var _SAORt = "StartAssociationsOnceResult";
    var _SAR = "StartAccessRequest";
    var _SARR = "StartAccessRequestRequest";
    var _SARRt = "StartAccessRequestResponse";
    var _SAS = "SendAutomationSignal";
    var _SASR = "SendAutomationSignalRequest";
    var _SASRe = "SendAutomationSignalResult";
    var _SBN = "S3BucketName";
    var _SC = "ServiceCode";
    var _SCR = "SendCommandRequest";
    var _SCRE = "StartChangeRequestExecution";
    var _SCRER = "StartChangeRequestExecutionRequest";
    var _SCRERt = "StartChangeRequestExecutionResult";
    var _SCRe = "SendCommandResult";
    var _SCT = "SyncCreatedTime";
    var _SCe = "SendCommand";
    var _SCy = "SyncCompliance";
    var _SD = "StatusDetails";
    var _SDO = "SchemaDeleteOption";
    var _SDU = "SnapshotDownloadUrl";
    var _SDV = "SharedDocumentVersion";
    var _SDe = "S3Destination";
    var _SDt = "StartDate";
    var _SE = "ScheduleExpression";
    var _SEC = "StandardErrorContent";
    var _SEF = "StepExecutionFilter";
    var _SEFL = "StepExecutionFilterList";
    var _SEI = "StepExecutionId";
    var _SEL = "StepExecutionList";
    var _SEP = "StartExecutionPreview";
    var _SEPR = "StartExecutionPreviewRequest";
    var _SEPRt = "StartExecutionPreviewResponse";
    var _SET = "StepExecutionsTruncated";
    var _SETc = "ScheduledEndTime";
    var _SEU = "StandardErrorUrl";
    var _SEt = "StepExecutions";
    var _SEte = "StepExecution";
    var _SF = "StepFunctions";
    var _SFL = "SessionFilterList";
    var _SFe = "SessionFilter";
    var _SFy = "SyncFormat";
    var _SI10 = "StatusInformation";
    var _SIe = "SettingId";
    var _SIes = "SessionId";
    var _SIn = "SnapshotId";
    var _SIo = "SourceId";
    var _SIu = "SummaryItems";
    var _SKP = "S3KeyPrefix";
    var _SL = "S3Location";
    var _SLMT = "SyncLastModifiedTime";
    var _SLe = "SessionList";
    var _SM = "StatusMessage";
    var _SMOU = "SessionManagerOutputUrl";
    var _SMP = "SessionManagerParameters";
    var _SN10 = "SyncName";
    var _SNCC = "SecurityNonCompliantCount";
    var _SNt = "StepName";
    var _SO = "ScheduleOffset";
    var _SOC = "StandardOutputContent";
    var _SOL = "S3OutputLocation";
    var _SOU = "StandardOutputUrl";
    var _SOUu = "S3OutputUrl";
    var _SP = "StepPreviews";
    var _SQEE = "ServiceQuotaExceededException";
    var _SR = "ServiceRole";
    var _SRA = "ServiceRoleArn";
    var _SRe = "S3Region";
    var _SRo = "SourceResult";
    var _SRou = "SourceRegions";
    var _SS = "SeveritySummary";
    var _SSNF = "ServiceSettingNotFound";
    var _SSR = "StartSessionRequest";
    var _SSRt = "StartSessionResponse";
    var _SSe = "ServiceSetting";
    var _SSt = "StepStatus";
    var _SSta = "StartSession";
    var _SSu = "SuccessSteps";
    var _SSy = "SyncSource";
    var _ST11 = "SyncType";
    var _STCLEE = "SubTypeCountLimitExceededException";
    var _STT10 = "SessionTokenType";
    var _STc = "ScheduledTime";
    var _STch = "ScheduleTimezone";
    var _STe = "SessionToken";
    var _STi = "SignalType";
    var _STo = "SourceType";
    var _STt = "StartTime";
    var _STu = "SubType";
    var _SU = "StatusUnchanged";
    var _SUt = "StreamUrl";
    var _SV = "SchemaVersion";
    var _SVe = "SettingValue";
    var _SWE = "ScheduledWindowExecutions";
    var _SWEL = "ScheduledWindowExecutionList";
    var _SWEc = "ScheduledWindowExecution";
    var _Sa = "Safe";
    var _Sc = "Schedule";
    var _Sch = "Schemas";
    var _Se = "Severity";
    var _Sel = "Selector";
    var _Ses = "Sessions";
    var _Sess = "Session";
    var _Sh = "Shared";
    var _Sha = "Sha1";
    var _Si = "Size";
    var _So = "Sources";
    var _Sou = "Source";
    var _St = "Status";
    var _Su = "Successful";
    var _Sum = "Summary";
    var _Summ = "Summaries";
    var _T10 = "Tags";
    var _TA = "TriggeredAlarms";
    var _TAa = "TaskArn";
    var _TAo = "TotalAccounts";
    var _TC10 = "TargetCount";
    var _TCo = "TotalCount";
    var _TE = "ThrottlingException";
    var _TEI = "TaskExecutionId";
    var _TI = "TaskId";
    var _TIP = "TaskInvocationParameters";
    var _TIUE = "TargetInUseException";
    var _TIa = "TaskIds";
    var _TK = "TagKeys";
    var _TL = "TargetLocations";
    var _TLAC = "TargetLocationAlarmConfiguration";
    var _TLMC = "TargetLocationMaxConcurrency";
    var _TLME = "TargetLocationMaxErrors";
    var _TLURL = "TargetLocationsURL";
    var _TLa = "TagList";
    var _TLar = "TargetLocation";
    var _TM = "TargetMaps";
    var _TMC = "TargetsMaxConcurrency";
    var _TME = "TargetsMaxErrors";
    var _TMTE = "TooManyTagsError";
    var _TMU = "TooManyUpdates";
    var _TMa = "TargetMap";
    var _TN = "TypeName";
    var _TNC = "TargetNotConnected";
    var _TO = "TraceOutput";
    var _TOS = "TimedOutSteps";
    var _TP = "TargetPreviews";
    var _TPL = "TargetPreviewList";
    var _TPN = "TargetParameterName";
    var _TPa = "TaskParameters";
    var _TPar = "TargetPreview";
    var _TS = "TimeoutSeconds";
    var _TSLEE = "TotalSizeLimitExceededException";
    var _TSR = "TerminateSessionRequest";
    var _TSRe = "TerminateSessionResponse";
    var _TSe = "TerminateSession";
    var _TSo = "TotalSteps";
    var _TT = "TargetType";
    var _TTa = "TaskType";
    var _TV = "TokenValue";
    var _Ta10 = "Targets";
    var _Tag = "Tag";
    var _Tar = "Target";
    var _Tas = "Tasks";
    var _Ti = "Title";
    var _Tie = "Tier";
    var _Tr = "Truncated";
    var _Ty = "Type";
    var _U = "Url";
    var _UA = "UpdateAssociation";
    var _UAR = "UpdateAssociationRequest";
    var _UARp = "UpdateAssociationResult";
    var _UAS = "UpdateAssociationStatus";
    var _UASR = "UpdateAssociationStatusRequest";
    var _UASRp = "UpdateAssociationStatusResult";
    var _UC = "UnspecifiedCount";
    var _UCE4 = "UnsupportedCalendarException";
    var _UD = "UpdateDocument";
    var _UDDV = "UpdateDocumentDefaultVersion";
    var _UDDVR = "UpdateDocumentDefaultVersionRequest";
    var _UDDVRp = "UpdateDocumentDefaultVersionResult";
    var _UDM = "UpdateDocumentMetadata";
    var _UDMR = "UpdateDocumentMetadataRequest";
    var _UDMRp = "UpdateDocumentMetadataResponse";
    var _UDR = "UpdateDocumentRequest";
    var _UDRp = "UpdateDocumentResult";
    var _UFRE = "UnsupportedFeatureRequiredException";
    var _UIICE = "UnsupportedInventoryItemContextException";
    var _UISVE = "UnsupportedInventorySchemaVersionException";
    var _UMIR = "UpdateManagedInstanceRole";
    var _UMIRR = "UpdateManagedInstanceRoleRequest";
    var _UMIRRp = "UpdateManagedInstanceRoleResult";
    var _UMW = "UpdateMaintenanceWindow";
    var _UMWR = "UpdateMaintenanceWindowRequest";
    var _UMWRp = "UpdateMaintenanceWindowResult";
    var _UMWT = "UpdateMaintenanceWindowTarget";
    var _UMWTR = "UpdateMaintenanceWindowTargetRequest";
    var _UMWTRp = "UpdateMaintenanceWindowTargetResult";
    var _UMWTRpd = "UpdateMaintenanceWindowTaskRequest";
    var _UMWTRpda = "UpdateMaintenanceWindowTaskResult";
    var _UMWTp = "UpdateMaintenanceWindowTask";
    var _UNAC = "UnreportedNotApplicableCount";
    var _UOE = "UnsupportedOperationException";
    var _UOI = "UpdateOpsItem";
    var _UOIR = "UpdateOpsItemRequest";
    var _UOIRp = "UpdateOpsItemResponse";
    var _UOM = "UpdateOpsMetadata";
    var _UOMR = "UpdateOpsMetadataRequest";
    var _UOMRp = "UpdateOpsMetadataResult";
    var _UOS = "UnsupportedOperatingSystem";
    var _UPB = "UpdatePatchBaseline";
    var _UPBR = "UpdatePatchBaselineRequest";
    var _UPBRp = "UpdatePatchBaselineResult";
    var _UPT = "UnsupportedParameterType";
    var _UPTn = "UnsupportedPlatformType";
    var _UPV = "UnlabelParameterVersion";
    var _UPVR = "UnlabelParameterVersionRequest";
    var _UPVRn = "UnlabelParameterVersionResult";
    var _URDS = "UpdateResourceDataSync";
    var _URDSR = "UpdateResourceDataSyncRequest";
    var _URDSRp = "UpdateResourceDataSyncResult";
    var _USDSE = "UseS3DualStackEndpoint";
    var _USS = "UpdateServiceSetting";
    var _USSR = "UpdateServiceSettingRequest";
    var _USSRp = "UpdateServiceSettingResult";
    var _UT = "UpdatedTime";
    var _UTp = "UploadType";
    var _V10 = "Value";
    var _VE10 = "ValidationException";
    var _VN = "VersionName";
    var _VNS = "ValidNextSteps";
    var _Va = "Values";
    var _Var = "Variables";
    var _Ve = "Version";
    var _Ven = "Vendor";
    var _WD = "WithDecryption";
    var _WE = "WindowExecutions";
    var _WEI = "WindowExecutionId";
    var _WETI = "WindowExecutionTaskIdentities";
    var _WETII = "WindowExecutionTaskInvocationIdentities";
    var _WI = "WindowId";
    var _WIi = "WindowIdentities";
    var _WTI = "WindowTargetId";
    var _WTIi = "WindowTaskId";
    var _aQE10 = "awsQueryError";
    var _c32 = "client";
    var _e32 = "error";
    var _en = "entries";
    var _k = "key";
    var _m29 = "message";
    var _s32 = "smithy.ts.sdk.synthetic.com.amazonaws.ssm";
    var _se14 = "server";
    var _v = "value";
    var _vS = "valueSet";
    var _xN = "xmlName";
    var n032 = "com.amazonaws.ssm";
    var schema_1 = (init_schema4(), __toCommonJS(schema_exports));
    var errors_1 = require_errors18();
    var SSMServiceException_1 = require_SSMServiceException();
    var _s_registry32 = schema_1.TypeRegistry.for(_s32);
    exports2.SSMServiceException$ = [-3, _s32, "SSMServiceException", 0, [], []];
    _s_registry32.registerError(exports2.SSMServiceException$, SSMServiceException_1.SSMServiceException);
    var n0_registry32 = schema_1.TypeRegistry.for(n032);
    exports2.AccessDeniedException$ = [
      -3,
      n032,
      _ADE13,
      { [_e32]: _c32 },
      [_M],
      [0],
      1
    ];
    n0_registry32.registerError(exports2.AccessDeniedException$, errors_1.AccessDeniedException);
    exports2.AlreadyExistsException$ = [
      -3,
      n032,
      _AEE,
      { [_aQE10]: [`AlreadyExistsException`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.AlreadyExistsException$, errors_1.AlreadyExistsException);
    exports2.AssociatedInstances$ = [
      -3,
      n032,
      _AI2,
      { [_aQE10]: [`AssociatedInstances`, 400], [_e32]: _c32 },
      [],
      []
    ];
    n0_registry32.registerError(exports2.AssociatedInstances$, errors_1.AssociatedInstances);
    exports2.AssociationAlreadyExists$ = [
      -3,
      n032,
      _AAE,
      { [_aQE10]: [`AssociationAlreadyExists`, 400], [_e32]: _c32 },
      [],
      []
    ];
    n0_registry32.registerError(exports2.AssociationAlreadyExists$, errors_1.AssociationAlreadyExists);
    exports2.AssociationDoesNotExist$ = [
      -3,
      n032,
      _ADNE,
      { [_aQE10]: [`AssociationDoesNotExist`, 404], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.AssociationDoesNotExist$, errors_1.AssociationDoesNotExist);
    exports2.AssociationExecutionDoesNotExist$ = [
      -3,
      n032,
      _AEDNE,
      { [_aQE10]: [`AssociationExecutionDoesNotExist`, 404], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.AssociationExecutionDoesNotExist$, errors_1.AssociationExecutionDoesNotExist);
    exports2.AssociationLimitExceeded$ = [
      -3,
      n032,
      _ALE,
      { [_aQE10]: [`AssociationLimitExceeded`, 400], [_e32]: _c32 },
      [],
      []
    ];
    n0_registry32.registerError(exports2.AssociationLimitExceeded$, errors_1.AssociationLimitExceeded);
    exports2.AssociationVersionLimitExceeded$ = [
      -3,
      n032,
      _AVLE,
      { [_aQE10]: [`AssociationVersionLimitExceeded`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.AssociationVersionLimitExceeded$, errors_1.AssociationVersionLimitExceeded);
    exports2.AutomationDefinitionNotApprovedException$ = [
      -3,
      n032,
      _ADNAE,
      { [_aQE10]: [`AutomationDefinitionNotApproved`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.AutomationDefinitionNotApprovedException$, errors_1.AutomationDefinitionNotApprovedException);
    exports2.AutomationDefinitionNotFoundException$ = [
      -3,
      n032,
      _ADNFE,
      { [_aQE10]: [`AutomationDefinitionNotFound`, 404], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.AutomationDefinitionNotFoundException$, errors_1.AutomationDefinitionNotFoundException);
    exports2.AutomationDefinitionVersionNotFoundException$ = [
      -3,
      n032,
      _ADVNFE,
      { [_aQE10]: [`AutomationDefinitionVersionNotFound`, 404], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.AutomationDefinitionVersionNotFoundException$, errors_1.AutomationDefinitionVersionNotFoundException);
    exports2.AutomationExecutionLimitExceededException$ = [
      -3,
      n032,
      _AELEE,
      { [_aQE10]: [`AutomationExecutionLimitExceeded`, 429], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.AutomationExecutionLimitExceededException$, errors_1.AutomationExecutionLimitExceededException);
    exports2.AutomationExecutionNotFoundException$ = [
      -3,
      n032,
      _AENFE,
      { [_aQE10]: [`AutomationExecutionNotFound`, 404], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.AutomationExecutionNotFoundException$, errors_1.AutomationExecutionNotFoundException);
    exports2.AutomationStepNotFoundException$ = [
      -3,
      n032,
      _ASNFE,
      { [_aQE10]: [`AutomationStepNotFoundException`, 404], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.AutomationStepNotFoundException$, errors_1.AutomationStepNotFoundException);
    exports2.ComplianceTypeCountLimitExceededException$ = [
      -3,
      n032,
      _CTCLEE,
      { [_aQE10]: [`ComplianceTypeCountLimitExceeded`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ComplianceTypeCountLimitExceededException$, errors_1.ComplianceTypeCountLimitExceededException);
    exports2.CustomSchemaCountLimitExceededException$ = [
      -3,
      n032,
      _CSCLEE,
      { [_aQE10]: [`CustomSchemaCountLimitExceeded`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.CustomSchemaCountLimitExceededException$, errors_1.CustomSchemaCountLimitExceededException);
    exports2.DocumentAlreadyExists$ = [
      -3,
      n032,
      _DAE,
      { [_aQE10]: [`DocumentAlreadyExists`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.DocumentAlreadyExists$, errors_1.DocumentAlreadyExists);
    exports2.DocumentLimitExceeded$ = [
      -3,
      n032,
      _DLE,
      { [_aQE10]: [`DocumentLimitExceeded`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.DocumentLimitExceeded$, errors_1.DocumentLimitExceeded);
    exports2.DocumentPermissionLimit$ = [
      -3,
      n032,
      _DPL,
      { [_aQE10]: [`DocumentPermissionLimit`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.DocumentPermissionLimit$, errors_1.DocumentPermissionLimit);
    exports2.DocumentVersionLimitExceeded$ = [
      -3,
      n032,
      _DVLE,
      { [_aQE10]: [`DocumentVersionLimitExceeded`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.DocumentVersionLimitExceeded$, errors_1.DocumentVersionLimitExceeded);
    exports2.DoesNotExistException$ = [
      -3,
      n032,
      _DNEE,
      { [_aQE10]: [`DoesNotExistException`, 404], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.DoesNotExistException$, errors_1.DoesNotExistException);
    exports2.DuplicateDocumentContent$ = [
      -3,
      n032,
      _DDC,
      { [_aQE10]: [`DuplicateDocumentContent`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.DuplicateDocumentContent$, errors_1.DuplicateDocumentContent);
    exports2.DuplicateDocumentVersionName$ = [
      -3,
      n032,
      _DDVN,
      { [_aQE10]: [`DuplicateDocumentVersionName`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.DuplicateDocumentVersionName$, errors_1.DuplicateDocumentVersionName);
    exports2.DuplicateInstanceId$ = [
      -3,
      n032,
      _DII,
      { [_aQE10]: [`DuplicateInstanceId`, 404], [_e32]: _c32 },
      [],
      []
    ];
    n0_registry32.registerError(exports2.DuplicateInstanceId$, errors_1.DuplicateInstanceId);
    exports2.FeatureNotAvailableException$ = [
      -3,
      n032,
      _FNAE,
      { [_aQE10]: [`FeatureNotAvailableException`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.FeatureNotAvailableException$, errors_1.FeatureNotAvailableException);
    exports2.HierarchyLevelLimitExceededException$ = [
      -3,
      n032,
      _HLLEE,
      { [_aQE10]: [`HierarchyLevelLimitExceededException`, 400], [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.HierarchyLevelLimitExceededException$, errors_1.HierarchyLevelLimitExceededException);
    exports2.HierarchyTypeMismatchException$ = [
      -3,
      n032,
      _HTME,
      { [_aQE10]: [`HierarchyTypeMismatchException`, 400], [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.HierarchyTypeMismatchException$, errors_1.HierarchyTypeMismatchException);
    exports2.IdempotentParameterMismatch$ = [
      -3,
      n032,
      _IPM,
      { [_aQE10]: [`IdempotentParameterMismatch`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.IdempotentParameterMismatch$, errors_1.IdempotentParameterMismatch);
    exports2.IncompatiblePolicyException$ = [
      -3,
      n032,
      _IPE2,
      { [_aQE10]: [`IncompatiblePolicyException`, 400], [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.IncompatiblePolicyException$, errors_1.IncompatiblePolicyException);
    exports2.InternalServerError$ = [
      -3,
      n032,
      _ISE13,
      { [_aQE10]: [`InternalServerError`, 500], [_e32]: _se14 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InternalServerError$, errors_1.InternalServerError);
    exports2.InvalidActivation$ = [
      -3,
      n032,
      _IA,
      { [_aQE10]: [`InvalidActivation`, 404], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidActivation$, errors_1.InvalidActivation);
    exports2.InvalidActivationId$ = [
      -3,
      n032,
      _IAI,
      { [_aQE10]: [`InvalidActivationId`, 404], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidActivationId$, errors_1.InvalidActivationId);
    exports2.InvalidAggregatorException$ = [
      -3,
      n032,
      _IAE,
      { [_aQE10]: [`InvalidAggregator`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidAggregatorException$, errors_1.InvalidAggregatorException);
    exports2.InvalidAllowedPatternException$ = [
      -3,
      n032,
      _IAPE,
      { [_aQE10]: [`InvalidAllowedPatternException`, 400], [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidAllowedPatternException$, errors_1.InvalidAllowedPatternException);
    exports2.InvalidAssociation$ = [
      -3,
      n032,
      _IAn,
      { [_aQE10]: [`InvalidAssociation`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidAssociation$, errors_1.InvalidAssociation);
    exports2.InvalidAssociationVersion$ = [
      -3,
      n032,
      _IAV,
      { [_aQE10]: [`InvalidAssociationVersion`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidAssociationVersion$, errors_1.InvalidAssociationVersion);
    exports2.InvalidAutomationExecutionParametersException$ = [
      -3,
      n032,
      _IAEPE,
      { [_aQE10]: [`InvalidAutomationExecutionParameters`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidAutomationExecutionParametersException$, errors_1.InvalidAutomationExecutionParametersException);
    exports2.InvalidAutomationSignalException$ = [
      -3,
      n032,
      _IASE,
      { [_aQE10]: [`InvalidAutomationSignalException`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidAutomationSignalException$, errors_1.InvalidAutomationSignalException);
    exports2.InvalidAutomationStatusUpdateException$ = [
      -3,
      n032,
      _IASUE,
      { [_aQE10]: [`InvalidAutomationStatusUpdateException`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidAutomationStatusUpdateException$, errors_1.InvalidAutomationStatusUpdateException);
    exports2.InvalidCommandId$ = [
      -3,
      n032,
      _ICI,
      { [_aQE10]: [`InvalidCommandId`, 404], [_e32]: _c32 },
      [],
      []
    ];
    n0_registry32.registerError(exports2.InvalidCommandId$, errors_1.InvalidCommandId);
    exports2.InvalidDeleteInventoryParametersException$ = [
      -3,
      n032,
      _IDIPE,
      { [_aQE10]: [`InvalidDeleteInventoryParameters`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidDeleteInventoryParametersException$, errors_1.InvalidDeleteInventoryParametersException);
    exports2.InvalidDeletionIdException$ = [
      -3,
      n032,
      _IDIE,
      { [_aQE10]: [`InvalidDeletionId`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidDeletionIdException$, errors_1.InvalidDeletionIdException);
    exports2.InvalidDocument$ = [
      -3,
      n032,
      _ID,
      { [_aQE10]: [`InvalidDocument`, 404], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidDocument$, errors_1.InvalidDocument);
    exports2.InvalidDocumentContent$ = [
      -3,
      n032,
      _IDC,
      { [_aQE10]: [`InvalidDocumentContent`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidDocumentContent$, errors_1.InvalidDocumentContent);
    exports2.InvalidDocumentOperation$ = [
      -3,
      n032,
      _IDO,
      { [_aQE10]: [`InvalidDocumentOperation`, 403], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidDocumentOperation$, errors_1.InvalidDocumentOperation);
    exports2.InvalidDocumentSchemaVersion$ = [
      -3,
      n032,
      _IDSV,
      { [_aQE10]: [`InvalidDocumentSchemaVersion`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidDocumentSchemaVersion$, errors_1.InvalidDocumentSchemaVersion);
    exports2.InvalidDocumentType$ = [
      -3,
      n032,
      _IDT,
      { [_aQE10]: [`InvalidDocumentType`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidDocumentType$, errors_1.InvalidDocumentType);
    exports2.InvalidDocumentVersion$ = [
      -3,
      n032,
      _IDV,
      { [_aQE10]: [`InvalidDocumentVersion`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidDocumentVersion$, errors_1.InvalidDocumentVersion);
    exports2.InvalidFilter$ = [
      -3,
      n032,
      _IF,
      { [_aQE10]: [`InvalidFilter`, 441], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidFilter$, errors_1.InvalidFilter);
    exports2.InvalidFilterKey$ = [
      -3,
      n032,
      _IFK,
      { [_aQE10]: [`InvalidFilterKey`, 400], [_e32]: _c32 },
      [],
      []
    ];
    n0_registry32.registerError(exports2.InvalidFilterKey$, errors_1.InvalidFilterKey);
    exports2.InvalidFilterOption$ = [
      -3,
      n032,
      _IFO,
      { [_aQE10]: [`InvalidFilterOption`, 400], [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidFilterOption$, errors_1.InvalidFilterOption);
    exports2.InvalidFilterValue$ = [
      -3,
      n032,
      _IFV,
      { [_aQE10]: [`InvalidFilterValue`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidFilterValue$, errors_1.InvalidFilterValue);
    exports2.InvalidInstanceId$ = [
      -3,
      n032,
      _III,
      { [_aQE10]: [`InvalidInstanceId`, 404], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidInstanceId$, errors_1.InvalidInstanceId);
    exports2.InvalidInstanceInformationFilterValue$ = [
      -3,
      n032,
      _IIIFV,
      { [_aQE10]: [`InvalidInstanceInformationFilterValue`, 400], [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidInstanceInformationFilterValue$, errors_1.InvalidInstanceInformationFilterValue);
    exports2.InvalidInstancePropertyFilterValue$ = [
      -3,
      n032,
      _IIPFV,
      { [_aQE10]: [`InvalidInstancePropertyFilterValue`, 400], [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidInstancePropertyFilterValue$, errors_1.InvalidInstancePropertyFilterValue);
    exports2.InvalidInventoryGroupException$ = [
      -3,
      n032,
      _IIGE,
      { [_aQE10]: [`InvalidInventoryGroup`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidInventoryGroupException$, errors_1.InvalidInventoryGroupException);
    exports2.InvalidInventoryItemContextException$ = [
      -3,
      n032,
      _IIICE,
      { [_aQE10]: [`InvalidInventoryItemContext`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidInventoryItemContextException$, errors_1.InvalidInventoryItemContextException);
    exports2.InvalidInventoryRequestException$ = [
      -3,
      n032,
      _IIRE,
      { [_aQE10]: [`InvalidInventoryRequest`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidInventoryRequestException$, errors_1.InvalidInventoryRequestException);
    exports2.InvalidItemContentException$ = [
      -3,
      n032,
      _IICE,
      { [_aQE10]: [`InvalidItemContent`, 400], [_e32]: _c32 },
      [_TN, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.InvalidItemContentException$, errors_1.InvalidItemContentException);
    exports2.InvalidKeyId$ = [
      -3,
      n032,
      _IKI,
      { [_aQE10]: [`InvalidKeyId`, 400], [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidKeyId$, errors_1.InvalidKeyId);
    exports2.InvalidNextToken$ = [
      -3,
      n032,
      _INT,
      { [_aQE10]: [`InvalidNextToken`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidNextToken$, errors_1.InvalidNextToken);
    exports2.InvalidNotificationConfig$ = [
      -3,
      n032,
      _INC,
      { [_aQE10]: [`InvalidNotificationConfig`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidNotificationConfig$, errors_1.InvalidNotificationConfig);
    exports2.InvalidOptionException$ = [
      -3,
      n032,
      _IOE,
      { [_aQE10]: [`InvalidOption`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidOptionException$, errors_1.InvalidOptionException);
    exports2.InvalidOutputFolder$ = [
      -3,
      n032,
      _IOF,
      { [_aQE10]: [`InvalidOutputFolder`, 400], [_e32]: _c32 },
      [],
      []
    ];
    n0_registry32.registerError(exports2.InvalidOutputFolder$, errors_1.InvalidOutputFolder);
    exports2.InvalidOutputLocation$ = [
      -3,
      n032,
      _IOL,
      { [_aQE10]: [`InvalidOutputLocation`, 400], [_e32]: _c32 },
      [],
      []
    ];
    n0_registry32.registerError(exports2.InvalidOutputLocation$, errors_1.InvalidOutputLocation);
    exports2.InvalidParameters$ = [
      -3,
      n032,
      _IP,
      { [_aQE10]: [`InvalidParameters`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidParameters$, errors_1.InvalidParameters);
    exports2.InvalidPermissionType$ = [
      -3,
      n032,
      _IPT2,
      { [_aQE10]: [`InvalidPermissionType`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidPermissionType$, errors_1.InvalidPermissionType);
    exports2.InvalidPluginName$ = [
      -3,
      n032,
      _IPN,
      { [_aQE10]: [`InvalidPluginName`, 404], [_e32]: _c32 },
      [],
      []
    ];
    n0_registry32.registerError(exports2.InvalidPluginName$, errors_1.InvalidPluginName);
    exports2.InvalidPolicyAttributeException$ = [
      -3,
      n032,
      _IPAE,
      { [_aQE10]: [`InvalidPolicyAttributeException`, 400], [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidPolicyAttributeException$, errors_1.InvalidPolicyAttributeException);
    exports2.InvalidPolicyTypeException$ = [
      -3,
      n032,
      _IPTE,
      { [_aQE10]: [`InvalidPolicyTypeException`, 400], [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidPolicyTypeException$, errors_1.InvalidPolicyTypeException);
    exports2.InvalidResourceId$ = [
      -3,
      n032,
      _IRI,
      { [_aQE10]: [`InvalidResourceId`, 400], [_e32]: _c32 },
      [],
      []
    ];
    n0_registry32.registerError(exports2.InvalidResourceId$, errors_1.InvalidResourceId);
    exports2.InvalidResourceType$ = [
      -3,
      n032,
      _IRT,
      { [_aQE10]: [`InvalidResourceType`, 400], [_e32]: _c32 },
      [],
      []
    ];
    n0_registry32.registerError(exports2.InvalidResourceType$, errors_1.InvalidResourceType);
    exports2.InvalidResultAttributeException$ = [
      -3,
      n032,
      _IRAE,
      { [_aQE10]: [`InvalidResultAttribute`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidResultAttributeException$, errors_1.InvalidResultAttributeException);
    exports2.InvalidRole$ = [
      -3,
      n032,
      _IR,
      { [_aQE10]: [`InvalidRole`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidRole$, errors_1.InvalidRole);
    exports2.InvalidSchedule$ = [
      -3,
      n032,
      _IS,
      { [_aQE10]: [`InvalidSchedule`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidSchedule$, errors_1.InvalidSchedule);
    exports2.InvalidTag$ = [
      -3,
      n032,
      _IT4,
      { [_aQE10]: [`InvalidTag`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidTag$, errors_1.InvalidTag);
    exports2.InvalidTarget$ = [
      -3,
      n032,
      _ITn,
      { [_aQE10]: [`InvalidTarget`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidTarget$, errors_1.InvalidTarget);
    exports2.InvalidTargetMaps$ = [
      -3,
      n032,
      _ITM,
      { [_aQE10]: [`InvalidTargetMaps`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidTargetMaps$, errors_1.InvalidTargetMaps);
    exports2.InvalidTypeNameException$ = [
      -3,
      n032,
      _ITNE,
      { [_aQE10]: [`InvalidTypeName`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidTypeNameException$, errors_1.InvalidTypeNameException);
    exports2.InvalidUpdate$ = [
      -3,
      n032,
      _IU,
      { [_aQE10]: [`InvalidUpdate`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.InvalidUpdate$, errors_1.InvalidUpdate);
    exports2.InvocationDoesNotExist$ = [
      -3,
      n032,
      _IDNE,
      { [_aQE10]: [`InvocationDoesNotExist`, 400], [_e32]: _c32 },
      [],
      []
    ];
    n0_registry32.registerError(exports2.InvocationDoesNotExist$, errors_1.InvocationDoesNotExist);
    exports2.ItemContentMismatchException$ = [
      -3,
      n032,
      _ICME,
      { [_aQE10]: [`ItemContentMismatch`, 400], [_e32]: _c32 },
      [_TN, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.ItemContentMismatchException$, errors_1.ItemContentMismatchException);
    exports2.ItemSizeLimitExceededException$ = [
      -3,
      n032,
      _ISLEE,
      { [_aQE10]: [`ItemSizeLimitExceeded`, 400], [_e32]: _c32 },
      [_TN, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.ItemSizeLimitExceededException$, errors_1.ItemSizeLimitExceededException);
    exports2.MalformedResourcePolicyDocumentException$ = [
      -3,
      n032,
      _MRPDE,
      { [_aQE10]: [`MalformedResourcePolicyDocumentException`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.MalformedResourcePolicyDocumentException$, errors_1.MalformedResourcePolicyDocumentException);
    exports2.MaxDocumentSizeExceeded$ = [
      -3,
      n032,
      _MDSE,
      { [_aQE10]: [`MaxDocumentSizeExceeded`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.MaxDocumentSizeExceeded$, errors_1.MaxDocumentSizeExceeded);
    exports2.NoLongerSupportedException$ = [
      -3,
      n032,
      _NLSE,
      { [_aQE10]: [`NoLongerSupported`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.NoLongerSupportedException$, errors_1.NoLongerSupportedException);
    exports2.OpsItemAccessDeniedException$ = [
      -3,
      n032,
      _OIADE,
      { [_aQE10]: [`OpsItemAccessDeniedException`, 403], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.OpsItemAccessDeniedException$, errors_1.OpsItemAccessDeniedException);
    exports2.OpsItemAlreadyExistsException$ = [
      -3,
      n032,
      _OIAEE,
      { [_aQE10]: [`OpsItemAlreadyExistsException`, 400], [_e32]: _c32 },
      [_M, _OII],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.OpsItemAlreadyExistsException$, errors_1.OpsItemAlreadyExistsException);
    exports2.OpsItemConflictException$ = [
      -3,
      n032,
      _OICE,
      { [_aQE10]: [`OpsItemConflictException`, 409], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.OpsItemConflictException$, errors_1.OpsItemConflictException);
    exports2.OpsItemInvalidParameterException$ = [
      -3,
      n032,
      _OIIPE,
      { [_aQE10]: [`OpsItemInvalidParameterException`, 400], [_e32]: _c32 },
      [_PN, _M],
      [64 | 0, 0]
    ];
    n0_registry32.registerError(exports2.OpsItemInvalidParameterException$, errors_1.OpsItemInvalidParameterException);
    exports2.OpsItemLimitExceededException$ = [
      -3,
      n032,
      _OILEE,
      { [_aQE10]: [`OpsItemLimitExceededException`, 400], [_e32]: _c32 },
      [_RT13, _L2, _LT, _M],
      [64 | 0, 1, 0, 0]
    ];
    n0_registry32.registerError(exports2.OpsItemLimitExceededException$, errors_1.OpsItemLimitExceededException);
    exports2.OpsItemNotFoundException$ = [
      -3,
      n032,
      _OINFE,
      { [_aQE10]: [`OpsItemNotFoundException`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.OpsItemNotFoundException$, errors_1.OpsItemNotFoundException);
    exports2.OpsItemRelatedItemAlreadyExistsException$ = [
      -3,
      n032,
      _OIRIAEE,
      { [_aQE10]: [`OpsItemRelatedItemAlreadyExistsException`, 400], [_e32]: _c32 },
      [_M, _RU, _OII],
      [0, 0, 0]
    ];
    n0_registry32.registerError(exports2.OpsItemRelatedItemAlreadyExistsException$, errors_1.OpsItemRelatedItemAlreadyExistsException);
    exports2.OpsItemRelatedItemAssociationNotFoundException$ = [
      -3,
      n032,
      _OIRIANFE,
      { [_aQE10]: [`OpsItemRelatedItemAssociationNotFoundException`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.OpsItemRelatedItemAssociationNotFoundException$, errors_1.OpsItemRelatedItemAssociationNotFoundException);
    exports2.OpsMetadataAlreadyExistsException$ = [
      -3,
      n032,
      _OMAEE,
      { [_aQE10]: [`OpsMetadataAlreadyExistsException`, 400], [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.OpsMetadataAlreadyExistsException$, errors_1.OpsMetadataAlreadyExistsException);
    exports2.OpsMetadataInvalidArgumentException$ = [
      -3,
      n032,
      _OMIAE,
      { [_aQE10]: [`OpsMetadataInvalidArgumentException`, 400], [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.OpsMetadataInvalidArgumentException$, errors_1.OpsMetadataInvalidArgumentException);
    exports2.OpsMetadataKeyLimitExceededException$ = [
      -3,
      n032,
      _OMKLEE,
      { [_aQE10]: [`OpsMetadataKeyLimitExceededException`, 429], [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.OpsMetadataKeyLimitExceededException$, errors_1.OpsMetadataKeyLimitExceededException);
    exports2.OpsMetadataLimitExceededException$ = [
      -3,
      n032,
      _OMLEE,
      { [_aQE10]: [`OpsMetadataLimitExceededException`, 429], [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.OpsMetadataLimitExceededException$, errors_1.OpsMetadataLimitExceededException);
    exports2.OpsMetadataNotFoundException$ = [
      -3,
      n032,
      _OMNFE,
      { [_aQE10]: [`OpsMetadataNotFoundException`, 404], [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.OpsMetadataNotFoundException$, errors_1.OpsMetadataNotFoundException);
    exports2.OpsMetadataTooManyUpdatesException$ = [
      -3,
      n032,
      _OMTMUE,
      { [_aQE10]: [`OpsMetadataTooManyUpdatesException`, 429], [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.OpsMetadataTooManyUpdatesException$, errors_1.OpsMetadataTooManyUpdatesException);
    exports2.ParameterAlreadyExists$ = [
      -3,
      n032,
      _PAE,
      { [_aQE10]: [`ParameterAlreadyExists`, 400], [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ParameterAlreadyExists$, errors_1.ParameterAlreadyExists);
    exports2.ParameterLimitExceeded$ = [
      -3,
      n032,
      _PLE,
      { [_aQE10]: [`ParameterLimitExceeded`, 429], [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ParameterLimitExceeded$, errors_1.ParameterLimitExceeded);
    exports2.ParameterMaxVersionLimitExceeded$ = [
      -3,
      n032,
      _PMVLE,
      { [_aQE10]: [`ParameterMaxVersionLimitExceeded`, 400], [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ParameterMaxVersionLimitExceeded$, errors_1.ParameterMaxVersionLimitExceeded);
    exports2.ParameterNotFound$ = [
      -3,
      n032,
      _PNF,
      { [_aQE10]: [`ParameterNotFound`, 404], [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ParameterNotFound$, errors_1.ParameterNotFound);
    exports2.ParameterPatternMismatchException$ = [
      -3,
      n032,
      _PPME,
      { [_aQE10]: [`ParameterPatternMismatchException`, 400], [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ParameterPatternMismatchException$, errors_1.ParameterPatternMismatchException);
    exports2.ParameterVersionLabelLimitExceeded$ = [
      -3,
      n032,
      _PVLLE,
      { [_aQE10]: [`ParameterVersionLabelLimitExceeded`, 400], [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ParameterVersionLabelLimitExceeded$, errors_1.ParameterVersionLabelLimitExceeded);
    exports2.ParameterVersionNotFound$ = [
      -3,
      n032,
      _PVNF,
      { [_aQE10]: [`ParameterVersionNotFound`, 400], [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.ParameterVersionNotFound$, errors_1.ParameterVersionNotFound);
    exports2.PoliciesLimitExceededException$ = [
      -3,
      n032,
      _PLEE,
      { [_aQE10]: [`PoliciesLimitExceededException`, 400], [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.PoliciesLimitExceededException$, errors_1.PoliciesLimitExceededException);
    exports2.ResourceDataSyncAlreadyExistsException$ = [
      -3,
      n032,
      _RDSAEE,
      { [_aQE10]: [`ResourceDataSyncAlreadyExists`, 400], [_e32]: _c32 },
      [_SN10],
      [0]
    ];
    n0_registry32.registerError(exports2.ResourceDataSyncAlreadyExistsException$, errors_1.ResourceDataSyncAlreadyExistsException);
    exports2.ResourceDataSyncConflictException$ = [
      -3,
      n032,
      _RDSCE,
      { [_aQE10]: [`ResourceDataSyncConflictException`, 409], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ResourceDataSyncConflictException$, errors_1.ResourceDataSyncConflictException);
    exports2.ResourceDataSyncCountExceededException$ = [
      -3,
      n032,
      _RDSCEE,
      { [_aQE10]: [`ResourceDataSyncCountExceeded`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ResourceDataSyncCountExceededException$, errors_1.ResourceDataSyncCountExceededException);
    exports2.ResourceDataSyncInvalidConfigurationException$ = [
      -3,
      n032,
      _RDSICE,
      { [_aQE10]: [`ResourceDataSyncInvalidConfiguration`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ResourceDataSyncInvalidConfigurationException$, errors_1.ResourceDataSyncInvalidConfigurationException);
    exports2.ResourceDataSyncNotFoundException$ = [
      -3,
      n032,
      _RDSNFE,
      { [_aQE10]: [`ResourceDataSyncNotFound`, 404], [_e32]: _c32 },
      [_SN10, _ST11, _M],
      [0, 0, 0]
    ];
    n0_registry32.registerError(exports2.ResourceDataSyncNotFoundException$, errors_1.ResourceDataSyncNotFoundException);
    exports2.ResourceInUseException$ = [
      -3,
      n032,
      _RIUE,
      { [_aQE10]: [`ResourceInUseException`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ResourceInUseException$, errors_1.ResourceInUseException);
    exports2.ResourceLimitExceededException$ = [
      -3,
      n032,
      _RLEE,
      { [_aQE10]: [`ResourceLimitExceededException`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ResourceLimitExceededException$, errors_1.ResourceLimitExceededException);
    exports2.ResourceNotFoundException$ = [
      -3,
      n032,
      _RNFE11,
      { [_aQE10]: [`ResourceNotFoundException`, 404], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ResourceNotFoundException$, errors_1.ResourceNotFoundException);
    exports2.ResourcePolicyConflictException$ = [
      -3,
      n032,
      _RPCE,
      { [_aQE10]: [`ResourcePolicyConflictException`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ResourcePolicyConflictException$, errors_1.ResourcePolicyConflictException);
    exports2.ResourcePolicyInvalidParameterException$ = [
      -3,
      n032,
      _RPIPE,
      { [_aQE10]: [`ResourcePolicyInvalidParameterException`, 400], [_e32]: _c32 },
      [_PN, _M],
      [64 | 0, 0]
    ];
    n0_registry32.registerError(exports2.ResourcePolicyInvalidParameterException$, errors_1.ResourcePolicyInvalidParameterException);
    exports2.ResourcePolicyLimitExceededException$ = [
      -3,
      n032,
      _RPLEE,
      { [_aQE10]: [`ResourcePolicyLimitExceededException`, 400], [_e32]: _c32 },
      [_L2, _LT, _M],
      [1, 0, 0]
    ];
    n0_registry32.registerError(exports2.ResourcePolicyLimitExceededException$, errors_1.ResourcePolicyLimitExceededException);
    exports2.ResourcePolicyNotFoundException$ = [
      -3,
      n032,
      _RPNFE,
      { [_aQE10]: [`ResourcePolicyNotFoundException`, 404], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ResourcePolicyNotFoundException$, errors_1.ResourcePolicyNotFoundException);
    exports2.ServiceQuotaExceededException$ = [
      -3,
      n032,
      _SQEE,
      { [_e32]: _c32 },
      [_M, _QC, _SC, _RI, _RTe],
      [0, 0, 0, 0, 0],
      3
    ];
    n0_registry32.registerError(exports2.ServiceQuotaExceededException$, errors_1.ServiceQuotaExceededException);
    exports2.ServiceSettingNotFound$ = [
      -3,
      n032,
      _SSNF,
      { [_aQE10]: [`ServiceSettingNotFound`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.ServiceSettingNotFound$, errors_1.ServiceSettingNotFound);
    exports2.StatusUnchanged$ = [
      -3,
      n032,
      _SU,
      { [_aQE10]: [`StatusUnchanged`, 400], [_e32]: _c32 },
      [],
      []
    ];
    n0_registry32.registerError(exports2.StatusUnchanged$, errors_1.StatusUnchanged);
    exports2.SubTypeCountLimitExceededException$ = [
      -3,
      n032,
      _STCLEE,
      { [_aQE10]: [`SubTypeCountLimitExceeded`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.SubTypeCountLimitExceededException$, errors_1.SubTypeCountLimitExceededException);
    exports2.TargetInUseException$ = [
      -3,
      n032,
      _TIUE,
      { [_aQE10]: [`TargetInUseException`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.TargetInUseException$, errors_1.TargetInUseException);
    exports2.TargetNotConnected$ = [
      -3,
      n032,
      _TNC,
      { [_aQE10]: [`TargetNotConnected`, 430], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.TargetNotConnected$, errors_1.TargetNotConnected);
    exports2.ThrottlingException$ = [
      -3,
      n032,
      _TE,
      { [_e32]: _c32 },
      [_M, _QC, _SC],
      [0, 0, 0],
      1
    ];
    n0_registry32.registerError(exports2.ThrottlingException$, errors_1.ThrottlingException);
    exports2.TooManyTagsError$ = [
      -3,
      n032,
      _TMTE,
      { [_aQE10]: [`TooManyTagsError`, 400], [_e32]: _c32 },
      [],
      []
    ];
    n0_registry32.registerError(exports2.TooManyTagsError$, errors_1.TooManyTagsError);
    exports2.TooManyUpdates$ = [
      -3,
      n032,
      _TMU,
      { [_aQE10]: [`TooManyUpdates`, 429], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.TooManyUpdates$, errors_1.TooManyUpdates);
    exports2.TotalSizeLimitExceededException$ = [
      -3,
      n032,
      _TSLEE,
      { [_aQE10]: [`TotalSizeLimitExceeded`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.TotalSizeLimitExceededException$, errors_1.TotalSizeLimitExceededException);
    exports2.UnsupportedCalendarException$ = [
      -3,
      n032,
      _UCE4,
      { [_aQE10]: [`UnsupportedCalendarException`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.UnsupportedCalendarException$, errors_1.UnsupportedCalendarException);
    exports2.UnsupportedFeatureRequiredException$ = [
      -3,
      n032,
      _UFRE,
      { [_aQE10]: [`UnsupportedFeatureRequiredException`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.UnsupportedFeatureRequiredException$, errors_1.UnsupportedFeatureRequiredException);
    exports2.UnsupportedInventoryItemContextException$ = [
      -3,
      n032,
      _UIICE,
      { [_aQE10]: [`UnsupportedInventoryItemContext`, 400], [_e32]: _c32 },
      [_TN, _M],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.UnsupportedInventoryItemContextException$, errors_1.UnsupportedInventoryItemContextException);
    exports2.UnsupportedInventorySchemaVersionException$ = [
      -3,
      n032,
      _UISVE,
      { [_aQE10]: [`UnsupportedInventorySchemaVersion`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.UnsupportedInventorySchemaVersionException$, errors_1.UnsupportedInventorySchemaVersionException);
    exports2.UnsupportedOperatingSystem$ = [
      -3,
      n032,
      _UOS,
      { [_aQE10]: [`UnsupportedOperatingSystem`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.UnsupportedOperatingSystem$, errors_1.UnsupportedOperatingSystem);
    exports2.UnsupportedOperationException$ = [
      -3,
      n032,
      _UOE,
      { [_aQE10]: [`UnsupportedOperation`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.UnsupportedOperationException$, errors_1.UnsupportedOperationException);
    exports2.UnsupportedParameterType$ = [
      -3,
      n032,
      _UPT,
      { [_aQE10]: [`UnsupportedParameterType`, 400], [_e32]: _c32 },
      [_m29],
      [0]
    ];
    n0_registry32.registerError(exports2.UnsupportedParameterType$, errors_1.UnsupportedParameterType);
    exports2.UnsupportedPlatformType$ = [
      -3,
      n032,
      _UPTn,
      { [_aQE10]: [`UnsupportedPlatformType`, 400], [_e32]: _c32 },
      [_M],
      [0]
    ];
    n0_registry32.registerError(exports2.UnsupportedPlatformType$, errors_1.UnsupportedPlatformType);
    exports2.ValidationException$ = [
      -3,
      n032,
      _VE10,
      { [_aQE10]: [`ValidationException`, 400], [_e32]: _c32 },
      [_M, _RC10],
      [0, 0]
    ];
    n0_registry32.registerError(exports2.ValidationException$, errors_1.ValidationException);
    exports2.errorTypeRegistries = [
      _s_registry32,
      n0_registry32
    ];
    var AccessKeySecretType = [0, n032, _AKST, 8, 0];
    var IPAddress = [0, n032, _IPA, 8, 0];
    var MaintenanceWindowDescription = [0, n032, _MWD, 8, 0];
    var MaintenanceWindowExecutionTaskInvocationParameters = [0, n032, _MWETIP, 8, 0];
    var MaintenanceWindowLambdaPayload = [0, n032, _MWLP, 8, 21];
    var MaintenanceWindowStepFunctionsInput = [0, n032, _MWSFI, 8, 0];
    var MaintenanceWindowTaskParameterValue = [0, n032, _MWTPV, 8, 0];
    var OwnerInformation = [0, n032, _OI, 8, 0];
    var PatchSourceConfiguration = [0, n032, _PSC, 8, 0];
    var PSParameterValue = [0, n032, _PSPV, 8, 0];
    var SessionTokenType10 = [0, n032, _STT10, 8, 0];
    exports2.AccountSharingInfo$ = [
      3,
      n032,
      _ASI,
      0,
      [_AIc, _SDV],
      [0, 0]
    ];
    exports2.Activation$ = [
      3,
      n032,
      _A10,
      0,
      [_AIct, _D, _DIN, _IRa, _RL, _RCe, _ED, _E11, _CD, _T10],
      [0, 0, 0, 0, 1, 1, 4, 2, 4, () => TagList]
    ];
    exports2.AddTagsToResourceRequest$ = [
      3,
      n032,
      _ATTRR,
      0,
      [_RTe, _RI, _T10],
      [0, 0, () => TagList],
      3
    ];
    exports2.AddTagsToResourceResult$ = [
      3,
      n032,
      _ATTRRd,
      0,
      [],
      []
    ];
    exports2.Alarm$ = [
      3,
      n032,
      _Al,
      0,
      [_N],
      [0],
      1
    ];
    exports2.AlarmConfiguration$ = [
      3,
      n032,
      _AC,
      0,
      [_Ala, _IPAF],
      [() => AlarmList, 2],
      1
    ];
    exports2.AlarmStateInformation$ = [
      3,
      n032,
      _ASIl,
      0,
      [_N, _S],
      [0, 0],
      2
    ];
    exports2.AssociateOpsItemRelatedItemRequest$ = [
      3,
      n032,
      _AOIRIR,
      0,
      [_OII, _AT13, _RTe, _RU],
      [0, 0, 0, 0],
      4
    ];
    exports2.AssociateOpsItemRelatedItemResponse$ = [
      3,
      n032,
      _AOIRIRs,
      0,
      [_AIs],
      [0]
    ];
    exports2.Association$ = [
      3,
      n032,
      _As,
      0,
      [_N, _II2, _AIs, _AV, _DV, _Ta10, _LED, _O, _SE, _AN, _SO, _Du, _TM],
      [0, 0, 0, 0, 0, () => Targets2, 4, () => exports2.AssociationOverview$, 0, 0, 1, 1, [1, n032, _TM, 0, [2, n032, _TMa, 0, 0, 64 | 0]]]
    ];
    exports2.AssociationDescription$ = [
      3,
      n032,
      _AD,
      0,
      [_N, _II2, _AV, _Da, _LUAD, _St, _O, _DV, _ATPN, _P10, _AIs, _Ta10, _SE, _OL, _LED, _LSED, _AN, _ME, _MC, _CS4, _SCy, _AOACI, _CN, _TL, _SO, _Du, _TM, _AC, _TA, _ADAR],
      [0, 0, 0, 4, 4, () => exports2.AssociationStatus$, () => exports2.AssociationOverview$, 0, 0, [() => _Parameters, 0], 0, () => Targets2, 0, () => exports2.InstanceAssociationOutputLocation$, 4, 4, 0, 0, 0, 0, 0, 2, 64 | 0, () => TargetLocations, 1, 1, [1, n032, _TM, 0, [2, n032, _TMa, 0, 0, 64 | 0]], () => exports2.AlarmConfiguration$, () => AlarmStateInformationList, 0]
    ];
    exports2.AssociationExecution$ = [
      3,
      n032,
      _AE,
      0,
      [_AIs, _AV, _EI10, _St, _DS10, _CT4, _LED, _RCBS, _AC, _TA],
      [0, 0, 0, 0, 0, 4, 4, 0, () => exports2.AlarmConfiguration$, () => AlarmStateInformationList]
    ];
    exports2.AssociationExecutionFilter$ = [
      3,
      n032,
      _AEF,
      0,
      [_K10, _V10, _Ty],
      [0, 0, 0],
      3
    ];
    exports2.AssociationExecutionTarget$ = [
      3,
      n032,
      _AET,
      0,
      [_AIs, _AV, _EI10, _RI, _RTe, _St, _DS10, _LED, _OS],
      [0, 0, 0, 0, 0, 0, 0, 4, () => exports2.OutputSource$]
    ];
    exports2.AssociationExecutionTargetsFilter$ = [
      3,
      n032,
      _AETF,
      0,
      [_K10, _V10],
      [0, 0],
      2
    ];
    exports2.AssociationFilter$ = [
      3,
      n032,
      _AF,
      0,
      [_k, _v],
      [0, 0],
      2
    ];
    exports2.AssociationOverview$ = [
      3,
      n032,
      _AO,
      0,
      [_St, _DS10, _ASAC],
      [0, 0, 128 | 1]
    ];
    exports2.AssociationStatus$ = [
      3,
      n032,
      _AS,
      0,
      [_Da, _N, _M, _AId],
      [4, 0, 0, 0],
      3
    ];
    exports2.AssociationVersionInfo$ = [
      3,
      n032,
      _AVI,
      0,
      [_AIs, _AV, _CD, _N, _DV, _P10, _Ta10, _SE, _OL, _AN, _ME, _MC, _CS4, _SCy, _AOACI, _CN, _TL, _SO, _Du, _TM, _ADAR],
      [0, 0, 4, 0, 0, [() => _Parameters, 0], () => Targets2, 0, () => exports2.InstanceAssociationOutputLocation$, 0, 0, 0, 0, 0, 2, 64 | 0, () => TargetLocations, 1, 1, [1, n032, _TM, 0, [2, n032, _TMa, 0, 0, 64 | 0]], 0]
    ];
    exports2.AttachmentContent$ = [
      3,
      n032,
      _ACt,
      0,
      [_N, _Si, _H, _HT, _U],
      [0, 1, 0, 0, 0]
    ];
    exports2.AttachmentInformation$ = [
      3,
      n032,
      _AIt,
      0,
      [_N],
      [0]
    ];
    exports2.AttachmentsSource$ = [
      3,
      n032,
      _ASt,
      0,
      [_K10, _Va, _N],
      [0, 64 | 0, 0]
    ];
    exports2.AutomationExecution$ = [
      3,
      n032,
      _AEu,
      0,
      [_AEI, _DN, _DV, _EST, _EET, _AES, _SEt, _SET, _P10, _Ou, _FM, _Mo, _PAEI, _EB, _CSN, _CA10, _TPN, _Ta10, _TM, _RTes, _MC, _ME, _Tar, _TL, _PC10, _AC, _TA, _TLURL, _ASu, _STc, _R, _OII, _AIs, _CRN, _Var],
      [0, 0, 0, 4, 4, 0, () => StepExecutionList, 2, [2, n032, _APM, 0, 0, 64 | 0], [2, n032, _APM, 0, 0, 64 | 0], 0, 0, 0, 0, 0, 0, 0, () => Targets2, [1, n032, _TM, 0, [2, n032, _TMa, 0, 0, 64 | 0]], () => exports2.ResolvedTargets$, 0, 0, 0, () => TargetLocations, () => exports2.ProgressCounters$, () => exports2.AlarmConfiguration$, () => AlarmStateInformationList, 0, 0, 4, () => Runbooks, 0, 0, 0, [2, n032, _APM, 0, 0, 64 | 0]]
    ];
    exports2.AutomationExecutionFilter$ = [
      3,
      n032,
      _AEFu,
      0,
      [_K10, _Va],
      [0, 64 | 0],
      2
    ];
    exports2.AutomationExecutionInputs$ = [
      3,
      n032,
      _AEIu,
      0,
      [_P10, _TPN, _Ta10, _TM, _TL, _TLURL],
      [[2, n032, _APM, 0, 0, 64 | 0], 0, () => Targets2, [1, n032, _TM, 0, [2, n032, _TMa, 0, 0, 64 | 0]], () => TargetLocations, 0]
    ];
    exports2.AutomationExecutionMetadata$ = [
      3,
      n032,
      _AEM,
      0,
      [_AEI, _DN, _DV, _AES, _EST, _EET, _EB, _LF, _Ou, _Mo, _PAEI, _CSN, _CA10, _FM, _TPN, _Ta10, _TM, _RTes, _MC, _ME, _Tar, _ATu, _AC, _TA, _TLURL, _ASu, _STc, _R, _OII, _AIs, _CRN],
      [0, 0, 0, 0, 4, 4, 0, 0, [2, n032, _APM, 0, 0, 64 | 0], 0, 0, 0, 0, 0, 0, () => Targets2, [1, n032, _TM, 0, [2, n032, _TMa, 0, 0, 64 | 0]], () => exports2.ResolvedTargets$, 0, 0, 0, 0, () => exports2.AlarmConfiguration$, () => AlarmStateInformationList, 0, 0, 4, () => Runbooks, 0, 0, 0]
    ];
    exports2.AutomationExecutionPreview$ = [
      3,
      n032,
      _AEP,
      0,
      [_SP, _Re, _TP, _TAo],
      [128 | 1, 64 | 0, () => TargetPreviewList, 1]
    ];
    exports2.BaselineOverride$ = [
      3,
      n032,
      _BO,
      0,
      [_OSp, _GF, _AR10, _AP, _APCL, _RP, _RPA, _APENS, _So, _ASUCS],
      [0, () => exports2.PatchFilterGroup$, () => exports2.PatchRuleGroup$, 64 | 0, 0, 64 | 0, 0, 2, [() => PatchSourceList, 0], 0]
    ];
    exports2.CancelCommandRequest$ = [
      3,
      n032,
      _CCR,
      0,
      [_CI, _IIn],
      [0, 64 | 0],
      1
    ];
    exports2.CancelCommandResult$ = [
      3,
      n032,
      _CCRa,
      0,
      [],
      []
    ];
    exports2.CancelMaintenanceWindowExecutionRequest$ = [
      3,
      n032,
      _CMWER,
      0,
      [_WEI],
      [0],
      1
    ];
    exports2.CancelMaintenanceWindowExecutionResult$ = [
      3,
      n032,
      _CMWERa,
      0,
      [_WEI],
      [0]
    ];
    exports2.CloudWatchOutputConfig$ = [
      3,
      n032,
      _CWOC,
      0,
      [_CWLGN, _CWOE],
      [0, 2]
    ];
    exports2.Command$ = [
      3,
      n032,
      _C11,
      0,
      [_CI, _DN, _DV, _Co, _EA, _P10, _IIn, _Ta10, _RDT, _St, _SD, _OSR, _OSBN, _OSKP, _MC, _ME, _TC10, _CC, _EC, _DTOC, _SR, _NC, _CWOC, _TS, _AC, _TA],
      [0, 0, 0, 0, 4, [() => _Parameters, 0], 64 | 0, () => Targets2, 4, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, () => exports2.NotificationConfig$, () => exports2.CloudWatchOutputConfig$, 1, () => exports2.AlarmConfiguration$, () => AlarmStateInformationList]
    ];
    exports2.CommandFilter$ = [
      3,
      n032,
      _CF,
      0,
      [_k, _v],
      [0, 0],
      2
    ];
    exports2.CommandInvocation$ = [
      3,
      n032,
      _CIo,
      0,
      [_CI, _II2, _IN, _Co, _DN, _DV, _RDT, _St, _SD, _TO, _SOU, _SEU, _CP, _SR, _NC, _CWOC],
      [0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, () => CommandPluginList, 0, () => exports2.NotificationConfig$, () => exports2.CloudWatchOutputConfig$]
    ];
    exports2.CommandPlugin$ = [
      3,
      n032,
      _CPo,
      0,
      [_N, _St, _SD, _RCes, _RSDT, _RFDT, _Out, _SOU, _SEU, _OSR, _OSBN, _OSKP],
      [0, 0, 0, 1, 4, 4, 0, 0, 0, 0, 0, 0]
    ];
    exports2.ComplianceExecutionSummary$ = [
      3,
      n032,
      _CES,
      0,
      [_ET, _EI10, _ETx],
      [4, 0, 0],
      1
    ];
    exports2.ComplianceItem$ = [
      3,
      n032,
      _CIom,
      0,
      [_CTo, _RTe, _RI, _I, _Ti, _St, _Se, _ES, _De],
      [0, 0, 0, 0, 0, 0, 0, () => exports2.ComplianceExecutionSummary$, 128 | 0]
    ];
    exports2.ComplianceItemEntry$ = [
      3,
      n032,
      _CIE,
      0,
      [_Se, _St, _I, _Ti, _De],
      [0, 0, 0, 0, 128 | 0],
      2
    ];
    exports2.ComplianceStringFilter$ = [
      3,
      n032,
      _CSF,
      0,
      [_K10, _Va, _Ty],
      [0, [() => ComplianceStringFilterValueList, 0], 0]
    ];
    exports2.ComplianceSummaryItem$ = [
      3,
      n032,
      _CSI,
      0,
      [_CTo, _CSo, _NCS],
      [0, () => exports2.CompliantSummary$, () => exports2.NonCompliantSummary$]
    ];
    exports2.CompliantSummary$ = [
      3,
      n032,
      _CSo,
      0,
      [_CCo, _SS],
      [1, () => exports2.SeveritySummary$]
    ];
    exports2.CreateActivationRequest$ = [
      3,
      n032,
      _CAR,
      0,
      [_IRa, _D, _DIN, _RL, _ED, _T10, _RM],
      [0, 0, 0, 1, 4, () => TagList, () => RegistrationMetadataList],
      1
    ];
    exports2.CreateActivationResult$ = [
      3,
      n032,
      _CARr,
      0,
      [_AIct, _ACc],
      [0, 0]
    ];
    exports2.CreateAssociationBatchRequest$ = [
      3,
      n032,
      _CABR,
      0,
      [_En, _ADAR],
      [[() => CreateAssociationBatchRequestEntries, 0], 0],
      1
    ];
    exports2.CreateAssociationBatchRequestEntry$ = [
      3,
      n032,
      _CABRE,
      0,
      [_N, _II2, _P10, _ATPN, _DV, _Ta10, _SE, _OL, _AN, _ME, _MC, _CS4, _SCy, _AOACI, _CN, _TL, _SO, _Du, _TM, _AC],
      [0, 0, [() => _Parameters, 0], 0, 0, () => Targets2, 0, () => exports2.InstanceAssociationOutputLocation$, 0, 0, 0, 0, 0, 2, 64 | 0, () => TargetLocations, 1, 1, [1, n032, _TM, 0, [2, n032, _TMa, 0, 0, 64 | 0]], () => exports2.AlarmConfiguration$],
      1
    ];
    exports2.CreateAssociationBatchResult$ = [
      3,
      n032,
      _CABRr,
      0,
      [_Su, _F],
      [[() => AssociationDescriptionList, 0], [() => FailedCreateAssociationList, 0]]
    ];
    exports2.CreateAssociationRequest$ = [
      3,
      n032,
      _CARre,
      0,
      [_N, _DV, _II2, _P10, _Ta10, _SE, _OL, _AN, _ATPN, _ME, _MC, _CS4, _SCy, _AOACI, _CN, _TL, _SO, _Du, _TM, _T10, _AC, _ADAR],
      [0, 0, 0, [() => _Parameters, 0], () => Targets2, 0, () => exports2.InstanceAssociationOutputLocation$, 0, 0, 0, 0, 0, 0, 2, 64 | 0, () => TargetLocations, 1, 1, [1, n032, _TM, 0, [2, n032, _TMa, 0, 0, 64 | 0]], () => TagList, () => exports2.AlarmConfiguration$, 0],
      1
    ];
    exports2.CreateAssociationResult$ = [
      3,
      n032,
      _CARrea,
      0,
      [_AD],
      [[() => exports2.AssociationDescription$, 0]]
    ];
    exports2.CreateDocumentRequest$ = [
      3,
      n032,
      _CDR,
      0,
      [_Con, _N, _Req, _At, _DNi, _VN, _DT, _DF, _TT, _T10],
      [0, 0, () => DocumentRequiresList, () => AttachmentsSourceList, 0, 0, 0, 0, 0, () => TagList],
      2
    ];
    exports2.CreateDocumentResult$ = [
      3,
      n032,
      _CDRr,
      0,
      [_DD],
      [[() => exports2.DocumentDescription$, 0]]
    ];
    exports2.CreateMaintenanceWindowRequest$ = [
      3,
      n032,
      _CMWR,
      0,
      [_N, _Sc, _Du, _Cu, _AUT, _D, _SDt, _EDn, _STch, _SO, _CTl, _T10],
      [0, 0, 1, 1, 2, [() => MaintenanceWindowDescription, 0], 0, 0, 0, 1, [0, 4], () => TagList],
      5
    ];
    exports2.CreateMaintenanceWindowResult$ = [
      3,
      n032,
      _CMWRr,
      0,
      [_WI],
      [0]
    ];
    exports2.CreateOpsItemRequest$ = [
      3,
      n032,
      _COIR,
      0,
      [_D, _Sou, _Ti, _OIT, _OD, _No, _Pr10, _ROI, _T10, _Ca, _Se, _AST, _AETc, _PST, _PET, _AIc],
      [0, 0, 0, 0, () => OpsItemOperationalData, () => OpsItemNotifications, 1, () => RelatedOpsItems, () => TagList, 0, 0, 4, 4, 4, 4, 0],
      3
    ];
    exports2.CreateOpsItemResponse$ = [
      3,
      n032,
      _COIRr,
      0,
      [_OII, _OIA],
      [0, 0]
    ];
    exports2.CreateOpsMetadataRequest$ = [
      3,
      n032,
      _COMR,
      0,
      [_RI, _Me, _T10],
      [0, () => MetadataMap, () => TagList],
      1
    ];
    exports2.CreateOpsMetadataResult$ = [
      3,
      n032,
      _COMRr,
      0,
      [_OMA],
      [0]
    ];
    exports2.CreatePatchBaselineRequest$ = [
      3,
      n032,
      _CPBR,
      0,
      [_N, _OSp, _GF, _AR10, _AP, _APCL, _APENS, _RP, _RPA, _D, _So, _ASUCS, _CTl, _T10],
      [0, 0, () => exports2.PatchFilterGroup$, () => exports2.PatchRuleGroup$, 64 | 0, 0, 2, 64 | 0, 0, 0, [() => PatchSourceList, 0], 0, [0, 4], () => TagList],
      1
    ];
    exports2.CreatePatchBaselineResult$ = [
      3,
      n032,
      _CPBRr,
      0,
      [_BI],
      [0]
    ];
    exports2.CreateResourceDataSyncRequest$ = [
      3,
      n032,
      _CRDSR,
      0,
      [_SN10, _SDe, _ST11, _SSy],
      [0, () => exports2.ResourceDataSyncS3Destination$, 0, () => exports2.ResourceDataSyncSource$],
      1
    ];
    exports2.CreateResourceDataSyncResult$ = [
      3,
      n032,
      _CRDSRr,
      0,
      [],
      []
    ];
    exports2.Credentials$ = [
      3,
      n032,
      _Cr,
      0,
      [_AKI11, _SAK10, _STe, _ETxp],
      [0, [() => AccessKeySecretType, 0], [() => SessionTokenType10, 0], 4],
      4
    ];
    exports2.DeleteActivationRequest$ = [
      3,
      n032,
      _DAR,
      0,
      [_AIct],
      [0],
      1
    ];
    exports2.DeleteActivationResult$ = [
      3,
      n032,
      _DARe,
      0,
      [],
      []
    ];
    exports2.DeleteAssociationRequest$ = [
      3,
      n032,
      _DARel,
      0,
      [_N, _II2, _AIs],
      [0, 0, 0]
    ];
    exports2.DeleteAssociationResult$ = [
      3,
      n032,
      _DARele,
      0,
      [],
      []
    ];
    exports2.DeleteDocumentRequest$ = [
      3,
      n032,
      _DDR,
      0,
      [_N, _DV, _VN, _Fo],
      [0, 0, 0, 2],
      1
    ];
    exports2.DeleteDocumentResult$ = [
      3,
      n032,
      _DDRe,
      0,
      [],
      []
    ];
    exports2.DeleteInventoryRequest$ = [
      3,
      n032,
      _DIR,
      0,
      [_TN, _SDO, _DR, _CTl],
      [0, 0, 2, [0, 4]],
      1
    ];
    exports2.DeleteInventoryResult$ = [
      3,
      n032,
      _DIRe,
      0,
      [_DI, _TN, _DSe],
      [0, 0, () => exports2.InventoryDeletionSummary$]
    ];
    exports2.DeleteMaintenanceWindowRequest$ = [
      3,
      n032,
      _DMWR,
      0,
      [_WI],
      [0],
      1
    ];
    exports2.DeleteMaintenanceWindowResult$ = [
      3,
      n032,
      _DMWRe,
      0,
      [_WI],
      [0]
    ];
    exports2.DeleteOpsItemRequest$ = [
      3,
      n032,
      _DOIR,
      0,
      [_OII],
      [0],
      1
    ];
    exports2.DeleteOpsItemResponse$ = [
      3,
      n032,
      _DOIRe,
      0,
      [],
      []
    ];
    exports2.DeleteOpsMetadataRequest$ = [
      3,
      n032,
      _DOMR,
      0,
      [_OMA],
      [0],
      1
    ];
    exports2.DeleteOpsMetadataResult$ = [
      3,
      n032,
      _DOMRe,
      0,
      [],
      []
    ];
    exports2.DeleteParameterRequest$ = [
      3,
      n032,
      _DPR,
      0,
      [_N],
      [0],
      1
    ];
    exports2.DeleteParameterResult$ = [
      3,
      n032,
      _DPRe,
      0,
      [],
      []
    ];
    exports2.DeleteParametersRequest$ = [
      3,
      n032,
      _DPRel,
      0,
      [_Na],
      [64 | 0],
      1
    ];
    exports2.DeleteParametersResult$ = [
      3,
      n032,
      _DPRele,
      0,
      [_DP, _IP],
      [64 | 0, 64 | 0]
    ];
    exports2.DeletePatchBaselineRequest$ = [
      3,
      n032,
      _DPBR,
      0,
      [_BI],
      [0],
      1
    ];
    exports2.DeletePatchBaselineResult$ = [
      3,
      n032,
      _DPBRe,
      0,
      [_BI],
      [0]
    ];
    exports2.DeleteResourceDataSyncRequest$ = [
      3,
      n032,
      _DRDSR,
      0,
      [_SN10, _ST11],
      [0, 0],
      1
    ];
    exports2.DeleteResourceDataSyncResult$ = [
      3,
      n032,
      _DRDSRe,
      0,
      [],
      []
    ];
    exports2.DeleteResourcePolicyRequest$ = [
      3,
      n032,
      _DRPR,
      0,
      [_RA10, _PI10, _PH],
      [0, 0, 0],
      3
    ];
    exports2.DeleteResourcePolicyResponse$ = [
      3,
      n032,
      _DRPRe,
      0,
      [],
      []
    ];
    exports2.DeregisterManagedInstanceRequest$ = [
      3,
      n032,
      _DMIR,
      0,
      [_II2],
      [0],
      1
    ];
    exports2.DeregisterManagedInstanceResult$ = [
      3,
      n032,
      _DMIRe,
      0,
      [],
      []
    ];
    exports2.DeregisterPatchBaselineForPatchGroupRequest$ = [
      3,
      n032,
      _DPBFPGR,
      0,
      [_BI, _PG],
      [0, 0],
      2
    ];
    exports2.DeregisterPatchBaselineForPatchGroupResult$ = [
      3,
      n032,
      _DPBFPGRe,
      0,
      [_BI, _PG],
      [0, 0]
    ];
    exports2.DeregisterTargetFromMaintenanceWindowRequest$ = [
      3,
      n032,
      _DTFMWR,
      0,
      [_WI, _WTI, _Sa],
      [0, 0, 2],
      2
    ];
    exports2.DeregisterTargetFromMaintenanceWindowResult$ = [
      3,
      n032,
      _DTFMWRe,
      0,
      [_WI, _WTI],
      [0, 0]
    ];
    exports2.DeregisterTaskFromMaintenanceWindowRequest$ = [
      3,
      n032,
      _DTFMWRer,
      0,
      [_WI, _WTIi],
      [0, 0],
      2
    ];
    exports2.DeregisterTaskFromMaintenanceWindowResult$ = [
      3,
      n032,
      _DTFMWRere,
      0,
      [_WI, _WTIi],
      [0, 0]
    ];
    exports2.DescribeActivationsFilter$ = [
      3,
      n032,
      _DAF,
      0,
      [_FK, _FV],
      [0, 64 | 0]
    ];
    exports2.DescribeActivationsRequest$ = [
      3,
      n032,
      _DARes,
      0,
      [_Fi, _MR, _NT],
      [() => DescribeActivationsFilterList, 1, 0]
    ];
    exports2.DescribeActivationsResult$ = [
      3,
      n032,
      _DAResc,
      0,
      [_AL, _NT],
      [() => ActivationList, 0]
    ];
    exports2.DescribeAssociationExecutionsRequest$ = [
      3,
      n032,
      _DAER,
      0,
      [_AIs, _Fi, _MR, _NT],
      [0, [() => AssociationExecutionFilterList, 0], 1, 0],
      1
    ];
    exports2.DescribeAssociationExecutionsResult$ = [
      3,
      n032,
      _DAERe,
      0,
      [_AEs, _NT],
      [[() => AssociationExecutionsList, 0], 0]
    ];
    exports2.DescribeAssociationExecutionTargetsRequest$ = [
      3,
      n032,
      _DAETR,
      0,
      [_AIs, _EI10, _Fi, _MR, _NT],
      [0, 0, [() => AssociationExecutionTargetsFilterList, 0], 1, 0],
      2
    ];
    exports2.DescribeAssociationExecutionTargetsResult$ = [
      3,
      n032,
      _DAETRe,
      0,
      [_AETs, _NT],
      [[() => AssociationExecutionTargetsList, 0], 0]
    ];
    exports2.DescribeAssociationRequest$ = [
      3,
      n032,
      _DARescr,
      0,
      [_N, _II2, _AIs, _AV],
      [0, 0, 0, 0]
    ];
    exports2.DescribeAssociationResult$ = [
      3,
      n032,
      _DARescri,
      0,
      [_AD],
      [[() => exports2.AssociationDescription$, 0]]
    ];
    exports2.DescribeAutomationExecutionsRequest$ = [
      3,
      n032,
      _DAERes,
      0,
      [_Fi, _MR, _NT],
      [() => AutomationExecutionFilterList, 1, 0]
    ];
    exports2.DescribeAutomationExecutionsResult$ = [
      3,
      n032,
      _DAEResc,
      0,
      [_AEML, _NT],
      [() => AutomationExecutionMetadataList, 0]
    ];
    exports2.DescribeAutomationStepExecutionsRequest$ = [
      3,
      n032,
      _DASER,
      0,
      [_AEI, _Fi, _NT, _MR, _RO],
      [0, () => StepExecutionFilterList, 0, 1, 2],
      1
    ];
    exports2.DescribeAutomationStepExecutionsResult$ = [
      3,
      n032,
      _DASERe,
      0,
      [_SEt, _NT],
      [() => StepExecutionList, 0]
    ];
    exports2.DescribeAvailablePatchesRequest$ = [
      3,
      n032,
      _DAPR,
      0,
      [_Fi, _MR, _NT],
      [() => PatchOrchestratorFilterList, 1, 0]
    ];
    exports2.DescribeAvailablePatchesResult$ = [
      3,
      n032,
      _DAPRe,
      0,
      [_Pa, _NT],
      [() => PatchList, 0]
    ];
    exports2.DescribeDocumentPermissionRequest$ = [
      3,
      n032,
      _DDPR,
      0,
      [_N, _PT, _MR, _NT],
      [0, 0, 1, 0],
      2
    ];
    exports2.DescribeDocumentPermissionResponse$ = [
      3,
      n032,
      _DDPRe,
      0,
      [_AIcc, _ASIL, _NT],
      [[() => AccountIdList, 0], [() => AccountSharingInfoList, 0], 0]
    ];
    exports2.DescribeDocumentRequest$ = [
      3,
      n032,
      _DDRes,
      0,
      [_N, _DV, _VN],
      [0, 0, 0],
      1
    ];
    exports2.DescribeDocumentResult$ = [
      3,
      n032,
      _DDResc,
      0,
      [_Do],
      [[() => exports2.DocumentDescription$, 0]]
    ];
    exports2.DescribeEffectiveInstanceAssociationsRequest$ = [
      3,
      n032,
      _DEIAR,
      0,
      [_II2, _MR, _NT],
      [0, 1, 0],
      1
    ];
    exports2.DescribeEffectiveInstanceAssociationsResult$ = [
      3,
      n032,
      _DEIARe,
      0,
      [_Ass, _NT],
      [() => InstanceAssociationList, 0]
    ];
    exports2.DescribeEffectivePatchesForPatchBaselineRequest$ = [
      3,
      n032,
      _DEPFPBR,
      0,
      [_BI, _MR, _NT],
      [0, 1, 0],
      1
    ];
    exports2.DescribeEffectivePatchesForPatchBaselineResult$ = [
      3,
      n032,
      _DEPFPBRe,
      0,
      [_EP, _NT],
      [() => EffectivePatchList, 0]
    ];
    exports2.DescribeInstanceAssociationsStatusRequest$ = [
      3,
      n032,
      _DIASR,
      0,
      [_II2, _MR, _NT],
      [0, 1, 0],
      1
    ];
    exports2.DescribeInstanceAssociationsStatusResult$ = [
      3,
      n032,
      _DIASRe,
      0,
      [_IASI, _NT],
      [() => InstanceAssociationStatusInfos, 0]
    ];
    exports2.DescribeInstanceInformationRequest$ = [
      3,
      n032,
      _DIIR,
      0,
      [_IIFL, _Fi, _MR, _NT],
      [[() => InstanceInformationFilterList, 0], [() => InstanceInformationStringFilterList, 0], 1, 0]
    ];
    exports2.DescribeInstanceInformationResult$ = [
      3,
      n032,
      _DIIRe,
      0,
      [_IIL, _NT],
      [[() => InstanceInformationList, 0], 0]
    ];
    exports2.DescribeInstancePatchesRequest$ = [
      3,
      n032,
      _DIPR,
      0,
      [_II2, _Fi, _NT, _MR],
      [0, () => PatchOrchestratorFilterList, 0, 1],
      1
    ];
    exports2.DescribeInstancePatchesResult$ = [
      3,
      n032,
      _DIPRe,
      0,
      [_Pa, _NT],
      [() => PatchComplianceDataList, 0]
    ];
    exports2.DescribeInstancePatchStatesForPatchGroupRequest$ = [
      3,
      n032,
      _DIPSFPGR,
      0,
      [_PG, _Fi, _NT, _MR],
      [0, () => InstancePatchStateFilterList, 0, 1],
      1
    ];
    exports2.DescribeInstancePatchStatesForPatchGroupResult$ = [
      3,
      n032,
      _DIPSFPGRe,
      0,
      [_IPS, _NT],
      [[() => InstancePatchStatesList, 0], 0]
    ];
    exports2.DescribeInstancePatchStatesRequest$ = [
      3,
      n032,
      _DIPSR,
      0,
      [_IIn, _NT, _MR],
      [64 | 0, 0, 1],
      1
    ];
    exports2.DescribeInstancePatchStatesResult$ = [
      3,
      n032,
      _DIPSRe,
      0,
      [_IPS, _NT],
      [[() => InstancePatchStateList, 0], 0]
    ];
    exports2.DescribeInstancePropertiesRequest$ = [
      3,
      n032,
      _DIPRes,
      0,
      [_IPFL, _FWO, _MR, _NT],
      [[() => InstancePropertyFilterList, 0], [() => InstancePropertyStringFilterList, 0], 1, 0]
    ];
    exports2.DescribeInstancePropertiesResult$ = [
      3,
      n032,
      _DIPResc,
      0,
      [_IPn, _NT],
      [[() => InstanceProperties, 0], 0]
    ];
    exports2.DescribeInventoryDeletionsRequest$ = [
      3,
      n032,
      _DIDR,
      0,
      [_DI, _NT, _MR],
      [0, 0, 1]
    ];
    exports2.DescribeInventoryDeletionsResult$ = [
      3,
      n032,
      _DIDRe,
      0,
      [_IDn, _NT],
      [() => InventoryDeletionsList, 0]
    ];
    exports2.DescribeMaintenanceWindowExecutionsRequest$ = [
      3,
      n032,
      _DMWER,
      0,
      [_WI, _Fi, _MR, _NT],
      [0, () => MaintenanceWindowFilterList, 1, 0],
      1
    ];
    exports2.DescribeMaintenanceWindowExecutionsResult$ = [
      3,
      n032,
      _DMWERe,
      0,
      [_WE, _NT],
      [() => MaintenanceWindowExecutionList, 0]
    ];
    exports2.DescribeMaintenanceWindowExecutionTaskInvocationsRequest$ = [
      3,
      n032,
      _DMWETIR,
      0,
      [_WEI, _TI, _Fi, _MR, _NT],
      [0, 0, () => MaintenanceWindowFilterList, 1, 0],
      2
    ];
    exports2.DescribeMaintenanceWindowExecutionTaskInvocationsResult$ = [
      3,
      n032,
      _DMWETIRe,
      0,
      [_WETII, _NT],
      [[() => MaintenanceWindowExecutionTaskInvocationIdentityList, 0], 0]
    ];
    exports2.DescribeMaintenanceWindowExecutionTasksRequest$ = [
      3,
      n032,
      _DMWETR,
      0,
      [_WEI, _Fi, _MR, _NT],
      [0, () => MaintenanceWindowFilterList, 1, 0],
      1
    ];
    exports2.DescribeMaintenanceWindowExecutionTasksResult$ = [
      3,
      n032,
      _DMWETRe,
      0,
      [_WETI, _NT],
      [() => MaintenanceWindowExecutionTaskIdentityList, 0]
    ];
    exports2.DescribeMaintenanceWindowScheduleRequest$ = [
      3,
      n032,
      _DMWSR,
      0,
      [_WI, _Ta10, _RTe, _Fi, _MR, _NT],
      [0, () => Targets2, 0, () => PatchOrchestratorFilterList, 1, 0]
    ];
    exports2.DescribeMaintenanceWindowScheduleResult$ = [
      3,
      n032,
      _DMWSRe,
      0,
      [_SWE, _NT],
      [() => ScheduledWindowExecutionList, 0]
    ];
    exports2.DescribeMaintenanceWindowsForTargetRequest$ = [
      3,
      n032,
      _DMWFTR,
      0,
      [_Ta10, _RTe, _MR, _NT],
      [() => Targets2, 0, 1, 0],
      2
    ];
    exports2.DescribeMaintenanceWindowsForTargetResult$ = [
      3,
      n032,
      _DMWFTRe,
      0,
      [_WIi, _NT],
      [() => MaintenanceWindowsForTargetList, 0]
    ];
    exports2.DescribeMaintenanceWindowsRequest$ = [
      3,
      n032,
      _DMWRes,
      0,
      [_Fi, _MR, _NT],
      [() => MaintenanceWindowFilterList, 1, 0]
    ];
    exports2.DescribeMaintenanceWindowsResult$ = [
      3,
      n032,
      _DMWResc,
      0,
      [_WIi, _NT],
      [[() => MaintenanceWindowIdentityList, 0], 0]
    ];
    exports2.DescribeMaintenanceWindowTargetsRequest$ = [
      3,
      n032,
      _DMWTR,
      0,
      [_WI, _Fi, _MR, _NT],
      [0, () => MaintenanceWindowFilterList, 1, 0],
      1
    ];
    exports2.DescribeMaintenanceWindowTargetsResult$ = [
      3,
      n032,
      _DMWTRe,
      0,
      [_Ta10, _NT],
      [[() => MaintenanceWindowTargetList, 0], 0]
    ];
    exports2.DescribeMaintenanceWindowTasksRequest$ = [
      3,
      n032,
      _DMWTRes,
      0,
      [_WI, _Fi, _MR, _NT],
      [0, () => MaintenanceWindowFilterList, 1, 0],
      1
    ];
    exports2.DescribeMaintenanceWindowTasksResult$ = [
      3,
      n032,
      _DMWTResc,
      0,
      [_Tas, _NT],
      [[() => MaintenanceWindowTaskList, 0], 0]
    ];
    exports2.DescribeOpsItemsRequest$ = [
      3,
      n032,
      _DOIRes,
      0,
      [_OIF, _MR, _NT],
      [() => OpsItemFilters, 1, 0]
    ];
    exports2.DescribeOpsItemsResponse$ = [
      3,
      n032,
      _DOIResc,
      0,
      [_NT, _OIS],
      [0, () => OpsItemSummaries]
    ];
    exports2.DescribeParametersRequest$ = [
      3,
      n032,
      _DPRes,
      0,
      [_Fi, _PF, _MR, _NT, _Sh],
      [() => ParametersFilterList, () => ParameterStringFilterList, 1, 0, 2]
    ];
    exports2.DescribeParametersResult$ = [
      3,
      n032,
      _DPResc,
      0,
      [_P10, _NT],
      [() => ParameterMetadataList, 0]
    ];
    exports2.DescribePatchBaselinesRequest$ = [
      3,
      n032,
      _DPBRes,
      0,
      [_Fi, _MR, _NT],
      [() => PatchOrchestratorFilterList, 1, 0]
    ];
    exports2.DescribePatchBaselinesResult$ = [
      3,
      n032,
      _DPBResc,
      0,
      [_BIa, _NT],
      [() => PatchBaselineIdentityList, 0]
    ];
    exports2.DescribePatchGroupsRequest$ = [
      3,
      n032,
      _DPGR,
      0,
      [_MR, _Fi, _NT],
      [1, () => PatchOrchestratorFilterList, 0]
    ];
    exports2.DescribePatchGroupsResult$ = [
      3,
      n032,
      _DPGRe,
      0,
      [_Ma, _NT],
      [() => PatchGroupPatchBaselineMappingList, 0]
    ];
    exports2.DescribePatchGroupStateRequest$ = [
      3,
      n032,
      _DPGSR,
      0,
      [_PG],
      [0],
      1
    ];
    exports2.DescribePatchGroupStateResult$ = [
      3,
      n032,
      _DPGSRe,
      0,
      [_In, _IWIP, _IWIOP, _IWIPRP, _IWIRP, _IWMP, _IWFP, _IWNAP, _IWUNAP, _IWCNCP, _IWSNCP, _IWONCP, _IWASU],
      [1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1]
    ];
    exports2.DescribePatchPropertiesRequest$ = [
      3,
      n032,
      _DPPR,
      0,
      [_OSp, _Pro, _PS, _MR, _NT],
      [0, 0, 0, 1, 0],
      2
    ];
    exports2.DescribePatchPropertiesResult$ = [
      3,
      n032,
      _DPPRe,
      0,
      [_Prop, _NT],
      [[1, n032, _PPL, 0, 128 | 0], 0]
    ];
    exports2.DescribeSessionsRequest$ = [
      3,
      n032,
      _DSR,
      0,
      [_S, _MR, _NT, _Fi],
      [0, 1, 0, () => SessionFilterList],
      1
    ];
    exports2.DescribeSessionsResponse$ = [
      3,
      n032,
      _DSRe,
      0,
      [_Ses, _NT],
      [() => SessionList, 0]
    ];
    exports2.DisassociateOpsItemRelatedItemRequest$ = [
      3,
      n032,
      _DOIRIR,
      0,
      [_OII, _AIs],
      [0, 0],
      2
    ];
    exports2.DisassociateOpsItemRelatedItemResponse$ = [
      3,
      n032,
      _DOIRIRi,
      0,
      [],
      []
    ];
    exports2.DocumentDefaultVersionDescription$ = [
      3,
      n032,
      _DDVD,
      0,
      [_N, _DVe, _DVN],
      [0, 0, 0]
    ];
    exports2.DocumentDescription$ = [
      3,
      n032,
      _DD,
      0,
      [_Sha, _H, _HT, _N, _DNi, _VN, _Ow, _CD, _St, _SI10, _DV, _D, _P10, _PTl, _DT, _SV, _LV, _DVe, _DF, _TT, _T10, _AItt, _Req, _Au10, _RIe, _AVp, _PRV, _RS, _Ca, _CE],
      [0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, [() => DocumentParameterList, 0], [() => PlatformTypeList, 0], 0, 0, 0, 0, 0, 0, () => TagList, [() => AttachmentInformationList, 0], () => DocumentRequiresList, 0, [() => ReviewInformationList, 0], 0, 0, 0, 64 | 0, 64 | 0]
    ];
    exports2.DocumentFilter$ = [
      3,
      n032,
      _DFo,
      0,
      [_k, _v],
      [0, 0],
      2
    ];
    exports2.DocumentIdentifier$ = [
      3,
      n032,
      _DIo,
      0,
      [_N, _CD, _DNi, _Ow, _VN, _PTl, _DV, _DT, _SV, _DF, _TT, _T10, _Req, _RS, _Au10],
      [0, 4, 0, 0, 0, [() => PlatformTypeList, 0], 0, 0, 0, 0, 0, () => TagList, () => DocumentRequiresList, 0, 0]
    ];
    exports2.DocumentKeyValuesFilter$ = [
      3,
      n032,
      _DKVF,
      0,
      [_K10, _Va],
      [0, 64 | 0]
    ];
    exports2.DocumentMetadataResponseInfo$ = [
      3,
      n032,
      _DMRI,
      0,
      [_RR],
      [() => DocumentReviewerResponseList]
    ];
    exports2.DocumentParameter$ = [
      3,
      n032,
      _DPo,
      0,
      [_N, _Ty, _D, _DVef],
      [0, 0, 0, 0]
    ];
    exports2.DocumentRequires$ = [
      3,
      n032,
      _DRo,
      0,
      [_N, _Ve, _RTeq, _VN],
      [0, 0, 0, 0],
      1
    ];
    exports2.DocumentReviewCommentSource$ = [
      3,
      n032,
      _DRCS,
      0,
      [_Ty, _Con],
      [0, 0]
    ];
    exports2.DocumentReviewerResponseSource$ = [
      3,
      n032,
      _DRRS,
      0,
      [_CTr, _UT, _RS, _Co, _Rev],
      [4, 4, 0, () => DocumentReviewCommentList, 0]
    ];
    exports2.DocumentReviews$ = [
      3,
      n032,
      _DRoc,
      0,
      [_Ac, _Co],
      [0, () => DocumentReviewCommentList],
      1
    ];
    exports2.DocumentVersionInfo$ = [
      3,
      n032,
      _DVI,
      0,
      [_N, _DNi, _DV, _VN, _CD, _IDVs, _DF, _St, _SI10, _RS],
      [0, 0, 0, 0, 4, 2, 0, 0, 0, 0]
    ];
    exports2.EffectivePatch$ = [
      3,
      n032,
      _EPf,
      0,
      [_Pat, _PSa],
      [() => exports2.Patch$, () => exports2.PatchStatus$]
    ];
    exports2.FailedCreateAssociation$ = [
      3,
      n032,
      _FCA,
      0,
      [_Ent, _M, _Fa],
      [[() => exports2.CreateAssociationBatchRequestEntry$, 0], 0, 0]
    ];
    exports2.FailureDetails$ = [
      3,
      n032,
      _FD,
      0,
      [_FS, _FT, _De],
      [0, 0, [2, n032, _APM, 0, 0, 64 | 0]]
    ];
    exports2.GetAccessTokenRequest$ = [
      3,
      n032,
      _GATR,
      0,
      [_ARI10],
      [0],
      1
    ];
    exports2.GetAccessTokenResponse$ = [
      3,
      n032,
      _GATRe,
      0,
      [_Cr, _ARS],
      [[() => exports2.Credentials$, 0], 0]
    ];
    exports2.GetAutomationExecutionRequest$ = [
      3,
      n032,
      _GAER,
      0,
      [_AEI],
      [0],
      1
    ];
    exports2.GetAutomationExecutionResult$ = [
      3,
      n032,
      _GAERe,
      0,
      [_AEu],
      [() => exports2.AutomationExecution$]
    ];
    exports2.GetCalendarStateRequest$ = [
      3,
      n032,
      _GCSR,
      0,
      [_CN, _ATt],
      [64 | 0, 0],
      1
    ];
    exports2.GetCalendarStateResponse$ = [
      3,
      n032,
      _GCSRe,
      0,
      [_S, _ATt, _NTT],
      [0, 0, 0]
    ];
    exports2.GetCommandInvocationRequest$ = [
      3,
      n032,
      _GCIR,
      0,
      [_CI, _II2, _PNl],
      [0, 0, 0],
      2
    ];
    exports2.GetCommandInvocationResult$ = [
      3,
      n032,
      _GCIRe,
      0,
      [_CI, _II2, _Co, _DN, _DV, _PNl, _RCes, _ESDT, _EETx, _EEDT, _St, _SD, _SOC, _SOU, _SEC, _SEU, _CWOC],
      [0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, () => exports2.CloudWatchOutputConfig$]
    ];
    exports2.GetConnectionStatusRequest$ = [
      3,
      n032,
      _GCSRet,
      0,
      [_Tar],
      [0],
      1
    ];
    exports2.GetConnectionStatusResponse$ = [
      3,
      n032,
      _GCSReto,
      0,
      [_Tar, _St],
      [0, 0]
    ];
    exports2.GetDefaultPatchBaselineRequest$ = [
      3,
      n032,
      _GDPBR,
      0,
      [_OSp],
      [0]
    ];
    exports2.GetDefaultPatchBaselineResult$ = [
      3,
      n032,
      _GDPBRe,
      0,
      [_BI, _OSp],
      [0, 0]
    ];
    exports2.GetDeployablePatchSnapshotForInstanceRequest$ = [
      3,
      n032,
      _GDPSFIR,
      0,
      [_II2, _SIn, _BO, _USDSE],
      [0, 0, [() => exports2.BaselineOverride$, 0], 2],
      2
    ];
    exports2.GetDeployablePatchSnapshotForInstanceResult$ = [
      3,
      n032,
      _GDPSFIRe,
      0,
      [_II2, _SIn, _SDU, _Prod],
      [0, 0, 0, 0]
    ];
    exports2.GetDocumentRequest$ = [
      3,
      n032,
      _GDR,
      0,
      [_N, _VN, _DV, _DF],
      [0, 0, 0, 0],
      1
    ];
    exports2.GetDocumentResult$ = [
      3,
      n032,
      _GDRe,
      0,
      [_N, _CD, _DNi, _VN, _DV, _St, _SI10, _Con, _DT, _DF, _Req, _ACtt, _RS],
      [0, 4, 0, 0, 0, 0, 0, 0, 0, 0, () => DocumentRequiresList, [() => AttachmentContentList, 0], 0]
    ];
    exports2.GetExecutionPreviewRequest$ = [
      3,
      n032,
      _GEPR,
      0,
      [_EPI],
      [0],
      1
    ];
    exports2.GetExecutionPreviewResponse$ = [
      3,
      n032,
      _GEPRe,
      0,
      [_EPI, _EAn, _St, _SM, _EPx],
      [0, 4, 0, 0, () => exports2.ExecutionPreview$]
    ];
    exports2.GetInventoryRequest$ = [
      3,
      n032,
      _GIR2,
      0,
      [_Fi, _Ag, _RAe, _NT, _MR],
      [[() => InventoryFilterList, 0], [() => InventoryAggregatorList, 0], [() => ResultAttributeList, 0], 0, 1]
    ];
    exports2.GetInventoryResult$ = [
      3,
      n032,
      _GIRe,
      0,
      [_Enti, _NT],
      [[() => InventoryResultEntityList, 0], 0]
    ];
    exports2.GetInventorySchemaRequest$ = [
      3,
      n032,
      _GISR,
      0,
      [_TN, _NT, _MR, _Agg, _STu],
      [0, 0, 1, 2, 2]
    ];
    exports2.GetInventorySchemaResult$ = [
      3,
      n032,
      _GISRe,
      0,
      [_Sch, _NT],
      [[() => InventoryItemSchemaResultList, 0], 0]
    ];
    exports2.GetMaintenanceWindowExecutionRequest$ = [
      3,
      n032,
      _GMWER,
      0,
      [_WEI],
      [0],
      1
    ];
    exports2.GetMaintenanceWindowExecutionResult$ = [
      3,
      n032,
      _GMWERe,
      0,
      [_WEI, _TIa, _St, _SD, _STt, _ETn],
      [0, 64 | 0, 0, 0, 4, 4]
    ];
    exports2.GetMaintenanceWindowExecutionTaskInvocationRequest$ = [
      3,
      n032,
      _GMWETIR,
      0,
      [_WEI, _TI, _IInv],
      [0, 0, 0],
      3
    ];
    exports2.GetMaintenanceWindowExecutionTaskInvocationResult$ = [
      3,
      n032,
      _GMWETIRe,
      0,
      [_WEI, _TEI, _IInv, _EI10, _TTa, _P10, _St, _SD, _STt, _ETn, _OI, _WTI],
      [0, 0, 0, 0, 0, [() => MaintenanceWindowExecutionTaskInvocationParameters, 0], 0, 0, 4, 4, [() => OwnerInformation, 0], 0]
    ];
    exports2.GetMaintenanceWindowExecutionTaskRequest$ = [
      3,
      n032,
      _GMWETR,
      0,
      [_WEI, _TI],
      [0, 0],
      2
    ];
    exports2.GetMaintenanceWindowExecutionTaskResult$ = [
      3,
      n032,
      _GMWETRe,
      0,
      [_WEI, _TEI, _TAa, _SR, _Ty, _TPa, _Pr10, _MC, _ME, _St, _SD, _STt, _ETn, _AC, _TA],
      [0, 0, 0, 0, 0, [() => MaintenanceWindowTaskParametersList, 0], 1, 0, 0, 0, 0, 4, 4, () => exports2.AlarmConfiguration$, () => AlarmStateInformationList]
    ];
    exports2.GetMaintenanceWindowRequest$ = [
      3,
      n032,
      _GMWR,
      0,
      [_WI],
      [0],
      1
    ];
    exports2.GetMaintenanceWindowResult$ = [
      3,
      n032,
      _GMWRe,
      0,
      [_WI, _N, _D, _SDt, _EDn, _Sc, _STch, _SO, _NET, _Du, _Cu, _AUT, _Ena, _CD, _MD],
      [0, 0, [() => MaintenanceWindowDescription, 0], 0, 0, 0, 0, 1, 0, 1, 1, 2, 2, 4, 4]
    ];
    exports2.GetMaintenanceWindowTaskRequest$ = [
      3,
      n032,
      _GMWTR,
      0,
      [_WI, _WTIi],
      [0, 0],
      2
    ];
    exports2.GetMaintenanceWindowTaskResult$ = [
      3,
      n032,
      _GMWTRe,
      0,
      [_WI, _WTIi, _Ta10, _TAa, _SRA, _TTa, _TPa, _TIP, _Pr10, _MC, _ME, _LI, _N, _D, _CB, _AC],
      [0, 0, () => Targets2, 0, 0, 0, [() => MaintenanceWindowTaskParameters, 0], [() => exports2.MaintenanceWindowTaskInvocationParameters$, 0], 1, 0, 0, () => exports2.LoggingInfo$, 0, [() => MaintenanceWindowDescription, 0], 0, () => exports2.AlarmConfiguration$]
    ];
    exports2.GetOpsItemRequest$ = [
      3,
      n032,
      _GOIR,
      0,
      [_OII, _OIA],
      [0, 0],
      1
    ];
    exports2.GetOpsItemResponse$ = [
      3,
      n032,
      _GOIRe,
      0,
      [_OIp],
      [() => exports2.OpsItem$]
    ];
    exports2.GetOpsMetadataRequest$ = [
      3,
      n032,
      _GOMR,
      0,
      [_OMA, _MR, _NT],
      [0, 1, 0],
      1
    ];
    exports2.GetOpsMetadataResult$ = [
      3,
      n032,
      _GOMRe,
      0,
      [_RI, _Me, _NT],
      [0, () => MetadataMap, 0]
    ];
    exports2.GetOpsSummaryRequest$ = [
      3,
      n032,
      _GOSR,
      0,
      [_SN10, _Fi, _Ag, _RAe, _NT, _MR],
      [0, [() => OpsFilterList, 0], [() => OpsAggregatorList, 0], [() => OpsResultAttributeList, 0], 0, 1]
    ];
    exports2.GetOpsSummaryResult$ = [
      3,
      n032,
      _GOSRe,
      0,
      [_Enti, _NT],
      [[() => OpsEntityList, 0], 0]
    ];
    exports2.GetParameterHistoryRequest$ = [
      3,
      n032,
      _GPHR,
      0,
      [_N, _WD, _MR, _NT],
      [0, 2, 1, 0],
      1
    ];
    exports2.GetParameterHistoryResult$ = [
      3,
      n032,
      _GPHRe,
      0,
      [_P10, _NT],
      [[() => ParameterHistoryList, 0], 0]
    ];
    exports2.GetParameterRequest$ = [
      3,
      n032,
      _GPR,
      0,
      [_N, _WD],
      [0, 2],
      1
    ];
    exports2.GetParameterResult$ = [
      3,
      n032,
      _GPRe,
      0,
      [_Par],
      [[() => exports2.Parameter$, 0]]
    ];
    exports2.GetParametersByPathRequest$ = [
      3,
      n032,
      _GPBPR,
      0,
      [_Path, _Rec, _PF, _WD, _MR, _NT],
      [0, 2, () => ParameterStringFilterList, 2, 1, 0],
      1
    ];
    exports2.GetParametersByPathResult$ = [
      3,
      n032,
      _GPBPRe,
      0,
      [_P10, _NT],
      [[() => ParameterList, 0], 0]
    ];
    exports2.GetParametersRequest$ = [
      3,
      n032,
      _GPRet,
      0,
      [_Na, _WD],
      [64 | 0, 2],
      1
    ];
    exports2.GetParametersResult$ = [
      3,
      n032,
      _GPReta,
      0,
      [_P10, _IP],
      [[() => ParameterList, 0], 64 | 0]
    ];
    exports2.GetPatchBaselineForPatchGroupRequest$ = [
      3,
      n032,
      _GPBFPGR,
      0,
      [_PG, _OSp],
      [0, 0],
      1
    ];
    exports2.GetPatchBaselineForPatchGroupResult$ = [
      3,
      n032,
      _GPBFPGRe,
      0,
      [_BI, _PG, _OSp],
      [0, 0, 0]
    ];
    exports2.GetPatchBaselineRequest$ = [
      3,
      n032,
      _GPBR,
      0,
      [_BI],
      [0],
      1
    ];
    exports2.GetPatchBaselineResult$ = [
      3,
      n032,
      _GPBRe,
      0,
      [_BI, _N, _OSp, _GF, _AR10, _AP, _APCL, _APENS, _RP, _RPA, _PGa, _CD, _MD, _D, _So, _ASUCS],
      [0, 0, 0, () => exports2.PatchFilterGroup$, () => exports2.PatchRuleGroup$, 64 | 0, 0, 2, 64 | 0, 0, 64 | 0, 4, 4, 0, [() => PatchSourceList, 0], 0]
    ];
    exports2.GetResourcePoliciesRequest$ = [
      3,
      n032,
      _GRPR,
      0,
      [_RA10, _NT, _MR],
      [0, 0, 1],
      1
    ];
    exports2.GetResourcePoliciesResponse$ = [
      3,
      n032,
      _GRPRe,
      0,
      [_NT, _Po],
      [0, () => GetResourcePoliciesResponseEntries]
    ];
    exports2.GetResourcePoliciesResponseEntry$ = [
      3,
      n032,
      _GRPRE,
      0,
      [_PI10, _PH, _Pol],
      [0, 0, 0]
    ];
    exports2.GetServiceSettingRequest$ = [
      3,
      n032,
      _GSSR,
      0,
      [_SIe],
      [0],
      1
    ];
    exports2.GetServiceSettingResult$ = [
      3,
      n032,
      _GSSRe,
      0,
      [_SSe],
      [() => exports2.ServiceSetting$]
    ];
    exports2.InstanceAggregatedAssociationOverview$ = [
      3,
      n032,
      _IAAO,
      0,
      [_DS10, _IASAC],
      [0, 128 | 1]
    ];
    exports2.InstanceAssociation$ = [
      3,
      n032,
      _IAns,
      0,
      [_AIs, _II2, _Con, _AV],
      [0, 0, 0, 0]
    ];
    exports2.InstanceAssociationOutputLocation$ = [
      3,
      n032,
      _IAOL,
      0,
      [_SL],
      [() => exports2.S3OutputLocation$]
    ];
    exports2.InstanceAssociationOutputUrl$ = [
      3,
      n032,
      _IAOU,
      0,
      [_SOUu],
      [() => exports2.S3OutputUrl$]
    ];
    exports2.InstanceAssociationStatusInfo$ = [
      3,
      n032,
      _IASIn,
      0,
      [_AIs, _N, _DV, _AV, _II2, _EDx, _St, _DS10, _ES, _ECr, _OU, _AN],
      [0, 0, 0, 0, 0, 4, 0, 0, 0, 0, () => exports2.InstanceAssociationOutputUrl$, 0]
    ];
    exports2.InstanceInfo$ = [
      3,
      n032,
      _IIns,
      0,
      [_ATg, _AVg, _CNo, _ISn, _IAp, _MS, _PTla, _PNla, _PV, _RTe],
      [0, 0, 0, 0, [() => IPAddress, 0], 0, 0, 0, 0, 0]
    ];
    exports2.InstanceInformation$ = [
      3,
      n032,
      _IInst,
      0,
      [_II2, _PSi, _LPDT, _AVg, _ILV, _PTla, _PNla, _PV, _AIct, _IRa, _RD, _RTe, _N, _IPA, _CNo, _AS, _LAED, _LSAED, _AO, _SIo, _STo],
      [0, 0, 4, 0, 2, 0, 0, 0, 0, 0, 4, 0, 0, [() => IPAddress, 0], 0, 0, 4, 4, () => exports2.InstanceAggregatedAssociationOverview$, 0, 0]
    ];
    exports2.InstanceInformationFilter$ = [
      3,
      n032,
      _IIF,
      0,
      [_k, _vS],
      [0, [() => InstanceInformationFilterValueSet, 0]],
      2
    ];
    exports2.InstanceInformationStringFilter$ = [
      3,
      n032,
      _IISF,
      0,
      [_K10, _Va],
      [0, [() => InstanceInformationFilterValueSet, 0]],
      2
    ];
    exports2.InstancePatchState$ = [
      3,
      n032,
      _IPSn,
      0,
      [_II2, _PG, _BI, _OST, _OET, _Op, _SIn, _IOLn, _OI, _IC, _IOC, _IPRC, _IRC, _MCi, _FC, _UNAC, _NAC, _ASUC, _LNRIOT, _ROe, _CNCC, _SNCC, _ONCC],
      [0, 0, 0, 4, 4, 0, 0, 0, [() => OwnerInformation, 0], 1, 1, 1, 1, 1, 1, 1, 1, 1, 4, 0, 1, 1, 1],
      6
    ];
    exports2.InstancePatchStateFilter$ = [
      3,
      n032,
      _IPSF,
      0,
      [_K10, _Va, _Ty],
      [0, 64 | 0, 0],
      3
    ];
    exports2.InstanceProperty$ = [
      3,
      n032,
      _IPns,
      0,
      [_N, _II2, _ITns, _IRn, _KN, _ISns, _Ar, _IPA, _LTa, _PSi, _LPDT, _AVg, _PTla, _PNla, _PV, _AIct, _IRa, _RD, _RTe, _CNo, _AS, _LAED, _LSAED, _AO, _SIo, _STo],
      [0, 0, 0, 0, 0, 0, 0, [() => IPAddress, 0], 4, 0, 4, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 4, 4, () => exports2.InstanceAggregatedAssociationOverview$, 0, 0]
    ];
    exports2.InstancePropertyFilter$ = [
      3,
      n032,
      _IPF,
      0,
      [_k, _vS],
      [0, [() => InstancePropertyFilterValueSet, 0]],
      2
    ];
    exports2.InstancePropertyStringFilter$ = [
      3,
      n032,
      _IPSFn,
      0,
      [_K10, _Va, _Ope],
      [0, [() => InstancePropertyFilterValueSet, 0], 0],
      2
    ];
    exports2.InventoryAggregator$ = [
      3,
      n032,
      _IAnv,
      0,
      [_Ex, _Ag, _G],
      [0, [() => InventoryAggregatorList, 0], [() => InventoryGroupList, 0]]
    ];
    exports2.InventoryDeletionStatusItem$ = [
      3,
      n032,
      _IDSI,
      0,
      [_DI, _TN, _DST, _LS, _LSM, _DSe, _LSUT],
      [0, 0, 4, 0, 0, () => exports2.InventoryDeletionSummary$, 4]
    ];
    exports2.InventoryDeletionSummary$ = [
      3,
      n032,
      _IDS,
      0,
      [_TCo, _RCem, _SIu],
      [1, 1, () => InventoryDeletionSummaryItems]
    ];
    exports2.InventoryDeletionSummaryItem$ = [
      3,
      n032,
      _IDSIn,
      0,
      [_Ve, _Cou, _RCem],
      [0, 1, 1]
    ];
    exports2.InventoryFilter$ = [
      3,
      n032,
      _IFn,
      0,
      [_K10, _Va, _Ty],
      [0, [() => InventoryFilterValueList, 0], 0],
      2
    ];
    exports2.InventoryGroup$ = [
      3,
      n032,
      _IG,
      0,
      [_N, _Fi],
      [0, [() => InventoryFilterList, 0]],
      2
    ];
    exports2.InventoryItem$ = [
      3,
      n032,
      _IInve,
      0,
      [_TN, _SV, _CTa, _CH, _Con, _Cont],
      [0, 0, 0, 0, [1, n032, _IIEL, 0, 128 | 0], 128 | 0],
      3
    ];
    exports2.InventoryItemAttribute$ = [
      3,
      n032,
      _IIA,
      0,
      [_N, _DTa],
      [0, 0],
      2
    ];
    exports2.InventoryItemSchema$ = [
      3,
      n032,
      _IIS,
      0,
      [_TN, _Att, _Ve, _DNi],
      [0, [() => InventoryItemAttributeList, 0], 0, 0],
      2
    ];
    exports2.InventoryResultEntity$ = [
      3,
      n032,
      _IRE13,
      0,
      [_I, _Dat],
      [0, () => InventoryResultItemMap]
    ];
    exports2.InventoryResultItem$ = [
      3,
      n032,
      _IRIn,
      0,
      [_TN, _SV, _Con, _CTa, _CH],
      [0, 0, [1, n032, _IIEL, 0, 128 | 0], 0, 0],
      3
    ];
    exports2.LabelParameterVersionRequest$ = [
      3,
      n032,
      _LPVR,
      0,
      [_N, _La, _PVa],
      [0, 64 | 0, 1],
      2
    ];
    exports2.LabelParameterVersionResult$ = [
      3,
      n032,
      _LPVRa,
      0,
      [_IL, _PVa],
      [64 | 0, 1]
    ];
    exports2.ListAssociationsRequest$ = [
      3,
      n032,
      _LAR,
      0,
      [_AFL, _MR, _NT],
      [[() => AssociationFilterList, 0], 1, 0]
    ];
    exports2.ListAssociationsResult$ = [
      3,
      n032,
      _LARi,
      0,
      [_Ass, _NT],
      [[() => AssociationList, 0], 0]
    ];
    exports2.ListAssociationVersionsRequest$ = [
      3,
      n032,
      _LAVR,
      0,
      [_AIs, _MR, _NT],
      [0, 1, 0],
      1
    ];
    exports2.ListAssociationVersionsResult$ = [
      3,
      n032,
      _LAVRi,
      0,
      [_AVs, _NT],
      [[() => AssociationVersionList, 0], 0]
    ];
    exports2.ListCommandInvocationsRequest$ = [
      3,
      n032,
      _LCIR,
      0,
      [_CI, _II2, _MR, _NT, _Fi, _De],
      [0, 0, 1, 0, () => CommandFilterList, 2]
    ];
    exports2.ListCommandInvocationsResult$ = [
      3,
      n032,
      _LCIRi,
      0,
      [_CIomm, _NT],
      [() => CommandInvocationList, 0]
    ];
    exports2.ListCommandsRequest$ = [
      3,
      n032,
      _LCR,
      0,
      [_CI, _II2, _MR, _NT, _Fi],
      [0, 0, 1, 0, () => CommandFilterList]
    ];
    exports2.ListCommandsResult$ = [
      3,
      n032,
      _LCRi,
      0,
      [_Com, _NT],
      [[() => CommandList, 0], 0]
    ];
    exports2.ListComplianceItemsRequest$ = [
      3,
      n032,
      _LCIRis,
      0,
      [_Fi, _RIes, _RT13, _NT, _MR],
      [[() => ComplianceStringFilterList, 0], 64 | 0, 64 | 0, 0, 1]
    ];
    exports2.ListComplianceItemsResult$ = [
      3,
      n032,
      _LCIRist,
      0,
      [_CIomp, _NT],
      [[() => ComplianceItemList, 0], 0]
    ];
    exports2.ListComplianceSummariesRequest$ = [
      3,
      n032,
      _LCSR,
      0,
      [_Fi, _NT, _MR],
      [[() => ComplianceStringFilterList, 0], 0, 1]
    ];
    exports2.ListComplianceSummariesResult$ = [
      3,
      n032,
      _LCSRi,
      0,
      [_CSIo, _NT],
      [[() => ComplianceSummaryItemList, 0], 0]
    ];
    exports2.ListDocumentMetadataHistoryRequest$ = [
      3,
      n032,
      _LDMHR,
      0,
      [_N, _Me, _DV, _NT, _MR],
      [0, 0, 0, 0, 1],
      2
    ];
    exports2.ListDocumentMetadataHistoryResponse$ = [
      3,
      n032,
      _LDMHRi,
      0,
      [_N, _DV, _Au10, _Me, _NT],
      [0, 0, 0, () => exports2.DocumentMetadataResponseInfo$, 0]
    ];
    exports2.ListDocumentsRequest$ = [
      3,
      n032,
      _LDR,
      0,
      [_DFL, _Fi, _MR, _NT],
      [[() => DocumentFilterList, 0], () => DocumentKeyValuesFilterList, 1, 0]
    ];
    exports2.ListDocumentsResult$ = [
      3,
      n032,
      _LDRi,
      0,
      [_DIoc, _NT],
      [[() => DocumentIdentifierList, 0], 0]
    ];
    exports2.ListDocumentVersionsRequest$ = [
      3,
      n032,
      _LDVR,
      0,
      [_N, _MR, _NT],
      [0, 1, 0],
      1
    ];
    exports2.ListDocumentVersionsResult$ = [
      3,
      n032,
      _LDVRi,
      0,
      [_DVo, _NT],
      [() => DocumentVersionList, 0]
    ];
    exports2.ListInventoryEntriesRequest$ = [
      3,
      n032,
      _LIER,
      0,
      [_II2, _TN, _Fi, _NT, _MR],
      [0, 0, [() => InventoryFilterList, 0], 0, 1],
      2
    ];
    exports2.ListInventoryEntriesResult$ = [
      3,
      n032,
      _LIERi,
      0,
      [_TN, _II2, _SV, _CTa, _En, _NT],
      [0, 0, 0, 0, [1, n032, _IIEL, 0, 128 | 0], 0]
    ];
    exports2.ListNodesRequest$ = [
      3,
      n032,
      _LNR,
      0,
      [_SN10, _Fi, _NT, _MR],
      [0, [() => NodeFilterList, 0], 0, 1]
    ];
    exports2.ListNodesResult$ = [
      3,
      n032,
      _LNRi,
      0,
      [_Nod, _NT],
      [[() => NodeList, 0], 0]
    ];
    exports2.ListNodesSummaryRequest$ = [
      3,
      n032,
      _LNSR,
      0,
      [_Ag, _SN10, _Fi, _NT, _MR],
      [[() => NodeAggregatorList, 0], 0, [() => NodeFilterList, 0], 0, 1],
      1
    ];
    exports2.ListNodesSummaryResult$ = [
      3,
      n032,
      _LNSRi,
      0,
      [_Sum, _NT],
      [[1, n032, _NSL, 0, 128 | 0], 0]
    ];
    exports2.ListOpsItemEventsRequest$ = [
      3,
      n032,
      _LOIER,
      0,
      [_Fi, _MR, _NT],
      [() => OpsItemEventFilters, 1, 0]
    ];
    exports2.ListOpsItemEventsResponse$ = [
      3,
      n032,
      _LOIERi,
      0,
      [_NT, _Summ],
      [0, () => OpsItemEventSummaries]
    ];
    exports2.ListOpsItemRelatedItemsRequest$ = [
      3,
      n032,
      _LOIRIR,
      0,
      [_OII, _Fi, _MR, _NT],
      [0, () => OpsItemRelatedItemsFilters, 1, 0]
    ];
    exports2.ListOpsItemRelatedItemsResponse$ = [
      3,
      n032,
      _LOIRIRi,
      0,
      [_NT, _Summ],
      [0, () => OpsItemRelatedItemSummaries]
    ];
    exports2.ListOpsMetadataRequest$ = [
      3,
      n032,
      _LOMR,
      0,
      [_Fi, _MR, _NT],
      [() => OpsMetadataFilterList, 1, 0]
    ];
    exports2.ListOpsMetadataResult$ = [
      3,
      n032,
      _LOMRi,
      0,
      [_OML, _NT],
      [() => OpsMetadataList, 0]
    ];
    exports2.ListResourceComplianceSummariesRequest$ = [
      3,
      n032,
      _LRCSR,
      0,
      [_Fi, _NT, _MR],
      [[() => ComplianceStringFilterList, 0], 0, 1]
    ];
    exports2.ListResourceComplianceSummariesResult$ = [
      3,
      n032,
      _LRCSRi,
      0,
      [_RCSI, _NT],
      [[() => ResourceComplianceSummaryItemList, 0], 0]
    ];
    exports2.ListResourceDataSyncRequest$ = [
      3,
      n032,
      _LRDSR,
      0,
      [_ST11, _NT, _MR],
      [0, 0, 1]
    ];
    exports2.ListResourceDataSyncResult$ = [
      3,
      n032,
      _LRDSRi,
      0,
      [_RDSI, _NT],
      [() => ResourceDataSyncItemList, 0]
    ];
    exports2.ListTagsForResourceRequest$ = [
      3,
      n032,
      _LTFRR,
      0,
      [_RTe, _RI],
      [0, 0],
      2
    ];
    exports2.ListTagsForResourceResult$ = [
      3,
      n032,
      _LTFRRi,
      0,
      [_TLa],
      [() => TagList]
    ];
    exports2.LoggingInfo$ = [
      3,
      n032,
      _LI,
      0,
      [_SBN, _SRe, _SKP],
      [0, 0, 0],
      2
    ];
    exports2.MaintenanceWindowAutomationParameters$ = [
      3,
      n032,
      _MWAP,
      0,
      [_DV, _P10],
      [0, [2, n032, _APM, 0, 0, 64 | 0]]
    ];
    exports2.MaintenanceWindowExecution$ = [
      3,
      n032,
      _MWE,
      0,
      [_WI, _WEI, _St, _SD, _STt, _ETn],
      [0, 0, 0, 0, 4, 4]
    ];
    exports2.MaintenanceWindowExecutionTaskIdentity$ = [
      3,
      n032,
      _MWETI,
      0,
      [_WEI, _TEI, _St, _SD, _STt, _ETn, _TAa, _TTa, _AC, _TA],
      [0, 0, 0, 0, 4, 4, 0, 0, () => exports2.AlarmConfiguration$, () => AlarmStateInformationList]
    ];
    exports2.MaintenanceWindowExecutionTaskInvocationIdentity$ = [
      3,
      n032,
      _MWETII,
      0,
      [_WEI, _TEI, _IInv, _EI10, _TTa, _P10, _St, _SD, _STt, _ETn, _OI, _WTI],
      [0, 0, 0, 0, 0, [() => MaintenanceWindowExecutionTaskInvocationParameters, 0], 0, 0, 4, 4, [() => OwnerInformation, 0], 0]
    ];
    exports2.MaintenanceWindowFilter$ = [
      3,
      n032,
      _MWF,
      0,
      [_K10, _Va],
      [0, 64 | 0]
    ];
    exports2.MaintenanceWindowIdentity$ = [
      3,
      n032,
      _MWI,
      0,
      [_WI, _N, _D, _Ena, _Du, _Cu, _Sc, _STch, _SO, _EDn, _SDt, _NET],
      [0, 0, [() => MaintenanceWindowDescription, 0], 2, 1, 1, 0, 0, 1, 0, 0, 0]
    ];
    exports2.MaintenanceWindowIdentityForTarget$ = [
      3,
      n032,
      _MWIFT,
      0,
      [_WI, _N],
      [0, 0]
    ];
    exports2.MaintenanceWindowLambdaParameters$ = [
      3,
      n032,
      _MWLPa,
      0,
      [_CCl, _Q, _Pay],
      [0, 0, [() => MaintenanceWindowLambdaPayload, 0]]
    ];
    exports2.MaintenanceWindowRunCommandParameters$ = [
      3,
      n032,
      _MWRCP,
      0,
      [_Co, _CWOC, _DH, _DHT, _DV, _NC, _OSBN, _OSKP, _P10, _SRA, _TS],
      [0, () => exports2.CloudWatchOutputConfig$, 0, 0, 0, () => exports2.NotificationConfig$, 0, 0, [() => _Parameters, 0], 0, 1]
    ];
    exports2.MaintenanceWindowStepFunctionsParameters$ = [
      3,
      n032,
      _MWSFP,
      0,
      [_Inp, _N],
      [[() => MaintenanceWindowStepFunctionsInput, 0], 0]
    ];
    exports2.MaintenanceWindowTarget$ = [
      3,
      n032,
      _MWT,
      0,
      [_WI, _WTI, _RTe, _Ta10, _OI, _N, _D],
      [0, 0, 0, () => Targets2, [() => OwnerInformation, 0], 0, [() => MaintenanceWindowDescription, 0]]
    ];
    exports2.MaintenanceWindowTask$ = [
      3,
      n032,
      _MWTa,
      0,
      [_WI, _WTIi, _TAa, _Ty, _Ta10, _TPa, _Pr10, _LI, _SRA, _MC, _ME, _N, _D, _CB, _AC],
      [0, 0, 0, 0, () => Targets2, [() => MaintenanceWindowTaskParameters, 0], 1, () => exports2.LoggingInfo$, 0, 0, 0, 0, [() => MaintenanceWindowDescription, 0], 0, () => exports2.AlarmConfiguration$]
    ];
    exports2.MaintenanceWindowTaskInvocationParameters$ = [
      3,
      n032,
      _MWTIP,
      0,
      [_RCu, _Aut, _SF, _Lam],
      [[() => exports2.MaintenanceWindowRunCommandParameters$, 0], () => exports2.MaintenanceWindowAutomationParameters$, [() => exports2.MaintenanceWindowStepFunctionsParameters$, 0], [() => exports2.MaintenanceWindowLambdaParameters$, 0]]
    ];
    exports2.MaintenanceWindowTaskParameterValueExpression$ = [
      3,
      n032,
      _MWTPVE,
      8,
      [_Va],
      [[() => MaintenanceWindowTaskParameterValueList, 0]]
    ];
    exports2.MetadataValue$ = [
      3,
      n032,
      _MV,
      0,
      [_V10],
      [0]
    ];
    exports2.ModifyDocumentPermissionRequest$ = [
      3,
      n032,
      _MDPR,
      0,
      [_N, _PT, _AITA, _AITR, _SDV],
      [0, 0, [() => AccountIdList, 0], [() => AccountIdList, 0], 0],
      2
    ];
    exports2.ModifyDocumentPermissionResponse$ = [
      3,
      n032,
      _MDPRo,
      0,
      [],
      []
    ];
    exports2.Node$ = [
      3,
      n032,
      _Node,
      0,
      [_CTa, _I, _Ow, _Reg, _NTo],
      [4, 0, () => exports2.NodeOwnerInfo$, 0, [() => exports2.NodeType$, 0]]
    ];
    exports2.NodeAggregator$ = [
      3,
      n032,
      _NA,
      0,
      [_ATgg, _TN, _ANt, _Ag],
      [0, 0, 0, [() => NodeAggregatorList, 0]],
      3
    ];
    exports2.NodeFilter$ = [
      3,
      n032,
      _NF,
      0,
      [_K10, _Va, _Ty],
      [0, [() => NodeFilterValueList, 0], 0],
      2
    ];
    exports2.NodeOwnerInfo$ = [
      3,
      n032,
      _NOI,
      0,
      [_AIc, _OUI, _OUP],
      [0, 0, 0]
    ];
    exports2.NonCompliantSummary$ = [
      3,
      n032,
      _NCS,
      0,
      [_NCC, _SS],
      [1, () => exports2.SeveritySummary$]
    ];
    exports2.NotificationConfig$ = [
      3,
      n032,
      _NC,
      0,
      [_NAo, _NE, _NTot],
      [0, 64 | 0, 0]
    ];
    exports2.OpsAggregator$ = [
      3,
      n032,
      _OA,
      0,
      [_ATgg, _TN, _ANt, _Va, _Fi, _Ag],
      [0, 0, 0, 128 | 0, [() => OpsFilterList, 0], [() => OpsAggregatorList, 0]]
    ];
    exports2.OpsEntity$ = [
      3,
      n032,
      _OE,
      0,
      [_I, _Dat],
      [0, () => OpsEntityItemMap]
    ];
    exports2.OpsEntityItem$ = [
      3,
      n032,
      _OEI,
      0,
      [_CTa, _Con],
      [0, [1, n032, _OEIEL, 0, 128 | 0]]
    ];
    exports2.OpsFilter$ = [
      3,
      n032,
      _OF,
      0,
      [_K10, _Va, _Ty],
      [0, [() => OpsFilterValueList, 0], 0],
      2
    ];
    exports2.OpsItem$ = [
      3,
      n032,
      _OIp,
      0,
      [_CBr, _OIT, _CT4, _D, _LMB, _LMT, _No, _Pr10, _ROI, _St, _OII, _Ve, _Ti, _Sou, _OD, _Ca, _Se, _AST, _AETc, _PST, _PET, _OIA],
      [0, 0, 4, 0, 0, 4, () => OpsItemNotifications, 1, () => RelatedOpsItems, 0, 0, 0, 0, 0, () => OpsItemOperationalData, 0, 0, 4, 4, 4, 4, 0]
    ];
    exports2.OpsItemDataValue$ = [
      3,
      n032,
      _OIDV,
      0,
      [_V10, _Ty],
      [0, 0]
    ];
    exports2.OpsItemEventFilter$ = [
      3,
      n032,
      _OIEF,
      0,
      [_K10, _Va, _Ope],
      [0, 64 | 0, 0],
      3
    ];
    exports2.OpsItemEventSummary$ = [
      3,
      n032,
      _OIES,
      0,
      [_OII, _EIv, _Sou, _DTe, _Det, _CBr, _CT4],
      [0, 0, 0, 0, 0, () => exports2.OpsItemIdentity$, 4]
    ];
    exports2.OpsItemFilter$ = [
      3,
      n032,
      _OIFp,
      0,
      [_K10, _Va, _Ope],
      [0, 64 | 0, 0],
      3
    ];
    exports2.OpsItemIdentity$ = [
      3,
      n032,
      _OIIp,
      0,
      [_Arn],
      [0]
    ];
    exports2.OpsItemNotification$ = [
      3,
      n032,
      _OIN,
      0,
      [_Arn],
      [0]
    ];
    exports2.OpsItemRelatedItemsFilter$ = [
      3,
      n032,
      _OIRIF,
      0,
      [_K10, _Va, _Ope],
      [0, 64 | 0, 0],
      3
    ];
    exports2.OpsItemRelatedItemSummary$ = [
      3,
      n032,
      _OIRIS,
      0,
      [_OII, _AIs, _RTe, _AT13, _RU, _CBr, _CT4, _LMB, _LMT],
      [0, 0, 0, 0, 0, () => exports2.OpsItemIdentity$, 4, () => exports2.OpsItemIdentity$, 4]
    ];
    exports2.OpsItemSummary$ = [
      3,
      n032,
      _OISp,
      0,
      [_CBr, _CT4, _LMB, _LMT, _Pr10, _Sou, _St, _OII, _Ti, _OD, _Ca, _Se, _OIT, _AST, _AETc, _PST, _PET],
      [0, 4, 0, 4, 1, 0, 0, 0, 0, () => OpsItemOperationalData, 0, 0, 0, 4, 4, 4, 4]
    ];
    exports2.OpsMetadata$ = [
      3,
      n032,
      _OM,
      0,
      [_RI, _OMA, _LMD, _LMU, _CDr],
      [0, 0, 4, 0, 4]
    ];
    exports2.OpsMetadataFilter$ = [
      3,
      n032,
      _OMF,
      0,
      [_K10, _Va],
      [0, 64 | 0],
      2
    ];
    exports2.OpsResultAttribute$ = [
      3,
      n032,
      _ORA,
      0,
      [_TN],
      [0],
      1
    ];
    exports2.OutputSource$ = [
      3,
      n032,
      _OS,
      0,
      [_OSI, _OSTu],
      [0, 0]
    ];
    exports2.Parameter$ = [
      3,
      n032,
      _Par,
      0,
      [_N, _Ty, _V10, _Ve, _Sel, _SRo, _LMD, _ARN, _DTa],
      [0, 0, [() => PSParameterValue, 0], 1, 0, 0, 4, 0, 0]
    ];
    exports2.ParameterHistory$ = [
      3,
      n032,
      _PHa,
      0,
      [_N, _Ty, _KI, _LMD, _LMU, _D, _V10, _APl, _Ve, _La, _Tie, _Po, _DTa],
      [0, 0, 0, 4, 0, 0, [() => PSParameterValue, 0], 0, 1, 64 | 0, 0, () => ParameterPolicyList, 0]
    ];
    exports2.ParameterInlinePolicy$ = [
      3,
      n032,
      _PIP,
      0,
      [_PTo, _PTol, _PSo],
      [0, 0, 0]
    ];
    exports2.ParameterMetadata$ = [
      3,
      n032,
      _PM,
      0,
      [_N, _ARN, _Ty, _KI, _LMD, _LMU, _D, _APl, _Ve, _Tie, _Po, _DTa],
      [0, 0, 0, 0, 4, 0, 0, 0, 1, 0, () => ParameterPolicyList, 0]
    ];
    exports2.ParametersFilter$ = [
      3,
      n032,
      _PFa,
      0,
      [_K10, _Va],
      [0, 64 | 0],
      2
    ];
    exports2.ParameterStringFilter$ = [
      3,
      n032,
      _PSF,
      0,
      [_K10, _Opt, _Va],
      [0, 0, 64 | 0],
      1
    ];
    exports2.ParentStepDetails$ = [
      3,
      n032,
      _PSD,
      0,
      [_SEI, _SNt, _Ac, _It, _IV],
      [0, 0, 0, 1, 0]
    ];
    exports2.Patch$ = [
      3,
      n032,
      _Pat,
      0,
      [_I, _RDe, _Ti, _D, _CU, _Ven, _PFr, _Prod, _Cl, _MSs, _KNb, _MN, _Lan, _AIdv, _BIu, _CVEI, _N, _Ep, _Ve, _Rel, _Arc, _Se, _Rep],
      [0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 64 | 0, 64 | 0, 64 | 0, 0, 1, 0, 0, 0, 0, 0]
    ];
    exports2.PatchBaselineIdentity$ = [
      3,
      n032,
      _PBI,
      0,
      [_BI, _BN, _OSp, _BD, _DB],
      [0, 0, 0, 0, 2]
    ];
    exports2.PatchComplianceData$ = [
      3,
      n032,
      _PCD,
      0,
      [_Ti, _KBI, _Cl, _Se, _S, _ITnst, _CVEI],
      [0, 0, 0, 0, 0, 4, 0],
      6
    ];
    exports2.PatchFilter$ = [
      3,
      n032,
      _PFat,
      0,
      [_K10, _Va],
      [0, 64 | 0],
      2
    ];
    exports2.PatchFilterGroup$ = [
      3,
      n032,
      _PFG,
      0,
      [_PFatc],
      [() => PatchFilterList],
      1
    ];
    exports2.PatchGroupPatchBaselineMapping$ = [
      3,
      n032,
      _PGPBM,
      0,
      [_PG, _BIas],
      [0, () => exports2.PatchBaselineIdentity$]
    ];
    exports2.PatchOrchestratorFilter$ = [
      3,
      n032,
      _POF,
      0,
      [_K10, _Va],
      [0, 64 | 0]
    ];
    exports2.PatchRule$ = [
      3,
      n032,
      _PR,
      0,
      [_PFG, _CL, _AAD, _AUD, _ENS],
      [() => exports2.PatchFilterGroup$, 0, 1, 0, 2],
      1
    ];
    exports2.PatchRuleGroup$ = [
      3,
      n032,
      _PRG,
      0,
      [_PRa],
      [() => PatchRuleList],
      1
    ];
    exports2.PatchSource$ = [
      3,
      n032,
      _PSat,
      0,
      [_N, _Produ, _Conf],
      [0, 64 | 0, [() => PatchSourceConfiguration, 0]],
      3
    ];
    exports2.PatchStatus$ = [
      3,
      n032,
      _PSa,
      0,
      [_DSep, _CL, _ADp],
      [0, 0, 4]
    ];
    exports2.ProgressCounters$ = [
      3,
      n032,
      _PC10,
      0,
      [_TSo, _SSu, _FSa, _CSa, _TOS],
      [1, 1, 1, 1, 1]
    ];
    exports2.PutComplianceItemsRequest$ = [
      3,
      n032,
      _PCIR,
      0,
      [_RI, _RTe, _CTo, _ES, _Ite, _ICH, _UTp],
      [0, 0, 0, () => exports2.ComplianceExecutionSummary$, () => ComplianceItemEntryList, 0, 0],
      5
    ];
    exports2.PutComplianceItemsResult$ = [
      3,
      n032,
      _PCIRu,
      0,
      [],
      []
    ];
    exports2.PutInventoryRequest$ = [
      3,
      n032,
      _PIR,
      0,
      [_II2, _Ite],
      [0, [() => InventoryItemList, 0]],
      2
    ];
    exports2.PutInventoryResult$ = [
      3,
      n032,
      _PIRu,
      0,
      [_M],
      [0]
    ];
    exports2.PutParameterRequest$ = [
      3,
      n032,
      _PPR,
      0,
      [_N, _V10, _D, _Ty, _KI, _Ov, _APl, _T10, _Tie, _Po, _DTa],
      [0, [() => PSParameterValue, 0], 0, 0, 0, 2, 0, () => TagList, 0, 0, 0],
      2
    ];
    exports2.PutParameterResult$ = [
      3,
      n032,
      _PPRu,
      0,
      [_Ve, _Tie],
      [1, 0]
    ];
    exports2.PutResourcePolicyRequest$ = [
      3,
      n032,
      _PRPR,
      0,
      [_RA10, _Pol, _PI10, _PH],
      [0, 0, 0, 0],
      2
    ];
    exports2.PutResourcePolicyResponse$ = [
      3,
      n032,
      _PRPRu,
      0,
      [_PI10, _PH],
      [0, 0]
    ];
    exports2.RegisterDefaultPatchBaselineRequest$ = [
      3,
      n032,
      _RDPBR,
      0,
      [_BI],
      [0],
      1
    ];
    exports2.RegisterDefaultPatchBaselineResult$ = [
      3,
      n032,
      _RDPBRe,
      0,
      [_BI],
      [0]
    ];
    exports2.RegisterPatchBaselineForPatchGroupRequest$ = [
      3,
      n032,
      _RPBFPGR,
      0,
      [_BI, _PG],
      [0, 0],
      2
    ];
    exports2.RegisterPatchBaselineForPatchGroupResult$ = [
      3,
      n032,
      _RPBFPGRe,
      0,
      [_BI, _PG],
      [0, 0]
    ];
    exports2.RegisterTargetWithMaintenanceWindowRequest$ = [
      3,
      n032,
      _RTWMWR,
      0,
      [_WI, _RTe, _Ta10, _OI, _N, _D, _CTl],
      [0, 0, () => Targets2, [() => OwnerInformation, 0], 0, [() => MaintenanceWindowDescription, 0], [0, 4]],
      3
    ];
    exports2.RegisterTargetWithMaintenanceWindowResult$ = [
      3,
      n032,
      _RTWMWRe,
      0,
      [_WTI],
      [0]
    ];
    exports2.RegisterTaskWithMaintenanceWindowRequest$ = [
      3,
      n032,
      _RTWMWReg,
      0,
      [_WI, _TAa, _TTa, _Ta10, _SRA, _TPa, _TIP, _Pr10, _MC, _ME, _LI, _N, _D, _CTl, _CB, _AC],
      [0, 0, 0, () => Targets2, 0, [() => MaintenanceWindowTaskParameters, 0], [() => exports2.MaintenanceWindowTaskInvocationParameters$, 0], 1, 0, 0, () => exports2.LoggingInfo$, 0, [() => MaintenanceWindowDescription, 0], [0, 4], 0, () => exports2.AlarmConfiguration$],
      3
    ];
    exports2.RegisterTaskWithMaintenanceWindowResult$ = [
      3,
      n032,
      _RTWMWRegi,
      0,
      [_WTIi],
      [0]
    ];
    exports2.RegistrationMetadataItem$ = [
      3,
      n032,
      _RMI,
      0,
      [_K10, _V10],
      [0, 0],
      2
    ];
    exports2.RelatedOpsItem$ = [
      3,
      n032,
      _ROIe,
      0,
      [_OII],
      [0],
      1
    ];
    exports2.RemoveTagsFromResourceRequest$ = [
      3,
      n032,
      _RTFRR,
      0,
      [_RTe, _RI, _TK],
      [0, 0, 64 | 0],
      3
    ];
    exports2.RemoveTagsFromResourceResult$ = [
      3,
      n032,
      _RTFRRe,
      0,
      [],
      []
    ];
    exports2.ResetServiceSettingRequest$ = [
      3,
      n032,
      _RSSR,
      0,
      [_SIe],
      [0],
      1
    ];
    exports2.ResetServiceSettingResult$ = [
      3,
      n032,
      _RSSRe,
      0,
      [_SSe],
      [() => exports2.ServiceSetting$]
    ];
    exports2.ResolvedTargets$ = [
      3,
      n032,
      _RTes,
      0,
      [_PVar, _Tr],
      [64 | 0, 2]
    ];
    exports2.ResourceComplianceSummaryItem$ = [
      3,
      n032,
      _RCSIe,
      0,
      [_CTo, _RTe, _RI, _St, _OSv, _ES, _CSo, _NCS],
      [0, 0, 0, 0, 0, () => exports2.ComplianceExecutionSummary$, () => exports2.CompliantSummary$, () => exports2.NonCompliantSummary$]
    ];
    exports2.ResourceDataSyncAwsOrganizationsSource$ = [
      3,
      n032,
      _RDSAOS,
      0,
      [_OSTr, _OUr],
      [0, () => ResourceDataSyncOrganizationalUnitList],
      1
    ];
    exports2.ResourceDataSyncDestinationDataSharing$ = [
      3,
      n032,
      _RDSDDS,
      0,
      [_DDST],
      [0]
    ];
    exports2.ResourceDataSyncItem$ = [
      3,
      n032,
      _RDSIe,
      0,
      [_SN10, _ST11, _SSy, _SDe, _LST, _LSST, _SLMT, _LS, _SCT, _LSSM],
      [0, 0, () => exports2.ResourceDataSyncSourceWithState$, () => exports2.ResourceDataSyncS3Destination$, 4, 4, 4, 0, 4, 0]
    ];
    exports2.ResourceDataSyncOrganizationalUnit$ = [
      3,
      n032,
      _RDSOU,
      0,
      [_OUI],
      [0]
    ];
    exports2.ResourceDataSyncS3Destination$ = [
      3,
      n032,
      _RDSSD,
      0,
      [_BNu, _SFy, _Reg, _Pre, _AWSKMSKARN, _DDS],
      [0, 0, 0, 0, 0, () => exports2.ResourceDataSyncDestinationDataSharing$],
      3
    ];
    exports2.ResourceDataSyncSource$ = [
      3,
      n032,
      _RDSS,
      0,
      [_STo, _SRou, _AOS, _IFR, _EAODS],
      [0, 64 | 0, () => exports2.ResourceDataSyncAwsOrganizationsSource$, 2, 2],
      2
    ];
    exports2.ResourceDataSyncSourceWithState$ = [
      3,
      n032,
      _RDSSWS,
      0,
      [_STo, _AOS, _SRou, _IFR, _S, _EAODS],
      [0, () => exports2.ResourceDataSyncAwsOrganizationsSource$, 64 | 0, 2, 0, 2]
    ];
    exports2.ResultAttribute$ = [
      3,
      n032,
      _RAes,
      0,
      [_TN],
      [0],
      1
    ];
    exports2.ResumeSessionRequest$ = [
      3,
      n032,
      _RSR,
      0,
      [_SIes],
      [0],
      1
    ];
    exports2.ResumeSessionResponse$ = [
      3,
      n032,
      _RSRe,
      0,
      [_SIes, _TV, _SUt],
      [0, 0, 0]
    ];
    exports2.ReviewInformation$ = [
      3,
      n032,
      _RIe,
      0,
      [_RTev, _St, _Rev],
      [4, 0, 0]
    ];
    exports2.Runbook$ = [
      3,
      n032,
      _Ru,
      0,
      [_DN, _DV, _P10, _TPN, _Ta10, _TM, _MC, _ME, _TL],
      [0, 0, [2, n032, _APM, 0, 0, 64 | 0], 0, () => Targets2, [1, n032, _TM, 0, [2, n032, _TMa, 0, 0, 64 | 0]], 0, 0, () => TargetLocations],
      1
    ];
    exports2.S3OutputLocation$ = [
      3,
      n032,
      _SOL,
      0,
      [_OSR, _OSBN, _OSKP],
      [0, 0, 0]
    ];
    exports2.S3OutputUrl$ = [
      3,
      n032,
      _SOUu,
      0,
      [_OU],
      [0]
    ];
    exports2.ScheduledWindowExecution$ = [
      3,
      n032,
      _SWEc,
      0,
      [_WI, _N, _ET],
      [0, 0, 0]
    ];
    exports2.SendAutomationSignalRequest$ = [
      3,
      n032,
      _SASR,
      0,
      [_AEI, _STi, _Pay],
      [0, 0, [2, n032, _APM, 0, 0, 64 | 0]],
      2
    ];
    exports2.SendAutomationSignalResult$ = [
      3,
      n032,
      _SASRe,
      0,
      [],
      []
    ];
    exports2.SendCommandRequest$ = [
      3,
      n032,
      _SCR,
      0,
      [_DN, _IIn, _Ta10, _DV, _DH, _DHT, _TS, _Co, _P10, _OSR, _OSBN, _OSKP, _MC, _ME, _SRA, _NC, _CWOC, _AC],
      [0, 64 | 0, () => Targets2, 0, 0, 0, 1, 0, [() => _Parameters, 0], 0, 0, 0, 0, 0, 0, () => exports2.NotificationConfig$, () => exports2.CloudWatchOutputConfig$, () => exports2.AlarmConfiguration$],
      1
    ];
    exports2.SendCommandResult$ = [
      3,
      n032,
      _SCRe,
      0,
      [_C11],
      [[() => exports2.Command$, 0]]
    ];
    exports2.ServiceSetting$ = [
      3,
      n032,
      _SSe,
      0,
      [_SIe, _SVe, _LMD, _LMU, _ARN, _St],
      [0, 0, 4, 0, 0, 0]
    ];
    exports2.Session$ = [
      3,
      n032,
      _Sess,
      0,
      [_SIes, _Tar, _St, _SDt, _EDn, _DN, _Ow, _Rea, _De, _OU, _MSD, _ATc],
      [0, 0, 0, 4, 4, 0, 0, 0, 0, () => exports2.SessionManagerOutputUrl$, 0, 0]
    ];
    exports2.SessionFilter$ = [
      3,
      n032,
      _SFe,
      0,
      [_k, _v],
      [0, 0],
      2
    ];
    exports2.SessionManagerOutputUrl$ = [
      3,
      n032,
      _SMOU,
      0,
      [_SOUu, _CWOU],
      [0, 0]
    ];
    exports2.SeveritySummary$ = [
      3,
      n032,
      _SS,
      0,
      [_CCr, _HC, _MCe, _LC, _ICn, _UC],
      [1, 1, 1, 1, 1, 1]
    ];
    exports2.StartAccessRequestRequest$ = [
      3,
      n032,
      _SARR,
      0,
      [_Rea, _Ta10, _T10],
      [0, () => Targets2, () => TagList],
      2
    ];
    exports2.StartAccessRequestResponse$ = [
      3,
      n032,
      _SARRt,
      0,
      [_ARI10],
      [0]
    ];
    exports2.StartAssociationsOnceRequest$ = [
      3,
      n032,
      _SAOR,
      0,
      [_AIss],
      [64 | 0],
      1
    ];
    exports2.StartAssociationsOnceResult$ = [
      3,
      n032,
      _SAORt,
      0,
      [],
      []
    ];
    exports2.StartAutomationExecutionRequest$ = [
      3,
      n032,
      _SAER,
      0,
      [_DN, _DV, _P10, _CTl, _Mo, _TPN, _Ta10, _TM, _MC, _ME, _TL, _T10, _AC, _TLURL],
      [0, 0, [2, n032, _APM, 0, 0, 64 | 0], 0, 0, 0, () => Targets2, [1, n032, _TM, 0, [2, n032, _TMa, 0, 0, 64 | 0]], 0, 0, () => TargetLocations, () => TagList, () => exports2.AlarmConfiguration$, 0],
      1
    ];
    exports2.StartAutomationExecutionResult$ = [
      3,
      n032,
      _SAERt,
      0,
      [_AEI],
      [0]
    ];
    exports2.StartChangeRequestExecutionRequest$ = [
      3,
      n032,
      _SCRER,
      0,
      [_DN, _R, _STc, _DV, _P10, _CRN, _CTl, _AA, _T10, _SETc, _CDh],
      [0, () => Runbooks, 4, 0, [2, n032, _APM, 0, 0, 64 | 0], 0, 0, 2, () => TagList, 4, 0],
      2
    ];
    exports2.StartChangeRequestExecutionResult$ = [
      3,
      n032,
      _SCRERt,
      0,
      [_AEI],
      [0]
    ];
    exports2.StartExecutionPreviewRequest$ = [
      3,
      n032,
      _SEPR,
      0,
      [_DN, _DV, _EIx],
      [0, 0, () => exports2.ExecutionInputs$],
      1
    ];
    exports2.StartExecutionPreviewResponse$ = [
      3,
      n032,
      _SEPRt,
      0,
      [_EPI],
      [0]
    ];
    exports2.StartSessionRequest$ = [
      3,
      n032,
      _SSR,
      0,
      [_Tar, _DN, _Rea, _P10],
      [0, 0, 0, [2, n032, _SMP, 0, 0, 64 | 0]],
      1
    ];
    exports2.StartSessionResponse$ = [
      3,
      n032,
      _SSRt,
      0,
      [_SIes, _TV, _SUt],
      [0, 0, 0]
    ];
    exports2.StepExecution$ = [
      3,
      n032,
      _SEte,
      0,
      [_SNt, _Ac, _TS, _OFn, _MA, _EST, _EET, _SSt, _RCes, _Inpu, _Ou, _Res, _FM, _FD, _SEI, _OP, _IE, _NS, _ICs, _VNS, _Ta10, _TLar, _TA, _PSD],
      [0, 0, 1, 0, 1, 4, 4, 0, 0, 128 | 0, [2, n032, _APM, 0, 0, 64 | 0], 0, 0, () => exports2.FailureDetails$, 0, [2, n032, _APM, 0, 0, 64 | 0], 2, 0, 2, 64 | 0, () => Targets2, () => exports2.TargetLocation$, () => AlarmStateInformationList, () => exports2.ParentStepDetails$]
    ];
    exports2.StepExecutionFilter$ = [
      3,
      n032,
      _SEF,
      0,
      [_K10, _Va],
      [0, 64 | 0],
      2
    ];
    exports2.StopAutomationExecutionRequest$ = [
      3,
      n032,
      _SAERto,
      0,
      [_AEI, _Ty],
      [0, 0],
      1
    ];
    exports2.StopAutomationExecutionResult$ = [
      3,
      n032,
      _SAERtop,
      0,
      [],
      []
    ];
    exports2.Tag$ = [
      3,
      n032,
      _Tag,
      0,
      [_K10, _V10],
      [0, 0],
      2
    ];
    exports2.Target$ = [
      3,
      n032,
      _Tar,
      0,
      [_K10, _Va],
      [0, 64 | 0]
    ];
    exports2.TargetLocation$ = [
      3,
      n032,
      _TLar,
      0,
      [_Acc, _Re, _TLMC, _TLME, _ERN, _TLAC, _ICOU, _EAx, _Ta10, _TMC, _TME],
      [64 | 0, 64 | 0, 0, 0, 0, () => exports2.AlarmConfiguration$, 2, 64 | 0, () => Targets2, 0, 0]
    ];
    exports2.TargetPreview$ = [
      3,
      n032,
      _TPar,
      0,
      [_Cou, _TT],
      [1, 0]
    ];
    exports2.TerminateSessionRequest$ = [
      3,
      n032,
      _TSR,
      0,
      [_SIes],
      [0],
      1
    ];
    exports2.TerminateSessionResponse$ = [
      3,
      n032,
      _TSRe,
      0,
      [_SIes],
      [0]
    ];
    exports2.UnlabelParameterVersionRequest$ = [
      3,
      n032,
      _UPVR,
      0,
      [_N, _PVa, _La],
      [0, 1, 64 | 0],
      3
    ];
    exports2.UnlabelParameterVersionResult$ = [
      3,
      n032,
      _UPVRn,
      0,
      [_RLe, _IL],
      [64 | 0, 64 | 0]
    ];
    exports2.UpdateAssociationRequest$ = [
      3,
      n032,
      _UAR,
      0,
      [_AIs, _P10, _DV, _SE, _OL, _N, _Ta10, _AN, _AV, _ATPN, _ME, _MC, _CS4, _SCy, _AOACI, _CN, _TL, _SO, _Du, _TM, _AC, _ADAR],
      [0, [() => _Parameters, 0], 0, 0, () => exports2.InstanceAssociationOutputLocation$, 0, () => Targets2, 0, 0, 0, 0, 0, 0, 0, 2, 64 | 0, () => TargetLocations, 1, 1, [1, n032, _TM, 0, [2, n032, _TMa, 0, 0, 64 | 0]], () => exports2.AlarmConfiguration$, 0],
      1
    ];
    exports2.UpdateAssociationResult$ = [
      3,
      n032,
      _UARp,
      0,
      [_AD],
      [[() => exports2.AssociationDescription$, 0]]
    ];
    exports2.UpdateAssociationStatusRequest$ = [
      3,
      n032,
      _UASR,
      0,
      [_N, _II2, _AS],
      [0, 0, () => exports2.AssociationStatus$],
      3
    ];
    exports2.UpdateAssociationStatusResult$ = [
      3,
      n032,
      _UASRp,
      0,
      [_AD],
      [[() => exports2.AssociationDescription$, 0]]
    ];
    exports2.UpdateDocumentDefaultVersionRequest$ = [
      3,
      n032,
      _UDDVR,
      0,
      [_N, _DV],
      [0, 0],
      2
    ];
    exports2.UpdateDocumentDefaultVersionResult$ = [
      3,
      n032,
      _UDDVRp,
      0,
      [_D],
      [() => exports2.DocumentDefaultVersionDescription$]
    ];
    exports2.UpdateDocumentMetadataRequest$ = [
      3,
      n032,
      _UDMR,
      0,
      [_N, _DRoc, _DV],
      [0, () => exports2.DocumentReviews$, 0],
      2
    ];
    exports2.UpdateDocumentMetadataResponse$ = [
      3,
      n032,
      _UDMRp,
      0,
      [],
      []
    ];
    exports2.UpdateDocumentRequest$ = [
      3,
      n032,
      _UDR,
      0,
      [_Con, _N, _At, _DNi, _VN, _DV, _DF, _TT],
      [0, 0, () => AttachmentsSourceList, 0, 0, 0, 0, 0],
      2
    ];
    exports2.UpdateDocumentResult$ = [
      3,
      n032,
      _UDRp,
      0,
      [_DD],
      [[() => exports2.DocumentDescription$, 0]]
    ];
    exports2.UpdateMaintenanceWindowRequest$ = [
      3,
      n032,
      _UMWR,
      0,
      [_WI, _N, _D, _SDt, _EDn, _Sc, _STch, _SO, _Du, _Cu, _AUT, _Ena, _Repl],
      [0, 0, [() => MaintenanceWindowDescription, 0], 0, 0, 0, 0, 1, 1, 1, 2, 2, 2],
      1
    ];
    exports2.UpdateMaintenanceWindowResult$ = [
      3,
      n032,
      _UMWRp,
      0,
      [_WI, _N, _D, _SDt, _EDn, _Sc, _STch, _SO, _Du, _Cu, _AUT, _Ena],
      [0, 0, [() => MaintenanceWindowDescription, 0], 0, 0, 0, 0, 1, 1, 1, 2, 2]
    ];
    exports2.UpdateMaintenanceWindowTargetRequest$ = [
      3,
      n032,
      _UMWTR,
      0,
      [_WI, _WTI, _Ta10, _OI, _N, _D, _Repl],
      [0, 0, () => Targets2, [() => OwnerInformation, 0], 0, [() => MaintenanceWindowDescription, 0], 2],
      2
    ];
    exports2.UpdateMaintenanceWindowTargetResult$ = [
      3,
      n032,
      _UMWTRp,
      0,
      [_WI, _WTI, _Ta10, _OI, _N, _D],
      [0, 0, () => Targets2, [() => OwnerInformation, 0], 0, [() => MaintenanceWindowDescription, 0]]
    ];
    exports2.UpdateMaintenanceWindowTaskRequest$ = [
      3,
      n032,
      _UMWTRpd,
      0,
      [_WI, _WTIi, _Ta10, _TAa, _SRA, _TPa, _TIP, _Pr10, _MC, _ME, _LI, _N, _D, _Repl, _CB, _AC],
      [0, 0, () => Targets2, 0, 0, [() => MaintenanceWindowTaskParameters, 0], [() => exports2.MaintenanceWindowTaskInvocationParameters$, 0], 1, 0, 0, () => exports2.LoggingInfo$, 0, [() => MaintenanceWindowDescription, 0], 2, 0, () => exports2.AlarmConfiguration$],
      2
    ];
    exports2.UpdateMaintenanceWindowTaskResult$ = [
      3,
      n032,
      _UMWTRpda,
      0,
      [_WI, _WTIi, _Ta10, _TAa, _SRA, _TPa, _TIP, _Pr10, _MC, _ME, _LI, _N, _D, _CB, _AC],
      [0, 0, () => Targets2, 0, 0, [() => MaintenanceWindowTaskParameters, 0], [() => exports2.MaintenanceWindowTaskInvocationParameters$, 0], 1, 0, 0, () => exports2.LoggingInfo$, 0, [() => MaintenanceWindowDescription, 0], 0, () => exports2.AlarmConfiguration$]
    ];
    exports2.UpdateManagedInstanceRoleRequest$ = [
      3,
      n032,
      _UMIRR,
      0,
      [_II2, _IRa],
      [0, 0],
      2
    ];
    exports2.UpdateManagedInstanceRoleResult$ = [
      3,
      n032,
      _UMIRRp,
      0,
      [],
      []
    ];
    exports2.UpdateOpsItemRequest$ = [
      3,
      n032,
      _UOIR,
      0,
      [_OII, _D, _OD, _ODTD, _No, _Pr10, _ROI, _St, _Ti, _Ca, _Se, _AST, _AETc, _PST, _PET, _OIA],
      [0, 0, () => OpsItemOperationalData, 64 | 0, () => OpsItemNotifications, 1, () => RelatedOpsItems, 0, 0, 0, 0, 4, 4, 4, 4, 0],
      1
    ];
    exports2.UpdateOpsItemResponse$ = [
      3,
      n032,
      _UOIRp,
      0,
      [],
      []
    ];
    exports2.UpdateOpsMetadataRequest$ = [
      3,
      n032,
      _UOMR,
      0,
      [_OMA, _MTU, _KTD],
      [0, () => MetadataMap, 64 | 0],
      1
    ];
    exports2.UpdateOpsMetadataResult$ = [
      3,
      n032,
      _UOMRp,
      0,
      [_OMA],
      [0]
    ];
    exports2.UpdatePatchBaselineRequest$ = [
      3,
      n032,
      _UPBR,
      0,
      [_BI, _N, _GF, _AR10, _AP, _APCL, _APENS, _RP, _RPA, _D, _So, _ASUCS, _Repl],
      [0, 0, () => exports2.PatchFilterGroup$, () => exports2.PatchRuleGroup$, 64 | 0, 0, 2, 64 | 0, 0, 0, [() => PatchSourceList, 0], 0, 2],
      1
    ];
    exports2.UpdatePatchBaselineResult$ = [
      3,
      n032,
      _UPBRp,
      0,
      [_BI, _N, _OSp, _GF, _AR10, _AP, _APCL, _APENS, _RP, _RPA, _CD, _MD, _D, _So, _ASUCS],
      [0, 0, 0, () => exports2.PatchFilterGroup$, () => exports2.PatchRuleGroup$, 64 | 0, 0, 2, 64 | 0, 0, 4, 4, 0, [() => PatchSourceList, 0], 0]
    ];
    exports2.UpdateResourceDataSyncRequest$ = [
      3,
      n032,
      _URDSR,
      0,
      [_SN10, _ST11, _SSy],
      [0, 0, () => exports2.ResourceDataSyncSource$],
      3
    ];
    exports2.UpdateResourceDataSyncResult$ = [
      3,
      n032,
      _URDSRp,
      0,
      [],
      []
    ];
    exports2.UpdateServiceSettingRequest$ = [
      3,
      n032,
      _USSR,
      0,
      [_SIe, _SVe],
      [0, 0],
      2
    ];
    exports2.UpdateServiceSettingResult$ = [
      3,
      n032,
      _USSRp,
      0,
      [],
      []
    ];
    var AccountIdList = [
      1,
      n032,
      _AIL,
      0,
      [
        0,
        { [_xN]: _AIc }
      ]
    ];
    var Accounts = 64 | 0;
    var AccountSharingInfoList = [
      1,
      n032,
      _ASIL,
      0,
      [
        () => exports2.AccountSharingInfo$,
        { [_xN]: _ASI }
      ]
    ];
    var ActivationList = [
      1,
      n032,
      _AL,
      0,
      () => exports2.Activation$
    ];
    var AlarmList = [
      1,
      n032,
      _ALl,
      0,
      () => exports2.Alarm$
    ];
    var AlarmStateInformationList = [
      1,
      n032,
      _ASILl,
      0,
      () => exports2.AlarmStateInformation$
    ];
    var AssociationDescriptionList = [
      1,
      n032,
      _ADL,
      0,
      [
        () => exports2.AssociationDescription$,
        { [_xN]: _AD }
      ]
    ];
    var AssociationExecutionFilterList = [
      1,
      n032,
      _AEFL,
      0,
      [
        () => exports2.AssociationExecutionFilter$,
        { [_xN]: _AEF }
      ]
    ];
    var AssociationExecutionsList = [
      1,
      n032,
      _AEL,
      0,
      [
        () => exports2.AssociationExecution$,
        { [_xN]: _AE }
      ]
    ];
    var AssociationExecutionTargetsFilterList = [
      1,
      n032,
      _AETFL,
      0,
      [
        () => exports2.AssociationExecutionTargetsFilter$,
        { [_xN]: _AETF }
      ]
    ];
    var AssociationExecutionTargetsList = [
      1,
      n032,
      _AETL,
      0,
      [
        () => exports2.AssociationExecutionTarget$,
        { [_xN]: _AET }
      ]
    ];
    var AssociationFilterList = [
      1,
      n032,
      _AFL,
      0,
      [
        () => exports2.AssociationFilter$,
        { [_xN]: _AF }
      ]
    ];
    var AssociationIdList = 64 | 0;
    var AssociationList = [
      1,
      n032,
      _ALs,
      0,
      [
        () => exports2.Association$,
        { [_xN]: _As }
      ]
    ];
    var AssociationVersionList = [
      1,
      n032,
      _AVL,
      0,
      [
        () => exports2.AssociationVersionInfo$,
        0
      ]
    ];
    var AttachmentContentList = [
      1,
      n032,
      _ACL,
      0,
      [
        () => exports2.AttachmentContent$,
        { [_xN]: _ACt }
      ]
    ];
    var AttachmentInformationList = [
      1,
      n032,
      _AILt,
      0,
      [
        () => exports2.AttachmentInformation$,
        { [_xN]: _AIt }
      ]
    ];
    var AttachmentsSourceList = [
      1,
      n032,
      _ASL,
      0,
      () => exports2.AttachmentsSource$
    ];
    var AttachmentsSourceValues = 64 | 0;
    var AutomationExecutionFilterList = [
      1,
      n032,
      _AEFLu,
      0,
      () => exports2.AutomationExecutionFilter$
    ];
    var AutomationExecutionFilterValueList = 64 | 0;
    var AutomationExecutionMetadataList = [
      1,
      n032,
      _AEML,
      0,
      () => exports2.AutomationExecutionMetadata$
    ];
    var AutomationParameterValueList = 64 | 0;
    var CalendarNameOrARNList = 64 | 0;
    var CategoryEnumList = 64 | 0;
    var CategoryList = 64 | 0;
    var CommandFilterList = [
      1,
      n032,
      _CFL,
      0,
      () => exports2.CommandFilter$
    ];
    var CommandInvocationList = [
      1,
      n032,
      _CIL,
      0,
      () => exports2.CommandInvocation$
    ];
    var CommandList = [
      1,
      n032,
      _CLo,
      0,
      [
        () => exports2.Command$,
        0
      ]
    ];
    var CommandPluginList = [
      1,
      n032,
      _CPL,
      0,
      () => exports2.CommandPlugin$
    ];
    var ComplianceItemEntryList = [
      1,
      n032,
      _CIEL,
      0,
      () => exports2.ComplianceItemEntry$
    ];
    var ComplianceItemList = [
      1,
      n032,
      _CILo,
      0,
      [
        () => exports2.ComplianceItem$,
        { [_xN]: _Item }
      ]
    ];
    var ComplianceResourceIdList = 64 | 0;
    var ComplianceResourceTypeList = 64 | 0;
    var ComplianceStringFilterList = [
      1,
      n032,
      _CSFL,
      0,
      [
        () => exports2.ComplianceStringFilter$,
        { [_xN]: _CFo }
      ]
    ];
    var ComplianceStringFilterValueList = [
      1,
      n032,
      _CSFVL,
      0,
      [
        0,
        { [_xN]: _FVi }
      ]
    ];
    var ComplianceSummaryItemList = [
      1,
      n032,
      _CSIL,
      0,
      [
        () => exports2.ComplianceSummaryItem$,
        { [_xN]: _Item }
      ]
    ];
    var CreateAssociationBatchRequestEntries = [
      1,
      n032,
      _CABREr,
      0,
      [
        () => exports2.CreateAssociationBatchRequestEntry$,
        { [_xN]: _en }
      ]
    ];
    var DescribeActivationsFilterList = [
      1,
      n032,
      _DAFL,
      0,
      () => exports2.DescribeActivationsFilter$
    ];
    var DocumentFilterList = [
      1,
      n032,
      _DFL,
      0,
      [
        () => exports2.DocumentFilter$,
        { [_xN]: _DFo }
      ]
    ];
    var DocumentIdentifierList = [
      1,
      n032,
      _DIL,
      0,
      [
        () => exports2.DocumentIdentifier$,
        { [_xN]: _DIo }
      ]
    ];
    var DocumentKeyValuesFilterList = [
      1,
      n032,
      _DKVFL,
      0,
      () => exports2.DocumentKeyValuesFilter$
    ];
    var DocumentKeyValuesFilterValues = 64 | 0;
    var DocumentParameterList = [
      1,
      n032,
      _DPLo,
      0,
      [
        () => exports2.DocumentParameter$,
        { [_xN]: _DPo }
      ]
    ];
    var DocumentRequiresList = [
      1,
      n032,
      _DRL,
      0,
      () => exports2.DocumentRequires$
    ];
    var DocumentReviewCommentList = [
      1,
      n032,
      _DRCL,
      0,
      () => exports2.DocumentReviewCommentSource$
    ];
    var DocumentReviewerResponseList = [
      1,
      n032,
      _DRRL,
      0,
      () => exports2.DocumentReviewerResponseSource$
    ];
    var DocumentVersionList = [
      1,
      n032,
      _DVL,
      0,
      () => exports2.DocumentVersionInfo$
    ];
    var EffectivePatchList = [
      1,
      n032,
      _EPL,
      0,
      () => exports2.EffectivePatch$
    ];
    var ExcludeAccounts = 64 | 0;
    var FailedCreateAssociationList = [
      1,
      n032,
      _FCAL,
      0,
      [
        () => exports2.FailedCreateAssociation$,
        { [_xN]: _FCAE }
      ]
    ];
    var GetResourcePoliciesResponseEntries = [
      1,
      n032,
      _GRPREe,
      0,
      () => exports2.GetResourcePoliciesResponseEntry$
    ];
    var InstanceAssociationList = [
      1,
      n032,
      _IAL,
      0,
      () => exports2.InstanceAssociation$
    ];
    var InstanceAssociationStatusInfos = [
      1,
      n032,
      _IASI,
      0,
      () => exports2.InstanceAssociationStatusInfo$
    ];
    var InstanceIdList = 64 | 0;
    var InstanceInformationFilterList = [
      1,
      n032,
      _IIFL,
      0,
      [
        () => exports2.InstanceInformationFilter$,
        { [_xN]: _IIF }
      ]
    ];
    var InstanceInformationFilterValueSet = [
      1,
      n032,
      _IIFVS,
      0,
      [
        0,
        { [_xN]: _IIFV }
      ]
    ];
    var InstanceInformationList = [
      1,
      n032,
      _IIL,
      0,
      [
        () => exports2.InstanceInformation$,
        { [_xN]: _IInst }
      ]
    ];
    var InstanceInformationStringFilterList = [
      1,
      n032,
      _IISFL,
      0,
      [
        () => exports2.InstanceInformationStringFilter$,
        { [_xN]: _IISF }
      ]
    ];
    var InstancePatchStateFilterList = [
      1,
      n032,
      _IPSFL,
      0,
      () => exports2.InstancePatchStateFilter$
    ];
    var InstancePatchStateFilterValues = 64 | 0;
    var InstancePatchStateList = [
      1,
      n032,
      _IPSL,
      0,
      [
        () => exports2.InstancePatchState$,
        0
      ]
    ];
    var InstancePatchStatesList = [
      1,
      n032,
      _IPSLn,
      0,
      [
        () => exports2.InstancePatchState$,
        0
      ]
    ];
    var InstanceProperties = [
      1,
      n032,
      _IPn,
      0,
      [
        () => exports2.InstanceProperty$,
        { [_xN]: _IPns }
      ]
    ];
    var InstancePropertyFilterList = [
      1,
      n032,
      _IPFL,
      0,
      [
        () => exports2.InstancePropertyFilter$,
        { [_xN]: _IPF }
      ]
    ];
    var InstancePropertyFilterValueSet = [
      1,
      n032,
      _IPFVS,
      0,
      [
        0,
        { [_xN]: _IPFV }
      ]
    ];
    var InstancePropertyStringFilterList = [
      1,
      n032,
      _IPSFLn,
      0,
      [
        () => exports2.InstancePropertyStringFilter$,
        { [_xN]: _IPSFn }
      ]
    ];
    var InventoryAggregatorList = [
      1,
      n032,
      _IALn,
      0,
      [
        () => exports2.InventoryAggregator$,
        { [_xN]: _Agg }
      ]
    ];
    var InventoryDeletionsList = [
      1,
      n032,
      _IDL,
      0,
      () => exports2.InventoryDeletionStatusItem$
    ];
    var InventoryDeletionSummaryItems = [
      1,
      n032,
      _IDSInv,
      0,
      () => exports2.InventoryDeletionSummaryItem$
    ];
    var InventoryFilterList = [
      1,
      n032,
      _IFL,
      0,
      [
        () => exports2.InventoryFilter$,
        { [_xN]: _IFn }
      ]
    ];
    var InventoryFilterValueList = [
      1,
      n032,
      _IFVL,
      0,
      [
        0,
        { [_xN]: _FVi }
      ]
    ];
    var InventoryGroupList = [
      1,
      n032,
      _IGL,
      0,
      [
        () => exports2.InventoryGroup$,
        { [_xN]: _IG }
      ]
    ];
    var InventoryItemAttributeList = [
      1,
      n032,
      _IIAL,
      0,
      [
        () => exports2.InventoryItemAttribute$,
        { [_xN]: _Attr }
      ]
    ];
    var InventoryItemEntryList = [
      1,
      n032,
      _IIEL,
      0,
      128 | 0
    ];
    var InventoryItemList = [
      1,
      n032,
      _IILn,
      0,
      [
        () => exports2.InventoryItem$,
        { [_xN]: _Item }
      ]
    ];
    var InventoryItemSchemaResultList = [
      1,
      n032,
      _IISRL,
      0,
      [
        () => exports2.InventoryItemSchema$,
        0
      ]
    ];
    var InventoryResultEntityList = [
      1,
      n032,
      _IREL,
      0,
      [
        () => exports2.InventoryResultEntity$,
        { [_xN]: _Entit }
      ]
    ];
    var KeyList = 64 | 0;
    var MaintenanceWindowExecutionList = [
      1,
      n032,
      _MWEL,
      0,
      () => exports2.MaintenanceWindowExecution$
    ];
    var MaintenanceWindowExecutionTaskIdentityList = [
      1,
      n032,
      _MWETIL,
      0,
      () => exports2.MaintenanceWindowExecutionTaskIdentity$
    ];
    var MaintenanceWindowExecutionTaskIdList = 64 | 0;
    var MaintenanceWindowExecutionTaskInvocationIdentityList = [
      1,
      n032,
      _MWETIIL,
      0,
      [
        () => exports2.MaintenanceWindowExecutionTaskInvocationIdentity$,
        0
      ]
    ];
    var MaintenanceWindowFilterList = [
      1,
      n032,
      _MWFL,
      0,
      () => exports2.MaintenanceWindowFilter$
    ];
    var MaintenanceWindowFilterValues = 64 | 0;
    var MaintenanceWindowIdentityList = [
      1,
      n032,
      _MWIL,
      0,
      [
        () => exports2.MaintenanceWindowIdentity$,
        0
      ]
    ];
    var MaintenanceWindowsForTargetList = [
      1,
      n032,
      _MWFTL,
      0,
      () => exports2.MaintenanceWindowIdentityForTarget$
    ];
    var MaintenanceWindowTargetList = [
      1,
      n032,
      _MWTL,
      0,
      [
        () => exports2.MaintenanceWindowTarget$,
        0
      ]
    ];
    var MaintenanceWindowTaskList = [
      1,
      n032,
      _MWTLa,
      0,
      [
        () => exports2.MaintenanceWindowTask$,
        0
      ]
    ];
    var MaintenanceWindowTaskParametersList = [
      1,
      n032,
      _MWTPL,
      8,
      [
        () => MaintenanceWindowTaskParameters,
        0
      ]
    ];
    var MaintenanceWindowTaskParameterValueList = [
      1,
      n032,
      _MWTPVL,
      8,
      [
        () => MaintenanceWindowTaskParameterValue,
        0
      ]
    ];
    var MetadataKeysToDeleteList = 64 | 0;
    var NodeAggregatorList = [
      1,
      n032,
      _NAL,
      0,
      [
        () => exports2.NodeAggregator$,
        { [_xN]: _NA }
      ]
    ];
    var NodeFilterList = [
      1,
      n032,
      _NFL,
      0,
      [
        () => exports2.NodeFilter$,
        { [_xN]: _NF }
      ]
    ];
    var NodeFilterValueList = [
      1,
      n032,
      _NFVL,
      0,
      [
        0,
        { [_xN]: _FVi }
      ]
    ];
    var NodeList = [
      1,
      n032,
      _NL,
      0,
      [
        () => exports2.Node$,
        0
      ]
    ];
    var NodeSummaryList = [
      1,
      n032,
      _NSL,
      0,
      128 | 0
    ];
    var NotificationEventList = 64 | 0;
    var OpsAggregatorList = [
      1,
      n032,
      _OAL,
      0,
      [
        () => exports2.OpsAggregator$,
        { [_xN]: _Agg }
      ]
    ];
    var OpsEntityItemEntryList = [
      1,
      n032,
      _OEIEL,
      0,
      128 | 0
    ];
    var OpsEntityList = [
      1,
      n032,
      _OEL,
      0,
      [
        () => exports2.OpsEntity$,
        { [_xN]: _Entit }
      ]
    ];
    var OpsFilterList = [
      1,
      n032,
      _OFL,
      0,
      [
        () => exports2.OpsFilter$,
        { [_xN]: _OF }
      ]
    ];
    var OpsFilterValueList = [
      1,
      n032,
      _OFVL,
      0,
      [
        0,
        { [_xN]: _FVi }
      ]
    ];
    var OpsItemEventFilters = [
      1,
      n032,
      _OIEFp,
      0,
      () => exports2.OpsItemEventFilter$
    ];
    var OpsItemEventFilterValues = 64 | 0;
    var OpsItemEventSummaries = [
      1,
      n032,
      _OIESp,
      0,
      () => exports2.OpsItemEventSummary$
    ];
    var OpsItemFilters = [
      1,
      n032,
      _OIF,
      0,
      () => exports2.OpsItemFilter$
    ];
    var OpsItemFilterValues = 64 | 0;
    var OpsItemNotifications = [
      1,
      n032,
      _OINp,
      0,
      () => exports2.OpsItemNotification$
    ];
    var OpsItemOpsDataKeysList = 64 | 0;
    var OpsItemParameterNamesList = 64 | 0;
    var OpsItemRelatedItemsFilters = [
      1,
      n032,
      _OIRIFp,
      0,
      () => exports2.OpsItemRelatedItemsFilter$
    ];
    var OpsItemRelatedItemsFilterValues = 64 | 0;
    var OpsItemRelatedItemSummaries = [
      1,
      n032,
      _OIRISp,
      0,
      () => exports2.OpsItemRelatedItemSummary$
    ];
    var OpsItemSummaries = [
      1,
      n032,
      _OIS,
      0,
      () => exports2.OpsItemSummary$
    ];
    var OpsMetadataFilterList = [
      1,
      n032,
      _OMFL,
      0,
      () => exports2.OpsMetadataFilter$
    ];
    var OpsMetadataFilterValueList = 64 | 0;
    var OpsMetadataList = [
      1,
      n032,
      _OML,
      0,
      () => exports2.OpsMetadata$
    ];
    var OpsResultAttributeList = [
      1,
      n032,
      _ORAL,
      0,
      [
        () => exports2.OpsResultAttribute$,
        { [_xN]: _ORA }
      ]
    ];
    var ParameterHistoryList = [
      1,
      n032,
      _PHL,
      0,
      [
        () => exports2.ParameterHistory$,
        0
      ]
    ];
    var ParameterLabelList = 64 | 0;
    var ParameterList = [
      1,
      n032,
      _PL,
      0,
      [
        () => exports2.Parameter$,
        0
      ]
    ];
    var ParameterMetadataList = [
      1,
      n032,
      _PML,
      0,
      () => exports2.ParameterMetadata$
    ];
    var ParameterNameList = 64 | 0;
    var ParameterPolicyList = [
      1,
      n032,
      _PPLa,
      0,
      () => exports2.ParameterInlinePolicy$
    ];
    var ParametersFilterList = [
      1,
      n032,
      _PFL,
      0,
      () => exports2.ParametersFilter$
    ];
    var ParametersFilterValueList = 64 | 0;
    var ParameterStringFilterList = [
      1,
      n032,
      _PSFL,
      0,
      () => exports2.ParameterStringFilter$
    ];
    var ParameterStringFilterValueList = 64 | 0;
    var ParameterValueList = 64 | 0;
    var PatchAdvisoryIdList = 64 | 0;
    var PatchBaselineIdentityList = [
      1,
      n032,
      _PBIL,
      0,
      () => exports2.PatchBaselineIdentity$
    ];
    var PatchBugzillaIdList = 64 | 0;
    var PatchComplianceDataList = [
      1,
      n032,
      _PCDL,
      0,
      () => exports2.PatchComplianceData$
    ];
    var PatchCVEIdList = 64 | 0;
    var PatchFilterList = [
      1,
      n032,
      _PFLa,
      0,
      () => exports2.PatchFilter$
    ];
    var PatchFilterValueList = 64 | 0;
    var PatchGroupList = 64 | 0;
    var PatchGroupPatchBaselineMappingList = [
      1,
      n032,
      _PGPBML,
      0,
      () => exports2.PatchGroupPatchBaselineMapping$
    ];
    var PatchIdList = 64 | 0;
    var PatchList = [
      1,
      n032,
      _PLa,
      0,
      () => exports2.Patch$
    ];
    var PatchOrchestratorFilterList = [
      1,
      n032,
      _POFL,
      0,
      () => exports2.PatchOrchestratorFilter$
    ];
    var PatchOrchestratorFilterValues = 64 | 0;
    var PatchPropertiesList = [
      1,
      n032,
      _PPL,
      0,
      128 | 0
    ];
    var PatchRuleList = [
      1,
      n032,
      _PRL,
      0,
      () => exports2.PatchRule$
    ];
    var PatchSourceList = [
      1,
      n032,
      _PSL,
      0,
      [
        () => exports2.PatchSource$,
        0
      ]
    ];
    var PatchSourceProductList = 64 | 0;
    var PlatformTypeList = [
      1,
      n032,
      _PTL,
      0,
      [
        0,
        { [_xN]: _PTla }
      ]
    ];
    var RegionList = 64 | 0;
    var Regions = 64 | 0;
    var RegistrationMetadataList = [
      1,
      n032,
      _RML,
      0,
      () => exports2.RegistrationMetadataItem$
    ];
    var RelatedOpsItems = [
      1,
      n032,
      _ROI,
      0,
      () => exports2.RelatedOpsItem$
    ];
    var ResourceComplianceSummaryItemList = [
      1,
      n032,
      _RCSIL,
      0,
      [
        () => exports2.ResourceComplianceSummaryItem$,
        { [_xN]: _Item }
      ]
    ];
    var ResourceDataSyncItemList = [
      1,
      n032,
      _RDSIL,
      0,
      () => exports2.ResourceDataSyncItem$
    ];
    var ResourceDataSyncOrganizationalUnitList = [
      1,
      n032,
      _RDSOUL,
      0,
      () => exports2.ResourceDataSyncOrganizationalUnit$
    ];
    var ResourceDataSyncSourceRegionList = 64 | 0;
    var ResourcePolicyParameterNamesList = 64 | 0;
    var ResultAttributeList = [
      1,
      n032,
      _RAL,
      0,
      [
        () => exports2.ResultAttribute$,
        { [_xN]: _RAes }
      ]
    ];
    var ReviewInformationList = [
      1,
      n032,
      _RIL,
      0,
      [
        () => exports2.ReviewInformation$,
        { [_xN]: _RIe }
      ]
    ];
    var Runbooks = [
      1,
      n032,
      _R,
      0,
      () => exports2.Runbook$
    ];
    var ScheduledWindowExecutionList = [
      1,
      n032,
      _SWEL,
      0,
      () => exports2.ScheduledWindowExecution$
    ];
    var SessionFilterList = [
      1,
      n032,
      _SFL,
      0,
      () => exports2.SessionFilter$
    ];
    var SessionList = [
      1,
      n032,
      _SLe,
      0,
      () => exports2.Session$
    ];
    var SessionManagerParameterValueList = 64 | 0;
    var StepExecutionFilterList = [
      1,
      n032,
      _SEFL,
      0,
      () => exports2.StepExecutionFilter$
    ];
    var StepExecutionFilterValueList = 64 | 0;
    var StepExecutionList = [
      1,
      n032,
      _SEL,
      0,
      () => exports2.StepExecution$
    ];
    var StringList = 64 | 0;
    var TagList = [
      1,
      n032,
      _TLa,
      0,
      () => exports2.Tag$
    ];
    var TargetLocations = [
      1,
      n032,
      _TL,
      0,
      () => exports2.TargetLocation$
    ];
    var TargetMaps = [
      1,
      n032,
      _TM,
      0,
      [2, n032, _TMa, 0, 0, 64 | 0]
    ];
    var TargetMapValueList = 64 | 0;
    var TargetParameterList = 64 | 0;
    var TargetPreviewList = [
      1,
      n032,
      _TPL,
      0,
      () => exports2.TargetPreview$
    ];
    var Targets2 = [
      1,
      n032,
      _Ta10,
      0,
      () => exports2.Target$
    ];
    var TargetValues = 64 | 0;
    var ValidNextStepList = 64 | 0;
    var AssociationStatusAggregatedCount = 128 | 1;
    var AutomationParameterMap = [
      2,
      n032,
      _APM,
      0,
      0,
      64 | 0
    ];
    var ComplianceItemDetails = 128 | 0;
    var InstanceAssociationStatusAggregatedCount = 128 | 1;
    var InventoryItemContentContext = 128 | 0;
    var InventoryItemEntry = 128 | 0;
    var InventoryResultItemMap = [
      2,
      n032,
      _IRIM,
      0,
      0,
      () => exports2.InventoryResultItem$
    ];
    var MaintenanceWindowTaskParameters = [
      2,
      n032,
      _MWTP,
      8,
      [
        0,
        0
      ],
      [
        () => exports2.MaintenanceWindowTaskParameterValueExpression$,
        0
      ]
    ];
    var MetadataMap = [
      2,
      n032,
      _MM,
      0,
      0,
      () => exports2.MetadataValue$
    ];
    var NodeSummary = 128 | 0;
    var NormalStringMap = 128 | 0;
    var OpsAggregatorValueMap = 128 | 0;
    var OpsEntityItemEntry = 128 | 0;
    var OpsEntityItemMap = [
      2,
      n032,
      _OEIM,
      0,
      0,
      () => exports2.OpsEntityItem$
    ];
    var OpsItemOperationalData = [
      2,
      n032,
      _OIOD,
      0,
      0,
      () => exports2.OpsItemDataValue$
    ];
    var _Parameters = [
      2,
      n032,
      _P10,
      8,
      0,
      64 | 0
    ];
    var PatchPropertyEntry = 128 | 0;
    var SessionManagerParameters = [
      2,
      n032,
      _SMP,
      0,
      0,
      64 | 0
    ];
    var StepPreviewMap = 128 | 1;
    var TargetMap = [
      2,
      n032,
      _TMa,
      0,
      0,
      64 | 0
    ];
    exports2.ExecutionInputs$ = [
      4,
      n032,
      _EIx,
      0,
      [_Aut],
      [() => exports2.AutomationExecutionInputs$]
    ];
    exports2.ExecutionPreview$ = [
      4,
      n032,
      _EPx,
      0,
      [_Aut],
      [() => exports2.AutomationExecutionPreview$]
    ];
    exports2.NodeType$ = [
      4,
      n032,
      _NTo,
      0,
      [_Ins],
      [[() => exports2.InstanceInfo$, 0]]
    ];
    exports2.AddTagsToResource$ = [
      9,
      n032,
      _ATTR,
      0,
      () => exports2.AddTagsToResourceRequest$,
      () => exports2.AddTagsToResourceResult$
    ];
    exports2.AssociateOpsItemRelatedItem$ = [
      9,
      n032,
      _AOIRI,
      0,
      () => exports2.AssociateOpsItemRelatedItemRequest$,
      () => exports2.AssociateOpsItemRelatedItemResponse$
    ];
    exports2.CancelCommand$ = [
      9,
      n032,
      _CCa,
      0,
      () => exports2.CancelCommandRequest$,
      () => exports2.CancelCommandResult$
    ];
    exports2.CancelMaintenanceWindowExecution$ = [
      9,
      n032,
      _CMWE,
      0,
      () => exports2.CancelMaintenanceWindowExecutionRequest$,
      () => exports2.CancelMaintenanceWindowExecutionResult$
    ];
    exports2.CreateActivation$ = [
      9,
      n032,
      _CAr,
      0,
      () => exports2.CreateActivationRequest$,
      () => exports2.CreateActivationResult$
    ];
    exports2.CreateAssociation$ = [
      9,
      n032,
      _CAre,
      0,
      () => exports2.CreateAssociationRequest$,
      () => exports2.CreateAssociationResult$
    ];
    exports2.CreateAssociationBatch$ = [
      9,
      n032,
      _CAB,
      0,
      () => exports2.CreateAssociationBatchRequest$,
      () => exports2.CreateAssociationBatchResult$
    ];
    exports2.CreateDocument$ = [
      9,
      n032,
      _CDre,
      0,
      () => exports2.CreateDocumentRequest$,
      () => exports2.CreateDocumentResult$
    ];
    exports2.CreateMaintenanceWindow$ = [
      9,
      n032,
      _CMW,
      0,
      () => exports2.CreateMaintenanceWindowRequest$,
      () => exports2.CreateMaintenanceWindowResult$
    ];
    exports2.CreateOpsItem$ = [
      9,
      n032,
      _COI,
      0,
      () => exports2.CreateOpsItemRequest$,
      () => exports2.CreateOpsItemResponse$
    ];
    exports2.CreateOpsMetadata$ = [
      9,
      n032,
      _COM,
      0,
      () => exports2.CreateOpsMetadataRequest$,
      () => exports2.CreateOpsMetadataResult$
    ];
    exports2.CreatePatchBaseline$ = [
      9,
      n032,
      _CPB,
      0,
      () => exports2.CreatePatchBaselineRequest$,
      () => exports2.CreatePatchBaselineResult$
    ];
    exports2.CreateResourceDataSync$ = [
      9,
      n032,
      _CRDS,
      0,
      () => exports2.CreateResourceDataSyncRequest$,
      () => exports2.CreateResourceDataSyncResult$
    ];
    exports2.DeleteActivation$ = [
      9,
      n032,
      _DA,
      0,
      () => exports2.DeleteActivationRequest$,
      () => exports2.DeleteActivationResult$
    ];
    exports2.DeleteAssociation$ = [
      9,
      n032,
      _DAe,
      0,
      () => exports2.DeleteAssociationRequest$,
      () => exports2.DeleteAssociationResult$
    ];
    exports2.DeleteDocument$ = [
      9,
      n032,
      _DDe,
      0,
      () => exports2.DeleteDocumentRequest$,
      () => exports2.DeleteDocumentResult$
    ];
    exports2.DeleteInventory$ = [
      9,
      n032,
      _DIe,
      0,
      () => exports2.DeleteInventoryRequest$,
      () => exports2.DeleteInventoryResult$
    ];
    exports2.DeleteMaintenanceWindow$ = [
      9,
      n032,
      _DMW,
      0,
      () => exports2.DeleteMaintenanceWindowRequest$,
      () => exports2.DeleteMaintenanceWindowResult$
    ];
    exports2.DeleteOpsItem$ = [
      9,
      n032,
      _DOI,
      0,
      () => exports2.DeleteOpsItemRequest$,
      () => exports2.DeleteOpsItemResponse$
    ];
    exports2.DeleteOpsMetadata$ = [
      9,
      n032,
      _DOM,
      0,
      () => exports2.DeleteOpsMetadataRequest$,
      () => exports2.DeleteOpsMetadataResult$
    ];
    exports2.DeleteParameter$ = [
      9,
      n032,
      _DPe,
      0,
      () => exports2.DeleteParameterRequest$,
      () => exports2.DeleteParameterResult$
    ];
    exports2.DeleteParameters$ = [
      9,
      n032,
      _DPel,
      0,
      () => exports2.DeleteParametersRequest$,
      () => exports2.DeleteParametersResult$
    ];
    exports2.DeletePatchBaseline$ = [
      9,
      n032,
      _DPB,
      0,
      () => exports2.DeletePatchBaselineRequest$,
      () => exports2.DeletePatchBaselineResult$
    ];
    exports2.DeleteResourceDataSync$ = [
      9,
      n032,
      _DRDS,
      0,
      () => exports2.DeleteResourceDataSyncRequest$,
      () => exports2.DeleteResourceDataSyncResult$
    ];
    exports2.DeleteResourcePolicy$ = [
      9,
      n032,
      _DRP,
      0,
      () => exports2.DeleteResourcePolicyRequest$,
      () => exports2.DeleteResourcePolicyResponse$
    ];
    exports2.DeregisterManagedInstance$ = [
      9,
      n032,
      _DMI,
      0,
      () => exports2.DeregisterManagedInstanceRequest$,
      () => exports2.DeregisterManagedInstanceResult$
    ];
    exports2.DeregisterPatchBaselineForPatchGroup$ = [
      9,
      n032,
      _DPBFPG,
      0,
      () => exports2.DeregisterPatchBaselineForPatchGroupRequest$,
      () => exports2.DeregisterPatchBaselineForPatchGroupResult$
    ];
    exports2.DeregisterTargetFromMaintenanceWindow$ = [
      9,
      n032,
      _DTFMW,
      0,
      () => exports2.DeregisterTargetFromMaintenanceWindowRequest$,
      () => exports2.DeregisterTargetFromMaintenanceWindowResult$
    ];
    exports2.DeregisterTaskFromMaintenanceWindow$ = [
      9,
      n032,
      _DTFMWe,
      0,
      () => exports2.DeregisterTaskFromMaintenanceWindowRequest$,
      () => exports2.DeregisterTaskFromMaintenanceWindowResult$
    ];
    exports2.DescribeActivations$ = [
      9,
      n032,
      _DAes,
      0,
      () => exports2.DescribeActivationsRequest$,
      () => exports2.DescribeActivationsResult$
    ];
    exports2.DescribeAssociation$ = [
      9,
      n032,
      _DAesc,
      0,
      () => exports2.DescribeAssociationRequest$,
      () => exports2.DescribeAssociationResult$
    ];
    exports2.DescribeAssociationExecutions$ = [
      9,
      n032,
      _DAEe,
      0,
      () => exports2.DescribeAssociationExecutionsRequest$,
      () => exports2.DescribeAssociationExecutionsResult$
    ];
    exports2.DescribeAssociationExecutionTargets$ = [
      9,
      n032,
      _DAET,
      0,
      () => exports2.DescribeAssociationExecutionTargetsRequest$,
      () => exports2.DescribeAssociationExecutionTargetsResult$
    ];
    exports2.DescribeAutomationExecutions$ = [
      9,
      n032,
      _DAEes,
      0,
      () => exports2.DescribeAutomationExecutionsRequest$,
      () => exports2.DescribeAutomationExecutionsResult$
    ];
    exports2.DescribeAutomationStepExecutions$ = [
      9,
      n032,
      _DASE,
      0,
      () => exports2.DescribeAutomationStepExecutionsRequest$,
      () => exports2.DescribeAutomationStepExecutionsResult$
    ];
    exports2.DescribeAvailablePatches$ = [
      9,
      n032,
      _DAP,
      0,
      () => exports2.DescribeAvailablePatchesRequest$,
      () => exports2.DescribeAvailablePatchesResult$
    ];
    exports2.DescribeDocument$ = [
      9,
      n032,
      _DDes,
      0,
      () => exports2.DescribeDocumentRequest$,
      () => exports2.DescribeDocumentResult$
    ];
    exports2.DescribeDocumentPermission$ = [
      9,
      n032,
      _DDP,
      0,
      () => exports2.DescribeDocumentPermissionRequest$,
      () => exports2.DescribeDocumentPermissionResponse$
    ];
    exports2.DescribeEffectiveInstanceAssociations$ = [
      9,
      n032,
      _DEIA,
      0,
      () => exports2.DescribeEffectiveInstanceAssociationsRequest$,
      () => exports2.DescribeEffectiveInstanceAssociationsResult$
    ];
    exports2.DescribeEffectivePatchesForPatchBaseline$ = [
      9,
      n032,
      _DEPFPB,
      0,
      () => exports2.DescribeEffectivePatchesForPatchBaselineRequest$,
      () => exports2.DescribeEffectivePatchesForPatchBaselineResult$
    ];
    exports2.DescribeInstanceAssociationsStatus$ = [
      9,
      n032,
      _DIAS,
      0,
      () => exports2.DescribeInstanceAssociationsStatusRequest$,
      () => exports2.DescribeInstanceAssociationsStatusResult$
    ];
    exports2.DescribeInstanceInformation$ = [
      9,
      n032,
      _DIIe,
      0,
      () => exports2.DescribeInstanceInformationRequest$,
      () => exports2.DescribeInstanceInformationResult$
    ];
    exports2.DescribeInstancePatches$ = [
      9,
      n032,
      _DIP,
      0,
      () => exports2.DescribeInstancePatchesRequest$,
      () => exports2.DescribeInstancePatchesResult$
    ];
    exports2.DescribeInstancePatchStates$ = [
      9,
      n032,
      _DIPS,
      0,
      () => exports2.DescribeInstancePatchStatesRequest$,
      () => exports2.DescribeInstancePatchStatesResult$
    ];
    exports2.DescribeInstancePatchStatesForPatchGroup$ = [
      9,
      n032,
      _DIPSFPG,
      0,
      () => exports2.DescribeInstancePatchStatesForPatchGroupRequest$,
      () => exports2.DescribeInstancePatchStatesForPatchGroupResult$
    ];
    exports2.DescribeInstanceProperties$ = [
      9,
      n032,
      _DIPe,
      0,
      () => exports2.DescribeInstancePropertiesRequest$,
      () => exports2.DescribeInstancePropertiesResult$
    ];
    exports2.DescribeInventoryDeletions$ = [
      9,
      n032,
      _DID,
      0,
      () => exports2.DescribeInventoryDeletionsRequest$,
      () => exports2.DescribeInventoryDeletionsResult$
    ];
    exports2.DescribeMaintenanceWindowExecutions$ = [
      9,
      n032,
      _DMWE,
      0,
      () => exports2.DescribeMaintenanceWindowExecutionsRequest$,
      () => exports2.DescribeMaintenanceWindowExecutionsResult$
    ];
    exports2.DescribeMaintenanceWindowExecutionTaskInvocations$ = [
      9,
      n032,
      _DMWETI,
      0,
      () => exports2.DescribeMaintenanceWindowExecutionTaskInvocationsRequest$,
      () => exports2.DescribeMaintenanceWindowExecutionTaskInvocationsResult$
    ];
    exports2.DescribeMaintenanceWindowExecutionTasks$ = [
      9,
      n032,
      _DMWET,
      0,
      () => exports2.DescribeMaintenanceWindowExecutionTasksRequest$,
      () => exports2.DescribeMaintenanceWindowExecutionTasksResult$
    ];
    exports2.DescribeMaintenanceWindows$ = [
      9,
      n032,
      _DMWe,
      0,
      () => exports2.DescribeMaintenanceWindowsRequest$,
      () => exports2.DescribeMaintenanceWindowsResult$
    ];
    exports2.DescribeMaintenanceWindowSchedule$ = [
      9,
      n032,
      _DMWS,
      0,
      () => exports2.DescribeMaintenanceWindowScheduleRequest$,
      () => exports2.DescribeMaintenanceWindowScheduleResult$
    ];
    exports2.DescribeMaintenanceWindowsForTarget$ = [
      9,
      n032,
      _DMWFT,
      0,
      () => exports2.DescribeMaintenanceWindowsForTargetRequest$,
      () => exports2.DescribeMaintenanceWindowsForTargetResult$
    ];
    exports2.DescribeMaintenanceWindowTargets$ = [
      9,
      n032,
      _DMWT,
      0,
      () => exports2.DescribeMaintenanceWindowTargetsRequest$,
      () => exports2.DescribeMaintenanceWindowTargetsResult$
    ];
    exports2.DescribeMaintenanceWindowTasks$ = [
      9,
      n032,
      _DMWTe,
      0,
      () => exports2.DescribeMaintenanceWindowTasksRequest$,
      () => exports2.DescribeMaintenanceWindowTasksResult$
    ];
    exports2.DescribeOpsItems$ = [
      9,
      n032,
      _DOIe,
      0,
      () => exports2.DescribeOpsItemsRequest$,
      () => exports2.DescribeOpsItemsResponse$
    ];
    exports2.DescribeParameters$ = [
      9,
      n032,
      _DPes,
      0,
      () => exports2.DescribeParametersRequest$,
      () => exports2.DescribeParametersResult$
    ];
    exports2.DescribePatchBaselines$ = [
      9,
      n032,
      _DPBe,
      0,
      () => exports2.DescribePatchBaselinesRequest$,
      () => exports2.DescribePatchBaselinesResult$
    ];
    exports2.DescribePatchGroups$ = [
      9,
      n032,
      _DPG,
      0,
      () => exports2.DescribePatchGroupsRequest$,
      () => exports2.DescribePatchGroupsResult$
    ];
    exports2.DescribePatchGroupState$ = [
      9,
      n032,
      _DPGS,
      0,
      () => exports2.DescribePatchGroupStateRequest$,
      () => exports2.DescribePatchGroupStateResult$
    ];
    exports2.DescribePatchProperties$ = [
      9,
      n032,
      _DPP,
      0,
      () => exports2.DescribePatchPropertiesRequest$,
      () => exports2.DescribePatchPropertiesResult$
    ];
    exports2.DescribeSessions$ = [
      9,
      n032,
      _DSes,
      0,
      () => exports2.DescribeSessionsRequest$,
      () => exports2.DescribeSessionsResponse$
    ];
    exports2.DisassociateOpsItemRelatedItem$ = [
      9,
      n032,
      _DOIRI,
      0,
      () => exports2.DisassociateOpsItemRelatedItemRequest$,
      () => exports2.DisassociateOpsItemRelatedItemResponse$
    ];
    exports2.GetAccessToken$ = [
      9,
      n032,
      _GAT,
      0,
      () => exports2.GetAccessTokenRequest$,
      () => exports2.GetAccessTokenResponse$
    ];
    exports2.GetAutomationExecution$ = [
      9,
      n032,
      _GAE,
      0,
      () => exports2.GetAutomationExecutionRequest$,
      () => exports2.GetAutomationExecutionResult$
    ];
    exports2.GetCalendarState$ = [
      9,
      n032,
      _GCS,
      0,
      () => exports2.GetCalendarStateRequest$,
      () => exports2.GetCalendarStateResponse$
    ];
    exports2.GetCommandInvocation$ = [
      9,
      n032,
      _GCI,
      0,
      () => exports2.GetCommandInvocationRequest$,
      () => exports2.GetCommandInvocationResult$
    ];
    exports2.GetConnectionStatus$ = [
      9,
      n032,
      _GCSe,
      0,
      () => exports2.GetConnectionStatusRequest$,
      () => exports2.GetConnectionStatusResponse$
    ];
    exports2.GetDefaultPatchBaseline$ = [
      9,
      n032,
      _GDPB,
      0,
      () => exports2.GetDefaultPatchBaselineRequest$,
      () => exports2.GetDefaultPatchBaselineResult$
    ];
    exports2.GetDeployablePatchSnapshotForInstance$ = [
      9,
      n032,
      _GDPSFI,
      0,
      () => exports2.GetDeployablePatchSnapshotForInstanceRequest$,
      () => exports2.GetDeployablePatchSnapshotForInstanceResult$
    ];
    exports2.GetDocument$ = [
      9,
      n032,
      _GD,
      0,
      () => exports2.GetDocumentRequest$,
      () => exports2.GetDocumentResult$
    ];
    exports2.GetExecutionPreview$ = [
      9,
      n032,
      _GEP,
      0,
      () => exports2.GetExecutionPreviewRequest$,
      () => exports2.GetExecutionPreviewResponse$
    ];
    exports2.GetInventory$ = [
      9,
      n032,
      _GI2,
      0,
      () => exports2.GetInventoryRequest$,
      () => exports2.GetInventoryResult$
    ];
    exports2.GetInventorySchema$ = [
      9,
      n032,
      _GIS,
      0,
      () => exports2.GetInventorySchemaRequest$,
      () => exports2.GetInventorySchemaResult$
    ];
    exports2.GetMaintenanceWindow$ = [
      9,
      n032,
      _GMW,
      0,
      () => exports2.GetMaintenanceWindowRequest$,
      () => exports2.GetMaintenanceWindowResult$
    ];
    exports2.GetMaintenanceWindowExecution$ = [
      9,
      n032,
      _GMWE,
      0,
      () => exports2.GetMaintenanceWindowExecutionRequest$,
      () => exports2.GetMaintenanceWindowExecutionResult$
    ];
    exports2.GetMaintenanceWindowExecutionTask$ = [
      9,
      n032,
      _GMWET,
      0,
      () => exports2.GetMaintenanceWindowExecutionTaskRequest$,
      () => exports2.GetMaintenanceWindowExecutionTaskResult$
    ];
    exports2.GetMaintenanceWindowExecutionTaskInvocation$ = [
      9,
      n032,
      _GMWETI,
      0,
      () => exports2.GetMaintenanceWindowExecutionTaskInvocationRequest$,
      () => exports2.GetMaintenanceWindowExecutionTaskInvocationResult$
    ];
    exports2.GetMaintenanceWindowTask$ = [
      9,
      n032,
      _GMWT,
      0,
      () => exports2.GetMaintenanceWindowTaskRequest$,
      () => exports2.GetMaintenanceWindowTaskResult$
    ];
    exports2.GetOpsItem$ = [
      9,
      n032,
      _GOI,
      0,
      () => exports2.GetOpsItemRequest$,
      () => exports2.GetOpsItemResponse$
    ];
    exports2.GetOpsMetadata$ = [
      9,
      n032,
      _GOM,
      0,
      () => exports2.GetOpsMetadataRequest$,
      () => exports2.GetOpsMetadataResult$
    ];
    exports2.GetOpsSummary$ = [
      9,
      n032,
      _GOS,
      0,
      () => exports2.GetOpsSummaryRequest$,
      () => exports2.GetOpsSummaryResult$
    ];
    exports2.GetParameter$ = [
      9,
      n032,
      _GP,
      0,
      () => exports2.GetParameterRequest$,
      () => exports2.GetParameterResult$
    ];
    exports2.GetParameterHistory$ = [
      9,
      n032,
      _GPH,
      0,
      () => exports2.GetParameterHistoryRequest$,
      () => exports2.GetParameterHistoryResult$
    ];
    exports2.GetParameters$ = [
      9,
      n032,
      _GPe,
      0,
      () => exports2.GetParametersRequest$,
      () => exports2.GetParametersResult$
    ];
    exports2.GetParametersByPath$ = [
      9,
      n032,
      _GPBP,
      0,
      () => exports2.GetParametersByPathRequest$,
      () => exports2.GetParametersByPathResult$
    ];
    exports2.GetPatchBaseline$ = [
      9,
      n032,
      _GPB,
      0,
      () => exports2.GetPatchBaselineRequest$,
      () => exports2.GetPatchBaselineResult$
    ];
    exports2.GetPatchBaselineForPatchGroup$ = [
      9,
      n032,
      _GPBFPG,
      0,
      () => exports2.GetPatchBaselineForPatchGroupRequest$,
      () => exports2.GetPatchBaselineForPatchGroupResult$
    ];
    exports2.GetResourcePolicies$ = [
      9,
      n032,
      _GRP,
      0,
      () => exports2.GetResourcePoliciesRequest$,
      () => exports2.GetResourcePoliciesResponse$
    ];
    exports2.GetServiceSetting$ = [
      9,
      n032,
      _GSS,
      0,
      () => exports2.GetServiceSettingRequest$,
      () => exports2.GetServiceSettingResult$
    ];
    exports2.LabelParameterVersion$ = [
      9,
      n032,
      _LPV,
      0,
      () => exports2.LabelParameterVersionRequest$,
      () => exports2.LabelParameterVersionResult$
    ];
    exports2.ListAssociations$ = [
      9,
      n032,
      _LA,
      0,
      () => exports2.ListAssociationsRequest$,
      () => exports2.ListAssociationsResult$
    ];
    exports2.ListAssociationVersions$ = [
      9,
      n032,
      _LAV,
      0,
      () => exports2.ListAssociationVersionsRequest$,
      () => exports2.ListAssociationVersionsResult$
    ];
    exports2.ListCommandInvocations$ = [
      9,
      n032,
      _LCI,
      0,
      () => exports2.ListCommandInvocationsRequest$,
      () => exports2.ListCommandInvocationsResult$
    ];
    exports2.ListCommands$ = [
      9,
      n032,
      _LCi,
      0,
      () => exports2.ListCommandsRequest$,
      () => exports2.ListCommandsResult$
    ];
    exports2.ListComplianceItems$ = [
      9,
      n032,
      _LCIi,
      0,
      () => exports2.ListComplianceItemsRequest$,
      () => exports2.ListComplianceItemsResult$
    ];
    exports2.ListComplianceSummaries$ = [
      9,
      n032,
      _LCS,
      0,
      () => exports2.ListComplianceSummariesRequest$,
      () => exports2.ListComplianceSummariesResult$
    ];
    exports2.ListDocumentMetadataHistory$ = [
      9,
      n032,
      _LDMH,
      0,
      () => exports2.ListDocumentMetadataHistoryRequest$,
      () => exports2.ListDocumentMetadataHistoryResponse$
    ];
    exports2.ListDocuments$ = [
      9,
      n032,
      _LD,
      0,
      () => exports2.ListDocumentsRequest$,
      () => exports2.ListDocumentsResult$
    ];
    exports2.ListDocumentVersions$ = [
      9,
      n032,
      _LDV,
      0,
      () => exports2.ListDocumentVersionsRequest$,
      () => exports2.ListDocumentVersionsResult$
    ];
    exports2.ListInventoryEntries$ = [
      9,
      n032,
      _LIE,
      0,
      () => exports2.ListInventoryEntriesRequest$,
      () => exports2.ListInventoryEntriesResult$
    ];
    exports2.ListNodes$ = [
      9,
      n032,
      _LN,
      0,
      () => exports2.ListNodesRequest$,
      () => exports2.ListNodesResult$
    ];
    exports2.ListNodesSummary$ = [
      9,
      n032,
      _LNS,
      0,
      () => exports2.ListNodesSummaryRequest$,
      () => exports2.ListNodesSummaryResult$
    ];
    exports2.ListOpsItemEvents$ = [
      9,
      n032,
      _LOIE,
      0,
      () => exports2.ListOpsItemEventsRequest$,
      () => exports2.ListOpsItemEventsResponse$
    ];
    exports2.ListOpsItemRelatedItems$ = [
      9,
      n032,
      _LOIRI,
      0,
      () => exports2.ListOpsItemRelatedItemsRequest$,
      () => exports2.ListOpsItemRelatedItemsResponse$
    ];
    exports2.ListOpsMetadata$ = [
      9,
      n032,
      _LOM,
      0,
      () => exports2.ListOpsMetadataRequest$,
      () => exports2.ListOpsMetadataResult$
    ];
    exports2.ListResourceComplianceSummaries$ = [
      9,
      n032,
      _LRCS,
      0,
      () => exports2.ListResourceComplianceSummariesRequest$,
      () => exports2.ListResourceComplianceSummariesResult$
    ];
    exports2.ListResourceDataSync$ = [
      9,
      n032,
      _LRDS,
      0,
      () => exports2.ListResourceDataSyncRequest$,
      () => exports2.ListResourceDataSyncResult$
    ];
    exports2.ListTagsForResource$ = [
      9,
      n032,
      _LTFR,
      0,
      () => exports2.ListTagsForResourceRequest$,
      () => exports2.ListTagsForResourceResult$
    ];
    exports2.ModifyDocumentPermission$ = [
      9,
      n032,
      _MDP,
      0,
      () => exports2.ModifyDocumentPermissionRequest$,
      () => exports2.ModifyDocumentPermissionResponse$
    ];
    exports2.PutComplianceItems$ = [
      9,
      n032,
      _PCI,
      0,
      () => exports2.PutComplianceItemsRequest$,
      () => exports2.PutComplianceItemsResult$
    ];
    exports2.PutInventory$ = [
      9,
      n032,
      _PIu,
      0,
      () => exports2.PutInventoryRequest$,
      () => exports2.PutInventoryResult$
    ];
    exports2.PutParameter$ = [
      9,
      n032,
      _PP,
      0,
      () => exports2.PutParameterRequest$,
      () => exports2.PutParameterResult$
    ];
    exports2.PutResourcePolicy$ = [
      9,
      n032,
      _PRP,
      0,
      () => exports2.PutResourcePolicyRequest$,
      () => exports2.PutResourcePolicyResponse$
    ];
    exports2.RegisterDefaultPatchBaseline$ = [
      9,
      n032,
      _RDPB,
      0,
      () => exports2.RegisterDefaultPatchBaselineRequest$,
      () => exports2.RegisterDefaultPatchBaselineResult$
    ];
    exports2.RegisterPatchBaselineForPatchGroup$ = [
      9,
      n032,
      _RPBFPG,
      0,
      () => exports2.RegisterPatchBaselineForPatchGroupRequest$,
      () => exports2.RegisterPatchBaselineForPatchGroupResult$
    ];
    exports2.RegisterTargetWithMaintenanceWindow$ = [
      9,
      n032,
      _RTWMW,
      0,
      () => exports2.RegisterTargetWithMaintenanceWindowRequest$,
      () => exports2.RegisterTargetWithMaintenanceWindowResult$
    ];
    exports2.RegisterTaskWithMaintenanceWindow$ = [
      9,
      n032,
      _RTWMWe,
      0,
      () => exports2.RegisterTaskWithMaintenanceWindowRequest$,
      () => exports2.RegisterTaskWithMaintenanceWindowResult$
    ];
    exports2.RemoveTagsFromResource$ = [
      9,
      n032,
      _RTFR,
      0,
      () => exports2.RemoveTagsFromResourceRequest$,
      () => exports2.RemoveTagsFromResourceResult$
    ];
    exports2.ResetServiceSetting$ = [
      9,
      n032,
      _RSS,
      0,
      () => exports2.ResetServiceSettingRequest$,
      () => exports2.ResetServiceSettingResult$
    ];
    exports2.ResumeSession$ = [
      9,
      n032,
      _RSe,
      0,
      () => exports2.ResumeSessionRequest$,
      () => exports2.ResumeSessionResponse$
    ];
    exports2.SendAutomationSignal$ = [
      9,
      n032,
      _SAS,
      0,
      () => exports2.SendAutomationSignalRequest$,
      () => exports2.SendAutomationSignalResult$
    ];
    exports2.SendCommand$ = [
      9,
      n032,
      _SCe,
      0,
      () => exports2.SendCommandRequest$,
      () => exports2.SendCommandResult$
    ];
    exports2.StartAccessRequest$ = [
      9,
      n032,
      _SAR,
      0,
      () => exports2.StartAccessRequestRequest$,
      () => exports2.StartAccessRequestResponse$
    ];
    exports2.StartAssociationsOnce$ = [
      9,
      n032,
      _SAO,
      0,
      () => exports2.StartAssociationsOnceRequest$,
      () => exports2.StartAssociationsOnceResult$
    ];
    exports2.StartAutomationExecution$ = [
      9,
      n032,
      _SAE,
      0,
      () => exports2.StartAutomationExecutionRequest$,
      () => exports2.StartAutomationExecutionResult$
    ];
    exports2.StartChangeRequestExecution$ = [
      9,
      n032,
      _SCRE,
      0,
      () => exports2.StartChangeRequestExecutionRequest$,
      () => exports2.StartChangeRequestExecutionResult$
    ];
    exports2.StartExecutionPreview$ = [
      9,
      n032,
      _SEP,
      0,
      () => exports2.StartExecutionPreviewRequest$,
      () => exports2.StartExecutionPreviewResponse$
    ];
    exports2.StartSession$ = [
      9,
      n032,
      _SSta,
      0,
      () => exports2.StartSessionRequest$,
      () => exports2.StartSessionResponse$
    ];
    exports2.StopAutomationExecution$ = [
      9,
      n032,
      _SAEt,
      0,
      () => exports2.StopAutomationExecutionRequest$,
      () => exports2.StopAutomationExecutionResult$
    ];
    exports2.TerminateSession$ = [
      9,
      n032,
      _TSe,
      0,
      () => exports2.TerminateSessionRequest$,
      () => exports2.TerminateSessionResponse$
    ];
    exports2.UnlabelParameterVersion$ = [
      9,
      n032,
      _UPV,
      0,
      () => exports2.UnlabelParameterVersionRequest$,
      () => exports2.UnlabelParameterVersionResult$
    ];
    exports2.UpdateAssociation$ = [
      9,
      n032,
      _UA,
      0,
      () => exports2.UpdateAssociationRequest$,
      () => exports2.UpdateAssociationResult$
    ];
    exports2.UpdateAssociationStatus$ = [
      9,
      n032,
      _UAS,
      0,
      () => exports2.UpdateAssociationStatusRequest$,
      () => exports2.UpdateAssociationStatusResult$
    ];
    exports2.UpdateDocument$ = [
      9,
      n032,
      _UD,
      0,
      () => exports2.UpdateDocumentRequest$,
      () => exports2.UpdateDocumentResult$
    ];
    exports2.UpdateDocumentDefaultVersion$ = [
      9,
      n032,
      _UDDV,
      0,
      () => exports2.UpdateDocumentDefaultVersionRequest$,
      () => exports2.UpdateDocumentDefaultVersionResult$
    ];
    exports2.UpdateDocumentMetadata$ = [
      9,
      n032,
      _UDM,
      0,
      () => exports2.UpdateDocumentMetadataRequest$,
      () => exports2.UpdateDocumentMetadataResponse$
    ];
    exports2.UpdateMaintenanceWindow$ = [
      9,
      n032,
      _UMW,
      0,
      () => exports2.UpdateMaintenanceWindowRequest$,
      () => exports2.UpdateMaintenanceWindowResult$
    ];
    exports2.UpdateMaintenanceWindowTarget$ = [
      9,
      n032,
      _UMWT,
      0,
      () => exports2.UpdateMaintenanceWindowTargetRequest$,
      () => exports2.UpdateMaintenanceWindowTargetResult$
    ];
    exports2.UpdateMaintenanceWindowTask$ = [
      9,
      n032,
      _UMWTp,
      0,
      () => exports2.UpdateMaintenanceWindowTaskRequest$,
      () => exports2.UpdateMaintenanceWindowTaskResult$
    ];
    exports2.UpdateManagedInstanceRole$ = [
      9,
      n032,
      _UMIR,
      0,
      () => exports2.UpdateManagedInstanceRoleRequest$,
      () => exports2.UpdateManagedInstanceRoleResult$
    ];
    exports2.UpdateOpsItem$ = [
      9,
      n032,
      _UOI,
      0,
      () => exports2.UpdateOpsItemRequest$,
      () => exports2.UpdateOpsItemResponse$
    ];
    exports2.UpdateOpsMetadata$ = [
      9,
      n032,
      _UOM,
      0,
      () => exports2.UpdateOpsMetadataRequest$,
      () => exports2.UpdateOpsMetadataResult$
    ];
    exports2.UpdatePatchBaseline$ = [
      9,
      n032,
      _UPB,
      0,
      () => exports2.UpdatePatchBaselineRequest$,
      () => exports2.UpdatePatchBaselineResult$
    ];
    exports2.UpdateResourceDataSync$ = [
      9,
      n032,
      _URDS,
      0,
      () => exports2.UpdateResourceDataSyncRequest$,
      () => exports2.UpdateResourceDataSyncResult$
    ];
    exports2.UpdateServiceSetting$ = [
      9,
      n032,
      _USS,
      0,
      () => exports2.UpdateServiceSettingRequest$,
      () => exports2.UpdateServiceSettingResult$
    ];
  }
});

// ../../node_modules/@aws-sdk/client-ssm/dist-cjs/runtimeConfig.shared.js
var require_runtimeConfig_shared20 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/dist-cjs/runtimeConfig.shared.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var httpAuthSchemes_1 = (init_httpAuthSchemes12(), __toCommonJS(httpAuthSchemes_exports10));
    var protocols_1 = (init_protocols18(), __toCommonJS(protocols_exports15));
    var smithy_client_1 = require_dist_cjs34();
    var url_parser_1 = require_dist_cjs18();
    var util_base64_1 = require_dist_cjs10();
    var util_utf8_1 = require_dist_cjs9();
    var httpAuthSchemeProvider_1 = require_httpAuthSchemeProvider19();
    var endpointResolver_1 = require_endpointResolver19();
    var schemas_0_1 = require_schemas_019();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      return {
        apiVersion: "2014-11-06",
        base64Decoder: config2?.base64Decoder ?? util_base64_1.fromBase64,
        base64Encoder: config2?.base64Encoder ?? util_base64_1.toBase64,
        disableHostPrefix: config2?.disableHostPrefix ?? false,
        endpointProvider: config2?.endpointProvider ?? endpointResolver_1.defaultEndpointResolver,
        extensions: config2?.extensions ?? [],
        httpAuthSchemeProvider: config2?.httpAuthSchemeProvider ?? httpAuthSchemeProvider_1.defaultSSMHttpAuthSchemeProvider,
        httpAuthSchemes: config2?.httpAuthSchemes ?? [
          {
            schemeId: "aws.auth#sigv4",
            identityProvider: /* @__PURE__ */ __name((ipc) => ipc.getIdentityProvider("aws.auth#sigv4"), "identityProvider"),
            signer: new httpAuthSchemes_1.AwsSdkSigV4Signer()
          }
        ],
        logger: config2?.logger ?? new smithy_client_1.NoOpLogger(),
        protocol: config2?.protocol ?? protocols_1.AwsJson1_1Protocol,
        protocolSettings: config2?.protocolSettings ?? {
          defaultNamespace: "com.amazonaws.ssm",
          errorTypeRegistries: schemas_0_1.errorTypeRegistries,
          xmlNamespace: "http://ssm.amazonaws.com/doc/2014-11-06/",
          version: "2014-11-06",
          serviceTarget: "AmazonSSM"
        },
        serviceId: config2?.serviceId ?? "SSM",
        urlParser: config2?.urlParser ?? url_parser_1.parseUrl,
        utf8Decoder: config2?.utf8Decoder ?? util_utf8_1.fromUtf8,
        utf8Encoder: config2?.utf8Encoder ?? util_utf8_1.toUtf8
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/dist-cjs/runtimeConfig.js
var require_runtimeConfig20 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/dist-cjs/runtimeConfig.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getRuntimeConfig = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var package_json_1 = tslib_1.__importDefault(require_package19());
    var client_1 = (init_client19(), __toCommonJS(client_exports14));
    var httpAuthSchemes_1 = (init_httpAuthSchemes12(), __toCommonJS(httpAuthSchemes_exports10));
    var credential_provider_node_1 = require_dist_cjs208();
    var util_user_agent_node_1 = require_dist_cjs202();
    var config_resolver_1 = require_dist_cjs25();
    var hash_node_1 = require_dist_cjs44();
    var middleware_retry_1 = require_dist_cjs198();
    var node_config_provider_1 = require_dist_cjs29();
    var node_http_handler_1 = require_dist_cjs13();
    var smithy_client_1 = require_dist_cjs34();
    var util_body_length_node_1 = require_dist_cjs45();
    var util_defaults_mode_node_1 = require_dist_cjs46();
    var util_retry_1 = require_dist_cjs22();
    var runtimeConfig_shared_1 = require_runtimeConfig_shared20();
    var getRuntimeConfig63 = /* @__PURE__ */ __name((config2) => {
      (0, smithy_client_1.emitWarningIfUnsupportedVersion)(process.version);
      const defaultsMode = (0, util_defaults_mode_node_1.resolveDefaultsModeConfig)(config2);
      const defaultConfigProvider = /* @__PURE__ */ __name(() => defaultsMode().then(smithy_client_1.loadConfigsForDefaultMode), "defaultConfigProvider");
      const clientSharedValues = (0, runtimeConfig_shared_1.getRuntimeConfig)(config2);
      (0, client_1.emitWarningIfUnsupportedVersion)(process.version);
      const loaderConfig = {
        profile: config2?.profile,
        logger: clientSharedValues.logger
      };
      return {
        ...clientSharedValues,
        ...config2,
        runtime: "node",
        defaultsMode,
        authSchemePreference: config2?.authSchemePreference ?? (0, node_config_provider_1.loadConfig)(httpAuthSchemes_1.NODE_AUTH_SCHEME_PREFERENCE_OPTIONS, loaderConfig),
        bodyLengthChecker: config2?.bodyLengthChecker ?? util_body_length_node_1.calculateBodyLength,
        credentialDefaultProvider: config2?.credentialDefaultProvider ?? credential_provider_node_1.defaultProvider,
        defaultUserAgentProvider: config2?.defaultUserAgentProvider ?? (0, util_user_agent_node_1.createDefaultUserAgentProvider)({ serviceId: clientSharedValues.serviceId, clientVersion: package_json_1.default.version }),
        maxAttempts: config2?.maxAttempts ?? (0, node_config_provider_1.loadConfig)(middleware_retry_1.NODE_MAX_ATTEMPT_CONFIG_OPTIONS, config2),
        region: config2?.region ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_REGION_CONFIG_OPTIONS, { ...config_resolver_1.NODE_REGION_CONFIG_FILE_OPTIONS, ...loaderConfig }),
        requestHandler: node_http_handler_1.NodeHttpHandler.create(config2?.requestHandler ?? defaultConfigProvider),
        retryMode: config2?.retryMode ?? (0, node_config_provider_1.loadConfig)({
          ...middleware_retry_1.NODE_RETRY_MODE_CONFIG_OPTIONS,
          default: /* @__PURE__ */ __name(async () => (await defaultConfigProvider()).retryMode || util_retry_1.DEFAULT_RETRY_MODE, "default")
        }, config2),
        sha256: config2?.sha256 ?? hash_node_1.Hash.bind(null, "sha256"),
        streamCollector: config2?.streamCollector ?? node_http_handler_1.streamCollector,
        useDualstackEndpoint: config2?.useDualstackEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_DUALSTACK_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        useFipsEndpoint: config2?.useFipsEndpoint ?? (0, node_config_provider_1.loadConfig)(config_resolver_1.NODE_USE_FIPS_ENDPOINT_CONFIG_OPTIONS, loaderConfig),
        userAgentAppId: config2?.userAgentAppId ?? (0, node_config_provider_1.loadConfig)(util_user_agent_node_1.NODE_APP_ID_CONFIG_OPTIONS, loaderConfig)
      };
    }, "getRuntimeConfig");
    exports2.getRuntimeConfig = getRuntimeConfig63;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-waiter/dist-cjs/index.js
var require_dist_cjs209 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/node_modules/@smithy/util-waiter/dist-cjs/index.js"(exports2) {
    "use strict";
    var getCircularReplacer3 = /* @__PURE__ */ __name(() => {
      const seen = /* @__PURE__ */ new WeakSet();
      return (key, value) => {
        if (typeof value === "object" && value !== null) {
          if (seen.has(value)) {
            return "[Circular]";
          }
          seen.add(value);
        }
        return value;
      };
    }, "getCircularReplacer");
    var sleep4 = /* @__PURE__ */ __name((seconds) => {
      return new Promise((resolve13) => setTimeout(resolve13, seconds * 1e3));
    }, "sleep");
    var waiterServiceDefaults3 = {
      minDelay: 2,
      maxDelay: 120
    };
    exports2.WaiterState = void 0;
    (function(WaiterState3) {
      WaiterState3["ABORTED"] = "ABORTED";
      WaiterState3["FAILURE"] = "FAILURE";
      WaiterState3["SUCCESS"] = "SUCCESS";
      WaiterState3["RETRY"] = "RETRY";
      WaiterState3["TIMEOUT"] = "TIMEOUT";
    })(exports2.WaiterState || (exports2.WaiterState = {}));
    var checkExceptions3 = /* @__PURE__ */ __name((result2) => {
      if (result2.state === exports2.WaiterState.ABORTED) {
        const abortError = new Error(`${JSON.stringify({
          ...result2,
          reason: "Request was aborted"
        }, getCircularReplacer3())}`);
        abortError.name = "AbortError";
        throw abortError;
      } else if (result2.state === exports2.WaiterState.TIMEOUT) {
        const timeoutError = new Error(`${JSON.stringify({
          ...result2,
          reason: "Waiter has timed out"
        }, getCircularReplacer3())}`);
        timeoutError.name = "TimeoutError";
        throw timeoutError;
      } else if (result2.state !== exports2.WaiterState.SUCCESS) {
        throw new Error(`${JSON.stringify(result2, getCircularReplacer3())}`);
      }
      return result2;
    }, "checkExceptions");
    var runPolling3 = /* @__PURE__ */ __name(async ({ minDelay, maxDelay, maxWaitTime, abortController, client, abortSignal }, input, acceptorChecks) => {
      const observedResponses = {};
      const [minDelayMs, maxDelayMs] = [minDelay * 1e3, maxDelay * 1e3];
      let currentAttempt = 0;
      const waitUntil = Date.now() + maxWaitTime * 1e3;
      const warn403Time = Date.now() + 6e4;
      let didWarn403 = false;
      while (true) {
        if (currentAttempt > 0) {
          const delayMs = exponentialBackoffWithJitter3(minDelayMs, maxDelayMs, currentAttempt, waitUntil);
          if (abortController?.signal?.aborted || abortSignal?.aborted) {
            const message2 = "AbortController signal aborted.";
            observedResponses[message2] |= 0;
            observedResponses[message2] += 1;
            return { state: exports2.WaiterState.ABORTED, observedResponses };
          }
          if (Date.now() + delayMs > waitUntil) {
            return { state: exports2.WaiterState.TIMEOUT, observedResponses };
          }
          await sleep4(delayMs / 1e3);
        }
        const { state: state13, reason } = await acceptorChecks(client, input);
        if (reason) {
          const message2 = createMessageFromResponse3(reason);
          observedResponses[message2] |= 0;
          observedResponses[message2] += 1;
        }
        if (state13 !== exports2.WaiterState.RETRY) {
          return { state: state13, reason, final: reason, observedResponses };
        }
        currentAttempt += 1;
        if (!didWarn403 && Date.now() >= warn403Time) {
          checkWarn4033(observedResponses, client);
          didWarn403 = true;
        }
      }
    }, "runPolling");
    var checkWarn4033 = /* @__PURE__ */ __name((observedResponses = {}, client) => {
      const orderedErrors = Object.keys(observedResponses);
      let count403 = 0;
      for (const response of orderedErrors) {
        const n10 = observedResponses[response] | 0;
        if (response.startsWith("403:")) {
          count403 += n10;
        }
      }
      const clientLogger = client?.config?.logger;
      const warningLogger = typeof clientLogger?.warn === "function" && !clientLogger.constructor?.name?.includes?.("NoOpLogger") ? clientLogger : console;
      if (count403 >= 3 || orderedErrors[orderedErrors.length - 1].startsWith("403:")) {
        warningLogger.warn(`@smithy/util-waiter WARN - 403 status code encountered during waiter polling.`);
      }
    }, "checkWarn403");
    var createMessageFromResponse3 = /* @__PURE__ */ __name((reason) => {
      const status = reason?.$response?.statusCode ?? reason?.$metadata?.httpStatusCode;
      if (reason?.$responseBodyText) {
        return `${status ? status + ": " : ""}Deserialization error for body: ${reason.$responseBodyText}`;
      }
      if (status) {
        if (reason?.$response || reason?.message) {
          return `${status ?? "Unknown"}: ${reason?.message}`;
        }
        return `${status}: OK`;
      }
      return String(reason?.message ?? JSON.stringify(reason, getCircularReplacer3()) ?? "Unknown");
    }, "createMessageFromResponse");
    var exponentialBackoffWithJitter3 = /* @__PURE__ */ __name((minDelayMs, maxDelayMs, attempt, waitUntil) => {
      const attemptCountCeiling = Math.log(maxDelayMs / minDelayMs) / Math.log(2) + 1;
      if (attempt > attemptCountCeiling) {
        return maxDelayMs;
      }
      const delay = minDelayMs * 2 ** (attempt - 1);
      const capped = Math.min(delay, maxDelayMs);
      const waitFor2 = randomInRange3(minDelayMs, capped);
      if (Date.now() + waitFor2 > waitUntil) {
        const timeRemaining = waitUntil - Date.now();
        return Math.max(0, timeRemaining - 500);
      }
      return waitFor2;
    }, "exponentialBackoffWithJitter");
    var randomInRange3 = /* @__PURE__ */ __name((min, max) => min + Math.random() * (max - min), "randomInRange");
    var validateWaiterOptions3 = /* @__PURE__ */ __name((options) => {
      if (options.maxWaitTime <= 0) {
        throw new Error(`WaiterConfiguration.maxWaitTime must be greater than 0`);
      } else if (options.minDelay <= 0) {
        throw new Error(`WaiterConfiguration.minDelay must be greater than 0`);
      } else if (options.maxDelay <= 0) {
        throw new Error(`WaiterConfiguration.maxDelay must be greater than 0`);
      } else if (options.maxWaitTime <= options.minDelay) {
        throw new Error(`WaiterConfiguration.maxWaitTime [${options.maxWaitTime}] must be greater than WaiterConfiguration.minDelay [${options.minDelay}] for this waiter`);
      } else if (options.maxDelay < options.minDelay) {
        throw new Error(`WaiterConfiguration.maxDelay [${options.maxDelay}] must be greater than WaiterConfiguration.minDelay [${options.minDelay}] for this waiter`);
      }
    }, "validateWaiterOptions");
    var abortTimeout3 = /* @__PURE__ */ __name((abortSignal) => {
      let onAbort;
      const promise = new Promise((resolve13) => {
        onAbort = /* @__PURE__ */ __name(() => resolve13({ state: exports2.WaiterState.ABORTED }), "onAbort");
        if (typeof abortSignal.addEventListener === "function") {
          abortSignal.addEventListener("abort", onAbort);
        } else {
          abortSignal.onabort = onAbort;
        }
      });
      return {
        clearListener() {
          if (typeof abortSignal.removeEventListener === "function") {
            abortSignal.removeEventListener("abort", onAbort);
          }
        },
        aborted: promise
      };
    }, "abortTimeout");
    var createWaiter3 = /* @__PURE__ */ __name(async (options, input, acceptorChecks) => {
      const params = {
        ...waiterServiceDefaults3,
        ...options
      };
      validateWaiterOptions3(params);
      const exitConditions = [runPolling3(params, input, acceptorChecks)];
      const finalize = [];
      if (options.abortSignal) {
        const { aborted, clearListener } = abortTimeout3(options.abortSignal);
        finalize.push(clearListener);
        exitConditions.push(aborted);
      }
      if (options.abortController?.signal) {
        const { aborted, clearListener } = abortTimeout3(options.abortController.signal);
        finalize.push(clearListener);
        exitConditions.push(aborted);
      }
      return Promise.race(exitConditions).then((result2) => {
        for (const fn of finalize) {
          fn();
        }
        return result2;
      });
    }, "createWaiter");
    exports2.checkExceptions = checkExceptions3;
    exports2.createWaiter = createWaiter3;
    exports2.waiterServiceDefaults = waiterServiceDefaults3;
  }
});

// ../../node_modules/@aws-sdk/client-ssm/dist-cjs/index.js
var require_dist_cjs210 = __commonJS({
  "../../node_modules/@aws-sdk/client-ssm/dist-cjs/index.js"(exports2) {
    "use strict";
    var middlewareHostHeader = require_dist_cjs3();
    var middlewareLogger = require_dist_cjs4();
    var middlewareRecursionDetection = require_dist_cjs5();
    var middlewareUserAgent = require_dist_cjs197();
    var configResolver = require_dist_cjs25();
    var core = (init_dist_es(), __toCommonJS(dist_es_exports));
    var schema = (init_schema4(), __toCommonJS(schema_exports));
    var middlewareContentLength = require_dist_cjs26();
    var middlewareEndpoint = require_dist_cjs31();
    var middlewareRetry = require_dist_cjs198();
    var smithyClient = require_dist_cjs34();
    var httpAuthSchemeProvider = require_httpAuthSchemeProvider19();
    var runtimeConfig = require_runtimeConfig20();
    var regionConfigResolver = require_dist_cjs48();
    var protocolHttp = require_dist_cjs2();
    var schemas_0 = require_schemas_019();
    var utilWaiter = require_dist_cjs209();
    var errors = require_errors18();
    var SSMServiceException = require_SSMServiceException();
    var resolveClientEndpointParameters32 = /* @__PURE__ */ __name((options) => {
      return Object.assign(options, {
        useDualstackEndpoint: options.useDualstackEndpoint ?? false,
        useFipsEndpoint: options.useFipsEndpoint ?? false,
        defaultSigningName: "ssm"
      });
    }, "resolveClientEndpointParameters");
    var commonParams32 = {
      UseFIPS: { type: "builtInParams", name: "useFipsEndpoint" },
      Endpoint: { type: "builtInParams", name: "endpoint" },
      Region: { type: "builtInParams", name: "region" },
      UseDualStack: { type: "builtInParams", name: "useDualstackEndpoint" }
    };
    var getHttpAuthExtensionConfiguration32 = /* @__PURE__ */ __name((runtimeConfig2) => {
      const _httpAuthSchemes = runtimeConfig2.httpAuthSchemes;
      let _httpAuthSchemeProvider = runtimeConfig2.httpAuthSchemeProvider;
      let _credentials = runtimeConfig2.credentials;
      return {
        setHttpAuthScheme(httpAuthScheme) {
          const index = _httpAuthSchemes.findIndex((scheme) => scheme.schemeId === httpAuthScheme.schemeId);
          if (index === -1) {
            _httpAuthSchemes.push(httpAuthScheme);
          } else {
            _httpAuthSchemes.splice(index, 1, httpAuthScheme);
          }
        },
        httpAuthSchemes() {
          return _httpAuthSchemes;
        },
        setHttpAuthSchemeProvider(httpAuthSchemeProvider2) {
          _httpAuthSchemeProvider = httpAuthSchemeProvider2;
        },
        httpAuthSchemeProvider() {
          return _httpAuthSchemeProvider;
        },
        setCredentials(credentials) {
          _credentials = credentials;
        },
        credentials() {
          return _credentials;
        }
      };
    }, "getHttpAuthExtensionConfiguration");
    var resolveHttpAuthRuntimeConfig32 = /* @__PURE__ */ __name((config2) => {
      return {
        httpAuthSchemes: config2.httpAuthSchemes(),
        httpAuthSchemeProvider: config2.httpAuthSchemeProvider(),
        credentials: config2.credentials()
      };
    }, "resolveHttpAuthRuntimeConfig");
    var resolveRuntimeExtensions32 = /* @__PURE__ */ __name((runtimeConfig2, extensions) => {
      const extensionConfiguration = Object.assign(regionConfigResolver.getAwsRegionExtensionConfiguration(runtimeConfig2), smithyClient.getDefaultExtensionConfiguration(runtimeConfig2), protocolHttp.getHttpHandlerExtensionConfiguration(runtimeConfig2), getHttpAuthExtensionConfiguration32(runtimeConfig2));
      extensions.forEach((extension) => extension.configure(extensionConfiguration));
      return Object.assign(runtimeConfig2, regionConfigResolver.resolveAwsRegionExtensionConfiguration(extensionConfiguration), smithyClient.resolveDefaultRuntimeConfig(extensionConfiguration), protocolHttp.resolveHttpHandlerRuntimeConfig(extensionConfiguration), resolveHttpAuthRuntimeConfig32(extensionConfiguration));
    }, "resolveRuntimeExtensions");
    var SSMClient2 = class extends smithyClient.Client {
      static {
        __name(this, "SSMClient");
      }
      config;
      constructor(...[configuration]) {
        const _config_0 = runtimeConfig.getRuntimeConfig(configuration || {});
        super(_config_0);
        this.initConfig = _config_0;
        const _config_1 = resolveClientEndpointParameters32(_config_0);
        const _config_2 = middlewareUserAgent.resolveUserAgentConfig(_config_1);
        const _config_3 = middlewareRetry.resolveRetryConfig(_config_2);
        const _config_4 = configResolver.resolveRegionConfig(_config_3);
        const _config_5 = middlewareHostHeader.resolveHostHeaderConfig(_config_4);
        const _config_6 = middlewareEndpoint.resolveEndpointConfig(_config_5);
        const _config_7 = httpAuthSchemeProvider.resolveHttpAuthSchemeConfig(_config_6);
        const _config_8 = resolveRuntimeExtensions32(_config_7, configuration?.extensions || []);
        this.config = _config_8;
        this.middlewareStack.use(schema.getSchemaSerdePlugin(this.config));
        this.middlewareStack.use(middlewareUserAgent.getUserAgentPlugin(this.config));
        this.middlewareStack.use(middlewareRetry.getRetryPlugin(this.config));
        this.middlewareStack.use(middlewareContentLength.getContentLengthPlugin(this.config));
        this.middlewareStack.use(middlewareHostHeader.getHostHeaderPlugin(this.config));
        this.middlewareStack.use(middlewareLogger.getLoggerPlugin(this.config));
        this.middlewareStack.use(middlewareRecursionDetection.getRecursionDetectionPlugin(this.config));
        this.middlewareStack.use(core.getHttpAuthSchemeEndpointRuleSetPlugin(this.config, {
          httpAuthSchemeParametersProvider: httpAuthSchemeProvider.defaultSSMHttpAuthSchemeParametersProvider,
          identityProviderConfigProvider: /* @__PURE__ */ __name(async (config2) => new core.DefaultIdentityProviderConfig({
            "aws.auth#sigv4": config2.credentials
          }), "identityProviderConfigProvider")
        }));
        this.middlewareStack.use(core.getHttpSigningPlugin(this.config));
      }
      destroy() {
        super.destroy();
      }
    };
    var AddTagsToResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "AddTagsToResource", {}).n("SSMClient", "AddTagsToResourceCommand").sc(schemas_0.AddTagsToResource$).build() {
      static {
        __name(this, "AddTagsToResourceCommand");
      }
    };
    var AssociateOpsItemRelatedItemCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "AssociateOpsItemRelatedItem", {}).n("SSMClient", "AssociateOpsItemRelatedItemCommand").sc(schemas_0.AssociateOpsItemRelatedItem$).build() {
      static {
        __name(this, "AssociateOpsItemRelatedItemCommand");
      }
    };
    var CancelCommandCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "CancelCommand", {}).n("SSMClient", "CancelCommandCommand").sc(schemas_0.CancelCommand$).build() {
      static {
        __name(this, "CancelCommandCommand");
      }
    };
    var CancelMaintenanceWindowExecutionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "CancelMaintenanceWindowExecution", {}).n("SSMClient", "CancelMaintenanceWindowExecutionCommand").sc(schemas_0.CancelMaintenanceWindowExecution$).build() {
      static {
        __name(this, "CancelMaintenanceWindowExecutionCommand");
      }
    };
    var CreateActivationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "CreateActivation", {}).n("SSMClient", "CreateActivationCommand").sc(schemas_0.CreateActivation$).build() {
      static {
        __name(this, "CreateActivationCommand");
      }
    };
    var CreateAssociationBatchCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "CreateAssociationBatch", {}).n("SSMClient", "CreateAssociationBatchCommand").sc(schemas_0.CreateAssociationBatch$).build() {
      static {
        __name(this, "CreateAssociationBatchCommand");
      }
    };
    var CreateAssociationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "CreateAssociation", {}).n("SSMClient", "CreateAssociationCommand").sc(schemas_0.CreateAssociation$).build() {
      static {
        __name(this, "CreateAssociationCommand");
      }
    };
    var CreateDocumentCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "CreateDocument", {}).n("SSMClient", "CreateDocumentCommand").sc(schemas_0.CreateDocument$).build() {
      static {
        __name(this, "CreateDocumentCommand");
      }
    };
    var CreateMaintenanceWindowCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "CreateMaintenanceWindow", {}).n("SSMClient", "CreateMaintenanceWindowCommand").sc(schemas_0.CreateMaintenanceWindow$).build() {
      static {
        __name(this, "CreateMaintenanceWindowCommand");
      }
    };
    var CreateOpsItemCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "CreateOpsItem", {}).n("SSMClient", "CreateOpsItemCommand").sc(schemas_0.CreateOpsItem$).build() {
      static {
        __name(this, "CreateOpsItemCommand");
      }
    };
    var CreateOpsMetadataCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "CreateOpsMetadata", {}).n("SSMClient", "CreateOpsMetadataCommand").sc(schemas_0.CreateOpsMetadata$).build() {
      static {
        __name(this, "CreateOpsMetadataCommand");
      }
    };
    var CreatePatchBaselineCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "CreatePatchBaseline", {}).n("SSMClient", "CreatePatchBaselineCommand").sc(schemas_0.CreatePatchBaseline$).build() {
      static {
        __name(this, "CreatePatchBaselineCommand");
      }
    };
    var CreateResourceDataSyncCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "CreateResourceDataSync", {}).n("SSMClient", "CreateResourceDataSyncCommand").sc(schemas_0.CreateResourceDataSync$).build() {
      static {
        __name(this, "CreateResourceDataSyncCommand");
      }
    };
    var DeleteActivationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DeleteActivation", {}).n("SSMClient", "DeleteActivationCommand").sc(schemas_0.DeleteActivation$).build() {
      static {
        __name(this, "DeleteActivationCommand");
      }
    };
    var DeleteAssociationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DeleteAssociation", {}).n("SSMClient", "DeleteAssociationCommand").sc(schemas_0.DeleteAssociation$).build() {
      static {
        __name(this, "DeleteAssociationCommand");
      }
    };
    var DeleteDocumentCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DeleteDocument", {}).n("SSMClient", "DeleteDocumentCommand").sc(schemas_0.DeleteDocument$).build() {
      static {
        __name(this, "DeleteDocumentCommand");
      }
    };
    var DeleteInventoryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DeleteInventory", {}).n("SSMClient", "DeleteInventoryCommand").sc(schemas_0.DeleteInventory$).build() {
      static {
        __name(this, "DeleteInventoryCommand");
      }
    };
    var DeleteMaintenanceWindowCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DeleteMaintenanceWindow", {}).n("SSMClient", "DeleteMaintenanceWindowCommand").sc(schemas_0.DeleteMaintenanceWindow$).build() {
      static {
        __name(this, "DeleteMaintenanceWindowCommand");
      }
    };
    var DeleteOpsItemCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DeleteOpsItem", {}).n("SSMClient", "DeleteOpsItemCommand").sc(schemas_0.DeleteOpsItem$).build() {
      static {
        __name(this, "DeleteOpsItemCommand");
      }
    };
    var DeleteOpsMetadataCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DeleteOpsMetadata", {}).n("SSMClient", "DeleteOpsMetadataCommand").sc(schemas_0.DeleteOpsMetadata$).build() {
      static {
        __name(this, "DeleteOpsMetadataCommand");
      }
    };
    var DeleteParameterCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DeleteParameter", {}).n("SSMClient", "DeleteParameterCommand").sc(schemas_0.DeleteParameter$).build() {
      static {
        __name(this, "DeleteParameterCommand");
      }
    };
    var DeleteParametersCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DeleteParameters", {}).n("SSMClient", "DeleteParametersCommand").sc(schemas_0.DeleteParameters$).build() {
      static {
        __name(this, "DeleteParametersCommand");
      }
    };
    var DeletePatchBaselineCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DeletePatchBaseline", {}).n("SSMClient", "DeletePatchBaselineCommand").sc(schemas_0.DeletePatchBaseline$).build() {
      static {
        __name(this, "DeletePatchBaselineCommand");
      }
    };
    var DeleteResourceDataSyncCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DeleteResourceDataSync", {}).n("SSMClient", "DeleteResourceDataSyncCommand").sc(schemas_0.DeleteResourceDataSync$).build() {
      static {
        __name(this, "DeleteResourceDataSyncCommand");
      }
    };
    var DeleteResourcePolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DeleteResourcePolicy", {}).n("SSMClient", "DeleteResourcePolicyCommand").sc(schemas_0.DeleteResourcePolicy$).build() {
      static {
        __name(this, "DeleteResourcePolicyCommand");
      }
    };
    var DeregisterManagedInstanceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DeregisterManagedInstance", {}).n("SSMClient", "DeregisterManagedInstanceCommand").sc(schemas_0.DeregisterManagedInstance$).build() {
      static {
        __name(this, "DeregisterManagedInstanceCommand");
      }
    };
    var DeregisterPatchBaselineForPatchGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DeregisterPatchBaselineForPatchGroup", {}).n("SSMClient", "DeregisterPatchBaselineForPatchGroupCommand").sc(schemas_0.DeregisterPatchBaselineForPatchGroup$).build() {
      static {
        __name(this, "DeregisterPatchBaselineForPatchGroupCommand");
      }
    };
    var DeregisterTargetFromMaintenanceWindowCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DeregisterTargetFromMaintenanceWindow", {}).n("SSMClient", "DeregisterTargetFromMaintenanceWindowCommand").sc(schemas_0.DeregisterTargetFromMaintenanceWindow$).build() {
      static {
        __name(this, "DeregisterTargetFromMaintenanceWindowCommand");
      }
    };
    var DeregisterTaskFromMaintenanceWindowCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DeregisterTaskFromMaintenanceWindow", {}).n("SSMClient", "DeregisterTaskFromMaintenanceWindowCommand").sc(schemas_0.DeregisterTaskFromMaintenanceWindow$).build() {
      static {
        __name(this, "DeregisterTaskFromMaintenanceWindowCommand");
      }
    };
    var DescribeActivationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeActivations", {}).n("SSMClient", "DescribeActivationsCommand").sc(schemas_0.DescribeActivations$).build() {
      static {
        __name(this, "DescribeActivationsCommand");
      }
    };
    var DescribeAssociationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeAssociation", {}).n("SSMClient", "DescribeAssociationCommand").sc(schemas_0.DescribeAssociation$).build() {
      static {
        __name(this, "DescribeAssociationCommand");
      }
    };
    var DescribeAssociationExecutionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeAssociationExecutions", {}).n("SSMClient", "DescribeAssociationExecutionsCommand").sc(schemas_0.DescribeAssociationExecutions$).build() {
      static {
        __name(this, "DescribeAssociationExecutionsCommand");
      }
    };
    var DescribeAssociationExecutionTargetsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeAssociationExecutionTargets", {}).n("SSMClient", "DescribeAssociationExecutionTargetsCommand").sc(schemas_0.DescribeAssociationExecutionTargets$).build() {
      static {
        __name(this, "DescribeAssociationExecutionTargetsCommand");
      }
    };
    var DescribeAutomationExecutionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeAutomationExecutions", {}).n("SSMClient", "DescribeAutomationExecutionsCommand").sc(schemas_0.DescribeAutomationExecutions$).build() {
      static {
        __name(this, "DescribeAutomationExecutionsCommand");
      }
    };
    var DescribeAutomationStepExecutionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeAutomationStepExecutions", {}).n("SSMClient", "DescribeAutomationStepExecutionsCommand").sc(schemas_0.DescribeAutomationStepExecutions$).build() {
      static {
        __name(this, "DescribeAutomationStepExecutionsCommand");
      }
    };
    var DescribeAvailablePatchesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeAvailablePatches", {}).n("SSMClient", "DescribeAvailablePatchesCommand").sc(schemas_0.DescribeAvailablePatches$).build() {
      static {
        __name(this, "DescribeAvailablePatchesCommand");
      }
    };
    var DescribeDocumentCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeDocument", {}).n("SSMClient", "DescribeDocumentCommand").sc(schemas_0.DescribeDocument$).build() {
      static {
        __name(this, "DescribeDocumentCommand");
      }
    };
    var DescribeDocumentPermissionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeDocumentPermission", {}).n("SSMClient", "DescribeDocumentPermissionCommand").sc(schemas_0.DescribeDocumentPermission$).build() {
      static {
        __name(this, "DescribeDocumentPermissionCommand");
      }
    };
    var DescribeEffectiveInstanceAssociationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeEffectiveInstanceAssociations", {}).n("SSMClient", "DescribeEffectiveInstanceAssociationsCommand").sc(schemas_0.DescribeEffectiveInstanceAssociations$).build() {
      static {
        __name(this, "DescribeEffectiveInstanceAssociationsCommand");
      }
    };
    var DescribeEffectivePatchesForPatchBaselineCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeEffectivePatchesForPatchBaseline", {}).n("SSMClient", "DescribeEffectivePatchesForPatchBaselineCommand").sc(schemas_0.DescribeEffectivePatchesForPatchBaseline$).build() {
      static {
        __name(this, "DescribeEffectivePatchesForPatchBaselineCommand");
      }
    };
    var DescribeInstanceAssociationsStatusCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeInstanceAssociationsStatus", {}).n("SSMClient", "DescribeInstanceAssociationsStatusCommand").sc(schemas_0.DescribeInstanceAssociationsStatus$).build() {
      static {
        __name(this, "DescribeInstanceAssociationsStatusCommand");
      }
    };
    var DescribeInstanceInformationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeInstanceInformation", {}).n("SSMClient", "DescribeInstanceInformationCommand").sc(schemas_0.DescribeInstanceInformation$).build() {
      static {
        __name(this, "DescribeInstanceInformationCommand");
      }
    };
    var DescribeInstancePatchesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeInstancePatches", {}).n("SSMClient", "DescribeInstancePatchesCommand").sc(schemas_0.DescribeInstancePatches$).build() {
      static {
        __name(this, "DescribeInstancePatchesCommand");
      }
    };
    var DescribeInstancePatchStatesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeInstancePatchStates", {}).n("SSMClient", "DescribeInstancePatchStatesCommand").sc(schemas_0.DescribeInstancePatchStates$).build() {
      static {
        __name(this, "DescribeInstancePatchStatesCommand");
      }
    };
    var DescribeInstancePatchStatesForPatchGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeInstancePatchStatesForPatchGroup", {}).n("SSMClient", "DescribeInstancePatchStatesForPatchGroupCommand").sc(schemas_0.DescribeInstancePatchStatesForPatchGroup$).build() {
      static {
        __name(this, "DescribeInstancePatchStatesForPatchGroupCommand");
      }
    };
    var DescribeInstancePropertiesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeInstanceProperties", {}).n("SSMClient", "DescribeInstancePropertiesCommand").sc(schemas_0.DescribeInstanceProperties$).build() {
      static {
        __name(this, "DescribeInstancePropertiesCommand");
      }
    };
    var DescribeInventoryDeletionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeInventoryDeletions", {}).n("SSMClient", "DescribeInventoryDeletionsCommand").sc(schemas_0.DescribeInventoryDeletions$).build() {
      static {
        __name(this, "DescribeInventoryDeletionsCommand");
      }
    };
    var DescribeMaintenanceWindowExecutionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeMaintenanceWindowExecutions", {}).n("SSMClient", "DescribeMaintenanceWindowExecutionsCommand").sc(schemas_0.DescribeMaintenanceWindowExecutions$).build() {
      static {
        __name(this, "DescribeMaintenanceWindowExecutionsCommand");
      }
    };
    var DescribeMaintenanceWindowExecutionTaskInvocationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeMaintenanceWindowExecutionTaskInvocations", {}).n("SSMClient", "DescribeMaintenanceWindowExecutionTaskInvocationsCommand").sc(schemas_0.DescribeMaintenanceWindowExecutionTaskInvocations$).build() {
      static {
        __name(this, "DescribeMaintenanceWindowExecutionTaskInvocationsCommand");
      }
    };
    var DescribeMaintenanceWindowExecutionTasksCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeMaintenanceWindowExecutionTasks", {}).n("SSMClient", "DescribeMaintenanceWindowExecutionTasksCommand").sc(schemas_0.DescribeMaintenanceWindowExecutionTasks$).build() {
      static {
        __name(this, "DescribeMaintenanceWindowExecutionTasksCommand");
      }
    };
    var DescribeMaintenanceWindowScheduleCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeMaintenanceWindowSchedule", {}).n("SSMClient", "DescribeMaintenanceWindowScheduleCommand").sc(schemas_0.DescribeMaintenanceWindowSchedule$).build() {
      static {
        __name(this, "DescribeMaintenanceWindowScheduleCommand");
      }
    };
    var DescribeMaintenanceWindowsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeMaintenanceWindows", {}).n("SSMClient", "DescribeMaintenanceWindowsCommand").sc(schemas_0.DescribeMaintenanceWindows$).build() {
      static {
        __name(this, "DescribeMaintenanceWindowsCommand");
      }
    };
    var DescribeMaintenanceWindowsForTargetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeMaintenanceWindowsForTarget", {}).n("SSMClient", "DescribeMaintenanceWindowsForTargetCommand").sc(schemas_0.DescribeMaintenanceWindowsForTarget$).build() {
      static {
        __name(this, "DescribeMaintenanceWindowsForTargetCommand");
      }
    };
    var DescribeMaintenanceWindowTargetsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeMaintenanceWindowTargets", {}).n("SSMClient", "DescribeMaintenanceWindowTargetsCommand").sc(schemas_0.DescribeMaintenanceWindowTargets$).build() {
      static {
        __name(this, "DescribeMaintenanceWindowTargetsCommand");
      }
    };
    var DescribeMaintenanceWindowTasksCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeMaintenanceWindowTasks", {}).n("SSMClient", "DescribeMaintenanceWindowTasksCommand").sc(schemas_0.DescribeMaintenanceWindowTasks$).build() {
      static {
        __name(this, "DescribeMaintenanceWindowTasksCommand");
      }
    };
    var DescribeOpsItemsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeOpsItems", {}).n("SSMClient", "DescribeOpsItemsCommand").sc(schemas_0.DescribeOpsItems$).build() {
      static {
        __name(this, "DescribeOpsItemsCommand");
      }
    };
    var DescribeParametersCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeParameters", {}).n("SSMClient", "DescribeParametersCommand").sc(schemas_0.DescribeParameters$).build() {
      static {
        __name(this, "DescribeParametersCommand");
      }
    };
    var DescribePatchBaselinesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribePatchBaselines", {}).n("SSMClient", "DescribePatchBaselinesCommand").sc(schemas_0.DescribePatchBaselines$).build() {
      static {
        __name(this, "DescribePatchBaselinesCommand");
      }
    };
    var DescribePatchGroupsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribePatchGroups", {}).n("SSMClient", "DescribePatchGroupsCommand").sc(schemas_0.DescribePatchGroups$).build() {
      static {
        __name(this, "DescribePatchGroupsCommand");
      }
    };
    var DescribePatchGroupStateCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribePatchGroupState", {}).n("SSMClient", "DescribePatchGroupStateCommand").sc(schemas_0.DescribePatchGroupState$).build() {
      static {
        __name(this, "DescribePatchGroupStateCommand");
      }
    };
    var DescribePatchPropertiesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribePatchProperties", {}).n("SSMClient", "DescribePatchPropertiesCommand").sc(schemas_0.DescribePatchProperties$).build() {
      static {
        __name(this, "DescribePatchPropertiesCommand");
      }
    };
    var DescribeSessionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DescribeSessions", {}).n("SSMClient", "DescribeSessionsCommand").sc(schemas_0.DescribeSessions$).build() {
      static {
        __name(this, "DescribeSessionsCommand");
      }
    };
    var DisassociateOpsItemRelatedItemCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "DisassociateOpsItemRelatedItem", {}).n("SSMClient", "DisassociateOpsItemRelatedItemCommand").sc(schemas_0.DisassociateOpsItemRelatedItem$).build() {
      static {
        __name(this, "DisassociateOpsItemRelatedItemCommand");
      }
    };
    var GetAccessTokenCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "GetAccessToken", {}).n("SSMClient", "GetAccessTokenCommand").sc(schemas_0.GetAccessToken$).build() {
      static {
        __name(this, "GetAccessTokenCommand");
      }
    };
    var GetAutomationExecutionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "GetAutomationExecution", {}).n("SSMClient", "GetAutomationExecutionCommand").sc(schemas_0.GetAutomationExecution$).build() {
      static {
        __name(this, "GetAutomationExecutionCommand");
      }
    };
    var GetCalendarStateCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "GetCalendarState", {}).n("SSMClient", "GetCalendarStateCommand").sc(schemas_0.GetCalendarState$).build() {
      static {
        __name(this, "GetCalendarStateCommand");
      }
    };
    var GetCommandInvocationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "GetCommandInvocation", {}).n("SSMClient", "GetCommandInvocationCommand").sc(schemas_0.GetCommandInvocation$).build() {
      static {
        __name(this, "GetCommandInvocationCommand");
      }
    };
    var GetConnectionStatusCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "GetConnectionStatus", {}).n("SSMClient", "GetConnectionStatusCommand").sc(schemas_0.GetConnectionStatus$).build() {
      static {
        __name(this, "GetConnectionStatusCommand");
      }
    };
    var GetDefaultPatchBaselineCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "GetDefaultPatchBaseline", {}).n("SSMClient", "GetDefaultPatchBaselineCommand").sc(schemas_0.GetDefaultPatchBaseline$).build() {
      static {
        __name(this, "GetDefaultPatchBaselineCommand");
      }
    };
    var GetDeployablePatchSnapshotForInstanceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "GetDeployablePatchSnapshotForInstance", {}).n("SSMClient", "GetDeployablePatchSnapshotForInstanceCommand").sc(schemas_0.GetDeployablePatchSnapshotForInstance$).build() {
      static {
        __name(this, "GetDeployablePatchSnapshotForInstanceCommand");
      }
    };
    var GetDocumentCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "GetDocument", {}).n("SSMClient", "GetDocumentCommand").sc(schemas_0.GetDocument$).build() {
      static {
        __name(this, "GetDocumentCommand");
      }
    };
    var GetExecutionPreviewCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "GetExecutionPreview", {}).n("SSMClient", "GetExecutionPreviewCommand").sc(schemas_0.GetExecutionPreview$).build() {
      static {
        __name(this, "GetExecutionPreviewCommand");
      }
    };
    var GetInventoryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "GetInventory", {}).n("SSMClient", "GetInventoryCommand").sc(schemas_0.GetInventory$).build() {
      static {
        __name(this, "GetInventoryCommand");
      }
    };
    var GetInventorySchemaCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "GetInventorySchema", {}).n("SSMClient", "GetInventorySchemaCommand").sc(schemas_0.GetInventorySchema$).build() {
      static {
        __name(this, "GetInventorySchemaCommand");
      }
    };
    var GetMaintenanceWindowCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "GetMaintenanceWindow", {}).n("SSMClient", "GetMaintenanceWindowCommand").sc(schemas_0.GetMaintenanceWindow$).build() {
      static {
        __name(this, "GetMaintenanceWindowCommand");
      }
    };
    var GetMaintenanceWindowExecutionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "GetMaintenanceWindowExecution", {}).n("SSMClient", "GetMaintenanceWindowExecutionCommand").sc(schemas_0.GetMaintenanceWindowExecution$).build() {
      static {
        __name(this, "GetMaintenanceWindowExecutionCommand");
      }
    };
    var GetMaintenanceWindowExecutionTaskCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "GetMaintenanceWindowExecutionTask", {}).n("SSMClient", "GetMaintenanceWindowExecutionTaskCommand").sc(schemas_0.GetMaintenanceWindowExecutionTask$).build() {
      static {
        __name(this, "GetMaintenanceWindowExecutionTaskCommand");
      }
    };
    var GetMaintenanceWindowExecutionTaskInvocationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "GetMaintenanceWindowExecutionTaskInvocation", {}).n("SSMClient", "GetMaintenanceWindowExecutionTaskInvocationCommand").sc(schemas_0.GetMaintenanceWindowExecutionTaskInvocation$).build() {
      static {
        __name(this, "GetMaintenanceWindowExecutionTaskInvocationCommand");
      }
    };
    var GetMaintenanceWindowTaskCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "GetMaintenanceWindowTask", {}).n("SSMClient", "GetMaintenanceWindowTaskCommand").sc(schemas_0.GetMaintenanceWindowTask$).build() {
      static {
        __name(this, "GetMaintenanceWindowTaskCommand");
      }
    };
    var GetOpsItemCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "GetOpsItem", {}).n("SSMClient", "GetOpsItemCommand").sc(schemas_0.GetOpsItem$).build() {
      static {
        __name(this, "GetOpsItemCommand");
      }
    };
    var GetOpsMetadataCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "GetOpsMetadata", {}).n("SSMClient", "GetOpsMetadataCommand").sc(schemas_0.GetOpsMetadata$).build() {
      static {
        __name(this, "GetOpsMetadataCommand");
      }
    };
    var GetOpsSummaryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "GetOpsSummary", {}).n("SSMClient", "GetOpsSummaryCommand").sc(schemas_0.GetOpsSummary$).build() {
      static {
        __name(this, "GetOpsSummaryCommand");
      }
    };
    var GetParameterCommand2 = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "GetParameter", {}).n("SSMClient", "GetParameterCommand").sc(schemas_0.GetParameter$).build() {
      static {
        __name(this, "GetParameterCommand");
      }
    };
    var GetParameterHistoryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "GetParameterHistory", {}).n("SSMClient", "GetParameterHistoryCommand").sc(schemas_0.GetParameterHistory$).build() {
      static {
        __name(this, "GetParameterHistoryCommand");
      }
    };
    var GetParametersByPathCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "GetParametersByPath", {}).n("SSMClient", "GetParametersByPathCommand").sc(schemas_0.GetParametersByPath$).build() {
      static {
        __name(this, "GetParametersByPathCommand");
      }
    };
    var GetParametersCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "GetParameters", {}).n("SSMClient", "GetParametersCommand").sc(schemas_0.GetParameters$).build() {
      static {
        __name(this, "GetParametersCommand");
      }
    };
    var GetPatchBaselineCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "GetPatchBaseline", {}).n("SSMClient", "GetPatchBaselineCommand").sc(schemas_0.GetPatchBaseline$).build() {
      static {
        __name(this, "GetPatchBaselineCommand");
      }
    };
    var GetPatchBaselineForPatchGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "GetPatchBaselineForPatchGroup", {}).n("SSMClient", "GetPatchBaselineForPatchGroupCommand").sc(schemas_0.GetPatchBaselineForPatchGroup$).build() {
      static {
        __name(this, "GetPatchBaselineForPatchGroupCommand");
      }
    };
    var GetResourcePoliciesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "GetResourcePolicies", {}).n("SSMClient", "GetResourcePoliciesCommand").sc(schemas_0.GetResourcePolicies$).build() {
      static {
        __name(this, "GetResourcePoliciesCommand");
      }
    };
    var GetServiceSettingCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "GetServiceSetting", {}).n("SSMClient", "GetServiceSettingCommand").sc(schemas_0.GetServiceSetting$).build() {
      static {
        __name(this, "GetServiceSettingCommand");
      }
    };
    var LabelParameterVersionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "LabelParameterVersion", {}).n("SSMClient", "LabelParameterVersionCommand").sc(schemas_0.LabelParameterVersion$).build() {
      static {
        __name(this, "LabelParameterVersionCommand");
      }
    };
    var ListAssociationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "ListAssociations", {}).n("SSMClient", "ListAssociationsCommand").sc(schemas_0.ListAssociations$).build() {
      static {
        __name(this, "ListAssociationsCommand");
      }
    };
    var ListAssociationVersionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "ListAssociationVersions", {}).n("SSMClient", "ListAssociationVersionsCommand").sc(schemas_0.ListAssociationVersions$).build() {
      static {
        __name(this, "ListAssociationVersionsCommand");
      }
    };
    var ListCommandInvocationsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "ListCommandInvocations", {}).n("SSMClient", "ListCommandInvocationsCommand").sc(schemas_0.ListCommandInvocations$).build() {
      static {
        __name(this, "ListCommandInvocationsCommand");
      }
    };
    var ListCommandsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "ListCommands", {}).n("SSMClient", "ListCommandsCommand").sc(schemas_0.ListCommands$).build() {
      static {
        __name(this, "ListCommandsCommand");
      }
    };
    var ListComplianceItemsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "ListComplianceItems", {}).n("SSMClient", "ListComplianceItemsCommand").sc(schemas_0.ListComplianceItems$).build() {
      static {
        __name(this, "ListComplianceItemsCommand");
      }
    };
    var ListComplianceSummariesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "ListComplianceSummaries", {}).n("SSMClient", "ListComplianceSummariesCommand").sc(schemas_0.ListComplianceSummaries$).build() {
      static {
        __name(this, "ListComplianceSummariesCommand");
      }
    };
    var ListDocumentMetadataHistoryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "ListDocumentMetadataHistory", {}).n("SSMClient", "ListDocumentMetadataHistoryCommand").sc(schemas_0.ListDocumentMetadataHistory$).build() {
      static {
        __name(this, "ListDocumentMetadataHistoryCommand");
      }
    };
    var ListDocumentsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "ListDocuments", {}).n("SSMClient", "ListDocumentsCommand").sc(schemas_0.ListDocuments$).build() {
      static {
        __name(this, "ListDocumentsCommand");
      }
    };
    var ListDocumentVersionsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "ListDocumentVersions", {}).n("SSMClient", "ListDocumentVersionsCommand").sc(schemas_0.ListDocumentVersions$).build() {
      static {
        __name(this, "ListDocumentVersionsCommand");
      }
    };
    var ListInventoryEntriesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "ListInventoryEntries", {}).n("SSMClient", "ListInventoryEntriesCommand").sc(schemas_0.ListInventoryEntries$).build() {
      static {
        __name(this, "ListInventoryEntriesCommand");
      }
    };
    var ListNodesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "ListNodes", {}).n("SSMClient", "ListNodesCommand").sc(schemas_0.ListNodes$).build() {
      static {
        __name(this, "ListNodesCommand");
      }
    };
    var ListNodesSummaryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "ListNodesSummary", {}).n("SSMClient", "ListNodesSummaryCommand").sc(schemas_0.ListNodesSummary$).build() {
      static {
        __name(this, "ListNodesSummaryCommand");
      }
    };
    var ListOpsItemEventsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "ListOpsItemEvents", {}).n("SSMClient", "ListOpsItemEventsCommand").sc(schemas_0.ListOpsItemEvents$).build() {
      static {
        __name(this, "ListOpsItemEventsCommand");
      }
    };
    var ListOpsItemRelatedItemsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "ListOpsItemRelatedItems", {}).n("SSMClient", "ListOpsItemRelatedItemsCommand").sc(schemas_0.ListOpsItemRelatedItems$).build() {
      static {
        __name(this, "ListOpsItemRelatedItemsCommand");
      }
    };
    var ListOpsMetadataCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "ListOpsMetadata", {}).n("SSMClient", "ListOpsMetadataCommand").sc(schemas_0.ListOpsMetadata$).build() {
      static {
        __name(this, "ListOpsMetadataCommand");
      }
    };
    var ListResourceComplianceSummariesCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "ListResourceComplianceSummaries", {}).n("SSMClient", "ListResourceComplianceSummariesCommand").sc(schemas_0.ListResourceComplianceSummaries$).build() {
      static {
        __name(this, "ListResourceComplianceSummariesCommand");
      }
    };
    var ListResourceDataSyncCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "ListResourceDataSync", {}).n("SSMClient", "ListResourceDataSyncCommand").sc(schemas_0.ListResourceDataSync$).build() {
      static {
        __name(this, "ListResourceDataSyncCommand");
      }
    };
    var ListTagsForResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "ListTagsForResource", {}).n("SSMClient", "ListTagsForResourceCommand").sc(schemas_0.ListTagsForResource$).build() {
      static {
        __name(this, "ListTagsForResourceCommand");
      }
    };
    var ModifyDocumentPermissionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "ModifyDocumentPermission", {}).n("SSMClient", "ModifyDocumentPermissionCommand").sc(schemas_0.ModifyDocumentPermission$).build() {
      static {
        __name(this, "ModifyDocumentPermissionCommand");
      }
    };
    var PutComplianceItemsCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "PutComplianceItems", {}).n("SSMClient", "PutComplianceItemsCommand").sc(schemas_0.PutComplianceItems$).build() {
      static {
        __name(this, "PutComplianceItemsCommand");
      }
    };
    var PutInventoryCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "PutInventory", {}).n("SSMClient", "PutInventoryCommand").sc(schemas_0.PutInventory$).build() {
      static {
        __name(this, "PutInventoryCommand");
      }
    };
    var PutParameterCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "PutParameter", {}).n("SSMClient", "PutParameterCommand").sc(schemas_0.PutParameter$).build() {
      static {
        __name(this, "PutParameterCommand");
      }
    };
    var PutResourcePolicyCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "PutResourcePolicy", {}).n("SSMClient", "PutResourcePolicyCommand").sc(schemas_0.PutResourcePolicy$).build() {
      static {
        __name(this, "PutResourcePolicyCommand");
      }
    };
    var RegisterDefaultPatchBaselineCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "RegisterDefaultPatchBaseline", {}).n("SSMClient", "RegisterDefaultPatchBaselineCommand").sc(schemas_0.RegisterDefaultPatchBaseline$).build() {
      static {
        __name(this, "RegisterDefaultPatchBaselineCommand");
      }
    };
    var RegisterPatchBaselineForPatchGroupCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "RegisterPatchBaselineForPatchGroup", {}).n("SSMClient", "RegisterPatchBaselineForPatchGroupCommand").sc(schemas_0.RegisterPatchBaselineForPatchGroup$).build() {
      static {
        __name(this, "RegisterPatchBaselineForPatchGroupCommand");
      }
    };
    var RegisterTargetWithMaintenanceWindowCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "RegisterTargetWithMaintenanceWindow", {}).n("SSMClient", "RegisterTargetWithMaintenanceWindowCommand").sc(schemas_0.RegisterTargetWithMaintenanceWindow$).build() {
      static {
        __name(this, "RegisterTargetWithMaintenanceWindowCommand");
      }
    };
    var RegisterTaskWithMaintenanceWindowCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "RegisterTaskWithMaintenanceWindow", {}).n("SSMClient", "RegisterTaskWithMaintenanceWindowCommand").sc(schemas_0.RegisterTaskWithMaintenanceWindow$).build() {
      static {
        __name(this, "RegisterTaskWithMaintenanceWindowCommand");
      }
    };
    var RemoveTagsFromResourceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "RemoveTagsFromResource", {}).n("SSMClient", "RemoveTagsFromResourceCommand").sc(schemas_0.RemoveTagsFromResource$).build() {
      static {
        __name(this, "RemoveTagsFromResourceCommand");
      }
    };
    var ResetServiceSettingCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "ResetServiceSetting", {}).n("SSMClient", "ResetServiceSettingCommand").sc(schemas_0.ResetServiceSetting$).build() {
      static {
        __name(this, "ResetServiceSettingCommand");
      }
    };
    var ResumeSessionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "ResumeSession", {}).n("SSMClient", "ResumeSessionCommand").sc(schemas_0.ResumeSession$).build() {
      static {
        __name(this, "ResumeSessionCommand");
      }
    };
    var SendAutomationSignalCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "SendAutomationSignal", {}).n("SSMClient", "SendAutomationSignalCommand").sc(schemas_0.SendAutomationSignal$).build() {
      static {
        __name(this, "SendAutomationSignalCommand");
      }
    };
    var SendCommandCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "SendCommand", {}).n("SSMClient", "SendCommandCommand").sc(schemas_0.SendCommand$).build() {
      static {
        __name(this, "SendCommandCommand");
      }
    };
    var StartAccessRequestCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "StartAccessRequest", {}).n("SSMClient", "StartAccessRequestCommand").sc(schemas_0.StartAccessRequest$).build() {
      static {
        __name(this, "StartAccessRequestCommand");
      }
    };
    var StartAssociationsOnceCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "StartAssociationsOnce", {}).n("SSMClient", "StartAssociationsOnceCommand").sc(schemas_0.StartAssociationsOnce$).build() {
      static {
        __name(this, "StartAssociationsOnceCommand");
      }
    };
    var StartAutomationExecutionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "StartAutomationExecution", {}).n("SSMClient", "StartAutomationExecutionCommand").sc(schemas_0.StartAutomationExecution$).build() {
      static {
        __name(this, "StartAutomationExecutionCommand");
      }
    };
    var StartChangeRequestExecutionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "StartChangeRequestExecution", {}).n("SSMClient", "StartChangeRequestExecutionCommand").sc(schemas_0.StartChangeRequestExecution$).build() {
      static {
        __name(this, "StartChangeRequestExecutionCommand");
      }
    };
    var StartExecutionPreviewCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "StartExecutionPreview", {}).n("SSMClient", "StartExecutionPreviewCommand").sc(schemas_0.StartExecutionPreview$).build() {
      static {
        __name(this, "StartExecutionPreviewCommand");
      }
    };
    var StartSessionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "StartSession", {}).n("SSMClient", "StartSessionCommand").sc(schemas_0.StartSession$).build() {
      static {
        __name(this, "StartSessionCommand");
      }
    };
    var StopAutomationExecutionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "StopAutomationExecution", {}).n("SSMClient", "StopAutomationExecutionCommand").sc(schemas_0.StopAutomationExecution$).build() {
      static {
        __name(this, "StopAutomationExecutionCommand");
      }
    };
    var TerminateSessionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "TerminateSession", {}).n("SSMClient", "TerminateSessionCommand").sc(schemas_0.TerminateSession$).build() {
      static {
        __name(this, "TerminateSessionCommand");
      }
    };
    var UnlabelParameterVersionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "UnlabelParameterVersion", {}).n("SSMClient", "UnlabelParameterVersionCommand").sc(schemas_0.UnlabelParameterVersion$).build() {
      static {
        __name(this, "UnlabelParameterVersionCommand");
      }
    };
    var UpdateAssociationCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "UpdateAssociation", {}).n("SSMClient", "UpdateAssociationCommand").sc(schemas_0.UpdateAssociation$).build() {
      static {
        __name(this, "UpdateAssociationCommand");
      }
    };
    var UpdateAssociationStatusCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "UpdateAssociationStatus", {}).n("SSMClient", "UpdateAssociationStatusCommand").sc(schemas_0.UpdateAssociationStatus$).build() {
      static {
        __name(this, "UpdateAssociationStatusCommand");
      }
    };
    var UpdateDocumentCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "UpdateDocument", {}).n("SSMClient", "UpdateDocumentCommand").sc(schemas_0.UpdateDocument$).build() {
      static {
        __name(this, "UpdateDocumentCommand");
      }
    };
    var UpdateDocumentDefaultVersionCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "UpdateDocumentDefaultVersion", {}).n("SSMClient", "UpdateDocumentDefaultVersionCommand").sc(schemas_0.UpdateDocumentDefaultVersion$).build() {
      static {
        __name(this, "UpdateDocumentDefaultVersionCommand");
      }
    };
    var UpdateDocumentMetadataCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "UpdateDocumentMetadata", {}).n("SSMClient", "UpdateDocumentMetadataCommand").sc(schemas_0.UpdateDocumentMetadata$).build() {
      static {
        __name(this, "UpdateDocumentMetadataCommand");
      }
    };
    var UpdateMaintenanceWindowCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "UpdateMaintenanceWindow", {}).n("SSMClient", "UpdateMaintenanceWindowCommand").sc(schemas_0.UpdateMaintenanceWindow$).build() {
      static {
        __name(this, "UpdateMaintenanceWindowCommand");
      }
    };
    var UpdateMaintenanceWindowTargetCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "UpdateMaintenanceWindowTarget", {}).n("SSMClient", "UpdateMaintenanceWindowTargetCommand").sc(schemas_0.UpdateMaintenanceWindowTarget$).build() {
      static {
        __name(this, "UpdateMaintenanceWindowTargetCommand");
      }
    };
    var UpdateMaintenanceWindowTaskCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "UpdateMaintenanceWindowTask", {}).n("SSMClient", "UpdateMaintenanceWindowTaskCommand").sc(schemas_0.UpdateMaintenanceWindowTask$).build() {
      static {
        __name(this, "UpdateMaintenanceWindowTaskCommand");
      }
    };
    var UpdateManagedInstanceRoleCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "UpdateManagedInstanceRole", {}).n("SSMClient", "UpdateManagedInstanceRoleCommand").sc(schemas_0.UpdateManagedInstanceRole$).build() {
      static {
        __name(this, "UpdateManagedInstanceRoleCommand");
      }
    };
    var UpdateOpsItemCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "UpdateOpsItem", {}).n("SSMClient", "UpdateOpsItemCommand").sc(schemas_0.UpdateOpsItem$).build() {
      static {
        __name(this, "UpdateOpsItemCommand");
      }
    };
    var UpdateOpsMetadataCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "UpdateOpsMetadata", {}).n("SSMClient", "UpdateOpsMetadataCommand").sc(schemas_0.UpdateOpsMetadata$).build() {
      static {
        __name(this, "UpdateOpsMetadataCommand");
      }
    };
    var UpdatePatchBaselineCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "UpdatePatchBaseline", {}).n("SSMClient", "UpdatePatchBaselineCommand").sc(schemas_0.UpdatePatchBaseline$).build() {
      static {
        __name(this, "UpdatePatchBaselineCommand");
      }
    };
    var UpdateResourceDataSyncCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "UpdateResourceDataSync", {}).n("SSMClient", "UpdateResourceDataSyncCommand").sc(schemas_0.UpdateResourceDataSync$).build() {
      static {
        __name(this, "UpdateResourceDataSyncCommand");
      }
    };
    var UpdateServiceSettingCommand = class extends smithyClient.Command.classBuilder().ep(commonParams32).m(function(Command3, cs, config2, o10) {
      return [middlewareEndpoint.getEndpointPlugin(config2, Command3.getEndpointParameterInstructions())];
    }).s("AmazonSSM", "UpdateServiceSetting", {}).n("SSMClient", "UpdateServiceSettingCommand").sc(schemas_0.UpdateServiceSetting$).build() {
      static {
        __name(this, "UpdateServiceSettingCommand");
      }
    };
    var paginateDescribeActivations = core.createPaginator(SSMClient2, DescribeActivationsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeAssociationExecutions = core.createPaginator(SSMClient2, DescribeAssociationExecutionsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeAssociationExecutionTargets = core.createPaginator(SSMClient2, DescribeAssociationExecutionTargetsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeAutomationExecutions = core.createPaginator(SSMClient2, DescribeAutomationExecutionsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeAutomationStepExecutions = core.createPaginator(SSMClient2, DescribeAutomationStepExecutionsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeAvailablePatches = core.createPaginator(SSMClient2, DescribeAvailablePatchesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeEffectiveInstanceAssociations = core.createPaginator(SSMClient2, DescribeEffectiveInstanceAssociationsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeEffectivePatchesForPatchBaseline = core.createPaginator(SSMClient2, DescribeEffectivePatchesForPatchBaselineCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeInstanceAssociationsStatus = core.createPaginator(SSMClient2, DescribeInstanceAssociationsStatusCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeInstanceInformation = core.createPaginator(SSMClient2, DescribeInstanceInformationCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeInstancePatches = core.createPaginator(SSMClient2, DescribeInstancePatchesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeInstancePatchStatesForPatchGroup = core.createPaginator(SSMClient2, DescribeInstancePatchStatesForPatchGroupCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeInstancePatchStates = core.createPaginator(SSMClient2, DescribeInstancePatchStatesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeInstanceProperties = core.createPaginator(SSMClient2, DescribeInstancePropertiesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeInventoryDeletions = core.createPaginator(SSMClient2, DescribeInventoryDeletionsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeMaintenanceWindowExecutions = core.createPaginator(SSMClient2, DescribeMaintenanceWindowExecutionsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeMaintenanceWindowExecutionTaskInvocations = core.createPaginator(SSMClient2, DescribeMaintenanceWindowExecutionTaskInvocationsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeMaintenanceWindowExecutionTasks = core.createPaginator(SSMClient2, DescribeMaintenanceWindowExecutionTasksCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeMaintenanceWindowSchedule = core.createPaginator(SSMClient2, DescribeMaintenanceWindowScheduleCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeMaintenanceWindowsForTarget = core.createPaginator(SSMClient2, DescribeMaintenanceWindowsForTargetCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeMaintenanceWindows = core.createPaginator(SSMClient2, DescribeMaintenanceWindowsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeMaintenanceWindowTargets = core.createPaginator(SSMClient2, DescribeMaintenanceWindowTargetsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeMaintenanceWindowTasks = core.createPaginator(SSMClient2, DescribeMaintenanceWindowTasksCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeOpsItems = core.createPaginator(SSMClient2, DescribeOpsItemsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeParameters = core.createPaginator(SSMClient2, DescribeParametersCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribePatchBaselines = core.createPaginator(SSMClient2, DescribePatchBaselinesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribePatchGroups = core.createPaginator(SSMClient2, DescribePatchGroupsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribePatchProperties = core.createPaginator(SSMClient2, DescribePatchPropertiesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateDescribeSessions = core.createPaginator(SSMClient2, DescribeSessionsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetInventory = core.createPaginator(SSMClient2, GetInventoryCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetInventorySchema = core.createPaginator(SSMClient2, GetInventorySchemaCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetOpsSummary = core.createPaginator(SSMClient2, GetOpsSummaryCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetParameterHistory = core.createPaginator(SSMClient2, GetParameterHistoryCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetParametersByPath = core.createPaginator(SSMClient2, GetParametersByPathCommand, "NextToken", "NextToken", "MaxResults");
    var paginateGetResourcePolicies = core.createPaginator(SSMClient2, GetResourcePoliciesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListAssociations = core.createPaginator(SSMClient2, ListAssociationsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListAssociationVersions = core.createPaginator(SSMClient2, ListAssociationVersionsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListCommandInvocations = core.createPaginator(SSMClient2, ListCommandInvocationsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListCommands = core.createPaginator(SSMClient2, ListCommandsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListComplianceItems = core.createPaginator(SSMClient2, ListComplianceItemsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListComplianceSummaries = core.createPaginator(SSMClient2, ListComplianceSummariesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListDocuments = core.createPaginator(SSMClient2, ListDocumentsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListDocumentVersions = core.createPaginator(SSMClient2, ListDocumentVersionsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListNodes = core.createPaginator(SSMClient2, ListNodesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListNodesSummary = core.createPaginator(SSMClient2, ListNodesSummaryCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListOpsItemEvents = core.createPaginator(SSMClient2, ListOpsItemEventsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListOpsItemRelatedItems = core.createPaginator(SSMClient2, ListOpsItemRelatedItemsCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListOpsMetadata = core.createPaginator(SSMClient2, ListOpsMetadataCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListResourceComplianceSummaries = core.createPaginator(SSMClient2, ListResourceComplianceSummariesCommand, "NextToken", "NextToken", "MaxResults");
    var paginateListResourceDataSync = core.createPaginator(SSMClient2, ListResourceDataSyncCommand, "NextToken", "NextToken", "MaxResults");
    var checkState = /* @__PURE__ */ __name(async (client, input) => {
      let reason;
      try {
        let result2 = await client.send(new GetCommandInvocationCommand(input));
        reason = result2;
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.Status;
          }, "returnComparator");
          if (returnComparator() === "Pending") {
            return { state: utilWaiter.WaiterState.RETRY, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.Status;
          }, "returnComparator");
          if (returnComparator() === "InProgress") {
            return { state: utilWaiter.WaiterState.RETRY, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.Status;
          }, "returnComparator");
          if (returnComparator() === "Delayed") {
            return { state: utilWaiter.WaiterState.RETRY, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.Status;
          }, "returnComparator");
          if (returnComparator() === "Success") {
            return { state: utilWaiter.WaiterState.SUCCESS, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.Status;
          }, "returnComparator");
          if (returnComparator() === "Cancelled") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.Status;
          }, "returnComparator");
          if (returnComparator() === "TimedOut") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.Status;
          }, "returnComparator");
          if (returnComparator() === "Failed") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
        try {
          const returnComparator = /* @__PURE__ */ __name(() => {
            return result2.Status;
          }, "returnComparator");
          if (returnComparator() === "Cancelling") {
            return { state: utilWaiter.WaiterState.FAILURE, reason };
          }
        } catch (e32) {
        }
      } catch (exception) {
        reason = exception;
        if (exception.name === "InvocationDoesNotExist") {
          return { state: utilWaiter.WaiterState.RETRY, reason };
        }
      }
      return { state: utilWaiter.WaiterState.RETRY, reason };
    }, "checkState");
    var waitForCommandExecuted = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      return utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState);
    }, "waitForCommandExecuted");
    var waitUntilCommandExecuted = /* @__PURE__ */ __name(async (params, input) => {
      const serviceDefaults = { minDelay: 5, maxDelay: 120 };
      const result2 = await utilWaiter.createWaiter({ ...serviceDefaults, ...params }, input, checkState);
      return utilWaiter.checkExceptions(result2);
    }, "waitUntilCommandExecuted");
    var commands32 = {
      AddTagsToResourceCommand,
      AssociateOpsItemRelatedItemCommand,
      CancelCommandCommand,
      CancelMaintenanceWindowExecutionCommand,
      CreateActivationCommand,
      CreateAssociationCommand,
      CreateAssociationBatchCommand,
      CreateDocumentCommand,
      CreateMaintenanceWindowCommand,
      CreateOpsItemCommand,
      CreateOpsMetadataCommand,
      CreatePatchBaselineCommand,
      CreateResourceDataSyncCommand,
      DeleteActivationCommand,
      DeleteAssociationCommand,
      DeleteDocumentCommand,
      DeleteInventoryCommand,
      DeleteMaintenanceWindowCommand,
      DeleteOpsItemCommand,
      DeleteOpsMetadataCommand,
      DeleteParameterCommand,
      DeleteParametersCommand,
      DeletePatchBaselineCommand,
      DeleteResourceDataSyncCommand,
      DeleteResourcePolicyCommand,
      DeregisterManagedInstanceCommand,
      DeregisterPatchBaselineForPatchGroupCommand,
      DeregisterTargetFromMaintenanceWindowCommand,
      DeregisterTaskFromMaintenanceWindowCommand,
      DescribeActivationsCommand,
      DescribeAssociationCommand,
      DescribeAssociationExecutionsCommand,
      DescribeAssociationExecutionTargetsCommand,
      DescribeAutomationExecutionsCommand,
      DescribeAutomationStepExecutionsCommand,
      DescribeAvailablePatchesCommand,
      DescribeDocumentCommand,
      DescribeDocumentPermissionCommand,
      DescribeEffectiveInstanceAssociationsCommand,
      DescribeEffectivePatchesForPatchBaselineCommand,
      DescribeInstanceAssociationsStatusCommand,
      DescribeInstanceInformationCommand,
      DescribeInstancePatchesCommand,
      DescribeInstancePatchStatesCommand,
      DescribeInstancePatchStatesForPatchGroupCommand,
      DescribeInstancePropertiesCommand,
      DescribeInventoryDeletionsCommand,
      DescribeMaintenanceWindowExecutionsCommand,
      DescribeMaintenanceWindowExecutionTaskInvocationsCommand,
      DescribeMaintenanceWindowExecutionTasksCommand,
      DescribeMaintenanceWindowsCommand,
      DescribeMaintenanceWindowScheduleCommand,
      DescribeMaintenanceWindowsForTargetCommand,
      DescribeMaintenanceWindowTargetsCommand,
      DescribeMaintenanceWindowTasksCommand,
      DescribeOpsItemsCommand,
      DescribeParametersCommand,
      DescribePatchBaselinesCommand,
      DescribePatchGroupsCommand,
      DescribePatchGroupStateCommand,
      DescribePatchPropertiesCommand,
      DescribeSessionsCommand,
      DisassociateOpsItemRelatedItemCommand,
      GetAccessTokenCommand,
      GetAutomationExecutionCommand,
      GetCalendarStateCommand,
      GetCommandInvocationCommand,
      GetConnectionStatusCommand,
      GetDefaultPatchBaselineCommand,
      GetDeployablePatchSnapshotForInstanceCommand,
      GetDocumentCommand,
      GetExecutionPreviewCommand,
      GetInventoryCommand,
      GetInventorySchemaCommand,
      GetMaintenanceWindowCommand,
      GetMaintenanceWindowExecutionCommand,
      GetMaintenanceWindowExecutionTaskCommand,
      GetMaintenanceWindowExecutionTaskInvocationCommand,
      GetMaintenanceWindowTaskCommand,
      GetOpsItemCommand,
      GetOpsMetadataCommand,
      GetOpsSummaryCommand,
      GetParameterCommand: GetParameterCommand2,
      GetParameterHistoryCommand,
      GetParametersCommand,
      GetParametersByPathCommand,
      GetPatchBaselineCommand,
      GetPatchBaselineForPatchGroupCommand,
      GetResourcePoliciesCommand,
      GetServiceSettingCommand,
      LabelParameterVersionCommand,
      ListAssociationsCommand,
      ListAssociationVersionsCommand,
      ListCommandInvocationsCommand,
      ListCommandsCommand,
      ListComplianceItemsCommand,
      ListComplianceSummariesCommand,
      ListDocumentMetadataHistoryCommand,
      ListDocumentsCommand,
      ListDocumentVersionsCommand,
      ListInventoryEntriesCommand,
      ListNodesCommand,
      ListNodesSummaryCommand,
      ListOpsItemEventsCommand,
      ListOpsItemRelatedItemsCommand,
      ListOpsMetadataCommand,
      ListResourceComplianceSummariesCommand,
      ListResourceDataSyncCommand,
      ListTagsForResourceCommand,
      ModifyDocumentPermissionCommand,
      PutComplianceItemsCommand,
      PutInventoryCommand,
      PutParameterCommand,
      PutResourcePolicyCommand,
      RegisterDefaultPatchBaselineCommand,
      RegisterPatchBaselineForPatchGroupCommand,
      RegisterTargetWithMaintenanceWindowCommand,
      RegisterTaskWithMaintenanceWindowCommand,
      RemoveTagsFromResourceCommand,
      ResetServiceSettingCommand,
      ResumeSessionCommand,
      SendAutomationSignalCommand,
      SendCommandCommand,
      StartAccessRequestCommand,
      StartAssociationsOnceCommand,
      StartAutomationExecutionCommand,
      StartChangeRequestExecutionCommand,
      StartExecutionPreviewCommand,
      StartSessionCommand,
      StopAutomationExecutionCommand,
      TerminateSessionCommand,
      UnlabelParameterVersionCommand,
      UpdateAssociationCommand,
      UpdateAssociationStatusCommand,
      UpdateDocumentCommand,
      UpdateDocumentDefaultVersionCommand,
      UpdateDocumentMetadataCommand,
      UpdateMaintenanceWindowCommand,
      UpdateMaintenanceWindowTargetCommand,
      UpdateMaintenanceWindowTaskCommand,
      UpdateManagedInstanceRoleCommand,
      UpdateOpsItemCommand,
      UpdateOpsMetadataCommand,
      UpdatePatchBaselineCommand,
      UpdateResourceDataSyncCommand,
      UpdateServiceSettingCommand
    };
    var paginators = {
      paginateDescribeActivations,
      paginateDescribeAssociationExecutions,
      paginateDescribeAssociationExecutionTargets,
      paginateDescribeAutomationExecutions,
      paginateDescribeAutomationStepExecutions,
      paginateDescribeAvailablePatches,
      paginateDescribeEffectiveInstanceAssociations,
      paginateDescribeEffectivePatchesForPatchBaseline,
      paginateDescribeInstanceAssociationsStatus,
      paginateDescribeInstanceInformation,
      paginateDescribeInstancePatches,
      paginateDescribeInstancePatchStates,
      paginateDescribeInstancePatchStatesForPatchGroup,
      paginateDescribeInstanceProperties,
      paginateDescribeInventoryDeletions,
      paginateDescribeMaintenanceWindowExecutions,
      paginateDescribeMaintenanceWindowExecutionTaskInvocations,
      paginateDescribeMaintenanceWindowExecutionTasks,
      paginateDescribeMaintenanceWindows,
      paginateDescribeMaintenanceWindowSchedule,
      paginateDescribeMaintenanceWindowsForTarget,
      paginateDescribeMaintenanceWindowTargets,
      paginateDescribeMaintenanceWindowTasks,
      paginateDescribeOpsItems,
      paginateDescribeParameters,
      paginateDescribePatchBaselines,
      paginateDescribePatchGroups,
      paginateDescribePatchProperties,
      paginateDescribeSessions,
      paginateGetInventory,
      paginateGetInventorySchema,
      paginateGetOpsSummary,
      paginateGetParameterHistory,
      paginateGetParametersByPath,
      paginateGetResourcePolicies,
      paginateListAssociations,
      paginateListAssociationVersions,
      paginateListCommandInvocations,
      paginateListCommands,
      paginateListComplianceItems,
      paginateListComplianceSummaries,
      paginateListDocuments,
      paginateListDocumentVersions,
      paginateListNodes,
      paginateListNodesSummary,
      paginateListOpsItemEvents,
      paginateListOpsItemRelatedItems,
      paginateListOpsMetadata,
      paginateListResourceComplianceSummaries,
      paginateListResourceDataSync
    };
    var waiters = {
      waitUntilCommandExecuted
    };
    var SSM = class extends SSMClient2 {
      static {
        __name(this, "SSM");
      }
    };
    smithyClient.createAggregatedClient(commands32, SSM, { paginators, waiters });
    var AccessRequestStatus = {
      APPROVED: "Approved",
      EXPIRED: "Expired",
      PENDING: "Pending",
      REJECTED: "Rejected",
      REVOKED: "Revoked"
    };
    var AccessType = {
      JUSTINTIME: "JustInTime",
      STANDARD: "Standard"
    };
    var ResourceTypeForTagging = {
      ASSOCIATION: "Association",
      AUTOMATION: "Automation",
      DOCUMENT: "Document",
      MAINTENANCE_WINDOW: "MaintenanceWindow",
      MANAGED_INSTANCE: "ManagedInstance",
      OPSMETADATA: "OpsMetadata",
      OPS_ITEM: "OpsItem",
      PARAMETER: "Parameter",
      PATCH_BASELINE: "PatchBaseline"
    };
    var ExternalAlarmState = {
      ALARM: "ALARM",
      UNKNOWN: "UNKNOWN"
    };
    var AssociationComplianceSeverity = {
      Critical: "CRITICAL",
      High: "HIGH",
      Low: "LOW",
      Medium: "MEDIUM",
      Unspecified: "UNSPECIFIED"
    };
    var AssociationSyncCompliance = {
      Auto: "AUTO",
      Manual: "MANUAL"
    };
    var AssociationStatusName = {
      Failed: "Failed",
      Pending: "Pending",
      Success: "Success"
    };
    var Fault = {
      Client: "Client",
      Server: "Server",
      Unknown: "Unknown"
    };
    var AttachmentsSourceKey = {
      AttachmentReference: "AttachmentReference",
      S3FileUrl: "S3FileUrl",
      SourceUrl: "SourceUrl"
    };
    var DocumentFormat = {
      JSON: "JSON",
      TEXT: "TEXT",
      YAML: "YAML"
    };
    var DocumentType = {
      ApplicationConfiguration: "ApplicationConfiguration",
      ApplicationConfigurationSchema: "ApplicationConfigurationSchema",
      AutoApprovalPolicy: "AutoApprovalPolicy",
      Automation: "Automation",
      ChangeCalendar: "ChangeCalendar",
      ChangeTemplate: "Automation.ChangeTemplate",
      CloudFormation: "CloudFormation",
      Command: "Command",
      ConformancePackTemplate: "ConformancePackTemplate",
      DeploymentStrategy: "DeploymentStrategy",
      ManualApprovalPolicy: "ManualApprovalPolicy",
      Package: "Package",
      Policy: "Policy",
      ProblemAnalysis: "ProblemAnalysis",
      ProblemAnalysisTemplate: "ProblemAnalysisTemplate",
      QuickSetup: "QuickSetup",
      Session: "Session"
    };
    var DocumentHashType = {
      SHA1: "Sha1",
      SHA256: "Sha256"
    };
    var DocumentParameterType = {
      String: "String",
      StringList: "StringList"
    };
    var PlatformType = {
      LINUX: "Linux",
      MACOS: "MacOS",
      WINDOWS: "Windows"
    };
    var ReviewStatus = {
      APPROVED: "APPROVED",
      NOT_REVIEWED: "NOT_REVIEWED",
      PENDING: "PENDING",
      REJECTED: "REJECTED"
    };
    var DocumentStatus = {
      Active: "Active",
      Creating: "Creating",
      Deleting: "Deleting",
      Failed: "Failed",
      Updating: "Updating"
    };
    var OpsItemDataType = {
      SEARCHABLE_STRING: "SearchableString",
      STRING: "String"
    };
    var PatchComplianceLevel = {
      Critical: "CRITICAL",
      High: "HIGH",
      Informational: "INFORMATIONAL",
      Low: "LOW",
      Medium: "MEDIUM",
      Unspecified: "UNSPECIFIED"
    };
    var PatchFilterKey = {
      AdvisoryId: "ADVISORY_ID",
      Arch: "ARCH",
      BugzillaId: "BUGZILLA_ID",
      CVEId: "CVE_ID",
      Classification: "CLASSIFICATION",
      Epoch: "EPOCH",
      MsrcSeverity: "MSRC_SEVERITY",
      Name: "NAME",
      PatchId: "PATCH_ID",
      PatchSet: "PATCH_SET",
      Priority: "PRIORITY",
      Product: "PRODUCT",
      ProductFamily: "PRODUCT_FAMILY",
      Release: "RELEASE",
      Repository: "REPOSITORY",
      Section: "SECTION",
      Security: "SECURITY",
      Severity: "SEVERITY",
      Version: "VERSION"
    };
    var PatchComplianceStatus = {
      Compliant: "COMPLIANT",
      NonCompliant: "NON_COMPLIANT"
    };
    var OperatingSystem = {
      AlmaLinux: "ALMA_LINUX",
      AmazonLinux: "AMAZON_LINUX",
      AmazonLinux2: "AMAZON_LINUX_2",
      AmazonLinux2022: "AMAZON_LINUX_2022",
      AmazonLinux2023: "AMAZON_LINUX_2023",
      CentOS: "CENTOS",
      Debian: "DEBIAN",
      MacOS: "MACOS",
      OracleLinux: "ORACLE_LINUX",
      Raspbian: "RASPBIAN",
      RedhatEnterpriseLinux: "REDHAT_ENTERPRISE_LINUX",
      Rocky_Linux: "ROCKY_LINUX",
      Suse: "SUSE",
      Ubuntu: "UBUNTU",
      Windows: "WINDOWS"
    };
    var PatchAction = {
      AllowAsDependency: "ALLOW_AS_DEPENDENCY",
      Block: "BLOCK"
    };
    var ResourceDataSyncS3Format = {
      JSON_SERDE: "JsonSerDe"
    };
    var InventorySchemaDeleteOption = {
      DELETE_SCHEMA: "DeleteSchema",
      DISABLE_SCHEMA: "DisableSchema"
    };
    var DescribeActivationsFilterKeys = {
      ACTIVATION_IDS: "ActivationIds",
      DEFAULT_INSTANCE_NAME: "DefaultInstanceName",
      IAM_ROLE: "IamRole"
    };
    var AssociationExecutionFilterKey = {
      CreatedTime: "CreatedTime",
      ExecutionId: "ExecutionId",
      Status: "Status"
    };
    var AssociationFilterOperatorType = {
      Equal: "EQUAL",
      GreaterThan: "GREATER_THAN",
      LessThan: "LESS_THAN"
    };
    var AssociationExecutionTargetsFilterKey = {
      ResourceId: "ResourceId",
      ResourceType: "ResourceType",
      Status: "Status"
    };
    var AutomationExecutionFilterKey = {
      AUTOMATION_SUBTYPE: "AutomationSubtype",
      AUTOMATION_TYPE: "AutomationType",
      CURRENT_ACTION: "CurrentAction",
      DOCUMENT_NAME_PREFIX: "DocumentNamePrefix",
      EXECUTION_ID: "ExecutionId",
      EXECUTION_STATUS: "ExecutionStatus",
      OPS_ITEM_ID: "OpsItemId",
      PARENT_EXECUTION_ID: "ParentExecutionId",
      START_TIME_AFTER: "StartTimeAfter",
      START_TIME_BEFORE: "StartTimeBefore",
      TAG_KEY: "TagKey",
      TARGET_RESOURCE_GROUP: "TargetResourceGroup"
    };
    var AutomationExecutionStatus = {
      APPROVED: "Approved",
      CANCELLED: "Cancelled",
      CANCELLING: "Cancelling",
      CHANGE_CALENDAR_OVERRIDE_APPROVED: "ChangeCalendarOverrideApproved",
      CHANGE_CALENDAR_OVERRIDE_REJECTED: "ChangeCalendarOverrideRejected",
      COMPLETED_WITH_FAILURE: "CompletedWithFailure",
      COMPLETED_WITH_SUCCESS: "CompletedWithSuccess",
      EXITED: "Exited",
      FAILED: "Failed",
      INPROGRESS: "InProgress",
      PENDING: "Pending",
      PENDING_APPROVAL: "PendingApproval",
      PENDING_CHANGE_CALENDAR_OVERRIDE: "PendingChangeCalendarOverride",
      REJECTED: "Rejected",
      RUNBOOK_INPROGRESS: "RunbookInProgress",
      SCHEDULED: "Scheduled",
      SUCCESS: "Success",
      TIMEDOUT: "TimedOut",
      WAITING: "Waiting"
    };
    var AutomationSubtype = {
      AccessRequest: "AccessRequest",
      ChangeRequest: "ChangeRequest"
    };
    var AutomationType = {
      CrossAccount: "CrossAccount",
      Local: "Local"
    };
    var ExecutionMode = {
      Auto: "Auto",
      Interactive: "Interactive"
    };
    var StepExecutionFilterKey = {
      ACTION: "Action",
      PARENT_STEP_EXECUTION_ID: "ParentStepExecutionId",
      PARENT_STEP_ITERATION: "ParentStepIteration",
      PARENT_STEP_ITERATOR_VALUE: "ParentStepIteratorValue",
      START_TIME_AFTER: "StartTimeAfter",
      START_TIME_BEFORE: "StartTimeBefore",
      STEP_EXECUTION_ID: "StepExecutionId",
      STEP_EXECUTION_STATUS: "StepExecutionStatus",
      STEP_NAME: "StepName"
    };
    var DocumentPermissionType = {
      SHARE: "Share"
    };
    var PatchDeploymentStatus = {
      Approved: "APPROVED",
      ExplicitApproved: "EXPLICIT_APPROVED",
      ExplicitRejected: "EXPLICIT_REJECTED",
      PendingApproval: "PENDING_APPROVAL"
    };
    var InstanceInformationFilterKey = {
      ACTIVATION_IDS: "ActivationIds",
      AGENT_VERSION: "AgentVersion",
      ASSOCIATION_STATUS: "AssociationStatus",
      IAM_ROLE: "IamRole",
      INSTANCE_IDS: "InstanceIds",
      PING_STATUS: "PingStatus",
      PLATFORM_TYPES: "PlatformTypes",
      RESOURCE_TYPE: "ResourceType"
    };
    var PingStatus = {
      CONNECTION_LOST: "ConnectionLost",
      INACTIVE: "Inactive",
      ONLINE: "Online"
    };
    var ResourceType = {
      EC2_INSTANCE: "EC2Instance",
      MANAGED_INSTANCE: "ManagedInstance"
    };
    var SourceType = {
      AWS_EC2_INSTANCE: "AWS::EC2::Instance",
      AWS_IOT_THING: "AWS::IoT::Thing",
      AWS_SSM_MANAGEDINSTANCE: "AWS::SSM::ManagedInstance"
    };
    var PatchComplianceDataState = {
      AvailableSecurityUpdate: "AVAILABLE_SECURITY_UPDATE",
      Failed: "FAILED",
      Installed: "INSTALLED",
      InstalledOther: "INSTALLED_OTHER",
      InstalledPendingReboot: "INSTALLED_PENDING_REBOOT",
      InstalledRejected: "INSTALLED_REJECTED",
      Missing: "MISSING",
      NotApplicable: "NOT_APPLICABLE"
    };
    var PatchOperationType = {
      INSTALL: "Install",
      SCAN: "Scan"
    };
    var RebootOption = {
      NO_REBOOT: "NoReboot",
      REBOOT_IF_NEEDED: "RebootIfNeeded"
    };
    var InstancePatchStateOperatorType = {
      EQUAL: "Equal",
      GREATER_THAN: "GreaterThan",
      LESS_THAN: "LessThan",
      NOT_EQUAL: "NotEqual"
    };
    var InstancePropertyFilterOperator = {
      BEGIN_WITH: "BeginWith",
      EQUAL: "Equal",
      GREATER_THAN: "GreaterThan",
      LESS_THAN: "LessThan",
      NOT_EQUAL: "NotEqual"
    };
    var InstancePropertyFilterKey = {
      ACTIVATION_IDS: "ActivationIds",
      AGENT_VERSION: "AgentVersion",
      ASSOCIATION_STATUS: "AssociationStatus",
      DOCUMENT_NAME: "DocumentName",
      IAM_ROLE: "IamRole",
      INSTANCE_IDS: "InstanceIds",
      PING_STATUS: "PingStatus",
      PLATFORM_TYPES: "PlatformTypes",
      RESOURCE_TYPE: "ResourceType"
    };
    var InventoryDeletionStatus = {
      COMPLETE: "Complete",
      IN_PROGRESS: "InProgress"
    };
    var MaintenanceWindowExecutionStatus = {
      Cancelled: "CANCELLED",
      Cancelling: "CANCELLING",
      Failed: "FAILED",
      InProgress: "IN_PROGRESS",
      Pending: "PENDING",
      SkippedOverlapping: "SKIPPED_OVERLAPPING",
      Success: "SUCCESS",
      TimedOut: "TIMED_OUT"
    };
    var MaintenanceWindowTaskType = {
      Automation: "AUTOMATION",
      Lambda: "LAMBDA",
      RunCommand: "RUN_COMMAND",
      StepFunctions: "STEP_FUNCTIONS"
    };
    var MaintenanceWindowResourceType = {
      Instance: "INSTANCE",
      ResourceGroup: "RESOURCE_GROUP"
    };
    var MaintenanceWindowTaskCutoffBehavior = {
      CancelTask: "CANCEL_TASK",
      ContinueTask: "CONTINUE_TASK"
    };
    var OpsItemFilterKey = {
      ACCESS_REQUEST_APPROVER_ARN: "AccessRequestByApproverArn",
      ACCESS_REQUEST_APPROVER_ID: "AccessRequestByApproverId",
      ACCESS_REQUEST_IS_REPLICA: "AccessRequestByIsReplica",
      ACCESS_REQUEST_REQUESTER_ARN: "AccessRequestByRequesterArn",
      ACCESS_REQUEST_REQUESTER_ID: "AccessRequestByRequesterId",
      ACCESS_REQUEST_SOURCE_ACCOUNT_ID: "AccessRequestBySourceAccountId",
      ACCESS_REQUEST_SOURCE_OPS_ITEM_ID: "AccessRequestBySourceOpsItemId",
      ACCESS_REQUEST_SOURCE_REGION: "AccessRequestBySourceRegion",
      ACCESS_REQUEST_TARGET_RESOURCE_ID: "AccessRequestByTargetResourceId",
      ACCOUNT_ID: "AccountId",
      ACTUAL_END_TIME: "ActualEndTime",
      ACTUAL_START_TIME: "ActualStartTime",
      AUTOMATION_ID: "AutomationId",
      CATEGORY: "Category",
      CHANGE_REQUEST_APPROVER_ARN: "ChangeRequestByApproverArn",
      CHANGE_REQUEST_APPROVER_NAME: "ChangeRequestByApproverName",
      CHANGE_REQUEST_REQUESTER_ARN: "ChangeRequestByRequesterArn",
      CHANGE_REQUEST_REQUESTER_NAME: "ChangeRequestByRequesterName",
      CHANGE_REQUEST_TARGETS_RESOURCE_GROUP: "ChangeRequestByTargetsResourceGroup",
      CHANGE_REQUEST_TEMPLATE: "ChangeRequestByTemplate",
      CREATED_BY: "CreatedBy",
      CREATED_TIME: "CreatedTime",
      INSIGHT_TYPE: "InsightByType",
      LAST_MODIFIED_TIME: "LastModifiedTime",
      OPERATIONAL_DATA: "OperationalData",
      OPERATIONAL_DATA_KEY: "OperationalDataKey",
      OPERATIONAL_DATA_VALUE: "OperationalDataValue",
      OPSITEM_ID: "OpsItemId",
      OPSITEM_TYPE: "OpsItemType",
      PLANNED_END_TIME: "PlannedEndTime",
      PLANNED_START_TIME: "PlannedStartTime",
      PRIORITY: "Priority",
      RESOURCE_ID: "ResourceId",
      SEVERITY: "Severity",
      SOURCE: "Source",
      STATUS: "Status",
      TITLE: "Title"
    };
    var OpsItemFilterOperator = {
      CONTAINS: "Contains",
      EQUAL: "Equal",
      GREATER_THAN: "GreaterThan",
      LESS_THAN: "LessThan"
    };
    var OpsItemStatus = {
      APPROVED: "Approved",
      CANCELLED: "Cancelled",
      CANCELLING: "Cancelling",
      CHANGE_CALENDAR_OVERRIDE_APPROVED: "ChangeCalendarOverrideApproved",
      CHANGE_CALENDAR_OVERRIDE_REJECTED: "ChangeCalendarOverrideRejected",
      CLOSED: "Closed",
      COMPLETED_WITH_FAILURE: "CompletedWithFailure",
      COMPLETED_WITH_SUCCESS: "CompletedWithSuccess",
      FAILED: "Failed",
      IN_PROGRESS: "InProgress",
      OPEN: "Open",
      PENDING: "Pending",
      PENDING_APPROVAL: "PendingApproval",
      PENDING_CHANGE_CALENDAR_OVERRIDE: "PendingChangeCalendarOverride",
      REJECTED: "Rejected",
      RESOLVED: "Resolved",
      REVOKED: "Revoked",
      RUNBOOK_IN_PROGRESS: "RunbookInProgress",
      SCHEDULED: "Scheduled",
      TIMED_OUT: "TimedOut"
    };
    var ParametersFilterKey = {
      KEY_ID: "KeyId",
      NAME: "Name",
      TYPE: "Type"
    };
    var ParameterTier = {
      ADVANCED: "Advanced",
      INTELLIGENT_TIERING: "Intelligent-Tiering",
      STANDARD: "Standard"
    };
    var ParameterType = {
      SECURE_STRING: "SecureString",
      STRING: "String",
      STRING_LIST: "StringList"
    };
    var PatchSet = {
      Application: "APPLICATION",
      Os: "OS"
    };
    var PatchProperty = {
      PatchClassification: "CLASSIFICATION",
      PatchMsrcSeverity: "MSRC_SEVERITY",
      PatchPriority: "PRIORITY",
      PatchProductFamily: "PRODUCT_FAMILY",
      PatchSeverity: "SEVERITY",
      Product: "PRODUCT"
    };
    var SessionFilterKey = {
      ACCESS_TYPE: "AccessType",
      INVOKED_AFTER: "InvokedAfter",
      INVOKED_BEFORE: "InvokedBefore",
      OWNER: "Owner",
      SESSION_ID: "SessionId",
      STATUS: "Status",
      TARGET_ID: "Target"
    };
    var SessionState = {
      ACTIVE: "Active",
      HISTORY: "History"
    };
    var SessionStatus = {
      CONNECTED: "Connected",
      CONNECTING: "Connecting",
      DISCONNECTED: "Disconnected",
      FAILED: "Failed",
      TERMINATED: "Terminated",
      TERMINATING: "Terminating"
    };
    var CalendarState = {
      CLOSED: "CLOSED",
      OPEN: "OPEN"
    };
    var CommandInvocationStatus = {
      CANCELLED: "Cancelled",
      CANCELLING: "Cancelling",
      DELAYED: "Delayed",
      FAILED: "Failed",
      IN_PROGRESS: "InProgress",
      PENDING: "Pending",
      SUCCESS: "Success",
      TIMED_OUT: "TimedOut"
    };
    var ConnectionStatus = {
      CONNECTED: "connected",
      NOT_CONNECTED: "notconnected"
    };
    var AttachmentHashType = {
      SHA256: "Sha256"
    };
    var ImpactType = {
      MUTATING: "Mutating",
      NON_MUTATING: "NonMutating",
      UNDETERMINED: "Undetermined"
    };
    var ExecutionPreviewStatus = {
      FAILED: "Failed",
      IN_PROGRESS: "InProgress",
      PENDING: "Pending",
      SUCCESS: "Success"
    };
    var InventoryQueryOperatorType = {
      BEGIN_WITH: "BeginWith",
      EQUAL: "Equal",
      EXISTS: "Exists",
      GREATER_THAN: "GreaterThan",
      LESS_THAN: "LessThan",
      NOT_EQUAL: "NotEqual"
    };
    var InventoryAttributeDataType = {
      NUMBER: "number",
      STRING: "string"
    };
    var NotificationEvent = {
      ALL: "All",
      CANCELLED: "Cancelled",
      FAILED: "Failed",
      IN_PROGRESS: "InProgress",
      SUCCESS: "Success",
      TIMED_OUT: "TimedOut"
    };
    var NotificationType = {
      Command: "Command",
      Invocation: "Invocation"
    };
    var OpsFilterOperatorType = {
      BEGIN_WITH: "BeginWith",
      EQUAL: "Equal",
      EXISTS: "Exists",
      GREATER_THAN: "GreaterThan",
      LESS_THAN: "LessThan",
      NOT_EQUAL: "NotEqual"
    };
    var AssociationFilterKey = {
      AssociationId: "AssociationId",
      AssociationName: "AssociationName",
      InstanceId: "InstanceId",
      LastExecutedAfter: "LastExecutedAfter",
      LastExecutedBefore: "LastExecutedBefore",
      Name: "Name",
      ResourceGroupName: "ResourceGroupName",
      Status: "AssociationStatusName"
    };
    var CommandFilterKey = {
      DOCUMENT_NAME: "DocumentName",
      EXECUTION_STAGE: "ExecutionStage",
      INVOKED_AFTER: "InvokedAfter",
      INVOKED_BEFORE: "InvokedBefore",
      STATUS: "Status"
    };
    var CommandPluginStatus = {
      CANCELLED: "Cancelled",
      FAILED: "Failed",
      IN_PROGRESS: "InProgress",
      PENDING: "Pending",
      SUCCESS: "Success",
      TIMED_OUT: "TimedOut"
    };
    var CommandStatus = {
      CANCELLED: "Cancelled",
      CANCELLING: "Cancelling",
      FAILED: "Failed",
      IN_PROGRESS: "InProgress",
      PENDING: "Pending",
      SUCCESS: "Success",
      TIMED_OUT: "TimedOut"
    };
    var ComplianceQueryOperatorType = {
      BeginWith: "BEGIN_WITH",
      Equal: "EQUAL",
      GreaterThan: "GREATER_THAN",
      LessThan: "LESS_THAN",
      NotEqual: "NOT_EQUAL"
    };
    var ComplianceSeverity = {
      Critical: "CRITICAL",
      High: "HIGH",
      Informational: "INFORMATIONAL",
      Low: "LOW",
      Medium: "MEDIUM",
      Unspecified: "UNSPECIFIED"
    };
    var ComplianceStatus = {
      Compliant: "COMPLIANT",
      NonCompliant: "NON_COMPLIANT"
    };
    var DocumentMetadataEnum = {
      DocumentReviews: "DocumentReviews"
    };
    var DocumentReviewCommentType = {
      Comment: "Comment"
    };
    var DocumentFilterKey = {
      DocumentType: "DocumentType",
      Name: "Name",
      Owner: "Owner",
      PlatformTypes: "PlatformTypes"
    };
    var NodeFilterKey = {
      ACCOUNT_ID: "AccountId",
      AGENT_TYPE: "AgentType",
      AGENT_VERSION: "AgentVersion",
      COMPUTER_NAME: "ComputerName",
      INSTANCE_ID: "InstanceId",
      INSTANCE_STATUS: "InstanceStatus",
      IP_ADDRESS: "IpAddress",
      MANAGED_STATUS: "ManagedStatus",
      ORGANIZATIONAL_UNIT_ID: "OrganizationalUnitId",
      ORGANIZATIONAL_UNIT_PATH: "OrganizationalUnitPath",
      PLATFORM_NAME: "PlatformName",
      PLATFORM_TYPE: "PlatformType",
      PLATFORM_VERSION: "PlatformVersion",
      REGION: "Region",
      RESOURCE_TYPE: "ResourceType"
    };
    var NodeFilterOperatorType = {
      BEGIN_WITH: "BeginWith",
      EQUAL: "Equal",
      NOT_EQUAL: "NotEqual"
    };
    var ManagedStatus = {
      ALL: "All",
      MANAGED: "Managed",
      UNMANAGED: "Unmanaged"
    };
    var NodeAggregatorType = {
      COUNT: "Count"
    };
    var NodeAttributeName = {
      AGENT_VERSION: "AgentVersion",
      PLATFORM_NAME: "PlatformName",
      PLATFORM_TYPE: "PlatformType",
      PLATFORM_VERSION: "PlatformVersion",
      REGION: "Region",
      RESOURCE_TYPE: "ResourceType"
    };
    var NodeTypeName = {
      INSTANCE: "Instance"
    };
    var OpsItemEventFilterKey = {
      OPSITEM_ID: "OpsItemId"
    };
    var OpsItemEventFilterOperator = {
      EQUAL: "Equal"
    };
    var OpsItemRelatedItemsFilterKey = {
      ASSOCIATION_ID: "AssociationId",
      RESOURCE_TYPE: "ResourceType",
      RESOURCE_URI: "ResourceUri"
    };
    var OpsItemRelatedItemsFilterOperator = {
      EQUAL: "Equal"
    };
    var LastResourceDataSyncStatus = {
      FAILED: "Failed",
      INPROGRESS: "InProgress",
      SUCCESSFUL: "Successful"
    };
    var ComplianceUploadType = {
      Complete: "COMPLETE",
      Partial: "PARTIAL"
    };
    var SignalType = {
      APPROVE: "Approve",
      REJECT: "Reject",
      RESUME: "Resume",
      REVOKE: "Revoke",
      START_STEP: "StartStep",
      STOP_STEP: "StopStep"
    };
    var StopType = {
      CANCEL: "Cancel",
      COMPLETE: "Complete"
    };
    var DocumentReviewAction = {
      Approve: "Approve",
      Reject: "Reject",
      SendForReview: "SendForReview",
      UpdateReview: "UpdateReview"
    };
    exports2.$Command = smithyClient.Command;
    exports2.__Client = smithyClient.Client;
    exports2.SSMServiceException = SSMServiceException.SSMServiceException;
    exports2.AccessRequestStatus = AccessRequestStatus;
    exports2.AccessType = AccessType;
    exports2.AddTagsToResourceCommand = AddTagsToResourceCommand;
    exports2.AssociateOpsItemRelatedItemCommand = AssociateOpsItemRelatedItemCommand;
    exports2.AssociationComplianceSeverity = AssociationComplianceSeverity;
    exports2.AssociationExecutionFilterKey = AssociationExecutionFilterKey;
    exports2.AssociationExecutionTargetsFilterKey = AssociationExecutionTargetsFilterKey;
    exports2.AssociationFilterKey = AssociationFilterKey;
    exports2.AssociationFilterOperatorType = AssociationFilterOperatorType;
    exports2.AssociationStatusName = AssociationStatusName;
    exports2.AssociationSyncCompliance = AssociationSyncCompliance;
    exports2.AttachmentHashType = AttachmentHashType;
    exports2.AttachmentsSourceKey = AttachmentsSourceKey;
    exports2.AutomationExecutionFilterKey = AutomationExecutionFilterKey;
    exports2.AutomationExecutionStatus = AutomationExecutionStatus;
    exports2.AutomationSubtype = AutomationSubtype;
    exports2.AutomationType = AutomationType;
    exports2.CalendarState = CalendarState;
    exports2.CancelCommandCommand = CancelCommandCommand;
    exports2.CancelMaintenanceWindowExecutionCommand = CancelMaintenanceWindowExecutionCommand;
    exports2.CommandFilterKey = CommandFilterKey;
    exports2.CommandInvocationStatus = CommandInvocationStatus;
    exports2.CommandPluginStatus = CommandPluginStatus;
    exports2.CommandStatus = CommandStatus;
    exports2.ComplianceQueryOperatorType = ComplianceQueryOperatorType;
    exports2.ComplianceSeverity = ComplianceSeverity;
    exports2.ComplianceStatus = ComplianceStatus;
    exports2.ComplianceUploadType = ComplianceUploadType;
    exports2.ConnectionStatus = ConnectionStatus;
    exports2.CreateActivationCommand = CreateActivationCommand;
    exports2.CreateAssociationBatchCommand = CreateAssociationBatchCommand;
    exports2.CreateAssociationCommand = CreateAssociationCommand;
    exports2.CreateDocumentCommand = CreateDocumentCommand;
    exports2.CreateMaintenanceWindowCommand = CreateMaintenanceWindowCommand;
    exports2.CreateOpsItemCommand = CreateOpsItemCommand;
    exports2.CreateOpsMetadataCommand = CreateOpsMetadataCommand;
    exports2.CreatePatchBaselineCommand = CreatePatchBaselineCommand;
    exports2.CreateResourceDataSyncCommand = CreateResourceDataSyncCommand;
    exports2.DeleteActivationCommand = DeleteActivationCommand;
    exports2.DeleteAssociationCommand = DeleteAssociationCommand;
    exports2.DeleteDocumentCommand = DeleteDocumentCommand;
    exports2.DeleteInventoryCommand = DeleteInventoryCommand;
    exports2.DeleteMaintenanceWindowCommand = DeleteMaintenanceWindowCommand;
    exports2.DeleteOpsItemCommand = DeleteOpsItemCommand;
    exports2.DeleteOpsMetadataCommand = DeleteOpsMetadataCommand;
    exports2.DeleteParameterCommand = DeleteParameterCommand;
    exports2.DeleteParametersCommand = DeleteParametersCommand;
    exports2.DeletePatchBaselineCommand = DeletePatchBaselineCommand;
    exports2.DeleteResourceDataSyncCommand = DeleteResourceDataSyncCommand;
    exports2.DeleteResourcePolicyCommand = DeleteResourcePolicyCommand;
    exports2.DeregisterManagedInstanceCommand = DeregisterManagedInstanceCommand;
    exports2.DeregisterPatchBaselineForPatchGroupCommand = DeregisterPatchBaselineForPatchGroupCommand;
    exports2.DeregisterTargetFromMaintenanceWindowCommand = DeregisterTargetFromMaintenanceWindowCommand;
    exports2.DeregisterTaskFromMaintenanceWindowCommand = DeregisterTaskFromMaintenanceWindowCommand;
    exports2.DescribeActivationsCommand = DescribeActivationsCommand;
    exports2.DescribeActivationsFilterKeys = DescribeActivationsFilterKeys;
    exports2.DescribeAssociationCommand = DescribeAssociationCommand;
    exports2.DescribeAssociationExecutionTargetsCommand = DescribeAssociationExecutionTargetsCommand;
    exports2.DescribeAssociationExecutionsCommand = DescribeAssociationExecutionsCommand;
    exports2.DescribeAutomationExecutionsCommand = DescribeAutomationExecutionsCommand;
    exports2.DescribeAutomationStepExecutionsCommand = DescribeAutomationStepExecutionsCommand;
    exports2.DescribeAvailablePatchesCommand = DescribeAvailablePatchesCommand;
    exports2.DescribeDocumentCommand = DescribeDocumentCommand;
    exports2.DescribeDocumentPermissionCommand = DescribeDocumentPermissionCommand;
    exports2.DescribeEffectiveInstanceAssociationsCommand = DescribeEffectiveInstanceAssociationsCommand;
    exports2.DescribeEffectivePatchesForPatchBaselineCommand = DescribeEffectivePatchesForPatchBaselineCommand;
    exports2.DescribeInstanceAssociationsStatusCommand = DescribeInstanceAssociationsStatusCommand;
    exports2.DescribeInstanceInformationCommand = DescribeInstanceInformationCommand;
    exports2.DescribeInstancePatchStatesCommand = DescribeInstancePatchStatesCommand;
    exports2.DescribeInstancePatchStatesForPatchGroupCommand = DescribeInstancePatchStatesForPatchGroupCommand;
    exports2.DescribeInstancePatchesCommand = DescribeInstancePatchesCommand;
    exports2.DescribeInstancePropertiesCommand = DescribeInstancePropertiesCommand;
    exports2.DescribeInventoryDeletionsCommand = DescribeInventoryDeletionsCommand;
    exports2.DescribeMaintenanceWindowExecutionTaskInvocationsCommand = DescribeMaintenanceWindowExecutionTaskInvocationsCommand;
    exports2.DescribeMaintenanceWindowExecutionTasksCommand = DescribeMaintenanceWindowExecutionTasksCommand;
    exports2.DescribeMaintenanceWindowExecutionsCommand = DescribeMaintenanceWindowExecutionsCommand;
    exports2.DescribeMaintenanceWindowScheduleCommand = DescribeMaintenanceWindowScheduleCommand;
    exports2.DescribeMaintenanceWindowTargetsCommand = DescribeMaintenanceWindowTargetsCommand;
    exports2.DescribeMaintenanceWindowTasksCommand = DescribeMaintenanceWindowTasksCommand;
    exports2.DescribeMaintenanceWindowsCommand = DescribeMaintenanceWindowsCommand;
    exports2.DescribeMaintenanceWindowsForTargetCommand = DescribeMaintenanceWindowsForTargetCommand;
    exports2.DescribeOpsItemsCommand = DescribeOpsItemsCommand;
    exports2.DescribeParametersCommand = DescribeParametersCommand;
    exports2.DescribePatchBaselinesCommand = DescribePatchBaselinesCommand;
    exports2.DescribePatchGroupStateCommand = DescribePatchGroupStateCommand;
    exports2.DescribePatchGroupsCommand = DescribePatchGroupsCommand;
    exports2.DescribePatchPropertiesCommand = DescribePatchPropertiesCommand;
    exports2.DescribeSessionsCommand = DescribeSessionsCommand;
    exports2.DisassociateOpsItemRelatedItemCommand = DisassociateOpsItemRelatedItemCommand;
    exports2.DocumentFilterKey = DocumentFilterKey;
    exports2.DocumentFormat = DocumentFormat;
    exports2.DocumentHashType = DocumentHashType;
    exports2.DocumentMetadataEnum = DocumentMetadataEnum;
    exports2.DocumentParameterType = DocumentParameterType;
    exports2.DocumentPermissionType = DocumentPermissionType;
    exports2.DocumentReviewAction = DocumentReviewAction;
    exports2.DocumentReviewCommentType = DocumentReviewCommentType;
    exports2.DocumentStatus = DocumentStatus;
    exports2.DocumentType = DocumentType;
    exports2.ExecutionMode = ExecutionMode;
    exports2.ExecutionPreviewStatus = ExecutionPreviewStatus;
    exports2.ExternalAlarmState = ExternalAlarmState;
    exports2.Fault = Fault;
    exports2.GetAccessTokenCommand = GetAccessTokenCommand;
    exports2.GetAutomationExecutionCommand = GetAutomationExecutionCommand;
    exports2.GetCalendarStateCommand = GetCalendarStateCommand;
    exports2.GetCommandInvocationCommand = GetCommandInvocationCommand;
    exports2.GetConnectionStatusCommand = GetConnectionStatusCommand;
    exports2.GetDefaultPatchBaselineCommand = GetDefaultPatchBaselineCommand;
    exports2.GetDeployablePatchSnapshotForInstanceCommand = GetDeployablePatchSnapshotForInstanceCommand;
    exports2.GetDocumentCommand = GetDocumentCommand;
    exports2.GetExecutionPreviewCommand = GetExecutionPreviewCommand;
    exports2.GetInventoryCommand = GetInventoryCommand;
    exports2.GetInventorySchemaCommand = GetInventorySchemaCommand;
    exports2.GetMaintenanceWindowCommand = GetMaintenanceWindowCommand;
    exports2.GetMaintenanceWindowExecutionCommand = GetMaintenanceWindowExecutionCommand;
    exports2.GetMaintenanceWindowExecutionTaskCommand = GetMaintenanceWindowExecutionTaskCommand;
    exports2.GetMaintenanceWindowExecutionTaskInvocationCommand = GetMaintenanceWindowExecutionTaskInvocationCommand;
    exports2.GetMaintenanceWindowTaskCommand = GetMaintenanceWindowTaskCommand;
    exports2.GetOpsItemCommand = GetOpsItemCommand;
    exports2.GetOpsMetadataCommand = GetOpsMetadataCommand;
    exports2.GetOpsSummaryCommand = GetOpsSummaryCommand;
    exports2.GetParameterCommand = GetParameterCommand2;
    exports2.GetParameterHistoryCommand = GetParameterHistoryCommand;
    exports2.GetParametersByPathCommand = GetParametersByPathCommand;
    exports2.GetParametersCommand = GetParametersCommand;
    exports2.GetPatchBaselineCommand = GetPatchBaselineCommand;
    exports2.GetPatchBaselineForPatchGroupCommand = GetPatchBaselineForPatchGroupCommand;
    exports2.GetResourcePoliciesCommand = GetResourcePoliciesCommand;
    exports2.GetServiceSettingCommand = GetServiceSettingCommand;
    exports2.ImpactType = ImpactType;
    exports2.InstanceInformationFilterKey = InstanceInformationFilterKey;
    exports2.InstancePatchStateOperatorType = InstancePatchStateOperatorType;
    exports2.InstancePropertyFilterKey = InstancePropertyFilterKey;
    exports2.InstancePropertyFilterOperator = InstancePropertyFilterOperator;
    exports2.InventoryAttributeDataType = InventoryAttributeDataType;
    exports2.InventoryDeletionStatus = InventoryDeletionStatus;
    exports2.InventoryQueryOperatorType = InventoryQueryOperatorType;
    exports2.InventorySchemaDeleteOption = InventorySchemaDeleteOption;
    exports2.LabelParameterVersionCommand = LabelParameterVersionCommand;
    exports2.LastResourceDataSyncStatus = LastResourceDataSyncStatus;
    exports2.ListAssociationVersionsCommand = ListAssociationVersionsCommand;
    exports2.ListAssociationsCommand = ListAssociationsCommand;
    exports2.ListCommandInvocationsCommand = ListCommandInvocationsCommand;
    exports2.ListCommandsCommand = ListCommandsCommand;
    exports2.ListComplianceItemsCommand = ListComplianceItemsCommand;
    exports2.ListComplianceSummariesCommand = ListComplianceSummariesCommand;
    exports2.ListDocumentMetadataHistoryCommand = ListDocumentMetadataHistoryCommand;
    exports2.ListDocumentVersionsCommand = ListDocumentVersionsCommand;
    exports2.ListDocumentsCommand = ListDocumentsCommand;
    exports2.ListInventoryEntriesCommand = ListInventoryEntriesCommand;
    exports2.ListNodesCommand = ListNodesCommand;
    exports2.ListNodesSummaryCommand = ListNodesSummaryCommand;
    exports2.ListOpsItemEventsCommand = ListOpsItemEventsCommand;
    exports2.ListOpsItemRelatedItemsCommand = ListOpsItemRelatedItemsCommand;
    exports2.ListOpsMetadataCommand = ListOpsMetadataCommand;
    exports2.ListResourceComplianceSummariesCommand = ListResourceComplianceSummariesCommand;
    exports2.ListResourceDataSyncCommand = ListResourceDataSyncCommand;
    exports2.ListTagsForResourceCommand = ListTagsForResourceCommand;
    exports2.MaintenanceWindowExecutionStatus = MaintenanceWindowExecutionStatus;
    exports2.MaintenanceWindowResourceType = MaintenanceWindowResourceType;
    exports2.MaintenanceWindowTaskCutoffBehavior = MaintenanceWindowTaskCutoffBehavior;
    exports2.MaintenanceWindowTaskType = MaintenanceWindowTaskType;
    exports2.ManagedStatus = ManagedStatus;
    exports2.ModifyDocumentPermissionCommand = ModifyDocumentPermissionCommand;
    exports2.NodeAggregatorType = NodeAggregatorType;
    exports2.NodeAttributeName = NodeAttributeName;
    exports2.NodeFilterKey = NodeFilterKey;
    exports2.NodeFilterOperatorType = NodeFilterOperatorType;
    exports2.NodeTypeName = NodeTypeName;
    exports2.NotificationEvent = NotificationEvent;
    exports2.NotificationType = NotificationType;
    exports2.OperatingSystem = OperatingSystem;
    exports2.OpsFilterOperatorType = OpsFilterOperatorType;
    exports2.OpsItemDataType = OpsItemDataType;
    exports2.OpsItemEventFilterKey = OpsItemEventFilterKey;
    exports2.OpsItemEventFilterOperator = OpsItemEventFilterOperator;
    exports2.OpsItemFilterKey = OpsItemFilterKey;
    exports2.OpsItemFilterOperator = OpsItemFilterOperator;
    exports2.OpsItemRelatedItemsFilterKey = OpsItemRelatedItemsFilterKey;
    exports2.OpsItemRelatedItemsFilterOperator = OpsItemRelatedItemsFilterOperator;
    exports2.OpsItemStatus = OpsItemStatus;
    exports2.ParameterTier = ParameterTier;
    exports2.ParameterType = ParameterType;
    exports2.ParametersFilterKey = ParametersFilterKey;
    exports2.PatchAction = PatchAction;
    exports2.PatchComplianceDataState = PatchComplianceDataState;
    exports2.PatchComplianceLevel = PatchComplianceLevel;
    exports2.PatchComplianceStatus = PatchComplianceStatus;
    exports2.PatchDeploymentStatus = PatchDeploymentStatus;
    exports2.PatchFilterKey = PatchFilterKey;
    exports2.PatchOperationType = PatchOperationType;
    exports2.PatchProperty = PatchProperty;
    exports2.PatchSet = PatchSet;
    exports2.PingStatus = PingStatus;
    exports2.PlatformType = PlatformType;
    exports2.PutComplianceItemsCommand = PutComplianceItemsCommand;
    exports2.PutInventoryCommand = PutInventoryCommand;
    exports2.PutParameterCommand = PutParameterCommand;
    exports2.PutResourcePolicyCommand = PutResourcePolicyCommand;
    exports2.RebootOption = RebootOption;
    exports2.RegisterDefaultPatchBaselineCommand = RegisterDefaultPatchBaselineCommand;
    exports2.RegisterPatchBaselineForPatchGroupCommand = RegisterPatchBaselineForPatchGroupCommand;
    exports2.RegisterTargetWithMaintenanceWindowCommand = RegisterTargetWithMaintenanceWindowCommand;
    exports2.RegisterTaskWithMaintenanceWindowCommand = RegisterTaskWithMaintenanceWindowCommand;
    exports2.RemoveTagsFromResourceCommand = RemoveTagsFromResourceCommand;
    exports2.ResetServiceSettingCommand = ResetServiceSettingCommand;
    exports2.ResourceDataSyncS3Format = ResourceDataSyncS3Format;
    exports2.ResourceType = ResourceType;
    exports2.ResourceTypeForTagging = ResourceTypeForTagging;
    exports2.ResumeSessionCommand = ResumeSessionCommand;
    exports2.ReviewStatus = ReviewStatus;
    exports2.SSM = SSM;
    exports2.SSMClient = SSMClient2;
    exports2.SendAutomationSignalCommand = SendAutomationSignalCommand;
    exports2.SendCommandCommand = SendCommandCommand;
    exports2.SessionFilterKey = SessionFilterKey;
    exports2.SessionState = SessionState;
    exports2.SessionStatus = SessionStatus;
    exports2.SignalType = SignalType;
    exports2.SourceType = SourceType;
    exports2.StartAccessRequestCommand = StartAccessRequestCommand;
    exports2.StartAssociationsOnceCommand = StartAssociationsOnceCommand;
    exports2.StartAutomationExecutionCommand = StartAutomationExecutionCommand;
    exports2.StartChangeRequestExecutionCommand = StartChangeRequestExecutionCommand;
    exports2.StartExecutionPreviewCommand = StartExecutionPreviewCommand;
    exports2.StartSessionCommand = StartSessionCommand;
    exports2.StepExecutionFilterKey = StepExecutionFilterKey;
    exports2.StopAutomationExecutionCommand = StopAutomationExecutionCommand;
    exports2.StopType = StopType;
    exports2.TerminateSessionCommand = TerminateSessionCommand;
    exports2.UnlabelParameterVersionCommand = UnlabelParameterVersionCommand;
    exports2.UpdateAssociationCommand = UpdateAssociationCommand;
    exports2.UpdateAssociationStatusCommand = UpdateAssociationStatusCommand;
    exports2.UpdateDocumentCommand = UpdateDocumentCommand;
    exports2.UpdateDocumentDefaultVersionCommand = UpdateDocumentDefaultVersionCommand;
    exports2.UpdateDocumentMetadataCommand = UpdateDocumentMetadataCommand;
    exports2.UpdateMaintenanceWindowCommand = UpdateMaintenanceWindowCommand;
    exports2.UpdateMaintenanceWindowTargetCommand = UpdateMaintenanceWindowTargetCommand;
    exports2.UpdateMaintenanceWindowTaskCommand = UpdateMaintenanceWindowTaskCommand;
    exports2.UpdateManagedInstanceRoleCommand = UpdateManagedInstanceRoleCommand;
    exports2.UpdateOpsItemCommand = UpdateOpsItemCommand;
    exports2.UpdateOpsMetadataCommand = UpdateOpsMetadataCommand;
    exports2.UpdatePatchBaselineCommand = UpdatePatchBaselineCommand;
    exports2.UpdateResourceDataSyncCommand = UpdateResourceDataSyncCommand;
    exports2.UpdateServiceSettingCommand = UpdateServiceSettingCommand;
    exports2.paginateDescribeActivations = paginateDescribeActivations;
    exports2.paginateDescribeAssociationExecutionTargets = paginateDescribeAssociationExecutionTargets;
    exports2.paginateDescribeAssociationExecutions = paginateDescribeAssociationExecutions;
    exports2.paginateDescribeAutomationExecutions = paginateDescribeAutomationExecutions;
    exports2.paginateDescribeAutomationStepExecutions = paginateDescribeAutomationStepExecutions;
    exports2.paginateDescribeAvailablePatches = paginateDescribeAvailablePatches;
    exports2.paginateDescribeEffectiveInstanceAssociations = paginateDescribeEffectiveInstanceAssociations;
    exports2.paginateDescribeEffectivePatchesForPatchBaseline = paginateDescribeEffectivePatchesForPatchBaseline;
    exports2.paginateDescribeInstanceAssociationsStatus = paginateDescribeInstanceAssociationsStatus;
    exports2.paginateDescribeInstanceInformation = paginateDescribeInstanceInformation;
    exports2.paginateDescribeInstancePatchStates = paginateDescribeInstancePatchStates;
    exports2.paginateDescribeInstancePatchStatesForPatchGroup = paginateDescribeInstancePatchStatesForPatchGroup;
    exports2.paginateDescribeInstancePatches = paginateDescribeInstancePatches;
    exports2.paginateDescribeInstanceProperties = paginateDescribeInstanceProperties;
    exports2.paginateDescribeInventoryDeletions = paginateDescribeInventoryDeletions;
    exports2.paginateDescribeMaintenanceWindowExecutionTaskInvocations = paginateDescribeMaintenanceWindowExecutionTaskInvocations;
    exports2.paginateDescribeMaintenanceWindowExecutionTasks = paginateDescribeMaintenanceWindowExecutionTasks;
    exports2.paginateDescribeMaintenanceWindowExecutions = paginateDescribeMaintenanceWindowExecutions;
    exports2.paginateDescribeMaintenanceWindowSchedule = paginateDescribeMaintenanceWindowSchedule;
    exports2.paginateDescribeMaintenanceWindowTargets = paginateDescribeMaintenanceWindowTargets;
    exports2.paginateDescribeMaintenanceWindowTasks = paginateDescribeMaintenanceWindowTasks;
    exports2.paginateDescribeMaintenanceWindows = paginateDescribeMaintenanceWindows;
    exports2.paginateDescribeMaintenanceWindowsForTarget = paginateDescribeMaintenanceWindowsForTarget;
    exports2.paginateDescribeOpsItems = paginateDescribeOpsItems;
    exports2.paginateDescribeParameters = paginateDescribeParameters;
    exports2.paginateDescribePatchBaselines = paginateDescribePatchBaselines;
    exports2.paginateDescribePatchGroups = paginateDescribePatchGroups;
    exports2.paginateDescribePatchProperties = paginateDescribePatchProperties;
    exports2.paginateDescribeSessions = paginateDescribeSessions;
    exports2.paginateGetInventory = paginateGetInventory;
    exports2.paginateGetInventorySchema = paginateGetInventorySchema;
    exports2.paginateGetOpsSummary = paginateGetOpsSummary;
    exports2.paginateGetParameterHistory = paginateGetParameterHistory;
    exports2.paginateGetParametersByPath = paginateGetParametersByPath;
    exports2.paginateGetResourcePolicies = paginateGetResourcePolicies;
    exports2.paginateListAssociationVersions = paginateListAssociationVersions;
    exports2.paginateListAssociations = paginateListAssociations;
    exports2.paginateListCommandInvocations = paginateListCommandInvocations;
    exports2.paginateListCommands = paginateListCommands;
    exports2.paginateListComplianceItems = paginateListComplianceItems;
    exports2.paginateListComplianceSummaries = paginateListComplianceSummaries;
    exports2.paginateListDocumentVersions = paginateListDocumentVersions;
    exports2.paginateListDocuments = paginateListDocuments;
    exports2.paginateListNodes = paginateListNodes;
    exports2.paginateListNodesSummary = paginateListNodesSummary;
    exports2.paginateListOpsItemEvents = paginateListOpsItemEvents;
    exports2.paginateListOpsItemRelatedItems = paginateListOpsItemRelatedItems;
    exports2.paginateListOpsMetadata = paginateListOpsMetadata;
    exports2.paginateListResourceComplianceSummaries = paginateListResourceComplianceSummaries;
    exports2.paginateListResourceDataSync = paginateListResourceDataSync;
    exports2.waitForCommandExecuted = waitForCommandExecuted;
    exports2.waitUntilCommandExecuted = waitUntilCommandExecuted;
    Object.prototype.hasOwnProperty.call(schemas_0, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: schemas_0["__proto__"]
    });
    Object.keys(schemas_0).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = schemas_0[k32];
    });
    Object.prototype.hasOwnProperty.call(errors, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: errors["__proto__"]
    });
    Object.keys(errors).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = errors[k32];
    });
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/aws-auth/account-cache.ts
var path26, fs25, AccountAccessKeyCache;
var init_account_cache = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/aws-auth/account-cache.ts"() {
    "use strict";
    path26 = __toESM(require("path"));
    fs25 = __toESM(require_lib4());
    init_util3();
    AccountAccessKeyCache = class _AccountAccessKeyCache {
      static {
        __name(this, "AccountAccessKeyCache");
      }
      /**
       * Max number of entries in the cache, after which the cache will be reset.
       */
      static MAX_ENTRIES = 1e3;
      /**
       * The default path used for the accounts access key cache
       */
      static get DEFAULT_PATH() {
        return path26.join(cdkCacheDir(), "accounts_partitions.json");
      }
      cacheFile;
      debug;
      /**
       * @param filePath - Path to the cache file
       */
      constructor(filePath = _AccountAccessKeyCache.DEFAULT_PATH, debugFn) {
        this.cacheFile = filePath;
        this.debug = debugFn;
      }
      /**
       * Tries to fetch the account ID from cache. If it's not in the cache, invokes
       * the resolver function which should retrieve the account ID and return it.
       * Then, it will be stored into disk cache returned.
       *
       * Example:
       *
       *    const accountId = cache.fetch(accessKey, async () => {
       *      return await fetchAccountIdFromSomewhere(accessKey);
       *    });
       */
      async fetch(accessKeyId, resolver) {
        const cached3 = await this.get(accessKeyId);
        if (cached3) {
          await this.debug(`Retrieved account ID ${cached3.accountId} from disk cache`);
          return cached3;
        }
        const account = await resolver();
        if (account) {
          await this.put(accessKeyId, account);
        }
        return account;
      }
      /** Get the account ID from an access key or undefined if not in cache */
      async get(accessKeyId) {
        const map5 = await this.loadMap();
        return map5[accessKeyId];
      }
      /** Put a mapping between access key and account ID */
      async put(accessKeyId, account) {
        let map5 = await this.loadMap();
        if (Object.keys(map5).length >= _AccountAccessKeyCache.MAX_ENTRIES) {
          map5 = {};
        }
        map5[accessKeyId] = account;
        await this.saveMap(map5);
      }
      async loadMap() {
        try {
          return await fs25.readJson(this.cacheFile);
        } catch (e32) {
          if (e32.code === "ENOENT" || e32.code === "EACCES") {
            return {};
          }
          if (e32 instanceof SyntaxError) {
            return {};
          }
          throw e32;
        }
      }
      async saveMap(map5) {
        try {
          await fs25.ensureFile(this.cacheFile);
          await fs25.writeJson(this.cacheFile, map5, { spaces: 2 });
        } catch (e32) {
          if (e32.code === "ENOENT" || e32.code === "EACCES" || e32.code === "EROFS") {
            return;
          }
          throw e32;
        }
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/aws-auth/cached.ts
function cached2(obj, sym, fn) {
  if (!(sym in obj)) {
    obj[sym] = fn();
  }
  return obj[sym];
}
async function cachedAsync(obj, sym, fn) {
  if (!(sym in obj)) {
    obj[sym] = await fn();
  }
  return obj[sym];
}
var init_cached = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/aws-auth/cached.ts"() {
    "use strict";
    __name(cached2, "cached");
    __name(cachedAsync, "cachedAsync");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/aws-auth/tracing.ts
function setSdkTracing(enabled) {
  ENABLED = enabled;
}
function callTrace(fn, className, logger5) {
  if (!ENABLED || !logger5) {
    return;
  }
  logger5.info(`[trace] ${" ".repeat(INDENT)}${className || "(anonymous)"}#${fn}()`);
}
function traceCall(receiver, _propertyKey, descriptor, parentClassName) {
  const fn = descriptor.value;
  const className = typeof receiver === "function" ? receiver.name : parentClassName;
  descriptor.value = function(...args) {
    const logger5 = this.logger;
    if (!ENABLED || typeof logger5?.info !== "function") {
      return fn.apply(this, args);
    }
    logger5.info.apply(logger5, [`[trace] ${" ".repeat(INDENT)}${className || this.constructor.name || "(anonymous)"}#${fn.name}()`]);
    INDENT += 2;
    const ret = fn.apply(this, args);
    if (ret instanceof Promise) {
      return ret.finally(() => {
        INDENT -= 2;
      });
    } else {
      INDENT -= 2;
      return ret;
    }
  };
  return descriptor;
}
function traceMemberMethods(constructor) {
  for (const [name, descriptor] of Object.entries(Object.getOwnPropertyDescriptors(constructor.prototype))) {
    if (typeof descriptor.value !== "function") {
      continue;
    }
    const newDescriptor = traceCall(constructor.prototype, name, descriptor, constructor.name) ?? descriptor;
    Object.defineProperty(constructor.prototype, name, newDescriptor);
  }
}
var ENABLED, INDENT;
var init_tracing = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/aws-auth/tracing.ts"() {
    "use strict";
    ENABLED = false;
    INDENT = 0;
    __name(setSdkTracing, "setSdkTracing");
    __name(callTrace, "callTrace");
    __name(traceCall, "traceCall");
    __name(traceMemberMethods, "traceMemberMethods");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/aws-auth/util.ts
function readIfPossible(filename) {
  try {
    if (!fs26.pathExistsSync(filename)) {
      return void 0;
    }
    return fs26.readFileSync(filename, { encoding: "utf-8" });
  } catch (e32) {
    return void 0;
  }
}
var fs26;
var init_util7 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/aws-auth/util.ts"() {
    "use strict";
    fs26 = __toESM(require_lib4());
    __name(readIfPossible, "readIfPossible");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/aws-auth/user-agent.ts
function defaultCliUserAgent() {
  const root32 = bundledPackageRootDir(__dirname, false);
  const pkg = JSON.parse((root32 ? readIfPossible(path27.join(root32, "package.json")) : void 0) ?? "{}");
  const name = pkg.name ?? path27.basename(process.argv[1] ?? "cdk-cli");
  const version = pkg.version ?? "<unknown>";
  return `${name}/${version}`;
}
var path27;
var init_user_agent = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/aws-auth/user-agent.ts"() {
    "use strict";
    path27 = __toESM(require("path"));
    init_util7();
    init_util3();
    __name(defaultCliUserAgent, "defaultCliUserAgent");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/aws-auth/sdk.ts
function makeSdkLoggerSafeByBindingThis(logger5) {
  return {
    debug: logger5.debug.bind(logger5),
    info: logger5.info.bind(logger5),
    warn: logger5.warn.bind(logger5),
    error: logger5.error.bind(logger5)
  };
}
function cappedExponentialBackoff(baseMs, capMs) {
  return (attempt) => Math.min(baseMs * 2 ** attempt, capMs);
}
var import_client_appsync, import_client_bedrock_agentcore_control, import_client_cloudcontrol, import_client_cloudformation5, import_client_cloudwatch_logs, import_client_codebuild, import_client_ec2, import_client_ecr2, import_client_ecs, import_client_elastic_load_balancing_v2, import_client_iam, import_client_kms, import_client_lambda, import_client_route_53, import_client_s33, import_client_secrets_manager2, import_client_sfn, import_client_ssm, import_client_sts2, import_lib_storage2, import_middleware_endpoint73, import_util_retry39, SDK, CURRENT_ACCOUNT_KEY;
var init_sdk2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/aws-auth/sdk.ts"() {
    "use strict";
    import_client_appsync = __toESM(require_dist_cjs155());
    import_client_bedrock_agentcore_control = __toESM(require_dist_cjs157());
    import_client_cloudcontrol = __toESM(require_dist_cjs158());
    import_client_cloudformation5 = __toESM(require_dist_cjs140());
    import_client_cloudwatch_logs = __toESM(require_dist_cjs159());
    import_client_codebuild = __toESM(require_dist_cjs160());
    import_client_ec2 = __toESM(require_dist_cjs163());
    import_client_ecr2 = __toESM(require_dist_cjs61());
    import_client_ecs = __toESM(require_dist_cjs164());
    import_client_elastic_load_balancing_v2 = __toESM(require_dist_cjs165());
    import_client_iam = __toESM(require_dist_cjs166());
    import_client_kms = __toESM(require_dist_cjs179());
    import_client_lambda = __toESM(require_dist_cjs193());
    import_client_route_53 = __toESM(require_dist_cjs195());
    import_client_s33 = __toESM(require_dist_cjs90());
    import_client_secrets_manager2 = __toESM(require_dist_cjs103());
    import_client_sfn = __toESM(require_dist_cjs196());
    import_client_ssm = __toESM(require_dist_cjs210());
    import_client_sts2 = __toESM(require_dist_cjs123());
    import_lib_storage2 = __toESM(require_dist_cjs126());
    import_middleware_endpoint73 = __toESM(require_dist_cjs31());
    import_util_retry39 = __toESM(require_dist_cjs22());
    init_account_cache();
    init_cached();
    init_tracing();
    init_user_agent();
    init_toolkit_error();
    init_util3();
    SDK = class {
      constructor(credProvider, region, requestHandler, ioHelper, logger5) {
        this.credProvider = credProvider;
        const debugFn = /* @__PURE__ */ __name(async (msg) => ioHelper.defaults.debug(msg), "debugFn");
        this.accountCache = new AccountAccessKeyCache(AccountAccessKeyCache.DEFAULT_PATH, debugFn);
        this.debug = debugFn;
        this.config = {
          region,
          credentials: credProvider,
          requestHandler,
          retryStrategy: new import_util_retry39.ConfiguredRetryStrategy(7, cappedExponentialBackoff(300, 15e3)),
          customUserAgent: defaultCliUserAgent(),
          logger: logger5 ? makeSdkLoggerSafeByBindingThis(logger5) : void 0
        };
        this.currentRegion = region;
      }
      credProvider;
      currentRegion;
      config;
      accountCache;
      /**
       * STS is used to check credential validity, don't do too many retries.
       */
      stsRetryStrategy = new import_util_retry39.ConfiguredRetryStrategy(3, (attempt) => 100 * 2 ** attempt);
      /**
       * Whether we have proof that the credentials have not expired
       *
       * We need to do some manual plumbing around this because the JS SDKv2 treats `ExpiredToken`
       * as retriable and we have hefty retries on CFN calls making the CLI hang for a good 15 minutes
       * if the credentials have expired.
       */
      _credentialsValidated = false;
      /**
       * A function to create debug messages
       */
      debug;
      appendCustomUserAgent(userAgentData) {
        if (!userAgentData) {
          return;
        }
        const currentCustomUserAgent = this.config.customUserAgent;
        this.config.customUserAgent = currentCustomUserAgent ? `${currentCustomUserAgent} ${userAgentData}` : userAgentData;
      }
      removeCustomUserAgent(userAgentData) {
        this.config.customUserAgent = this.config.customUserAgent?.replace(userAgentData, "");
      }
      appsync() {
        const client = new import_client_appsync.AppSyncClient(this.config);
        return {
          getSchemaCreationStatus: /* @__PURE__ */ __name((input) => client.send(new import_client_appsync.GetSchemaCreationStatusCommand(input)), "getSchemaCreationStatus"),
          startSchemaCreation: /* @__PURE__ */ __name((input) => client.send(new import_client_appsync.StartSchemaCreationCommand(input)), "startSchemaCreation"),
          updateApiKey: /* @__PURE__ */ __name((input) => client.send(new import_client_appsync.UpdateApiKeyCommand(input)), "updateApiKey"),
          updateFunction: /* @__PURE__ */ __name((input) => client.send(new import_client_appsync.UpdateFunctionCommand(input)), "updateFunction"),
          updateResolver: /* @__PURE__ */ __name((input) => client.send(new import_client_appsync.UpdateResolverCommand(input)), "updateResolver"),
          // Pagination Functions
          listFunctions: /* @__PURE__ */ __name(async (input) => {
            const functions = Array();
            const paginator = (0, import_client_appsync.paginateListFunctions)({ client }, input);
            for await (const page of paginator) {
              functions.push(...page.functions || []);
            }
            return functions;
          }, "listFunctions")
        };
      }
      bedrockAgentCoreControl() {
        const client = new import_client_bedrock_agentcore_control.BedrockAgentCoreControlClient(this.config);
        return {
          getAgentRuntime: /* @__PURE__ */ __name((input) => client.send(new import_client_bedrock_agentcore_control.GetAgentRuntimeCommand(input)), "getAgentRuntime"),
          updateAgentRuntime: /* @__PURE__ */ __name((input) => client.send(new import_client_bedrock_agentcore_control.UpdateAgentRuntimeCommand(input)), "updateAgentRuntime")
        };
      }
      cloudControl() {
        const client = new import_client_cloudcontrol.CloudControlClient(this.config);
        return {
          listResources: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudcontrol.ListResourcesCommand(input)), "listResources"),
          getResource: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudcontrol.GetResourceCommand(input)), "getResource"),
          updateResource: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudcontrol.UpdateResourceCommand(input)), "updateResource")
        };
      }
      cloudFormation() {
        const client = new import_client_cloudformation5.CloudFormationClient({
          ...this.config,
          retryStrategy: new import_util_retry39.ConfiguredRetryStrategy(7, cappedExponentialBackoff(1e3, 15e3))
        });
        return {
          continueUpdateRollback: /* @__PURE__ */ __name(async (input) => client.send(new import_client_cloudformation5.ContinueUpdateRollbackCommand(input)), "continueUpdateRollback"),
          createChangeSet: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.CreateChangeSetCommand(input)), "createChangeSet"),
          createGeneratedTemplate: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.CreateGeneratedTemplateCommand(input)), "createGeneratedTemplate"),
          createStack: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.CreateStackCommand(input)), "createStack"),
          deleteChangeSet: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.DeleteChangeSetCommand(input)), "deleteChangeSet"),
          deleteGeneratedTemplate: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.DeleteGeneratedTemplateCommand(input)), "deleteGeneratedTemplate"),
          deleteStack: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.DeleteStackCommand(input)), "deleteStack"),
          detectStackDrift: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.DetectStackDriftCommand(input)), "detectStackDrift"),
          detectStackResourceDrift: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.DetectStackResourceDriftCommand(input)), "detectStackResourceDrift"),
          describeEvents: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.DescribeEventsCommand(input)), "describeEvents"),
          describeChangeSet: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.DescribeChangeSetCommand(input)), "describeChangeSet"),
          describeGeneratedTemplate: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.DescribeGeneratedTemplateCommand(input)), "describeGeneratedTemplate"),
          describeResourceScan: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.DescribeResourceScanCommand(input)), "describeResourceScan"),
          describeStackDriftDetectionStatus: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.DescribeStackDriftDetectionStatusCommand(input)), "describeStackDriftDetectionStatus"),
          describeStackResourceDrifts: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.DescribeStackResourceDriftsCommand(input)), "describeStackResourceDrifts"),
          describeStacks: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.DescribeStacksCommand(input)), "describeStacks"),
          describeStackResources: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.DescribeStackResourcesCommand(input)), "describeStackResources"),
          describeType: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.DescribeTypeCommand(input)), "describeType"),
          executeChangeSet: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.ExecuteChangeSetCommand(input)), "executeChangeSet"),
          getGeneratedTemplate: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.GetGeneratedTemplateCommand(input)), "getGeneratedTemplate"),
          getTemplate: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.GetTemplateCommand(input)), "getTemplate"),
          getTemplateSummary: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.GetTemplateSummaryCommand(input)), "getTemplateSummary"),
          listExports: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.ListExportsCommand(input)), "listExports"),
          listResourceScanRelatedResources: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.ListResourceScanRelatedResourcesCommand(input)), "listResourceScanRelatedResources"),
          listResourceScanResources: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.ListResourceScanResourcesCommand(input)), "listResourceScanResources"),
          listResourceScans: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.ListResourceScansCommand(input)), "listResourceScans"),
          listStacks: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.ListStacksCommand(input)), "listStacks"),
          rollbackStack: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.RollbackStackCommand(input)), "rollbackStack"),
          startResourceScan: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.StartResourceScanCommand(input)), "startResourceScan"),
          updateStack: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.UpdateStackCommand(input)), "updateStack"),
          updateTerminationProtection: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.UpdateTerminationProtectionCommand(input)), "updateTerminationProtection"),
          describeStackEvents: /* @__PURE__ */ __name((input) => {
            return client.send(new import_client_cloudformation5.DescribeStackEventsCommand(input));
          }, "describeStackEvents"),
          listStackResources: /* @__PURE__ */ __name(async (input) => {
            const stackResources = Array();
            const paginator = (0, import_client_cloudformation5.paginateListStackResources)({ client }, input);
            for await (const page of paginator) {
              stackResources.push(...page?.StackResourceSummaries || []);
            }
            return stackResources;
          }, "listStackResources"),
          paginatedListStacks: /* @__PURE__ */ __name(async (input) => {
            const stackResources = Array();
            const paginator = (0, import_client_cloudformation5.paginateListStacks)({ client }, input);
            for await (const page of paginator) {
              stackResources.push(...page?.StackSummaries || []);
            }
            return stackResources;
          }, "paginatedListStacks"),
          paginatedDescribeEvents: /* @__PURE__ */ __name(async (input) => {
            const stackResources = Array();
            const paginator = (0, import_client_cloudformation5.paginateDescribeEvents)({ client }, input);
            for await (const page of paginator) {
              stackResources.push(...page.OperationEvents || []);
            }
            return stackResources;
          }, "paginatedDescribeEvents"),
          createStackRefactor: /* @__PURE__ */ __name((input) => {
            return client.send(new import_client_cloudformation5.CreateStackRefactorCommand(input));
          }, "createStackRefactor"),
          executeStackRefactor: /* @__PURE__ */ __name((input) => {
            return client.send(new import_client_cloudformation5.ExecuteStackRefactorCommand(input));
          }, "executeStackRefactor"),
          waitUntilStackRefactorCreateComplete: /* @__PURE__ */ __name((input) => {
            return (0, import_client_cloudformation5.waitUntilStackRefactorCreateComplete)(
              {
                client,
                maxWaitTime: 600,
                minDelay: 6,
                maxDelay: 6
              },
              input
            );
          }, "waitUntilStackRefactorCreateComplete"),
          waitUntilStackRefactorExecuteComplete: /* @__PURE__ */ __name((input) => {
            return (0, import_client_cloudformation5.waitUntilStackRefactorExecuteComplete)(
              {
                client,
                maxWaitTime: 600,
                minDelay: 6,
                maxDelay: 6
              },
              input
            );
          }, "waitUntilStackRefactorExecuteComplete"),
          getHookResult: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.GetHookResultCommand(input)), "getHookResult"),
          listChangeSets: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudformation5.ListChangeSetsCommand(input)), "listChangeSets")
        };
      }
      cloudWatchLogs() {
        const client = new import_client_cloudwatch_logs.CloudWatchLogsClient(this.config);
        return {
          describeLogGroups: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudwatch_logs.DescribeLogGroupsCommand(input)), "describeLogGroups"),
          filterLogEvents: /* @__PURE__ */ __name((input) => client.send(new import_client_cloudwatch_logs.FilterLogEventsCommand(input)), "filterLogEvents")
        };
      }
      codeBuild() {
        const client = new import_client_codebuild.CodeBuildClient(this.config);
        return {
          updateProject: /* @__PURE__ */ __name((input) => client.send(new import_client_codebuild.UpdateProjectCommand(input)), "updateProject")
        };
      }
      ec2() {
        const client = new import_client_ec2.EC2Client(this.config);
        return {
          describeAvailabilityZones: /* @__PURE__ */ __name((input) => client.send(new import_client_ec2.DescribeAvailabilityZonesCommand(input)), "describeAvailabilityZones"),
          describeImages: /* @__PURE__ */ __name((input) => client.send(new import_client_ec2.DescribeImagesCommand(input)), "describeImages"),
          describeInstances: /* @__PURE__ */ __name((input) => client.send(new import_client_ec2.DescribeInstancesCommand(input)), "describeInstances"),
          describeRouteTables: /* @__PURE__ */ __name((input) => client.send(new import_client_ec2.DescribeRouteTablesCommand(input)), "describeRouteTables"),
          describeSecurityGroups: /* @__PURE__ */ __name((input) => client.send(new import_client_ec2.DescribeSecurityGroupsCommand(input)), "describeSecurityGroups"),
          describeSubnets: /* @__PURE__ */ __name((input) => client.send(new import_client_ec2.DescribeSubnetsCommand(input)), "describeSubnets"),
          describeVpcEndpointServices: /* @__PURE__ */ __name((input) => client.send(new import_client_ec2.DescribeVpcEndpointServicesCommand(input)), "describeVpcEndpointServices"),
          describeVpcs: /* @__PURE__ */ __name((input) => client.send(new import_client_ec2.DescribeVpcsCommand(input)), "describeVpcs"),
          describeVpnGateways: /* @__PURE__ */ __name((input) => client.send(new import_client_ec2.DescribeVpnGatewaysCommand(input)), "describeVpnGateways")
        };
      }
      ecr() {
        const client = new import_client_ecr2.ECRClient(this.config);
        return {
          batchDeleteImage: /* @__PURE__ */ __name((input) => client.send(new import_client_ecr2.BatchDeleteImageCommand(input)), "batchDeleteImage"),
          batchGetImage: /* @__PURE__ */ __name((input) => client.send(new import_client_ecr2.BatchGetImageCommand(input)), "batchGetImage"),
          createRepository: /* @__PURE__ */ __name((input) => client.send(new import_client_ecr2.CreateRepositoryCommand(input)), "createRepository"),
          describeImages: /* @__PURE__ */ __name((input) => client.send(new import_client_ecr2.DescribeImagesCommand(input)), "describeImages"),
          describeRepositories: /* @__PURE__ */ __name((input) => client.send(new import_client_ecr2.DescribeRepositoriesCommand(input)), "describeRepositories"),
          getAuthorizationToken: /* @__PURE__ */ __name((input) => client.send(new import_client_ecr2.GetAuthorizationTokenCommand(input)), "getAuthorizationToken"),
          listImages: /* @__PURE__ */ __name((input) => client.send(new import_client_ecr2.ListImagesCommand(input)), "listImages"),
          putImage: /* @__PURE__ */ __name((input) => client.send(new import_client_ecr2.PutImageCommand(input)), "putImage"),
          putImageScanningConfiguration: /* @__PURE__ */ __name((input) => client.send(new import_client_ecr2.PutImageScanningConfigurationCommand(input)), "putImageScanningConfiguration")
        };
      }
      ecs() {
        const client = new import_client_ecs.ECSClient(this.config);
        return {
          describeServices: /* @__PURE__ */ __name((input) => client.send(new import_client_ecs.DescribeServicesCommand(input)), "describeServices"),
          describeTaskDefinition: /* @__PURE__ */ __name((input) => client.send(new import_client_ecs.DescribeTaskDefinitionCommand(input)), "describeTaskDefinition"),
          describeTasks: /* @__PURE__ */ __name((input) => client.send(new import_client_ecs.DescribeTasksCommand(input)), "describeTasks"),
          listTasks: /* @__PURE__ */ __name((input) => client.send(new import_client_ecs.ListTasksCommand(input)), "listTasks"),
          listClusters: /* @__PURE__ */ __name((input) => client.send(new import_client_ecs.ListClustersCommand(input)), "listClusters"),
          registerTaskDefinition: /* @__PURE__ */ __name((input) => client.send(new import_client_ecs.RegisterTaskDefinitionCommand(input)), "registerTaskDefinition"),
          updateService: /* @__PURE__ */ __name((input) => client.send(new import_client_ecs.UpdateServiceCommand(input)), "updateService"),
          // Waiters
          waitUntilServicesStable: /* @__PURE__ */ __name((input, timeoutSeconds) => {
            return (0, import_client_ecs.waitUntilServicesStable)(
              {
                client,
                maxWaitTime: timeoutSeconds ?? 600,
                minDelay: 6,
                maxDelay: 6
              },
              input
            );
          }, "waitUntilServicesStable")
        };
      }
      elbv2() {
        const client = new import_client_elastic_load_balancing_v2.ElasticLoadBalancingV2Client(this.config);
        return {
          describeListeners: /* @__PURE__ */ __name((input) => client.send(new import_client_elastic_load_balancing_v2.DescribeListenersCommand(input)), "describeListeners"),
          describeLoadBalancers: /* @__PURE__ */ __name((input) => client.send(new import_client_elastic_load_balancing_v2.DescribeLoadBalancersCommand(input)), "describeLoadBalancers"),
          describeTags: /* @__PURE__ */ __name((input) => client.send(new import_client_elastic_load_balancing_v2.DescribeTagsCommand(input)), "describeTags"),
          // Pagination Functions
          paginateDescribeListeners: /* @__PURE__ */ __name(async (input) => {
            const listeners = Array();
            const paginator = (0, import_client_elastic_load_balancing_v2.paginateDescribeListeners)({ client }, input);
            for await (const page of paginator) {
              listeners.push(...page?.Listeners || []);
            }
            return listeners;
          }, "paginateDescribeListeners"),
          paginateDescribeLoadBalancers: /* @__PURE__ */ __name(async (input) => {
            const loadBalancers = Array();
            const paginator = (0, import_client_elastic_load_balancing_v2.paginateDescribeLoadBalancers)({ client }, input);
            for await (const page of paginator) {
              loadBalancers.push(...page?.LoadBalancers || []);
            }
            return loadBalancers;
          }, "paginateDescribeLoadBalancers")
        };
      }
      iam() {
        const client = new import_client_iam.IAMClient(this.config);
        return {
          createPolicy: /* @__PURE__ */ __name((input) => client.send(new import_client_iam.CreatePolicyCommand(input)), "createPolicy"),
          getPolicy: /* @__PURE__ */ __name((input) => client.send(new import_client_iam.GetPolicyCommand(input)), "getPolicy"),
          getRole: /* @__PURE__ */ __name((input) => client.send(new import_client_iam.GetRoleCommand(input)), "getRole")
        };
      }
      kms() {
        const client = new import_client_kms.KMSClient(this.config);
        return {
          describeKey: /* @__PURE__ */ __name((input) => client.send(new import_client_kms.DescribeKeyCommand(input)), "describeKey"),
          listAliases: /* @__PURE__ */ __name((input) => client.send(new import_client_kms.ListAliasesCommand(input)), "listAliases")
        };
      }
      lambda() {
        const client = new import_client_lambda.LambdaClient(this.config);
        return {
          invokeCommand: /* @__PURE__ */ __name((input) => client.send(new import_client_lambda.InvokeCommand(input)), "invokeCommand"),
          publishVersion: /* @__PURE__ */ __name((input) => client.send(new import_client_lambda.PublishVersionCommand(input)), "publishVersion"),
          updateAlias: /* @__PURE__ */ __name((input) => client.send(new import_client_lambda.UpdateAliasCommand(input)), "updateAlias"),
          updateFunctionCode: /* @__PURE__ */ __name((input) => client.send(new import_client_lambda.UpdateFunctionCodeCommand(input)), "updateFunctionCode"),
          updateFunctionConfiguration: /* @__PURE__ */ __name((input) => client.send(new import_client_lambda.UpdateFunctionConfigurationCommand(input)), "updateFunctionConfiguration"),
          // Waiters
          waitUntilFunctionUpdated: /* @__PURE__ */ __name((minDelaySeconds, maxDelaySeconds, input) => {
            return (0, import_client_lambda.waitUntilFunctionUpdatedV2)(
              {
                client,
                maxDelay: maxDelaySeconds,
                minDelay: minDelaySeconds,
                maxWaitTime: maxDelaySeconds * 60
              },
              input
            );
          }, "waitUntilFunctionUpdated")
        };
      }
      route53() {
        const client = new import_client_route_53.Route53Client(this.config);
        return {
          getHostedZone: /* @__PURE__ */ __name((input) => client.send(new import_client_route_53.GetHostedZoneCommand(input)), "getHostedZone"),
          listHostedZones: /* @__PURE__ */ __name((input) => client.send(new import_client_route_53.ListHostedZonesCommand(input)), "listHostedZones"),
          listHostedZonesByName: /* @__PURE__ */ __name((input) => client.send(new import_client_route_53.ListHostedZonesByNameCommand(input)), "listHostedZonesByName")
        };
      }
      s3() {
        const client = new import_client_s33.S3Client(this.config);
        return {
          deleteObjects: /* @__PURE__ */ __name((input) => client.send(new import_client_s33.DeleteObjectsCommand({
            ...input,
            ChecksumAlgorithm: "SHA256"
          })), "deleteObjects"),
          deleteObjectTagging: /* @__PURE__ */ __name((input) => client.send(new import_client_s33.DeleteObjectTaggingCommand(input)), "deleteObjectTagging"),
          getBucketEncryption: /* @__PURE__ */ __name((input) => client.send(new import_client_s33.GetBucketEncryptionCommand(input)), "getBucketEncryption"),
          getBucketLocation: /* @__PURE__ */ __name((input) => client.send(new import_client_s33.GetBucketLocationCommand(input)), "getBucketLocation"),
          getObject: /* @__PURE__ */ __name((input) => client.send(new import_client_s33.GetObjectCommand(input)), "getObject"),
          getObjectTagging: /* @__PURE__ */ __name((input) => client.send(new import_client_s33.GetObjectTaggingCommand(input)), "getObjectTagging"),
          listObjectsV2: /* @__PURE__ */ __name((input) => client.send(new import_client_s33.ListObjectsV2Command(input)), "listObjectsV2"),
          putObjectTagging: /* @__PURE__ */ __name((input) => client.send(new import_client_s33.PutObjectTaggingCommand({
            ...input,
            ChecksumAlgorithm: "SHA256"
          })), "putObjectTagging"),
          upload: /* @__PURE__ */ __name((input) => {
            try {
              const upload = new import_lib_storage2.Upload({
                client,
                params: { ...input, ChecksumAlgorithm: "SHA256" }
              });
              return upload.done();
            } catch (e32) {
              throw new AuthenticationError("S3UploadFailed", `Upload failed: ${formatErrorMessage(e32)}`);
            }
          }, "upload")
        };
      }
      secretsManager() {
        const client = new import_client_secrets_manager2.SecretsManagerClient(this.config);
        return {
          getSecretValue: /* @__PURE__ */ __name((input) => client.send(new import_client_secrets_manager2.GetSecretValueCommand(input)), "getSecretValue")
        };
      }
      ssm() {
        const client = new import_client_ssm.SSMClient(this.config);
        return {
          getParameter: /* @__PURE__ */ __name((input) => client.send(new import_client_ssm.GetParameterCommand(input)), "getParameter")
        };
      }
      stepFunctions() {
        const client = new import_client_sfn.SFNClient(this.config);
        return {
          updateStateMachine: /* @__PURE__ */ __name((input) => client.send(new import_client_sfn.UpdateStateMachineCommand(input)), "updateStateMachine")
        };
      }
      /**
       * The AWS SDK v3 requires a client config and a command in order to get an endpoint for
       * any given service.
       */
      async getUrlSuffix(region) {
        const cfn = new import_client_cloudformation5.CloudFormationClient({ region });
        const endpoint = await (0, import_middleware_endpoint73.getEndpointFromInstructions)({}, import_client_cloudformation5.DescribeStackResourcesCommand, { ...cfn.config });
        return endpoint.url.hostname.split(`${region}.`).pop();
      }
      async currentAccount() {
        return cachedAsync(this, CURRENT_ACCOUNT_KEY, async () => {
          const creds = await this.credProvider();
          return this.accountCache.fetch(creds.accessKeyId, async () => {
            await this.debug("Looking up default account ID from STS");
            const client = new import_client_sts2.STSClient({
              ...this.config,
              retryStrategy: this.stsRetryStrategy
            });
            const command = new import_client_sts2.GetCallerIdentityCommand({});
            const result2 = await client.send(command);
            const accountId = result2.Account;
            const partition4 = result2.Arn.split(":")[1];
            if (!accountId) {
              throw new AuthenticationError("NoAccountId", "STS didn't return an account ID");
            }
            await this.debug(`Default account ID: ${accountId}`);
            this._credentialsValidated = true;
            return { accountId, partition: partition4 };
          });
        });
      }
      /**
       * Make sure the the current credentials are not expired
       */
      async validateCredentials() {
        if (this._credentialsValidated) {
          return;
        }
        const client = new import_client_sts2.STSClient({ ...this.config, retryStrategy: this.stsRetryStrategy });
        await client.send(new import_client_sts2.GetCallerIdentityCommand({}));
        this._credentialsValidated = true;
      }
    };
    __name(SDK, "SDK");
    SDK = __decorateClass([
      traceMemberMethods
    ], SDK);
    CURRENT_ACCOUNT_KEY = /* @__PURE__ */ Symbol("current_account_key");
    __name(makeSdkLoggerSafeByBindingThis, "makeSdkLoggerSafeByBindingThis");
    __name(cappedExponentialBackoff, "cappedExponentialBackoff");
  }
});

// ../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.js
var require_ChecksumStream11 = __commonJS({
  "../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ChecksumStream = void 0;
    var util_base64_1 = require_dist_cjs10();
    var stream_1 = require("stream");
    var ChecksumStream5 = class extends stream_1.Duplex {
      static {
        __name(this, "ChecksumStream");
      }
      expectedChecksum;
      checksumSourceLocation;
      checksum;
      source;
      base64Encoder;
      pendingCallback = null;
      constructor({ expectedChecksum, checksum, source, checksumSourceLocation, base64Encoder }) {
        super();
        if (typeof source.pipe === "function") {
          this.source = source;
        } else {
          throw new Error(`@smithy/util-stream: unsupported source type ${source?.constructor?.name ?? source} in ChecksumStream.`);
        }
        this.base64Encoder = base64Encoder ?? util_base64_1.toBase64;
        this.expectedChecksum = expectedChecksum;
        this.checksum = checksum;
        this.checksumSourceLocation = checksumSourceLocation;
        this.source.pipe(this);
      }
      _read(size) {
        if (this.pendingCallback) {
          const callback = this.pendingCallback;
          this.pendingCallback = null;
          callback();
        }
      }
      _write(chunk, encoding, callback) {
        try {
          this.checksum.update(chunk);
          const canPushMore = this.push(chunk);
          if (!canPushMore) {
            this.pendingCallback = callback;
            return;
          }
        } catch (e32) {
          return callback(e32);
        }
        return callback();
      }
      async _final(callback) {
        try {
          const digest = await this.checksum.digest();
          const received = this.base64Encoder(digest);
          if (this.expectedChecksum !== received) {
            return callback(new Error(`Checksum mismatch: expected "${this.expectedChecksum}" but received "${received}" in response header "${this.checksumSourceLocation}".`));
          }
        } catch (e32) {
          return callback(e32);
        }
        this.push(null);
        return callback();
      }
    };
    exports2.ChecksumStream = ChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/stream-type-check.js
var require_stream_type_check11 = __commonJS({
  "../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/stream-type-check.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isBlob = exports2.isReadableStream = void 0;
    var isReadableStream6 = /* @__PURE__ */ __name((stream) => typeof ReadableStream === "function" && (stream?.constructor?.name === ReadableStream.name || stream instanceof ReadableStream), "isReadableStream");
    exports2.isReadableStream = isReadableStream6;
    var isBlob3 = /* @__PURE__ */ __name((blob) => {
      return typeof Blob === "function" && (blob?.constructor?.name === Blob.name || blob instanceof Blob);
    }, "isBlob");
    exports2.isBlob = isBlob3;
  }
});

// ../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.browser.js
var require_ChecksumStream_browser11 = __commonJS({
  "../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/checksum/ChecksumStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ChecksumStream = void 0;
    var ReadableStreamRef3 = typeof ReadableStream === "function" ? ReadableStream : function() {
    };
    var ChecksumStream5 = class extends ReadableStreamRef3 {
      static {
        __name(this, "ChecksumStream");
      }
    };
    exports2.ChecksumStream = ChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.browser.js
var require_createChecksumStream_browser11 = __commonJS({
  "../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createChecksumStream = void 0;
    var util_base64_1 = require_dist_cjs10();
    var stream_type_check_1 = require_stream_type_check11();
    var ChecksumStream_browser_1 = require_ChecksumStream_browser11();
    var createChecksumStream5 = /* @__PURE__ */ __name(({ expectedChecksum, checksum, source, checksumSourceLocation, base64Encoder }) => {
      if (!(0, stream_type_check_1.isReadableStream)(source)) {
        throw new Error(`@smithy/util-stream: unsupported source type ${source?.constructor?.name ?? source} in ChecksumStream.`);
      }
      const encoder = base64Encoder ?? util_base64_1.toBase64;
      if (typeof TransformStream !== "function") {
        throw new Error("@smithy/util-stream: unable to instantiate ChecksumStream because API unavailable: ReadableStream/TransformStream.");
      }
      const transform = new TransformStream({
        start() {
        },
        async transform(chunk, controller) {
          checksum.update(chunk);
          controller.enqueue(chunk);
        },
        async flush(controller) {
          const digest = await checksum.digest();
          const received = encoder(digest);
          if (expectedChecksum !== received) {
            const error4 = new Error(`Checksum mismatch: expected "${expectedChecksum}" but received "${received}" in response header "${checksumSourceLocation}".`);
            controller.error(error4);
          } else {
            controller.terminate();
          }
        }
      });
      source.pipeThrough(transform);
      const readable = transform.readable;
      Object.setPrototypeOf(readable, ChecksumStream_browser_1.ChecksumStream.prototype);
      return readable;
    }, "createChecksumStream");
    exports2.createChecksumStream = createChecksumStream5;
  }
});

// ../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.js
var require_createChecksumStream11 = __commonJS({
  "../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/checksum/createChecksumStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createChecksumStream = createChecksumStream5;
    var stream_type_check_1 = require_stream_type_check11();
    var ChecksumStream_1 = require_ChecksumStream11();
    var createChecksumStream_browser_1 = require_createChecksumStream_browser11();
    function createChecksumStream5(init) {
      if (typeof ReadableStream === "function" && (0, stream_type_check_1.isReadableStream)(init.source)) {
        return (0, createChecksumStream_browser_1.createChecksumStream)(init);
      }
      return new ChecksumStream_1.ChecksumStream(init);
    }
    __name(createChecksumStream5, "createChecksumStream");
  }
});

// ../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/ByteArrayCollector.js
var require_ByteArrayCollector11 = __commonJS({
  "../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/ByteArrayCollector.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ByteArrayCollector = void 0;
    var ByteArrayCollector3 = class {
      static {
        __name(this, "ByteArrayCollector");
      }
      allocByteArray;
      byteLength = 0;
      byteArrays = [];
      constructor(allocByteArray) {
        this.allocByteArray = allocByteArray;
      }
      push(byteArray) {
        this.byteArrays.push(byteArray);
        this.byteLength += byteArray.byteLength;
      }
      flush() {
        if (this.byteArrays.length === 1) {
          const bytes = this.byteArrays[0];
          this.reset();
          return bytes;
        }
        const aggregation = this.allocByteArray(this.byteLength);
        let cursor3 = 0;
        for (let i32 = 0; i32 < this.byteArrays.length; ++i32) {
          const bytes = this.byteArrays[i32];
          aggregation.set(bytes, cursor3);
          cursor3 += bytes.byteLength;
        }
        this.reset();
        return aggregation;
      }
      reset() {
        this.byteArrays = [];
        this.byteLength = 0;
      }
    };
    exports2.ByteArrayCollector = ByteArrayCollector3;
  }
});

// ../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadableStream.js
var require_createBufferedReadableStream11 = __commonJS({
  "../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadableStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createBufferedReadable = void 0;
    exports2.createBufferedReadableStream = createBufferedReadableStream3;
    exports2.merge = merge3;
    exports2.flush = flush3;
    exports2.sizeOf = sizeOf3;
    exports2.modeOf = modeOf3;
    var ByteArrayCollector_1 = require_ByteArrayCollector11();
    function createBufferedReadableStream3(upstream, size, logger5) {
      const reader = upstream.getReader();
      let streamBufferingLoggedWarning = false;
      let bytesSeen = 0;
      const buffers = ["", new ByteArrayCollector_1.ByteArrayCollector((size2) => new Uint8Array(size2))];
      let mode = -1;
      const pull = /* @__PURE__ */ __name(async (controller) => {
        const { value, done } = await reader.read();
        const chunk = value;
        if (done) {
          if (mode !== -1) {
            const remainder = flush3(buffers, mode);
            if (sizeOf3(remainder) > 0) {
              controller.enqueue(remainder);
            }
          }
          controller.close();
        } else {
          const chunkMode = modeOf3(chunk, false);
          if (mode !== chunkMode) {
            if (mode >= 0) {
              controller.enqueue(flush3(buffers, mode));
            }
            mode = chunkMode;
          }
          if (mode === -1) {
            controller.enqueue(chunk);
            return;
          }
          const chunkSize = sizeOf3(chunk);
          bytesSeen += chunkSize;
          const bufferSize = sizeOf3(buffers[mode]);
          if (chunkSize >= size && bufferSize === 0) {
            controller.enqueue(chunk);
          } else {
            const newSize = merge3(buffers, mode, chunk);
            if (!streamBufferingLoggedWarning && bytesSeen > size * 2) {
              streamBufferingLoggedWarning = true;
              logger5?.warn(`@smithy/util-stream - stream chunk size ${chunkSize} is below threshold of ${size}, automatically buffering.`);
            }
            if (newSize >= size) {
              controller.enqueue(flush3(buffers, mode));
            } else {
              await pull(controller);
            }
          }
        }
      }, "pull");
      return new ReadableStream({
        pull
      });
    }
    __name(createBufferedReadableStream3, "createBufferedReadableStream");
    exports2.createBufferedReadable = createBufferedReadableStream3;
    function merge3(buffers, mode, chunk) {
      switch (mode) {
        case 0:
          buffers[0] += chunk;
          return sizeOf3(buffers[0]);
        case 1:
        case 2:
          buffers[mode].push(chunk);
          return sizeOf3(buffers[mode]);
      }
    }
    __name(merge3, "merge");
    function flush3(buffers, mode) {
      switch (mode) {
        case 0:
          const s = buffers[0];
          buffers[0] = "";
          return s;
        case 1:
        case 2:
          return buffers[mode].flush();
      }
      throw new Error(`@smithy/util-stream - invalid index ${mode} given to flush()`);
    }
    __name(flush3, "flush");
    function sizeOf3(chunk) {
      return chunk?.byteLength ?? chunk?.length ?? 0;
    }
    __name(sizeOf3, "sizeOf");
    function modeOf3(chunk, allowBuffer = true) {
      if (allowBuffer && typeof Buffer !== "undefined" && chunk instanceof Buffer) {
        return 2;
      }
      if (chunk instanceof Uint8Array) {
        return 1;
      }
      if (typeof chunk === "string") {
        return 0;
      }
      return -1;
    }
    __name(modeOf3, "modeOf");
  }
});

// ../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadable.js
var require_createBufferedReadable11 = __commonJS({
  "../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/createBufferedReadable.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.createBufferedReadable = createBufferedReadable3;
    var node_stream_1 = require("node:stream");
    var ByteArrayCollector_1 = require_ByteArrayCollector11();
    var createBufferedReadableStream_1 = require_createBufferedReadableStream11();
    var stream_type_check_1 = require_stream_type_check11();
    function createBufferedReadable3(upstream, size, logger5) {
      if ((0, stream_type_check_1.isReadableStream)(upstream)) {
        return (0, createBufferedReadableStream_1.createBufferedReadableStream)(upstream, size, logger5);
      }
      const downstream = new node_stream_1.Readable({ read() {
      } });
      let streamBufferingLoggedWarning = false;
      let bytesSeen = 0;
      const buffers = [
        "",
        new ByteArrayCollector_1.ByteArrayCollector((size2) => new Uint8Array(size2)),
        new ByteArrayCollector_1.ByteArrayCollector((size2) => Buffer.from(new Uint8Array(size2)))
      ];
      let mode = -1;
      upstream.on("data", (chunk) => {
        const chunkMode = (0, createBufferedReadableStream_1.modeOf)(chunk, true);
        if (mode !== chunkMode) {
          if (mode >= 0) {
            downstream.push((0, createBufferedReadableStream_1.flush)(buffers, mode));
          }
          mode = chunkMode;
        }
        if (mode === -1) {
          downstream.push(chunk);
          return;
        }
        const chunkSize = (0, createBufferedReadableStream_1.sizeOf)(chunk);
        bytesSeen += chunkSize;
        const bufferSize = (0, createBufferedReadableStream_1.sizeOf)(buffers[mode]);
        if (chunkSize >= size && bufferSize === 0) {
          downstream.push(chunk);
        } else {
          const newSize = (0, createBufferedReadableStream_1.merge)(buffers, mode, chunk);
          if (!streamBufferingLoggedWarning && bytesSeen > size * 2) {
            streamBufferingLoggedWarning = true;
            logger5?.warn(`@smithy/util-stream - stream chunk size ${chunkSize} is below threshold of ${size}, automatically buffering.`);
          }
          if (newSize >= size) {
            downstream.push((0, createBufferedReadableStream_1.flush)(buffers, mode));
          }
        }
      });
      upstream.on("end", () => {
        if (mode !== -1) {
          const remainder = (0, createBufferedReadableStream_1.flush)(buffers, mode);
          if ((0, createBufferedReadableStream_1.sizeOf)(remainder) > 0) {
            downstream.push(remainder);
          }
        }
        downstream.push(null);
      });
      return downstream;
    }
    __name(createBufferedReadable3, "createBufferedReadable");
  }
});

// ../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.browser.js
var require_getAwsChunkedEncodingStream_browser11 = __commonJS({
  "../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getAwsChunkedEncodingStream = void 0;
    var getAwsChunkedEncodingStream5 = /* @__PURE__ */ __name((readableStream, options) => {
      const { base64Encoder, bodyLengthChecker, checksumAlgorithmFn, checksumLocationName, streamHasher } = options;
      const checksumRequired = base64Encoder !== void 0 && bodyLengthChecker !== void 0 && checksumAlgorithmFn !== void 0 && checksumLocationName !== void 0 && streamHasher !== void 0;
      const digest = checksumRequired ? streamHasher(checksumAlgorithmFn, readableStream) : void 0;
      const reader = readableStream.getReader();
      return new ReadableStream({
        async pull(controller) {
          const { value, done } = await reader.read();
          if (done) {
            controller.enqueue(`0\r
`);
            if (checksumRequired) {
              const checksum = base64Encoder(await digest);
              controller.enqueue(`${checksumLocationName}:${checksum}\r
`);
              controller.enqueue(`\r
`);
            }
            controller.close();
          } else {
            controller.enqueue(`${(bodyLengthChecker(value) || 0).toString(16)}\r
${value}\r
`);
          }
        }
      });
    }, "getAwsChunkedEncodingStream");
    exports2.getAwsChunkedEncodingStream = getAwsChunkedEncodingStream5;
  }
});

// ../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.js
var require_getAwsChunkedEncodingStream11 = __commonJS({
  "../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/getAwsChunkedEncodingStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getAwsChunkedEncodingStream = getAwsChunkedEncodingStream5;
    var node_stream_1 = require("node:stream");
    var getAwsChunkedEncodingStream_browser_1 = require_getAwsChunkedEncodingStream_browser11();
    var stream_type_check_1 = require_stream_type_check11();
    function getAwsChunkedEncodingStream5(stream, options) {
      const readable = stream;
      const readableStream = stream;
      if ((0, stream_type_check_1.isReadableStream)(readableStream)) {
        return (0, getAwsChunkedEncodingStream_browser_1.getAwsChunkedEncodingStream)(readableStream, options);
      }
      const { base64Encoder, bodyLengthChecker, checksumAlgorithmFn, checksumLocationName, streamHasher } = options;
      const checksumRequired = base64Encoder !== void 0 && checksumAlgorithmFn !== void 0 && checksumLocationName !== void 0 && streamHasher !== void 0;
      const digest = checksumRequired ? streamHasher(checksumAlgorithmFn, readable) : void 0;
      const awsChunkedEncodingStream = new node_stream_1.Readable({
        read: /* @__PURE__ */ __name(() => {
        }, "read")
      });
      readable.on("data", (data3) => {
        const length = bodyLengthChecker(data3) || 0;
        if (length === 0) {
          return;
        }
        awsChunkedEncodingStream.push(`${length.toString(16)}\r
`);
        awsChunkedEncodingStream.push(data3);
        awsChunkedEncodingStream.push("\r\n");
      });
      readable.on("end", async () => {
        awsChunkedEncodingStream.push(`0\r
`);
        if (checksumRequired) {
          const checksum = base64Encoder(await digest);
          awsChunkedEncodingStream.push(`${checksumLocationName}:${checksum}\r
`);
          awsChunkedEncodingStream.push(`\r
`);
        }
        awsChunkedEncodingStream.push(null);
      });
      return awsChunkedEncodingStream;
    }
    __name(getAwsChunkedEncodingStream5, "getAwsChunkedEncodingStream");
  }
});

// ../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/headStream.browser.js
var require_headStream_browser11 = __commonJS({
  "../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/headStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.headStream = headStream5;
    async function headStream5(stream, bytes) {
      let byteLengthCounter = 0;
      const chunks2 = [];
      const reader = stream.getReader();
      let isDone = false;
      while (!isDone) {
        const { done, value } = await reader.read();
        if (value) {
          chunks2.push(value);
          byteLengthCounter += value?.byteLength ?? 0;
        }
        if (byteLengthCounter >= bytes) {
          break;
        }
        isDone = done;
      }
      reader.releaseLock();
      const collected = new Uint8Array(Math.min(bytes, byteLengthCounter));
      let offset = 0;
      for (const chunk of chunks2) {
        if (chunk.byteLength > collected.byteLength - offset) {
          collected.set(chunk.subarray(0, collected.byteLength - offset), offset);
          break;
        } else {
          collected.set(chunk, offset);
        }
        offset += chunk.length;
      }
      return collected;
    }
    __name(headStream5, "headStream");
  }
});

// ../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/headStream.js
var require_headStream11 = __commonJS({
  "../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/headStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.headStream = void 0;
    var stream_1 = require("stream");
    var headStream_browser_1 = require_headStream_browser11();
    var stream_type_check_1 = require_stream_type_check11();
    var headStream5 = /* @__PURE__ */ __name((stream, bytes) => {
      if ((0, stream_type_check_1.isReadableStream)(stream)) {
        return (0, headStream_browser_1.headStream)(stream, bytes);
      }
      return new Promise((resolve13, reject) => {
        const collector = new Collector8();
        collector.limit = bytes;
        stream.pipe(collector);
        stream.on("error", (err) => {
          collector.end();
          reject(err);
        });
        collector.on("error", reject);
        collector.on("finish", function() {
          const bytes2 = new Uint8Array(Buffer.concat(this.buffers));
          resolve13(bytes2);
        });
      });
    }, "headStream");
    exports2.headStream = headStream5;
    var Collector8 = class extends stream_1.Writable {
      static {
        __name(this, "Collector");
      }
      buffers = [];
      limit = Infinity;
      bytesBuffered = 0;
      _write(chunk, encoding, callback) {
        this.buffers.push(chunk);
        this.bytesBuffered += chunk.byteLength ?? 0;
        if (this.bytesBuffered >= this.limit) {
          const excess = this.bytesBuffered - this.limit;
          const tailBuffer = this.buffers[this.buffers.length - 1];
          this.buffers[this.buffers.length - 1] = tailBuffer.subarray(0, tailBuffer.byteLength - excess);
          this.emit("finish");
        }
        callback();
      }
    };
  }
});

// ../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.browser.js
var require_sdk_stream_mixin_browser11 = __commonJS({
  "../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.sdkStreamMixin = void 0;
    var fetch_http_handler_1 = require_dist_cjs14();
    var util_base64_1 = require_dist_cjs10();
    var util_hex_encoding_1 = require_dist_cjs15();
    var util_utf8_1 = require_dist_cjs9();
    var stream_type_check_1 = require_stream_type_check11();
    var ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11 = "The stream has already been transformed.";
    var sdkStreamMixin12 = /* @__PURE__ */ __name((stream) => {
      if (!isBlobInstance6(stream) && !(0, stream_type_check_1.isReadableStream)(stream)) {
        const name = stream?.__proto__?.constructor?.name || stream;
        throw new Error(`Unexpected stream implementation, expect Blob or ReadableStream, got ${name}`);
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
        }
        transformed = true;
        return await (0, fetch_http_handler_1.streamCollector)(stream);
      }, "transformToByteArray");
      const blobToWebStream = /* @__PURE__ */ __name((blob) => {
        if (typeof blob.stream !== "function") {
          throw new Error("Cannot transform payload Blob to web stream. Please make sure the Blob.stream() is polyfilled.\nIf you are using React Native, this API is not yet supported, see: https://react-native.canny.io/feature-requests/p/fetch-streaming-body");
        }
        return blob.stream();
      }, "blobToWebStream");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === "base64") {
            return (0, util_base64_1.toBase64)(buf);
          } else if (encoding === "hex") {
            return (0, util_hex_encoding_1.toHex)(buf);
          } else if (encoding === void 0 || encoding === "utf8" || encoding === "utf-8") {
            return (0, util_utf8_1.toUtf8)(buf);
          } else if (typeof TextDecoder === "function") {
            return new TextDecoder(encoding).decode(buf);
          } else {
            throw new Error("TextDecoder is not available, please make sure polyfill is provided.");
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
          }
          transformed = true;
          if (isBlobInstance6(stream)) {
            return blobToWebStream(stream);
          } else if ((0, stream_type_check_1.isReadableStream)(stream)) {
            return stream;
          } else {
            throw new Error(`Cannot transform payload to web stream, got ${stream}`);
          }
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
    exports2.sdkStreamMixin = sdkStreamMixin12;
    var isBlobInstance6 = /* @__PURE__ */ __name((stream) => typeof Blob === "function" && stream instanceof Blob, "isBlobInstance");
  }
});

// ../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.js
var require_sdk_stream_mixin11 = __commonJS({
  "../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/sdk-stream-mixin.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.sdkStreamMixin = void 0;
    var node_http_handler_1 = require_dist_cjs13();
    var util_buffer_from_1 = require_dist_cjs8();
    var stream_1 = require("stream");
    var sdk_stream_mixin_browser_1 = require_sdk_stream_mixin_browser11();
    var ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11 = "The stream has already been transformed.";
    var sdkStreamMixin12 = /* @__PURE__ */ __name((stream) => {
      if (!(stream instanceof stream_1.Readable)) {
        try {
          return (0, sdk_stream_mixin_browser_1.sdkStreamMixin)(stream);
        } catch (e32) {
          const name = stream?.__proto__?.constructor?.name || stream;
          throw new Error(`Unexpected stream implementation, expect Stream.Readable instance, got ${name}`);
        }
      }
      let transformed = false;
      const transformToByteArray = /* @__PURE__ */ __name(async () => {
        if (transformed) {
          throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
        }
        transformed = true;
        return await (0, node_http_handler_1.streamCollector)(stream);
      }, "transformToByteArray");
      return Object.assign(stream, {
        transformToByteArray,
        transformToString: /* @__PURE__ */ __name(async (encoding) => {
          const buf = await transformToByteArray();
          if (encoding === void 0 || Buffer.isEncoding(encoding)) {
            return (0, util_buffer_from_1.fromArrayBuffer)(buf.buffer, buf.byteOffset, buf.byteLength).toString(encoding);
          } else {
            const decoder = new TextDecoder(encoding);
            return decoder.decode(buf);
          }
        }, "transformToString"),
        transformToWebStream: /* @__PURE__ */ __name(() => {
          if (transformed) {
            throw new Error(ERR_MSG_STREAM_HAS_BEEN_TRANSFORMED11);
          }
          if (stream.readableFlowing !== null) {
            throw new Error("The stream has been consumed by other callbacks.");
          }
          if (typeof stream_1.Readable.toWeb !== "function") {
            throw new Error("Readable.toWeb() is not supported. Please ensure a polyfill is available.");
          }
          transformed = true;
          return stream_1.Readable.toWeb(stream);
        }, "transformToWebStream")
      });
    }, "sdkStreamMixin");
    exports2.sdkStreamMixin = sdkStreamMixin12;
  }
});

// ../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/splitStream.browser.js
var require_splitStream_browser11 = __commonJS({
  "../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/splitStream.browser.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.splitStream = splitStream5;
    async function splitStream5(stream) {
      if (typeof stream.stream === "function") {
        stream = stream.stream();
      }
      const readableStream = stream;
      return readableStream.tee();
    }
    __name(splitStream5, "splitStream");
  }
});

// ../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/splitStream.js
var require_splitStream11 = __commonJS({
  "../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/splitStream.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.splitStream = splitStream5;
    var stream_1 = require("stream");
    var splitStream_browser_1 = require_splitStream_browser11();
    var stream_type_check_1 = require_stream_type_check11();
    async function splitStream5(stream) {
      if ((0, stream_type_check_1.isReadableStream)(stream) || (0, stream_type_check_1.isBlob)(stream)) {
        return (0, splitStream_browser_1.splitStream)(stream);
      }
      const stream1 = new stream_1.PassThrough();
      const stream2 = new stream_1.PassThrough();
      stream.pipe(stream1);
      stream.pipe(stream2);
      return [stream1, stream2];
    }
    __name(splitStream5, "splitStream");
  }
});

// ../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/index.js
var require_dist_cjs211 = __commonJS({
  "../../node_modules/@aws-sdk/ec2-metadata-service/node_modules/@smithy/util-stream/dist-cjs/index.js"(exports2) {
    "use strict";
    var utilBase64 = require_dist_cjs10();
    var utilUtf8 = require_dist_cjs9();
    var ChecksumStream5 = require_ChecksumStream11();
    var createChecksumStream5 = require_createChecksumStream11();
    var createBufferedReadable3 = require_createBufferedReadable11();
    var getAwsChunkedEncodingStream5 = require_getAwsChunkedEncodingStream11();
    var headStream5 = require_headStream11();
    var sdkStreamMixin12 = require_sdk_stream_mixin11();
    var splitStream5 = require_splitStream11();
    var streamTypeCheck = require_stream_type_check11();
    var Uint8ArrayBlobAdapter8 = class _Uint8ArrayBlobAdapter extends Uint8Array {
      static {
        __name(this, "Uint8ArrayBlobAdapter");
      }
      static fromString(source, encoding = "utf-8") {
        if (typeof source === "string") {
          if (encoding === "base64") {
            return _Uint8ArrayBlobAdapter.mutate(utilBase64.fromBase64(source));
          }
          return _Uint8ArrayBlobAdapter.mutate(utilUtf8.fromUtf8(source));
        }
        throw new Error(`Unsupported conversion from ${typeof source} to Uint8ArrayBlobAdapter.`);
      }
      static mutate(source) {
        Object.setPrototypeOf(source, _Uint8ArrayBlobAdapter.prototype);
        return source;
      }
      transformToString(encoding = "utf-8") {
        if (encoding === "base64") {
          return utilBase64.toBase64(this);
        }
        return utilUtf8.toUtf8(this);
      }
    };
    exports2.isBlob = streamTypeCheck.isBlob;
    exports2.isReadableStream = streamTypeCheck.isReadableStream;
    exports2.Uint8ArrayBlobAdapter = Uint8ArrayBlobAdapter8;
    Object.prototype.hasOwnProperty.call(ChecksumStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: ChecksumStream5["__proto__"]
    });
    Object.keys(ChecksumStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = ChecksumStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(createChecksumStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: createChecksumStream5["__proto__"]
    });
    Object.keys(createChecksumStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = createChecksumStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(createBufferedReadable3, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: createBufferedReadable3["__proto__"]
    });
    Object.keys(createBufferedReadable3).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = createBufferedReadable3[k32];
    });
    Object.prototype.hasOwnProperty.call(getAwsChunkedEncodingStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: getAwsChunkedEncodingStream5["__proto__"]
    });
    Object.keys(getAwsChunkedEncodingStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = getAwsChunkedEncodingStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(headStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: headStream5["__proto__"]
    });
    Object.keys(headStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = headStream5[k32];
    });
    Object.prototype.hasOwnProperty.call(sdkStreamMixin12, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: sdkStreamMixin12["__proto__"]
    });
    Object.keys(sdkStreamMixin12).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = sdkStreamMixin12[k32];
    });
    Object.prototype.hasOwnProperty.call(splitStream5, "__proto__") && !Object.prototype.hasOwnProperty.call(exports2, "__proto__") && Object.defineProperty(exports2, "__proto__", {
      enumerable: true,
      value: splitStream5["__proto__"]
    });
    Object.keys(splitStream5).forEach(function(k32) {
      if (k32 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, k32)) exports2[k32] = splitStream5[k32];
    });
  }
});

// ../../node_modules/@aws-sdk/ec2-metadata-service/dist-cjs/index.js
var require_dist_cjs212 = __commonJS({
  "../../node_modules/@aws-sdk/ec2-metadata-service/dist-cjs/index.js"(exports2) {
    "use strict";
    var nodeConfigProvider = require_dist_cjs29();
    var nodeHttpHandler = require_dist_cjs13();
    var protocolHttp = require_dist_cjs2();
    var utilStream = require_dist_cjs211();
    var Endpoint;
    (function(Endpoint2) {
      Endpoint2["IPv4"] = "http://169.254.169.254";
      Endpoint2["IPv6"] = "http://[fd00:ec2::254]";
    })(Endpoint || (Endpoint = {}));
    var EndpointMode;
    (function(EndpointMode2) {
      EndpointMode2["IPv4"] = "IPv4";
      EndpointMode2["IPv6"] = "IPv6";
    })(EndpointMode || (EndpointMode = {}));
    var ENV_ENDPOINT_NAME = "AWS_EC2_METADATA_SERVICE_ENDPOINT";
    var CONFIG_ENDPOINT_NAME = "ec2_metadata_service_endpoint";
    var ENDPOINT_SELECTORS = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[ENV_ENDPOINT_NAME], "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[CONFIG_ENDPOINT_NAME], "configFileSelector"),
      default: Endpoint.IPv4
    };
    ({
      default: EndpointMode.IPv4
    });
    var AWS_EC2_METADATA_V1_DISABLED = "AWS_EC2_METADATA_V1_DISABLED";
    var PROFILE_AWS_EC2_METADATA_V1_DISABLED = "ec2_metadata_v1_disabled";
    var IMDSv1_DISABLED_SELECTORS = {
      environmentVariableSelector: /* @__PURE__ */ __name((env3) => env3[AWS_EC2_METADATA_V1_DISABLED] ? env3[AWS_EC2_METADATA_V1_DISABLED] !== "false" : void 0, "environmentVariableSelector"),
      configFileSelector: /* @__PURE__ */ __name((profile) => profile[PROFILE_AWS_EC2_METADATA_V1_DISABLED] ? profile[PROFILE_AWS_EC2_METADATA_V1_DISABLED] !== "false" : void 0, "configFileSelector"),
      default: false
    };
    var MetadataService2 = class {
      static {
        __name(this, "MetadataService");
      }
      disableFetchToken;
      config;
      retries;
      backoffFn;
      tokenTtl;
      port;
      constructor(options = {}) {
        this.config = (async () => {
          const profile = options?.profile || process.env.AWS_PROFILE;
          return {
            endpoint: options.endpoint ?? await nodeConfigProvider.loadConfig(ENDPOINT_SELECTORS, { profile })(),
            httpOptions: {
              timeout: options?.httpOptions?.timeout || 0
            },
            ec2MetadataV1Disabled: options?.ec2MetadataV1Disabled ?? await nodeConfigProvider.loadConfig(IMDSv1_DISABLED_SELECTORS, { profile })()
          };
        })();
        this.disableFetchToken = options?.disableFetchToken || false;
        this.retries = options?.retries ?? 3;
        this.backoffFn = this.createBackoffFunction(options?.backoff);
        this.tokenTtl = this.validateTokenTtl(options?.tokenTtl ?? 21600);
        this.port = options?.port;
      }
      validateTokenTtl(tokenTtl) {
        if (!Number.isInteger(tokenTtl) || tokenTtl <= 0) {
          throw new Error("tokenTtl must be a positive integer");
        }
        return tokenTtl;
      }
      resolvePort(endpointUrl) {
        if (this.port !== void 0) {
          return this.port;
        }
        if (endpointUrl.port) {
          return parseInt(endpointUrl.port);
        }
        return void 0;
      }
      createBackoffFunction(backoff) {
        if (typeof backoff === "function") {
          return backoff;
        }
        if (typeof backoff === "number") {
          return () => backoff;
        }
        return (numFailures) => Math.pow(1.2, numFailures);
      }
      sleep(ms) {
        return new Promise((resolve13) => setTimeout(resolve13, ms));
      }
      async retryWithBackoff(operation3) {
        let lastError;
        for (let attempt = 0; attempt <= this.retries; attempt++) {
          try {
            return await operation3();
          } catch (error4) {
            lastError = error4;
            if (attempt === this.retries) {
              break;
            }
            if (this.shouldNotRetry(error4)) {
              throw error4;
            }
            const backoffResult = this.backoffFn(attempt);
            if (typeof backoffResult === "number") {
              await this.sleep(backoffResult * 1e3);
            } else {
              await backoffResult;
            }
          }
        }
        throw lastError;
      }
      shouldNotRetry(error4) {
        const statusCode = error4.statusCode || error4.$metadata?.httpStatusCode;
        return statusCode === 400 || statusCode === 403 || statusCode === 404;
      }
      async request(path47, options) {
        return this.retryWithBackoff(async () => {
          const { endpoint, ec2MetadataV1Disabled, httpOptions } = await this.config;
          const handler = new nodeHttpHandler.NodeHttpHandler({
            requestTimeout: httpOptions?.timeout,
            throwOnRequestTimeout: true,
            connectionTimeout: httpOptions?.timeout
          });
          const endpointUrl = new URL(endpoint);
          const headers = options.headers || {};
          if (this.disableFetchToken && ec2MetadataV1Disabled) {
            throw new Error("IMDSv1 is disabled and fetching token is disabled, cannot make the request.");
          }
          if (!this.disableFetchToken) {
            try {
              headers["x-aws-ec2-metadata-token"] = await this.fetchMetadataTokenInternal();
            } catch (err) {
              if (ec2MetadataV1Disabled) {
                throw err;
              }
            }
          }
          const request4 = new protocolHttp.HttpRequest({
            method: options.method || "GET",
            headers,
            hostname: endpointUrl.hostname,
            path: endpointUrl.pathname + path47,
            protocol: endpointUrl.protocol,
            port: this.resolvePort(endpointUrl)
          });
          try {
            const { response } = await handler.handle(request4, {});
            if (response.statusCode === 200 && response.body) {
              return utilStream.sdkStreamMixin(response.body).transformToString();
            } else {
              throw Object.assign(new Error(`Request failed with status code ${response.statusCode}`), {
                $metadata: { httpStatusCode: response.statusCode }
              });
            }
          } catch (error4) {
            const wrappedError = new Error(`Error making request to the metadata service: ${error4}`);
            const { $metadata } = error4;
            if ($metadata?.httpStatusCode !== void 0) {
              Object.assign(wrappedError, { $metadata });
            }
            throw wrappedError;
          }
        });
      }
      async fetchMetadataToken() {
        return this.retryWithBackoff(() => this.fetchMetadataTokenInternal());
      }
      async fetchMetadataTokenInternal() {
        const { endpoint, httpOptions } = await this.config;
        const handler = new nodeHttpHandler.NodeHttpHandler({
          requestTimeout: httpOptions?.timeout,
          throwOnRequestTimeout: true,
          connectionTimeout: httpOptions?.timeout
        });
        const endpointUrl = new URL(endpoint);
        const tokenRequest = new protocolHttp.HttpRequest({
          method: "PUT",
          headers: {
            "x-aws-ec2-metadata-token-ttl-seconds": String(this.tokenTtl)
          },
          hostname: endpointUrl.hostname,
          path: "/latest/api/token",
          protocol: endpointUrl.protocol,
          port: this.resolvePort(endpointUrl)
        });
        try {
          const { response } = await handler.handle(tokenRequest, {});
          let bodyString = "";
          if (response.body) {
            bodyString = await utilStream.sdkStreamMixin(response.body).transformToString();
          }
          if (response.statusCode === 200 && bodyString) {
            return bodyString;
          } else {
            throw Object.assign(new Error(`Failed to fetch metadata token with status code ${response.statusCode}`), {
              $metadata: { httpStatusCode: response.statusCode }
            });
          }
        } catch (error4) {
          if (error4.message === "TimeoutError" || [403, 404, 405].includes(error4.statusCode || error4.$metadata?.httpStatusCode)) {
            this.disableFetchToken = true;
            throw new Error(`Error fetching metadata token: ${error4}. [disableFetchToken] is now set to true.`);
          }
          throw new Error(`Error fetching metadata token: ${error4}`);
        }
      }
    };
    exports2.MetadataService = MetadataService2;
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/aws-auth/ec2-detection.ts
function isEc2Instance() {
  if (cachedIsEc2 !== void 0) {
    return cachedIsEc2;
  }
  cachedIsEc2 = detectEc2();
  return cachedIsEc2;
}
function detectEc2() {
  const os14 = (0, import_node_os6.platform)();
  try {
    if (os14 === "linux") {
      return detectEc2Linux();
    }
    if (os14 === "win32") {
      return detectEc2Windows();
    }
    return false;
  } catch {
    return true;
  }
}
function detectEc2Linux() {
  const boardAssetTag = "/sys/devices/virtual/dmi/id/board_asset_tag";
  if ((0, import_node_fs3.existsSync)(boardAssetTag)) {
    const tag3 = (0, import_node_fs3.readFileSync)(boardAssetTag, "utf-8").trim();
    if (tag3.startsWith("i-")) {
      return true;
    }
  }
  const hypervisorUuid = "/sys/hypervisor/uuid";
  if ((0, import_node_fs3.existsSync)(hypervisorUuid)) {
    const uuid = (0, import_node_fs3.readFileSync)(hypervisorUuid, "utf-8").trim().toLowerCase();
    if (uuid.startsWith("ec2")) {
      return true;
    }
  }
  return false;
}
function detectEc2Windows() {
  const tag3 = (0, import_node_child_process.execSync)(
    'reg query "HKLM\\SYSTEM\\HardwareConfig\\Current" /v BaseBoardAssetTag 2>nul',
    { encoding: "utf-8", timeout: 500 }
  ).trim();
  if (/i-[0-9a-f]+/i.test(tag3)) {
    return true;
  }
  return false;
}
var import_node_child_process, import_node_fs3, import_node_os6, cachedIsEc2;
var init_ec2_detection = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/aws-auth/ec2-detection.ts"() {
    "use strict";
    import_node_child_process = require("node:child_process");
    import_node_fs3 = require("node:fs");
    import_node_os6 = require("node:os");
    __name(isEc2Instance, "isEc2Instance");
    __name(detectEc2, "detectEc2");
    __name(detectEc2Linux, "detectEc2Linux");
    __name(detectEc2Windows, "detectEc2Windows");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/aws-auth/provider-caching.ts
function makeCachingProvider(provider) {
  return (0, import_property_provider10.memoize)(
    provider,
    credentialsAboutToExpire,
    (token) => !!token.expiration
  );
}
function credentialsAboutToExpire(token) {
  const expiryMarginSecs = 5;
  return !!token.expiration && token.expiration.getTime() - Date.now() < expiryMarginSecs * 1e3;
}
var import_property_provider10;
var init_provider_caching = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/aws-auth/provider-caching.ts"() {
    "use strict";
    import_property_provider10 = __toESM(require_dist_cjs27());
    __name(makeCachingProvider, "makeCachingProvider");
    __name(credentialsAboutToExpire, "credentialsAboutToExpire");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/aws-auth/awscli-compatible.ts
function shouldPrioritizeEnv() {
  const id = process.env.AWS_ACCESS_KEY_ID || process.env.AMAZON_ACCESS_KEY_ID;
  const key = process.env.AWS_SECRET_ACCESS_KEY || process.env.AMAZON_SECRET_ACCESS_KEY;
  if (!!id && !!key) {
    process.env.AWS_ACCESS_KEY_ID = id;
    process.env.AWS_SECRET_ACCESS_KEY = key;
    const sessionToken = process.env.AWS_SESSION_TOKEN ?? process.env.AMAZON_SESSION_TOKEN;
    if (sessionToken) {
      process.env.AWS_SESSION_TOKEN = sessionToken;
    }
    return true;
  }
  return false;
}
function sdkRequestHandler(agent) {
  return {
    connectionTimeout: DEFAULT_CONNECTION_TIMEOUT,
    requestTimeout: DEFAULT_TIMEOUT,
    httpsAgent: agent,
    httpAgent: agent
  };
}
var import_node_util3, import_credential_providers2, import_ec2_metadata_service, import_shared_ini_file_loader, DEFAULT_CONNECTION_TIMEOUT, DEFAULT_TIMEOUT, AwsCliCompatible;
var init_awscli_compatible = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/aws-auth/awscli-compatible.ts"() {
    "use strict";
    import_node_util3 = require("node:util");
    import_credential_providers2 = __toESM(require_dist_cjs125());
    import_ec2_metadata_service = __toESM(require_dist_cjs212());
    import_shared_ini_file_loader = __toESM(require_dist_cjs28());
    init_ec2_detection();
    init_provider_caching();
    init_toolkit_error();
    init_private();
    DEFAULT_CONNECTION_TIMEOUT = 1e4;
    DEFAULT_TIMEOUT = 3e5;
    AwsCliCompatible = class {
      static {
        __name(this, "AwsCliCompatible");
      }
      ioHelper;
      requestHandler;
      logger;
      constructor(ioHelper, requestHandler, logger5) {
        this.ioHelper = ioHelper;
        this.requestHandler = requestHandler;
        this.logger = logger5;
      }
      async baseConfig(profile, region) {
        const credentialProvider = await this.credentialChainBuilder({
          profile,
          logger: this.logger
        });
        const defaultRegion = region ?? await this.region(profile);
        return { credentialProvider, defaultRegion };
      }
      /**
       * Build an AWS CLI-compatible credential chain provider
       *
       * The credential chain returned by this function is always caching.
       */
      async credentialChainBuilder(options = {}) {
        const clientConfig = {
          requestHandler: this.requestHandler,
          customUserAgent: "aws-cdk",
          logger: options.logger
        };
        const parentClientConfig = {
          region: await this.region(options.profile)
        };
        if (options.profile) {
          return makeCachingProvider((0, import_credential_providers2.fromIni)({
            profile: options.profile,
            ignoreCache: true,
            mfaCodeProvider: this.tokenCodeFn.bind(this),
            clientConfig,
            parentClientConfig,
            logger: options.logger
          }));
        }
        const envProfile = process.env.AWS_PROFILE || process.env.AWS_DEFAULT_PROFILE;
        if (process.env.AWS_EC2_METADATA_DISABLED === void 0 && !isEc2Instance()) {
          process.env.AWS_EC2_METADATA_DISABLED = "true";
        }
        const nodeProviderChain = (0, import_credential_providers2.fromNodeProviderChain)({
          profile: envProfile,
          clientConfig,
          parentClientConfig,
          logger: options.logger,
          mfaCodeProvider: this.tokenCodeFn.bind(this),
          ignoreCache: true
        });
        return shouldPrioritizeEnv() ? (0, import_credential_providers2.createCredentialChain)((0, import_credential_providers2.fromEnv)(), nodeProviderChain).expireAfter(60 * 6e4) : nodeProviderChain;
      }
      /**
       * Attempts to get the region from a number of sources and falls back to us-east-1 if no region can be found,
       * as is done in the AWS CLI.
       *
       * The order of priority is the following:
       *
       * 1. Environment variables specifying region, with both an AWS prefix and AMAZON prefix
       *    to maintain backwards compatibility, and without `DEFAULT` in the name because
       *    Lambda and CodeBuild set the $AWS_REGION variable.
       * 2. Regions listed in the Shared Ini Files - First checking for the profile provided
       *    and then checking for the default profile.
       * 3. IMDS instance identity region from the Metadata Service.
       * 4. us-east-1
       */
      async region(maybeProfile) {
        const defaultRegion = "us-east-1";
        const profile = maybeProfile || process.env.AWS_PROFILE || process.env.AWS_DEFAULT_PROFILE || "default";
        const region = process.env.AWS_REGION || process.env.AMAZON_REGION || process.env.AWS_DEFAULT_REGION || process.env.AMAZON_DEFAULT_REGION || await this.getRegionFromIni(profile) || await this.regionFromMetadataService();
        if (!region) {
          const usedProfile = !profile ? "" : ` (profile: "${profile}")`;
          await this.ioHelper.defaults.debug(
            `Unable to determine AWS region from environment or AWS configuration${usedProfile}, defaulting to '${defaultRegion}'`
          );
          return defaultRegion;
        }
        return region;
      }
      /**
       * The MetadataService class will attempt to fetch the instance identity document from
       * IMDSv2 first, and then will attempt v1 as a fallback.
       *
       * If this fails, we will use us-east-1 as the region so no error should be thrown.
       * @returns The region for the instance identity
       */
      async regionFromMetadataService() {
        if (!isEc2Instance()) {
          return void 0;
        }
        await this.ioHelper.defaults.debug("Looking up AWS region in the EC2 Instance Metadata Service (IMDS).");
        try {
          const metadataService = new import_ec2_metadata_service.MetadataService({
            httpOptions: {
              timeout: 1e3
            }
          });
          await metadataService.fetchMetadataToken();
          const document2 = await metadataService.request("/latest/dynamic/instance-identity/document", {});
          return JSON.parse(document2).region;
        } catch (e32) {
          await this.ioHelper.defaults.debug(`Unable to retrieve AWS region from IMDS: ${e32}`);
        }
      }
      /**
       * Looks up the region of the provided profile. If no region is present,
       * it will attempt to lookup the default region.
       * @param profile - The profile to use to lookup the region
       * @returns The region for the profile or default profile, if present. Otherwise returns undefined.
       */
      async getRegionFromIni(profile) {
        const sharedFiles = await (0, import_shared_ini_file_loader.loadSharedConfigFiles)({ ignoreCache: true });
        return this.getRegionFromIniFile(profile, sharedFiles.credentialsFile) ?? this.getRegionFromIniFile(profile, sharedFiles.configFile) ?? this.getRegionFromIniFile("default", sharedFiles.credentialsFile) ?? this.getRegionFromIniFile("default", sharedFiles.configFile);
      }
      getRegionFromIniFile(profile, data3) {
        return data3?.[profile]?.region;
      }
      /**
       * Ask user for MFA token for given MFA device
       *
       * Result is send to callback function for SDK to authorize the request
       */
      async tokenCodeFn(deviceArn) {
        const debugFn = /* @__PURE__ */ __name((msg, ...args) => this.ioHelper.defaults.debug((0, import_node_util3.format)(msg, ...args)), "debugFn");
        await debugFn("Require MFA token from MFA device with ARN", deviceArn);
        try {
          const token = await this.ioHelper.requestResponse(IO.CDK_SDK_I1100.req(`MFA token for ${deviceArn}`, {
            deviceArn
          }, ""));
          await debugFn("Successfully got MFA token from user");
          return token;
        } catch (err) {
          await debugFn("Failed to get MFA token", err);
          const e32 = new AuthenticationError("MfaTokenError", `Error fetching MFA token: ${err.message ?? err}`);
          e32.name = "SharedIniFileCredentialsProviderFailure";
          throw e32;
        }
      }
    };
    __name(shouldPrioritizeEnv, "shouldPrioritizeEnv");
    __name(sdkRequestHandler, "sdkRequestHandler");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/aws-auth/credential-plugins.ts
async function v3ProviderFromPlugin(producer) {
  const initial = await producer();
  if (isV3Provider(initial)) {
    return makeCachingProvider(initial);
  } else if (isV3Credentials(initial) && initial.expiration === void 0) {
    return () => Promise.resolve(initial);
  } else if (isV3Credentials(initial) && initial.expiration !== void 0) {
    return refreshFromPluginProvider(initial, producer);
  } else if (isV2Credentials(initial)) {
    return v3ProviderFromV2Credentials(initial);
  } else {
    throw new AuthenticationError("InvalidPluginCredentials", `Plugin returned a value that doesn't resemble AWS credentials: ${(0, import_util42.inspect)(initial)}`);
  }
}
function v3ProviderFromV2Credentials(x) {
  return async () => {
    await x.getPromise();
    return {
      accessKeyId: x.accessKeyId,
      secretAccessKey: x.secretAccessKey,
      sessionToken: x.sessionToken,
      expiration: x.expireTime ?? void 0
    };
  };
}
function refreshFromPluginProvider(current, producer) {
  return async () => {
    if (credentialsAboutToExpire(current)) {
      const newCreds = await producer();
      if (!isV3Credentials(newCreds)) {
        throw new AuthenticationError("PluginCredentialTypeMismatch", `Plugin initially returned static V3 credentials but now returned something else: ${(0, import_util42.inspect)(newCreds)}`);
      }
      current = newCreds;
    }
    return current;
  };
}
function isV3Provider(x) {
  return typeof x === "function";
}
function isV2Credentials(x) {
  return !!(x && typeof x === "object" && x.getPromise);
}
function isV3Credentials(x) {
  return !!(x && typeof x === "object" && x.accessKeyId && !isV2Credentials(x));
}
var import_util42, CredentialPlugins;
var init_credential_plugins = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/aws-auth/credential-plugins.ts"() {
    "use strict";
    import_util42 = require("util");
    init_provider_caching();
    init_toolkit_error();
    init_util3();
    init_private();
    CredentialPlugins = class {
      constructor(host, ioHelper) {
        this.host = host;
        this.ioHelper = ioHelper;
      }
      host;
      ioHelper;
      static {
        __name(this, "CredentialPlugins");
      }
      cache = {};
      async fetchCredentialsFor(awsAccountId, mode) {
        const key = `${awsAccountId}-${mode}`;
        if (!(key in this.cache)) {
          this.cache[key] = await this.lookupCredentials(awsAccountId, mode);
        }
        return this.cache[key];
      }
      get availablePluginNames() {
        return this.host.credentialProviderSources.map((s) => s.name);
      }
      async lookupCredentials(awsAccountId, mode) {
        const triedSources = [];
        for (const source of this.host.credentialProviderSources) {
          let available;
          try {
            available = await source.isAvailable();
          } catch (e32) {
            await this.ioHelper.notify(IO.CDK_TOOLKIT_W0100.msg(`Uncaught exception in ${source.name}: ${formatErrorMessage(e32)}`));
            available = false;
          }
          if (!available) {
            await this.ioHelper.defaults.debug(`Credentials source ${source.name} is not available, ignoring it.`);
            continue;
          }
          triedSources.push(source);
          let canProvide;
          try {
            canProvide = await source.canProvideCredentials(awsAccountId);
          } catch (e32) {
            await this.ioHelper.notify(IO.CDK_TOOLKIT_W0100.msg(`Uncaught exception in ${source.name}: ${formatErrorMessage(e32)}`));
            canProvide = false;
          }
          if (!canProvide) {
            continue;
          }
          await this.ioHelper.defaults.debug(`Using ${source.name} credentials for account ${awsAccountId}`);
          return {
            credentials: await v3ProviderFromPlugin(() => source.getProvider(awsAccountId, mode, {
              supportsV3Providers: true
            })),
            pluginName: source.name
          };
        }
        return void 0;
      }
    };
    __name(v3ProviderFromPlugin, "v3ProviderFromPlugin");
    __name(v3ProviderFromV2Credentials, "v3ProviderFromV2Credentials");
    __name(refreshFromPluginProvider, "refreshFromPluginProvider");
    __name(isV3Provider, "isV3Provider");
    __name(isV2Credentials, "isV2Credentials");
    __name(isV3Credentials, "isV3Credentials");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/aws-auth/sdk-provider.ts
function safeUsername2() {
  try {
    return os9.userInfo().username.replace(/[^\w+=,.@-]/g, "@");
  } catch {
    return "noname";
  }
}
function fmtObtainCredentialsError(targetAccountId, obtainResult) {
  const msg = [`Need to perform AWS calls for account ${targetAccountId}`];
  switch (obtainResult.source) {
    case "incorrectDefault":
      msg.push(`but the current credentials are for ${obtainResult.accountId}`);
      break;
    case "none":
      msg.push("but no credentials have been configured");
  }
  if (obtainResult.unusedPlugins.length > 0) {
    msg.push(`and none of these plugins found any: ${obtainResult.unusedPlugins.join(", ")}`);
  }
  return msg.join(", ");
}
function fmtObtainedCredentials(obtainResult) {
  switch (obtainResult.source) {
    case "correctDefault":
      return "current credentials";
    case "plugin":
      return `credentials returned by plugin '${obtainResult.pluginName}'`;
    case "incorrectDefault":
      const msg = [];
      msg.push(`current credentials (which are for account ${obtainResult.accountId}`);
      if (obtainResult.unusedPlugins.length > 0) {
        msg.push(`, and none of the following plugins provided credentials: ${obtainResult.unusedPlugins.join(", ")}`);
      }
      msg.push(")");
      return msg.join("");
  }
}
async function initContextProviderSdk(aws, options) {
  const account = options.account;
  const region = options.region;
  const creds = {
    assumeRoleArn: options.lookupRoleArn,
    assumeRoleExternalId: options.lookupRoleExternalId,
    assumeRoleAdditionalOptions: options.assumeRoleAdditionalOptions
  };
  return (await aws.forEnvironment(import_cloud_assembly_api7.EnvironmentUtils.make(account, region), 0 /* ForReading */, creds)).sdk;
}
var os9, import_cloud_assembly_api7, import_credential_providers3, CACHED_ACCOUNT, SdkProvider;
var init_sdk_provider = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/aws-auth/sdk-provider.ts"() {
    "use strict";
    os9 = __toESM(require("os"));
    import_cloud_assembly_api7 = __toESM(require_lib3());
    import_credential_providers3 = __toESM(require_dist_cjs125());
    init_awscli_compatible();
    init_cached();
    init_credential_plugins();
    init_provider_caching();
    init_sdk2();
    init_tracing();
    init_toolkit_error();
    init_util3();
    init_plugin2();
    CACHED_ACCOUNT = /* @__PURE__ */ Symbol("cached_account");
    SdkProvider = class {
      /**
       * Create a new SdkProvider which gets its defaults in a way that behaves like the AWS CLI does
       *
       * The AWS SDK for JS behaves slightly differently from the AWS CLI in a number of ways; see the
       * class `AwsCliCompatible` for the details.
       *
       * @param options - Options for the default SDK provider
       * @param profile - Profile to read from ~/.aws
       * @param region - Region override. Takes priority over environment variables, profile config, and the us-east-1 default.
       * @returns a configured SdkProvider
       */
      static async withAwsCliCompatibleDefaults(options, profile, region) {
        callTrace(SdkProvider.withAwsCliCompatibleDefaults.name, SdkProvider.constructor.name, options.logger);
        const config2 = await new AwsCliCompatible(options.ioHelper, options.requestHandler ?? {}, options.logger).baseConfig(profile, region);
        return new SdkProvider(config2.credentialProvider, config2.defaultRegion, options);
      }
      defaultRegion;
      defaultCredentialProvider;
      plugins;
      requestHandler;
      ioHelper;
      logger;
      constructor(defaultCredentialProvider, defaultRegion, options) {
        this.defaultCredentialProvider = defaultCredentialProvider;
        this.defaultRegion = defaultRegion ?? "us-east-1";
        this.requestHandler = options.requestHandler ?? {};
        this.ioHelper = options.ioHelper;
        this.logger = options.logger;
        this.plugins = new CredentialPlugins(options.pluginHost ?? new PluginHost(), this.ioHelper);
      }
      /**
       * Return an SDK which can do operations in the given environment
       *
       * The `environment` parameter is resolved first (see `resolveEnvironment()`).
       */
      async forEnvironment(environment, mode, options) {
        const env3 = await this.resolveEnvironment(environment);
        const baseCreds = await this.obtainBaseCredentials(env3.account, mode);
        if (baseCreds.source === "none") {
          throw new AuthenticationError("NoCredentials", fmtObtainCredentialsError(env3.account, baseCreds));
        }
        if (options?.assumeRoleArn === void 0) {
          if (baseCreds.source === "incorrectDefault") {
            throw new AuthenticationError("IncorrectDefaultCredentials", fmtObtainCredentialsError(env3.account, baseCreds));
          }
          const sdk = this._makeSdk(baseCreds.credentials, env3.region);
          await sdk.validateCredentials();
          return { sdk, didAssumeRole: false };
        }
        try {
          const sdk = await this.withAssumedRole(
            baseCreds,
            options.assumeRoleArn,
            options.assumeRoleExternalId,
            options.assumeRoleAdditionalOptions,
            env3.region
          );
          return { sdk, didAssumeRole: true };
        } catch (err) {
          if (err.name === "ExpiredToken") {
            throw AuthenticationError.withCause("AssumeRoleExpiredToken", "Assuming role failed: ExpiredToken", err);
          }
          if (baseCreds.source === "correctDefault" || baseCreds.source === "plugin") {
            await this.ioHelper.defaults.debug(err.message);
            await this.ioHelper.defaults.warn(
              `${fmtObtainedCredentials(baseCreds)} could not be used to assume '${options.assumeRoleArn}', but are for the right account. Proceeding anyway.`
            );
            return {
              sdk: this._makeSdk(baseCreds.credentials, env3.region),
              didAssumeRole: false
            };
          }
          throw err;
        }
      }
      /**
       * Return the partition that base credentials are for
       *
       * Returns `undefined` if there are no base credentials.
       */
      async baseCredentialsPartition(environment, mode) {
        const env3 = await this.resolveEnvironment(environment);
        const baseCreds = await this.obtainBaseCredentials(env3.account, mode);
        if (baseCreds.source === "none") {
          return void 0;
        }
        return (await this._makeSdk(baseCreds.credentials, env3.region).currentAccount()).partition;
      }
      /**
       * Resolve the environment for a stack
       *
       * Replaces the magic values `UNKNOWN_REGION` and `UNKNOWN_ACCOUNT`
       * with the defaults for the current SDK configuration (`~/.aws/config` or
       * otherwise).
       *
       * It is an error if `UNKNOWN_ACCOUNT` is used but the user hasn't configured
       * any SDK credentials.
       */
      async resolveEnvironment(env3) {
        const region = env3.region !== import_cloud_assembly_api7.UNKNOWN_REGION ? env3.region : this.defaultRegion;
        const account = env3.account !== import_cloud_assembly_api7.UNKNOWN_ACCOUNT ? env3.account : (await this.defaultAccount())?.accountId;
        if (!account) {
          throw new AuthenticationError(
            "UnresolvedAccount",
            "Unable to resolve AWS account to use. It must be either configured when you define your CDK Stack, or through the environment"
          );
        }
        return {
          region,
          account,
          name: import_cloud_assembly_api7.EnvironmentUtils.format(account, region)
        };
      }
      /**
       * The account we'd auth into if we used default credentials.
       *
       * Default credentials are the set of ambiently configured credentials using
       * one of the environment variables, or ~/.aws/credentials, or the *one*
       * profile that was passed into the CLI.
       *
       * Might return undefined if there are no default/ambient credentials
       * available (in which case the user should better hope they have
       * credential plugins configured).
       *
       * Uses a cache to avoid STS calls if we don't need 'em.
       */
      async defaultAccount() {
        return cached2(this, CACHED_ACCOUNT, async () => {
          try {
            return await this._makeSdk(this.defaultCredentialProvider, this.defaultRegion).currentAccount();
          } catch (e32) {
            if (e32.name === "ExpiredToken") {
              await this.ioHelper.defaults.warn(
                "There are expired AWS credentials in your environment. The CDK app will synth without current account information."
              );
              return void 0;
            }
            await this.ioHelper.defaults.debug(`Unable to determine the default AWS account (${e32.name}): ${formatErrorMessage(e32)}`);
            return void 0;
          }
        });
      }
      /**
       * Get credentials for the given account ID in the given mode
       *
       * 1. Use the default credentials if the destination account matches the
       *    current credentials' account.
       * 2. Otherwise try all credential plugins.
       * 3. Fail if neither of these yield any credentials.
       * 4. Return a failure if any of them returned credentials
       */
      async obtainBaseCredentials(accountId, mode) {
        const defaultAccountId = (await this.defaultAccount())?.accountId;
        if (defaultAccountId === accountId) {
          return {
            source: "correctDefault",
            credentials: await this.defaultCredentialProvider
          };
        }
        const pluginCreds = await this.plugins.fetchCredentialsFor(accountId, mode);
        if (pluginCreds) {
          return { source: "plugin", ...pluginCreds };
        }
        if (defaultAccountId !== void 0) {
          return {
            source: "incorrectDefault",
            accountId: defaultAccountId,
            credentials: await this.defaultCredentialProvider,
            unusedPlugins: this.plugins.availablePluginNames
          };
        }
        return {
          source: "none",
          unusedPlugins: this.plugins.availablePluginNames
        };
      }
      /**
       * Return an SDK which uses assumed role credentials
       *
       * The base credentials used to retrieve the assumed role credentials will be the
       * same credentials returned by obtainCredentials if an environment and mode is passed,
       * otherwise it will be the current credentials.
       */
      async withAssumedRole(mainCredentials, roleArn, externalId, additionalOptions, region) {
        await this.ioHelper.defaults.debug(`Assuming role '${roleArn}'.`);
        region = region ?? this.defaultRegion;
        const sourceDescription = fmtObtainedCredentials(mainCredentials);
        try {
          const credentials = await makeCachingProvider((0, import_credential_providers3.fromTemporaryCredentials)({
            masterCredentials: mainCredentials.credentials,
            params: {
              RoleArn: roleArn,
              ExternalId: externalId,
              RoleSessionName: `aws-cdk-${safeUsername2()}`,
              ...additionalOptions,
              TransitiveTagKeys: additionalOptions?.Tags ? additionalOptions.Tags.map((t) => t.Key) : void 0
            },
            clientConfig: {
              region,
              requestHandler: this.requestHandler,
              customUserAgent: "aws-cdk",
              logger: this.logger
            },
            logger: this.logger
          }));
          await credentials();
          return this._makeSdk(credentials, region);
        } catch (err) {
          if (err.name === "ExpiredToken") {
            throw err;
          }
          await this.ioHelper.defaults.debug(`Assuming role failed: ${err.message}`);
          throw new AuthenticationError(
            "AssumeRoleFailed",
            [
              "Could not assume role in target account",
              ...sourceDescription ? [`using ${sourceDescription}`] : [],
              err.message,
              ". Please make sure that this role exists in the account. If it doesn't exist, (re)-bootstrap the environment with the right '--trust', using the latest version of the CDK CLI."
            ].join(" ")
          );
        }
      }
      /**
       * Factory function that creates a new SDK instance
       *
       * This is a function here, instead of all the places where this is used creating a `new SDK`
       * instance, so that it is trivial to mock from tests.
       *
       * Use like this:
       *
       * ```ts
       * const mockSdk = jest.spyOn(SdkProvider.prototype, '_makeSdk').mockReturnValue(new MockSdk());
       * // ...
       * mockSdk.mockRestore();
       * ```
       *
       * @internal
       */
      _makeSdk(credProvider, region) {
        return new SDK(credProvider, region, this.requestHandler, this.ioHelper, this.logger);
      }
    };
    __name(SdkProvider, "SdkProvider");
    SdkProvider = __decorateClass([
      traceMemberMethods
    ], SdkProvider);
    __name(safeUsername2, "safeUsername");
    __name(fmtObtainCredentialsError, "fmtObtainCredentialsError");
    __name(fmtObtainedCredentials, "fmtObtainedCredentials");
    __name(initContextProviderSdk, "initContextProviderSdk");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/aws-auth/sdk-logger.ts
function formatSdkLoggerContent(content) {
  if (content.length === 1) {
    const apiFmt = formatApiCall(content[0]);
    if (apiFmt) {
      return apiFmt;
    }
  }
  return content.map((x) => typeof x === "string" ? x : (0, import_util45.inspect)(x)).join("");
}
function formatApiCall(content) {
  if (!isSdkApiCallSuccess(content) && !isSdkApiCallError(content)) {
    return void 0;
  }
  const service = content.clientName.replace(/Client$/, "");
  const api = content.commandName.replace(/Command$/, "");
  const parts = [];
  if ((content.metadata?.attempts ?? 0) > 1) {
    parts.push(`[${content.metadata?.attempts} attempts, ${content.metadata?.totalRetryDelay}ms retry]`);
  }
  parts.push(`${service}.${api}(${JSON.stringify(content.input, replacerBufferWithInfo)})`);
  if (isSdkApiCallSuccess(content)) {
    parts.push("-> OK");
  } else {
    parts.push(`-> ${content.error}`);
  }
  return parts.join(" ");
}
function isSdkApiCallSuccess(x) {
  return x && typeof x === "object" && x.commandName && x.output;
}
function isSdkApiCallError(x) {
  return x && typeof x === "object" && x.commandName && x.error;
}
var import_util45, IoHostSdkLogger;
var init_sdk_logger = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/aws-auth/sdk-logger.ts"() {
    "use strict";
    import_util45 = require("util");
    init_util3();
    init_private();
    IoHostSdkLogger = class {
      static {
        __name(this, "IoHostSdkLogger");
      }
      ioHelper;
      constructor(ioHelper) {
        this.ioHelper = ioHelper;
      }
      notify(level, ...content) {
        void this.ioHelper.notify(IO.CDK_SDK_I0100.msg((0, import_util45.format)("[SDK %s] %s", level, formatSdkLoggerContent(content)), {
          sdkLevel: level,
          content
        }));
      }
      trace(..._content) {
      }
      debug(..._content) {
      }
      /**
       * Info is called mostly (exclusively?) for successful API calls
       *
       * Payload:
       *
       * (Note the input contains entire CFN templates, for example)
       *
       * ```
       * {
       *   clientName: 'S3Client',
       *   commandName: 'GetBucketLocationCommand',
       *   input: {
       *     Bucket: '.....',
       *     ExpectedBucketOwner: undefined
       *   },
       *   output: { LocationConstraint: 'eu-central-1' },
       *   metadata: {
       *     httpStatusCode: 200,
       *     requestId: '....',
       *     extendedRequestId: '...',
       *     cfId: undefined,
       *     attempts: 1,
       *     totalRetryDelay: 0
       *   }
       * }
       * ```
       */
      info(...content) {
        this.notify("info", ...content);
      }
      warn(...content) {
        this.notify("warn", ...content);
      }
      /**
       * Error is called mostly (exclusively?) for failing API calls
       *
       * Payload (input would be the entire API call arguments).
       *
       * ```
       * {
       *   clientName: 'STSClient',
       *   commandName: 'GetCallerIdentityCommand',
       *   input: {},
       *   error: AggregateError [ECONNREFUSED]:
       *       at internalConnectMultiple (node:net:1121:18)
       *       at afterConnectMultiple (node:net:1688:7) {
       *     code: 'ECONNREFUSED',
       *     '$metadata': { attempts: 3, totalRetryDelay: 600 },
       *     [errors]: [ [Error], [Error] ]
       *   },
       *   metadata: { attempts: 3, totalRetryDelay: 600 }
       * }
       * ```
       */
      error(...content) {
        this.notify("error", ...content);
      }
    };
    __name(formatSdkLoggerContent, "formatSdkLoggerContent");
    __name(formatApiCall, "formatApiCall");
    __name(isSdkApiCallSuccess, "isSdkApiCallSuccess");
    __name(isSdkApiCallError, "isSdkApiCallError");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/aws-auth/private/index.ts
var init_private2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/aws-auth/private/index.ts"() {
    "use strict";
    init_sdk2();
    init_sdk_provider();
    init_sdk_logger();
    init_account_cache();
    init_cached();
    init_awscli_compatible();
    init_tracing();
    init_credential_plugins();
    init_provider_caching();
    init_user_agent();
  }
});

// ../@aws-cdk/toolkit-lib/lib/context-providers/ami.ts
function descending(valueOf) {
  return (a32, b32) => {
    return valueOf(b32) - valueOf(a32);
  };
}
var AmiContextProviderPlugin;
var init_ami2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/context-providers/ami.ts"() {
    "use strict";
    init_private2();
    init_toolkit_error();
    AmiContextProviderPlugin = class {
      constructor(aws, io) {
        this.aws = aws;
        this.io = io;
      }
      aws;
      io;
      static {
        __name(this, "AmiContextProviderPlugin");
      }
      async getValue(args) {
        const region = args.region;
        const account = args.account;
        await this.io.info(`Searching for AMI in ${account}:${region}`);
        await this.io.debug(`AMI search parameters: ${JSON.stringify(args)}`);
        const ec2 = (await initContextProviderSdk(this.aws, args)).ec2();
        const response = await ec2.describeImages({
          Owners: args.owners,
          Filters: Object.entries(args.filters).map(([key, values]) => ({
            Name: key,
            Values: values
          }))
        });
        const images = [...response.Images || []].filter((i32) => i32.ImageId !== void 0);
        if (images.length === 0) {
          throw new ContextProviderError("AmiNotFound", "No AMI found that matched the search criteria");
        }
        images.sort(descending((i32) => Date.parse(i32.CreationDate || "1970")));
        await this.io.debug(`Selected image '${images[0].ImageId}' created at '${images[0].CreationDate}'`);
        return images[0].ImageId;
      }
    };
    __name(descending, "descending");
  }
});

// ../@aws-cdk/toolkit-lib/lib/context-providers/availability-zones.ts
var AZContextProviderPlugin;
var init_availability_zones2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/context-providers/availability-zones.ts"() {
    "use strict";
    init_private2();
    AZContextProviderPlugin = class {
      constructor(aws, io) {
        this.aws = aws;
        this.io = io;
      }
      aws;
      io;
      static {
        __name(this, "AZContextProviderPlugin");
      }
      async getValue(args) {
        const region = args.region;
        const account = args.account;
        await this.io.debug(`Reading AZs for ${account}:${region}`);
        const ec2 = (await initContextProviderSdk(this.aws, args)).ec2();
        const response = await ec2.describeAvailabilityZones({});
        if (!response.AvailabilityZones) {
          return [];
        }
        const azs = response.AvailabilityZones.filter((zone) => zone.State === "available").map(
          (zone) => zone.ZoneName
        );
        return azs;
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/context-providers/cc-api-provider.ts
function foundResourceFromCcApi(desc) {
  return {
    identifier: desc.Identifier ?? "*MISSING*",
    properties: JSON.parse(desc.Properties ?? "{}")
  };
}
function propertyMatchesFilter(actual, expected) {
  return expected === actual;
}
function isObject2(x) {
  return typeof x === "object" && x !== null && !Array.isArray(x);
}
function expectedMatchCountText(expectation) {
  switch (expectation) {
    case "at-least-one":
      return "at least one";
    case "at-most-one":
      return "at most one";
    case "exactly-one":
      return "exactly one";
    case "any":
      return "any number";
    default:
      return expectation;
  }
}
var import_client_cloudcontrol2, CcApiContextProviderPlugin;
var init_cc_api_provider = __esm({
  "../@aws-cdk/toolkit-lib/lib/context-providers/cc-api-provider.ts"() {
    "use strict";
    import_client_cloudcontrol2 = __toESM(require_dist_cjs158());
    init_private2();
    init_toolkit_error();
    init_util3();
    CcApiContextProviderPlugin = class {
      constructor(aws) {
        this.aws = aws;
      }
      aws;
      static {
        __name(this, "CcApiContextProviderPlugin");
      }
      /**
       * This returns a data object with the value from CloudControl API result.
       *
       * See the documentation in the Cloud Assembly Schema for the semantics of
       * each query parameter.
       */
      async getValue(args) {
        if (args.exactIdentifier && args.propertyMatch) {
          throw new ContextProviderError("ConflictingQueryParams", `Provider protocol error: specify either exactIdentifier or propertyMatch, but not both (got ${JSON.stringify(args)})`);
        }
        if (args.ignoreErrorOnMissingContext && args.dummyValue === void 0) {
          throw new ContextProviderError("MissingDummyValue", `Provider protocol error: if ignoreErrorOnMissingContext is set, a dummyValue must be supplied (got ${JSON.stringify(args)})`);
        }
        if (args.dummyValue !== void 0 && (!Array.isArray(args.dummyValue) || !args.dummyValue.every(isObject2))) {
          throw new ContextProviderError("InvalidDummyValue", `Provider protocol error: dummyValue must be an array of objects (got ${JSON.stringify(args.dummyValue)})`);
        }
        const cloudControl = (await initContextProviderSdk(this.aws, args)).cloudControl();
        try {
          let resources;
          if (args.exactIdentifier) {
            resources = await this.getResource(cloudControl, args.typeName, args.exactIdentifier);
          } else if (args.propertyMatch) {
            resources = await this.listResources(cloudControl, args.typeName, args.propertyMatch, args.expectedMatchCount, args.resourceModel);
          } else {
            throw new ContextProviderError("MissingQueryParams", `Provider protocol error: neither exactIdentifier nor propertyMatch is specified in ${JSON.stringify(args)}.`);
          }
          return resources.map((r32) => getResultObj(r32.properties, r32.identifier, args.propertiesToReturn));
        } catch (err) {
          if (ContextProviderError.isNoResultsFoundError(err) && args.ignoreErrorOnMissingContext) {
            return args.dummyValue;
          }
          throw err;
        }
      }
      /**
       * Calls getResource from CC API to get the resource.
       * See https://docs.aws.amazon.com/cli/latest/reference/cloudcontrol/get-resource.html
       *
       * Will always return exactly one resource, or fail.
       */
      async getResource(cc, typeName, exactIdentifier) {
        try {
          const result2 = await cc.getResource({
            TypeName: typeName,
            Identifier: exactIdentifier
          });
          if (!result2.ResourceDescription) {
            throw new ContextProviderError("EmptyResponse", "Unexpected CloudControl API behavior: returned empty response");
          }
          return [foundResourceFromCcApi(result2.ResourceDescription)];
        } catch (err) {
          if (err instanceof import_client_cloudcontrol2.ResourceNotFoundException || err.name === "ResourceNotFoundException") {
            throw new NoResultsFoundError(`No resource of type ${typeName} with identifier: ${exactIdentifier}`);
          }
          if (!ContextProviderError.isContextProviderError(err)) {
            throw ContextProviderError.withCause("CloudControlGetFailed", `Encountered CC API error while getting ${typeName} resource ${exactIdentifier}`, err);
          }
          throw err;
        }
      }
      /**
       * Calls listResources from CC API to get the resources and apply args.propertyMatch to find the resources.
       * See https://docs.aws.amazon.com/cli/latest/reference/cloudcontrol/list-resources.html
       *
       * Will return 0 or more resources.
       *
       * Does not currently paginate through more than one result page.
       */
      async listResources(cc, typeName, propertyMatch, expectedMatchCount, resourceModel) {
        try {
          const found = [];
          let nextToken = void 0;
          const resourceModelJSON = resourceModel ? JSON.stringify(resourceModel) : void 0;
          do {
            const result2 = await cc.listResources({
              TypeName: typeName,
              ResourceModel: resourceModelJSON,
              MaxResults: 100,
              ...nextToken ? { NextToken: nextToken } : {}
            });
            found.push(
              ...(result2.ResourceDescriptions ?? []).map(foundResourceFromCcApi).filter((r32) => {
                return Object.entries(propertyMatch).every(([propPath, expected]) => {
                  const actual = findJsonValue(r32.properties, propPath);
                  return propertyMatchesFilter(actual, expected);
                });
              })
            );
            nextToken = result2.NextToken;
            if ((expectedMatchCount === "at-most-one" || expectedMatchCount === "exactly-one") && found.length > 1) {
              const atLeast = nextToken ? "at least " : "";
              throw new ContextProviderError("TooManyMatches", `Found ${atLeast}${found.length} resources matching ${JSON.stringify(propertyMatch)}; expected ${expectedMatchCountText(expectedMatchCount)}. Please narrow the search criteria`);
            }
          } while (nextToken);
          if ((expectedMatchCount === "at-least-one" || expectedMatchCount === "exactly-one") && found.length === 0) {
            throw new NoResultsFoundError(`Could not find any resources matching ${JSON.stringify(propertyMatch)}; expected ${expectedMatchCountText(expectedMatchCount)}.`);
          }
          return found;
        } catch (err) {
          if (!ContextProviderError.isContextProviderError(err)) {
            throw ContextProviderError.withCause("CloudControlListFailed", `Encountered CC API error while listing ${typeName} resources matching ${JSON.stringify(propertyMatch)}`, err);
          }
          throw err;
        }
      }
    };
    __name(foundResourceFromCcApi, "foundResourceFromCcApi");
    __name(propertyMatchesFilter, "propertyMatchesFilter");
    __name(isObject2, "isObject");
    __name(expectedMatchCountText, "expectedMatchCountText");
  }
});

// ../@aws-cdk/toolkit-lib/lib/context-providers/endpoint-service-availability-zones.ts
var EndpointServiceAZContextProviderPlugin;
var init_endpoint_service_availability_zones2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/context-providers/endpoint-service-availability-zones.ts"() {
    "use strict";
    init_private2();
    EndpointServiceAZContextProviderPlugin = class {
      constructor(aws, io) {
        this.aws = aws;
        this.io = io;
      }
      aws;
      io;
      static {
        __name(this, "EndpointServiceAZContextProviderPlugin");
      }
      async getValue(args) {
        const region = args.region;
        const account = args.account;
        const serviceName = args.serviceName;
        await this.io.debug(`Reading AZs for ${account}:${region}:${serviceName}`);
        const ec2 = (await initContextProviderSdk(this.aws, args)).ec2();
        const response = await ec2.describeVpcEndpointServices({
          ServiceNames: [serviceName]
        });
        if (!response.ServiceDetails || response.ServiceDetails.length === 0) {
          await this.io.debug(`Could not retrieve service details for ${account}:${region}:${serviceName}`);
          return [];
        }
        const azs = response.ServiceDetails[0].AvailabilityZones;
        await this.io.debug(`Endpoint service ${account}:${region}:${serviceName} is available in availability zones ${azs}`);
        return azs;
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/context-providers/hosted-zones.ts
var HostedZoneContextProviderPlugin;
var init_hosted_zones = __esm({
  "../@aws-cdk/toolkit-lib/lib/context-providers/hosted-zones.ts"() {
    "use strict";
    init_private2();
    init_toolkit_error();
    HostedZoneContextProviderPlugin = class {
      constructor(aws, io) {
        this.aws = aws;
        this.io = io;
      }
      aws;
      io;
      static {
        __name(this, "HostedZoneContextProviderPlugin");
      }
      async getValue(args) {
        const account = args.account;
        const region = args.region;
        if (!this.isHostedZoneQuery(args)) {
          throw new ContextProviderError("MissingDomainName", `HostedZoneProvider requires domainName property to be set in ${args}`);
        }
        const domainName = args.domainName;
        await this.io.debug(`Reading hosted zone ${account}:${region}:${domainName}`);
        const r53 = (await initContextProviderSdk(this.aws, args)).route53();
        const response = await r53.listHostedZonesByName({ DNSName: domainName });
        if (!response.HostedZones) {
          throw new ContextProviderError("HostedZoneNotFound", `Hosted Zone not found in account ${account}, region ${region}: ${domainName}`);
        }
        const candidateZones = await this.filterZones(r53, response.HostedZones, args);
        if (candidateZones.length !== 1) {
          const filteProps = `dns:${domainName}, privateZone:${args.privateZone}, vpcId:${args.vpcId}`;
          throw new ContextProviderError("HostedZoneCountMismatch", `Found zones: ${JSON.stringify(candidateZones)} for ${filteProps}, but wanted exactly 1 zone`);
        }
        return {
          Id: candidateZones[0].Id,
          Name: candidateZones[0].Name
        };
      }
      async filterZones(r53, zones, props) {
        let candidates = [];
        const domainName = props.domainName.endsWith(".") ? props.domainName : `${props.domainName}.`;
        await this.io.debug(`Found the following zones ${JSON.stringify(zones)}`);
        candidates = zones.filter((zone) => zone.Name === domainName);
        await this.io.debug(`Found the following matched name zones ${JSON.stringify(candidates)}`);
        if (props.privateZone) {
          candidates = candidates.filter((zone) => zone.Config && zone.Config.PrivateZone);
        } else {
          candidates = candidates.filter((zone) => !zone.Config || !zone.Config.PrivateZone);
        }
        if (props.vpcId) {
          const vpcZones = [];
          for (const zone of candidates) {
            const data3 = await r53.getHostedZone({ Id: zone.Id });
            if (!data3.VPCs) {
              await this.io.debug(`Expected VPC for private zone but no VPC found ${zone.Id}`);
              continue;
            }
            if (data3.VPCs.map((vpc) => vpc.VPCId).includes(props.vpcId)) {
              vpcZones.push(zone);
            }
          }
          return vpcZones;
        }
        return candidates;
      }
      isHostedZoneQuery(props) {
        return props.domainName !== void 0;
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/context-providers/keys.ts
var KeyContextProviderPlugin;
var init_keys = __esm({
  "../@aws-cdk/toolkit-lib/lib/context-providers/keys.ts"() {
    "use strict";
    init_private2();
    init_toolkit_error();
    KeyContextProviderPlugin = class {
      constructor(aws, io) {
        this.aws = aws;
        this.io = io;
      }
      aws;
      io;
      static {
        __name(this, "KeyContextProviderPlugin");
      }
      async getValue(args) {
        const kms = (await initContextProviderSdk(this.aws, args)).kms();
        const aliasListEntry = await this.findKey(kms, args);
        return this.readKeyProps(aliasListEntry, args);
      }
      // TODO: use paginator function
      async findKey(kms, args) {
        await this.io.debug(`Listing keys in ${args.account}:${args.region}`);
        let response;
        let nextMarker;
        do {
          response = await kms.listAliases({
            Marker: nextMarker
          });
          const aliases = response.Aliases || [];
          for (const alias of aliases) {
            if (alias.AliasName == args.aliasName) {
              return alias;
            }
          }
          nextMarker = response.NextMarker;
        } while (nextMarker);
        const suppressError = "ignoreErrorOnMissingContext" in args && args.ignoreErrorOnMissingContext;
        const hasDummyKeyId = "dummyValue" in args && typeof args.dummyValue === "object" && args.dummyValue !== null && "keyId" in args.dummyValue;
        if (suppressError && hasDummyKeyId) {
          const keyId = args.dummyValue.keyId;
          return { TargetKeyId: keyId };
        }
        throw new ContextProviderError("KeyNotFound", `Could not find any key with alias named ${args.aliasName}`);
      }
      async readKeyProps(alias, args) {
        if (!alias.TargetKeyId) {
          throw new ContextProviderError("KeyMissingTargetId", `Could not find any key with alias named ${args.aliasName}`);
        }
        await this.io.debug(`Key found ${alias.TargetKeyId}`);
        return {
          keyId: alias.TargetKeyId
        };
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/context-providers/load-balancers.ts
var import_cloud_assembly_api8, LoadBalancerContextProviderPlugin, LoadBalancerListenerContextProviderPlugin, LoadBalancerProvider;
var init_load_balancers = __esm({
  "../@aws-cdk/toolkit-lib/lib/context-providers/load-balancers.ts"() {
    "use strict";
    import_cloud_assembly_api8 = __toESM(require_lib3());
    init_private2();
    init_toolkit_error();
    LoadBalancerContextProviderPlugin = class {
      constructor(aws) {
        this.aws = aws;
      }
      aws;
      static {
        __name(this, "LoadBalancerContextProviderPlugin");
      }
      async getValue(query) {
        if (!query.loadBalancerArn && !query.loadBalancerTags) {
          throw new ContextProviderError("MissingLoadBalancerFilter", "The load balancer lookup query must specify either `loadBalancerArn` or `loadBalancerTags`");
        }
        const loadBalancer = await (await LoadBalancerProvider.getClient(this.aws, query)).getLoadBalancer();
        const ipAddressType = loadBalancer.IpAddressType === "ipv4" ? import_cloud_assembly_api8.LoadBalancerIpAddressType.IPV4 : import_cloud_assembly_api8.LoadBalancerIpAddressType.DUAL_STACK;
        return {
          loadBalancerArn: loadBalancer.LoadBalancerArn,
          loadBalancerCanonicalHostedZoneId: loadBalancer.CanonicalHostedZoneId,
          loadBalancerDnsName: loadBalancer.DNSName,
          vpcId: loadBalancer.VpcId,
          securityGroupIds: loadBalancer.SecurityGroups ?? [],
          ipAddressType
        };
      }
    };
    LoadBalancerListenerContextProviderPlugin = class {
      constructor(aws) {
        this.aws = aws;
      }
      aws;
      static {
        __name(this, "LoadBalancerListenerContextProviderPlugin");
      }
      async getValue(query) {
        if (!query.listenerArn && !query.loadBalancerArn && !query.loadBalancerTags) {
          throw new ContextProviderError(
            "MissingListenerFilter",
            "The load balancer listener query must specify at least one of: `listenerArn`, `loadBalancerArn` or `loadBalancerTags`"
          );
        }
        return (await LoadBalancerProvider.getClient(this.aws, query)).getListener();
      }
    };
    LoadBalancerProvider = class _LoadBalancerProvider {
      constructor(client, filter, listener) {
        this.client = client;
        this.filter = filter;
        this.listener = listener;
      }
      client;
      filter;
      listener;
      static {
        __name(this, "LoadBalancerProvider");
      }
      static async getClient(aws, query) {
        const client = (await initContextProviderSdk(aws, query)).elbv2();
        try {
          const listener = query.listenerArn ? (
            // Assert we're sure there's at least one so it throws if not
            (await client.describeListeners({ ListenerArns: [query.listenerArn] })).Listeners[0]
          ) : void 0;
          return new _LoadBalancerProvider(
            client,
            { ...query, loadBalancerArn: listener?.LoadBalancerArn || query.loadBalancerArn },
            listener
          );
        } catch (err) {
          throw new ContextProviderError("ListenerNotFound", `No load balancer listeners found matching arn ${query.listenerArn}`);
        }
      }
      async getLoadBalancer() {
        const loadBalancers = await this.getLoadBalancers();
        if (loadBalancers.length === 0) {
          throw new ContextProviderError("LoadBalancerNotFound", `No load balancers found matching ${JSON.stringify(this.filter)}`);
        }
        if (loadBalancers.length > 1) {
          throw new ContextProviderError(
            "MultipleLoadBalancersFound",
            `Multiple load balancers found matching ${JSON.stringify(this.filter)} - please provide more specific criteria`
          );
        }
        return loadBalancers[0];
      }
      async getListener() {
        if (this.listener) {
          try {
            const loadBalancer = await this.getLoadBalancer();
            return {
              listenerArn: this.listener.ListenerArn,
              listenerPort: this.listener.Port,
              securityGroupIds: loadBalancer.SecurityGroups || []
            };
          } catch (err) {
            throw new ContextProviderError("LoadBalancerForListenerNotFound", `No associated load balancer found for listener arn ${this.filter.listenerArn}`);
          }
        }
        const loadBalancers = await this.getLoadBalancers();
        if (loadBalancers.length === 0) {
          throw new ContextProviderError(
            "NoLoadBalancersForListener",
            `No associated load balancers found for load balancer listener query ${JSON.stringify(this.filter)}`
          );
        }
        const listeners = (await this.getListenersForLoadBalancers(loadBalancers)).filter((listener) => {
          return (!this.filter.listenerPort || listener.Port === this.filter.listenerPort) && (!this.filter.listenerProtocol || listener.Protocol === this.filter.listenerProtocol);
        });
        if (listeners.length === 0) {
          throw new ContextProviderError("ListenerNotFound", `No load balancer listeners found matching ${JSON.stringify(this.filter)}`);
        }
        if (listeners.length > 1) {
          throw new ContextProviderError(
            "MultipleListenersFound",
            `Multiple load balancer listeners found matching ${JSON.stringify(this.filter)} - please provide more specific criteria`
          );
        }
        return {
          listenerArn: listeners[0].ListenerArn,
          listenerPort: listeners[0].Port,
          securityGroupIds: loadBalancers.find((lb) => listeners[0].LoadBalancerArn === lb.LoadBalancerArn)?.SecurityGroups || []
        };
      }
      async getLoadBalancers() {
        const loadBalancerArns = this.filter.loadBalancerArn ? [this.filter.loadBalancerArn] : void 0;
        const loadBalancers = (await this.client.paginateDescribeLoadBalancers({
          LoadBalancerArns: loadBalancerArns
        })).filter((lb) => lb.Type === this.filter.loadBalancerType);
        return this.filterByTags(loadBalancers);
      }
      async filterByTags(loadBalancers) {
        if (!this.filter.loadBalancerTags) {
          return loadBalancers;
        }
        return (await this.describeTags(loadBalancers.map((lb) => lb.LoadBalancerArn))).filter((tagDescription) => {
          return this.filter.loadBalancerTags.every((filter) => {
            return tagDescription.Tags?.some((tag3) => filter.key === tag3.Key && filter.value === tag3.Value);
          });
        }).flatMap((tag3) => loadBalancers.filter((loadBalancer) => tag3.ResourceArn === loadBalancer.LoadBalancerArn));
      }
      /**
       * Returns tag descriptions associated with the resources. The API doesn't support
       * pagination, so this function breaks the resource list into chunks and issues
       * the appropriate requests.
       */
      async describeTags(resourceArns) {
        const chunkSize = 20;
        const tags = Array();
        for (let i32 = 0; i32 < resourceArns.length; i32 += chunkSize) {
          const chunk = resourceArns.slice(i32, Math.min(i32 + chunkSize, resourceArns.length));
          const chunkTags = await this.client.describeTags({
            ResourceArns: chunk
          });
          tags.push(...chunkTags.TagDescriptions || []);
        }
        return tags;
      }
      async getListenersForLoadBalancers(loadBalancers) {
        const listeners = [];
        for (const loadBalancer of loadBalancers.map((lb) => lb.LoadBalancerArn)) {
          listeners.push(...await this.client.paginateDescribeListeners({ LoadBalancerArn: loadBalancer }));
        }
        return listeners;
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/context-providers/security-groups.ts
function hasAllTrafficEgress(securityGroup) {
  let hasAllTrafficCidrV4 = false;
  let hasAllTrafficCidrV6 = false;
  for (const ipPermission of securityGroup.IpPermissionsEgress ?? []) {
    const isAllProtocols = ipPermission.IpProtocol === "-1";
    if (isAllProtocols && ipPermission.IpRanges?.some((m20) => m20.CidrIp === "0.0.0.0/0")) {
      hasAllTrafficCidrV4 = true;
    }
    if (isAllProtocols && ipPermission.Ipv6Ranges?.some((m20) => m20.CidrIpv6 === "::/0")) {
      hasAllTrafficCidrV6 = true;
    }
  }
  return hasAllTrafficCidrV4 && hasAllTrafficCidrV6;
}
var SecurityGroupContextProviderPlugin;
var init_security_groups = __esm({
  "../@aws-cdk/toolkit-lib/lib/context-providers/security-groups.ts"() {
    "use strict";
    init_private2();
    init_toolkit_error();
    SecurityGroupContextProviderPlugin = class {
      constructor(aws) {
        this.aws = aws;
      }
      aws;
      static {
        __name(this, "SecurityGroupContextProviderPlugin");
      }
      async getValue(args) {
        if (args.securityGroupId && args.securityGroupName) {
          throw new ContextProviderError(
            "ConflictingSecurityGroupFilters",
            "'securityGroupId' and 'securityGroupName' can not be specified both when looking up a security group"
          );
        }
        if (!args.securityGroupId && !args.securityGroupName) {
          throw new ContextProviderError("MissingSecurityGroupFilter", "'securityGroupId' or 'securityGroupName' must be specified to look up a security group");
        }
        const ec2 = (await initContextProviderSdk(this.aws, args)).ec2();
        const filters = [];
        if (args.vpcId) {
          filters.push({
            Name: "vpc-id",
            Values: [args.vpcId]
          });
        }
        if (args.securityGroupName) {
          filters.push({
            Name: "group-name",
            Values: [args.securityGroupName]
          });
        }
        const response = await ec2.describeSecurityGroups({
          GroupIds: args.securityGroupId ? [args.securityGroupId] : void 0,
          Filters: filters.length > 0 ? filters : void 0
        });
        const securityGroups = response.SecurityGroups ?? [];
        if (securityGroups.length === 0) {
          throw new ContextProviderError("SecurityGroupNotFound", `No security groups found matching ${JSON.stringify(args)}`);
        }
        if (securityGroups.length > 1) {
          throw new ContextProviderError("MultipleSecurityGroupsFound", `More than one security groups found matching ${JSON.stringify(args)}`);
        }
        const [securityGroup] = securityGroups;
        return {
          securityGroupId: securityGroup.GroupId,
          allowAllOutbound: hasAllTrafficEgress(securityGroup)
        };
      }
    };
    __name(hasAllTrafficEgress, "hasAllTrafficEgress");
  }
});

// ../@aws-cdk/toolkit-lib/lib/context-providers/ssm-parameters.ts
var SSMContextProviderPlugin;
var init_ssm_parameters = __esm({
  "../@aws-cdk/toolkit-lib/lib/context-providers/ssm-parameters.ts"() {
    "use strict";
    init_private2();
    init_toolkit_error();
    SSMContextProviderPlugin = class {
      constructor(aws, io) {
        this.aws = aws;
        this.io = io;
      }
      aws;
      io;
      static {
        __name(this, "SSMContextProviderPlugin");
      }
      async getValue(args) {
        const region = args.region;
        const account = args.account;
        if (!("parameterName" in args)) {
          throw new ContextProviderError("MissingParameterName", "parameterName must be provided in props for SSMContextProviderPlugin");
        }
        const parameterName = args.parameterName;
        await this.io.debug(`Reading SSM parameter ${account}:${region}:${parameterName}`);
        const response = await this.getSsmParameterValue(args);
        const parameterNotFound = !response.Parameter || response.Parameter.Value === void 0;
        const suppressError = "ignoreErrorOnMissingContext" in args && args.ignoreErrorOnMissingContext;
        if (parameterNotFound && suppressError && "dummyValue" in args) {
          return args.dummyValue;
        }
        if (parameterNotFound) {
          throw new ContextProviderError("SsmParameterNotFound", `SSM parameter not available in account ${account}, region ${region}: ${parameterName}`);
        }
        return response.Parameter.Value;
      }
      /**
       * Gets the value of an SSM Parameter, while not thrown if the parameter does not exist.
       * @param account       - the account in which the SSM Parameter is expected to be.
       * @param region        - the region in which the SSM Parameter is expected to be.
       * @param parameterName - the name of the SSM Parameter
       * @param lookupRoleArn - the ARN of the lookup role.
       *
       * @returns the result of the ``GetParameter`` operation.
       *
       * @throws Error if a service error (other than ``ParameterNotFound``) occurs.
       */
      async getSsmParameterValue(args) {
        const ssm = (await initContextProviderSdk(this.aws, args)).ssm();
        try {
          return await ssm.getParameter({ Name: args.parameterName });
        } catch (e32) {
          if (e32.name === "ParameterNotFound") {
            return { $metadata: {} };
          }
          throw e32;
        }
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/context-providers/vpcs.ts
function getTag(name, tags) {
  for (const tag3 of tags || []) {
    if (tag3.Key === name) {
      return tag3.Value;
    }
  }
  return void 0;
}
function groupSubnets(subnets) {
  const grouping = {};
  for (const subnet of subnets) {
    const key = [subnet.type, subnet.name].toString();
    if (!(key in grouping)) {
      grouping[key] = [];
    }
    grouping[key].push(subnet);
  }
  const groups = Object.values(grouping).map((sns) => {
    sns.sort((a32, b32) => a32.az.localeCompare(b32.az));
    return {
      type: sns[0].type,
      name: sns[0].name,
      subnets: sns
    };
  });
  const azs = groups[0].subnets.map((s) => s.az);
  for (const group7 of groups) {
    const groupAZs = group7.subnets.map((s) => s.az);
    if (!arraysEqual(groupAZs, azs)) {
      throw new ContextProviderError("InconsistentSubnetAzs", `Not all subnets in VPC have the same AZs: ${groupAZs} vs ${azs}`);
    }
  }
  return { azs, groups };
}
function groupAsymmetricSubnets(subnets) {
  const grouping = {};
  for (const subnet of subnets) {
    const key = [subnet.type, subnet.name].toString();
    if (!(key in grouping)) {
      grouping[key] = [];
    }
    grouping[key].push(subnet);
  }
  return Object.values(grouping).map((subnetArray) => {
    subnetArray.sort((subnet1, subnet2) => subnet1.az.localeCompare(subnet2.az));
    return {
      name: subnetArray[0].name,
      type: subnetTypeToVpcSubnetType(subnetArray[0].type),
      subnets: subnetArray.map((subnet) => ({
        subnetId: subnet.subnetId,
        cidr: subnet.cidr,
        availabilityZone: subnet.az,
        routeTableId: subnet.routeTableId
      }))
    };
  });
}
function subnetTypeToVpcSubnetType(type) {
  switch (type) {
    case "Isolated" /* Isolated */:
      return import_cloud_assembly_api9.VpcSubnetGroupType.ISOLATED;
    case "Private" /* Private */:
      return import_cloud_assembly_api9.VpcSubnetGroupType.PRIVATE;
    case "Public" /* Public */:
      return import_cloud_assembly_api9.VpcSubnetGroupType.PUBLIC;
  }
}
function isValidSubnetType(val) {
  return val === "Public" /* Public */ || val === "Private" /* Private */ || val === "Isolated" /* Isolated */;
}
function arraysEqual(as, bs) {
  if (as.length !== bs.length) {
    return false;
  }
  for (let i32 = 0; i32 < as.length; i32++) {
    if (as[i32] !== bs[i32]) {
      return false;
    }
  }
  return true;
}
function findGroups(type, groups) {
  return groups.groups.filter((g32) => g32.type === type);
}
function flatMap3(xs, fn) {
  const ret = new Array();
  for (const x of xs) {
    ret.push(...fn(x));
  }
  return ret;
}
function collapse(xs) {
  if (xs.length > 0) {
    return xs;
  }
  return void 0;
}
var import_cloud_assembly_api9, VpcNetworkContextProviderPlugin, RouteTables;
var init_vpcs = __esm({
  "../@aws-cdk/toolkit-lib/lib/context-providers/vpcs.ts"() {
    "use strict";
    import_cloud_assembly_api9 = __toESM(require_lib3());
    init_private2();
    init_toolkit_error();
    VpcNetworkContextProviderPlugin = class {
      constructor(aws, io) {
        this.aws = aws;
        this.io = io;
      }
      aws;
      io;
      static {
        __name(this, "VpcNetworkContextProviderPlugin");
      }
      async getValue(args) {
        const ec2 = (await initContextProviderSdk(this.aws, args)).ec2();
        const vpcId = await this.findVpc(ec2, args);
        return this.readVpcProps(ec2, vpcId, args);
      }
      async findVpc(ec2, args) {
        const filters = Object.entries(args.filter).map(([tag3, value]) => ({ Name: tag3, Values: [value] }));
        await this.io.debug(`Listing VPCs in ${args.account}:${args.region}`);
        const response = await ec2.describeVpcs({ Filters: filters });
        const vpcs = response.Vpcs || [];
        if (vpcs.length === 0) {
          throw new ContextProviderError("VpcNotFound", `Could not find any VPCs matching ${JSON.stringify(args)}`);
        }
        if (vpcs.length > 1) {
          throw new ContextProviderError("MultipleVpcsFound", `Found ${vpcs.length} VPCs matching ${JSON.stringify(args)}; please narrow the search criteria`);
        }
        return vpcs[0];
      }
      async readVpcProps(ec2, vpc, args) {
        const vpcId = vpc.VpcId;
        await this.io.debug(`Describing VPC ${vpcId}`);
        const filters = { Filters: [{ Name: "vpc-id", Values: [vpcId] }] };
        const subnetsResponse = await ec2.describeSubnets(filters);
        const listedSubnets = subnetsResponse.Subnets || [];
        const routeTablesResponse = await ec2.describeRouteTables(filters);
        const routeTables = new RouteTables(routeTablesResponse.RouteTables || []);
        const azs = Array.from(new Set(listedSubnets.map((s) => s.AvailabilityZone)));
        azs.sort();
        const subnets = listedSubnets.map((subnet) => {
          let type = getTag("aws-cdk:subnet-type", subnet.Tags);
          if (type === void 0 && subnet.MapPublicIpOnLaunch) {
            type = "Public" /* Public */;
          }
          if (type === void 0 && routeTables.hasRouteToIgw(subnet.SubnetId)) {
            type = "Public" /* Public */;
          }
          if (type === void 0 && routeTables.hasRouteToNatGateway(subnet.SubnetId)) {
            type = "Private" /* Private */;
          }
          if (type === void 0 && routeTables.hasRouteToTransitGateway(subnet.SubnetId)) {
            type = "Private" /* Private */;
          }
          if (type === void 0) {
            type = "Isolated" /* Isolated */;
          }
          if (!isValidSubnetType(type)) {
            throw new ContextProviderError(
              "InvalidSubnetType",
              `Subnet ${subnet.SubnetArn} has invalid subnet type ${type} (must be ${"Public" /* Public */}, ${"Private" /* Private */} or ${"Isolated" /* Isolated */})`
            );
          }
          if (args.subnetGroupNameTag && !getTag(args.subnetGroupNameTag, subnet.Tags)) {
            throw new ContextProviderError(
              "MissingSubnetGroupTag",
              `Invalid subnetGroupNameTag: Subnet ${subnet.SubnetArn} does not have an associated tag with Key='${args.subnetGroupNameTag}'`
            );
          }
          const name = getTag(args.subnetGroupNameTag || "aws-cdk:subnet-name", subnet.Tags) || type;
          const routeTableId = routeTables.routeTableIdForSubnetId(subnet.SubnetId);
          if (!routeTableId) {
            throw new ContextProviderError(
              "MissingRouteTable",
              `Subnet ${subnet.SubnetArn} does not have an associated route table (and there is no "main" table)`
            );
          }
          return {
            az: subnet.AvailabilityZone,
            cidr: subnet.CidrBlock,
            type,
            name,
            subnetId: subnet.SubnetId,
            routeTableId
          };
        });
        let grouped;
        let assymetricSubnetGroups;
        if (args.returnAsymmetricSubnets) {
          grouped = { azs: [], groups: [] };
          assymetricSubnetGroups = groupAsymmetricSubnets(subnets);
        } else {
          grouped = groupSubnets(subnets);
          assymetricSubnetGroups = void 0;
        }
        const vpnGatewayResponse = args.returnVpnGateways ?? true ? await ec2.describeVpnGateways({
          Filters: [
            {
              Name: "attachment.vpc-id",
              Values: [vpcId]
            },
            {
              Name: "attachment.state",
              Values: ["attached"]
            },
            {
              Name: "state",
              Values: ["available"]
            }
          ]
        }) : void 0;
        const vpnGatewayId = vpnGatewayResponse?.VpnGateways?.length === 1 ? vpnGatewayResponse.VpnGateways[0].VpnGatewayId : void 0;
        return {
          vpcId,
          vpcCidrBlock: vpc.CidrBlock,
          ownerAccountId: vpc.OwnerId,
          availabilityZones: grouped.azs,
          isolatedSubnetIds: collapse(
            flatMap3(findGroups("Isolated" /* Isolated */, grouped), (group7) => group7.subnets.map((s) => s.subnetId))
          ),
          isolatedSubnetNames: collapse(
            flatMap3(findGroups("Isolated" /* Isolated */, grouped), (group7) => group7.name ? [group7.name] : [])
          ),
          isolatedSubnetRouteTableIds: collapse(
            flatMap3(findGroups("Isolated" /* Isolated */, grouped), (group7) => group7.subnets.map((s) => s.routeTableId))
          ),
          privateSubnetIds: collapse(
            flatMap3(findGroups("Private" /* Private */, grouped), (group7) => group7.subnets.map((s) => s.subnetId))
          ),
          privateSubnetNames: collapse(
            flatMap3(findGroups("Private" /* Private */, grouped), (group7) => group7.name ? [group7.name] : [])
          ),
          privateSubnetRouteTableIds: collapse(
            flatMap3(findGroups("Private" /* Private */, grouped), (group7) => group7.subnets.map((s) => s.routeTableId))
          ),
          publicSubnetIds: collapse(
            flatMap3(findGroups("Public" /* Public */, grouped), (group7) => group7.subnets.map((s) => s.subnetId))
          ),
          publicSubnetNames: collapse(
            flatMap3(findGroups("Public" /* Public */, grouped), (group7) => group7.name ? [group7.name] : [])
          ),
          publicSubnetRouteTableIds: collapse(
            flatMap3(findGroups("Public" /* Public */, grouped), (group7) => group7.subnets.map((s) => s.routeTableId))
          ),
          vpnGatewayId,
          subnetGroups: assymetricSubnetGroups
        };
      }
    };
    RouteTables = class {
      constructor(tables) {
        this.tables = tables;
        this.mainRouteTable = this.tables.find(
          (table3) => !!table3.Associations && table3.Associations.some((assoc) => !!assoc.Main)
        );
      }
      tables;
      static {
        __name(this, "RouteTables");
      }
      mainRouteTable;
      routeTableIdForSubnetId(subnetId) {
        const table3 = this.tableForSubnet(subnetId);
        return table3 && table3.RouteTableId || this.mainRouteTable && this.mainRouteTable.RouteTableId;
      }
      /**
       * Whether the given subnet has a route to a NAT Gateway
       */
      hasRouteToNatGateway(subnetId) {
        const table3 = this.tableForSubnet(subnetId) || this.mainRouteTable;
        return !!table3 && !!table3.Routes && table3.Routes.some((route) => !!route.NatGatewayId && route.DestinationCidrBlock === "0.0.0.0/0");
      }
      /**
       * Whether the given subnet has a route to a Transit Gateway
       */
      hasRouteToTransitGateway(subnetId) {
        const table3 = this.tableForSubnet(subnetId) || this.mainRouteTable;
        return !!table3 && !!table3.Routes && table3.Routes.some((route) => !!route.TransitGatewayId && route.DestinationCidrBlock === "0.0.0.0/0");
      }
      /**
       * Whether the given subnet has a route to an IGW
       */
      hasRouteToIgw(subnetId) {
        const table3 = this.tableForSubnet(subnetId) || this.mainRouteTable;
        return !!table3 && !!table3.Routes && table3.Routes.some((route) => !!route.GatewayId && route.GatewayId.startsWith("igw-"));
      }
      tableForSubnet(subnetId) {
        return this.tables.find(
          (table3) => !!table3.Associations && table3.Associations.some((assoc) => assoc.SubnetId === subnetId)
        );
      }
    };
    __name(getTag, "getTag");
    __name(groupSubnets, "groupSubnets");
    __name(groupAsymmetricSubnets, "groupAsymmetricSubnets");
    __name(subnetTypeToVpcSubnetType, "subnetTypeToVpcSubnetType");
    __name(isValidSubnetType, "isValidSubnetType");
    __name(arraysEqual, "arraysEqual");
    __name(findGroups, "findGroups");
    __name(flatMap3, "flatMap");
    __name(collapse, "collapse");
  }
});

// ../@aws-cdk/toolkit-lib/lib/context-providers/index.ts
async function provideContextValues(missingValues, sdk, pluginHost, ioHelper) {
  const updates = {};
  for (const missingContext of missingValues) {
    const key = missingContext.key;
    const providerName = missingContext.provider === cxschema9.ContextProvider.PLUGIN ? `${PLUGIN_PROVIDER_PREFIX}:${missingContext.props.pluginName}` : missingContext.provider;
    let factory;
    if (providerName.startsWith(`${PLUGIN_PROVIDER_PREFIX}:`)) {
      const plugin = pluginHost.contextProviderPlugins[providerName.substring(PLUGIN_PROVIDER_PREFIX.length + 1)];
      if (!plugin) {
        throw new ContextProviderError("UnrecognizedPlugin", `Unrecognized plugin context provider name: ${missingContext.provider}.`);
      }
      factory = /* @__PURE__ */ __name(() => plugin, "factory");
    } else {
      factory = availableContextProviders[providerName];
      if (!factory) {
        throw new ContextProviderError("UnrecognizedProvider", `Unrecognized context provider name: ${missingContext.provider}. You might need to update the toolkit to match the version of the construct library.`);
      }
    }
    const provider = factory(sdk, new ContextProviderMessages(ioHelper, providerName));
    let value;
    try {
      const environment = missingContext.props.account && missingContext.props.region ? import_cloud_assembly_api10.EnvironmentUtils.make(missingContext.props.account, missingContext.props.region) : void 0;
      const resolvedEnvironment = environment ? await sdk.resolveEnvironment(environment) : { account: "?", region: "?", name: "?" };
      const arns = await replaceEnvPlaceholders({
        lookupRoleArn: missingContext.props.lookupRoleArn
      }, resolvedEnvironment, sdk);
      value = await provider.getValue({ ...missingContext.props, lookupRoleArn: arns.lookupRoleArn });
    } catch (e32) {
      value = { [import_cloud_assembly_api10.PROVIDER_ERROR_KEY]: formatErrorMessage(e32), [TRANSIENT_CONTEXT_KEY]: true };
    }
    updates[key] = value;
    await ioHelper.defaults.debug(`Setting "${key}" context to ${JSON.stringify(value)}`);
  }
  return updates;
}
var import_cloud_assembly_api10, cxschema9, PLUGIN_PROVIDER_PREFIX, ContextProviderMessages, availableContextProviders;
var init_context_providers = __esm({
  "../@aws-cdk/toolkit-lib/lib/context-providers/index.ts"() {
    "use strict";
    import_cloud_assembly_api10 = __toESM(require_lib3());
    cxschema9 = __toESM(require_lib2());
    init_ami2();
    init_availability_zones2();
    init_cc_api_provider();
    init_endpoint_service_availability_zones2();
    init_hosted_zones();
    init_keys();
    init_load_balancers();
    init_security_groups();
    init_ssm_parameters();
    init_vpcs();
    init_context2();
    init_environment2();
    init_private();
    init_toolkit_error();
    init_util3();
    PLUGIN_PROVIDER_PREFIX = "plugin";
    ContextProviderMessages = class {
      static {
        __name(this, "ContextProviderMessages");
      }
      ioHelper;
      providerName;
      constructor(ioHelper, providerName) {
        this.ioHelper = ioHelper;
        this.providerName = providerName;
      }
      async info(message2) {
        return this.ioHelper.notify(IO.CDK_ASSEMBLY_I0300.msg(message2, {
          provider: this.providerName
        }));
      }
      async debug(message2) {
        return this.ioHelper.notify(IO.CDK_ASSEMBLY_I0301.msg(message2, {
          provider: this.providerName
        }));
      }
    };
    __name(provideContextValues, "provideContextValues");
    availableContextProviders = {
      [cxschema9.ContextProvider.AVAILABILITY_ZONE_PROVIDER]: (s, io) => new AZContextProviderPlugin(s, io),
      [cxschema9.ContextProvider.SSM_PARAMETER_PROVIDER]: (s, io) => new SSMContextProviderPlugin(s, io),
      [cxschema9.ContextProvider.HOSTED_ZONE_PROVIDER]: (s, io) => new HostedZoneContextProviderPlugin(s, io),
      [cxschema9.ContextProvider.VPC_PROVIDER]: (s, io) => new VpcNetworkContextProviderPlugin(s, io),
      [cxschema9.ContextProvider.AMI_PROVIDER]: (s, io) => new AmiContextProviderPlugin(s, io),
      [cxschema9.ContextProvider.ENDPOINT_SERVICE_AVAILABILITY_ZONE_PROVIDER]: (s, io) => new EndpointServiceAZContextProviderPlugin(s, io),
      [cxschema9.ContextProvider.SECURITY_GROUP_PROVIDER]: (s) => new SecurityGroupContextProviderPlugin(s),
      [cxschema9.ContextProvider.LOAD_BALANCER_PROVIDER]: (s) => new LoadBalancerContextProviderPlugin(s),
      [cxschema9.ContextProvider.LOAD_BALANCER_LISTENER_PROVIDER]: (s) => new LoadBalancerListenerContextProviderPlugin(s),
      [cxschema9.ContextProvider.KEY_PROVIDER]: (s, io) => new KeyContextProviderPlugin(s, io),
      [cxschema9.ContextProvider.CC_API_PROVIDER]: (s) => new CcApiContextProviderPlugin(s)
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/private/helpers.ts
function temporarilyWriteEnv(env3) {
  const oldEnv = process.env;
  process.env = detectSynthvarConflicts({
    ...process.env,
    ...env3
  });
  return {
    [Symbol.dispose]() {
      process.env = oldEnv;
    }
  };
}
function detectSynthvarConflicts(obj) {
  return new Proxy(obj, {
    get(target, prop) {
      return target[prop];
    },
    set(target, prop, value) {
      if (["CDK_CONTEXT", "CDK_OUTDIR"].includes(String(prop))) {
        throw new ToolkitError("EnvImmutableDuringSynth", "process.env is temporarily immutable. Set 'clobberEnv: false' if you want to run multiple 'fromAssemblyBuilder' synths concurrently");
      }
      target[prop] = value;
      return true;
    }
  });
}
function missingContextKeys(missing) {
  return new Set((missing || []).map((m20) => m20.key));
}
var init_helpers = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/private/helpers.ts"() {
    "use strict";
    init_toolkit_error();
    __name(temporarilyWriteEnv, "temporarilyWriteEnv");
    __name(detectSynthvarConflicts, "detectSynthvarConflicts");
    __name(missingContextKeys, "missingContextKeys");
  }
});

// ../@aws-cdk/toolkit-lib/lib/util/sets.ts
function equalSets(a32, b32) {
  if (a32.size !== b32.size) {
    return false;
  }
  for (const x of a32) {
    if (!b32.has(x)) {
      return false;
    }
  }
  return true;
}
function setDiff(a32, b32) {
  return new Set(Array.from(a32).filter((x) => !b32.has(x)));
}
var init_sets = __esm({
  "../@aws-cdk/toolkit-lib/lib/util/sets.ts"() {
    "use strict";
    __name(equalSets, "equalSets");
    __name(setDiff, "setDiff");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/private/context-aware-source.ts
var ContextAwareCloudAssemblySource;
var init_context_aware_source = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/private/context-aware-source.ts"() {
    "use strict";
    init_disposable_box();
    init_context_providers();
    init_toolkit_error();
    init_private();
    init_helpers();
    init_sets();
    ContextAwareCloudAssemblySource = class {
      constructor(source, props) {
        this.source = source;
        this.props = props;
        this.canLookup = props.lookups ?? true;
        this.context = props.contextStore;
        this.ioHelper = props.services.ioHelper;
      }
      source;
      props;
      static {
        __name(this, "ContextAwareCloudAssemblySource");
      }
      canLookup;
      context;
      ioHelper;
      /**
       * Produce a Cloud Assembly, i.e. a set of stacks
       */
      async produce() {
        let previouslyMissingKeys;
        while (true) {
          var _stack = [];
          try {
            const readableAsm = __using(_stack, new AsyncDisposableBox(await this.source.produce()), true);
            const assembly = readableAsm.value.cloudAssembly;
            if (assembly.manifest.missing && assembly.manifest.missing.length > 0) {
              const missingKeysSet = missingContextKeys(assembly.manifest.missing);
              const missingKeys = Array.from(missingKeysSet);
              if (!this.canLookup) {
                throw new ToolkitError(
                  "ContextLookupsDisabled",
                  `Context lookups have been disabled. Make sure all necessary context is already in 'cdk.context.json' by running 'cdk synth' on a machine with sufficient AWS credentials and committing the result. Missing context keys: '${missingKeys.join(", ")}'`
                );
              }
              let tryLookup = true;
              if (previouslyMissingKeys && equalSets(missingKeysSet, previouslyMissingKeys)) {
                await this.ioHelper.notify(IO.CDK_ASSEMBLY_I0240.msg("Not making progress trying to resolve environmental context. Giving up.", { missingKeys }));
                tryLookup = false;
              }
              previouslyMissingKeys = missingKeysSet;
              if (tryLookup) {
                await this.ioHelper.notify(IO.CDK_ASSEMBLY_I0241.msg("Some context information is missing. Fetching...", { missingKeys }));
                const contextUpdates = await provideContextValues(
                  assembly.manifest.missing,
                  this.props.services.sdkProvider,
                  this.props.services.pluginHost,
                  this.ioHelper
                );
                await this.ioHelper.notify(IO.CDK_ASSEMBLY_I0042.msg("Writing context updates...", {
                  context: contextUpdates
                }));
                await this.context.update(contextUpdates);
                await readableAsm.value._unlock();
                continue;
              }
            }
            return readableAsm.take();
          } catch (_) {
            var _error = _, _hasError = true;
          } finally {
            var _promise = __callDispose(_stack, _error, _hasError);
            _promise && await _promise;
          }
        }
      }
    };
  }
});

// ../../node_modules/split2/index.js
var require_split2 = __commonJS({
  "../../node_modules/split2/index.js"(exports2, module2) {
    "use strict";
    var { Transform } = require("stream");
    var { StringDecoder } = require("string_decoder");
    var kLast = /* @__PURE__ */ Symbol("last");
    var kDecoder = /* @__PURE__ */ Symbol("decoder");
    function transform(chunk, enc, cb) {
      let list3;
      if (this.overflow) {
        const buf = this[kDecoder].write(chunk);
        list3 = buf.split(this.matcher);
        if (list3.length === 1) return cb();
        list3.shift();
        this.overflow = false;
      } else {
        this[kLast] += this[kDecoder].write(chunk);
        list3 = this[kLast].split(this.matcher);
      }
      this[kLast] = list3.pop();
      for (let i32 = 0; i32 < list3.length; i32++) {
        try {
          push(this, this.mapper(list3[i32]));
        } catch (error4) {
          return cb(error4);
        }
      }
      this.overflow = this[kLast].length > this.maxLength;
      if (this.overflow && !this.skipOverflow) {
        cb(new Error("maximum buffer reached"));
        return;
      }
      cb();
    }
    __name(transform, "transform");
    function flush3(cb) {
      this[kLast] += this[kDecoder].end();
      if (this[kLast]) {
        try {
          push(this, this.mapper(this[kLast]));
        } catch (error4) {
          return cb(error4);
        }
      }
      cb();
    }
    __name(flush3, "flush");
    function push(self2, val) {
      if (val !== void 0) {
        self2.push(val);
      }
    }
    __name(push, "push");
    function noop(incoming) {
      return incoming;
    }
    __name(noop, "noop");
    function split4(matcher, mapper, options) {
      matcher = matcher || /\r?\n/;
      mapper = mapper || noop;
      options = options || {};
      switch (arguments.length) {
        case 1:
          if (typeof matcher === "function") {
            mapper = matcher;
            matcher = /\r?\n/;
          } else if (typeof matcher === "object" && !(matcher instanceof RegExp) && !matcher[Symbol.split]) {
            options = matcher;
            matcher = /\r?\n/;
          }
          break;
        case 2:
          if (typeof matcher === "function") {
            options = mapper;
            mapper = matcher;
            matcher = /\r?\n/;
          } else if (typeof mapper === "object") {
            options = mapper;
            mapper = noop;
          }
      }
      options = Object.assign({}, options);
      options.autoDestroy = true;
      options.transform = transform;
      options.flush = flush3;
      options.readableObjectMode = true;
      const stream = new Transform(options);
      stream[kLast] = "";
      stream[kDecoder] = new StringDecoder("utf8");
      stream.matcher = matcher;
      stream.mapper = mapper;
      stream.maxLength = options.maxLength;
      stream.skipOverflow = options.skipOverflow || false;
      stream.overflow = false;
      stream._destroy = function(err, cb) {
        this._writableState.errorEmitted = false;
        cb(err);
      };
      return stream;
    }
    __name(split4, "split");
    module2.exports = split4;
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/private/exec.ts
async function execInChildProcess(commandAndArgs, options = {}) {
  const captureOutput = options.captureOutput ?? true;
  return new Promise((ok, fail) => {
    const proc = child_process2.spawn(commandAndArgs, {
      stdio: captureOutput ? ["ignore", "pipe", "pipe"] : ["ignore", "inherit", "inherit"],
      detached: false,
      cwd: options.cwd,
      env: {
        // On Windwows, Python will default to cp1252 when not connected to a terminal, but we
        // expect it to be UTF-8 below (to be able to split on lines).
        PYTHONIOENCODING: "utf-8",
        ...options.env
      },
      // We are using 'shell: true' on purprose. Traditionally we have allowed shell features in
      // this string, so we have to continue to do so into the future. On Windows, this is simply
      // necessary to run .bat and .cmd files properly.
      // Code scanning tools will flag this as a risk. The input comes from a trusted source,
      // so it does not represent a security risk.
      shell: true
    });
    const eventPublisher = options.eventPublisher ?? ((type, line) => {
      switch (type) {
        case "data_stdout":
          process.stdout.write(line + "\n");
          return;
        case "data_stderr":
          process.stderr.write(line + "\n");
          return;
        case "open":
        case "close":
          return;
      }
    });
    const stderr = new Array();
    if (captureOutput) {
      proc.stdout.pipe(split3()).on("data", (line) => eventPublisher("data_stdout", line));
      proc.stderr.pipe(split3()).on("data", (line) => {
        stderr.push(line);
        return eventPublisher("data_stderr", line);
      });
    }
    proc.on("error", (e32) => {
      fail(AssemblyError.withCause(`Failed to execute CDK app: ${commandAndArgs}`, e32));
    });
    proc.on("exit", (code) => {
      if (code === 0) {
        return ok();
      } else {
        const stdErrString = stderr.join("\n");
        let cause;
        if (stderr.length) {
          cause = new Error(stdErrString);
          cause.name = "ExecutionError";
        }
        let error4 = AssemblyError.withCause(`${commandAndArgs}: Subprocess exited with error ${code}`, cause);
        if (options.errorCodeFile) {
          const contents = tryReadFile(options.errorCodeFile);
          if (contents) {
            const errorInStdErr = contents.split("\n")[0];
            if (errorInStdErr) {
              error4.attachSynthesisErrorCode(errorInStdErr);
            }
          }
        }
        return fail(error4);
      }
    });
  });
}
function tryReadFile(name) {
  try {
    return (0, import_fs4.readFileSync)(name, "utf-8");
  } catch (e32) {
    if (e32.code === "ENOENT") {
      return void 0;
    }
    throw e32;
  }
}
var child_process2, import_fs4, split3;
var init_exec = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/private/exec.ts"() {
    "use strict";
    child_process2 = __toESM(require("child_process"));
    import_fs4 = require("fs");
    init_toolkit_error();
    split3 = require_split2();
    __name(execInChildProcess, "execInChildProcess");
    __name(tryReadFile, "tryReadFile");
  }
});

// ../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/context/vpc.js
var require_vpc = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/context/vpc.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.VpcSubnetGroupType = void 0;
    var VpcSubnetGroupType3;
    (function(VpcSubnetGroupType4) {
      VpcSubnetGroupType4["PUBLIC"] = "Public";
      VpcSubnetGroupType4["PRIVATE"] = "Private";
      VpcSubnetGroupType4["ISOLATED"] = "Isolated";
    })(VpcSubnetGroupType3 || (exports2.VpcSubnetGroupType = VpcSubnetGroupType3 = {}));
  }
});

// ../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/context/ami.js
var require_ami = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/context/ami.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
  }
});

// ../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/context/load-balancer.js
var require_load_balancer = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/context/load-balancer.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.LoadBalancerIpAddressType = void 0;
    var LoadBalancerIpAddressType3;
    (function(LoadBalancerIpAddressType4) {
      LoadBalancerIpAddressType4["IPV4"] = "ipv4";
      LoadBalancerIpAddressType4["DUAL_STACK"] = "dualstack";
      LoadBalancerIpAddressType4["DUAL_STACK_WITHOUT_PUBLIC_IPV4"] = "dualstack-without-public-ipv4";
    })(LoadBalancerIpAddressType3 || (exports2.LoadBalancerIpAddressType = LoadBalancerIpAddressType3 = {}));
  }
});

// ../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/context/availability-zones.js
var require_availability_zones = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/context/availability-zones.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.AVAILABILITY_ZONE_FALLBACK_CONTEXT_KEY = void 0;
    exports2.AVAILABILITY_ZONE_FALLBACK_CONTEXT_KEY = "aws:cdk:availability-zones:fallback";
  }
});

// ../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/context/endpoint-service-availability-zones.js
var require_endpoint_service_availability_zones = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/context/endpoint-service-availability-zones.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ENDPOINT_SERVICE_AVAILABILITY_ZONE_PROVIDER = void 0;
    exports2.ENDPOINT_SERVICE_AVAILABILITY_ZONE_PROVIDER = "endpoint-service-availability-zones";
  }
});

// ../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/context/security-group.js
var require_security_group = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/context/security-group.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
  }
});

// ../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/context/key.js
var require_key = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/context/key.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
  }
});

// ../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/context/generic.js
var require_generic = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/context/generic.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.PROVIDER_ERROR_KEY = void 0;
    exports2.PROVIDER_ERROR_KEY = "$providerError";
  }
});

// ../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/metadata.js
var require_metadata = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/metadata.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.SynthesisMessageLevel = exports2.PATH_METADATA_KEY = void 0;
    exports2.PATH_METADATA_KEY = "aws:cdk:path";
    var SynthesisMessageLevel5;
    (function(SynthesisMessageLevel6) {
      SynthesisMessageLevel6["INFO"] = "info";
      SynthesisMessageLevel6["WARNING"] = "warning";
      SynthesisMessageLevel6["ERROR"] = "error";
    })(SynthesisMessageLevel5 || (exports2.SynthesisMessageLevel = SynthesisMessageLevel5 = {}));
  }
});

// ../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/private/error.js
var require_error2 = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/private/error.js"(exports2) {
    "use strict";
    var __classPrivateFieldGet2 = exports2 && exports2.__classPrivateFieldGet || function(receiver, state13, kind, f32) {
      if (kind === "a" && !f32) throw new TypeError("Private accessor was defined without a getter");
      if (typeof state13 === "function" ? receiver !== state13 || !f32 : !state13.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
      return kind === "m" ? f32 : kind === "a" ? f32.call(receiver) : f32 ? f32.value : state13.get(receiver);
    };
    var __classPrivateFieldSet2 = exports2 && exports2.__classPrivateFieldSet || function(receiver, state13, value, kind, f32) {
      if (kind === "m") throw new TypeError("Private method is not writable");
      if (kind === "a" && !f32) throw new TypeError("Private accessor was defined without a setter");
      if (typeof state13 === "function" ? receiver !== state13 || !f32 : !state13.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
      return kind === "a" ? f32.call(receiver, value) : f32 ? f32.value = value : state13.set(receiver, value), value;
    };
    var _CloudAssemblyError_time;
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.CloudAssemblyError = void 0;
    var ASSEMBLY_ERROR_SYMBOL3 = /* @__PURE__ */ Symbol.for("@aws-cdk/cx-api.CloudAssemblyError");
    var CloudAssemblyError2 = class _CloudAssemblyError extends Error {
      static {
        __name(this, "CloudAssemblyError");
      }
      /**
       * The time the error was thrown.
       */
      get time() {
        return __classPrivateFieldGet2(this, _CloudAssemblyError_time, "f");
      }
      get type() {
        return "assembly";
      }
      constructor(msg) {
        super(msg);
        _CloudAssemblyError_time.set(this, void 0);
        Object.setPrototypeOf(this, _CloudAssemblyError.prototype);
        Object.defineProperty(this, ASSEMBLY_ERROR_SYMBOL3, { value: true });
        this.name = new.target.name;
        __classPrivateFieldSet2(this, _CloudAssemblyError_time, (/* @__PURE__ */ new Date()).toISOString(), "f");
      }
    };
    exports2.CloudAssemblyError = CloudAssemblyError2;
    _CloudAssemblyError_time = /* @__PURE__ */ new WeakMap();
  }
});

// ../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/cloud-artifact.js
var require_cloud_artifact = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/cloud-artifact.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.CloudArtifact = void 0;
    var fs51 = require("fs");
    var path47 = require("path");
    var cxschema12 = require_lib2();
    var metadata_1 = require_metadata();
    var error_1 = require_error2();
    var CloudArtifact2 = class _CloudArtifact {
      static {
        __name(this, "CloudArtifact");
      }
      /**
       * Read the metadata for the given artifact
       *
       * HISTORICAL OR PRIVATE USE ONLY
       *
       * This is publicly exposed as a static function for downstream libraries that
       * don't use the `CloudAssembly`/`CloudArtifact` API, yet still need to read
       * an artifact's metadata.
       *
       * 99% of consumers should just access `artifact.metadata`.
       */
      static readMetadata(assemblyDirectory, x) {
        const ret = {};
        if (x.additionalMetadataFile) {
          Object.assign(ret, JSON.parse(fs51.readFileSync(path47.join(assemblyDirectory, x.additionalMetadataFile), "utf-8")));
        }
        for (const [p10, entries] of Object.entries(x.metadata ?? {})) {
          if (ret[p10]) {
            ret[p10].push(...entries);
          } else {
            ret[p10] = entries;
          }
        }
        return ret;
      }
      /**
       * Returns a subclass of `CloudArtifact` based on the artifact type defined in the artifact manifest.
       *
       * @param assembly - The cloud assembly from which to load the artifact
       * @param id - The artifact ID
       * @param artifact - The artifact manifest
       * @returns the `CloudArtifact` that matches the artifact type or `undefined` if it's an artifact type that is unrecognized by this module.
       */
      static fromManifest(assembly, id, artifact) {
        void assembly, void id, void artifact;
        throw new error_1.CloudAssemblyError("Implementation not overridden yet");
      }
      constructor(assembly, id, manifest) {
        this.assembly = assembly;
        this.id = id;
        this.manifest = manifest;
        this.messages = this.renderMessages();
        this._dependencyIDs = manifest.dependencies || [];
      }
      /**
       * Returns the metadata associated with this Cloud Artifact
       */
      get metadata() {
        return _CloudArtifact.readMetadata(this.assembly.directory, this.manifest);
      }
      /**
       * Returns all the artifacts that this artifact depends on.
       */
      get dependencies() {
        if (this._deps) {
          return this._deps;
        }
        this._deps = this._dependencyIDs.map((id) => {
          const dep = this.assembly.tryGetArtifact(id);
          if (!dep) {
            throw new error_1.CloudAssemblyError(`Artifact ${this.id} depends on non-existing artifact ${id}`);
          }
          return dep;
        });
        return this._deps;
      }
      /**
       * @returns all the metadata entries of a specific type in this artifact.
       */
      findMetadataByType(type) {
        const metadata = this.metadata;
        const result2 = new Array();
        for (const p10 of Object.keys(metadata || {})) {
          for (const entry of (metadata || {})[p10]) {
            if (entry.type === type) {
              result2.push({ path: p10, ...entry });
            }
          }
        }
        return result2;
      }
      renderMessages() {
        const messages = new Array();
        for (const [id, metadata] of Object.entries(this.metadata || {})) {
          for (const entry of metadata) {
            let level;
            switch (entry.type) {
              case cxschema12.ArtifactMetadataEntryType.WARN:
                level = metadata_1.SynthesisMessageLevel.WARNING;
                break;
              case cxschema12.ArtifactMetadataEntryType.ERROR:
                level = metadata_1.SynthesisMessageLevel.ERROR;
                break;
              case cxschema12.ArtifactMetadataEntryType.INFO:
                level = metadata_1.SynthesisMessageLevel.INFO;
                break;
              default:
                continue;
            }
            messages.push({ level, entry, id });
          }
        }
        return messages;
      }
      /**
       * An identifier that shows where this artifact is located in the tree
       * of nested assemblies, based on their manifests. Defaults to the normal
       * id. Should only be used in user interfaces.
       */
      get hierarchicalId() {
        return this.manifest.displayName ?? this.id;
      }
    };
    exports2.CloudArtifact = CloudArtifact2;
  }
});

// ../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/artifacts/asset-manifest-artifact.js
var require_asset_manifest_artifact = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/artifacts/asset-manifest-artifact.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.AssetManifestArtifact = void 0;
    var fs51 = require("fs");
    var path47 = require("path");
    var cloud_artifact_1 = require_cloud_artifact();
    var error_1 = require_error2();
    var ASSET_MANIFEST_ARTIFACT_SYM2 = /* @__PURE__ */ Symbol.for("@aws-cdk/cx-api.AssetManifestArtifact");
    var AssetManifestArtifact6 = class extends cloud_artifact_1.CloudArtifact {
      static {
        __name(this, "AssetManifestArtifact");
      }
      /**
       * Checks if `art` is an instance of this class.
       *
       * Use this method instead of `instanceof` to properly detect `AssetManifestArtifact`
       * instances, even when the construct library is symlinked.
       *
       * Explanation: in JavaScript, multiple copies of the `cx-api` library on
       * disk are seen as independent, completely different libraries. As a
       * consequence, the class `AssetManifestArtifact` in each copy of the `cx-api` library
       * is seen as a different class, and an instance of one class will not test as
       * `instanceof` the other class. `npm install` will not create installations
       * like this, but users may manually symlink construct libraries together or
       * use a monorepo tool: in those cases, multiple copies of the `cx-api`
       * library can be accidentally installed, and `instanceof` will behave
       * unpredictably. It is safest to avoid using `instanceof`, and using
       * this type-testing method instead.
       */
      static isAssetManifestArtifact(art) {
        return art && typeof art === "object" && art[ASSET_MANIFEST_ARTIFACT_SYM2];
      }
      constructor(assembly, name, artifact) {
        super(assembly, name, artifact);
        const properties = this.manifest.properties || {};
        if (!properties.file) {
          throw new error_1.CloudAssemblyError('Invalid AssetManifestArtifact. Missing "file" property');
        }
        this.file = path47.resolve(this.assembly.directory, properties.file);
        this.requiresBootstrapStackVersion = properties.requiresBootstrapStackVersion;
        this.bootstrapStackVersionSsmParameter = properties.bootstrapStackVersionSsmParameter;
      }
      /**
       * The Asset Manifest contents
       */
      get contents() {
        if (this._contents !== void 0) {
          return this._contents;
        }
        const contents = this._contents = JSON.parse(fs51.readFileSync(this.file, "utf-8"));
        return contents;
      }
    };
    exports2.AssetManifestArtifact = AssetManifestArtifact6;
    Object.defineProperty(AssetManifestArtifact6.prototype, ASSET_MANIFEST_ARTIFACT_SYM2, {
      value: true,
      enumerable: false,
      writable: false
    });
  }
});

// ../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/environment.js
var require_environment = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/environment.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.EnvironmentUtils = exports2.UNKNOWN_REGION = exports2.UNKNOWN_ACCOUNT = void 0;
    var error_1 = require_error2();
    var AWS_ENV_REGEX2 = /aws\:\/\/([a-z0-9A-Z\-\@\.\_]+)\/([a-z\-0-9]+)/;
    exports2.UNKNOWN_ACCOUNT = "unknown-account";
    exports2.UNKNOWN_REGION = "unknown-region";
    var EnvironmentUtils5 = class {
      static {
        __name(this, "EnvironmentUtils");
      }
      static parse(environment) {
        const env3 = AWS_ENV_REGEX2.exec(environment);
        if (!env3) {
          throw new error_1.CloudAssemblyError(`Unable to parse environment specification "${environment}". Expected format: aws://account/region`);
        }
        const [, account, region] = env3;
        if (!account || !region) {
          throw new error_1.CloudAssemblyError(`Invalid environment specification: ${environment}`);
        }
        return { account, region, name: environment };
      }
      /**
       * Build an environment object from an account and region
       */
      static make(account, region) {
        return { account, region, name: this.format(account, region) };
      }
      /**
       * Format an environment string from an account and region
       */
      static format(account, region) {
        return `aws://${account}/${region}`;
      }
    };
    exports2.EnvironmentUtils = EnvironmentUtils5;
  }
});

// ../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/artifacts/cloudformation-artifact.js
var require_cloudformation_artifact = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/artifacts/cloudformation-artifact.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.CloudFormationStackArtifact = void 0;
    var fs51 = require("fs");
    var path47 = require("path");
    var cxschema12 = require_lib2();
    var cloud_artifact_1 = require_cloud_artifact();
    var environment_1 = require_environment();
    var error_1 = require_error2();
    var CLOUDFORMATION_STACK_ARTIFACT_SYM2 = /* @__PURE__ */ Symbol.for("@aws-cdk/cx-api.CloudFormationStackArtifact");
    var CloudFormationStackArtifact4 = class extends cloud_artifact_1.CloudArtifact {
      static {
        __name(this, "CloudFormationStackArtifact");
      }
      /**
       * Checks if `art` is an instance of this class.
       *
       * Use this method instead of `instanceof` to properly detect `CloudFormationStackArtifact`
       * instances, even when the construct library is symlinked.
       *
       * Explanation: in JavaScript, multiple copies of the `cx-api` library on
       * disk are seen as independent, completely different libraries. As a
       * consequence, the class `CloudFormationStackArtifact` in each copy of the `cx-api` library
       * is seen as a different class, and an instance of one class will not test as
       * `instanceof` the other class. `npm install` will not create installations
       * like this, but users may manually symlink construct libraries together or
       * use a monorepo tool: in those cases, multiple copies of the `cx-api`
       * library can be accidentally installed, and `instanceof` will behave
       * unpredictably. It is safest to avoid using `instanceof`, and using
       * this type-testing method instead.
       */
      static isCloudFormationStackArtifact(art) {
        return art && typeof art === "object" && CLOUDFORMATION_STACK_ARTIFACT_SYM2 in art;
      }
      constructor(assembly, artifactId, artifact) {
        super(assembly, artifactId, artifact);
        const properties = this.manifest.properties || {};
        if (!properties.templateFile) {
          throw new error_1.CloudAssemblyError('Invalid CloudFormation stack artifact. Missing "templateFile" property in cloud assembly manifest');
        }
        if (!artifact.environment) {
          throw new error_1.CloudAssemblyError("Invalid CloudFormation stack artifact. Missing environment");
        }
        this.environment = environment_1.EnvironmentUtils.parse(artifact.environment);
        this.templateFile = properties.templateFile;
        this.parameters = properties.parameters ?? {};
        this.tags = properties.tags ?? {};
        this.notificationArns = properties.notificationArns;
        this.assumeRoleArn = properties.assumeRoleArn;
        this.assumeRoleExternalId = properties.assumeRoleExternalId;
        this.assumeRoleAdditionalOptions = properties.assumeRoleAdditionalOptions;
        this.cloudFormationExecutionRoleArn = properties.cloudFormationExecutionRoleArn;
        this.stackTemplateAssetObjectUrl = properties.stackTemplateAssetObjectUrl;
        this.requiresBootstrapStackVersion = properties.requiresBootstrapStackVersion;
        this.bootstrapStackVersionSsmParameter = properties.bootstrapStackVersionSsmParameter;
        this.terminationProtection = properties.terminationProtection;
        this.validateOnSynth = properties.validateOnSynth;
        this.lookupRole = properties.lookupRole;
        this.stackName = properties.stackName || artifactId;
        this.assets = this.findMetadataByType(cxschema12.ArtifactMetadataEntryType.ASSET).map((e32) => e32.data);
        this.displayName = this.stackName === artifactId ? this.hierarchicalId : `${this.hierarchicalId} (${this.stackName})`;
        this.name = this.stackName;
        this.originalName = this.stackName;
      }
      /**
       * Full path to the template file
       */
      get templateFullPath() {
        return path47.join(this.assembly.directory, this.templateFile);
      }
      /**
       * The CloudFormation template for this stack.
       */
      get template() {
        if (this._template === void 0) {
          this._template = JSON.parse(fs51.readFileSync(this.templateFullPath, "utf-8"));
        }
        return this._template;
      }
    };
    exports2.CloudFormationStackArtifact = CloudFormationStackArtifact4;
    Object.defineProperty(CloudFormationStackArtifact4.prototype, CLOUDFORMATION_STACK_ARTIFACT_SYM2, {
      value: true,
      enumerable: false,
      writable: false
    });
  }
});

// ../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/artifacts/nested-cloud-assembly-artifact.js
var require_nested_cloud_assembly_artifact = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/artifacts/nested-cloud-assembly-artifact.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.NestedCloudAssemblyArtifact = void 0;
    var path47 = require("path");
    var cloud_artifact_1 = require_cloud_artifact();
    var NESTED_CLOUD_ASSEMBLY_SYM2 = /* @__PURE__ */ Symbol.for("@aws-cdk/cx-api.NestedCloudAssemblyArtifact");
    var NestedCloudAssemblyArtifact3 = class extends cloud_artifact_1.CloudArtifact {
      static {
        __name(this, "NestedCloudAssemblyArtifact");
      }
      /**
       * Checks if `art` is an instance of this class.
       *
       * Use this method instead of `instanceof` to properly detect `NestedCloudAssemblyArtifact`
       * instances, even when the construct library is symlinked.
       *
       * Explanation: in JavaScript, multiple copies of the `cx-api` library on
       * disk are seen as independent, completely different libraries. As a
       * consequence, the class `NestedCloudAssemblyArtifact` in each copy of the `cx-api` library
       * is seen as a different class, and an instance of one class will not test as
       * `instanceof` the other class. `npm install` will not create installations
       * like this, but users may manually symlink construct libraries together or
       * use a monorepo tool: in those cases, multiple copies of the `cx-api`
       * library can be accidentally installed, and `instanceof` will behave
       * unpredictably. It is safest to avoid using `instanceof`, and using
       * this type-testing method instead.
       */
      static isNestedCloudAssemblyArtifact(art) {
        return art && typeof art === "object" && NESTED_CLOUD_ASSEMBLY_SYM2 in art;
      }
      constructor(assembly, name, artifact) {
        super(assembly, name, artifact);
        const properties = this.manifest.properties || {};
        this.directoryName = properties.directoryName;
        this.displayName = properties.displayName ?? name;
      }
      /**
       * Full path to the nested assembly directory
       */
      get fullPath() {
        return path47.join(this.assembly.directory, this.directoryName);
      }
    };
    exports2.NestedCloudAssemblyArtifact = NestedCloudAssemblyArtifact3;
    Object.defineProperty(NestedCloudAssemblyArtifact3.prototype, NESTED_CLOUD_ASSEMBLY_SYM2, {
      value: true,
      enumerable: false,
      writable: false
    });
  }
});

// ../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/artifacts/tree-cloud-artifact.js
var require_tree_cloud_artifact = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/artifacts/tree-cloud-artifact.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.TreeCloudArtifact = void 0;
    var cloud_artifact_1 = require_cloud_artifact();
    var error_1 = require_error2();
    var TREE_CLOUD_ARTIFACT_SYM2 = /* @__PURE__ */ Symbol.for("@aws-cdk/cx-api.TreeCloudArtifact");
    var TreeCloudArtifact2 = class extends cloud_artifact_1.CloudArtifact {
      static {
        __name(this, "TreeCloudArtifact");
      }
      /**
       * Checks if `art` is an instance of this class.
       *
       * Use this method instead of `instanceof` to properly detect `TreeCloudArtifact`
       * instances, even when the construct library is symlinked.
       *
       * Explanation: in JavaScript, multiple copies of the `cx-api` library on
       * disk are seen as independent, completely different libraries. As a
       * consequence, the class `TreeCloudArtifact` in each copy of the `cx-api` library
       * is seen as a different class, and an instance of one class will not test as
       * `instanceof` the other class. `npm install` will not create installations
       * like this, but users may manually symlink construct libraries together or
       * use a monorepo tool: in those cases, multiple copies of the `cx-api`
       * library can be accidentally installed, and `instanceof` will behave
       * unpredictably. It is safest to avoid using `instanceof`, and using
       * this type-testing method instead.
       */
      static isTreeCloudArtifact(art) {
        return art && typeof art === "object" && TREE_CLOUD_ARTIFACT_SYM2 in art;
      }
      constructor(assembly, name, artifact) {
        super(assembly, name, artifact);
        const properties = this.manifest.properties || {};
        if (!properties.file) {
          throw new error_1.CloudAssemblyError('Invalid TreeCloudArtifact. Missing "file" property');
        }
        this.file = properties.file;
      }
    };
    exports2.TreeCloudArtifact = TreeCloudArtifact2;
    Object.defineProperty(TreeCloudArtifact2.prototype, TREE_CLOUD_ARTIFACT_SYM2, {
      value: true,
      enumerable: false,
      writable: false
    });
  }
});

// ../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/cloud-artifact-aug.js
var require_cloud_artifact_aug = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/cloud-artifact-aug.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var cxschema12 = require_lib2();
    var asset_manifest_artifact_1 = require_asset_manifest_artifact();
    var cloudformation_artifact_1 = require_cloudformation_artifact();
    var nested_cloud_assembly_artifact_1 = require_nested_cloud_assembly_artifact();
    var tree_cloud_artifact_1 = require_tree_cloud_artifact();
    var cloud_artifact_1 = require_cloud_artifact();
    cloud_artifact_1.CloudArtifact.fromManifest = /* @__PURE__ */ __name(function fromManifest2(assembly, id, artifact) {
      switch (artifact.type) {
        case cxschema12.ArtifactType.AWS_CLOUDFORMATION_STACK:
          return new cloudformation_artifact_1.CloudFormationStackArtifact(assembly, id, artifact);
        case cxschema12.ArtifactType.CDK_TREE:
          return new tree_cloud_artifact_1.TreeCloudArtifact(assembly, id, artifact);
        case cxschema12.ArtifactType.ASSET_MANIFEST:
          return new asset_manifest_artifact_1.AssetManifestArtifact(assembly, id, artifact);
        case cxschema12.ArtifactType.NESTED_CLOUD_ASSEMBLY:
          return new nested_cloud_assembly_artifact_1.NestedCloudAssemblyArtifact(assembly, id, artifact);
        default:
          return void 0;
      }
    }, "fromManifest");
  }
});

// ../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/private/toposort.js
var require_toposort = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/private/toposort.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.topologicalSort = topologicalSort2;
    var error_1 = require_error2();
    function topologicalSort2(xs, keyFn, depFn) {
      const remaining = /* @__PURE__ */ new Map();
      for (const element of xs) {
        const key = keyFn(element);
        remaining.set(key, { key, element, dependencies: depFn(element) });
      }
      const ret = new Array();
      while (remaining.size > 0) {
        const selectable = Array.from(remaining.values()).filter((e32) => e32.dependencies.every((d32) => !remaining.has(d32)));
        selectable.sort((a32, b32) => a32.key < b32.key ? -1 : b32.key < a32.key ? 1 : 0);
        for (const selected of selectable) {
          ret.push(selected.element);
          remaining.delete(selected.key);
        }
        if (selectable.length === 0) {
          throw new error_1.CloudAssemblyError(`Could not determine ordering between: ${Array.from(remaining.keys()).join(", ")}`);
        }
      }
      return ret;
    }
    __name(topologicalSort2, "topologicalSort");
  }
});

// ../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/cloud-assembly.js
var require_cloud_assembly = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/cloud-assembly.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.CloudAssemblyBuilder = exports2.CloudAssembly = void 0;
    var fs51 = require("fs");
    var os14 = require("os");
    var path47 = require("path");
    var cxschema12 = require_lib2();
    var cloudformation_artifact_1 = require_cloudformation_artifact();
    var nested_cloud_assembly_artifact_1 = require_nested_cloud_assembly_artifact();
    var tree_cloud_artifact_1 = require_tree_cloud_artifact();
    var cloud_artifact_1 = require_cloud_artifact();
    var error_1 = require_error2();
    var toposort_1 = require_toposort();
    var CLOUD_ASSEMBLY_SYMBOL2 = /* @__PURE__ */ Symbol.for("@aws-cdk/cx-api.CloudAssembly");
    var MANIFEST_FILE2 = "manifest.json";
    var CloudAssembly7 = class {
      static {
        __name(this, "CloudAssembly");
      }
      /**
       * Return whether the given object is a CloudAssembly.
       *
       * We do attribute detection since we can't reliably use 'instanceof'.
       */
      static isCloudAssembly(x) {
        return x !== null && typeof x === "object" && CLOUD_ASSEMBLY_SYMBOL2 in x;
      }
      /**
       * Cleans up any temporary assembly directories that got created in this process
       *
       * If a Cloud Assembly is emitted to a temporary directory, its directory gets
       * added to a list. This function iterates over that list and deletes each
       * directory in it, to free up disk space.
       *
       * This function will normally be called automatically during Node process
       * exit and so you don't need to call this. However, some test environments do
       * not properly trigger Node's `exit` event. Notably: Jest does not trigger
       * the `exit` event (<https://github.com/jestjs/jest/issues/10927>).
       *
       * ## Cleaning up temporary directories in jest
       *
       * For Jest, you have to make sure this function is called at the end of the
       * test suite instead:
       *
       * ```js
       * import { CloudAssembly } from 'aws-cdk-lib/cx-api';
       *
       * afterAll(CloudAssembly.cleanupTemporaryDirectories);
       * ```
       *
       * Alternatively, you can use the `setupFilesAfterEnv` feature and use a
       * provided helper script to automatically inject the above into every
       * test file, so you don't have to do it by hand.
       *
       * ```
       * $ npx jest --setupFilesAfterEnv aws-cdk-lib/testhelpers/jest-autoclean
       * ```
       *
       * Or put the following into `jest.config.js`:
       *
       * ```js
       * module.exports = {
       *   // ...
       *   setupFilesAfterEnv: ['aws-cdk-lib/testhelpers/jest-cleanup'],
       * };
       * ```
       */
      static cleanupTemporaryDirectories() {
        for (const dir of TEMPORARY_ASSEMBLY_DIRS2) {
          fs51.rmSync(dir, { recursive: true, force: true });
        }
        TEMPORARY_ASSEMBLY_DIRS2.splice(0, TEMPORARY_ASSEMBLY_DIRS2.length);
      }
      /**
       * Reads a cloud assembly from the specified directory.
       * @param directory - The root directory of the assembly.
       */
      constructor(directory, loadOptions) {
        this.directory = directory;
        this.loadOptions = loadOptions;
        this.manifest = cxschema12.Manifest.loadAssemblyManifest(path47.join(directory, MANIFEST_FILE2), this.loadOptions);
        this.version = this.manifest.version;
        this.artifacts = this.renderArtifacts(this.loadOptions?.topoSort ?? true);
        this.runtime = this.manifest.runtime || { libraries: {} };
        Object.defineProperty(this, CLOUD_ASSEMBLY_SYMBOL2, { value: true });
        this.validateDeps();
      }
      /**
       * Attempts to find an artifact with a specific identity.
       * @returns A `CloudArtifact` object or `undefined` if the artifact does not exist in this assembly.
       * @param id - The artifact ID
       */
      tryGetArtifact(id) {
        return this.artifacts.find((a32) => a32.id === id);
      }
      /**
       * Returns a CloudFormation stack artifact from this assembly.
       *
       * Will only search the current assembly.
       *
       * @param stackName - the name of the CloudFormation stack.
       * @throws if there is no stack artifact by that name
       * @throws if there is more than one stack with the same stack name. You can
       * use `getStackArtifact(stack.artifactId)` instead.
       * @returns a `CloudFormationStackArtifact` object.
       */
      getStackByName(stackName) {
        const artifacts = this.artifacts.filter((a32) => a32 instanceof cloudformation_artifact_1.CloudFormationStackArtifact && a32.stackName === stackName);
        if (!artifacts || artifacts.length === 0) {
          throw new error_1.CloudAssemblyError(`Unable to find stack with stack name "${stackName}"`);
        }
        if (artifacts.length > 1) {
          throw new error_1.CloudAssemblyError(`There are multiple stacks with the stack name "${stackName}" (${artifacts.map((a32) => a32.id).join(",")}). Use "getStackArtifact(id)" instead`);
        }
        return artifacts[0];
      }
      /**
       * Returns a CloudFormation stack artifact by name from this assembly.
       * @deprecated renamed to `getStackByName` (or `getStackArtifact(id)`)
       */
      getStack(stackName) {
        return this.getStackByName(stackName);
      }
      /**
       * Returns a CloudFormation stack artifact from this assembly.
       *
       * @param artifactId - the artifact id of the stack (can be obtained through `stack.artifactId`).
       * @throws if there is no stack artifact with that id
       * @returns a `CloudFormationStackArtifact` object.
       */
      getStackArtifact(artifactId) {
        const artifact = this.tryGetArtifactRecursively(artifactId);
        if (!artifact) {
          throw new error_1.CloudAssemblyError(`Unable to find artifact with id "${artifactId}"`);
        }
        if (!(artifact instanceof cloudformation_artifact_1.CloudFormationStackArtifact)) {
          throw new error_1.CloudAssemblyError(`Artifact ${artifactId} is not a CloudFormation stack`);
        }
        return artifact;
      }
      tryGetArtifactRecursively(artifactId) {
        return this.stacksRecursively.find((a32) => a32.id === artifactId);
      }
      /**
       * Returns all the stacks, including the ones in nested assemblies
       */
      get stacksRecursively() {
        function search(stackArtifacts, assemblies) {
          if (assemblies.length === 0) {
            return stackArtifacts;
          }
          const [head, ...tail] = assemblies;
          const nestedAssemblies = head.nestedAssemblies.map((asm) => asm.nestedAssembly);
          return search(stackArtifacts.concat(head.stacks), tail.concat(nestedAssemblies));
        }
        __name(search, "search");
        return search([], [this]);
      }
      /**
       * Returns a nested assembly artifact.
       *
       * @param artifactId - The artifact ID of the nested assembly
       */
      getNestedAssemblyArtifact(artifactId) {
        const artifact = this.tryGetArtifact(artifactId);
        if (!artifact) {
          throw new error_1.CloudAssemblyError(`Unable to find artifact with id "${artifactId}"`);
        }
        if (!(artifact instanceof nested_cloud_assembly_artifact_1.NestedCloudAssemblyArtifact)) {
          throw new error_1.CloudAssemblyError(`Found artifact '${artifactId}' but it's not a nested cloud assembly`);
        }
        return artifact;
      }
      /**
       * Returns a nested assembly.
       *
       * @param artifactId - The artifact ID of the nested assembly
       */
      getNestedAssembly(artifactId) {
        return this.getNestedAssemblyArtifact(artifactId).nestedAssembly;
      }
      /**
       * Returns the tree metadata artifact from this assembly.
       * @throws if there is no metadata artifact by that name
       * @returns a `TreeCloudArtifact` object if there is one defined in the manifest, `undefined` otherwise.
       */
      tree() {
        const trees = this.artifacts.filter((a32) => a32.manifest.type === cxschema12.ArtifactType.CDK_TREE);
        if (trees.length === 0) {
          return void 0;
        } else if (trees.length > 1) {
          throw new error_1.CloudAssemblyError(`Multiple artifacts of type ${cxschema12.ArtifactType.CDK_TREE} found in manifest`);
        }
        const tree = trees[0];
        if (!(tree instanceof tree_cloud_artifact_1.TreeCloudArtifact)) {
          throw new error_1.CloudAssemblyError('"Tree" artifact is not of expected type');
        }
        return tree;
      }
      /**
       * @returns all the CloudFormation stack artifacts that are included in this assembly.
       */
      get stacks() {
        return this.artifacts.filter(isCloudFormationStackArtifact);
        function isCloudFormationStackArtifact(x) {
          return x instanceof cloudformation_artifact_1.CloudFormationStackArtifact;
        }
        __name(isCloudFormationStackArtifact, "isCloudFormationStackArtifact");
      }
      /**
       * The nested assembly artifacts in this assembly
       */
      get nestedAssemblies() {
        return this.artifacts.filter(isNestedCloudAssemblyArtifact);
        function isNestedCloudAssemblyArtifact(x) {
          return x instanceof nested_cloud_assembly_artifact_1.NestedCloudAssemblyArtifact;
        }
        __name(isNestedCloudAssemblyArtifact, "isNestedCloudAssemblyArtifact");
      }
      validateDeps() {
        for (const artifact of this.artifacts) {
          ignore2(artifact.dependencies);
        }
      }
      renderArtifacts(topoSort) {
        const result2 = new Array();
        for (const [name, artifact] of Object.entries(this.manifest.artifacts || {})) {
          const cloudartifact = cloud_artifact_1.CloudArtifact.fromManifest(this, name, artifact);
          if (cloudartifact) {
            result2.push(cloudartifact);
          }
        }
        return topoSort ? (0, toposort_1.topologicalSort)(result2, (x) => x.id, (x) => x._dependencyIDs) : result2;
      }
    };
    exports2.CloudAssembly = CloudAssembly7;
    var CloudAssemblyBuilder3 = class _CloudAssemblyBuilder {
      static {
        __name(this, "CloudAssemblyBuilder");
      }
      /**
       * Initializes a cloud assembly builder.
       * @param outdir - The output directory, uses temporary directory if undefined
       */
      constructor(outdir, props = {}) {
        this.artifacts = {};
        this.missing = new Array();
        this.outdir = determineOutputDirectory2(outdir);
        this.assetOutdir = props.assetOutdir ?? this.outdir;
        this.parentBuilder = props.parentBuilder;
        ensureDirSync2(this.outdir);
      }
      /**
       * Adds an artifact into the cloud assembly.
       * @param id - The ID of the artifact.
       * @param manifest - The artifact manifest
       */
      addArtifact(id, manifest) {
        this.artifacts[id] = filterUndefined2(manifest);
      }
      /**
       * Reports that some context is missing in order for this cloud assembly to be fully synthesized.
       * @param missing - Missing context information.
       */
      addMissing(missing) {
        if (this.missing.every((m20) => m20.key !== missing.key)) {
          this.missing.push(missing);
        }
        this.parentBuilder?.addMissing(missing);
      }
      /**
       * Finalizes the cloud assembly into the output directory returns a
       * `CloudAssembly` object that can be used to inspect the assembly.
       */
      buildAssembly(options = {}) {
        let manifest = {
          version: cxschema12.Manifest.version(),
          artifacts: this.artifacts,
          runtime: options.runtimeInfo,
          missing: this.missing.length > 0 ? this.missing : void 0
        };
        manifest = filterUndefined2(manifest);
        const manifestFilePath = path47.join(this.outdir, MANIFEST_FILE2);
        cxschema12.Manifest.saveAssemblyManifest(manifest, manifestFilePath);
        fs51.writeFileSync(path47.join(this.outdir, "cdk.out"), JSON.stringify({ version: manifest.version }));
        return new CloudAssembly7(this.outdir);
      }
      /**
       * Creates a nested cloud assembly
       */
      createNestedAssembly(artifactId, displayName) {
        const directoryName = artifactId;
        const innerAsmDir = path47.join(this.outdir, directoryName);
        this.addArtifact(artifactId, {
          type: cxschema12.ArtifactType.NESTED_CLOUD_ASSEMBLY,
          properties: {
            directoryName,
            displayName
          }
        });
        return new _CloudAssemblyBuilder(innerAsmDir, {
          // Reuse the same asset output directory as the current Casm builder
          assetOutdir: this.assetOutdir,
          parentBuilder: this
        });
      }
      /**
       * Delete the cloud assembly directory
       */
      delete() {
        fs51.rmSync(this.outdir, { recursive: true, force: true });
      }
    };
    exports2.CloudAssemblyBuilder = CloudAssemblyBuilder3;
    function filterUndefined2(obj) {
      if (Array.isArray(obj)) {
        return obj.filter((x) => x !== void 0).map((x) => filterUndefined2(x));
      }
      if (typeof obj === "object") {
        const ret = {};
        for (const [key, value] of Object.entries(obj)) {
          if (value === void 0) {
            continue;
          }
          ret[key] = filterUndefined2(value);
        }
        return ret;
      }
      return obj;
    }
    __name(filterUndefined2, "filterUndefined");
    function ignore2(_x) {
      return;
    }
    __name(ignore2, "ignore");
    function determineOutputDirectory2(outdir) {
      if (outdir) {
        return outdir;
      }
      const tmpDir = fs51.mkdtempSync(path47.join(fs51.realpathSync(os14.tmpdir()), "cdk.out"));
      TEMPORARY_ASSEMBLY_DIRS2.push(tmpDir);
      return outdir ?? tmpDir;
    }
    __name(determineOutputDirectory2, "determineOutputDirectory");
    function ensureDirSync2(dir) {
      if (fs51.existsSync(dir)) {
        if (!fs51.statSync(dir).isDirectory()) {
          throw new error_1.CloudAssemblyError(`${dir} must be a directory`);
        }
      } else {
        fs51.mkdirSync(dir, { recursive: true });
      }
    }
    __name(ensureDirSync2, "ensureDirSync");
    var TEMPORARY_ASSEMBLY_DIRS2 = [];
    process.on("exit", () => CloudAssembly7.cleanupTemporaryDirectories());
  }
});

// ../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/artifacts/nested-cloud-assembly-artifact-aug.js
var require_nested_cloud_assembly_artifact_aug = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/artifacts/nested-cloud-assembly-artifact-aug.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var nested_cloud_assembly_artifact_1 = require_nested_cloud_assembly_artifact();
    var cloud_assembly_1 = require_cloud_assembly();
    var cacheSym2 = /* @__PURE__ */ Symbol();
    Object.defineProperty(nested_cloud_assembly_artifact_1.NestedCloudAssemblyArtifact.prototype, "nestedAssembly", {
      get() {
        if (!this[cacheSym2]) {
          this[cacheSym2] = new cloud_assembly_1.CloudAssembly(this.fullPath, this.assembly.loadOptions);
        }
        return this[cacheSym2];
      }
    });
  }
});

// ../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/assets.js
var require_assets = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/assets.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ASSET_PREFIX_SEPARATOR = exports2.ASSET_RESOURCE_METADATA_DOCKER_CACHE_DISABLED_KEY = exports2.ASSET_RESOURCE_METADATA_DOCKER_CACHE_TO_KEY = exports2.ASSET_RESOURCE_METADATA_DOCKER_CACHE_FROM_KEY = exports2.ASSET_RESOURCE_METADATA_DOCKER_OUTPUTS_KEY = exports2.ASSET_RESOURCE_METADATA_IS_BUNDLED_KEY = exports2.ASSET_RESOURCE_METADATA_PROPERTY_KEY = exports2.ASSET_RESOURCE_METADATA_DOCKER_BUILD_TARGET_KEY = exports2.ASSET_RESOURCE_METADATA_DOCKER_BUILD_SSH_KEY = exports2.ASSET_RESOURCE_METADATA_DOCKER_BUILD_SECRETS_KEY = exports2.ASSET_RESOURCE_METADATA_DOCKER_BUILD_CONTEXTS_KEY = exports2.ASSET_RESOURCE_METADATA_DOCKER_BUILD_ARGS_KEY = exports2.ASSET_RESOURCE_METADATA_DOCKERFILE_PATH_KEY = exports2.ASSET_RESOURCE_METADATA_PATH_KEY = exports2.ASSET_RESOURCE_METADATA_ENABLED_CONTEXT = void 0;
    exports2.ASSET_RESOURCE_METADATA_ENABLED_CONTEXT = "aws:cdk:enable-asset-metadata";
    exports2.ASSET_RESOURCE_METADATA_PATH_KEY = "aws:asset:path";
    exports2.ASSET_RESOURCE_METADATA_DOCKERFILE_PATH_KEY = "aws:asset:dockerfile-path";
    exports2.ASSET_RESOURCE_METADATA_DOCKER_BUILD_ARGS_KEY = "aws:asset:docker-build-args";
    exports2.ASSET_RESOURCE_METADATA_DOCKER_BUILD_CONTEXTS_KEY = "aws:asset:docker-build-contexts";
    exports2.ASSET_RESOURCE_METADATA_DOCKER_BUILD_SECRETS_KEY = "aws:asset:docker-build-secrets";
    exports2.ASSET_RESOURCE_METADATA_DOCKER_BUILD_SSH_KEY = "aws:asset:docker-build-ssh";
    exports2.ASSET_RESOURCE_METADATA_DOCKER_BUILD_TARGET_KEY = "aws:asset:docker-build-target";
    exports2.ASSET_RESOURCE_METADATA_PROPERTY_KEY = "aws:asset:property";
    exports2.ASSET_RESOURCE_METADATA_IS_BUNDLED_KEY = "aws:asset:is-bundled";
    exports2.ASSET_RESOURCE_METADATA_DOCKER_OUTPUTS_KEY = "aws:asset:docker-outputs";
    exports2.ASSET_RESOURCE_METADATA_DOCKER_CACHE_FROM_KEY = "aws:asset:docker-cache-from";
    exports2.ASSET_RESOURCE_METADATA_DOCKER_CACHE_TO_KEY = "aws:asset:docker-cache-to";
    exports2.ASSET_RESOURCE_METADATA_DOCKER_CACHE_DISABLED_KEY = "aws:asset:docker-cache-disabled";
    exports2.ASSET_PREFIX_SEPARATOR = "||";
  }
});

// ../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/placeholders.js
var require_placeholders = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/placeholders.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.EnvironmentPlaceholders = void 0;
    var EnvironmentPlaceholders6 = class _EnvironmentPlaceholders {
      static {
        __name(this, "EnvironmentPlaceholders");
      }
      /**
       * Replace the environment placeholders in all strings found in a complex object.
       *
       * Duplicated between cdk-assets and aws-cdk CLI because we don't have a good single place to put it
       * (they're nominally independent tools).
       */
      static replace(object, values) {
        return this.recurse(object, (value) => {
          value = replaceAll2(value, _EnvironmentPlaceholders.CURRENT_REGION, values.region);
          value = replaceAll2(value, _EnvironmentPlaceholders.CURRENT_ACCOUNT, values.accountId);
          value = replaceAll2(value, _EnvironmentPlaceholders.CURRENT_PARTITION, values.partition);
          return value;
        });
      }
      /**
       * Like 'replace', but asynchronous
       */
      static async replaceAsync(object, provider) {
        let needRegion = false;
        let needAccountId = false;
        let needPartition = false;
        this.recurse(object, (value) => {
          if (value.indexOf(_EnvironmentPlaceholders.CURRENT_REGION) > 1) {
            needRegion = true;
          }
          if (value.indexOf(_EnvironmentPlaceholders.CURRENT_ACCOUNT) > 1) {
            needAccountId = true;
          }
          if (value.indexOf(_EnvironmentPlaceholders.CURRENT_PARTITION) > 1) {
            needPartition = true;
          }
          return value;
        });
        const region = needRegion ? await provider.region() : void 0;
        const accountId = needAccountId ? await provider.accountId() : void 0;
        const partition4 = needPartition ? await provider.partition() : void 0;
        return this.recurse(object, (value) => {
          value = replaceAll2(value, _EnvironmentPlaceholders.CURRENT_REGION, region ?? "WONTHAPPEN");
          value = replaceAll2(value, _EnvironmentPlaceholders.CURRENT_ACCOUNT, accountId ?? "WONTHAPPEN");
          value = replaceAll2(value, _EnvironmentPlaceholders.CURRENT_PARTITION, partition4 ?? "WONTHAPPEN");
          return value;
        });
      }
      static recurse(value, cb) {
        if (typeof value === "string") {
          return cb(value);
        }
        if (typeof value !== "object" || value === null) {
          return value;
        }
        if (Array.isArray(value)) {
          return value.map((x) => this.recurse(x, cb));
        }
        const ret = {};
        for (const [key, inner] of Object.entries(value)) {
          ret[key] = this.recurse(inner, cb);
        }
        return ret;
      }
    };
    exports2.EnvironmentPlaceholders = EnvironmentPlaceholders6;
    EnvironmentPlaceholders6.CURRENT_REGION = "${AWS::Region}";
    EnvironmentPlaceholders6.CURRENT_ACCOUNT = "${AWS::AccountId}";
    EnvironmentPlaceholders6.CURRENT_PARTITION = "${AWS::Partition}";
    function replaceAll2(s, search, replace) {
      return s.split(search).join(replace);
    }
    __name(replaceAll2, "replaceAll");
  }
});

// ../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/bootstrap.js
var require_bootstrap = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/bootstrap.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.SSMPARAM_NO_INVALIDATE = void 0;
    exports2.SSMPARAM_NO_INVALIDATE = "[cdk:skip]";
  }
});

// ../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/index.js
var require_lib10 = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/node_modules/@aws-cdk/cloud-assembly-api/lib/index.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __exportStar3 = exports2 && exports2.__exportStar || function(m20, exports3) {
      for (var p10 in m20) if (p10 !== "default" && !Object.prototype.hasOwnProperty.call(exports3, p10)) __createBinding3(exports3, m20, p10);
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    __exportStar3(require_vpc(), exports2);
    __exportStar3(require_ami(), exports2);
    __exportStar3(require_load_balancer(), exports2);
    __exportStar3(require_availability_zones(), exports2);
    __exportStar3(require_endpoint_service_availability_zones(), exports2);
    __exportStar3(require_security_group(), exports2);
    __exportStar3(require_key(), exports2);
    __exportStar3(require_generic(), exports2);
    __exportStar3(require_cloud_artifact(), exports2);
    require_cloud_artifact_aug();
    __exportStar3(require_asset_manifest_artifact(), exports2);
    __exportStar3(require_cloudformation_artifact(), exports2);
    __exportStar3(require_tree_cloud_artifact(), exports2);
    __exportStar3(require_nested_cloud_assembly_artifact(), exports2);
    require_nested_cloud_assembly_artifact_aug();
    __exportStar3(require_cloud_assembly(), exports2);
    __exportStar3(require_assets(), exports2);
    __exportStar3(require_metadata(), exports2);
    __exportStar3(require_placeholders(), exports2);
    __exportStar3(require_environment(), exports2);
    __exportStar3(require_bootstrap(), exports2);
  }
});

// ../../node_modules/@aws-cdk/cx-api/lib/legacy-moved.js
var require_legacy_moved = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/lib/legacy-moved.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.LoadBalancerIpAddressType = exports2.VpcSubnetGroupType = exports2.SynthesisMessageLevel = exports2.UNKNOWN_REGION = exports2.UNKNOWN_ACCOUNT = exports2.SSMPARAM_NO_INVALIDATE = exports2.PROVIDER_ERROR_KEY = exports2.PATH_METADATA_KEY = exports2.ENDPOINT_SERVICE_AVAILABILITY_ZONE_PROVIDER = exports2.AVAILABILITY_ZONE_FALLBACK_CONTEXT_KEY = exports2.ASSET_RESOURCE_METADATA_PROPERTY_KEY = exports2.ASSET_RESOURCE_METADATA_PATH_KEY = exports2.ASSET_RESOURCE_METADATA_IS_BUNDLED_KEY = exports2.ASSET_RESOURCE_METADATA_ENABLED_CONTEXT = exports2.ASSET_RESOURCE_METADATA_DOCKERFILE_PATH_KEY = exports2.ASSET_RESOURCE_METADATA_DOCKER_OUTPUTS_KEY = exports2.ASSET_RESOURCE_METADATA_DOCKER_CACHE_TO_KEY = exports2.ASSET_RESOURCE_METADATA_DOCKER_CACHE_FROM_KEY = exports2.ASSET_RESOURCE_METADATA_DOCKER_CACHE_DISABLED_KEY = exports2.ASSET_RESOURCE_METADATA_DOCKER_BUILD_TARGET_KEY = exports2.ASSET_RESOURCE_METADATA_DOCKER_BUILD_SSH_KEY = exports2.ASSET_RESOURCE_METADATA_DOCKER_BUILD_SECRETS_KEY = exports2.ASSET_RESOURCE_METADATA_DOCKER_BUILD_CONTEXTS_KEY = exports2.ASSET_RESOURCE_METADATA_DOCKER_BUILD_ARGS_KEY = exports2.ASSET_PREFIX_SEPARATOR = void 0;
    exports2._convertCloudAssembly = _convertCloudAssembly;
    exports2._convertCloudAssemblyBuilder = _convertCloudAssemblyBuilder;
    var cloud_assembly_api_1 = require_lib10();
    Object.defineProperty(exports2, "ASSET_PREFIX_SEPARATOR", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return cloud_assembly_api_1.ASSET_PREFIX_SEPARATOR;
    }, "get") });
    Object.defineProperty(exports2, "ASSET_RESOURCE_METADATA_DOCKER_BUILD_ARGS_KEY", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return cloud_assembly_api_1.ASSET_RESOURCE_METADATA_DOCKER_BUILD_ARGS_KEY;
    }, "get") });
    Object.defineProperty(exports2, "ASSET_RESOURCE_METADATA_DOCKER_BUILD_CONTEXTS_KEY", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return cloud_assembly_api_1.ASSET_RESOURCE_METADATA_DOCKER_BUILD_CONTEXTS_KEY;
    }, "get") });
    Object.defineProperty(exports2, "ASSET_RESOURCE_METADATA_DOCKER_BUILD_SECRETS_KEY", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return cloud_assembly_api_1.ASSET_RESOURCE_METADATA_DOCKER_BUILD_SECRETS_KEY;
    }, "get") });
    Object.defineProperty(exports2, "ASSET_RESOURCE_METADATA_DOCKER_BUILD_SSH_KEY", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return cloud_assembly_api_1.ASSET_RESOURCE_METADATA_DOCKER_BUILD_SSH_KEY;
    }, "get") });
    Object.defineProperty(exports2, "ASSET_RESOURCE_METADATA_DOCKER_BUILD_TARGET_KEY", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return cloud_assembly_api_1.ASSET_RESOURCE_METADATA_DOCKER_BUILD_TARGET_KEY;
    }, "get") });
    Object.defineProperty(exports2, "ASSET_RESOURCE_METADATA_DOCKER_CACHE_DISABLED_KEY", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return cloud_assembly_api_1.ASSET_RESOURCE_METADATA_DOCKER_CACHE_DISABLED_KEY;
    }, "get") });
    Object.defineProperty(exports2, "ASSET_RESOURCE_METADATA_DOCKER_CACHE_FROM_KEY", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return cloud_assembly_api_1.ASSET_RESOURCE_METADATA_DOCKER_CACHE_FROM_KEY;
    }, "get") });
    Object.defineProperty(exports2, "ASSET_RESOURCE_METADATA_DOCKER_CACHE_TO_KEY", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return cloud_assembly_api_1.ASSET_RESOURCE_METADATA_DOCKER_CACHE_TO_KEY;
    }, "get") });
    Object.defineProperty(exports2, "ASSET_RESOURCE_METADATA_DOCKER_OUTPUTS_KEY", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return cloud_assembly_api_1.ASSET_RESOURCE_METADATA_DOCKER_OUTPUTS_KEY;
    }, "get") });
    Object.defineProperty(exports2, "ASSET_RESOURCE_METADATA_DOCKERFILE_PATH_KEY", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return cloud_assembly_api_1.ASSET_RESOURCE_METADATA_DOCKERFILE_PATH_KEY;
    }, "get") });
    Object.defineProperty(exports2, "ASSET_RESOURCE_METADATA_ENABLED_CONTEXT", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return cloud_assembly_api_1.ASSET_RESOURCE_METADATA_ENABLED_CONTEXT;
    }, "get") });
    Object.defineProperty(exports2, "ASSET_RESOURCE_METADATA_IS_BUNDLED_KEY", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return cloud_assembly_api_1.ASSET_RESOURCE_METADATA_IS_BUNDLED_KEY;
    }, "get") });
    Object.defineProperty(exports2, "ASSET_RESOURCE_METADATA_PATH_KEY", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return cloud_assembly_api_1.ASSET_RESOURCE_METADATA_PATH_KEY;
    }, "get") });
    Object.defineProperty(exports2, "ASSET_RESOURCE_METADATA_PROPERTY_KEY", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return cloud_assembly_api_1.ASSET_RESOURCE_METADATA_PROPERTY_KEY;
    }, "get") });
    Object.defineProperty(exports2, "AVAILABILITY_ZONE_FALLBACK_CONTEXT_KEY", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return cloud_assembly_api_1.AVAILABILITY_ZONE_FALLBACK_CONTEXT_KEY;
    }, "get") });
    Object.defineProperty(exports2, "ENDPOINT_SERVICE_AVAILABILITY_ZONE_PROVIDER", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return cloud_assembly_api_1.ENDPOINT_SERVICE_AVAILABILITY_ZONE_PROVIDER;
    }, "get") });
    Object.defineProperty(exports2, "PATH_METADATA_KEY", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return cloud_assembly_api_1.PATH_METADATA_KEY;
    }, "get") });
    Object.defineProperty(exports2, "PROVIDER_ERROR_KEY", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return cloud_assembly_api_1.PROVIDER_ERROR_KEY;
    }, "get") });
    Object.defineProperty(exports2, "SSMPARAM_NO_INVALIDATE", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return cloud_assembly_api_1.SSMPARAM_NO_INVALIDATE;
    }, "get") });
    Object.defineProperty(exports2, "UNKNOWN_ACCOUNT", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return cloud_assembly_api_1.UNKNOWN_ACCOUNT;
    }, "get") });
    Object.defineProperty(exports2, "UNKNOWN_REGION", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return cloud_assembly_api_1.UNKNOWN_REGION;
    }, "get") });
    var SynthesisMessageLevel5;
    (function(SynthesisMessageLevel6) {
      SynthesisMessageLevel6["INFO"] = "info";
      SynthesisMessageLevel6["WARNING"] = "warning";
      SynthesisMessageLevel6["ERROR"] = "error";
    })(SynthesisMessageLevel5 || (exports2.SynthesisMessageLevel = SynthesisMessageLevel5 = {}));
    exports2.CloudAssembly = cloud_assembly_api_1.CloudAssembly;
    exports2.CloudArtifact = cloud_assembly_api_1.CloudArtifact;
    exports2.CloudFormationStackArtifact = cloud_assembly_api_1.CloudFormationStackArtifact;
    exports2.AssetManifestArtifact = cloud_assembly_api_1.AssetManifestArtifact;
    exports2.NestedCloudAssemblyArtifact = cloud_assembly_api_1.NestedCloudAssemblyArtifact;
    exports2.TreeCloudArtifact = cloud_assembly_api_1.TreeCloudArtifact;
    exports2.CloudAssemblyBuilder = cloud_assembly_api_1.CloudAssemblyBuilder;
    function _convertCloudAssembly(x) {
      return x;
    }
    __name(_convertCloudAssembly, "_convertCloudAssembly");
    function _convertCloudAssemblyBuilder(x) {
      return x;
    }
    __name(_convertCloudAssemblyBuilder, "_convertCloudAssemblyBuilder");
    exports2.EnvironmentPlaceholders = cloud_assembly_api_1.EnvironmentPlaceholders;
    exports2.EnvironmentUtils = cloud_assembly_api_1.EnvironmentUtils;
    var VpcSubnetGroupType3;
    (function(VpcSubnetGroupType4) {
      VpcSubnetGroupType4["PUBLIC"] = "Public";
      VpcSubnetGroupType4["PRIVATE"] = "Private";
      VpcSubnetGroupType4["ISOLATED"] = "Isolated";
    })(VpcSubnetGroupType3 || (exports2.VpcSubnetGroupType = VpcSubnetGroupType3 = {}));
    var LoadBalancerIpAddressType3;
    (function(LoadBalancerIpAddressType4) {
      LoadBalancerIpAddressType4["IPV4"] = "ipv4";
      LoadBalancerIpAddressType4["DUAL_STACK"] = "dualstack";
      LoadBalancerIpAddressType4["DUAL_STACK_WITHOUT_PUBLIC_IPV4"] = "dualstack-without-public-ipv4";
    })(LoadBalancerIpAddressType3 || (exports2.LoadBalancerIpAddressType = LoadBalancerIpAddressType3 = {}));
  }
});

// ../../node_modules/@aws-cdk/cx-api/lib/cxapi.js
var require_cxapi = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/lib/cxapi.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.VALIDATION_REPORT_JSON_CONTEXT = exports2.LEGACY_VALIDATION_REPORT_FILE = exports2.VALIDATION_REPORT_FILE = exports2.FAIL_SYNTH_ON_VALIDATION_ERRORS_CONTEXT = exports2.TOOLKIT_VERSION_ENV = exports2.CLI_VERSION_ENV = exports2.CLI_ASM_VERSION_ENV = exports2.DEFAULT_REGION_ENV = exports2.DEFAULT_ACCOUNT_ENV = exports2.CONTEXT_OVERFLOW_LOCATION_ENV = exports2.PERF_COUNTERS_FILE_ENV = exports2.ERRORFILE_ENV = exports2.CONTEXT_ENV = exports2.OUTDIR_ENV = void 0;
    exports2.OUTDIR_ENV = "CDK_OUTDIR";
    exports2.CONTEXT_ENV = "CDK_CONTEXT_JSON";
    exports2.ERRORFILE_ENV = "CDK_ERROR_FILE";
    exports2.PERF_COUNTERS_FILE_ENV = "CDK_PERF_COUNTERS_FILE";
    exports2.CONTEXT_OVERFLOW_LOCATION_ENV = "CONTEXT_OVERFLOW_LOCATION_ENV";
    exports2.DEFAULT_ACCOUNT_ENV = "CDK_DEFAULT_ACCOUNT";
    exports2.DEFAULT_REGION_ENV = "CDK_DEFAULT_REGION";
    exports2.CLI_ASM_VERSION_ENV = "CDK_CLI_ASM_VERSION";
    exports2.CLI_VERSION_ENV = "CDK_CLI_VERSION";
    exports2.TOOLKIT_VERSION_ENV = "CDK_TOOLKIT_VERSION";
    exports2.FAIL_SYNTH_ON_VALIDATION_ERRORS_CONTEXT = "@aws-cdk/core:failSynthOnValidationErrors";
    exports2.VALIDATION_REPORT_FILE = "validation-report.json";
    exports2.LEGACY_VALIDATION_REPORT_FILE = "policy-validation-report.json";
    exports2.VALIDATION_REPORT_JSON_CONTEXT = "@aws-cdk/core:validationReportJson";
  }
});

// ../../node_modules/@aws-cdk/cx-api/lib/private/flag-modeling.js
var require_flag_modeling = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/lib/private/flag-modeling.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.MAGIC_V2NEXT = exports2.FlagType = void 0;
    exports2.compareVersions = compareVersions;
    var FlagType;
    (function(FlagType2) {
      FlagType2[FlagType2["ApiDefault"] = 0] = "ApiDefault";
      FlagType2[FlagType2["BugFix"] = 1] = "BugFix";
      FlagType2[FlagType2["VisibleContext"] = 2] = "VisibleContext";
      FlagType2[FlagType2["Temporary"] = 3] = "Temporary";
    })(FlagType || (exports2.FlagType = FlagType = {}));
    exports2.MAGIC_V2NEXT = "V2NEXT";
    function compareVersions(a32, b32) {
      if (a32 === b32) {
        return 0;
      }
      if (a32 === void 0) {
        return -1;
      }
      if (b32 === void 0) {
        return 1;
      }
      const as = a32.split(".").map((x) => parseInt(x, 10));
      const bs = b32.split(".").map((x) => parseInt(x, 10));
      if (a32 === exports2.MAGIC_V2NEXT) {
        return bs[0] <= 2 ? 1 : -1;
      }
      if (b32 === exports2.MAGIC_V2NEXT) {
        return as[0] <= 2 ? -1 : 1;
      }
      for (let i32 = 0; i32 < Math.min(as.length, bs.length); i32++) {
        if (as[i32] < bs[i32]) {
          return -1;
        }
        if (as[i32] > bs[i32]) {
          return 1;
        }
      }
      return as.length - bs.length;
    }
    __name(compareVersions, "compareVersions");
  }
});

// ../../node_modules/@aws-cdk/cx-api/lib/features.js
var require_features = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/lib/features.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.EFS_MOUNTTARGET_ORDERINSENSITIVE_LOGICAL_ID = exports2.EFS_DENY_ANONYMOUS_ACCESS = exports2.KMS_APPLY_IMPORTED_ALIAS_PERMISSIONS_TO_PRINCIPAL = exports2.KMS_ALIAS_NAME_REF = exports2.INCLUDE_PREFIX_IN_UNIQUE_NAME_GENERATION = exports2.APIGATEWAY_REQUEST_VALIDATOR_UNIQUE_ID = exports2.EC2_RESTRICT_DEFAULT_SECURITY_GROUP = exports2.ENABLE_EMR_SERVICE_POLICY_V2 = exports2.REDSHIFT_COLUMN_ID = exports2.SECRETS_MANAGER_TARGET_ATTACHMENT_RESOURCE_POLICY = exports2.EC2_LAUNCH_TEMPLATE_DEFAULT_USER_DATA = exports2.APIGATEWAY_AUTHORIZER_CHANGE_DEPLOYMENT_LOGICAL_ID = exports2.CODEDEPLOY_REMOVE_ALARMS_FROM_DEPLOYMENT_GROUP = exports2.DATABASE_PROXY_UNIQUE_RESOURCE_NAME = exports2.AWS_CUSTOM_RESOURCE_LATEST_SDK_DEFAULT = exports2.ROUTE53_PATTERNS_USE_DISTRIBUTION = exports2.ROUTE53_PATTERNS_USE_CERTIFICATE = exports2.S3_SERVER_ACCESS_LOGS_USE_BUCKET_POLICY = exports2.ECS_PATTERNS_SEC_GROUPS_DISABLES_IMPLICIT_OPEN_LISTENER = exports2.ECS_DISABLE_EXPLICIT_DEPLOYMENT_CONTROLLER_FOR_CIRCUIT_BREAKER = exports2.EVENTS_TARGET_QUEUE_SAME_ACCOUNT = exports2.ENABLE_PARTITION_LITERALS = exports2.APIGATEWAY_DISABLE_CLOUDWATCH_ROLE = exports2.SNS_SUBSCRIPTIONS_SQS_DECRYPTION_POLICY = exports2.S3_CREATE_DEFAULT_LOGGING_POLICY = exports2.CODEPIPELINE_CROSS_ACCOUNT_KEY_ALIAS_STACK_SAFE_RESOURCE_NAME = exports2.VALIDATE_SNAPSHOT_REMOVAL_POLICY = exports2.IAM_IMPORTED_ROLE_STACK_SAFE_DEFAULT_POLICY_NAME = exports2.IAM_MINIMIZE_POLICIES = exports2.ECS_ARN_FORMAT_INCLUDES_CLUSTER_NAME = exports2.EC2_UNIQUE_IMDSV2_LAUNCH_TEMPLATE_NAME = exports2.ECS_SERVICE_EXTENSIONS_ENABLE_DEFAULT_LOG_DRIVER = exports2.TARGET_PARTITIONS = exports2.CHECK_SECRET_USAGE = exports2.CLOUDFRONT_DEFAULT_SECURITY_POLICY_TLS_V1_2_2021 = exports2.LAMBDA_RECOGNIZE_LAYER_VERSION = exports2.LAMBDA_RECOGNIZE_VERSION_PROPS = exports2.EFS_DEFAULT_ENCRYPTION_AT_REST = exports2.APIGATEWAY_USAGEPLANKEY_ORDERINSENSITIVE_ID = exports2.RDS_LOWERCASE_DB_IDENTIFIER = exports2.ECS_REMOVE_DEFAULT_DESIRED_COUNT = exports2.S3_GRANT_WRITE_WITHOUT_ACL = exports2.KMS_DEFAULT_KEY_POLICIES = exports2.SECRETS_MANAGER_PARSE_OWNED_SECRET_NAME = exports2.DOCKER_IGNORE_SUPPORT = exports2.STACK_RELATIVE_EXPORTS_CONTEXT = exports2.NEW_STYLE_STACK_SYNTHESIS_CONTEXT = exports2.ENABLE_DIFF_NO_FAIL = exports2.ENABLE_DIFF_NO_FAIL_CONTEXT = exports2.ENABLE_STACK_NAME_DUPLICATES_CONTEXT = void 0;
    exports2.USE_CDK_MANAGED_LAMBDA_LOGGROUP = exports2.S3_PUBLIC_ACCESS_BLOCKED_BY_DEFAULT = exports2.USE_RESOURCEID_FOR_VPCV2_MIGRATION = exports2.EC2_REQUIRE_PRIVATE_SUBNETS_FOR_EGRESSONLYINTERNETGATEWAY = exports2.S3_TRUST_KEY_POLICY_FOR_SNS_SUBSCRIPTIONS = exports2.PIPELINE_REDUCE_CROSS_ACCOUNT_ACTION_ROLE_TRUST_SCOPE = exports2.LOG_USER_POOL_CLIENT_SECRET_VALUE = exports2.DYNAMODB_TABLE_RETAIN_TABLE_REPLICA = exports2.ASPECT_PRIORITIES_MUTATING = exports2.EVENTBUS_POLICY_SID_REQUIRED = exports2.PIPELINE_REDUCE_STAGE_ROLE_TRUST_SCOPE = exports2.SET_UNIQUE_REPLICATION_ROLE_NAME = exports2.LAMBDA_CREATE_NEW_POLICIES_WITH_ADDTOROLEPOLICY = exports2.ENABLE_ADDITIONAL_METADATA_COLLECTION = exports2.IAM_OIDC_REJECT_UNAUTHORIZED_CONNECTIONS = exports2.ALB_DUALSTACK_WITHOUT_PUBLIC_IPV4_SECURITY_GROUP_RULES_DEFAULT = exports2.USER_POOL_DOMAIN_NAME_METHOD_WITHOUT_CUSTOM_RESOURCE = exports2.SIGNER_PROFILE_NAME_PASSED_TO_CFN = exports2.ASPECT_STABILIZATION = exports2.BASTION_HOST_USE_AMAZON_LINUX_2023_BY_DEFAULT = exports2.STEPFUNCTIONS_USE_DISTRIBUTED_MAP_RESULT_WRITER_V2 = exports2.STEPFUNCTIONS_TASKS_FIX_RUN_ECS_TASK_POLICY = exports2.LAMBDA_NODEJS_SDK_V3_EXCLUDE_SMITHY_PACKAGES = exports2.CFN_INCLUDE_REJECT_COMPLEX_RESOURCE_UPDATE_CREATE_POLICY_INTRINSICS = exports2.USE_CORRECT_VALUE_FOR_INSTANCE_RESOURCE_ID_PROPERTY = exports2.APPSYNC_GRAPHQLAPI_SCOPE_LAMBDA_FUNCTION_PERMISSION = exports2.EC2_SUM_TIMEOUT_ENABLED = exports2.DYNAMODB_TABLEV2_RESOURCE_POLICY_PER_REPLICA = exports2.REDUCE_EC2_FARGATE_CLOUDWATCH_PERMISSIONS = exports2.EXPLICIT_STACK_TAGS = exports2.USE_NEW_S3URI_PARAMETERS_FOR_BEDROCK_INVOKE_MODEL_TASK = exports2.S3_KEEP_NOTIFICATION_IN_IMPORTED_BUCKET = exports2.LOG_API_RESPONSE_DATA_PROPERTY_TRUE_DEFAULT = exports2.ECS_REMOVE_DEFAULT_DEPLOYMENT_ALARM = exports2.EBS_DEFAULT_GP3 = exports2.ECS_PATTERNS_UNIQUE_TARGET_GROUP_ID = exports2.EKS_USE_NATIVE_OIDC_PROVIDER = exports2.EKS_NODEGROUP_NAME = exports2.PIPELINE_REDUCE_ASSET_ROLE_TRUST_SCOPE = exports2.KMS_REDUCE_CROSS_ACCOUNT_REGION_POLICY_SCOPE = exports2.CODEPIPELINE_DEFAULT_PIPELINE_TYPE_TO_V2 = exports2.CODEPIPELINE_CROSS_ACCOUNT_KEYS_DEFAULT_VALUE_TO_FALSE = exports2.LAMBDA_PERMISSION_LOGICAL_ID_FOR_LAMBDA_ACTION = exports2.CODECOMMIT_SOURCE_ACTION_DEFAULT_BRANCH_NAME = exports2.APPSYNC_ENABLE_USE_ARN_IDENTIFIER_SOURCE_API_ASSOCIATION = exports2.AURORA_CLUSTER_CHANGE_SCOPE_OF_INSTANCE_PARAMETER_GROUP_WITH_EACH_PARAMETERS = exports2.RDS_PREVENT_RENDERING_DEPRECATED_CREDENTIALS = exports2.LAMBDA_NODEJS_USE_LATEST_RUNTIME = exports2.ENABLE_OPENSEARCH_MULTIAZ_WITH_STANDBY = exports2.AUTOSCALING_GENERATE_LAUNCH_TEMPLATE = void 0;
    exports2.NEW_PROJECT_DEFAULT_CONTEXT = exports2.FUTURE_FLAGS = exports2.FUTURE_FLAGS_EXPIRED = exports2.CURRENT_VERSION_FLAG_DEFAULTS = exports2.CURRENTLY_RECOMMENDED_FLAGS = exports2.CURRENT_VERSION_EXPIRED_FLAGS = exports2.CURRENT_MV = exports2.FLAGS = exports2.DEFAULT_CROSS_STACK_REFERENCES = exports2.ANNOTATIONS_IN_VALIDATION_REPORT = exports2.EKS_DEFAULT_AL2023 = exports2.BATCH_DEFAULT_AL2023 = exports2.AUTOMATIC_L1_TRAITS = exports2.ELB_USE_POST_QUANTUM_TLS_POLICY = exports2.CLOUDFRONT_FUNCTION_DEFAULT_RUNTIME_V2_0 = exports2.STEPFUNCTIONS_TASKS_HTTPINVOKE_DYNAMIC_JSONPATH_ENDPOINT = exports2.NETWORK_LOAD_BALANCER_WITH_SECURITY_GROUP_BY_DEFAULT = void 0;
    exports2.futureFlagDefault = futureFlagDefault2;
    var flag_modeling_1 = require_flag_modeling();
    exports2.ENABLE_STACK_NAME_DUPLICATES_CONTEXT = "@aws-cdk/core:enableStackNameDuplicates";
    exports2.ENABLE_DIFF_NO_FAIL_CONTEXT = "aws-cdk:enableDiffNoFail";
    exports2.ENABLE_DIFF_NO_FAIL = exports2.ENABLE_DIFF_NO_FAIL_CONTEXT;
    exports2.NEW_STYLE_STACK_SYNTHESIS_CONTEXT = "@aws-cdk/core:newStyleStackSynthesis";
    exports2.STACK_RELATIVE_EXPORTS_CONTEXT = "@aws-cdk/core:stackRelativeExports";
    exports2.DOCKER_IGNORE_SUPPORT = "@aws-cdk/aws-ecr-assets:dockerIgnoreSupport";
    exports2.SECRETS_MANAGER_PARSE_OWNED_SECRET_NAME = "@aws-cdk/aws-secretsmanager:parseOwnedSecretName";
    exports2.KMS_DEFAULT_KEY_POLICIES = "@aws-cdk/aws-kms:defaultKeyPolicies";
    exports2.S3_GRANT_WRITE_WITHOUT_ACL = "@aws-cdk/aws-s3:grantWriteWithoutAcl";
    exports2.ECS_REMOVE_DEFAULT_DESIRED_COUNT = "@aws-cdk/aws-ecs-patterns:removeDefaultDesiredCount";
    exports2.RDS_LOWERCASE_DB_IDENTIFIER = "@aws-cdk/aws-rds:lowercaseDbIdentifier";
    exports2.APIGATEWAY_USAGEPLANKEY_ORDERINSENSITIVE_ID = "@aws-cdk/aws-apigateway:usagePlanKeyOrderInsensitiveId";
    exports2.EFS_DEFAULT_ENCRYPTION_AT_REST = "@aws-cdk/aws-efs:defaultEncryptionAtRest";
    exports2.LAMBDA_RECOGNIZE_VERSION_PROPS = "@aws-cdk/aws-lambda:recognizeVersionProps";
    exports2.LAMBDA_RECOGNIZE_LAYER_VERSION = "@aws-cdk/aws-lambda:recognizeLayerVersion";
    exports2.CLOUDFRONT_DEFAULT_SECURITY_POLICY_TLS_V1_2_2021 = "@aws-cdk/aws-cloudfront:defaultSecurityPolicyTLSv1.2_2021";
    exports2.CHECK_SECRET_USAGE = "@aws-cdk/core:checkSecretUsage";
    exports2.TARGET_PARTITIONS = "@aws-cdk/core:target-partitions";
    exports2.ECS_SERVICE_EXTENSIONS_ENABLE_DEFAULT_LOG_DRIVER = "@aws-cdk-containers/ecs-service-extensions:enableDefaultLogDriver";
    exports2.EC2_UNIQUE_IMDSV2_LAUNCH_TEMPLATE_NAME = "@aws-cdk/aws-ec2:uniqueImdsv2TemplateName";
    exports2.ECS_ARN_FORMAT_INCLUDES_CLUSTER_NAME = "@aws-cdk/aws-ecs:arnFormatIncludesClusterName";
    exports2.IAM_MINIMIZE_POLICIES = "@aws-cdk/aws-iam:minimizePolicies";
    exports2.IAM_IMPORTED_ROLE_STACK_SAFE_DEFAULT_POLICY_NAME = "@aws-cdk/aws-iam:importedRoleStackSafeDefaultPolicyName";
    exports2.VALIDATE_SNAPSHOT_REMOVAL_POLICY = "@aws-cdk/core:validateSnapshotRemovalPolicy";
    exports2.CODEPIPELINE_CROSS_ACCOUNT_KEY_ALIAS_STACK_SAFE_RESOURCE_NAME = "@aws-cdk/aws-codepipeline:crossAccountKeyAliasStackSafeResourceName";
    exports2.S3_CREATE_DEFAULT_LOGGING_POLICY = "@aws-cdk/aws-s3:createDefaultLoggingPolicy";
    exports2.SNS_SUBSCRIPTIONS_SQS_DECRYPTION_POLICY = "@aws-cdk/aws-sns-subscriptions:restrictSqsDescryption";
    exports2.APIGATEWAY_DISABLE_CLOUDWATCH_ROLE = "@aws-cdk/aws-apigateway:disableCloudWatchRole";
    exports2.ENABLE_PARTITION_LITERALS = "@aws-cdk/core:enablePartitionLiterals";
    exports2.EVENTS_TARGET_QUEUE_SAME_ACCOUNT = "@aws-cdk/aws-events:eventsTargetQueueSameAccount";
    exports2.ECS_DISABLE_EXPLICIT_DEPLOYMENT_CONTROLLER_FOR_CIRCUIT_BREAKER = "@aws-cdk/aws-ecs:disableExplicitDeploymentControllerForCircuitBreaker";
    exports2.ECS_PATTERNS_SEC_GROUPS_DISABLES_IMPLICIT_OPEN_LISTENER = "@aws-cdk/aws-ecs-patterns:secGroupsDisablesImplicitOpenListener";
    exports2.S3_SERVER_ACCESS_LOGS_USE_BUCKET_POLICY = "@aws-cdk/aws-s3:serverAccessLogsUseBucketPolicy";
    exports2.ROUTE53_PATTERNS_USE_CERTIFICATE = "@aws-cdk/aws-route53-patters:useCertificate";
    exports2.ROUTE53_PATTERNS_USE_DISTRIBUTION = "@aws-cdk/aws-route53-patterns:useDistribution";
    exports2.AWS_CUSTOM_RESOURCE_LATEST_SDK_DEFAULT = "@aws-cdk/customresources:installLatestAwsSdkDefault";
    exports2.DATABASE_PROXY_UNIQUE_RESOURCE_NAME = "@aws-cdk/aws-rds:databaseProxyUniqueResourceName";
    exports2.CODEDEPLOY_REMOVE_ALARMS_FROM_DEPLOYMENT_GROUP = "@aws-cdk/aws-codedeploy:removeAlarmsFromDeploymentGroup";
    exports2.APIGATEWAY_AUTHORIZER_CHANGE_DEPLOYMENT_LOGICAL_ID = "@aws-cdk/aws-apigateway:authorizerChangeDeploymentLogicalId";
    exports2.EC2_LAUNCH_TEMPLATE_DEFAULT_USER_DATA = "@aws-cdk/aws-ec2:launchTemplateDefaultUserData";
    exports2.SECRETS_MANAGER_TARGET_ATTACHMENT_RESOURCE_POLICY = "@aws-cdk/aws-secretsmanager:useAttachedSecretResourcePolicyForSecretTargetAttachments";
    exports2.REDSHIFT_COLUMN_ID = "@aws-cdk/aws-redshift:columnId";
    exports2.ENABLE_EMR_SERVICE_POLICY_V2 = "@aws-cdk/aws-stepfunctions-tasks:enableEmrServicePolicyV2";
    exports2.EC2_RESTRICT_DEFAULT_SECURITY_GROUP = "@aws-cdk/aws-ec2:restrictDefaultSecurityGroup";
    exports2.APIGATEWAY_REQUEST_VALIDATOR_UNIQUE_ID = "@aws-cdk/aws-apigateway:requestValidatorUniqueId";
    exports2.INCLUDE_PREFIX_IN_UNIQUE_NAME_GENERATION = "@aws-cdk/core:includePrefixInUniqueNameGeneration";
    exports2.KMS_ALIAS_NAME_REF = "@aws-cdk/aws-kms:aliasNameRef";
    exports2.KMS_APPLY_IMPORTED_ALIAS_PERMISSIONS_TO_PRINCIPAL = "@aws-cdk/aws-kms:applyImportedAliasPermissionsToPrincipal";
    exports2.EFS_DENY_ANONYMOUS_ACCESS = "@aws-cdk/aws-efs:denyAnonymousAccess";
    exports2.EFS_MOUNTTARGET_ORDERINSENSITIVE_LOGICAL_ID = "@aws-cdk/aws-efs:mountTargetOrderInsensitiveLogicalId";
    exports2.AUTOSCALING_GENERATE_LAUNCH_TEMPLATE = "@aws-cdk/aws-autoscaling:generateLaunchTemplateInsteadOfLaunchConfig";
    exports2.ENABLE_OPENSEARCH_MULTIAZ_WITH_STANDBY = "@aws-cdk/aws-opensearchservice:enableOpensearchMultiAzWithStandby";
    exports2.LAMBDA_NODEJS_USE_LATEST_RUNTIME = "@aws-cdk/aws-lambda-nodejs:useLatestRuntimeVersion";
    exports2.RDS_PREVENT_RENDERING_DEPRECATED_CREDENTIALS = "@aws-cdk/aws-rds:preventRenderingDeprecatedCredentials";
    exports2.AURORA_CLUSTER_CHANGE_SCOPE_OF_INSTANCE_PARAMETER_GROUP_WITH_EACH_PARAMETERS = "@aws-cdk/aws-rds:auroraClusterChangeScopeOfInstanceParameterGroupWithEachParameters";
    exports2.APPSYNC_ENABLE_USE_ARN_IDENTIFIER_SOURCE_API_ASSOCIATION = "@aws-cdk/aws-appsync:useArnForSourceApiAssociationIdentifier";
    exports2.CODECOMMIT_SOURCE_ACTION_DEFAULT_BRANCH_NAME = "@aws-cdk/aws-codepipeline-actions:useNewDefaultBranchForCodeCommitSource";
    exports2.LAMBDA_PERMISSION_LOGICAL_ID_FOR_LAMBDA_ACTION = "@aws-cdk/aws-cloudwatch-actions:changeLambdaPermissionLogicalIdForLambdaAction";
    exports2.CODEPIPELINE_CROSS_ACCOUNT_KEYS_DEFAULT_VALUE_TO_FALSE = "@aws-cdk/aws-codepipeline:crossAccountKeysDefaultValueToFalse";
    exports2.CODEPIPELINE_DEFAULT_PIPELINE_TYPE_TO_V2 = "@aws-cdk/aws-codepipeline:defaultPipelineTypeToV2";
    exports2.KMS_REDUCE_CROSS_ACCOUNT_REGION_POLICY_SCOPE = "@aws-cdk/aws-kms:reduceCrossAccountRegionPolicyScope";
    exports2.PIPELINE_REDUCE_ASSET_ROLE_TRUST_SCOPE = "@aws-cdk/pipelines:reduceAssetRoleTrustScope";
    exports2.EKS_NODEGROUP_NAME = "@aws-cdk/aws-eks:nodegroupNameAttribute";
    exports2.EKS_USE_NATIVE_OIDC_PROVIDER = "@aws-cdk/aws-eks:useNativeOidcProvider";
    exports2.ECS_PATTERNS_UNIQUE_TARGET_GROUP_ID = "@aws-cdk/aws-ecs-patterns:uniqueTargetGroupId";
    exports2.EBS_DEFAULT_GP3 = "@aws-cdk/aws-ec2:ebsDefaultGp3Volume";
    exports2.ECS_REMOVE_DEFAULT_DEPLOYMENT_ALARM = "@aws-cdk/aws-ecs:removeDefaultDeploymentAlarm";
    exports2.LOG_API_RESPONSE_DATA_PROPERTY_TRUE_DEFAULT = "@aws-cdk/custom-resources:logApiResponseDataPropertyTrueDefault";
    exports2.S3_KEEP_NOTIFICATION_IN_IMPORTED_BUCKET = "@aws-cdk/aws-s3:keepNotificationInImportedBucket";
    exports2.USE_NEW_S3URI_PARAMETERS_FOR_BEDROCK_INVOKE_MODEL_TASK = "@aws-cdk/aws-stepfunctions-tasks:useNewS3UriParametersForBedrockInvokeModelTask";
    exports2.EXPLICIT_STACK_TAGS = "@aws-cdk/core:explicitStackTags";
    exports2.REDUCE_EC2_FARGATE_CLOUDWATCH_PERMISSIONS = "@aws-cdk/aws-ecs:reduceEc2FargateCloudWatchPermissions";
    exports2.DYNAMODB_TABLEV2_RESOURCE_POLICY_PER_REPLICA = "@aws-cdk/aws-dynamodb:resourcePolicyPerReplica";
    exports2.EC2_SUM_TIMEOUT_ENABLED = "@aws-cdk/aws-ec2:ec2SumTImeoutEnabled";
    exports2.APPSYNC_GRAPHQLAPI_SCOPE_LAMBDA_FUNCTION_PERMISSION = "@aws-cdk/aws-appsync:appSyncGraphQLAPIScopeLambdaPermission";
    exports2.USE_CORRECT_VALUE_FOR_INSTANCE_RESOURCE_ID_PROPERTY = "@aws-cdk/aws-rds:setCorrectValueForDatabaseInstanceReadReplicaInstanceResourceId";
    exports2.CFN_INCLUDE_REJECT_COMPLEX_RESOURCE_UPDATE_CREATE_POLICY_INTRINSICS = "@aws-cdk/core:cfnIncludeRejectComplexResourceUpdateCreatePolicyIntrinsics";
    exports2.LAMBDA_NODEJS_SDK_V3_EXCLUDE_SMITHY_PACKAGES = "@aws-cdk/aws-lambda-nodejs:sdkV3ExcludeSmithyPackages";
    exports2.STEPFUNCTIONS_TASKS_FIX_RUN_ECS_TASK_POLICY = "@aws-cdk/aws-stepfunctions-tasks:fixRunEcsTaskPolicy";
    exports2.STEPFUNCTIONS_USE_DISTRIBUTED_MAP_RESULT_WRITER_V2 = "@aws-cdk/aws-stepfunctions:useDistributedMapResultWriterV2";
    exports2.BASTION_HOST_USE_AMAZON_LINUX_2023_BY_DEFAULT = "@aws-cdk/aws-ec2:bastionHostUseAmazonLinux2023ByDefault";
    exports2.ASPECT_STABILIZATION = "@aws-cdk/core:aspectStabilization";
    exports2.SIGNER_PROFILE_NAME_PASSED_TO_CFN = "@aws-cdk/aws-signer:signingProfileNamePassedToCfn";
    exports2.USER_POOL_DOMAIN_NAME_METHOD_WITHOUT_CUSTOM_RESOURCE = "@aws-cdk/aws-route53-targets:userPoolDomainNameMethodWithoutCustomResource";
    exports2.ALB_DUALSTACK_WITHOUT_PUBLIC_IPV4_SECURITY_GROUP_RULES_DEFAULT = "@aws-cdk/aws-elasticloadbalancingV2:albDualstackWithoutPublicIpv4SecurityGroupRulesDefault";
    exports2.IAM_OIDC_REJECT_UNAUTHORIZED_CONNECTIONS = "@aws-cdk/aws-iam:oidcRejectUnauthorizedConnections";
    exports2.ENABLE_ADDITIONAL_METADATA_COLLECTION = "@aws-cdk/core:enableAdditionalMetadataCollection";
    exports2.LAMBDA_CREATE_NEW_POLICIES_WITH_ADDTOROLEPOLICY = "@aws-cdk/aws-lambda:createNewPoliciesWithAddToRolePolicy";
    exports2.SET_UNIQUE_REPLICATION_ROLE_NAME = "@aws-cdk/aws-s3:setUniqueReplicationRoleName";
    exports2.PIPELINE_REDUCE_STAGE_ROLE_TRUST_SCOPE = "@aws-cdk/pipelines:reduceStageRoleTrustScope";
    exports2.EVENTBUS_POLICY_SID_REQUIRED = "@aws-cdk/aws-events:requireEventBusPolicySid";
    exports2.ASPECT_PRIORITIES_MUTATING = "@aws-cdk/core:aspectPrioritiesMutating";
    exports2.DYNAMODB_TABLE_RETAIN_TABLE_REPLICA = "@aws-cdk/aws-dynamodb:retainTableReplica";
    exports2.LOG_USER_POOL_CLIENT_SECRET_VALUE = "@aws-cdk/cognito:logUserPoolClientSecretValue";
    exports2.PIPELINE_REDUCE_CROSS_ACCOUNT_ACTION_ROLE_TRUST_SCOPE = "@aws-cdk/pipelines:reduceCrossAccountActionRoleTrustScope";
    exports2.S3_TRUST_KEY_POLICY_FOR_SNS_SUBSCRIPTIONS = "@aws-cdk/s3-notifications:addS3TrustKeyPolicyForSnsSubscriptions";
    exports2.EC2_REQUIRE_PRIVATE_SUBNETS_FOR_EGRESSONLYINTERNETGATEWAY = "@aws-cdk/aws-ec2:requirePrivateSubnetsForEgressOnlyInternetGateway";
    exports2.USE_RESOURCEID_FOR_VPCV2_MIGRATION = "@aws-cdk/aws-ec2-alpha:useResourceIdForVpcV2Migration";
    exports2.S3_PUBLIC_ACCESS_BLOCKED_BY_DEFAULT = "@aws-cdk/aws-s3:publicAccessBlockedByDefault";
    exports2.USE_CDK_MANAGED_LAMBDA_LOGGROUP = "@aws-cdk/aws-lambda:useCdkManagedLogGroup";
    exports2.NETWORK_LOAD_BALANCER_WITH_SECURITY_GROUP_BY_DEFAULT = "@aws-cdk/aws-elasticloadbalancingv2:networkLoadBalancerWithSecurityGroupByDefault";
    exports2.STEPFUNCTIONS_TASKS_HTTPINVOKE_DYNAMIC_JSONPATH_ENDPOINT = "@aws-cdk/aws-stepfunctions-tasks:httpInvokeDynamicJsonPathEndpoint";
    exports2.CLOUDFRONT_FUNCTION_DEFAULT_RUNTIME_V2_0 = "@aws-cdk/aws-cloudfront:defaultFunctionRuntimeV2_0";
    exports2.ELB_USE_POST_QUANTUM_TLS_POLICY = "@aws-cdk/aws-elasticloadbalancingv2:usePostQuantumTlsPolicy";
    exports2.AUTOMATIC_L1_TRAITS = "@aws-cdk/core:automaticL1Traits";
    exports2.BATCH_DEFAULT_AL2023 = "@aws-cdk/aws-batch:defaultToAL2023";
    exports2.EKS_DEFAULT_AL2023 = "@aws-cdk/aws-eks:defaultToAL2023";
    exports2.ANNOTATIONS_IN_VALIDATION_REPORT = "@aws-cdk/core:annotationsInValidationReport";
    exports2.DEFAULT_CROSS_STACK_REFERENCES = "@aws-cdk/core:defaultCrossStackReferences";
    exports2.FLAGS = {
      //////////////////////////////////////////////////////////////////////
      [exports2.SIGNER_PROFILE_NAME_PASSED_TO_CFN]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "Pass signingProfileName to CfnSigningProfile",
        detailsMd: `
      When enabled, the \`signingProfileName\` property is passed to the L1 \`CfnSigningProfile\` construct,
      which ensures that the AWS Signer profile is created with the specified name.

      When disabled, the \`signingProfileName\` is not passed to CloudFormation, maintaining backward
      compatibility with existing deployments where CloudFormation auto-generated profile names.

      This feature flag is needed because enabling it can cause existing signing profiles to be
      replaced during deployment if a \`signingProfileName\` was specified but not previously used
      in the CloudFormation template.`,
        introducedIn: { v2: "2.212.0" },
        recommendedValue: true,
        unconfiguredBehavesLike: { v2: false }
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.ENABLE_STACK_NAME_DUPLICATES_CONTEXT]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "Allow multiple stacks with the same name",
        detailsMd: `
      If this is set, multiple stacks can use the same stack name (e.g. deployed to
      different environments). This means that the name of the synthesized template
      file will be based on the construct path and not on the defined \`stackName\`
      of the stack.`,
        recommendedValue: true,
        introducedIn: { v1: "1.16.0" },
        unconfiguredBehavesLike: { v2: true },
        compatibilityWithOldBehaviorMd: "Pass stack identifiers to the CLI instead of stack names."
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.ENABLE_DIFF_NO_FAIL_CONTEXT]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "Make `cdk diff` not fail when there are differences",
        detailsMd: `
      Determines what status code \`cdk diff\` should return when the specified stack
      differs from the deployed stack or the local CloudFormation template:

      * \`aws-cdk:enableDiffNoFail=true\` => status code == 0
      * \`aws-cdk:enableDiffNoFail=false\` => status code == 1

      You can override this behavior with the --fail flag:

      * \`--fail\` => status code == 1
      * \`--no-fail\` => status code == 0`,
        introducedIn: { v1: "1.19.0" },
        unconfiguredBehavesLike: { v2: true },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Specify `--fail` to the CLI."
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.NEW_STYLE_STACK_SYNTHESIS_CONTEXT]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "Switch to new stack synthesis method which enables CI/CD",
        detailsMd: `
      If this flag is specified, all \`Stack\`s will use the \`DefaultStackSynthesizer\` by
      default. If it is not set, they will use the \`LegacyStackSynthesizer\`.`,
        introducedIn: { v1: "1.39.0", v2: "2.0.0" },
        unconfiguredBehavesLike: { v2: true },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.STACK_RELATIVE_EXPORTS_CONTEXT]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "Name exports based on the construct paths relative to the stack, rather than the global construct path",
        detailsMd: `
      Combined with the stack name this relative construct path is good enough to
      ensure uniqueness, and makes the export names robust against refactoring
      the location of the stack in the construct tree (specifically, moving the Stack
      into a Stage).`,
        introducedIn: { v1: "1.58.0", v2: "2.0.0" },
        unconfiguredBehavesLike: { v2: true },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.DOCKER_IGNORE_SUPPORT]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "DockerImageAsset properly supports `.dockerignore` files by default",
        detailsMd: `
      If this flag is not set, the default behavior for \`DockerImageAsset\` is to use
      glob semantics for \`.dockerignore\` files. If this flag is set, the default behavior
      is standard Docker ignore semantics.

      This is a feature flag as the old behavior was technically incorrect but
      users may have come to depend on it.`,
        introducedIn: { v1: "1.73.0" },
        unconfiguredBehavesLike: { v2: true },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Update your `.dockerignore` file to match standard Docker ignore rules, if necessary."
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.SECRETS_MANAGER_PARSE_OWNED_SECRET_NAME]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "Fix the referencing of SecretsManager names from ARNs",
        detailsMd: `
      Secret.secretName for an "owned" secret will attempt to parse the secretName from the ARN,
      rather than the default full resource name, which includes the SecretsManager suffix.

      If this flag is not set, Secret.secretName will include the SecretsManager suffix, which cannot be directly
      used by SecretsManager.DescribeSecret, and must be parsed by the user first (e.g., Fn:Join, Fn:Select, Fn:Split).`,
        introducedIn: { v1: "1.77.0" },
        unconfiguredBehavesLike: { v2: true },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Use `parseArn(secret.secretName).resourceName` to emulate the incorrect old parsing."
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.KMS_DEFAULT_KEY_POLICIES]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "Tighten default KMS key policies",
        detailsMd: `
      KMS Keys start with a default key policy that grants the account access to administer the key,
      mirroring the behavior of the KMS SDK/CLI/Console experience. Users may override the default key
      policy by specifying their own.

      If this flag is not set, the default key policy depends on the setting of the \`trustAccountIdentities\`
      flag. If false (the default, for backwards-compatibility reasons), the default key policy somewhat
      resembles the default admin key policy, but with the addition of 'GenerateDataKey' permissions. If
      true, the policy matches what happens when this feature flag is set.

      Additionally, if this flag is not set and the user supplies a custom key policy, this will be appended
      to the key's default policy (rather than replacing it).`,
        introducedIn: { v1: "1.78.0" },
        unconfiguredBehavesLike: { v2: true },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Pass `trustAccountIdentities: false` to `Key` construct to restore the old behavior."
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.S3_GRANT_WRITE_WITHOUT_ACL]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "Remove `PutObjectAcl` from Bucket.grantWrite",
        detailsMd: `
      Change the old 's3:PutObject*' permission to 's3:PutObject' on Bucket,
      as the former includes 's3:PutObjectAcl',
      which could be used to grant read/write object access to IAM principals in other accounts.
      Use a feature flag to make sure existing customers who might be relying
      on the overly-broad permissions are not broken.`,
        introducedIn: { v1: "1.85.0" },
        unconfiguredBehavesLike: { v2: true },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Call `bucket.grantPutAcl()` in addition to `bucket.grantWrite()` to grant ACL permissions."
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.ECS_REMOVE_DEFAULT_DESIRED_COUNT]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "Do not specify a default DesiredCount for ECS services",
        detailsMd: `
      ApplicationLoadBalancedServiceBase, ApplicationMultipleTargetGroupServiceBase,
      NetworkLoadBalancedServiceBase, NetworkMultipleTargetGroupServiceBase, and
      QueueProcessingServiceBase currently determine a default value for the desired count of
      a CfnService if a desiredCount is not provided. The result of this is that on every
      deployment, the service count is reset to the fixed value, even if it was autoscaled.

      If this flag is not set, the default behaviour for CfnService.desiredCount is to set a
      desiredCount of 1, if one is not provided. If true, a default will not be defined for
      CfnService.desiredCount and as such desiredCount will be undefined, if one is not provided.`,
        introducedIn: { v1: "1.92.0" },
        unconfiguredBehavesLike: { v2: true },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "You can pass `desiredCount: 1` explicitly, but you should never need this."
      },
      [exports2.ECS_PATTERNS_SEC_GROUPS_DISABLES_IMPLICIT_OPEN_LISTENER]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "Disable implicit openListener when custom security groups are provided",
        detailsMd: `
      ApplicationLoadBalancedServiceBase currently defaults openListener to true, which creates
      security group rules allowing ingress from 0.0.0.0/0. This can be a security risk when
      users provide custom security groups on their load balancer, expecting those to be the
      only ingress rules.

      If this flag is not set, openListener will always default to true for backward compatibility.
      If true, openListener will default to false when custom security groups are detected on the
      load balancer, and true otherwise. Users can still explicitly set openListener: true to
      override this behavior.`,
        introducedIn: { v2: "2.214.0" },
        unconfiguredBehavesLike: { v2: false },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "You can pass `openListener: true` explicitly to maintain the old behavior."
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.RDS_LOWERCASE_DB_IDENTIFIER]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "Force lowercasing of RDS Cluster names in CDK",
        detailsMd: `
      Cluster names must be lowercase, and the service will lowercase the name when the cluster
      is created. However, CDK did not use to know about this, and would use the user-provided name
      referencing the cluster, which would fail if it happened to be mixed-case.

      With this flag, lowercase the name in CDK so we can reference it properly.

      Must be behind a permanent flag because changing a name from mixed case to lowercase between deployments
      would lead CloudFormation to think the name was changed and would trigger a cluster replacement
      (losing data!).`,
        introducedIn: { v1: "1.97.0", v2: "2.0.0" },
        unconfiguredBehavesLike: { v2: true },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.APIGATEWAY_USAGEPLANKEY_ORDERINSENSITIVE_ID]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "Allow adding/removing multiple UsagePlanKeys independently",
        detailsMd: `
      The UsagePlanKey resource connects an ApiKey with a UsagePlan. API Gateway does not allow more than one UsagePlanKey
      for any given UsagePlan and ApiKey combination. For this reason, CloudFormation cannot replace this resource without
      either the UsagePlan or ApiKey changing.

      The feature addition to support multiple UsagePlanKey resources - 142bd0e2 - recognized this and attempted to keep
      existing UsagePlanKey logical ids unchanged.
      However, this intentionally caused the logical id of the UsagePlanKey to be sensitive to order. That is, when
      the 'first' UsagePlanKey resource is removed, the logical id of the 'second' assumes what was originally the 'first',
      which again is disallowed.

      In effect, there is no way to get out of this mess in a backwards compatible way, while supporting existing stacks.
      This flag changes the logical id layout of UsagePlanKey to not be sensitive to order.`,
        introducedIn: { v1: "1.98.0", v2: "2.0.0" },
        unconfiguredBehavesLike: { v2: true },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.EFS_DEFAULT_ENCRYPTION_AT_REST]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "Enable this feature flag to have elastic file systems encrypted at rest by default.",
        detailsMd: `
      Encryption can also be configured explicitly using the \`encrypted\` property.
      `,
        introducedIn: { v1: "1.98.0" },
        unconfiguredBehavesLike: { v2: true },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Pass the `encrypted: false` property to the `FileSystem` construct to disable encryption."
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.LAMBDA_RECOGNIZE_VERSION_PROPS]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "Enable this feature flag to opt in to the updated logical id calculation for Lambda Version created using the  `fn.currentVersion`.",
        detailsMd: `
      The previous calculation incorrectly considered properties of the \`AWS::Lambda::Function\` resource that did
      not constitute creating a new Version.

      See 'currentVersion' section in the aws-lambda module's README for more details.`,
        introducedIn: { v1: "1.106.0", v2: "2.0.0" },
        unconfiguredBehavesLike: { v2: true },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.LAMBDA_RECOGNIZE_LAYER_VERSION]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "Enable this feature flag to opt in to the updated logical id calculation for Lambda Version created using the `fn.currentVersion`.",
        detailsMd: `
      This flag correct incorporates Lambda Layer properties into the Lambda Function Version.

      See 'currentVersion' section in the aws-lambda module's README for more details.`,
        introducedIn: { v1: "1.159.0", v2: "2.27.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.CLOUDFRONT_DEFAULT_SECURITY_POLICY_TLS_V1_2_2021]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "Enable this feature flag to have cloudfront distributions use the security policy TLSv1.2_2021 by default.",
        detailsMd: `
      The security policy can also be configured explicitly using the \`minimumProtocolVersion\` property.`,
        introducedIn: { v1: "1.117.0", v2: "2.0.0" },
        unconfiguredBehavesLike: { v2: true },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.CHECK_SECRET_USAGE]: {
        type: flag_modeling_1.FlagType.VisibleContext,
        summary: "Enable this flag to make it impossible to accidentally use SecretValues in unsafe locations",
        detailsMd: `
      With this flag enabled, \`SecretValue\` instances can only be passed to
      constructs that accept \`SecretValue\`s; otherwise, \`unsafeUnwrap()\` must be
      called to use it as a regular string.`,
        introducedIn: { v1: "1.153.0", v2: "2.21.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.TARGET_PARTITIONS]: {
        type: flag_modeling_1.FlagType.VisibleContext,
        summary: "What regions to include in lookup tables of environment agnostic stacks",
        detailsMd: `
      Has no effect on stacks that have a defined region, but will limit the amount
      of unnecessary regions included in stacks without a known region.

      The type of this value should be a list of strings.`,
        introducedIn: { v1: "1.137.0", v2: "2.4.0" },
        recommendedValue: ["aws", "aws-cn"]
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.ECS_SERVICE_EXTENSIONS_ENABLE_DEFAULT_LOG_DRIVER]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "ECS extensions will automatically add an `awslogs` driver if no logging is specified",
        detailsMd: `
      Enable this feature flag to configure default logging behavior for the ECS Service Extensions. This will enable the
      \`awslogs\` log driver for the application container of the service to send the container logs to CloudWatch Logs.

      This is a feature flag as the new behavior provides a better default experience for the users.`,
        introducedIn: { v1: "1.140.0", v2: "2.8.0" },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Specify a log driver explicitly."
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.EC2_UNIQUE_IMDSV2_LAUNCH_TEMPLATE_NAME]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "Enable this feature flag to have Launch Templates generated by the `InstanceRequireImdsv2Aspect` use unique names.",
        detailsMd: `
      Previously, the generated Launch Template names were only unique within a stack because they were based only on the
      \`Instance\` construct ID. If another stack that has an \`Instance\` with the same construct ID is deployed in the same
      account and region, the deployments would always fail as the generated Launch Template names were the same.

      The new implementation addresses this issue by generating the Launch Template name with the \`Names.uniqueId\` method.`,
        introducedIn: { v1: "1.140.0", v2: "2.8.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.ECS_ARN_FORMAT_INCLUDES_CLUSTER_NAME]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "ARN format used by ECS. In the new ARN format, the cluster name is part of the resource ID.",
        detailsMd: `
      If this flag is not set, the old ARN format (without cluster name) for ECS is used.
      If this flag is set, the new ARN format (with cluster name) for ECS is used.

      This is a feature flag as the old format is still valid for existing ECS clusters.

      See https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-account-settings.html#ecs-resource-ids
      `,
        introducedIn: { v2: "2.35.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.IAM_MINIMIZE_POLICIES]: {
        type: flag_modeling_1.FlagType.VisibleContext,
        summary: "Minimize IAM policies by combining Statements",
        detailsMd: `
      Minimize IAM policies by combining Principals, Actions and Resources of two
      Statements in the policies, as long as it doesn't change the meaning of the
      policy.`,
        introducedIn: { v1: "1.150.0", v2: "2.18.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.VALIDATE_SNAPSHOT_REMOVAL_POLICY]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "Error on snapshot removal policies on resources that do not support it.",
        detailsMd: `
      Makes sure we do not allow snapshot removal policy on resources that do not support it.
      If supplied on an unsupported resource, CloudFormation ignores the policy altogether.
      This flag will reduce confusion and unexpected loss of data when erroneously supplying
      the snapshot removal policy.`,
        introducedIn: { v2: "2.28.0" },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "The old behavior was incorrect. Update your source to not specify SNAPSHOT policies on resources that do not support it."
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.CODEPIPELINE_CROSS_ACCOUNT_KEY_ALIAS_STACK_SAFE_RESOURCE_NAME]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "Generate key aliases that include the stack name",
        detailsMd: `
      Enable this feature flag to have CodePipeline generate a unique cross account key alias name using the stack name.

      Previously, when creating multiple pipelines with similar naming conventions and when crossAccountKeys is true,
      the KMS key alias name created for these pipelines may be the same due to how the uniqueId is generated.

      This new implementation creates a stack safe resource name for the alias using the stack name instead of the stack ID.
      `,
        introducedIn: { v2: "2.29.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.S3_CREATE_DEFAULT_LOGGING_POLICY]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "Enable this feature flag to create an S3 bucket policy by default in cases where an AWS service would automatically create the Policy if one does not exist.",
        detailsMd: `
      For example, in order to send VPC flow logs to an S3 bucket, there is a specific Bucket Policy
      that needs to be attached to the bucket. If you create the bucket without a policy and then add the
      bucket as the flow log destination, the service will automatically create the bucket policy with the
      necessary permissions. If you were to then try and add your own bucket policy CloudFormation will throw
      and error indicating that a bucket policy already exists.

      In cases where we know what the required policy is we can go ahead and create the policy so we can
      remain in control of it.

      @see https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/AWS-logs-and-resource-policy.html#AWS-logs-infrastructure-S3
      `,
        introducedIn: { v2: "2.31.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.SNS_SUBSCRIPTIONS_SQS_DECRYPTION_POLICY]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "Restrict KMS key policy for encrypted Queues a bit more",
        detailsMd: `
      Enable this feature flag to restrict the decryption of a SQS queue, which is subscribed to a SNS topic, to
      only the topic which it is subscribed to and not the whole SNS service of an account.

      Previously the decryption was only restricted to the SNS service principal. To make the SQS subscription more
      secure, it is a good practice to restrict the decryption further and only allow the connected SNS topic to decryption
      the subscribed queue.`,
        introducedIn: { v2: "2.32.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.APIGATEWAY_DISABLE_CLOUDWATCH_ROLE]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "Make default CloudWatch Role behavior safe for multiple API Gateways in one environment",
        detailsMd: `
      Enable this feature flag to change the default behavior for aws-apigateway.RestApi and aws-apigateway.SpecRestApi
      to _not_ create a CloudWatch role and Account. There is only a single ApiGateway account per AWS
      environment which means that each time you create a RestApi in your account the ApiGateway account
      is overwritten. If at some point the newest RestApi is deleted, the ApiGateway Account and CloudWatch
      role will also be deleted, breaking any existing ApiGateways that were depending on them.

      When this flag is enabled you should either create the ApiGateway account and CloudWatch role
      separately _or_ only enable the cloudWatchRole on a single RestApi.
      `,
        introducedIn: { v2: "2.38.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.ENABLE_PARTITION_LITERALS]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "Make ARNs concrete if AWS partition is known",
        // eslint-disable-next-line @cdklabs/no-literal-partition
        detailsMd: `
      Enable this feature flag to get partition names as string literals in Stacks with known regions defined in
      their environment, such as "aws" or "aws-cn".  Previously the CloudFormation intrinsic function
      "Ref: AWS::Partition" was used.  For example:

      \`\`\`yaml
      Principal:
        AWS:
          Fn::Join:
            - ""
            - - "arn:"
              - Ref: AWS::Partition
              - :iam::123456789876:root
      \`\`\`

      becomes:

      \`\`\`yaml
      Principal:
        AWS: "arn:aws:iam::123456789876:root"
      \`\`\`

      The intrinsic function will still be used in Stacks where no region is defined or the region's partition
      is unknown.
      `,
        introducedIn: { v2: "2.38.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.EVENTS_TARGET_QUEUE_SAME_ACCOUNT]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "Event Rules may only push to encrypted SQS queues in the same account",
        detailsMd: `
      This flag applies to SQS Queues that are used as the target of event Rules. When enabled, only principals
      from the same account as the Rule can send messages. If a queue is unencrypted, this restriction will
      always apply, regardless of the value of this flag.
      `,
        introducedIn: { v2: "2.51.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.ECS_DISABLE_EXPLICIT_DEPLOYMENT_CONTROLLER_FOR_CIRCUIT_BREAKER]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: 'Avoid setting the "ECS" deployment controller when adding a circuit breaker',
        detailsMd: `
      Enable this feature flag to avoid setting the "ECS" deployment controller when adding a circuit breaker to an
      ECS Service, as this will trigger a full replacement which fails to deploy when using set service names.
      This does not change any behaviour as the default deployment controller when it is not defined is ECS.

      This is a feature flag as the new behavior provides a better default experience for the users.
      `,
        introducedIn: { v2: "2.51.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.IAM_IMPORTED_ROLE_STACK_SAFE_DEFAULT_POLICY_NAME]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "Enable this feature to create default policy names for imported roles that depend on the stack the role is in.",
        detailsMd: `
      Without this, importing the same role in multiple places could lead to the permissions given for one version of the imported role
      to overwrite permissions given to the role at a different place where it was imported. This was due to all imported instances
      of a role using the same default policy name.

      This new implementation creates default policy names based on the constructs node path in their stack.
      `,
        introducedIn: { v2: "2.60.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.S3_SERVER_ACCESS_LOGS_USE_BUCKET_POLICY]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "Use S3 Bucket Policy instead of ACLs for Server Access Logging",
        detailsMd: `
      Enable this feature flag to use S3 Bucket Policy for granting permission for Server Access Logging
      rather than using the canned \`LogDeliveryWrite\` ACL. ACLs do not work when Object Ownership is
      enabled on the bucket.

      This flag uses a Bucket Policy statement to allow Server Access Log delivery, following best
      practices for S3.

      @see https://docs.aws.amazon.com/AmazonS3/latest/userguide/enable-server-access-logging.html
    `,
        introducedIn: { v2: "2.60.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.ROUTE53_PATTERNS_USE_CERTIFICATE]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "Use the official `Certificate` resource instead of `DnsValidatedCertificate`",
        detailsMd: `
      Enable this feature flag to use the official CloudFormation supported \`Certificate\` resource instead
      of the deprecated \`DnsValidatedCertificate\` construct. If this flag is enabled and you are creating
      the stack in a region other than us-east-1 then you must also set \`crossRegionReferences=true\` on the
      stack.
      `,
        introducedIn: { v2: "2.61.0" },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Define a `DnsValidatedCertificate` explicitly and pass in the `certificate` property"
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.AWS_CUSTOM_RESOURCE_LATEST_SDK_DEFAULT]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "Whether to install the latest SDK by default in AwsCustomResource",
        detailsMd: `
      This was originally introduced and enabled by default to not be limited by the SDK version
      that's installed on AWS Lambda. However, it creates issues for Lambdas bound to VPCs that
      do not have internet access, or in environments where 'npmjs.com' is not available.

      The recommended setting is to disable the default installation behavior, and pass the
      flag on a resource-by-resource basis to enable it if necessary.
    `,
        compatibilityWithOldBehaviorMd: "Set installLatestAwsSdk: true on all resources that need it.",
        introducedIn: { v2: "2.60.0" },
        recommendedValue: false
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.DATABASE_PROXY_UNIQUE_RESOURCE_NAME]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "Use unique resource name for Database Proxy",
        detailsMd: `
      If this flag is not set, the default behavior for \`DatabaseProxy\` is
      to use \`id\` of the constructor for \`dbProxyName\` when it's not specified in the argument.
      In this case, users can't deploy \`DatabaseProxy\`s that have the same \`id\` in the same region.

      If this flag is set, the default behavior is to use unique resource names for each \`DatabaseProxy\`.

      This is a feature flag as the old behavior was technically incorrect, but users may have come to depend on it.
    `,
        introducedIn: { v2: "2.65.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.CODEDEPLOY_REMOVE_ALARMS_FROM_DEPLOYMENT_GROUP]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "Remove CloudWatch alarms from deployment group",
        detailsMd: `
      Enable this flag to be able to remove all CloudWatch alarms from a deployment group by removing
      the alarms from the construct. If this flag is not set, removing all alarms from the construct
      will still leave the alarms configured for the deployment group.
    `,
        introducedIn: { v2: "2.65.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.APIGATEWAY_AUTHORIZER_CHANGE_DEPLOYMENT_LOGICAL_ID]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "Include authorizer configuration in the calculation of the API deployment logical ID.",
        detailsMd: `
      The logical ID of the AWS::ApiGateway::Deployment resource is calculated by hashing
      the API configuration, including methods, and resources, etc. Enable this feature flag
      to also include the configuration of any authorizer attached to the API in the
      calculation, so any changes made to an authorizer will create a new deployment.
      `,
        introducedIn: { v2: "2.66.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.EC2_LAUNCH_TEMPLATE_DEFAULT_USER_DATA]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "Define user data for a launch template by default when a machine image is provided.",
        detailsMd: `
      The ec2.LaunchTemplate construct did not define user data when a machine image is
      provided despite the document. If this is set, a user data is automatically defined
      according to the OS of the machine image.
      `,
        recommendedValue: true,
        introducedIn: { v2: "2.67.0" }
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.SECRETS_MANAGER_TARGET_ATTACHMENT_RESOURCE_POLICY]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "SecretTargetAttachments uses the ResourcePolicy of the attached Secret.",
        detailsMd: `
      Enable this feature flag to make SecretTargetAttachments use the ResourcePolicy of the attached Secret.
      SecretTargetAttachments are created to connect a Secret to a target resource.
      In CDK code, they behave like regular Secret and can be used as a stand-in in most situations.
      Previously, adding to the ResourcePolicy of a SecretTargetAttachment did attempt to create a separate ResourcePolicy for the same Secret.
      However Secrets can only have a single ResourcePolicy, causing the CloudFormation deployment to fail.

      When enabling this feature flag for an existing Stack, ResourcePolicies created via a SecretTargetAttachment will need replacement.
      This won't be possible without intervention due to limitation outlined above.
      First remove all permissions granted to the Secret and deploy without the ResourcePolicies.
      Then you can re-add the permissions and deploy again.
      `,
        recommendedValue: true,
        introducedIn: { v2: "2.67.0" }
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.REDSHIFT_COLUMN_ID]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "Whether to use an ID to track Redshift column changes",
        detailsMd: `
      Redshift columns are identified by their \`name\`. If a column is renamed, the old column
      will be dropped and a new column will be created. This can cause data loss.

      This flag enables the use of an \`id\` attribute for Redshift columns. If this flag is enabled, the
      internal CDK architecture will track changes of Redshift columns through their \`id\`, rather
      than their \`name\`. This will prevent data loss when columns are renamed.

      **NOTE** - Enabling this flag comes at a **risk**. When enabled, update the \`id\`s of all columns,
      **however** do not change the \`names\`s of the columns. If the \`name\`s of the columns are changed during
      initial deployment, the columns will be dropped and recreated, causing data loss. After the initial deployment
      of the \`id\`s, the \`name\`s of the columns can be changed without data loss.
      `,
        introducedIn: { v2: "2.68.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.ENABLE_EMR_SERVICE_POLICY_V2]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "Enable AmazonEMRServicePolicy_v2 managed policies",
        detailsMd: `
      If this flag is not set, the default behavior for \`EmrCreateCluster\` is
      to use \`AmazonElasticMapReduceRole\` managed policies.

      If this flag is set, the default behavior is to use the new \`AmazonEMRServicePolicy_v2\`
      managed policies.

      This is a feature flag as the old behavior will be deprecated, but some resources may require manual
      intervention since they might not have the appropriate tags propagated automatically.
      `,
        introducedIn: { v2: "2.72.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.EC2_RESTRICT_DEFAULT_SECURITY_GROUP]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "Restrict access to the VPC default security group",
        detailsMd: `
      Enable this feature flag to remove the default ingress/egress rules from the
      VPC default security group.

      When a VPC is created, a default security group is created as well and this cannot
      be deleted. The default security group is created with ingress/egress rules that allow
      _all_ traffic. [AWS Security best practices recommend](https://docs.aws.amazon.com/securityhub/latest/userguide/ec2-controls.html#ec2-2)
      removing these ingress/egress rules in order to restrict access to the default security group.
    `,
        introducedIn: { v2: "2.78.0" },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: `
      To allow all ingress/egress traffic to the VPC default security group you
      can set the \`restrictDefaultSecurityGroup: false\`.
    `
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.APIGATEWAY_REQUEST_VALIDATOR_UNIQUE_ID]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "Generate a unique id for each RequestValidator added to a method",
        detailsMd: `
      This flag allows multiple RequestValidators to be added to a RestApi when
      providing the \`RequestValidatorOptions\` in the \`addMethod()\` method.

      If the flag is not set then only a single RequestValidator can be added in this way.
      Any additional RequestValidators have to be created directly with \`new RequestValidator\`.
    `,
        introducedIn: { v2: "2.78.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.KMS_ALIAS_NAME_REF]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "KMS Alias name and keyArn will have implicit reference to KMS Key",
        detailsMd: `
      This flag allows an implicit dependency to be created between KMS Alias and KMS Key
      when referencing key.aliasName or key.keyArn.

      If the flag is not set then a raw string is passed as the Alias name and no
      implicit dependencies will be set.
    `,
        introducedIn: { v2: "2.83.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.KMS_APPLY_IMPORTED_ALIAS_PERMISSIONS_TO_PRINCIPAL]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "Enable grant methods on Aliases imported by name to use kms:ResourceAliases condition",
        detailsMd: `
      This flag enables the grant methods (grant, grantDecrypt, grantEncrypt, etc.) on Aliases imported
      by name to grant permissions based on the 'kms:ResourceAliases' condition rather than no-op grants.
      When disabled, grant calls on imported aliases will be dropped (no-op) to maintain compatibility.
    `,
        introducedIn: { v2: "2.202.0" },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Remove calls to the grant* methods on the aliases referenced by name"
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.AUTOSCALING_GENERATE_LAUNCH_TEMPLATE]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "Generate a launch template when creating an AutoScalingGroup",
        detailsMd: `
      Enable this flag to allow AutoScalingGroups to generate a launch template when being created.
      Launch configurations have been deprecated and cannot be created in AWS Accounts created after
      December 31, 2023. Existing 'AutoScalingGroup' properties used for creating a launch configuration
      will now create an equivalent 'launchTemplate'. Alternatively, users can provide an explicit
      'launchTemplate' or 'mixedInstancesPolicy'. When this flag is enabled a 'launchTemplate' will
      attempt to set user data according to the OS of the machine image if explicit user data is not
      provided.
    `,
        introducedIn: { v2: "2.88.0" },
        compatibilityWithOldBehaviorMd: `
      If backwards compatibility needs to be maintained due to an existing autoscaling group
      using a launch config, set this flag to false.
    `,
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.INCLUDE_PREFIX_IN_UNIQUE_NAME_GENERATION]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "Include the stack prefix in the stack name generation process",
        detailsMd: `
      This flag prevents the prefix of a stack from making the stack's name longer than the 128 character limit.

      If the flag is set, the prefix is included in the stack name generation process.
      If the flag is not set, then the prefix of the stack is prepended to the generated stack name.

      **NOTE** - Enabling this flag comes at a **risk**. If you have already deployed stacks, changing the status of this
      feature flag can lead to a change in stacks' name. Changing a stack name mean recreating the whole stack, which
      is not viable in some productive setups.
    `,
        introducedIn: { v2: "2.84.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.EFS_DENY_ANONYMOUS_ACCESS]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "EFS denies anonymous clients accesses",
        detailsMd: `
      This flag adds the file system policy that denies anonymous clients
      access to \`efs.FileSystem\`.

      If this flag is not set, \`efs.FileSystem\` will allow all anonymous clients
      that can access over the network.`,
        introducedIn: { v2: "2.93.0" },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "You can pass `allowAnonymousAccess: true` so allow anonymous clients access."
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.ENABLE_OPENSEARCH_MULTIAZ_WITH_STANDBY]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "Enables support for Multi-AZ with Standby deployment for opensearch domains",
        detailsMd: `
      If this is set, an opensearch domain will automatically be created with
      multi-az with standby enabled.
    `,
        introducedIn: { v2: "2.88.0" },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Pass `capacity.multiAzWithStandbyEnabled: false` to `Domain` construct to restore the old behavior."
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.LAMBDA_NODEJS_USE_LATEST_RUNTIME]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "Enables aws-lambda-nodejs.Function to use the latest available NodeJs runtime as the default",
        detailsMd: `
      If this is set, and a \`runtime\` prop is not passed to, Lambda NodeJs
      functions will use the latest version of the runtime provided by the Lambda
      service. Do not use this if you your lambda function is reliant on dependencies
      shipped as part of the runtime environment.
    `,
        introducedIn: { v2: "2.93.0" },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Pass `runtime: lambda.Runtime.NODEJS_16_X` to `Function` construct to restore the previous behavior."
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.EFS_MOUNTTARGET_ORDERINSENSITIVE_LOGICAL_ID]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, mount targets will have a stable logicalId that is linked to the associated subnet.",
        detailsMd: `
      When this feature flag is enabled, each mount target will have a stable
      logicalId that is linked to the associated subnet. If the flag is set to
      false then the logicalIds of the mount targets can change if the number of
      subnets changes.

      Set this flag to false for existing mount targets.
    `,
        introducedIn: { v2: "2.93.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.AURORA_CLUSTER_CHANGE_SCOPE_OF_INSTANCE_PARAMETER_GROUP_WITH_EACH_PARAMETERS]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, a scope of InstanceParameterGroup for AuroraClusterInstance with each parameters will change.",
        detailsMd: `
      When this feature flag is enabled, a scope of \`InstanceParameterGroup\` for
      \`AuroraClusterInstance\` with each parameters will change to AuroraClusterInstance
      from AuroraCluster.

      If the flag is set to false then it can only make one \`AuroraClusterInstance\`
      with each \`InstanceParameterGroup\` in the AuroraCluster.
    `,
        introducedIn: { v2: "2.97.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.APPSYNC_ENABLE_USE_ARN_IDENTIFIER_SOURCE_API_ASSOCIATION]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, will always use the arn for identifiers for CfnSourceApiAssociation in the GraphqlApi construct rather than id.",
        detailsMd: `
      When this feature flag is enabled, we use the IGraphqlApi ARN rather than ID when creating or updating CfnSourceApiAssociation in
      the GraphqlApi construct. Using the ARN allows the association to support an association with a source api or merged api in another account.
      Note that for existing source api associations created with this flag disabled, enabling the flag will lead to a resource replacement.
    `,
        introducedIn: { v2: "2.97.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.RDS_PREVENT_RENDERING_DEPRECATED_CREDENTIALS]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, creating an RDS database cluster from a snapshot will only render credentials for snapshot credentials.",
        detailsMd: `
      The \`credentials\` property on the \`DatabaseClusterFromSnapshotProps\`
      interface was deprecated with the new \`snapshotCredentials\` property being
      recommended. Before deprecating \`credentials\`, a secret would be generated
      while rendering credentials if the \`credentials\` property was undefined or
      if a secret wasn't provided via the \`credentials\` property. This behavior
      is replicated with the new \`snapshotCredentials\` property, but the original
      \`credentials\` secret can still be created resulting in an extra database
      secret.

      Set this flag to prevent rendering deprecated \`credentials\` and creating an
      extra database secret when only using \`snapshotCredentials\` to create an RDS
      database cluster from a snapshot.
    `,
        introducedIn: { v2: "2.98.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.CODECOMMIT_SOURCE_ACTION_DEFAULT_BRANCH_NAME]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, the CodeCommit source action is using the default branch name 'main'.",
        detailsMd: `
      When setting up a CodeCommit source action for the source stage of a pipeline, please note that the
      default branch is 'master'.
      However, with the activation of this feature flag, the default branch is updated to 'main'.
    `,
        introducedIn: { v2: "2.103.1" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.LAMBDA_PERMISSION_LOGICAL_ID_FOR_LAMBDA_ACTION]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, the logical ID of a Lambda permission for a Lambda action includes an alarm ID.",
        detailsMd: `
      When this feature flag is enabled, a logical ID of \`LambdaPermission\` for a
      \`LambdaAction\` will include an alarm ID. Therefore multiple alarms for the same Lambda
      can be created with \`LambdaAction\`.

      If the flag is set to false then it can only make one alarm for the Lambda with
      \`LambdaAction\`.
    `,
        introducedIn: { v2: "2.124.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.CODEPIPELINE_CROSS_ACCOUNT_KEYS_DEFAULT_VALUE_TO_FALSE]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "Enables Pipeline to set the default value for crossAccountKeys to false.",
        detailsMd: `
      When this feature flag is enabled, and the \`crossAccountKeys\` property is not provided in a \`Pipeline\`
      construct, the construct automatically defaults the value of this property to false.
    `,
        introducedIn: { v2: "2.127.0" },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Pass `crossAccountKeys: true` to `Pipeline` construct to restore the previous behavior."
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.CODEPIPELINE_DEFAULT_PIPELINE_TYPE_TO_V2]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "Enables Pipeline to set the default pipeline type to V2.",
        detailsMd: `
      When this feature flag is enabled, and the \`pipelineType\` property is not provided in a \`Pipeline\`
      construct, the construct automatically defaults the value of this property to \`PipelineType.V2\`.
    `,
        introducedIn: { v2: "2.133.0" },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Pass `pipelineType: PipelineType.V1` to `Pipeline` construct to restore the previous behavior."
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.KMS_REDUCE_CROSS_ACCOUNT_REGION_POLICY_SCOPE]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, IAM Policy created from KMS key grant will reduce the resource scope to this key only.",
        detailsMd: `
      When this feature flag is enabled and calling KMS key grant method, the created IAM policy will reduce the resource scope from
      '*' to this specific granting KMS key.
    `,
        introducedIn: { v2: "2.134.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.PIPELINE_REDUCE_ASSET_ROLE_TRUST_SCOPE]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "Remove the root account principal from PipelineAssetsFileRole trust policy",
        detailsMd: `
      When this feature flag is enabled, the root account principal will not be added to the trust policy of asset role.
      When this feature flag is disabled, it will keep the root account principal in the trust policy.
    `,
        introducedIn: { v2: "2.141.0" },
        unconfiguredBehavesLike: { v2: true },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Disable the feature flag to add the root account principal back"
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.EKS_NODEGROUP_NAME]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, nodegroupName attribute of the provisioned EKS NodeGroup will not have the cluster name prefix.",
        detailsMd: `
      When this feature flag is enabled, the nodegroupName attribute will be exactly the name of the nodegroup without
      any prefix.
    `,
        introducedIn: { v2: "2.139.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.EKS_USE_NATIVE_OIDC_PROVIDER]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, EKS V2 clusters will use the native OIDC provider resource AWS::IAM::OIDCProvider instead of creating the OIDCProvider with a custom resource (iam.OpenIDConnectProvider).",
        detailsMd: `
      When this feature flag is enabled, EKS clusters will use the native AWS::IAM::OIDCProvider
      CloudFormation resource instead of the custom resource provider for creating OIDC providers.

			WARNING: Enabling this flag on a cluster with an existing OIDC provider created by the custom resource (iam.OpenIDConnectProvider)
			will cause the OIDC provider to be replaced with the native resource, which may lead to disruption.

			To migrate in place without disruption, follow the guide at: https://github.com/aws/aws-cdk/blob/main/packages/aws-cdk-lib/aws-eks/README.md#migrating-from-the-deprecated-eksopenidconnectprovider-to-eksoidcprovidernative
    `,
        introducedIn: { v2: "2.237.0" },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Disable the feature flag to use the custom resource provider."
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.EBS_DEFAULT_GP3]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "When enabled, the default volume type of the EBS volume will be GP3",
        detailsMd: `
      When this featuer flag is enabled, the default volume type of the EBS volume will be \`EbsDeviceVolumeType.GENERAL_PURPOSE_SSD_GP3\`.
    `,
        introducedIn: { v2: "2.140.0" },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Pass `volumeType: EbsDeviceVolumeType.GENERAL_PURPOSE_SSD` to `Volume` construct to restore the previous behavior."
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.ECS_REMOVE_DEFAULT_DEPLOYMENT_ALARM]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "When enabled, remove default deployment alarm settings",
        detailsMd: `
      When this feature flag is enabled, remove the default deployment alarm settings when creating a AWS ECS service.
    `,
        introducedIn: { v2: "2.143.0" },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Set AWS::ECS::Service 'DeploymentAlarms' manually to restore the previous behavior."
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.LOG_API_RESPONSE_DATA_PROPERTY_TRUE_DEFAULT]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, the custom resource used for `AwsCustomResource` will configure the `logApiResponseData` property as true by default",
        detailsMd: `
      This results in 'logApiResponseData' being passed as true to the custom resource provider. This will cause the custom resource handler to receive an 'Update' event. If you don't
      have an SDK call configured for the 'Update' event and you're dependent on specific SDK call response data, you will see this error from CFN:

      CustomResource attribute error: Vendor response doesn't contain <attribute-name> attribute in object. See https://github.com/aws/aws-cdk/issues/29949) for more details.

      Unlike most feature flags, we don't recommend setting this feature flag to true. However, if you're using the 'AwsCustomResource' construct with 'logApiResponseData' as true in
      the event object, then setting this feature flag will keep this behavior. Otherwise, setting this feature flag to false will trigger an 'Update' event by removing the 'logApiResponseData'
      property from the event object.
    `,
        introducedIn: { v2: "2.145.0" },
        recommendedValue: false
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.S3_KEEP_NOTIFICATION_IN_IMPORTED_BUCKET]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, Adding notifications to a bucket in the current stack will not remove notification from imported stack.",
        detailsMd: `
      Currently, adding notifications to a bucket where it was created by ourselves will override notification added where it is imported.

      When this feature flag is enabled, adding notifications to a bucket in the current stack will only update notification defined in this stack.
      Other notifications that are not managed by this stack will be kept.
    `,
        introducedIn: { v2: "2.155.0" },
        recommendedValue: false
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.USE_NEW_S3URI_PARAMETERS_FOR_BEDROCK_INVOKE_MODEL_TASK]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, use new props for S3 URI field in task definition of state machine for bedrock invoke model.",
        detailsMd: `
    Currently, 'inputPath' and 'outputPath' from the TaskStateBase Props is being used under BedrockInvokeModelProps to define S3URI under 'input' and 'output' fields
    of State Machine Task definition.

    When this feature flag is enabled, specify newly introduced props 's3InputUri' and
    's3OutputUri' to populate S3 uri under input and output fields in state machine task definition for Bedrock invoke model.

    `,
        introducedIn: { v2: "2.156.0" },
        unconfiguredBehavesLike: { v2: true },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Disable the feature flag to use input and output path fields for s3 URI"
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.EXPLICIT_STACK_TAGS]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "When enabled, stack tags need to be assigned explicitly on a Stack.",
        detailsMd: `
    Without this feature flag enabled, if tags are added to a Stack using
    \`Tags.of(scope).add(...)\`, they will be added to both the stack and all resources
    in the stack template.

    That leads to the tags being applied twice: once in the template, and once
    again automatically by CloudFormation, which will apply all stack tags to
    all resources in the stack. This leads to loss of control, as the
    \`excludeResourceTypes\` option of the Tags API will not have any effect.

    With this flag enabled, tags added to a stack using \`Tags.of(...)\` are ignored,
    and Stack tags must be configured explicitly on the Stack object.
    `,
        introducedIn: { v2: "2.205.0" },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Configure stack-level tags using `new Stack(..., { tags: { ... } })`."
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.REDUCE_EC2_FARGATE_CLOUDWATCH_PERMISSIONS]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, we will only grant the necessary permissions when users specify cloudwatch log group through logConfiguration",
        detailsMd: `
    Currently, we automatically add a number of cloudwatch permissions to the task role when no cloudwatch log group is
    specified as logConfiguration and it will grant 'Resources': ['*'] to the task role.

    When this feature flag is enabled, we will only grant the necessary permissions when users specify cloudwatch log group.
    `,
        introducedIn: { v2: "2.159.0" },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Disable the feature flag to continue grant permissions to log group when no log group is specified"
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.DYNAMODB_TABLEV2_RESOURCE_POLICY_PER_REPLICA]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled will allow you to specify a resource policy per replica, and not copy the source table policy to all replicas",
        detailsMd: `
      If this flag is not set, the default behavior for \`TableV2\` is to use a different \`resourcePolicy\` for each replica.

      If this flag is set to false, the behavior is that each replica shares the same \`resourcePolicy\` as the source table.
      This will prevent you from creating a new table which has an additional replica and a resource policy.

      This is a feature flag as the old behavior was technically incorrect but users may have come to depend on it.`,
        introducedIn: { v2: "2.164.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.EC2_SUM_TIMEOUT_ENABLED]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, initOptions.timeout and resourceSignalTimeout values will be summed together.",
        detailsMd: `
      Currently is both initOptions.timeout and resourceSignalTimeout are both specified in the options for creating an EC2 Instance,
      only the value from 'resourceSignalTimeout' will be used.

      When this feature flag is enabled, if both initOptions.timeout and resourceSignalTimeout are specified, the values will to be summed together.
      `,
        recommendedValue: true,
        introducedIn: { v2: "2.160.0" }
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.APPSYNC_GRAPHQLAPI_SCOPE_LAMBDA_FUNCTION_PERMISSION]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, a Lambda authorizer Permission created when using GraphqlApi will be properly scoped with a SourceArn.",
        detailsMd: `
        Currently, when using a Lambda authorizer with an AppSync GraphQL API, the AWS CDK automatically generates the necessary AWS::Lambda::Permission
        to allow the AppSync API to invoke the Lambda authorizer. This permission is overly permissive because it lacks a SourceArn, meaning
        it allows invocations from any source.

        When this feature flag is enabled, the AWS::Lambda::Permission will be properly scoped with the SourceArn corresponding to the
        specific AppSync GraphQL API.
        `,
        recommendedValue: true,
        introducedIn: { v2: "2.161.0" }
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.USE_CORRECT_VALUE_FOR_INSTANCE_RESOURCE_ID_PROPERTY]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, the value of property `instanceResourceId` in construct `DatabaseInstanceReadReplica` will be set to the correct value which is `DbiResourceId` instead of currently `DbInstanceArn`",
        detailsMd: `
      Currently, the value of the property 'instanceResourceId' in construct 'DatabaseInstanceReadReplica' is not correct, and set to 'DbInstanceArn' which is not correct when it is used to create the IAM Policy in the grantConnect method.

      When this feature flag is enabled, the value of that property will be as expected set to 'DbiResourceId' attribute, and that will fix the grantConnect method.
    `,
        introducedIn: { v2: "2.161.0" },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Disable the feature flag to use `DbInstanceArn` as value for property `instanceResourceId`"
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.CFN_INCLUDE_REJECT_COMPLEX_RESOURCE_UPDATE_CREATE_POLICY_INTRINSICS]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, CFN templates added with `cfn-include` will error if the template contains Resource Update or Create policies with CFN Intrinsics that include non-primitive values.",
        detailsMd: `
    Without enabling this feature flag, \`cfn-include\` will silently drop resource update or create policies that contain CFN Intrinsics if they include non-primitive values.

    Enabling this feature flag will make \`cfn-include\` throw on these templates, unless you specify the logical ID of the resource in the 'unhydratedResources' property.
    `,
        recommendedValue: true,
        introducedIn: { v2: "2.161.0" }
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.LAMBDA_NODEJS_SDK_V3_EXCLUDE_SMITHY_PACKAGES]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, both `@aws-sdk` and `@smithy` packages will be excluded from the Lambda Node.js 18.x runtime to prevent version mismatches in bundled applications.",
        detailsMd: `
      Currently, when bundling Lambda functions with the non-latest runtime that supports AWS SDK JavaScript (v3), only the '@aws-sdk/*' packages are excluded by default.
      However, this can cause version mismatches between the '@aws-sdk/*' and '@smithy/*' packages, as they are tightly coupled dependencies in AWS SDK v3.

      When this feature flag is enabled, both '@aws-sdk/*' and '@smithy/*' packages will be excluded during the bundling process. This ensures that no mismatches
      occur between these tightly coupled dependencies when using the AWS SDK v3 in Lambda functions.
    `,
        introducedIn: { v2: "2.161.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.STEPFUNCTIONS_TASKS_FIX_RUN_ECS_TASK_POLICY]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, the resource of IAM Run Ecs policy generated by SFN EcsRunTask will reference the definition, instead of constructing ARN.",
        detailsMd: `
      Currently, in the IAM Run Ecs policy generated by SFN EcsRunTask(), CDK will construct the ARN with wildcard attached at the end.
      The revision number at the end will be replaced with a wildcard which it shouldn't.

      When this feature flag is enabled, if the task definition is created in the stack, the 'Resource' section will 'Ref' the taskDefinition.
    `,
        introducedIn: { v2: "2.163.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.BASTION_HOST_USE_AMAZON_LINUX_2023_BY_DEFAULT]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "When enabled, the BastionHost construct will use the latest Amazon Linux 2023 AMI, instead of Amazon Linux 2.",
        detailsMd: `
      Currently, if the machineImage property of the BastionHost construct defaults to using the latest Amazon Linux 2
      AMI. Amazon Linux 2 hits end-of-life in June 2025, so using Amazon Linux 2023 by default is a more future-proof
      and secure option.

      When this feature flag is enabled, if you do not pass the machineImage property to the BastionHost construct,
      the latest Amazon Linux 2023 version will be used instead of Amazon Linux 2.
    `,
        introducedIn: { v2: "2.172.0" },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Disable the feature flag or explicitly pass an Amazon Linux 2 machine image to the BastionHost construct."
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.ASPECT_STABILIZATION]: {
        type: flag_modeling_1.FlagType.VisibleContext,
        summary: "When enabled, a stabilization loop will be run when invoking Aspects during synthesis.",
        detailsMd: `
      Previously, Aspects were invoked in a single pass of the construct tree.
      This meant that Aspects which created other Aspects were not run, and Aspects that created new nodes in the tree sometimes did not inherit their parent Aspects.

      When this feature flag is enabled, a stabilization loop is run to recurse the construct tree multiple times when invoking Aspects.
    `,
        unconfiguredBehavesLike: { v2: true },
        introducedIn: { v2: "2.172.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.USER_POOL_DOMAIN_NAME_METHOD_WITHOUT_CUSTOM_RESOURCE]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, use a new method for DNS Name of user pool domain target without creating a custom resource.",
        detailsMd: `
    When this feature flag is enabled, a new method will be used to get the DNS Name of the user pool domain target. The old method
    creates a custom resource internally, but the new method doesn't need a custom resource.

    If the flag is set to false then a custom resource will be created when using \`UserPoolDomainTarget\`.
    `,
        introducedIn: { v2: "2.174.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.ALB_DUALSTACK_WITHOUT_PUBLIC_IPV4_SECURITY_GROUP_RULES_DEFAULT]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, the default security group ingress rules will allow IPv6 ingress from anywhere",
        detailsMd: `
      For internet facing ALBs with 'dualstack-without-public-ipv4' IP address type, the default security group rules
      will allow IPv6 ingress from anywhere (::/0). Previously, the default security group rules would only allow IPv4 ingress.

      Using a feature flag to make sure existing customers who might be relying
      on the overly restrictive permissions are not broken.`,
        introducedIn: { v2: "2.176.0" },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Disable the feature flag to only allow IPv4 ingress in the default security group rules."
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.IAM_OIDC_REJECT_UNAUTHORIZED_CONNECTIONS]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, the default behaviour of OIDC provider will reject unauthorized connections",
        detailsMd: `
      When this feature flag is enabled, the default behaviour of OIDC Provider's custom resource handler will
      default to reject unauthorized connections when downloading CA Certificates.

      When this feature flag is disabled, the behaviour will be the same as current and will allow downloading
      thumbprints from unsecure connections.`,
        introducedIn: { v2: "2.177.0" },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Disable the feature flag to allow unsecure OIDC connection."
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.ENABLE_ADDITIONAL_METADATA_COLLECTION]: {
        type: flag_modeling_1.FlagType.VisibleContext,
        summary: "When enabled, CDK will expand the scope of usage data collected to better inform CDK development and improve communication for security concerns and emerging issues.",
        detailsMd: `
    When this feature flag is enabled, CDK expands the scope of usage data collection to include the following:
      * L2 construct property keys - Collect which property keys you use from the L2 constructs in your app. This includes property keys nested in dictionary objects.
      * L2 construct property values of BOOL and ENUM types - Collect property key values of only BOOL and ENUM types. All other types, such as string values or construct references will be redacted.
      * L2 construct method usage - Collection method name, parameter keys and parameter values of BOOL and ENUM type.
    `,
        introducedIn: { v2: "2.178.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.LAMBDA_CREATE_NEW_POLICIES_WITH_ADDTOROLEPOLICY]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "[Deprecated] When enabled, Lambda will create new inline policies with AddToRolePolicy instead of adding to the Default Policy Statement",
        detailsMd: `
      [Deprecated default feature] When this feature flag is enabled, Lambda will create new inline policies with AddToRolePolicy.
      The purpose of this is to prevent lambda from creating a dependency on the Default Policy Statement.
      This solves an issue where a circular dependency could occur if adding lambda to something like a Cognito Trigger, then adding the User Pool to the lambda execution role permissions.
      However in the current implementation, we have removed a dependency of the lambda function on the policy. In addition to this, a Role will be attached to the Policy instead of an inline policy being attached to the role.
      This will create a data race condition in the CloudFormation template because the creation of the Lambda function no longer waits for the policy to be created. Having said that, we are not deprecating the feature (we are defaulting the feature flag to false for new stacks) since this feature can still be used to get around the circular dependency issue (issue-7016) particularly in cases where the lambda resource creation doesnt need to depend on the policy resource creation.
      We recommend to unset the feature flag if already set which will restore the original behavior.
    `,
        introducedIn: { v2: "2.180.0" },
        recommendedValue: false
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.SET_UNIQUE_REPLICATION_ROLE_NAME]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, CDK will automatically generate a unique role name that is used for s3 object replication.",
        detailsMd: `
      When performing cross-account S3 replication, we need to explicitly specify a role name for the replication execution role.
      When this feature flag is enabled, a unique role name is specified only when performing cross-account replication.
      When disabled, 'CDKReplicationRole' is always specified.
    `,
        introducedIn: { v2: "2.182.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.PIPELINE_REDUCE_STAGE_ROLE_TRUST_SCOPE]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "Remove the root account principal from Stage addActions trust policy",
        detailsMd: `
      When this feature flag is enabled, the root account principal will not be added to the trust policy of stage role.
      When this feature flag is disabled, it will keep the root account principal in the trust policy.

      For cross-account cases, when this feature flag is enabled the trust policy will be scoped to the role only.
      If you are providing a custom role, you will need to ensure 'roleName' is specified or set to PhysicalName.GENERATE_IF_NEEDED.
    `,
        introducedIn: { v2: "2.184.0" },
        unconfiguredBehavesLike: { v2: true },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Disable the feature flag to add the root account principal back"
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.EVENTBUS_POLICY_SID_REQUIRED]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, grantPutEventsTo() will use resource policies with Statement IDs for service principals.",
        detailsMd: `
      Currently, when granting permissions to service principals using grantPutEventsTo(), the operation silently fails
      because service principals require resource policies with Statement IDs.

      When this flag is enabled:
      - Resource policies will be created with Statement IDs for service principals
      - The operation will succeed as expected

      When this flag is disabled:
      - A warning will be emitted
      - The grant operation will be dropped
      - No permissions will be added

      This fixes the issue where permissions were silently not being added for service principals.
    `,
        introducedIn: { v2: "2.186.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.ASPECT_PRIORITIES_MUTATING]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "When set to true, Aspects added by the construct library on your behalf will be given a priority of MUTATING.",
        detailsMd: `
      Custom Aspects you add have a priority of DEFAULT (500) if you don't
      assign a more specific priority, which is higher than MUTATING (200). This
      is relevant if a custom Aspect you add and an Aspect added by CDK try to
      configure the same value.

      If this flag is set to false (old behavior), Aspects added by CDK are also
      added with a priority of DEFAULT; because their priorities are equal, the
      Aspects that is closest to the target construct executes last (either
      yours or the Aspect added by the CDK).

      If this flag is set to true (recommended behavior), Aspects added by CDK are added
      with a priority of MUTATING, and custom Aspects you add with DEFAULT
      priority will always execute last and "win" the write. If you need Aspects
      added by CDK to run after yours, your Aspect needs to have a priority of
      MUTATING or lower.

      This setting only applies to Aspects that were already being added for you
      before version 2.172.0. Aspects introduced since that version will always
      be added with a priority of MUTATING, independent of this feature flag.
    `,
        introducedIn: { v2: "2.189.1" },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: `
      To add mutating Aspects controlling construct values that can be overridden
      by Aspects added by CDK, give them MUTATING priority:

      \`\`\`
      Aspects.of(stack).add(new MyCustomAspect(), {
        priority: AspectPriority.MUTATING,
      });
      \`\`\`
    `
      },
      [exports2.DYNAMODB_TABLE_RETAIN_TABLE_REPLICA]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, table replica will be default to the removal policy of source table unless specified otherwise.",
        detailsMd: `
      Currently, table replica will always be deleted when stack deletes regardless of source table's deletion policy.
      When enabled, table replica will be default to the removal policy of source table unless specified otherwise.
    `,
        introducedIn: { v2: "2.187.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.LOG_USER_POOL_CLIENT_SECRET_VALUE]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "When disabled, the value of the user pool client secret will not be logged in the custom resource lambda function logs.",
        detailsMd: `
      When this feature flag is enabled, the SDK API call response to describe user pool client values will be logged in the custom
      resource lambda function logs.

      When this feature flag is disabled, the SDK API call response to describe user pool client values will not be logged in the custom
      resource lambda function logs.
    `,
        introducedIn: { v2: "2.187.0" },
        unconfiguredBehavesLike: { v2: false },
        recommendedValue: false,
        compatibilityWithOldBehaviorMd: "Enable the feature flag to keep the old behavior and log the client secret values"
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.PIPELINE_REDUCE_CROSS_ACCOUNT_ACTION_ROLE_TRUST_SCOPE]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "When enabled, scopes down the trust policy for the cross-account action role",
        detailsMd: `
        When this feature flag is enabled, the trust policy of the cross-account action role will be scoped to the pipeline role.
        If you are providing a custom role, you will need to ensure 'roleName' is specified or set to PhysicalName.GENERATE_IF_NEEDED.
        When this feature flag is disabled, it will keep the root account principal in the trust policy.
      `,
        introducedIn: { v2: "2.189.0" },
        unconfiguredBehavesLike: { v2: true },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Disable the feature flag to add the root account principal back"
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.STEPFUNCTIONS_USE_DISTRIBUTED_MAP_RESULT_WRITER_V2]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "When enabled, the resultWriterV2 property of DistributedMap will be used insted of resultWriter",
        detailsMd: `
      When this feature flag is enabled, the resultWriterV2 property is used instead of resultWriter in DistributedMap class.
      resultWriterV2 uses ResultWriterV2 class in StepFunctions ASL and can have either Bucket/Prefix or WriterConfig or both.
    `,
        introducedIn: { v2: "2.188.0" },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Disable the feature flag and set resultWriter in DistributedMap"
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.S3_TRUST_KEY_POLICY_FOR_SNS_SUBSCRIPTIONS]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "Add an S3 trust policy to a KMS key resource policy for SNS subscriptions.",
        detailsMd: `
      When this feature flag is enabled, a S3 trust policy will be added to the KMS key resource policy for encrypted SNS subscriptions.
          `,
        introducedIn: { v2: "2.195.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.EC2_REQUIRE_PRIVATE_SUBNETS_FOR_EGRESSONLYINTERNETGATEWAY]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, the EgressOnlyGateway resource is only created if private subnets are defined in the dual-stack VPC.",
        detailsMd: `
      When this feature flag is enabled, EgressOnlyGateway resource will not be created when you create a vpc with only public subnets.
          `,
        introducedIn: { v2: "2.196.0" },
        recommendedValue: true
      },
      /// ///////////////////////////////////////////////////////////////////
      [exports2.USE_RESOURCEID_FOR_VPCV2_MIGRATION]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "When enabled, use resource IDs for VPC V2 migration",
        detailsMd: `
        When this feature flag is enabled, the VPC V2 migration will use resource IDs instead of getAtt references
        for migrating resources from VPC V1 to VPC V2. This helps ensure a smoother migration path between
        the two versions.
      `,
        introducedIn: { v2: "2.196.0" },
        recommendedValue: false,
        unconfiguredBehavesLike: { v2: false },
        compatibilityWithOldBehaviorMd: "Disable the feature flag to use getAtt references for VPC V2 migration"
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.S3_PUBLIC_ACCESS_BLOCKED_BY_DEFAULT]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, setting any combination of options for BlockPublicAccess will automatically set true for any options not defined.",
        detailsMd: `
      When BlockPublicAccess is not set at all, s3's default behavior will be to set all options to true in aws console.
      The previous behavior in cdk before this feature was; if only some of the BlockPublicAccessOptions were set (not all 4), then the ones undefined would default to false.
      This is counter intuitive to the console behavior where the options would start in true state and a user would uncheck the boxes as needed.
      The new behavior from this feature will allow a user, for example, to set 1 of the 4 BlockPublicAccessOpsions to false, and on deployment the other 3 will remain true.
    `,
        introducedIn: { v2: "2.196.0" },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.USE_CDK_MANAGED_LAMBDA_LOGGROUP]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "When enabled, CDK creates and manages loggroup for the lambda function",
        detailsMd: `
        When this feature flag is enabled, CDK will create a loggroup for lambda function with default properties
        which supports CDK features Tag propagation, Property Injectors, Aspects
        if the cdk app doesnt pass a 'logRetention' or 'logGroup' explicitly.
        LogGroups created via 'logRetention' do not support Tag propagation, Property Injectors, Aspects.
        LogGroups created via 'logGroup' created in CDK support Tag propagation, Property Injectors, Aspects.

        When this feature flag is disabled, a loggroup is created by Lambda service on first invocation
        of the function (existing behavior).
        LogGroups created in this way do not support Tag propagation, Property Injectors, Aspects.

        DO NOT ENABLE: If you have an existing app defining a lambda function and
        have not supplied a logGroup or logRetention prop and your lambda function has
        executed at least once, the logGroup has been already created with the same name
        so your deployment will start failing.
        Refer aws-lambda/README.md for more details on Customizing Log Group creation.
      `,
        introducedIn: { v2: "2.200.0" },
        unconfiguredBehavesLike: { v2: false },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Disable the feature flag to let lambda service create logGroup or specify logGroup or logRetention"
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.NETWORK_LOAD_BALANCER_WITH_SECURITY_GROUP_BY_DEFAULT]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "When enabled, Network Load Balancer will be created with a security group by default.",
        detailsMd: `
      When this feature flag is enabled, Network Load Balancer will be created with a security group by default.
    `,
        introducedIn: { v2: "2.222.0" },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Disable the feature flag to create Network Load Balancer without a security group by default."
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.STEPFUNCTIONS_TASKS_HTTPINVOKE_DYNAMIC_JSONPATH_ENDPOINT]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, allows using a dynamic apiEndpoint with JSONPath format in HttpInvoke tasks.",
        detailsMd: `
      When this feature flag is enabled, the JSONPath apiEndpoint value will be resolved dynamically at runtime, while slightly increasing the size of the state machine definition.
      When disabled, the JSONPath apiEndpoint property will only support a static string value.
    `,
        introducedIn: { v2: "2.221.0" },
        unconfiguredBehavesLike: { v2: true },
        recommendedValue: true
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.ECS_PATTERNS_UNIQUE_TARGET_GROUP_ID]: {
        type: flag_modeling_1.FlagType.BugFix,
        summary: "When enabled, ECS patterns will generate unique target group IDs to prevent conflicts during load balancer replacement",
        detailsMd: `
      When this feature flag is enabled, ECS patterns will generate unique target group IDs that include
      both the load balancer type (public/private) and load balancer name. This prevents CloudFormation
      conflicts when switching between public and private load balancers or when changing load balancer names.

      Without this flag, target groups use generic IDs like 'ECS' which can cause conflicts when the
      underlying load balancer is replaced due to changes in internetFacing or loadBalancerName properties.

      This is a breaking change as it will cause target group replacement when the flag is enabled.
    `,
        introducedIn: { v2: "2.221.0" },
        recommendedValue: true
      },
      [exports2.ROUTE53_PATTERNS_USE_DISTRIBUTION]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "Use the `Distribution` resource instead of `CloudFrontWebDistribution`",
        detailsMd: `
      Enable this feature flag to use the new \`Distribution\` resource instead
      of the deprecated \`CloudFrontWebDistribution\` construct.
      `,
        introducedIn: { v2: "2.233.0" },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Define a `CloudFrontWebDistribution` explicitly"
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.CLOUDFRONT_FUNCTION_DEFAULT_RUNTIME_V2_0]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "Use cloudfront-js-2.0 as the default runtime for CloudFront Functions",
        detailsMd: `
      When enabled, CloudFront Functions will use cloudfront-js-2.0 runtime by default instead of cloudfront-js-1.0.
      The runtime can still be configured explicitly using the \`runtime\` property.

      If \`keyValueStore\` is specified, the runtime will always be cloudfront-js-2.0 regardless of this flag.`,
        introducedIn: { v2: "2.245.0" },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Set `runtime: FunctionRuntime.JS_1_0` explicitly to use the v1.0 runtime."
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.ELB_USE_POST_QUANTUM_TLS_POLICY]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "When enabled, HTTPS/TLS listeners use post-quantum TLS policy by default",
        detailsMd: `
      When this feature flag is enabled, HTTPS and TLS listeners that do not have an explicit
      \`sslPolicy\` will use the post-quantum cryptography policy
      \`ELBSecurityPolicy-TLS13-1-2-PQ-2025-09\` by default.

      This policy uses the non-restricted variant (without -Res-) to maintain AES-CBC cipher support
      for TLS 1.2 clients, ensuring nearly 100% backward compatibility with the previous CDK default.
      Post-quantum policies provide protection against "Harvest Now, Decrypt Later" attacks using
      hybrid ML-KEM key exchange.

      When disabled (default), no explicit SSL policy is set, preserving the existing CDK behavior
      where \`RECOMMENDED_TLS\` (\`ELBSecurityPolicy-TLS13-1-2-2021-06\`) is used.
    `,
        introducedIn: { v2: "2.245.0" },
        recommendedValue: true,
        compatibilityWithOldBehaviorMd: "Disable this feature flag to preserve existing behavior where no explicit SSL policy is set."
      },
      [exports2.AUTOMATIC_L1_TRAITS]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "Automatically use the default L1 traits for L1 constructs`",
        detailsMd: `
      When enabled, the construct library will apply default L1 traits for types that
      have no traits defined yet. Traits regulate behaviors such as how to create
      resource policies, or how to find an encryption key for a given L1 construct.
      `,
        introducedIn: { v2: "2.239.0" },
        recommendedValue: true,
        unconfiguredBehavesLike: { v2: true },
        compatibilityWithOldBehaviorMd: "Register traits explicitly for each resource type"
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.BATCH_DEFAULT_AL2023]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "Use AL2023 as the default imageType for EC2 Batch compute environments instead of the deprecated AL2",
        detailsMd: `
      When enabled, EC2 Batch compute environments (both ECS and EKS) that do not specify an \`imageType\`
      will default to \`ECS_AL2023\` or \`EKS_AL2023\` instead of the deprecated \`ECS_AL2\` or \`EKS_AL2\`
      (Amazon Linux 2, reaching EOL June 2026 for ECS; already EOL for EKS).

      For EKS compute environments with a launch template, \`userdataType\` will automatically be set
      to \`EKS_NODEADM\` when an AL2023 image type is used, as required by the AWS Batch API.

      When disabled, the default \`imageType\` remains \`ECS_AL2\` / \`EKS_AL2\` for backward compatibility.`,
        introducedIn: { v2: "2.249.0" },
        recommendedValue: true,
        unconfiguredBehavesLike: { v2: false },
        compatibilityWithOldBehaviorMd: `Explicitly set \`imageType\` to \`ECS_AL2\` or \`EKS_AL2\` in your compute environment images configuration.

**Warning**: Enabling this flag on existing stacks may cause compute environment replacement, which terminates running jobs. To migrate safely, first pin existing environments to their current imageType explicitly, then enable the flag.`
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.EKS_DEFAULT_AL2023]: {
        type: flag_modeling_1.FlagType.ApiDefault,
        summary: "Use AL2023 as the default AMI type for EKS managed node groups using non-GPU instance types instead of the deprecated AL2",
        detailsMd: `
      When enabled, EKS managed node groups that do not specify an \`amiType\` will default to
      AL2023 AMI types (AL2023_x86_64_STANDARD, AL2023_ARM_64_STANDARD) instead of the deprecated
      AL2 types (AL2_x86_64, AL2_ARM_64).

      This only affects non-GPU instance types. GPU instances continue to default to AL2_x86_64_GPU
      because AL2023 splits GPU support into separate NVIDIA and Neuron AMI variants.

      Amazon Linux 2 reached end of support on November 26, 2025. AL2023 is the AWS-recommended default.

      When disabled, the default AMI types remain AL2 for backward compatibility.`,
        introducedIn: { v2: "2.259.0" },
        recommendedValue: true,
        unconfiguredBehavesLike: { v2: false },
        compatibilityWithOldBehaviorMd: `Explicitly set \`amiType\` to the desired AL2 type (e.g., \`NodegroupAmiType.AL2_X86_64\`) in your nodegroup configuration.

**Warning**: Enabling this flag on existing stacks will cause node group replacement, which terminates running pods. To migrate safely, first pin existing node groups to their current amiType explicitly, then enable the flag for new node groups.`
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.ANNOTATIONS_IN_VALIDATION_REPORT]: {
        type: flag_modeling_1.FlagType.VisibleContext,
        summary: "Include construct annotations (warnings and errors) in the policy validation report",
        detailsMd: `
      When enabled, construct annotations added via \`Annotations.of()\` or \`Validations.of()\`
      are collected post-synthesis and included in the policy validation report alongside
      plugin violations. Annotations appear under a "Construct Annotations" source entry.

      When disabled, annotations are only displayed through the CLI's standard metadata
      output (e.g. \`[Warning at /path] message\`) and do not appear in the validation report.

      Note: enabling this flag may cause annotations to appear twice \u2014 once in the CLI's
      standard output and once in the validation report \u2014 until the CLI is updated to
      consolidate both displays.`,
        introducedIn: { v2: "2.253.0" },
        recommendedValue: true,
        unconfiguredBehavesLike: { v2: false }
      },
      //////////////////////////////////////////////////////////////////////
      [exports2.DEFAULT_CROSS_STACK_REFERENCES]: {
        type: flag_modeling_1.FlagType.VisibleContext,
        summary: "Controls whether cross-region stack references are strong, weak, or both",
        detailsMd: `
      Controls the default type of cross-region stack references. Accepted values are
      \`"strong"\`, \`"weak"\`, and \`"both"\`. This setting only affects same-account,
      cross-region references. Cross-account references are always weak, and same-region
      references are always strong (Fn::ImportValue).

      The flag is read from the **consumer** stack's context, not the producer's.

      - \`"strong"\` (default): Uses ExportWriter/ExportReader custom resources that
        write values to SSM Parameters in the consuming region. This prevents the
        producing stack from being deleted while consumers exist.
      - \`"weak"\`: Uses Fn::GetStackOutput to read an output directly from the
        producing stack. Simpler (no extra infrastructure), but the producing stack
        can be deleted independently of consumers.
      - \`"both"\`: A transitional state for migrating from strong to weak. The producer
        keeps the ExportWriter (continues writing to SSM) and also adds an Output. The
        consumer switches to Fn::GetStackOutput. This allows removing the ExportReader
        without breaking anything.

      **Migration from strong to weak**: set to \`"both"\` and deploy, then set to
      \`"weak"\` and deploy again.

      **Migration from weak to strong**: set directly to \`"strong"\` (single deployment).`,
        introducedIn: { v2: "2.254.0" },
        recommendedValue: "weak",
        unconfiguredBehavesLike: { v2: "strong" }
      }
    };
    exports2.CURRENT_MV = "v2";
    exports2.CURRENT_VERSION_EXPIRED_FLAGS = Object.entries(exports2.FLAGS).filter(([_, flag]) => flag.introducedIn[exports2.CURRENT_MV] === void 0).map(([name, _]) => name).sort();
    exports2.CURRENTLY_RECOMMENDED_FLAGS = Object.fromEntries(Object.entries(exports2.FLAGS).filter(([_, flag]) => flag.introducedIn[exports2.CURRENT_MV] !== void 0).filter(([_, flag]) => flag.recommendedValue !== flag.unconfiguredBehavesLike?.[exports2.CURRENT_MV]).map(([name, flag]) => [name, flag.recommendedValue]));
    exports2.CURRENT_VERSION_FLAG_DEFAULTS = Object.fromEntries(Object.entries(exports2.FLAGS).filter(([_, flag]) => flag.unconfiguredBehavesLike?.[exports2.CURRENT_MV] !== void 0).map(([name, flag]) => [name, flag.unconfiguredBehavesLike?.[exports2.CURRENT_MV]]));
    function futureFlagDefault2(flag) {
      const value = exports2.CURRENT_VERSION_FLAG_DEFAULTS[flag] ?? false;
      if (typeof value !== "boolean") {
        throw new Error(`futureFlagDefault: default type of flag '${flag}' should be boolean, got '${typeof value}'`);
      }
      return value;
    }
    __name(futureFlagDefault2, "futureFlagDefault");
    exports2.FUTURE_FLAGS_EXPIRED = exports2.CURRENT_VERSION_EXPIRED_FLAGS;
    exports2.FUTURE_FLAGS = Object.fromEntries(Object.entries(exports2.CURRENTLY_RECOMMENDED_FLAGS).filter(([_, v]) => typeof v === "boolean"));
    exports2.NEW_PROJECT_DEFAULT_CONTEXT = Object.fromEntries(Object.entries(exports2.CURRENTLY_RECOMMENDED_FLAGS).filter(([_, v]) => typeof v !== "boolean"));
  }
});

// ../../node_modules/@aws-cdk/cx-api/lib/app.js
var require_app = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/lib/app.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.BUNDLING_STACKS = exports2.DISABLE_CREATION_STACK_TRACES = exports2.DISABLE_LOGICAL_ID_METADATA = exports2.DISABLE_METADATA_STACK_TRACE = exports2.DISABLE_ASSET_STAGING_CONTEXT = exports2.PERFORMANCE_REPORTING_ENABLED_CONTEXT = exports2.ANALYTICS_REPORTING_ENABLED_CONTEXT = exports2.PATH_METADATA_ENABLE_CONTEXT = void 0;
    exports2.PATH_METADATA_ENABLE_CONTEXT = "aws:cdk:enable-path-metadata";
    exports2.ANALYTICS_REPORTING_ENABLED_CONTEXT = "aws:cdk:version-reporting";
    exports2.PERFORMANCE_REPORTING_ENABLED_CONTEXT = "aws:cdk:performance-reporting";
    exports2.DISABLE_ASSET_STAGING_CONTEXT = "aws:cdk:disable-asset-staging";
    exports2.DISABLE_METADATA_STACK_TRACE = "aws:cdk:disable-stack-trace";
    exports2.DISABLE_LOGICAL_ID_METADATA = "aws:cdk:disable-logicalId-metadata";
    exports2.DISABLE_CREATION_STACK_TRACES = "aws:cdk:disable-creation-stack-traces";
    exports2.BUNDLING_STACKS = "aws:cdk:bundling-stacks";
  }
});

// ../../node_modules/@aws-cdk/cx-api/lib/index.js
var require_lib11 = __commonJS({
  "../../node_modules/@aws-cdk/cx-api/lib/index.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __exportStar3 = exports2 && exports2.__exportStar || function(m20, exports3) {
      for (var p10 in m20) if (p10 !== "default" && !Object.prototype.hasOwnProperty.call(exports3, p10)) __createBinding3(exports3, m20, p10);
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    __exportStar3(require_legacy_moved(), exports2);
    __exportStar3(require_cxapi(), exports2);
    __exportStar3(require_features(), exports2);
    __exportStar3(require_app(), exports2);
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/environment.ts
async function prepareDefaultEnvironment(aws, debugFn) {
  const env3 = {};
  env3[cxapi4.DEFAULT_REGION_ENV] = aws.defaultRegion;
  await debugFn(`Setting "${cxapi4.DEFAULT_REGION_ENV}" environment variable to ${env3[cxapi4.DEFAULT_REGION_ENV]}`);
  const accountId = (await aws.defaultAccount())?.accountId;
  if (accountId) {
    env3[cxapi4.DEFAULT_ACCOUNT_ENV] = accountId;
    await debugFn(`Setting "${cxapi4.DEFAULT_ACCOUNT_ENV}" environment variable to ${env3[cxapi4.DEFAULT_ACCOUNT_ENV]}`);
  }
  return env3;
}
function contextFromSettings(settings) {
  const context = {};
  const pathMetadata = settings.get(["pathMetadata"]) ?? true;
  if (pathMetadata) {
    context[cxapi4.PATH_METADATA_ENABLE_CONTEXT] = true;
  }
  const assetMetadata = settings.get(["assetMetadata"]) ?? true;
  if (assetMetadata) {
    context[cxapi4.ASSET_RESOURCE_METADATA_ENABLED_CONTEXT] = true;
  }
  const versionReporting = settings.get(["versionReporting"]) ?? true;
  if (versionReporting) {
    context[cxapi4.ANALYTICS_REPORTING_ENABLED_CONTEXT] = true;
  }
  if (!versionReporting) {
    context["aws:cdk:disable-version-reporting"] = true;
  }
  const stagingEnabled = settings.get(["staging"]) ?? true;
  if (!stagingEnabled) {
    context[cxapi4.DISABLE_ASSET_STAGING_CONTEXT] = true;
  }
  const bundlingStacks = settings.get(["bundlingStacks"]) ?? ["**"];
  context[cxapi4.BUNDLING_STACKS] = bundlingStacks;
  context[cxapi4.FAIL_SYNTH_ON_VALIDATION_ERRORS_CONTEXT] = false;
  return context;
}
function synthParametersFromSettings(settings) {
  const debugEnvVars = {
    CDK_DEBUG: "true"
  };
  if (process.env.JSII_HOST_STACK_TRACES === void 0) {
    debugEnvVars.JSII_HOST_STACK_TRACES = "1";
  }
  return {
    context: contextFromSettings(settings),
    env: {
      ...settings.get(["debugApp"]) ? debugEnvVars : {}
    }
  };
}
function spaceAvailableForContext(env3, limit) {
  const size = /* @__PURE__ */ __name((value) => value != null ? Buffer.byteLength(value) : 0, "size");
  const usedSpace = Object.entries(env3).map(([k32, v]) => k32 === cxapi4.CONTEXT_ENV ? size(k32) : size(k32) + size(v)).reduce((a32, b32) => a32 + b32, 0);
  return Math.max(0, limit - usedSpace);
}
async function guessExecutable(commandLine, debugFn) {
  const fullFile = await checkFile(commandLine);
  if (fullFile) {
    return guessInterpreter(fullFile);
  }
  const [first, rest] = splitFirstShellWord(commandLine);
  const firstFile = await checkFile(first);
  if (firstFile) {
    return `${guessInterpreter(firstFile)} ${rest}`.trim();
  }
  await debugFn(`Not a file: '${commandLine}'. Using '${commandLine} as command-line`);
  return commandLine;
}
function guessInterpreter(file) {
  const isWindows2 = process.platform === "win32";
  const handler = EXTENSION_MAP[path28.extname(file.fileName)];
  if (handler && (!file.isExecutable || isWindows2)) {
    return handler(file.fileName);
  }
  return quoteSpaces(file.fileName);
}
function executeNode(scriptFile) {
  return `${quoteSpaces(process.execPath)} ${quoteSpaces(scriptFile)}`;
}
function splitFirstShellWord(commandLine) {
  commandLine = commandLine.trim();
  if (commandLine[0] === '"') {
    const endQuote = commandLine.indexOf('"', 1);
    return endQuote > -1 ? [commandLine.slice(1, endQuote), commandLine.slice(endQuote + 1).trim()] : [commandLine, ""];
  } else {
    const space = commandLine.indexOf(" ");
    return space > -1 ? [commandLine.slice(0, space), commandLine.slice(space + 1)] : [commandLine, ""];
  }
}
async function checkFile(fileName) {
  try {
    const fstat = await fs27.stat(fileName);
    return {
      fileName,
      // eslint-disable-next-line no-bitwise
      isExecutable: (fstat.mode & fs27.constants.X_OK) !== 0
    };
  } catch {
    return void 0;
  }
}
function quoteSpaces(part) {
  if (part.includes(" ")) {
    return `"${part}"`;
  }
  return part;
}
var path28, cxapi4, fs27, EXTENSION_MAP;
var init_environment3 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/environment.ts"() {
    "use strict";
    path28 = __toESM(require("path"));
    cxapi4 = __toESM(require_lib11());
    fs27 = __toESM(require_lib4());
    __name(prepareDefaultEnvironment, "prepareDefaultEnvironment");
    __name(contextFromSettings, "contextFromSettings");
    __name(synthParametersFromSettings, "synthParametersFromSettings");
    __name(spaceAvailableForContext, "spaceAvailableForContext");
    __name(guessExecutable, "guessExecutable");
    __name(guessInterpreter, "guessInterpreter");
    EXTENSION_MAP = {
      ".js": executeNode
    };
    __name(executeNode, "executeNode");
    __name(splitFirstShellWord, "splitFirstShellWord");
    __name(checkFile, "checkFile");
    __name(quoteSpaces, "quoteSpaces");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/private/prepare-source.ts
function writeContextToEnv(env3, context, completeness) {
  let contextOverflowLocation = null;
  const envVariableSizeLimit = os10.platform() === "win32" ? 32760 : 131072;
  const completeEnv = { ...completeness === "add-process-env-later" ? process.env : {}, ...env3 };
  const [smallContext, overflow] = splitBySize(context, spaceAvailableForContext(completeEnv, envVariableSizeLimit));
  env3[cxapi5.CONTEXT_ENV] = JSON.stringify(smallContext);
  if (Object.keys(overflow ?? {}).length > 0) {
    const contextDir = fs28.mkdtempSync(path29.join(os10.tmpdir(), "cdk-context"));
    contextOverflowLocation = path29.join(contextDir, "context-overflow.json");
    fs28.writeJSONSync(contextOverflowLocation, overflow);
    env3[cxapi5.CONTEXT_OVERFLOW_LOCATION_ENV] = contextOverflowLocation;
  }
  return async () => {
    if (contextOverflowLocation) {
      await fs28.promises.rm(path29.dirname(contextOverflowLocation), { recursive: true, force: true });
    }
  };
}
async function checkContextOverflowSupport(tree, ioHelper) {
  if (!frameworkSupportsContextOverflow(tree)) {
    await ioHelper.notify(IO.CDK_ASSEMBLY_W0010.msg("Part of the context could not be sent to the application. Please update the AWS CDK library to the latest version."));
  }
}
function findConstructLibraryVersion(tree) {
  let ret = void 0;
  some(tree, (node) => {
    const fqn = node.constructInfo?.fqn;
    const version = node.constructInfo?.version;
    if (fqn?.startsWith("aws-cdk-lib.") || fqn?.startsWith("@aws-cdk/core.")) {
      ret = version;
      return true;
    }
    return false;
  });
  return ret !== "0.0.0" ? ret : void 0;
}
function frameworkSupportsContextOverflow(tree) {
  const version = findConstructLibraryVersion(tree);
  return !version || !(0, import_semver.lte)(version, "2.38.0");
}
async function assemblyFromDirectory(assemblyDir, ioHelper, loadOptions = {}) {
  try {
    const assembly = new import_cloud_assembly_api11.CloudAssembly(assemblyDir, {
      skipVersionCheck: !(loadOptions.checkVersion ?? true),
      skipEnumCheck: !(loadOptions.checkEnums ?? true),
      // We sort as we deploy
      topoSort: false
    });
    const tree = await loadTree(assembly, ioHelper.defaults.trace.bind(ioHelper.defaults));
    await checkContextOverflowSupport(tree, ioHelper);
    return assembly;
  } catch (err) {
    if (err.message.includes(cxschema10.VERSION_MISMATCH)) {
      const message2 = "This AWS CDK Toolkit is not compatible with the AWS CDK library used by your application. Please upgrade to the latest version.";
      await ioHelper.notify(IO.CDK_ASSEMBLY_E1111.msg(message2, { error: err }));
      throw new ToolkitError("AssemblyVersionMismatch", `${message2}
(${err.message}`);
    }
    throw err;
  }
}
function settingsFromSynthOptions(synthOpts = {}) {
  return new Settings({
    debug: false,
    pathMetadata: true,
    versionReporting: true,
    assetMetadata: true,
    assetStaging: true,
    ...synthOpts
  }, true);
}
function parametersFromSynthOptions(synthOptions) {
  return synthParametersFromSettings(settingsFromSynthOptions(synthOptions ?? {}));
}
var import_dispose_polyfill5, os10, path29, import_node_util4, import_cloud_assembly_api11, cxschema10, cxapi5, fs28, import_semver, ExecutionEnvironment;
var init_prepare_source = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/private/prepare-source.ts"() {
    "use strict";
    import_dispose_polyfill5 = __toESM(require_dispose_polyfill());
    os10 = __toESM(require("node:os"));
    path29 = __toESM(require("node:path"));
    import_node_util4 = require("node:util");
    import_cloud_assembly_api11 = __toESM(require_lib3());
    cxschema10 = __toESM(require_lib2());
    cxapi5 = __toESM(require_lib11());
    fs28 = __toESM(require_lib4());
    import_semver = __toESM(require_semver4());
    init_toolkit_error();
    init_util3();
    init_private();
    init_rwlock();
    init_settings();
    init_tree();
    init_environment3();
    ExecutionEnvironment = class _ExecutionEnvironment {
      static {
        __name(this, "ExecutionEnvironment");
      }
      /**
       * Create an ExecutionEnvironment
       *
       * An ExecutionEnvironment holds a writer lock on the given directory which will
       * be cleaned up when the object is disposed.
       *
       * A temporary directory will be created if none is supplied, which will be cleaned
       * up when this object is disposed.
       *
       * If `markSuccessful()` is called, the writer lock is converted to a reader lock
       * and temporary directories will not be cleaned up anymore.
       */
      static async create(services, options) {
        let outDirIsTemporary = false;
        let dir = options.outdir;
        if (!dir) {
          outDirIsTemporary = true;
          dir = fs28.mkdtempSync(path29.join(fs28.realpathSync(os10.tmpdir()), "cdk.out"));
        }
        const lock = await new RWLock(dir).acquireWrite();
        const opts = {
          outdir: dir,
          resolveDefaultAppEnv: options.resolveDefaultAppEnv
        };
        return new _ExecutionEnvironment(services, opts, {
          lock,
          outDirIsTemporary
        });
      }
      /**
       * Should the outdir be disposed of.
       */
      get shouldDisposeOutDir() {
        return this.shouldClean;
      }
      /**
       * The directory the cloud assembly will be written to.
       */
      outdir;
      options;
      ioHelper;
      sdkProvider;
      debugFn;
      lock;
      shouldClean;
      constructor(services, options, { lock, outDirIsTemporary }) {
        this.ioHelper = services.ioHelper;
        this.sdkProvider = services.sdkProvider;
        this.debugFn = (msg) => this.ioHelper.defaults.debug(msg);
        this.lock = lock;
        this.shouldClean = outDirIsTemporary;
        this.outdir = options.outdir;
        this.options = options;
      }
      async [Symbol.asyncDispose]() {
        await this.lock?.release();
        if (this.shouldDisposeOutDir) {
          await fs28.rm(this.outdir, { recursive: true, force: true });
        }
      }
      /**
       * Mark the execution as successful, which stops the writer lock from being released upon disposal
       */
      async markSuccessful() {
        if (!this.lock) {
          throw new TypeError("Cannot mark successful more than once");
        }
        const readLock = await this.lock.convertToReaderLock();
        this.lock = void 0;
        this.shouldClean = false;
        return { readLock };
      }
      /**
       * Begin an execution in this environment
       *
       * This will acquire a write lock on the given environment. The write lock
       * will be released automatically when the return object is disposed, unless it
       * is converted to a reader lock.
       */
      async beginExecution() {
        const lock = await new RWLock(this.outdir).acquireWrite();
        let converted = false;
        return {
          async writeToReadLock() {
            converted = true;
            return lock.convertToReaderLock();
          },
          [Symbol.asyncDispose]: async () => {
            if (!converted) {
              await lock.release();
            }
          }
        };
      }
      /**
       * Guess the executable from the command-line argument
       *
       * Only do this if the file is NOT marked as executable. If it is,
       * we'll defer to the shebang inside the file itself.
       *
       * If we're on Windows, we ALWAYS take the handler, since it's hard to
       * verify if registry associations have or have not been set up for this
       * file type, so we'll assume the worst and take control.
       */
      guessExecutable(app) {
        return guessExecutable(app, this.debugFn);
      }
      /**
       * If we don't have region/account defined in context, we fall back to the default SDK behavior
       * where region is retrieved from ~/.aws/config and account is based on default credentials provider
       * chain and then STS is queried.
       *
       * This is done opportunistically: for example, if we can't access STS for some reason or the region
       * is not configured, the context value will be 'null' and there could failures down the line. In
       * some cases, synthesis does not require region/account information at all, so that might be perfectly
       * fine in certain scenarios.
       */
      async defaultEnvVars() {
        const debugFn = /* @__PURE__ */ __name((msg) => this.ioHelper.notify(IO.CDK_ASSEMBLY_I0010.msg(msg)), "debugFn");
        const env3 = this.options.resolveDefaultAppEnv ? await prepareDefaultEnvironment(this.sdkProvider, debugFn) : {};
        env3[cxapi5.OUTDIR_ENV] = this.outdir;
        await debugFn((0, import_node_util4.format)("outdir:", this.outdir));
        env3[cxapi5.CLI_ASM_VERSION_ENV] = cxschema10.Manifest.version();
        env3[cxapi5.CLI_VERSION_ENV] = versionNumber();
        await debugFn((0, import_node_util4.format)("env:", env3));
        return env3;
      }
      /**
       * Run code from a different working directory
       */
      async changeDir(block, workingDir) {
        const originalWorkingDir = process.cwd();
        try {
          if (workingDir) {
            process.chdir(workingDir);
          }
          return await block();
        } finally {
          if (workingDir) {
            process.chdir(originalWorkingDir);
          }
        }
      }
    };
    __name(writeContextToEnv, "writeContextToEnv");
    __name(checkContextOverflowSupport, "checkContextOverflowSupport");
    __name(findConstructLibraryVersion, "findConstructLibraryVersion");
    __name(frameworkSupportsContextOverflow, "frameworkSupportsContextOverflow");
    __name(assemblyFromDirectory, "assemblyFromDirectory");
    __name(settingsFromSynthOptions, "settingsFromSynthOptions");
    __name(parametersFromSynthOptions, "parametersFromSynthOptions");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/private/readable-assembly.ts
var import_node_fs4, ReadableCloudAssembly;
var init_readable_assembly = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/private/readable-assembly.ts"() {
    "use strict";
    import_node_fs4 = require("node:fs");
    ReadableCloudAssembly = class {
      constructor(cloudAssembly, lock, options) {
        this.cloudAssembly = cloudAssembly;
        this.lock = lock;
        this.options = options;
      }
      cloudAssembly;
      lock;
      options;
      static {
        __name(this, "ReadableCloudAssembly");
      }
      async _unlock() {
        return this.lock.release();
      }
      async dispose() {
        await this.lock.release();
        if (this.options?.deleteOnDispose) {
          await import_node_fs4.promises.rm(this.cloudAssembly.directory, { recursive: true, force: true });
        }
      }
      [Symbol.asyncDispose]() {
        return this.dispose();
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/source-builder.ts
var path30, import_util50, cxapi6, fs30, CloudAssemblySourceBuilder;
var init_source_builder = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/source-builder.ts"() {
    "use strict";
    path30 = __toESM(require("path"));
    import_util50 = require("util");
    cxapi6 = __toESM(require_lib3());
    fs30 = __toESM(require_lib4());
    init_context_store();
    init_rwlock();
    init_cached_source();
    init_context_aware_source();
    init_exec();
    init_prepare_source();
    init_readable_assembly();
    init_toolkit_error();
    init_util3();
    init_private();
    init_helpers();
    CloudAssemblySourceBuilder = class {
      static {
        __name(this, "CloudAssemblySourceBuilder");
      }
      /**
       * Create a Cloud Assembly from a Cloud Assembly builder function.
       *
       * ## Outdir
       *
       * If no output directory is given, it will synthesize into a temporary system
       * directory. The temporary directory will be cleaned up, unless
       * `disposeOutdir: false`.
       *
       * A write lock will be acquired on the output directory for the duration of
       * the CDK app synthesis (which means that no two apps can synthesize at the
       * same time), and after synthesis a read lock will be acquired on the
       * directory. This means that while the CloudAssembly is being used, no CDK
       * app synthesis can take place into that directory.
       *
       * ## Context
       *
       * If no `contextStore` is given, a `MemoryContext` will be used. This means
       * no provider lookups will be persisted anywhere by default. Use a different
       * type of context store if you want persistence between synth operations.
       *
       * @param builder - the builder function
       * @param props - additional configuration properties
       * @returns the CloudAssembly source
       */
      async fromAssemblyBuilder(builder, props = {}) {
        const services = await this.sourceBuilderServices();
        const contextStore = props.contextStore ?? new MemoryContext();
        const contextAssemblyProps = {
          services,
          contextStore,
          lookups: props.lookups
        };
        const outdir = props.outdir ? path30.resolve(props.outdir) : void 0;
        return new ContextAwareCloudAssemblySource(
          {
            produce: /* @__PURE__ */ __name(async () => {
              var _stack = [];
              try {
                const execution = __using(_stack, await ExecutionEnvironment.create(services, {
                  outdir,
                  resolveDefaultAppEnv: props.resolveDefaultEnvironment ?? true
                }), true);
                const synthParams = parametersFromSynthOptions(props.synthOptions);
                const fullContext = {
                  ...await contextStore.read(),
                  ...synthParams.context
                };
                await services.ioHelper.defaults.debug((0, import_util50.format)("context:", fullContext));
                const env3 = noUndefined({
                  // Versioning, outdir, default account and region
                  ...await execution.defaultEnvVars(),
                  // Environment variables derived from settings
                  ...synthParams.env
                });
                const cleanupContextTemp = writeContextToEnv(env3, fullContext, "env-is-complete");
                const _cleanupEnv = __using(_stack, props.clobberEnv ?? true ? temporarilyWriteEnv(env3) : void 0);
                let assembly;
                try {
                  assembly = await builder({
                    outdir: execution.outdir,
                    context: fullContext,
                    env: env3
                  });
                } catch (error4) {
                  if (ToolkitError.isToolkitError(error4)) {
                    throw error4;
                  }
                  throw AssemblyError.withCause("Assembly builder failed", error4);
                } finally {
                  await cleanupContextTemp();
                }
                const asm = cxapi6.CloudAssembly.isCloudAssembly(assembly) ? assembly : await assemblyFromDirectory(assembly.directory, services.ioHelper, props.loadAssemblyOptions);
                const success = await execution.markSuccessful();
                const deleteOnDispose = props.disposeOutdir ?? execution.shouldDisposeOutDir;
                return new ReadableCloudAssembly(asm, success.readLock, { deleteOnDispose });
              } catch (_) {
                var _error = _, _hasError = true;
              } finally {
                var _promise = __callDispose(_stack, _error, _hasError);
                _promise && await _promise;
              }
            }, "produce")
          },
          contextAssemblyProps
        );
      }
      /**
       * Creates a Cloud Assembly from an existing assembly directory.
       *
       * A read lock will be acquired for the directory. This means that while
       * the CloudAssembly is being used, no CDK app synthesis can take place into
       * that directory.
       *
       * @param directory - directory the directory of a already produced Cloud Assembly.
       * @returns the CloudAssembly source
       */
      async fromAssemblyDirectory(directory, props = {}) {
        const services = await this.sourceBuilderServices();
        return {
          async produce() {
            await services.ioHelper.notify(IO.CDK_ASSEMBLY_I0150.msg("--app points to a cloud assembly, so we bypass synth"));
            const readLock = await new RWLock(directory).acquireRead();
            try {
              const asm = await assemblyFromDirectory(directory, services.ioHelper, props.loadAssemblyOptions);
              const assembly = new ReadableCloudAssembly(asm, readLock, { deleteOnDispose: false });
              if (assembly.cloudAssembly.manifest.missing && assembly.cloudAssembly.manifest.missing.length > 0) {
                if (props.failOnMissingContext ?? true) {
                  const missingKeysSet = missingContextKeys(assembly.cloudAssembly.manifest.missing);
                  const missingKeys = Array.from(missingKeysSet);
                  throw AssemblyError.withCause(
                    `Assembly contains missing context. Make sure all necessary context is already in 'cdk.context.json' by running 'cdk synth' on a machine with sufficient AWS credentials and committing the result. Missing context keys: '${missingKeys.join(", ")}'`,
                    "Error producing assembly"
                  );
                }
              }
              return new CachedCloudAssembly(assembly);
            } catch (e32) {
              await readLock.release();
              throw e32;
            }
          }
        };
      }
      /**
       * Use an AWS CDK app exectuable as source.
       *
       * `app` is a command line that will be executed to produce a Cloud Assembly.
       * The command will be executed in a shell, so it must come from a trusted source.
       *
       * The subprocess will execute in `workingDirectory`, which defaults to
       * the current process' working directory if not given.
       *
       * ## Outdir
       *
       * If an output directory is supplied, relative paths are evaluated with
       * respect to the current process' working directory. If an output directory
       * is not supplied, the default is a `cdk.out` directory underneath
       * `workingDirectory`. The output directory will not be cleaned up unless
       * `disposeOutdir: true`.
       *
       * A write lock will be acquired on the output directory for the duration of
       * the CDK app synthesis (which means that no two apps can synthesize at the
       * same time), and after synthesis a read lock will be acquired on the
       * directory.  This means that while the CloudAssembly is being used, no CDK
       * app synthesis can take place into that directory.
       *
       * ## Context
       *
       * If no `contextStore` is given, a `CdkAppMultiContext` will be used, initialized
       * to the app's `workingDirectory`. This means that context will be loaded from
       * all the CDK's default context sources, and updates will be written to
       * `cdk.context.json`.
       *
       * @param props - additional configuration properties
       * @returns the CloudAssembly source
       */
      async fromCdkApp(app, props = {}) {
        const services = await this.sourceBuilderServices();
        const workingDirectory = props.workingDirectory ?? process.cwd();
        const outdir = props.outdir ? path30.resolve(props.outdir) : path30.resolve(workingDirectory, "cdk.out");
        const contextStore = props.contextStore ?? new CdkAppMultiContext(workingDirectory);
        const contextAssemblyProps = {
          services,
          contextStore,
          lookups: props.lookups
        };
        return new ContextAwareCloudAssemblySource(
          {
            produce: /* @__PURE__ */ __name(async () => {
              var _stack = [];
              try {
                try {
                  fs30.mkdirpSync(outdir);
                } catch (e32) {
                  throw new ToolkitError("OutputDirectoryCreateFailed", `Could not create output directory at '${outdir}' (${e32.message}).`);
                }
                const execution = __using(_stack, await ExecutionEnvironment.create(services, {
                  outdir,
                  resolveDefaultAppEnv: props.resolveDefaultEnvironment ?? true
                }), true);
                const commandLine = await execution.guessExecutable(app);
                const synthParams = parametersFromSynthOptions(props.synthOptions);
                const fullContext = {
                  ...await contextStore.read(),
                  ...synthParams.context
                };
                await services.ioHelper.defaults.debug((0, import_util50.format)("context:", fullContext));
                const env3 = noUndefined({
                  // Need to start with full env of `writeContextToEnv` will not be able to do the size
                  // calculation correctly.
                  ...process.env,
                  // User gave us something
                  ...props.env,
                  // Versioning, outdir, default account and region
                  ...await execution.defaultEnvVars(),
                  // Environment variables derived from settings
                  ...synthParams.env
                });
                const cleanupTemp = writeContextToEnv(env3, fullContext, "env-is-complete");
                try {
                  await execInChildProcess(commandLine, {
                    eventPublisher: /* @__PURE__ */ __name(async (type, line) => {
                      switch (type) {
                        case "data_stdout":
                          await services.ioHelper.notify(IO.CDK_ASSEMBLY_I1001.msg(line));
                          break;
                        case "data_stderr":
                          await services.ioHelper.notify(IO.CDK_ASSEMBLY_E1002.msg(line));
                          break;
                      }
                    }, "eventPublisher"),
                    env: env3,
                    cwd: workingDirectory
                  });
                } finally {
                  await cleanupTemp();
                }
                const asm = await assemblyFromDirectory(outdir, services.ioHelper, props.loadAssemblyOptions);
                const success = await execution.markSuccessful();
                const deleteOnDispose = props.disposeOutdir ?? execution.shouldDisposeOutDir;
                return new ReadableCloudAssembly(asm, success.readLock, { deleteOnDispose });
              } catch (_) {
                var _error = _, _hasError = true;
              } finally {
                var _promise = __callDispose(_stack, _error, _hasError);
                _promise && await _promise;
              }
            }, "produce")
          },
          contextAssemblyProps
        );
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/types.ts
var init_types12 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/types.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/index.ts
var cloud_assembly_exports3 = {};
__export(cloud_assembly_exports3, {
  CachedCloudAssembly: () => CachedCloudAssembly,
  CdkAppMultiContext: () => CdkAppMultiContext,
  CloudAssemblySourceBuilder: () => CloudAssemblySourceBuilder,
  ExpandStackSelection: () => ExpandStackSelection,
  FileContext: () => FileContext,
  MemoryContext: () => MemoryContext,
  StackSelectionStrategy: () => StackSelectionStrategy,
  persistableContext: () => persistableContext
});
var init_cloud_assembly3 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/index.ts"() {
    "use strict";
    init_stack_selector();
    init_cached_source();
    init_source_builder();
    init_types12();
    init_context_store();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/stack-collection.ts
var import_cloud_assembly_api12, StackCollection;
var init_stack_collection = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/stack-collection.ts"() {
    "use strict";
    import_cloud_assembly_api12 = __toESM(require_lib3());
    init_toolkit_error();
    StackCollection = class _StackCollection {
      constructor(assembly, stackArtifacts) {
        this.assembly = assembly;
        this.stackArtifacts = stackArtifacts;
      }
      assembly;
      stackArtifacts;
      static {
        __name(this, "StackCollection");
      }
      get stackCount() {
        return this.stackArtifacts.length;
      }
      get firstStack() {
        if (this.stackCount < 1) {
          throw new ToolkitError("EmptyStackCollection", "StackCollection contains no stack artifacts (trying to access the first one)");
        }
        return this.stackArtifacts[0];
      }
      get stackIds() {
        return this.stackArtifacts.map((s) => s.id);
      }
      get hierarchicalIds() {
        return this.stackArtifacts.map((s) => s.hierarchicalId);
      }
      withDependencies() {
        const allData = [];
        for (const stack of this.stackArtifacts) {
          const data3 = {
            id: stack.displayName ?? stack.id,
            name: stack.stackName,
            environment: stack.environment,
            // Might be huge so load it lazily
            get metadata() {
              return stack.metadata;
            },
            dependencies: []
          };
          for (const dependencyId of stack.dependencies.map((x) => x.id)) {
            if (dependencyId.includes(".assets")) {
              continue;
            }
            const depStack = this.assembly.stackById(dependencyId);
            if (depStack.firstStack.dependencies.filter((dep) => !dep.id.includes(".assets")).length > 0) {
              for (const stackDetail of depStack.withDependencies()) {
                data3.dependencies.push({
                  id: stackDetail.id,
                  dependencies: stackDetail.dependencies
                });
              }
            } else {
              data3.dependencies.push({
                id: depStack.firstStack.displayName ?? depStack.firstStack.id,
                dependencies: []
              });
            }
          }
          allData.push(data3);
        }
        return allData;
      }
      reversed() {
        const arts = [...this.stackArtifacts];
        arts.reverse();
        return new _StackCollection(this.assembly, arts);
      }
      filter(predicate) {
        return new _StackCollection(this.assembly, this.stackArtifacts.filter(predicate));
      }
      concat(...others) {
        return new _StackCollection(this.assembly, this.stackArtifacts.concat(...others.map((o10) => o10.stackArtifacts)));
      }
      /**
       * Extracts 'aws:cdk:warning|info|error' metadata entries from the stack synthesis
       *
       * @deprecated The formatting of this function is lackluster. Use `throwIfValidationFailures()` instead.
       */
      async validateMetadata(failAt = "error", logger5 = async () => {
      }) {
        let warnings = false;
        let errors = false;
        for (const stack of this.stackArtifacts) {
          for (const message2 of stack.messages) {
            switch (message2.level) {
              case import_cloud_assembly_api12.SynthesisMessageLevel.WARNING:
                warnings = true;
                await logger5("warn", message2);
                break;
              case import_cloud_assembly_api12.SynthesisMessageLevel.ERROR:
                errors = true;
                await logger5("error", message2);
                break;
              case import_cloud_assembly_api12.SynthesisMessageLevel.INFO:
                await logger5("info", message2);
                break;
            }
          }
        }
        if (errors && failAt != "none") {
          const error4 = AssemblyError.withStacks("Found errors", this.stackArtifacts);
          error4.attachSynthesisErrorCode("AnnotationErrors");
          throw error4;
        }
        if (warnings && failAt === "warn") {
          const error4 = AssemblyError.withStacks("Found warnings (--strict mode)", this.stackArtifacts);
          error4.attachSynthesisErrorCode("StrictAnnotationWarnings");
          throw error4;
        }
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/stack-assembly.ts
function indexByHierarchicalId(stacks) {
  const result2 = /* @__PURE__ */ new Map();
  for (const stack of stacks) {
    result2.set(stack.hierarchicalId, stack);
  }
  return result2;
}
async function includeDownstreamStacks(ioHelper, selectedStacks, allStacks) {
  const added = new Array();
  let madeProgress;
  do {
    madeProgress = false;
    for (const [id, stack] of allStacks) {
      if (!selectedStacks.has(id) && (stack.dependencies || []).some((dep) => selectedStacks.has(dep.id))) {
        selectedStacks.set(id, stack);
        added.push(id);
        madeProgress = true;
      }
    }
  } while (madeProgress);
  if (added.length > 0) {
    await ioHelper.defaults.info(`Including depending stacks: ${chalk13.bold(added.join(", "))}`);
  }
}
async function includeUpstreamStacks(ioHelper, selectedStacks, allStacks) {
  const added = new Array();
  let madeProgress = true;
  while (madeProgress) {
    madeProgress = false;
    for (const stack of selectedStacks.values()) {
      for (const dependencyId of stack.dependencies.map((x) => x.manifest.displayName ?? x.id)) {
        if (!selectedStacks.has(dependencyId) && allStacks.has(dependencyId)) {
          added.push(dependencyId);
          selectedStacks.set(dependencyId, allStacks.get(dependencyId));
          madeProgress = true;
        }
      }
    }
  }
  if (added.length > 0) {
    await ioHelper.defaults.info(`Including dependency stacks: ${chalk13.bold(added.join(", "))}`);
  }
}
var chalk13, import_picomatch, ExtendedStackSelection, BaseStackAssembly;
var init_stack_assembly = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/stack-assembly.ts"() {
    "use strict";
    chalk13 = __toESM(require_source());
    import_picomatch = __toESM(require_picomatch4());
    init_stack_collection();
    init_util3();
    ExtendedStackSelection = /* @__PURE__ */ ((ExtendedStackSelection2) => {
      ExtendedStackSelection2[ExtendedStackSelection2["None"] = 0] = "None";
      ExtendedStackSelection2[ExtendedStackSelection2["Upstream"] = 1] = "Upstream";
      ExtendedStackSelection2[ExtendedStackSelection2["Downstream"] = 2] = "Downstream";
      return ExtendedStackSelection2;
    })(ExtendedStackSelection || {});
    BaseStackAssembly = class {
      constructor(assembly, ioHelper) {
        this.assembly = assembly;
        this.directory = assembly.directory;
        this.ioHelper = ioHelper;
      }
      assembly;
      static {
        __name(this, "BaseStackAssembly");
      }
      /**
       * Sanitize a list of stack match patterns
       */
      static sanitizePatterns(patterns) {
        let sanitized = patterns.filter((s) => s != null);
        sanitized = [...new Set(sanitized)];
        return sanitized;
      }
      /**
       * The directory this CloudAssembly was read from
       */
      directory;
      /**
       * The IoHelper used for messaging
       */
      ioHelper;
      /**
       * Select a single stack by its ID
       */
      stackById(stackId) {
        return new StackCollection(this, [this.assembly.getStackArtifact(stackId)]);
      }
      async selectMatchingStacks(stacks, patterns, extend = 0 /* None */) {
        const matchingPattern = /* @__PURE__ */ __name((pattern) => (stack) => (0, import_picomatch.isMatch)(stack.hierarchicalId, pattern), "matchingPattern");
        const matchedStacks = flatten2(patterns.map((pattern) => stacks.filter(matchingPattern(pattern))));
        return this.extendStacks(matchedStacks, stacks, extend);
      }
      async extendStacks(matched, all, extend = 0 /* None */) {
        const allStacks = /* @__PURE__ */ new Map();
        for (const stack of all) {
          allStacks.set(stack.hierarchicalId, stack);
        }
        const index = indexByHierarchicalId(matched);
        switch (extend) {
          case 2 /* Downstream */:
            await includeDownstreamStacks(this.ioHelper, index, allStacks);
            break;
          case 1 /* Upstream */:
            await includeUpstreamStacks(this.ioHelper, index, allStacks);
            break;
        }
        const selectedList = all.filter((s) => index.has(s.hierarchicalId));
        return new StackCollection(this, selectedList);
      }
    };
    __name(indexByHierarchicalId, "indexByHierarchicalId");
    __name(includeDownstreamStacks, "includeDownstreamStacks");
    __name(includeUpstreamStacks, "includeUpstreamStacks");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/private/stack-assembly.ts
function expandToExtendEnum(extend) {
  switch (extend) {
    case "downstream" /* DOWNSTREAM */:
      return 2 /* Downstream */;
    case "upstream" /* UPSTREAM */:
      return 1 /* Upstream */;
    case "none" /* NONE */:
      return 0 /* None */;
    default:
      return void 0;
  }
}
var import_dispose_polyfill6, import_semver2, StackAssembly;
var init_stack_assembly2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/private/stack-assembly.ts"() {
    "use strict";
    import_dispose_polyfill6 = __toESM(require_dispose_polyfill());
    import_semver2 = __toESM(require_semver4());
    init_toolkit_error();
    init_stack_assembly();
    init_stack_collection();
    init_stack_selector();
    StackAssembly = class _StackAssembly extends BaseStackAssembly {
      constructor(_asm, ioHelper) {
        super(_asm.cloudAssembly, ioHelper);
        this._asm = _asm;
      }
      _asm;
      static {
        __name(this, "StackAssembly");
      }
      get cloudAssembly() {
        return this._asm.cloudAssembly;
      }
      async _unlock() {
        return this._asm._unlock();
      }
      async dispose() {
        return this._asm.dispose();
      }
      async [Symbol.asyncDispose]() {
        return this.dispose();
      }
      /**
       * Improved stack selection interface with a single selector
       * @throws when the assembly does not contain any stacks, unless `selector.failOnEmpty` is `false`
       * @throws when individual selection strategies are not satisfied
       */
      async selectStacksV2(selector) {
        const asm = this.assembly;
        const topLevelStacks = asm.stacks;
        const allStacks = (0, import_semver2.major)(asm.version) < 10 ? asm.stacks : asm.stacksRecursively;
        if (allStacks.length === 0 && (selector.failOnEmpty ?? true)) {
          throw new ToolkitError("NoStacksInApp", "This app contains no stacks");
        }
        const extend = expandToExtendEnum(selector.expand);
        const patterns = _StackAssembly.sanitizePatterns(selector.patterns ?? []);
        switch (selector.strategy) {
          case "all-stacks" /* ALL_STACKS */:
            return new StackCollection(this, allStacks);
          case "main-assembly" /* MAIN_ASSEMBLY */:
            if (topLevelStacks.length < 1) {
              throw new ToolkitError("NoStackInMainAssembly", 'No stack found in the main cloud assembly. Use "list" to print manifest');
            }
            return this.extendStacks(topLevelStacks, allStacks, extend);
          case "only-single" /* ONLY_SINGLE */:
            if (topLevelStacks.length !== 1) {
              throw new ToolkitError("MultipleStacksWithoutSelector", `Since this app includes more than a single stack, specify which stacks to use (wildcards are supported) or specify \`--all\`
Stacks: ${allStacks.map((x) => x.hierarchicalId).join(" \xB7 ")}`);
            }
            return new StackCollection(this, topLevelStacks);
          default:
            const matched = await this.selectMatchingStacks(allStacks, patterns, extend);
            if (selector.strategy === "pattern-must-match-single" /* PATTERN_MUST_MATCH_SINGLE */ && matched.stackCount !== 1) {
              throw new ToolkitError(
                "AmbiguousStackSelection",
                `Stack selection is ambiguous, please choose a specific stack for import [${allStacks.map((x) => x.hierarchicalId).join(",")}]`
              );
            }
            if (selector.strategy === "pattern-must-match" /* PATTERN_MUST_MATCH */ && matched.stackCount < 1) {
              throw new ToolkitError(
                "NoStacksMatched",
                `Stack selection is ambiguous, please choose a specific stack for import [${allStacks.map((x) => x.hierarchicalId).join(",")}]`
              );
            }
            return matched;
        }
      }
      /**
       * Select all stacks.
       *
       * This method never throws and can safely be used as a basis for other calculations.
       *
       * @returns a `StackCollection` of all stacks
       */
      selectAllStacks() {
        const allStacks = (0, import_semver2.major)(this.assembly.version) < 10 ? this.assembly.stacks : this.assembly.stacksRecursively;
        return new StackCollection(this, allStacks);
      }
      /**
       * Select all stacks that have the validateOnSynth flag et.
       *
       * @returns a `StackCollection` of all stacks that needs to be validated
       */
      selectStacksForValidation() {
        const allStacks = this.selectAllStacks();
        return allStacks.filter((art) => art.validateOnSynth ?? false);
      }
    };
    __name(expandToExtendEnum, "expandToExtendEnum");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/private/stack-selectors.ts
var ALL_STACKS;
var init_stack_selectors = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/private/stack-selectors.ts"() {
    "use strict";
    init_stack_selector();
    ALL_STACKS = {
      strategy: "all-stacks" /* ALL_STACKS */
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/private/index.ts
var init_private3 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/cloud-assembly/private/index.ts"() {
    "use strict";
    init_context_aware_source();
    init_stack_assembly2();
    init_exec();
    init_prepare_source();
    init_stack_selectors();
  }
});

// lib/api/cloud-assembly.ts
var init_cloud_assembly4 = __esm({
  "lib/api/cloud-assembly.ts"() {
    "use strict";
    init_cloud_assembly3();
    init_private3();
    init_environment3();
    init_stack_collection();
    init_stack_assembly();
  }
});

// lib/api/deployments.ts
var init_deployments3 = __esm({
  "lib/api/deployments.ts"() {
    "use strict";
    init_deployments2();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/aws-auth/types.ts
var init_types13 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/aws-auth/types.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/aws-auth/base-credentials.ts
var BaseCredentials;
var init_base_credentials = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/aws-auth/base-credentials.ts"() {
    "use strict";
    init_awscli_compatible();
    init_toolkit_error();
    init_sdk_logger();
    init_private();
    BaseCredentials = class {
      static {
        __name(this, "BaseCredentials");
      }
      /**
       * Use no base credentials
       *
       * There will be no current account and no current region during synthesis. To
       * successfully deploy with this set of base credentials:
       *
       * - The CDK app must provide concrete accounts and regions during synthesis
       * - Credential plugins must be installed to provide credentials for those
       *   accounts.
       */
      static none() {
        return new class {
          async sdkBaseConfig() {
            return {
              credentialProvider: /* @__PURE__ */ __name(() => {
                throw new AuthenticationError("NoBaseCredentials", "No credentials available due to BaseCredentials.none()");
              }, "credentialProvider")
            };
          }
          toString() {
            return "BaseCredentials.none()";
          }
        }();
      }
      /**
       * Obtain base credentials and base region the same way the AWS CLI would
       *
       * Credentials and region will be read from the environment first, falling back
       * to INI files or other sources if available.
       *
       * The profile name is configurable.
       */
      static awsCliCompatible(options = {}) {
        return new class {
          async sdkBaseConfig(ioHost, clientConfig) {
            const ioHelper = IoHelper.fromActionAwareIoHost(ioHost);
            const awsCli = new AwsCliCompatible(ioHelper, clientConfig.requestHandler ?? {}, new IoHostSdkLogger(ioHelper));
            const ret = await awsCli.baseConfig(options.profile);
            return options.defaultRegion ? { ...ret, defaultRegion: options.defaultRegion } : ret;
          }
          toString() {
            return `BaseCredentials.awsCliCompatible(${JSON.stringify(options)})`;
          }
        }();
      }
      /**
       * Use a custom SDK identity provider for the base credentials
       *
       * If your provider uses STS calls to obtain base credentials, you must make
       * sure to also configure the necessary HTTP options (like proxy and user
       * agent) and the region on the STS client directly; the toolkit code cannot
       * do this for you.
       */
      static custom(options) {
        return new class {
          sdkBaseConfig() {
            return Promise.resolve({
              credentialProvider: options.provider,
              defaultRegion: options.region
            });
          }
          toString() {
            return `BaseCredentials.custom(${JSON.stringify({
              ...options,
              provider: "..."
            })})`;
          }
        }();
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/aws-auth/index.ts
var aws_auth_exports = {};
__export(aws_auth_exports, {
  BaseCredentials: () => BaseCredentials
});
var init_aws_auth = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/aws-auth/index.ts"() {
    "use strict";
    init_types13();
    init_base_credentials();
  }
});

// lib/api/aws-auth.ts
var init_aws_auth2 = __esm({
  "lib/api/aws-auth.ts"() {
    "use strict";
    init_aws_auth();
    init_private2();
    init_awscli_compatible();
  }
});

// lib/api/notices.ts
var init_notices3 = __esm({
  "lib/api/notices.ts"() {
    "use strict";
    init_notices2();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/streams.ts
var import_node_stream28, StringWriteStream;
var init_streams = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/streams.ts"() {
    "use strict";
    import_node_stream28 = require("node:stream");
    StringWriteStream = class extends import_node_stream28.Writable {
      static {
        __name(this, "StringWriteStream");
      }
      buffer = [];
      /**
       * Terminal width in columns.
       * Used by formatTable() to apply width constraints and prevent table overflow.
       */
      get columns() {
        return process.stdout.columns;
      }
      constructor() {
        super();
      }
      _write(chunk, _encoding, callback) {
        this.buffer.push(chunk.toString());
        callback();
      }
      toString() {
        return this.buffer.join("");
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/diff/diff-formatter.ts
function permissionTypeFromDiff(diff) {
  if (diff.permissionsBroadened) {
    return "broadening" /* BROADENING */;
  } else if (diff.permissionsAnyChanges) {
    return "non-broadening" /* NON_BROADENING */;
  }
  return "none" /* NONE */;
}
function logicalIdMapFromTemplate(template) {
  const ret = {};
  for (const [logicalId, resource] of Object.entries(template.Resources ?? {})) {
    const path47 = resource?.Metadata?.["aws:cdk:path"];
    if (path47) {
      ret[logicalId] = path47;
    }
  }
  return ret;
}
function obscureDiff(diff) {
  if (diff.unknown) {
    diff.unknown = diff.unknown.filter((change) => {
      if (!change) {
        return true;
      }
      if (change.newValue?.CheckBootstrapVersion) {
        return false;
      }
      if (change.oldValue?.CheckBootstrapVersion) {
        return false;
      }
      return true;
    });
  }
  if (diff.resources) {
    diff.resources = diff.resources.filter((change) => {
      if (!change) {
        return true;
      }
      if (change.newResourceType === "AWS::CDK::Metadata") {
        return false;
      }
      if (change.oldResourceType === "AWS::CDK::Metadata") {
        return false;
      }
      return true;
    });
  }
}
var import_node_util5, import_cloudformation_diff, chalk14, DiffFormatter;
var init_diff_formatter = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/diff/diff-formatter.ts"() {
    "use strict";
    import_node_util5 = require("node:util");
    import_cloudformation_diff = __toESM(require_lib9());
    chalk14 = __toESM(require_source());
    init_payloads();
    init_logical_id_map();
    init_streams();
    DiffFormatter = class {
      static {
        __name(this, "DiffFormatter");
      }
      templateInfo;
      stackName;
      isImport;
      mappings;
      /**
       * Cache of computed TemplateDiffs, indexed by stack name.
       */
      cache = /* @__PURE__ */ new Map();
      constructor(props) {
        this.templateInfo = props.templateInfo;
        this.stackName = props.templateInfo.newTemplate.displayName ?? props.templateInfo.newTemplate.stackName;
        this.isImport = props.templateInfo.isImport ?? false;
        this.mappings = props.templateInfo.mappings ?? {};
      }
      get diffs() {
        return Object.fromEntries(this.cache);
      }
      /**
       * Compute the diff for a single stack. Results are cached by stack name.
       *
       * @param stackName - The name to cache the diff under
       * @param oldTemplate - The deployed template
       * @param newTemplate - The new/generated template (read from the artifact)
       * @param changeSet - The CloudFormation changeset for this specific stack, if available
       * @param mappings - Resource move mappings
       */
      computeDiff(stackName, oldTemplate, newTemplate, changeSet, mappings) {
        if (!this.cache.has(stackName)) {
          const templateDiff = (0, import_cloudformation_diff.fullDiff)(oldTemplate, newTemplate, changeSet, this.isImport);
          const setMove = /* @__PURE__ */ __name((change, direction, location) => {
            if (location != null) {
              const [sourceStackName, sourceLogicalId] = location.split(".");
              change.move = {
                direction,
                stackName: sourceStackName,
                resourceLogicalId: sourceLogicalId
              };
            }
          }, "setMove");
          templateDiff.resources.forEachDifference((id, change) => {
            const location = `${stackName}.${id}`;
            if (change.isAddition && Object.values(mappings).includes(location)) {
              setMove(change, "from", Object.keys(mappings).find((k32) => mappings[k32] === location));
            } else if (change.isRemoval && Object.keys(mappings).includes(location)) {
              setMove(change, "to", mappings[location]);
            }
          });
          this.cache.set(stackName, templateDiff);
        }
        return this.cache.get(stackName);
      }
      /**
       * Format the stack diff, including all nested stacks.
       */
      formatStackDiff(options = {}) {
        return this.formatStackDiffHelper({
          oldTemplate: this.templateInfo.oldTemplate,
          newTemplate: this.templateInfo.newTemplate.template,
          stackName: this.stackName,
          nestedStacks: this.templateInfo.nestedStacks,
          changeSet: this.templateInfo.changeSet,
          mappings: this.mappings,
          logicalIdMap: buildLogicalToPathMap(this.templateInfo.newTemplate).toPath
        }, options);
      }
      formatStackDiffHelper(params, options = {}) {
        const { oldTemplate, newTemplate, stackName, nestedStacks, changeSet, mappings, logicalIdMap } = params;
        const diff = this.computeDiff(stackName, oldTemplate, newTemplate, changeSet, mappings);
        const stream = new StringWriteStream();
        let numStacksWithChanges = 0;
        let formattedDiff = "";
        let filteredChangesCount = 0;
        try {
          if (stackName && (!options.quiet || !diff.isEmpty)) {
            stream.write((0, import_node_util5.format)(`Stack ${chalk14.bold(stackName)}
`));
          }
          if (!options.quiet && this.isImport) {
            stream.write("Parameters and rules created during migration do not affect resource configuration.\n");
          }
          let activeDiff = diff;
          if (diff.differenceCount && !options.strict) {
            const mangledNewTemplate = JSON.parse((0, import_cloudformation_diff.mangleLikeCloudFormation)(JSON.stringify(newTemplate)));
            const mangledDiff = (0, import_cloudformation_diff.fullDiff)(oldTemplate, mangledNewTemplate, changeSet);
            filteredChangesCount = Math.max(0, diff.differenceCount - mangledDiff.differenceCount);
            if (filteredChangesCount > 0) {
              activeDiff = mangledDiff;
            }
          }
          const diffWasNonEmpty = !activeDiff.isEmpty;
          if (!options.strict) {
            obscureDiff(activeDiff);
          }
          const metadataWasFiltered = diffWasNonEmpty && activeDiff.isEmpty;
          if (!activeDiff.isEmpty) {
            numStacksWithChanges++;
            (0, import_cloudformation_diff.formatDifferences)(stream, activeDiff, {
              ...logicalIdMapFromTemplate(oldTemplate),
              ...logicalIdMapFromTemplate(newTemplate),
              ...logicalIdMap
            }, options.contextLines);
          } else if (!options.quiet) {
            const hint = metadataWasFiltered ? chalk14.grey(" (CDK metadata changes were hidden, run cdk diff --strict to show)") : "";
            stream.write(`${chalk14.green("There were no differences")}${hint}
`);
          }
          if (filteredChangesCount > 0) {
            stream.write(chalk14.yellow(`Omitted ${filteredChangesCount} changes because they are likely mangled non-ASCII characters. Use --strict to print them.
`));
          }
        } finally {
          formattedDiff = stream.toString();
          stream.end();
        }
        for (const [logicalId, nestedStack] of Object.entries(nestedStacks ?? {})) {
          const nextDiff = this.formatStackDiffHelper({
            oldTemplate: nestedStack.deployedTemplate,
            newTemplate: nestedStack.generatedTemplate,
            stackName: nestedStack.physicalName ?? logicalId,
            nestedStacks: nestedStack.nestedStackTemplates,
            changeSet: nestedStack.changeSet,
            mappings,
            logicalIdMap: {}
          }, options);
          numStacksWithChanges += nextDiff.numStacksWithChanges;
          formattedDiff += nextDiff.formattedDiff;
        }
        return { numStacksWithChanges, formattedDiff };
      }
      /**
       * Format the security diff, including all nested stacks.
       */
      formatSecurityDiff(options = {}) {
        const { formattedDiff, permissionChangeType, numStacksWithChanges } = this.formatSecurityDiffHelper({
          oldTemplate: this.templateInfo.oldTemplate,
          newTemplate: this.templateInfo.newTemplate.template,
          stackName: this.stackName,
          nestedStacks: this.templateInfo.nestedStacks,
          changeSet: this.templateInfo.changeSet,
          logicalIdMap: buildLogicalToPathMap(this.templateInfo.newTemplate).toPath
        }, options);
        return { formattedDiff, permissionChangeType, numStacksWithChanges };
      }
      formatSecurityDiffHelper(params, options = {}) {
        const { oldTemplate, newTemplate, stackName, nestedStacks, changeSet, logicalIdMap } = params;
        const diff = this.computeDiff(stackName, oldTemplate, newTemplate, changeSet, this.mappings);
        const permissionChangeType = permissionTypeFromDiff(diff);
        const stream = new StringWriteStream();
        if (!options.quiet || permissionChangeType !== "none" /* NONE */) {
          stream.write((0, import_node_util5.format)(`Stack ${chalk14.bold(stackName)}
`));
        }
        try {
          (0, import_cloudformation_diff.formatSecurityChanges)(stream, diff, {
            ...logicalIdMapFromTemplate(newTemplate),
            ...logicalIdMap
          });
        } finally {
          stream.end();
        }
        let formattedDiff = stream.toString();
        if (!options.quiet && permissionChangeType === "none" /* NONE */) {
          formattedDiff += chalk14.green("There were no security-related changes (limitations: https://github.com/aws/aws-cdk/issues/1299)\n");
        }
        let numStacksWithChanges = permissionChangeType !== "none" /* NONE */ ? 1 : 0;
        let escalatedPermissionType = permissionChangeType;
        for (const [logicalId, nestedStack] of Object.entries(nestedStacks ?? {})) {
          const nestedResult = this.formatSecurityDiffHelper({
            oldTemplate: nestedStack.deployedTemplate,
            newTemplate: nestedStack.generatedTemplate,
            stackName: nestedStack.physicalName ?? logicalId,
            nestedStacks: nestedStack.nestedStackTemplates,
            changeSet: nestedStack.changeSet
          }, options);
          formattedDiff += nestedResult.formattedDiff ? "\n" + nestedResult.formattedDiff : "";
          numStacksWithChanges += nestedResult.numStacksWithChanges;
          if (nestedResult.permissionChangeType === "broadening" /* BROADENING */) {
            escalatedPermissionType = "broadening" /* BROADENING */;
          } else if (nestedResult.permissionChangeType === "non-broadening" /* NON_BROADENING */ && escalatedPermissionType === "none" /* NONE */) {
            escalatedPermissionType = "non-broadening" /* NON_BROADENING */;
          }
        }
        return { formattedDiff, permissionChangeType: escalatedPermissionType, numStacksWithChanges };
      }
    };
    __name(permissionTypeFromDiff, "permissionTypeFromDiff");
    __name(logicalIdMapFromTemplate, "logicalIdMapFromTemplate");
    __name(obscureDiff, "obscureDiff");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/diff/index.ts
var init_diff3 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/diff/index.ts"() {
    "use strict";
    init_diff_formatter();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/io/io-host.ts
var init_io_host = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/io/io-host.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/io/io-message.ts
var init_io_message = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/io/io-message.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/io/toolkit-action.ts
var init_toolkit_action = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/io/toolkit-action.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/io/index.ts
var io_exports = {};
var init_io = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/io/index.ts"() {
    "use strict";
    init_io_host();
    init_io_message();
    init_toolkit_action();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/logs-monitor/logs-monitor.ts
var import_node_crypto16, util6, chalk15, CloudWatchLogEventMonitor;
var init_logs_monitor2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/logs-monitor/logs-monitor.ts"() {
    "use strict";
    import_node_crypto16 = require("node:crypto");
    util6 = __toESM(require("node:util"));
    chalk15 = __toESM(require_source());
    init_util3();
    init_private();
    CloudWatchLogEventMonitor = class {
      static {
        __name(this, "CloudWatchLogEventMonitor");
      }
      /**
       * Determines which events not to display
       */
      startTime;
      /**
       * Map of environment (account:region) to LogGroupsAccessSettings
       */
      envsLogGroupsAccessSettings = /* @__PURE__ */ new Map();
      /**
       * After reading events from all CloudWatch log groups
       * how long should we wait to read more events.
       *
       * If there is some error with reading events (i.e. Throttle)
       * then this is also how long we wait until we try again
       */
      pollingInterval = 2e3;
      monitorId;
      ioHelper;
      currentTick;
      constructor(props) {
        this.startTime = props.startTime?.getTime() ?? Date.now();
        this.ioHelper = props.ioHelper;
      }
      /**
       * resume reading/printing events
       */
      async activate() {
        this.monitorId = (0, import_node_crypto16.randomUUID)();
        await this.ioHelper.notify(IO.CDK_TOOLKIT_I5032.msg("Start monitoring log groups", {
          monitor: this.monitorId,
          logGroupNames: this.logGroupNames()
        }));
        await this.tick();
      }
      /**
       * deactivates the monitor so no new events are read
       * use case for this is when we are in the middle of performing a deployment
       * and don't want to interweave all the logs together with the CFN
       * deployment logs
       *
       * Also resets the start time to be when the new deployment was triggered
       * and clears the list of tracked log groups
       */
      async deactivate() {
        const oldMonitorId = this.monitorId;
        this.monitorId = void 0;
        this.startTime = Date.now();
        clearTimeout(this.currentTick);
        await this.ioHelper.notify(IO.CDK_TOOLKIT_I5034.msg("Stopped monitoring log groups", {
          monitor: oldMonitorId,
          logGroupNames: this.logGroupNames()
        }));
        this.envsLogGroupsAccessSettings.clear();
      }
      /**
       * Adds CloudWatch log groups to read log events from.
       * Since we could be watching multiple stacks that deploy to
       * multiple environments (account+region), we need to store a list of log groups
       * per env along with the SDK object that has access to read from
       * that environment.
       */
      addLogGroups(env3, sdk, logGroupNames) {
        const awsEnv = `${env3.account}:${env3.region}`;
        const logGroupsStartTimes = logGroupNames.reduce(
          (acc, groupName) => {
            acc[groupName] = this.startTime;
            return acc;
          },
          {}
        );
        this.envsLogGroupsAccessSettings.set(awsEnv, {
          sdk,
          logGroupsStartTimes: {
            ...this.envsLogGroupsAccessSettings.get(awsEnv)?.logGroupsStartTimes,
            ...logGroupsStartTimes
          }
        });
      }
      logGroupNames() {
        return Array.from(this.envsLogGroupsAccessSettings.values()).flatMap((settings) => Object.keys(settings.logGroupsStartTimes));
      }
      scheduleNextTick() {
        if (!this.monitorId) {
          return;
        }
        this.currentTick = setTimeout(() => void this.tick(), this.pollingInterval);
      }
      async tick() {
        if (!this.monitorId) {
          return;
        }
        try {
          const events = flatten2(await this.readNewEvents());
          for (const event of events) {
            await this.print(event);
          }
          if (!this.monitorId) {
            return;
          }
        } catch (e32) {
          await this.ioHelper.notify(IO.CDK_TOOLKIT_E5035.msg(`Error occurred while monitoring logs: ${String(e32)}`, { error: e32 }));
        }
        this.scheduleNextTick();
      }
      /**
       * Reads all new log events from a set of CloudWatch Log Groups
       * in parallel
       */
      async readNewEvents() {
        const promises5 = [];
        for (const settings of this.envsLogGroupsAccessSettings.values()) {
          for (const group7 of Object.keys(settings.logGroupsStartTimes)) {
            promises5.push(this.readEventsFromLogGroup(settings, group7));
          }
        }
        return Promise.all(promises5);
      }
      /**
       * Print out a cloudwatch event
       */
      async print(event) {
        await this.ioHelper.notify(IO.CDK_TOOLKIT_I5033.msg(
          util6.format(
            "[%s] %s %s",
            chalk15.blue(event.logGroupName),
            chalk15.yellow(event.timestamp.toLocaleTimeString()),
            event.message.trim()
          ),
          event
        ));
      }
      /**
       * Reads all new log events from a CloudWatch Log Group
       * starting at either the time the hotswap was triggered or
       * when the last event was read on the previous tick
       */
      async readEventsFromLogGroup(logGroupsAccessSettings, logGroupName) {
        const events = [];
        const startTime = logGroupsAccessSettings.logGroupsStartTimes[logGroupName] ?? this.startTime;
        let endTime = startTime;
        try {
          const response = await logGroupsAccessSettings.sdk.cloudWatchLogs().filterLogEvents({
            logGroupName,
            limit: 100,
            startTime
          });
          const filteredEvents = response.events ?? [];
          for (const event of filteredEvents) {
            if (event.message) {
              events.push({
                message: event.message,
                logGroupName,
                timestamp: event.timestamp ? new Date(event.timestamp) : /* @__PURE__ */ new Date()
              });
              if (event.timestamp && endTime < event.timestamp) {
                endTime = event.timestamp;
              }
            }
          }
          if (filteredEvents.length === 100 && response.nextToken) {
            events.push({
              message: ">>> `watch` shows only the first 100 log messages - the rest have been truncated...",
              logGroupName,
              timestamp: new Date(endTime)
            });
          }
        } catch (e32) {
          if (e32.name === "ResourceNotFoundException") {
            return [];
          }
          throw e32;
        }
        logGroupsAccessSettings.logGroupsStartTimes[logGroupName] = endTime + 1;
        return events;
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/logs-monitor/find-cloudwatch-logs.ts
async function findCloudWatchLogGroups(sdkProvider, ioHelper, stackArtifact) {
  let sdk;
  const resolvedEnv = await sdkProvider.resolveEnvironment(stackArtifact.environment);
  try {
    sdk = (await new EnvironmentAccess(sdkProvider, DEFAULT_TOOLKIT_STACK_NAME, ioHelper).accessStackForLookup(stackArtifact)).sdk;
  } catch (e32) {
    await ioHelper.defaults.debug(`Failed to access SDK environment: ${formatErrorMessage(e32)}`);
    sdk = (await sdkProvider.forEnvironment(resolvedEnv, 0 /* ForReading */)).sdk;
  }
  const listStackResources = new LazyListStackResources(sdk, stackArtifact.stackName);
  const evaluateCfnTemplate = new EvaluateCloudFormationTemplate({
    stackArtifact,
    parameters: {},
    account: resolvedEnv.account,
    region: resolvedEnv.region,
    partition: (await sdk.currentAccount()).partition,
    sdk
  });
  const stackResources = await listStackResources.listStackResources();
  const logGroupNames = findAllLogGroupNames(stackResources, evaluateCfnTemplate);
  return {
    env: resolvedEnv,
    sdk,
    logGroupNames
  };
}
function isReferencedFromIgnoredResource(logGroupResource, evaluateCfnTemplate) {
  const resourcesReferencingLogGroup = evaluateCfnTemplate.findReferencesTo(logGroupResource.LogicalResourceId);
  return resourcesReferencingLogGroup.some((reference) => {
    return IGNORE_LOGS_RESOURCE_TYPES.includes(reference.Type);
  });
}
function findAllLogGroupNames(stackResources, evaluateCfnTemplate) {
  const logGroupNames = [];
  for (const resource of stackResources) {
    const logGroupResolver = cloudWatchLogsResolvers[resource.ResourceType];
    if (logGroupResolver) {
      const logGroupName = logGroupResolver(resource, evaluateCfnTemplate);
      if (logGroupName) {
        logGroupNames.push(logGroupName);
      }
    }
  }
  return logGroupNames;
}
var IGNORE_LOGS_RESOURCE_TYPES, cloudWatchLogsResolvers;
var init_find_cloudwatch_logs = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/logs-monitor/find-cloudwatch-logs.ts"() {
    "use strict";
    init_util3();
    init_cloudformation2();
    init_environment2();
    init_plugin2();
    init_toolkit_info();
    IGNORE_LOGS_RESOURCE_TYPES = ["AWS::EC2::FlowLog", "AWS::CloudTrail::Trail", "AWS::CodeBuild::Project"];
    __name(findCloudWatchLogGroups, "findCloudWatchLogGroups");
    __name(isReferencedFromIgnoredResource, "isReferencedFromIgnoredResource");
    cloudWatchLogsResolvers = {
      "AWS::Logs::LogGroup": /* @__PURE__ */ __name((resource, evaluateCfnTemplate) => {
        if (isReferencedFromIgnoredResource(resource, evaluateCfnTemplate)) {
          return void 0;
        }
        return resource.PhysicalResourceId?.toString();
      }, "AWS::Logs::LogGroup"),
      // Resource types that will create a CloudWatch log group with a specific name if one is not provided.
      // The keys are CFN resource types, and the values are the name of the physical name property of that resource
      // and the service name that is used in the automatically created CloudWatch log group.
      "AWS::Lambda::Function": /* @__PURE__ */ __name((resource, evaluateCfnTemplate) => {
        const loggingConfig = evaluateCfnTemplate.getResourceProperty(resource.LogicalResourceId, "LoggingConfig");
        if (loggingConfig?.LogGroup) {
          if (typeof loggingConfig.LogGroup === "string") {
            return loggingConfig.LogGroup;
          }
          if (typeof loggingConfig.LogGroup === "object") {
            if (loggingConfig.LogGroup.Ref) {
              return evaluateCfnTemplate.getResourceProperty(loggingConfig.LogGroup.Ref, "LogGroupName");
            }
          }
        }
        return `/aws/lambda/${resource.PhysicalResourceId}`;
      }, "AWS::Lambda::Function")
    };
    __name(findAllLogGroupNames, "findAllLogGroupNames");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/logs-monitor/index.ts
var init_logs_monitor3 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/logs-monitor/index.ts"() {
    "use strict";
    init_logs_monitor2();
    init_find_cloudwatch_logs();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/resource-import/importer.ts
function fmtdict(xs) {
  return Object.entries(xs).map(([k32, v]) => `${k32}=${v}`).join(", ");
}
function addDefaultDeletionPolicy(resource) {
  if (resource.DeletionPolicy) {
    return resource;
  }
  return {
    ...resource,
    DeletionPolicy: "Retain"
  };
}
function removeNonImportResources(stack) {
  const template = stack.template;
  delete template.Resources.CDKMetadata;
  delete template.Outputs;
  return template;
}
var import_util55, cfnDiff, chalk16, fs31, ResourceImporter;
var init_importer = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/resource-import/importer.ts"() {
    "use strict";
    import_util55 = require("util");
    cfnDiff = __toESM(require_lib9());
    chalk16 = __toESM(require_source());
    fs31 = __toESM(require_lib4());
    init_toolkit_error();
    init_deployments2();
    init_diff3();
    init_private();
    ResourceImporter = class {
      static {
        __name(this, "ResourceImporter");
      }
      _currentTemplate;
      stack;
      cfn;
      ioHelper;
      constructor(stack, props) {
        this.stack = stack;
        this.cfn = props.deployments;
        this.ioHelper = props.ioHelper;
      }
      /**
       * Ask the user for resources to import
       */
      async askForResourceIdentifiers(available) {
        const ret = { importResources: [], resourceMap: {} };
        const resourceIdentifiers2 = await this.resourceIdentifiers();
        for (const resource of available) {
          const identifier = await this.askForResourceIdentifier(resourceIdentifiers2, resource);
          if (!identifier) {
            continue;
          }
          ret.importResources.push(resource);
          ret.resourceMap[resource.logicalId] = identifier;
        }
        return ret;
      }
      /**
       * Load the resources to import from a file
       */
      async loadResourceIdentifiersFromFile(available, fileName) {
        const contents = await fs31.readJson(fileName);
        return this.loadResourceIdentifiers(available, contents);
      }
      /**
       * Load the resources to import from a mapping (JSON string or pre-parsed object)
       */
      async loadResourceIdentifiers(available, identifiers) {
        let parsed;
        if (typeof identifiers === "string") {
          try {
            parsed = JSON.parse(identifiers);
          } catch {
            throw new ToolkitError("InvalidResourceMapping", `Could not parse resource mapping as JSON: ${identifiers}`);
          }
        } else {
          parsed = identifiers;
        }
        const remaining = { ...parsed };
        const ret = { importResources: [], resourceMap: {} };
        for (const resource of available) {
          const descr = this.describeResource(resource.logicalId);
          const idProps = remaining[resource.logicalId];
          if (idProps) {
            await this.ioHelper.defaults.info((0, import_util55.format)("%s: importing using %s", chalk16.blue(descr), chalk16.blue(fmtdict(idProps))));
            ret.importResources.push(resource);
            ret.resourceMap[resource.logicalId] = idProps;
            delete remaining[resource.logicalId];
          } else {
            await this.ioHelper.defaults.info((0, import_util55.format)("%s: skipping", chalk16.blue(descr)));
          }
        }
        const unknown = Object.keys(remaining);
        if (unknown.length > 0) {
          await this.ioHelper.defaults.warn(`Unrecognized resource identifiers in mapping file: ${unknown.join(", ")}`);
        }
        return ret;
      }
      /**
       * Based on the provided resource mapping, prepare CFN structures for import (template,
       * ResourcesToImport structure) and perform the import operation (CloudFormation deployment)
       *
       * @param importMap - Mapping from CDK construct tree path to physical resource import identifiers
       * @param options - Options to pass to CloudFormation deploy operation
       */
      async importResourcesFromMap(importMap, options = {}) {
        const resourcesToImport = await this.makeResourcesToImport(importMap);
        const updatedTemplate = await this.currentTemplateWithAdditions(importMap.importResources);
        await this.importResources(updatedTemplate, resourcesToImport, options);
      }
      /**
       * Based on the app and resources file generated by cdk migrate. Removes all items from the template that
       * cannot be included in an import change-set for new stacks and performs the import operation,
       * creating the new stack.
       *
       * @param resourcesToImport - The mapping created by cdk migrate
       * @param options - Options to pass to CloudFormation deploy operation
       */
      async importResourcesFromMigrate(resourcesToImport, options = {}) {
        const updatedTemplate = this.removeNonImportResources();
        await this.importResources(updatedTemplate, resourcesToImport, options);
      }
      async importResources(overrideTemplate, resourcesToImport, options) {
        try {
          const result2 = await this.cfn.deployStack({
            stack: this.stack,
            deployName: this.stack.stackName,
            ...options,
            overrideTemplate,
            resourcesToImport
          });
          assertIsSuccessfulDeployStackResult(result2);
          const message2 = result2.noOp ? " \u2705  %s (no changes)" : " \u2705  %s";
          await this.ioHelper.defaults.info("\n" + chalk16.green((0, import_util55.format)(message2, this.stack.displayName)));
        } catch (e32) {
          await this.ioHelper.notify(IO.CDK_TOOLKIT_E3900.msg((0, import_util55.format)("\n \u274C  %s failed: %s", chalk16.bold(this.stack.displayName), e32), { error: e32 }));
          throw e32;
        }
      }
      /**
       * Perform a diff between the currently running and the new template, ensure that it is valid
       * for importing and return a list of resources that are being added in the new version
       *
       * @return mapping logicalResourceId -> resourceDifference
       */
      async discoverImportableResources(allowNonAdditions = false) {
        const currentTemplate = await this.currentTemplate();
        const diff = cfnDiff.fullDiff(currentTemplate, this.stack.template);
        const resourceChanges = Object.entries(diff.resources.changes).filter(([logicalId, _]) => logicalId !== "CDKMetadata");
        const nonAdditions = resourceChanges.filter(([_, dif]) => !dif.isAddition);
        const additions = resourceChanges.filter(([_, dif]) => dif.isAddition);
        if (nonAdditions.length && allowNonAdditions) {
          const offendingResources = nonAdditions.map(([logId, _]) => this.describeResource(logId));
          await this.ioHelper.defaults.warn(`Ignoring updated/deleted resources (--force): ${offendingResources.join(", ")}`);
        }
        return {
          additions: additions.map(([logicalId, resourceDiff]) => ({
            logicalId,
            resourceDiff,
            resourceDefinition: addDefaultDeletionPolicy(this.stack.template?.Resources?.[logicalId] ?? {})
          })),
          hasNonAdditions: nonAdditions.length > 0,
          nonAdditionNames: nonAdditions.map(([logId, _]) => this.describeResource(logId)),
          diffFormatter: new DiffFormatter({
            templateInfo: {
              oldTemplate: currentTemplate,
              newTemplate: this.stack
            }
          })
        };
      }
      /**
       * Resolves the environment of a stack.
       */
      async resolveEnvironment() {
        return this.cfn.resolveEnvironment(this.stack);
      }
      /**
       * Get currently deployed template of the given stack (SINGLETON)
       *
       * @returns Currently deployed CloudFormation template
       */
      async currentTemplate() {
        if (!this._currentTemplate) {
          this._currentTemplate = await this.cfn.readCurrentTemplate(this.stack);
        }
        return this._currentTemplate;
      }
      /**
       * Return the current template, with the given resources added to it
       */
      async currentTemplateWithAdditions(additions) {
        const template = await this.currentTemplate();
        if (!template.Resources) {
          template.Resources = {};
        }
        for (const add of additions) {
          template.Resources[add.logicalId] = add.resourceDefinition;
        }
        return template;
      }
      /**
       * Get a list of import identifiers for all resource types used in the given
       * template that do support the import operation (SINGLETON)
       *
       * @returns a mapping from a resource type to a list of property names that together identify the resource for import
       */
      async resourceIdentifiers() {
        const ret = {};
        const resourceIdentifierSummaries = await this.cfn.resourceIdentifierSummaries(this.stack);
        for (const summary of resourceIdentifierSummaries) {
          if ("ResourceType" in summary && summary.ResourceType && "ResourceIdentifiers" in summary && summary.ResourceIdentifiers) {
            ret[summary.ResourceType] = (summary.ResourceIdentifiers ?? [])?.map((x) => x.split(","));
          }
        }
        return ret;
      }
      /**
       * Ask for the importable identifier for the given resource
       *
       * There may be more than one identifier under which a resource can be imported. The `import`
       * operation needs exactly one of them.
       *
       * - If we can get one from the template, we will use one.
       * - Otherwise, we will ask the user for one of them.
       */
      async askForResourceIdentifier(resourceIdentifiers2, chg) {
        const resourceName = this.describeResource(chg.logicalId);
        const resourceType = chg.resourceDiff.newResourceType;
        if (resourceType === void 0 || !(resourceType in resourceIdentifiers2)) {
          await this.ioHelper.defaults.warn(`${resourceName}: unsupported resource type ${resourceType}, skipping import.`);
          return void 0;
        }
        const idPropSets = resourceIdentifiers2[resourceType];
        const resourceProps = Object.fromEntries(Object.entries(chg.resourceDefinition.Properties ?? {}).filter(([_, v]) => typeof v === "string"));
        const satisfiedPropSets = idPropSets.filter((ps) => ps.every((p10) => resourceProps[p10]));
        for (const satisfiedPropSet of satisfiedPropSets) {
          const candidateProps = Object.fromEntries(satisfiedPropSet.map((p10) => [p10, resourceProps[p10]]));
          const displayCandidateProps = fmtdict(candidateProps);
          const importTheResource = await this.ioHelper.requestResponse(IO.CDK_TOOLKIT_I3100.req(`${chalk16.blue(resourceName)} (${resourceType}): import with ${chalk16.yellow(displayCandidateProps)}`, {
            resource: {
              type: resourceType,
              props: candidateProps,
              stringifiedProps: displayCandidateProps
            }
          }));
          if (importTheResource) {
            return candidateProps;
          }
        }
        if (satisfiedPropSets.length > 0) {
          await this.ioHelper.defaults.info(chalk16.grey(`Skipping import of ${resourceName}`));
          return void 0;
        }
        const prefix = `${chalk16.blue(resourceName)} (${resourceType})`;
        const promptPattern = `${prefix}: enter %s`;
        if (idPropSets.length > 1) {
          const preamble = `${prefix}: enter one of ${idPropSets.map((x) => chalk16.blue(x.join("+"))).join(", ")} to import (leave all empty to skip)`;
          await this.ioHelper.defaults.info(preamble);
        }
        for (const idProps of idPropSets) {
          const input = {};
          for (const idProp of idProps) {
            const defaultValue2 = resourceProps[idProp] ?? "";
            const response = await this.ioHelper.requestResponse(IO.CDK_TOOLKIT_I3110.req(
              (0, import_util55.format)(promptPattern, chalk16.blue(idProp)),
              {
                resource: {
                  name: resourceName,
                  type: resourceType,
                  idProp
                },
                responseDescription: defaultValue2 ? void 0 : "empty to skip"
              },
              defaultValue2
            ));
            if (!response) {
              break;
            }
            input[idProp] = response;
            resourceProps[idProp] = response;
          }
          if (Object.keys(input).length === idProps.length) {
            return input;
          }
        }
        await this.ioHelper.defaults.info(chalk16.grey(`Skipping import of ${resourceName}`));
        return void 0;
      }
      /**
       * Convert the internal "resource mapping" structure to CloudFormation accepted "ResourcesToImport" structure
       */
      async makeResourcesToImport(resourceMap) {
        return resourceMap.importResources.map((res) => ({
          LogicalResourceId: res.logicalId,
          ResourceType: res.resourceDiff.newResourceType,
          ResourceIdentifier: resourceMap.resourceMap[res.logicalId]
        }));
      }
      /**
       * Convert CloudFormation logical resource ID to CDK construct tree path
       *
       * @param logicalId - CloudFormation logical ID of the resource (the key in the template's Resources section)
       * @returns Forward-slash separated path of the resource in CDK construct tree, e.g. MyStack/MyBucket/Resource
       */
      describeResource(logicalId) {
        return this.stack.template?.Resources?.[logicalId]?.Metadata?.["aws:cdk:path"] ?? logicalId;
      }
      /**
       * Removes CDKMetadata and Outputs in the template so that only resources for importing are left.
       * @returns template with import resources only
       */
      removeNonImportResources() {
        return removeNonImportResources(this.stack);
      }
    };
    __name(fmtdict, "fmtdict");
    __name(addDefaultDeletionPolicy, "addDefaultDeletionPolicy");
    __name(removeNonImportResources, "removeNonImportResources");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/resource-import/migrator.ts
var chalk17, fs32, ResourceMigrator;
var init_migrator = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/resource-import/migrator.ts"() {
    "use strict";
    chalk17 = __toESM(require_source());
    fs32 = __toESM(require_lib4());
    init_importer();
    init_util3();
    init_private();
    ResourceMigrator = class {
      static {
        __name(this, "ResourceMigrator");
      }
      props;
      ioHelper;
      constructor(props) {
        this.props = props;
        this.ioHelper = props.ioHelper;
      }
      /**
       * Checks to see if a migrate.json file exists. If it does and the source is either `filepath` or
       * is in the same environment as the stack deployment, a new stack is created and the resources are
       * migrated to the stack using an IMPORT changeset. The normal deployment will resume after this is complete
       * to add back in any outputs and the CDKMetadata.
       */
      async tryMigrateResources(stacks, options) {
        const stack = stacks.stackArtifacts[0];
        const migrateDeployment = new ResourceImporter(stack, {
          deployments: this.props.deployments,
          ioHelper: this.ioHelper
        });
        const resourcesToImport = await this.tryGetResources(await migrateDeployment.resolveEnvironment());
        if (resourcesToImport) {
          await this.ioHelper.defaults.info(`${chalk17.bold(stack.displayName)}: creating stack for resource migration...`);
          await this.ioHelper.defaults.info(`${chalk17.bold(stack.displayName)}: importing resources into stack...`);
          await this.performResourceMigration(migrateDeployment, resourcesToImport, options);
          fs32.rmSync("migrate.json");
          await this.ioHelper.defaults.info(`${chalk17.bold(stack.displayName)}: applying CDKMetadata and Outputs to stack (if applicable)...`);
        }
      }
      /**
       * Creates a new stack with just the resources to be migrated
       */
      async performResourceMigration(migrateDeployment, resourcesToImport, options) {
        const startDeployTime = (/* @__PURE__ */ new Date()).getTime();
        let elapsedDeployTime = 0;
        await migrateDeployment.importResourcesFromMigrate(resourcesToImport, {
          roleArn: options.roleArn,
          deploymentMethod: options.deploymentMethod,
          usePreviousParameters: true,
          rollback: options.rollback
        });
        elapsedDeployTime = (/* @__PURE__ */ new Date()).getTime() - startDeployTime;
        await this.ioHelper.notify(IO.CDK_TOOLKIT_I5002.msg(`'
\u2728  Resource migration time: ${formatTime(elapsedDeployTime)}s
'`, {
          duration: elapsedDeployTime
        }));
      }
      async tryGetResources(environment) {
        try {
          const migrateFile = fs32.readJsonSync("migrate.json", {
            encoding: "utf-8"
          });
          const sourceEnv = migrateFile.Source.split(":");
          if (sourceEnv[0] === "localfile" || sourceEnv[4] === environment.account && sourceEnv[3] === environment.region) {
            return migrateFile.Resources;
          }
        } catch (e32) {
        }
        return void 0;
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/resource-import/index.ts
var init_resource_import = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/resource-import/index.ts"() {
    "use strict";
    init_importer();
    init_migrator();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/orphan/private/helpers.ts
function walkObject(obj, visitor) {
  if (obj === null || obj === void 0) return;
  visitor(obj);
  if (typeof obj === "object") {
    for (const value of Object.values(obj)) {
      walkObject(value, visitor);
    }
  }
}
function replaceInObject(obj, logicalId, values) {
  if (obj === null || obj === void 0) return obj;
  if (typeof obj !== "object") return obj;
  if (Array.isArray(obj)) {
    return obj.map((item) => replaceInObject(item, logicalId, values));
  }
  if (Object.keys(obj).length === 1 && obj.Ref === logicalId) {
    return values.ref;
  }
  if (Object.keys(obj).length === 1 && Array.isArray(obj["Fn::GetAtt"]) && obj["Fn::GetAtt"][0] === logicalId) {
    const attr = obj["Fn::GetAtt"][1];
    if (values.attrs[attr]) {
      return values.attrs[attr];
    }
  }
  if (obj["Fn::Sub"] !== void 0) {
    const sub = obj["Fn::Sub"];
    const replaceSubString = /* @__PURE__ */ __name((str) => {
      for (const [attr, val] of Object.entries(values.attrs)) {
        str = str.replace(new RegExp(`\\$\\{${logicalId}\\.${attr}\\}`, "g"), val);
      }
      str = str.replace(new RegExp(`\\$\\{${logicalId}\\}`, "g"), values.ref);
      return str;
    }, "replaceSubString");
    if (typeof sub === "string") {
      return { "Fn::Sub": replaceSubString(sub) };
    }
    if (Array.isArray(sub) && typeof sub[0] === "string") {
      return {
        "Fn::Sub": [
          replaceSubString(sub[0]),
          sub[1] ? replaceInObject(sub[1], logicalId, values) : sub[1]
        ]
      };
    }
  }
  const result2 = {};
  for (const [key, value] of Object.entries(obj)) {
    result2[key] = replaceInObject(value, logicalId, values);
  }
  return result2;
}
function replaceReferences(template, logicalId, values) {
  for (const section of ["Resources", "Outputs", "Conditions"]) {
    if (!template[section]) continue;
    for (const [key, value] of Object.entries(template[section])) {
      if (section === "Resources" && key === logicalId) continue;
      template[section][key] = replaceInObject(value, logicalId, values);
    }
  }
}
function removeDependsOn(template, logicalId) {
  for (const resource of Object.values(template.Resources ?? {})) {
    const res = resource;
    if (Array.isArray(res.DependsOn)) {
      res.DependsOn = res.DependsOn.filter((dep) => dep !== logicalId);
      if (res.DependsOn.length === 0) delete res.DependsOn;
    } else if (res.DependsOn === logicalId) {
      delete res.DependsOn;
    }
  }
}
function assertDeploySucceeded(result2, step) {
  if (result2.type !== "did-deploy-stack") {
    throw new ToolkitError("OrphanDeployFailed", `${step}: unexpected deployment result '${result2.type}'`);
  }
}
function ensureNonEmptyResources(template) {
  if (Object.keys(template.Resources ?? {}).length === 0) {
    template.Resources = {
      CDKOrphanPlaceholder: {
        Type: "AWS::CloudFormation::WaitConditionHandle"
      }
    };
  }
}
function parseAndValidateConstructPaths(paths) {
  if (paths.length === 0) {
    throw new ToolkitError("MissingConstructPath", "At least one construct path is required (e.g. cdk orphan MyStack/MyTable)");
  }
  const constructPaths = [];
  let stackId;
  for (const raw of paths) {
    const p10 = raw.replace(/^\//, "");
    const slashIdx = p10.indexOf("/");
    if (slashIdx < 0) {
      throw new ToolkitError("InvalidConstructPath", `Construct path '${raw}' must include both a stack name and a construct path separated by '/' (e.g. MyStack/MyTable)`);
    }
    const thisStack = p10.substring(0, slashIdx);
    const constructPath = p10.substring(slashIdx + 1);
    if (stackId && thisStack !== stackId) {
      throw new ToolkitError("MultipleStacks", `All construct paths must reference the same stack, but got '${stackId}' and '${thisStack}'`);
    }
    stackId = thisStack;
    constructPaths.push(constructPath);
  }
  return { stackId, constructPaths };
}
var import_cloud_assembly_api13;
var init_helpers2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/orphan/private/helpers.ts"() {
    "use strict";
    import_cloud_assembly_api13 = __toESM(require_lib3());
    init_toolkit_error();
    __name(walkObject, "walkObject");
    __name(replaceInObject, "replaceInObject");
    __name(replaceReferences, "replaceReferences");
    __name(removeDependsOn, "removeDependsOn");
    __name(assertDeploySucceeded, "assertDeploySucceeded");
    __name(ensureNonEmptyResources, "ensureNonEmptyResources");
    __name(parseAndValidateConstructPaths, "parseAndValidateConstructPaths");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/orphan/private/index.ts
var init_private4 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/orphan/private/index.ts"() {
    "use strict";
    init_helpers2();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/orphan/orphaner.ts
var ResourceOrphaner;
var init_orphaner = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/orphan/orphaner.ts"() {
    "use strict";
    init_private4();
    init_toolkit_error();
    ResourceOrphaner = class {
      static {
        __name(this, "ResourceOrphaner");
      }
      deployments;
      ioHelper;
      roleArn;
      toolkitStackName;
      constructor(props) {
        this.deployments = props.deployments;
        this.ioHelper = props.ioHelper;
        this.roleArn = props.roleArn;
        this.toolkitStackName = props.toolkitStackName;
      }
      /**
       * Analyze the stack and build a plan of what will be orphaned.
       * This is read-only — no changes are made until `plan.execute()` is called.
       */
      async makePlan(stack, constructPaths) {
        const currentTemplate = await this.deployments.readCurrentTemplate(stack);
        const resources = currentTemplate.Resources ?? {};
        const pathToLogicalId = /* @__PURE__ */ new Map();
        for (const md of stack.findMetadataByType("aws:cdk:logicalId")) {
          pathToLogicalId.set(md.path, md.data);
        }
        const matched = [];
        for (const constructPath of constructPaths) {
          const prefix = `/${stack.hierarchicalId}/${constructPath}/`;
          for (const [path47, logicalId] of pathToLogicalId) {
            if (path47.startsWith(prefix) && resources[logicalId]) {
              matched.push({ logicalId, path: path47 });
            }
          }
        }
        if (matched.length === 0) {
          throw new ToolkitError("OrphanNoResources", `No resources found under construct path '${constructPaths.join(", ")}' in stack '${stack.stackName}'`);
        }
        const logicalIds = matched.map((m20) => m20.logicalId);
        const orphanedResources = matched.map((m20) => ({
          logicalId: m20.logicalId,
          resourceType: resources[m20.logicalId].Type ?? "Unknown",
          cdkPath: m20.path
        }));
        return {
          stackName: stack.stackName,
          orphanedResources,
          execute: /* @__PURE__ */ __name(() => this.execute(stack, logicalIds, currentTemplate), "execute")
        };
      }
      async execute(stack, logicalIds, currentTemplate) {
        const env3 = await this.deployments.envs.accessStackForReadOnlyStackOperations(stack);
        const cfn = env3.sdk.cloudFormation();
        const stackResources = await cfn.listStackResources({ StackName: stack.stackName });
        const physicalIds = /* @__PURE__ */ new Map();
        for (const res of stackResources) {
          if (res.LogicalResourceId && res.PhysicalResourceId) {
            physicalIds.set(res.LogicalResourceId, res.PhysicalResourceId);
          }
        }
        await this.ioHelper.defaults.info("Step 1/3: Resolving attribute values...");
        const resolvedValues = await this.resolveGetAttValues(stack, cfn, logicalIds, currentTemplate, physicalIds);
        await this.ioHelper.defaults.info("Step 2/3: Decoupling resources...");
        const decoupledTemplate = JSON.parse(JSON.stringify(currentTemplate));
        for (const id of logicalIds) {
          replaceReferences(decoupledTemplate, id, resolvedValues.get(id));
          removeDependsOn(decoupledTemplate, id);
          decoupledTemplate.Resources[id].DeletionPolicy = "Retain";
          decoupledTemplate.Resources[id].UpdateReplacePolicy = "Retain";
        }
        const step2Result = await this.deployStack(stack, decoupledTemplate, "cdk-orphan-step2");
        assertDeploySucceeded(step2Result, "Step 2");
        await this.ioHelper.defaults.info("Step 3/3: Removing resources from stack...");
        const removalTemplate = JSON.parse(JSON.stringify(decoupledTemplate));
        for (const id of logicalIds) {
          delete removalTemplate.Resources[id];
        }
        ensureNonEmptyResources(removalTemplate);
        const step3Result = await this.deployStack(stack, removalTemplate, "cdk-orphan-step3");
        assertDeploySucceeded(step3Result, "Step 3");
        if (step3Result.noOp) {
          throw new ToolkitError(
            "OrphanNoOp",
            "Orphan step 3 was unexpectedly a no-op \u2014 the resources were not removed from the stack. If this issue persists, please open an issue at https://github.com/aws/aws-cdk-cli/issues with your stack template attached."
          );
        }
        const resourceMapping = await this.getResourceIdentifiers(stack, logicalIds, physicalIds, currentTemplate);
        return { resourceMapping };
      }
      /**
       * Deploy a template override to the stack.
       */
      async deployStack(stack, template, changeSetName) {
        return this.deployments.deployStack({
          stack,
          roleArn: this.roleArn,
          toolkitStackName: this.toolkitStackName,
          deploymentMethod: { method: "change-set", changeSetName },
          overrideTemplate: template,
          usePreviousParameters: true,
          forceDeployment: true
        });
      }
      /**
       * Resolve GetAtt attribute values for orphaned resources.
       *
       * Current strategy: inject temporary Outputs into the stack that reference
       * each GetAtt, deploy, then read the resolved values from DescribeStacks.
       *
       * This function is intentionally decoupled from the rest of the orphan flow
       * so it can be replaced with a Cloud Control API-based approach later.
       *
       * Returns a complete map of resolved values (Ref + attrs) for each logical ID.
       */
      async resolveGetAttValues(stack, cfn, logicalIds, currentTemplate, physicalIds) {
        const values = /* @__PURE__ */ new Map();
        for (const id of logicalIds) {
          const physicalId = physicalIds.get(id);
          if (!physicalId) {
            throw new ToolkitError("OrphanMissingPhysicalId", `Could not resolve physical resource ID for '${id}'`);
          }
          values.set(id, { ref: physicalId, attrs: {} });
        }
        const getAttRefs = this.findGetAttReferences(currentTemplate, logicalIds);
        if (getAttRefs.size === 0) {
          return values;
        }
        const resolveTemplate = JSON.parse(JSON.stringify(currentTemplate));
        if (!resolveTemplate.Outputs) {
          resolveTemplate.Outputs = {};
        }
        for (const [outputKey, ref] of getAttRefs) {
          resolveTemplate.Outputs[outputKey] = {
            Value: { "Fn::GetAtt": [ref.logicalId, ref.attr] }
          };
        }
        const step1Result = await this.deployStack(stack, resolveTemplate, "cdk-orphan-step1");
        assertDeploySucceeded(step1Result, "Step 1");
        const stackDesc = await cfn.describeStacks({ StackName: stack.stackName });
        for (const output of stackDesc.Stacks?.[0]?.Outputs ?? []) {
          if (!output.OutputKey || !output.OutputValue) continue;
          const ref = getAttRefs.get(output.OutputKey);
          if (ref) {
            values.get(ref.logicalId).attrs[ref.attr] = output.OutputValue;
          }
        }
        return values;
      }
      findGetAttReferences(template, logicalIds) {
        const refs = /* @__PURE__ */ new Map();
        const addRef = /* @__PURE__ */ __name((id, attr) => {
          const outputKey = `CdkOrphan${id}${attr}`.replace(/[^a-zA-Z0-9]/g, "");
          if (!refs.has(outputKey)) {
            refs.set(outputKey, { logicalId: id, attr });
          }
        }, "addRef");
        const scanSubString = /* @__PURE__ */ __name((str) => {
          const pattern = /\$\{([^}.]+)\.([^}]+)\}/g;
          let match;
          while ((match = pattern.exec(str)) !== null) {
            const [, id, attr] = match;
            if (logicalIds.includes(id)) {
              addRef(id, attr);
            }
          }
        }, "scanSubString");
        walkObject(template, (value) => {
          if (value && typeof value === "object" && !Array.isArray(value)) {
            const getAtt = value["Fn::GetAtt"];
            if (Array.isArray(getAtt) && logicalIds.includes(getAtt[0])) {
              addRef(getAtt[0], getAtt[1]);
            }
            const sub = value["Fn::Sub"];
            if (typeof sub === "string") {
              scanSubString(sub);
            } else if (Array.isArray(sub) && typeof sub[0] === "string") {
              scanSubString(sub[0]);
            }
          }
        });
        return refs;
      }
      async getResourceIdentifiers(stack, logicalIds, physicalIds, template) {
        const result2 = {};
        try {
          const summaries = await this.deployments.resourceIdentifierSummaries(stack);
          const identifiersByType = /* @__PURE__ */ new Map();
          for (const summary of summaries) {
            if (summary.ResourceType && summary.ResourceIdentifiers) {
              identifiersByType.set(summary.ResourceType, summary.ResourceIdentifiers);
            }
          }
          const resources = template.Resources ?? {};
          for (const id of logicalIds) {
            const resource = resources[id];
            if (!resource) continue;
            const identifierProps = identifiersByType.get(resource.Type);
            if (!identifierProps || identifierProps.length === 0) continue;
            const identifier = {};
            const props = resource.Properties ?? {};
            for (const prop of identifierProps) {
              if (props[prop] && typeof props[prop] === "string") {
                identifier[prop] = props[prop];
              } else if (identifierProps.length === 1 && physicalIds.has(id)) {
                identifier[prop] = physicalIds.get(id);
              }
            }
            if (Object.keys(identifier).length > 0) {
              result2[id] = identifier;
            }
          }
        } catch (e32) {
          await this.ioHelper.defaults.warn(`Could not retrieve resource identifiers for import: ${e32.message}`);
        }
        return result2;
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/work-graph/work-graph-types.ts
var DeploymentState;
var init_work_graph_types = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/work-graph/work-graph-types.ts"() {
    "use strict";
    DeploymentState = /* @__PURE__ */ ((DeploymentState2) => {
      DeploymentState2["PENDING"] = "pending";
      DeploymentState2["QUEUED"] = "queued";
      DeploymentState2["DEPLOYING"] = "deploying";
      DeploymentState2["COMPLETED"] = "completed";
      DeploymentState2["FAILED"] = "failed";
      DeploymentState2["SKIPPED"] = "skipped";
      return DeploymentState2;
    })(DeploymentState || {});
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/work-graph/work-graph.ts
function sum2(xs) {
  let ret = 0;
  for (const x of xs) {
    ret += x;
  }
  return ret;
}
function retainOnly(xs, pred) {
  xs.splice(0, xs.length, ...xs.filter(pred));
}
function gv(id, attrs) {
  const attrString = Object.entries(attrs ?? {}).flatMap(([k32, v]) => v !== void 0 ? [`${k32}="${v}"`] : []).join(",");
  return attrString ? `"${simplifyId(id)}" [${attrString}]` : `"${simplifyId(id)}"`;
}
function simplifyId(id) {
  return id.replace(/([0-9a-f]{6})[0-9a-f]{6,}/g, "$1");
}
var WorkGraph;
var init_work_graph = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/work-graph/work-graph.ts"() {
    "use strict";
    init_work_graph_types();
    init_toolkit_error();
    init_util3();
    WorkGraph = class {
      static {
        __name(this, "WorkGraph");
      }
      /**
       * A helper to declare a noop action.
       */
      static NOOP = /* @__PURE__ */ __name(async () => {
      }, "NOOP");
      nodes;
      readyPool = [];
      lazyDependencies = /* @__PURE__ */ new Map();
      ioHelper;
      error;
      constructor(nodes32, ioHelper) {
        this.nodes = { ...nodes32 };
        this.ioHelper = ioHelper;
      }
      addNodes(...nodes32) {
        for (const node of nodes32) {
          if (this.nodes[node.id]) {
            throw new ToolkitError("DuplicateNodeId", `Duplicate use of node id: ${node.id}`);
          }
          const ld = this.lazyDependencies.get(node.id);
          if (ld) {
            for (const x of ld) {
              node.dependencies.add(x);
            }
            this.lazyDependencies.delete(node.id);
          }
          this.nodes[node.id] = node;
        }
      }
      removeNode(nodeId) {
        const id = typeof nodeId === "string" ? nodeId : nodeId.id;
        const removedNode = this.nodes[id];
        this.lazyDependencies.delete(id);
        delete this.nodes[id];
        if (removedNode) {
          for (const node of Object.values(this.nodes)) {
            node.dependencies.delete(removedNode.id);
          }
        }
      }
      /**
       * Return all nodes of a given type
       */
      nodesOfType(type) {
        return Object.values(this.nodes).filter((n10) => n10.type === type);
      }
      /**
       * Return all nodes that depend on a given node
       */
      dependees(nodeId) {
        const id = typeof nodeId === "string" ? nodeId : nodeId.id;
        return Object.values(this.nodes).filter((n10) => n10.dependencies.has(id));
      }
      /**
       * Add a dependency, that may come before or after the nodes involved
       */
      addDependency(fromId, toId) {
        const node = this.nodes[fromId];
        if (node) {
          node.dependencies.add(toId);
          return;
        }
        let lazyDeps = this.lazyDependencies.get(fromId);
        if (!lazyDeps) {
          lazyDeps = [];
          this.lazyDependencies.set(fromId, lazyDeps);
        }
        lazyDeps.push(toId);
      }
      tryGetNode(id) {
        return this.nodes[id];
      }
      node(id) {
        const ret = this.nodes[id];
        if (!ret) {
          throw new ToolkitError("NodeNotFound", `No node with id ${id} among ${Object.keys(this.nodes)}`);
        }
        return ret;
      }
      absorb(graph) {
        this.addNodes(...Object.values(graph.nodes));
      }
      hasFailed() {
        return Object.values(this.nodes).some((n10) => n10.deploymentState === "failed" /* FAILED */);
      }
      doParallel(concurrency, actions) {
        return this.forAllArtifacts(concurrency, async (x) => {
          switch (x.type) {
            case "stack":
              await actions.deployStack(x);
              break;
            case "asset-build":
              await actions.buildAsset(x);
              break;
            case "asset-publish":
              await actions.publishAsset(x);
              break;
            case "marker":
              await actions.marker(x);
              break;
          }
        });
      }
      /**
       * Execute all stack nodes in dependency order with the given concurrency.
       *
       * Unlike `doParallel`, this method only handles stack nodes and takes a
       * simple callback. Intended for destroy where there are no asset nodes.
       */
      processStacks(concurrency, fn) {
        return this.forAllArtifacts(concurrency, async (x) => {
          if (x.type !== "stack") {
            return;
          }
          await fn(x);
        });
      }
      /**
       * Return the set of unblocked nodes
       */
      async ready() {
        await this.updateReadyPool();
        return this.readyPool;
      }
      forAllArtifacts(n10, fn) {
        const graph = this;
        const max = typeof n10 === "number" ? {
          "asset-build": n10,
          "asset-publish": n10,
          "stack": n10,
          "marker": 1
        } : n10;
        const totalMax = typeof n10 === "number" ? n10 : sum2(Object.values(n10));
        return new Promise((ok, fail) => {
          let active = {
            "asset-build": 0,
            "asset-publish": 0,
            "stack": 0,
            "marker": 0
          };
          function totalActive() {
            return sum2(Object.values(active));
          }
          __name(totalActive, "totalActive");
          start();
          function start() {
            graph.updateReadyPool().then(() => {
              for (let i32 = 0; i32 < graph.readyPool.length; ) {
                const node = graph.readyPool[i32];
                if (active[node.type] < max[node.type] && totalActive() < totalMax) {
                  graph.readyPool.splice(i32, 1);
                  startOne(node);
                } else {
                  i32 += 1;
                }
              }
              if (totalActive() === 0) {
                if (graph.done()) {
                  ok();
                }
                if (graph.hasFailed()) {
                  fail(graph.error);
                }
              }
            }).catch((e32) => {
              fail(e32);
            });
          }
          __name(start, "start");
          function startOne(x) {
            x.deploymentState = "deploying" /* DEPLOYING */;
            active[x.type]++;
            void fn(x).finally(() => {
              active[x.type]--;
            }).then(() => {
              graph.deployed(x);
              start();
            }).catch((err) => {
              graph.failed(x, err);
              start();
            });
          }
          __name(startOne, "startOne");
        });
      }
      done() {
        return Object.values(this.nodes).every((n10) => "completed" /* COMPLETED */ === n10.deploymentState);
      }
      deployed(node) {
        node.deploymentState = "completed" /* COMPLETED */;
      }
      failed(node, error4) {
        this.error = error4;
        node.deploymentState = "failed" /* FAILED */;
        this.skipRest();
        this.readyPool.splice(0);
      }
      toString() {
        return [
          "digraph D {",
          ...Object.entries(this.nodes).flatMap(([id, node]) => renderNode(id, node)),
          "}"
        ].join("\n");
        function renderNode(id, node) {
          const ret = [];
          if (node.deploymentState === "completed" /* COMPLETED */) {
            ret.push(`  ${gv(id, { style: "filled", fillcolor: "yellow", comment: node.note })};`);
          } else {
            ret.push(`  ${gv(id, { comment: node.note })};`);
          }
          for (const dep of node.dependencies) {
            ret.push(`  ${gv(id)} -> ${gv(dep)};`);
          }
          return ret;
        }
        __name(renderNode, "renderNode");
      }
      /**
       * Ensure all dependencies actually exist. This protects against scenarios such as the following:
       * StackA depends on StackB, but StackB is not selected to deploy. The dependency is redundant
       * and will be dropped.
       * This assumes the manifest comes uncorrupted so we will not fail if a dependency is not found.
       */
      removeUnavailableDependencies() {
        for (const node of Object.values(this.nodes)) {
          const removeDeps = Array.from(node.dependencies).filter((dep) => this.nodes[dep] === void 0);
          removeDeps.forEach((d32) => {
            node.dependencies.delete(d32);
          });
        }
      }
      /**
       * Remove all asset publishing steps for assets that are already published, and then build
       * that aren't used anymore.
       *
       * Do this in parallel, because there may be a lot of assets in an application (seen in practice: >100 assets)
       */
      async removeUnnecessaryAssets(isUnnecessary) {
        await this.ioHelper.defaults.debug("Checking for previously published assets");
        const publishes = this.nodesOfType("asset-publish");
        const classifiedNodes = await parallelPromises(
          8,
          publishes.map((assetNode) => async () => [assetNode, await isUnnecessary(assetNode)])
        );
        const alreadyPublished = classifiedNodes.filter(([_, unnecessary]) => unnecessary).map(([assetNode, _]) => assetNode);
        for (const assetNode of alreadyPublished) {
          this.removeNode(assetNode);
        }
        await this.ioHelper.defaults.debug(`${publishes.length} total assets, ${publishes.length - alreadyPublished.length} still need to be published`);
        const unusedBuilds = this.nodesOfType("asset-build").filter((build) => this.dependees(build).length === 0);
        for (const unusedBuild of unusedBuilds) {
          this.removeNode(unusedBuild);
        }
      }
      async updateReadyPool() {
        const activeCount = Object.values(this.nodes).filter((x) => x.deploymentState === "deploying" /* DEPLOYING */).length;
        const pendingCount = Object.values(this.nodes).filter((x) => x.deploymentState === "pending" /* PENDING */).length;
        const newlyReady = Object.values(this.nodes).filter((x) => x.deploymentState === "pending" /* PENDING */ && Array.from(x.dependencies).every((id) => this.node(id).deploymentState === "completed" /* COMPLETED */));
        for (const node of newlyReady) {
          node.deploymentState = "queued" /* QUEUED */;
          this.readyPool.push(node);
        }
        retainOnly(this.readyPool, (node) => node.deploymentState === "queued" /* QUEUED */);
        this.readyPool.sort((a32, b32) => (b32.priority ?? 0) - (a32.priority ?? 0));
        if (this.readyPool.length === 0 && activeCount === 0 && pendingCount > 0) {
          const cycle = this.findCycle() ?? ["No cycle found!"];
          await this.ioHelper.defaults.trace(`Cycle ${cycle.join(" -> ")} in graph ${this}`);
          throw new ToolkitError("DependencyCycle", `Unable to make progress anymore, dependency cycle between remaining artifacts: ${cycle.join(" -> ")} (run with -vv for full graph)`);
        }
      }
      skipRest() {
        for (const node of Object.values(this.nodes)) {
          if (["queued" /* QUEUED */, "pending" /* PENDING */].includes(node.deploymentState)) {
            node.deploymentState = "skipped" /* SKIPPED */;
          }
        }
      }
      /**
       * Find cycles in a graph
       *
       * Not the fastest, but effective and should be rare
       */
      findCycle() {
        const seen = /* @__PURE__ */ new Set();
        const self2 = this;
        for (const nodeId of Object.keys(this.nodes)) {
          const cycle = recurse(nodeId, [nodeId]);
          if (cycle) {
            return cycle;
          }
        }
        return void 0;
        function recurse(nodeId, path47) {
          if (seen.has(nodeId)) {
            return void 0;
          }
          try {
            for (const dep of self2.nodes[nodeId].dependencies ?? []) {
              const index = path47.indexOf(dep);
              if (index > -1) {
                return [...path47.slice(index), dep];
              }
              const cycle = recurse(dep, [...path47, dep]);
              if (cycle) {
                return cycle;
              }
            }
            return void 0;
          } finally {
            seen.add(nodeId);
          }
        }
        __name(recurse, "recurse");
      }
      /**
       * Whether the `end` node is reachable from the `start` node, following the dependency arrows
       */
      reachable(start, end) {
        const seen = /* @__PURE__ */ new Set();
        const self2 = this;
        return recurse(start);
        function recurse(current) {
          if (seen.has(current)) {
            return false;
          }
          seen.add(current);
          if (current === end) {
            return true;
          }
          for (const dep of self2.nodes[current].dependencies) {
            if (recurse(dep)) {
              return true;
            }
          }
          return false;
        }
        __name(recurse, "recurse");
      }
    };
    __name(sum2, "sum");
    __name(retainOnly, "retainOnly");
    __name(gv, "gv");
    __name(simplifyId, "simplifyId");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/work-graph/build-destroy-work-graph.ts
function buildDestroyWorkGraph(stacks, ioHelper) {
  const graph = new WorkGraph({}, ioHelper);
  const selectedIds = new Set(stacks.map((s) => s.id));
  for (const stack of stacks) {
    graph.addNodes({
      type: "stack",
      id: stack.id,
      dependencies: /* @__PURE__ */ new Set(),
      stack,
      deploymentState: "pending" /* PENDING */,
      priority: 0
    });
  }
  for (const stack of stacks) {
    for (const dep of stack.dependencies) {
      if (cxapi7.CloudFormationStackArtifact.isCloudFormationStackArtifact(dep) && selectedIds.has(dep.id)) {
        graph.addDependency(dep.id, stack.id);
      }
    }
  }
  return graph;
}
var cxapi7;
var init_build_destroy_work_graph = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/work-graph/build-destroy-work-graph.ts"() {
    "use strict";
    cxapi7 = __toESM(require_lib3());
    init_work_graph();
    init_work_graph_types();
    __name(buildDestroyWorkGraph, "buildDestroyWorkGraph");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/work-graph/work-graph-builder.ts
function stacksFromAssets(artifacts) {
  const ret = /* @__PURE__ */ new Map();
  for (const stack of artifacts.filter((x) => cxapi8.CloudFormationStackArtifact.isCloudFormationStackArtifact(x))) {
    const assetArtifacts = stack.dependencies.filter((x) => cxapi8.AssetManifestArtifact.isAssetManifestArtifact(x));
    for (const art of assetArtifacts) {
      ret.set(art, stack);
    }
  }
  return ret;
}
function onlyStacks(artifacts) {
  return artifacts.filter((x) => cxapi8.CloudFormationStackArtifact.isCloudFormationStackArtifact(x));
}
var import_cdk_assets_lib4, cxapi8, WorkGraphBuilder;
var init_work_graph_builder = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/work-graph/work-graph-builder.ts"() {
    "use strict";
    import_cdk_assets_lib4 = __toESM(require_lib5());
    cxapi8 = __toESM(require_lib3());
    init_work_graph();
    init_work_graph_types();
    init_toolkit_error();
    init_util3();
    WorkGraphBuilder = class _WorkGraphBuilder {
      constructor(ioHelper, prebuildAssets, idPrefix = "") {
        this.prebuildAssets = prebuildAssets;
        this.idPrefix = idPrefix;
        this.graph = new WorkGraph({}, ioHelper);
        this.ioHelper = ioHelper;
      }
      prebuildAssets;
      idPrefix;
      static {
        __name(this, "WorkGraphBuilder");
      }
      /**
       * Default priorities for nodes
       *
       * Messages have the highest priority to ensure they are emitted as soon as
       * possible (because they will be used for measuring timings).
       *
       * Assets builds have higher priority than the other two operations, to make good on our promise that
       * '--prebuild-assets' will actually do assets before stacks (if it can). Unfortunately it is the
       * default :(
       *
       * But between stack dependencies and publish dependencies, stack dependencies go first
       */
      static PRIORITIES = {
        "asset-build": 10,
        "asset-publish": 0,
        "stack": 5,
        "marker": 100
      };
      graph;
      ioHelper;
      addStack(artifact) {
        this.graph.addNodes({
          type: "stack",
          id: `${this.idPrefix}${artifact.id}`,
          dependencies: new Set(this.stackArtifactIds(onlyStacks(artifact.dependencies))),
          stack: artifact,
          deploymentState: "pending" /* PENDING */,
          priority: _WorkGraphBuilder.PRIORITIES.stack
        });
      }
      /**
       * Oof, see this parameter list
       */
      // eslint-disable-next-line @stylistic/max-len
      addAsset(parentStack, assetManifestArtifact, assetManifest, asset) {
        const assetId = asset.id.assetId;
        const sourceHash = contentHashAny([assetId, asset.genericSource]).substring(0, 10);
        const buildId = `build-${assetId}-${sourceHash}`;
        const publishId = `publish-${assetId}-${sourceHash}${contentHashAny([assetId, asset.genericDestination]).substring(0, 10)}`;
        const startId = `start-${assetId}`;
        if (!this.graph.tryGetNode(startId)) {
          this.graph.addNodes({
            type: "marker",
            id: startId,
            dependencies: /* @__PURE__ */ new Set(),
            deploymentState: "pending" /* PENDING */,
            priority: _WorkGraphBuilder.PRIORITIES.marker,
            marker: { type: "start-asset", asset }
          });
        }
        const endId = `end-${assetId}`;
        if (!this.graph.tryGetNode(endId)) {
          this.graph.addNodes({
            type: "marker",
            id: endId,
            dependencies: /* @__PURE__ */ new Set(),
            deploymentState: "pending" /* PENDING */,
            priority: _WorkGraphBuilder.PRIORITIES.marker,
            marker: { type: "end-asset", asset }
          });
        }
        if (!this.graph.tryGetNode(buildId)) {
          const node = {
            type: "asset-build",
            id: buildId,
            note: asset.displayName(false),
            dependencies: /* @__PURE__ */ new Set([
              // Build depends on the start message having been emitted.
              startId,
              ...this.stackArtifactIds(assetManifestArtifact.dependencies),
              // If we disable prebuild, then assets inherit (stack) dependencies from their parent stack
              ...!this.prebuildAssets ? this.stackArtifactIds(onlyStacks(parentStack.dependencies)) : []
            ]),
            parentStack,
            assetManifestArtifact,
            assetManifest,
            asset,
            deploymentState: "pending" /* PENDING */,
            priority: _WorkGraphBuilder.PRIORITIES["asset-build"]
          };
          this.graph.addNodes(node);
        }
        const publishNode = this.graph.tryGetNode(publishId);
        if (!publishNode) {
          this.graph.addNodes({
            type: "asset-publish",
            id: publishId,
            note: asset.displayName(true),
            dependencies: /* @__PURE__ */ new Set([
              buildId
            ]),
            parentStack,
            assetManifestArtifact,
            assetManifest,
            asset,
            deploymentState: "pending" /* PENDING */,
            priority: _WorkGraphBuilder.PRIORITIES["asset-publish"]
          });
          this.graph.addDependency(endId, publishId);
        }
        for (const inheritedDep of this.stackArtifactIds(onlyStacks(parentStack.dependencies))) {
          this.graph.addDependency(publishId, inheritedDep);
        }
        this.graph.addDependency(`${this.idPrefix}${parentStack.id}`, publishId);
      }
      build(artifacts) {
        const parentStacks = stacksFromAssets(artifacts);
        for (const artifact of artifacts) {
          if (cxapi8.CloudFormationStackArtifact.isCloudFormationStackArtifact(artifact)) {
            this.addStack(artifact);
          } else if (cxapi8.AssetManifestArtifact.isAssetManifestArtifact(artifact)) {
            const manifest = import_cdk_assets_lib4.AssetManifest.fromFile(artifact.file);
            for (const entry of manifest.entries) {
              const parentStack = parentStacks.get(artifact);
              if (parentStack === void 0) {
                throw new ToolkitError("OrphanedAssetManifest", "Found an asset manifest that is not associated with a stack");
              }
              this.addAsset(parentStack, artifact, manifest, entry);
            }
          } else if (cxapi8.NestedCloudAssemblyArtifact.isNestedCloudAssemblyArtifact(artifact)) {
            const assembly = new cxapi8.CloudAssembly(artifact.fullPath, { topoSort: false });
            const nestedGraph = new _WorkGraphBuilder(
              this.ioHelper,
              this.prebuildAssets,
              `${this.idPrefix}${artifact.id}.`
            ).build(assembly.artifacts);
            this.graph.absorb(nestedGraph);
          } else {
          }
        }
        this.graph.removeUnavailableDependencies();
        this.removeStackPublishCycles();
        return this.graph;
      }
      stackArtifactIds(deps) {
        return deps.flatMap((d32) => cxapi8.CloudFormationStackArtifact.isCloudFormationStackArtifact(d32) ? [this.stackArtifactId(d32)] : []);
      }
      stackArtifactId(artifact) {
        if (!cxapi8.CloudFormationStackArtifact.isCloudFormationStackArtifact(artifact)) {
          throw new ToolkitError("InvalidArtifactType", `Can only call this on CloudFormationStackArtifact, got: ${artifact.constructor.name}`);
        }
        return `${this.idPrefix}${artifact.id}`;
      }
      /**
       * We may have accidentally introduced cycles in an attempt to make the messages printed to the
       * console not interfere with each other too much. Remove them again.
       */
      removeStackPublishCycles() {
        const publishSteps = this.graph.nodesOfType("asset-publish");
        for (const publishStep of publishSteps) {
          for (const dep of publishStep.dependencies) {
            if (this.graph.reachable(dep, publishStep.id)) {
              publishStep.dependencies.delete(dep);
            }
          }
        }
      }
    };
    __name(stacksFromAssets, "stacksFromAssets");
    __name(onlyStacks, "onlyStacks");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/work-graph/index.ts
var init_work_graph2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/work-graph/index.ts"() {
    "use strict";
    init_build_destroy_work_graph();
    init_work_graph();
    init_work_graph_builder();
    init_work_graph_types();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/garbage-collection/progress-printer.ts
var chalk18, ProgressPrinter;
var init_progress_printer = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/garbage-collection/progress-printer.ts"() {
    "use strict";
    chalk18 = __toESM(require_source());
    init_toolkit_error();
    ProgressPrinter = class {
      static {
        __name(this, "ProgressPrinter");
      }
      ioHelper;
      totalAssets;
      assetsScanned;
      taggedAsset;
      taggedAssetsSizeMb;
      deletedAssets;
      deletedAssetsSizeMb;
      interval;
      setInterval;
      isPaused;
      constructor(ioHelper, totalAssets, interval) {
        this.ioHelper = ioHelper;
        this.totalAssets = totalAssets;
        this.assetsScanned = 0;
        this.taggedAsset = 0;
        this.taggedAssetsSizeMb = 0;
        this.deletedAssets = 0;
        this.deletedAssetsSizeMb = 0;
        this.interval = interval ?? 1e4;
        this.isPaused = false;
      }
      reportScannedAsset(amt) {
        this.assetsScanned += amt;
      }
      reportTaggedAsset(assets) {
        this.taggedAsset += assets.length;
        const sizeInBytes = assets.reduce((total, asset) => total + asset.size, 0);
        this.taggedAssetsSizeMb += sizeInBytes / 1048576;
      }
      reportDeletedAsset(assets) {
        this.deletedAssets += assets.length;
        const sizeInBytes = assets.reduce((total, asset) => total + asset.size, 0);
        this.deletedAssetsSizeMb += sizeInBytes / 1048576;
      }
      start() {
        if (this.setInterval) {
          throw new ToolkitError("PrinterAlreadyRunning", "ProgressPrinter is already running. Stop it first using the stop() method before starting it again.");
        }
        this.setInterval = setInterval(() => {
          if (!this.isPaused) {
            this.print();
          }
        }, this.interval);
      }
      pause() {
        this.isPaused = true;
      }
      resume() {
        this.isPaused = false;
      }
      stop() {
        clearInterval(this.setInterval);
        if (!this.isPaused) {
          this.print();
        }
      }
      print() {
        const percentage = (this.assetsScanned / this.totalAssets * 100).toFixed(2);
        if (Math.max(this.taggedAssetsSizeMb, this.deletedAssetsSizeMb) >= 1e3) {
          void this.ioHelper.defaults.info(chalk18.green(`[${percentage}%] ${this.assetsScanned} files scanned: ${this.taggedAsset} assets (${(this.taggedAssetsSizeMb / 1e3).toFixed(2)} GiB) tagged, ${this.deletedAssets} assets (${(this.deletedAssetsSizeMb / 1e3).toFixed(2)} GiB) deleted.`));
        } else {
          void this.ioHelper.defaults.info(chalk18.green(`[${percentage}%] ${this.assetsScanned} files scanned: ${this.taggedAsset} assets (${this.taggedAssetsSizeMb.toFixed(2)} MiB) tagged, ${this.deletedAssets} assets (${this.deletedAssetsSizeMb.toFixed(2)} MiB) deleted.`));
        }
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/garbage-collection/stack-refresh.ts
async function paginateSdkCall(cb) {
  let finished = false;
  let nextToken;
  while (!finished) {
    nextToken = await cb(nextToken);
    if (nextToken === void 0) {
      finished = true;
    }
  }
}
async function fetchAllStackTemplates(cfn, ioHelper, qualifier) {
  const stackNames = [];
  await paginateSdkCall(async (nextToken) => {
    const stacks = await cfn.listStacks({ NextToken: nextToken });
    const ignoredStatues = ["CREATE_FAILED", "DELETE_COMPLETE", "DELETE_IN_PROGRESS", "DELETE_FAILED", "REVIEW_IN_PROGRESS"];
    stackNames.push(
      ...(stacks.StackSummaries ?? []).filter((s) => !ignoredStatues.includes(s.StackStatus)).map((s) => s.StackId ?? s.StackName)
    );
    return stacks.NextToken;
  });
  await ioHelper.defaults.debug(`Parsing through ${stackNames.length} stacks`);
  const templates = [];
  for (const stack of stackNames) {
    let summary;
    summary = await cfn.getTemplateSummary({
      StackName: stack
    });
    if (bootstrapFilter(summary.Parameters, qualifier)) {
      continue;
    } else {
      const template = await cfn.getTemplate({
        StackName: stack
      });
      templates.push((template.TemplateBody ?? "") + JSON.stringify(summary?.Parameters));
    }
  }
  await ioHelper.defaults.debug("Done parsing through stacks");
  return templates;
}
function bootstrapFilter(parameters, qualifier) {
  const bootstrapVersion = parameters?.find((p10) => p10.ParameterKey === "BootstrapVersion");
  const splitBootstrapVersion = bootstrapVersion?.DefaultValue?.split("/");
  return qualifier && splitBootstrapVersion && splitBootstrapVersion.length == 4 && splitBootstrapVersion[2] != qualifier;
}
async function refreshStacks(props) {
  try {
    const stacks = await fetchAllStackTemplates(props.cfn, props.ioHelper, props.qualifier);
    for (const stack of stacks) {
      props.activeAssets.rememberStack(stack);
    }
  } catch (err) {
    throw new ToolkitError("StackRefreshFailed", `Error refreshing stacks: ${err}`);
  }
}
var ActiveAssetCache, BackgroundStackRefresh;
var init_stack_refresh = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/garbage-collection/stack-refresh.ts"() {
    "use strict";
    init_toolkit_error();
    ActiveAssetCache = class {
      static {
        __name(this, "ActiveAssetCache");
      }
      stacks = /* @__PURE__ */ new Set();
      rememberStack(stackTemplate) {
        this.stacks.add(stackTemplate);
      }
      contains(asset) {
        for (const stack of this.stacks) {
          if (stack.includes(asset)) {
            return true;
          }
        }
        return false;
      }
    };
    __name(paginateSdkCall, "paginateSdkCall");
    __name(fetchAllStackTemplates, "fetchAllStackTemplates");
    __name(bootstrapFilter, "bootstrapFilter");
    __name(refreshStacks, "refreshStacks");
    BackgroundStackRefresh = class {
      constructor(props) {
        this.props = props;
        this.lastRefreshTime = Date.now();
      }
      props;
      static {
        __name(this, "BackgroundStackRefresh");
      }
      timeout;
      lastRefreshTime;
      queuedPromises = [];
      stopped = false;
      start() {
        this.timeout = setTimeout(() => this.refresh(), 3e5);
      }
      async refresh() {
        const startTime = Date.now();
        await refreshStacks({
          cfn: this.props.cfn,
          ioHelper: this.props.ioHelper,
          activeAssets: this.props.activeAssets,
          qualifier: this.props.qualifier
        });
        this.justRefreshedStacks();
        if (this.stopped) {
          return;
        }
        this.timeout = setTimeout(() => this.refresh(), Math.max(startTime + 3e5 - Date.now(), 0));
      }
      justRefreshedStacks() {
        this.lastRefreshTime = Date.now();
        for (const p10 of this.queuedPromises.splice(0, this.queuedPromises.length)) {
          p10(void 0);
        }
      }
      /**
       * Checks if the last successful background refresh happened within the specified time frame.
       * If the last refresh is older than the specified time frame, it returns a Promise that resolves
       * when the next background refresh completes or rejects if the refresh takes too long.
       */
      noOlderThan(ms) {
        const horizon = Date.now() - ms;
        if (this.lastRefreshTime >= horizon) {
          return Promise.resolve();
        }
        return Promise.race([
          new Promise((resolve13) => this.queuedPromises.push(resolve13)),
          new Promise((_, reject) => setTimeout(() => reject(new ToolkitError("StackRefreshTimeout", "refreshStacks took too long; the background thread likely threw an error")), ms))
        ]);
      }
      stop() {
        this.stopped = true;
        clearTimeout(this.timeout);
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/garbage-collection/garbage-collector.ts
function partition3(xs, pred) {
  const result2 = {
    included: [],
    excluded: []
  };
  for (const x of xs) {
    if (pred(x)) {
      result2.included.push(x);
    } else {
      result2.excluded.push(x);
    }
  }
  return result2;
}
function imageMap(imageIds) {
  const images = {};
  for (const image of imageIds ?? []) {
    if (!image.imageDigest || !image.imageTag) {
      continue;
    }
    if (!images[image.imageDigest]) {
      images[image.imageDigest] = [];
    }
    images[image.imageDigest].push(image.imageTag);
  }
  return images;
}
var chalk19, pLimit3, S3_ISOLATED_TAG, ECR_ISOLATED_TAG, P_LIMIT, DAY, ImageAsset, ObjectAsset, GarbageCollector;
var init_garbage_collector = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/garbage-collection/garbage-collector.ts"() {
    "use strict";
    chalk19 = __toESM(require_source());
    init_toolkit_info();
    init_progress_printer();
    init_stack_refresh();
    init_toolkit_error();
    init_private();
    init_plugin2();
    pLimit3 = require_p_limit();
    S3_ISOLATED_TAG = "aws-cdk:isolated";
    ECR_ISOLATED_TAG = "aws-cdk.isolated";
    P_LIMIT = 50;
    DAY = 24 * 60 * 60 * 1e3;
    ImageAsset = class {
      constructor(digest, size, tags, manifest) {
        this.digest = digest;
        this.size = size;
        this.tags = tags;
        this.manifest = manifest;
      }
      digest;
      size;
      tags;
      manifest;
      static {
        __name(this, "ImageAsset");
      }
      getTag(tag3) {
        return this.tags.find((t) => t.includes(tag3));
      }
      hasTag(tag3) {
        return this.tags.some((t) => t.includes(tag3));
      }
      hasIsolatedTag() {
        return this.hasTag(ECR_ISOLATED_TAG);
      }
      getIsolatedTag() {
        return this.getTag(ECR_ISOLATED_TAG);
      }
      isolatedTagBefore(date7) {
        const dateIsolated = this.dateIsolated();
        if (!dateIsolated || dateIsolated == "") {
          return false;
        }
        return new Date(Number(dateIsolated)) < date7;
      }
      buildImageTag(inc) {
        return `${inc}-${ECR_ISOLATED_TAG}-${String(Date.now())}`;
      }
      dateIsolated() {
        return this.getIsolatedTag()?.split("-")[3];
      }
    };
    ObjectAsset = class {
      constructor(bucket, key, size) {
        this.bucket = bucket;
        this.key = key;
        this.size = size;
      }
      bucket;
      key;
      size;
      static {
        __name(this, "ObjectAsset");
      }
      cached_tags = void 0;
      fileName() {
        return this.key.split(".")[0];
      }
      async allTags(s3) {
        if (this.cached_tags) {
          return this.cached_tags;
        }
        const response = await s3.getObjectTagging({ Bucket: this.bucket, Key: this.key });
        this.cached_tags = response.TagSet;
        return this.cached_tags;
      }
      getTag(tag3) {
        if (!this.cached_tags) {
          throw new ToolkitError("TagsNotLoaded", "Cannot call getTag before allTags");
        }
        return this.cached_tags.find((t) => t.Key === tag3)?.Value;
      }
      hasTag(tag3) {
        if (!this.cached_tags) {
          throw new ToolkitError("TagsNotLoaded", "Cannot call hasTag before allTags");
        }
        return this.cached_tags.some((t) => t.Key === tag3);
      }
      hasIsolatedTag() {
        return this.hasTag(S3_ISOLATED_TAG);
      }
      isolatedTagBefore(date7) {
        const tagValue = this.getTag(S3_ISOLATED_TAG);
        if (!tagValue || tagValue == "") {
          return false;
        }
        return new Date(Number(tagValue)) < date7;
      }
    };
    GarbageCollector = class {
      constructor(props) {
        this.props = props;
        this.ioHelper = props.ioHelper;
        this.garbageCollectS3Assets = ["s3", "all"].includes(props.type);
        this.garbageCollectEcrAssets = ["ecr", "all"].includes(props.type);
        this.permissionToDelete = ["delete-tagged", "full"].includes(props.action);
        this.permissionToTag = ["tag", "full"].includes(props.action);
        this.confirm = props.confirm ?? true;
        this.bootstrapStackName = props.bootstrapStackName ?? DEFAULT_TOOLKIT_STACK_NAME;
      }
      props;
      static {
        __name(this, "GarbageCollector");
      }
      garbageCollectS3Assets;
      garbageCollectEcrAssets;
      permissionToDelete;
      permissionToTag;
      bootstrapStackName;
      confirm;
      ioHelper;
      /**
       * Perform garbage collection on the resolved environment.
       */
      async garbageCollect() {
        await this.ioHelper.defaults.debug(`${this.garbageCollectS3Assets} ${this.garbageCollectEcrAssets}`);
        const sdk = (await this.props.sdkProvider.forEnvironment(this.props.resolvedEnvironment, 1 /* ForWriting */)).sdk;
        const cfn = sdk.cloudFormation();
        const qualifier = await this.bootstrapQualifier(sdk, this.bootstrapStackName);
        const activeAssets = new ActiveAssetCache();
        await refreshStacks({
          cfn,
          ioHelper: this.ioHelper,
          activeAssets,
          qualifier
        });
        const backgroundStackRefresh = new BackgroundStackRefresh({
          cfn,
          ioHelper: this.ioHelper,
          activeAssets,
          qualifier
        });
        backgroundStackRefresh.start();
        try {
          if (this.garbageCollectS3Assets) {
            await this.garbageCollectS3(sdk, activeAssets, backgroundStackRefresh);
          }
          if (this.garbageCollectEcrAssets) {
            await this.garbageCollectEcr(sdk, activeAssets, backgroundStackRefresh);
          }
        } catch (err) {
          throw new ToolkitError("GarbageCollectionFailed", err);
        } finally {
          backgroundStackRefresh.stop();
        }
      }
      /**
       * Perform garbage collection on ECR assets
       */
      async garbageCollectEcr(sdk, activeAssets, backgroundStackRefresh) {
        const ecr = sdk.ecr();
        const repo = await this.bootstrapRepositoryName(sdk, this.bootstrapStackName);
        const numImages = await this.numImagesInRepo(ecr, repo);
        const printer = new ProgressPrinter(this.ioHelper, numImages, 1e3);
        await this.ioHelper.defaults.debug(`Found bootstrap repo ${repo} with ${numImages} images`);
        try {
          const batchSize = 1e3;
          const currentTime = Date.now();
          const graceDays = this.props.rollbackBufferDays;
          await this.ioHelper.defaults.debug(`Parsing through ${numImages} images in batches`);
          printer.start();
          for await (const batch of this.readRepoInBatches(ecr, repo, batchSize, currentTime)) {
            await backgroundStackRefresh.noOlderThan(6e5);
            const { included: isolated, excluded: notIsolated } = partition3(batch, (asset) => !asset.tags.some((t) => activeAssets.contains(t)));
            await this.ioHelper.defaults.debug(`${isolated.length} isolated images`);
            await this.ioHelper.defaults.debug(`${notIsolated.length} not isolated images`);
            await this.ioHelper.defaults.debug(`${batch.length} images total`);
            let deletables = isolated;
            let taggables = [];
            let untaggables = [];
            if (graceDays > 0) {
              await this.ioHelper.defaults.debug("Filtering out images that are not old enough to delete");
              deletables = isolated.filter((img) => img.isolatedTagBefore(new Date(currentTime - graceDays * DAY)));
              taggables = isolated.filter((img) => !img.hasIsolatedTag());
              untaggables = notIsolated.filter((img) => img.hasIsolatedTag());
            }
            await this.ioHelper.defaults.debug(`${deletables.length} deletable assets`);
            await this.ioHelper.defaults.debug(`${taggables.length} taggable assets`);
            await this.ioHelper.defaults.debug(`${untaggables.length} assets to untag`);
            if (this.permissionToDelete && deletables.length > 0) {
              await this.confirmationPrompt(printer, deletables, "image");
              await this.parallelDeleteEcr(ecr, repo, deletables, printer);
            }
            if (this.permissionToTag && taggables.length > 0) {
              await this.parallelTagEcr(ecr, repo, taggables, printer);
            }
            if (this.permissionToTag && untaggables.length > 0) {
              await this.parallelUntagEcr(ecr, repo, untaggables);
            }
            printer.reportScannedAsset(batch.length);
          }
        } catch (err) {
          throw new ToolkitError("EcrGarbageCollectionFailed", err);
        } finally {
          printer.stop();
        }
      }
      /**
       * Perform garbage collection on S3 assets
       */
      async garbageCollectS3(sdk, activeAssets, backgroundStackRefresh) {
        const s3 = sdk.s3();
        const bucket = await this.bootstrapBucketName(sdk, this.bootstrapStackName);
        const numObjects = await this.numObjectsInBucket(s3, bucket);
        const printer = new ProgressPrinter(this.ioHelper, numObjects, 1e3);
        await this.ioHelper.defaults.debug(`Found bootstrap bucket ${bucket} with ${numObjects} objects`);
        try {
          const batchSize = 1e3;
          const currentTime = Date.now();
          const graceDays = this.props.rollbackBufferDays;
          await this.ioHelper.defaults.debug(`Parsing through ${numObjects} objects in batches`);
          printer.start();
          for await (const batch of this.readBucketInBatches(s3, bucket, batchSize, currentTime)) {
            await backgroundStackRefresh.noOlderThan(6e5);
            const { included: isolated, excluded: notIsolated } = partition3(batch, (asset) => !activeAssets.contains(asset.fileName()));
            await this.ioHelper.defaults.debug(`${isolated.length} isolated assets`);
            await this.ioHelper.defaults.debug(`${notIsolated.length} not isolated assets`);
            await this.ioHelper.defaults.debug(`${batch.length} objects total`);
            let deletables = isolated;
            let taggables = [];
            let untaggables = [];
            if (graceDays > 0) {
              await this.ioHelper.defaults.debug("Filtering out assets that are not old enough to delete");
              await this.parallelReadAllTags(s3, batch);
              deletables = isolated.filter((obj) => obj.isolatedTagBefore(new Date(currentTime - graceDays * DAY)));
              taggables = isolated.filter((obj) => !obj.hasIsolatedTag());
              untaggables = notIsolated.filter((obj) => obj.hasIsolatedTag());
            }
            await this.ioHelper.defaults.debug(`${deletables.length} deletable assets`);
            await this.ioHelper.defaults.debug(`${taggables.length} taggable assets`);
            await this.ioHelper.defaults.debug(`${untaggables.length} assets to untag`);
            if (this.permissionToDelete && deletables.length > 0) {
              await this.confirmationPrompt(printer, deletables, "object");
              await this.parallelDeleteS3(s3, bucket, deletables, printer);
            }
            if (this.permissionToTag && taggables.length > 0) {
              await this.parallelTagS3(s3, bucket, taggables, currentTime, printer);
            }
            if (this.permissionToTag && untaggables.length > 0) {
              await this.parallelUntagS3(s3, bucket, untaggables);
            }
            printer.reportScannedAsset(batch.length);
          }
        } catch (err) {
          throw new ToolkitError("S3GarbageCollectionFailed", err);
        } finally {
          printer.stop();
        }
      }
      async parallelReadAllTags(s3, objects) {
        const limit = pLimit3(P_LIMIT);
        for (const obj of objects) {
          await limit(() => obj.allTags(s3));
        }
      }
      /**
       * Untag assets that were previously tagged, but now currently referenced.
       * Since this is treated as an implementation detail, we do not print the results in the printer.
       */
      async parallelUntagEcr(ecr, repo, untaggables) {
        const limit = pLimit3(P_LIMIT);
        for (const img of untaggables) {
          const tag3 = img.getIsolatedTag();
          await limit(
            () => ecr.batchDeleteImage({
              repositoryName: repo,
              imageIds: [{
                imageTag: tag3
              }]
            })
          );
        }
        await this.ioHelper.defaults.debug(`Untagged ${untaggables.length} assets`);
      }
      /**
       * Untag assets that were previously tagged, but now currently referenced.
       * Since this is treated as an implementation detail, we do not print the results in the printer.
       */
      async parallelUntagS3(s3, bucket, untaggables) {
        const limit = pLimit3(P_LIMIT);
        for (const obj of untaggables) {
          const tags = await obj.allTags(s3) ?? [];
          const updatedTags = tags.filter((tag3) => tag3.Key !== S3_ISOLATED_TAG);
          await limit(
            () => s3.deleteObjectTagging({
              Bucket: bucket,
              Key: obj.key
            })
          );
          await limit(
            () => s3.putObjectTagging({
              Bucket: bucket,
              Key: obj.key,
              Tagging: {
                TagSet: updatedTags
              }
            })
          );
        }
        await this.ioHelper.defaults.debug(`Untagged ${untaggables.length} assets`);
      }
      /**
       * Tag images in parallel using p-limit
       */
      async parallelTagEcr(ecr, repo, taggables, printer) {
        const limit = pLimit3(P_LIMIT);
        for (let i32 = 0; i32 < taggables.length; i32++) {
          const img = taggables[i32];
          const tagEcr = /* @__PURE__ */ __name(async () => {
            try {
              await ecr.putImage({
                repositoryName: repo,
                imageDigest: img.digest,
                imageManifest: img.manifest,
                imageTag: img.buildImageTag(i32)
              });
            } catch (error4) {
              await this.ioHelper.defaults.debug(`Warning: unable to tag image ${JSON.stringify(img.tags)} with ${img.buildImageTag(i32)} due to the following error: ${error4}`);
            }
          }, "tagEcr");
          await limit(() => tagEcr());
        }
        printer.reportTaggedAsset(taggables);
        await this.ioHelper.defaults.debug(`Tagged ${taggables.length} assets`);
      }
      /**
       * Tag objects in parallel using p-limit. The putObjectTagging API does not
       * support batch tagging so we must handle the parallelism client-side.
       */
      async parallelTagS3(s3, bucket, taggables, date7, printer) {
        const limit = pLimit3(P_LIMIT);
        for (const obj of taggables) {
          await limit(
            () => s3.putObjectTagging({
              Bucket: bucket,
              Key: obj.key,
              Tagging: {
                TagSet: [
                  {
                    Key: S3_ISOLATED_TAG,
                    Value: String(date7)
                  }
                ]
              }
            })
          );
        }
        printer.reportTaggedAsset(taggables);
        await this.ioHelper.defaults.debug(`Tagged ${taggables.length} assets`);
      }
      /**
       * Delete images in parallel. The deleteImage API supports batches of 100.
       */
      async parallelDeleteEcr(ecr, repo, deletables, printer) {
        const batchSize = 100;
        const imagesToDelete = deletables.map((img) => ({
          imageDigest: img.digest
        }));
        try {
          const batches = [];
          for (let i32 = 0; i32 < imagesToDelete.length; i32 += batchSize) {
            batches.push(imagesToDelete.slice(i32, i32 + batchSize));
          }
          for (const batch of batches) {
            await ecr.batchDeleteImage({
              imageIds: batch,
              repositoryName: repo
            });
            const deletedCount = batch.length;
            await this.ioHelper.defaults.debug(`Deleted ${deletedCount} assets`);
            printer.reportDeletedAsset(deletables.slice(0, deletedCount));
          }
        } catch (err) {
          await this.ioHelper.defaults.error(`Error deleting images: ${err}`);
        }
      }
      /**
       * Delete objects in parallel. The deleteObjects API supports batches of 1000.
       */
      async parallelDeleteS3(s3, bucket, deletables, printer) {
        const batchSize = 1e3;
        const objectsToDelete = deletables.map((asset) => ({
          Key: asset.key
        }));
        try {
          const batches = [];
          for (let i32 = 0; i32 < objectsToDelete.length; i32 += batchSize) {
            batches.push(objectsToDelete.slice(i32, i32 + batchSize));
          }
          for (const batch of batches) {
            await s3.deleteObjects({
              Bucket: bucket,
              Delete: {
                Objects: batch,
                Quiet: true
              }
            });
            const deletedCount = batch.length;
            await this.ioHelper.defaults.debug(`Deleted ${deletedCount} assets`);
            printer.reportDeletedAsset(deletables.slice(0, deletedCount));
          }
        } catch (err) {
          await this.ioHelper.defaults.debug(chalk19.red(`Error deleting objects: ${err}`));
        }
      }
      async bootstrapBucketName(sdk, bootstrapStackName) {
        const toolkitInfo = await ToolkitInfo.lookup(this.props.resolvedEnvironment, sdk, this.ioHelper, bootstrapStackName);
        return toolkitInfo.bucketName;
      }
      async bootstrapRepositoryName(sdk, bootstrapStackName) {
        const toolkitInfo = await ToolkitInfo.lookup(this.props.resolvedEnvironment, sdk, this.ioHelper, bootstrapStackName);
        return toolkitInfo.repositoryName;
      }
      async bootstrapQualifier(sdk, bootstrapStackName) {
        const toolkitInfo = await ToolkitInfo.lookup(this.props.resolvedEnvironment, sdk, this.ioHelper, bootstrapStackName);
        return toolkitInfo.bootstrapStack.parameters.Qualifier;
      }
      async numObjectsInBucket(s3, bucket) {
        let totalCount = 0;
        let continuationToken;
        do {
          const response = await s3.listObjectsV2({
            Bucket: bucket,
            ContinuationToken: continuationToken
          });
          totalCount += response.KeyCount ?? 0;
          continuationToken = response.NextContinuationToken;
        } while (continuationToken);
        return totalCount;
      }
      async numImagesInRepo(ecr, repo) {
        let totalCount = 0;
        let nextToken;
        do {
          const response = await ecr.listImages({
            repositoryName: repo,
            nextToken
          });
          totalCount += response.imageIds?.length ?? 0;
          nextToken = response.nextToken;
        } while (nextToken);
        return totalCount;
      }
      async *readRepoInBatches(ecr, repo, batchSize = 1e3, currentTime) {
        let continuationToken;
        do {
          const batch = [];
          while (batch.length < batchSize) {
            const response = await ecr.listImages({
              repositoryName: repo,
              nextToken: continuationToken
            });
            if (!response.imageIds || response.imageIds.length === 0) {
              break;
            }
            const images = imageMap(response.imageIds ?? []);
            const imageIds = Object.keys(images).map((key) => ({
              imageDigest: key
            }));
            const describeImageInfo = await ecr.describeImages({
              repositoryName: repo,
              imageIds
            });
            const getImageInfo = await ecr.batchGetImage({
              repositoryName: repo,
              imageIds
            });
            const combinedImageInfo = describeImageInfo.imageDetails?.map((imageDetail) => {
              const matchingImage = getImageInfo.images?.find(
                (img) => img.imageId?.imageDigest === imageDetail.imageDigest
              );
              return {
                ...imageDetail,
                manifest: matchingImage?.imageManifest
              };
            });
            for (const image of combinedImageInfo ?? []) {
              const lastModified = image.imagePushedAt ?? new Date(currentTime);
              if (image.imageDigest && lastModified < new Date(currentTime - this.props.createdBufferDays * DAY)) {
                batch.push(new ImageAsset(image.imageDigest, image.imageSizeInBytes ?? 0, image.imageTags ?? [], image.manifest ?? ""));
              }
            }
            continuationToken = response.nextToken;
            if (!continuationToken) break;
          }
          if (batch.length > 0) {
            yield batch;
          }
        } while (continuationToken);
      }
      /**
       * Generator function that reads objects from the S3 Bucket in batches.
       */
      async *readBucketInBatches(s3, bucket, batchSize = 1e3, currentTime) {
        let continuationToken;
        do {
          const batch = [];
          while (batch.length < batchSize) {
            const response = await s3.listObjectsV2({
              Bucket: bucket,
              ContinuationToken: continuationToken
            });
            response.Contents?.forEach((obj) => {
              const key = obj.Key ?? "";
              const size = obj.Size ?? 0;
              const lastModified = obj.LastModified ?? new Date(currentTime);
              if (key && lastModified < new Date(currentTime - this.props.createdBufferDays * DAY)) {
                batch.push(new ObjectAsset(bucket, key, size));
              }
            });
            continuationToken = response.NextContinuationToken;
            if (!continuationToken) break;
          }
          if (batch.length > 0) {
            yield batch;
          }
        } while (continuationToken);
      }
      async confirmationPrompt(printer, deletables, type) {
        const pluralize = /* @__PURE__ */ __name((name, count) => {
          return count === 1 ? name : `${name}s`;
        }, "pluralize");
        if (this.confirm) {
          const message2 = [
            `Found ${deletables.length} ${pluralize(type, deletables.length)} to delete based off of the following criteria:`,
            `- ${type}s have been isolated for > ${this.props.rollbackBufferDays} days`,
            `- ${type}s were created > ${this.props.createdBufferDays} days ago`,
            "",
            "Delete this batch?"
          ].join("\n");
          printer.pause();
          const response = await this.ioHelper.requestResponse(IO.CDK_TOOLKIT_I9210.req(message2, {
            batch: {
              type,
              count: deletables.length,
              rollbackBufferDays: this.props.rollbackBufferDays,
              createdBufferDays: this.props.createdBufferDays
            },
            responseDescription: "[y]es/[n]o/[a]ll"
          }, "y"));
          const yes = ["y", "yes"];
          const all = ["a", "all", "delete-all"];
          if (!response || ![...yes, ...all].includes(response.toLowerCase())) {
            throw new ToolkitError("DeletionAborted", "Deletion aborted by user");
          } else if (all.includes(response.toLowerCase())) {
            this.confirm = false;
          }
        }
        printer.resume();
      }
    };
    __name(partition3, "partition");
    __name(imageMap, "imageMap");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/garbage-collection/index.ts
var init_garbage_collection = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/garbage-collection/index.ts"() {
    "use strict";
    init_garbage_collector();
    init_progress_printer();
    init_stack_refresh();
  }
});

// lib/api/index.ts
var api_exports = {};
__export(api_exports, {
  ALL_STACKS: () => ALL_STACKS,
  AccountAccessKeyCache: () => AccountAccessKeyCache,
  ActiveAssetCache: () => ActiveAssetCache,
  AssetManifestBuilder: () => AssetManifestBuilder,
  AwsCliCompatible: () => AwsCliCompatible,
  BOOTSTRAP_VARIANT_PARAMETER: () => BOOTSTRAP_VARIANT_PARAMETER,
  BOOTSTRAP_VERSION_OUTPUT: () => BOOTSTRAP_VERSION_OUTPUT,
  BOOTSTRAP_VERSION_RESOURCE: () => BOOTSTRAP_VERSION_RESOURCE,
  BUCKET_DOMAIN_NAME_OUTPUT: () => BUCKET_DOMAIN_NAME_OUTPUT,
  BUCKET_NAME_OUTPUT: () => BUCKET_NAME_OUTPUT,
  BackgroundStackRefresh: () => BackgroundStackRefresh,
  BaseCredentials: () => BaseCredentials,
  BaseStackAssembly: () => BaseStackAssembly,
  Bootstrapper: () => Bootstrapper,
  CachedCloudAssembly: () => CachedCloudAssembly,
  CdkAppMultiContext: () => CdkAppMultiContext,
  CfnEvaluationException: () => CfnEvaluationException,
  CloudAssemblySourceBuilder: () => CloudAssemblySourceBuilder,
  CloudFormationStack: () => CloudFormationStack,
  CloudWatchLogEventMonitor: () => CloudWatchLogEventMonitor,
  ContextAwareCloudAssemblySource: () => ContextAwareCloudAssemblySource,
  CredentialPlugins: () => CredentialPlugins,
  DEFAULT_BOOTSTRAP_VARIANT: () => DEFAULT_BOOTSTRAP_VARIANT,
  DEFAULT_TOOLKIT_STACK_NAME: () => DEFAULT_TOOLKIT_STACK_NAME,
  DeploymentState: () => DeploymentState,
  Deployments: () => Deployments,
  DiffFormatter: () => DiffFormatter,
  ECR_ISOLATED_TAG: () => ECR_ISOLATED_TAG,
  EvaluateCloudFormationTemplate: () => EvaluateCloudFormationTemplate,
  ExecutionEnvironment: () => ExecutionEnvironment,
  ExpandStackSelection: () => ExpandStackSelection,
  ExtendedStackSelection: () => ExtendedStackSelection,
  FileContext: () => FileContext,
  GarbageCollector: () => GarbageCollector,
  ImageAsset: () => ImageAsset,
  IoHostSdkLogger: () => IoHostSdkLogger,
  LazyListStackResources: () => LazyListStackResources,
  LazyLookupExport: () => LazyLookupExport,
  LookupExportError: () => LookupExportError,
  MemoryContext: () => MemoryContext,
  Notices: () => Notices,
  ObjectAsset: () => ObjectAsset,
  ProgressPrinter: () => ProgressPrinter,
  REPOSITORY_NAME_OUTPUT: () => REPOSITORY_NAME_OUTPUT,
  RESOURCE_TYPE_PRIMARY_IDENTIFIERS: () => RESOURCE_TYPE_PRIMARY_IDENTIFIERS,
  RWLock: () => RWLock,
  ResourceImporter: () => ResourceImporter,
  ResourceMigrator: () => ResourceMigrator,
  ResourceOrphaner: () => ResourceOrphaner,
  S3_ISOLATED_TAG: () => S3_ISOLATED_TAG,
  SDK: () => SDK,
  SdkProvider: () => SdkProvider,
  StackAssembly: () => StackAssembly,
  StackCollection: () => StackCollection,
  StackSelectionStrategy: () => StackSelectionStrategy,
  ToolkitInfo: () => ToolkitInfo,
  WorkGraph: () => WorkGraph,
  WorkGraphBuilder: () => WorkGraphBuilder,
  addMetadataAssetsToManifest: () => addMetadataAssetsToManifest,
  assemblyFromDirectory: () => assemblyFromDirectory,
  assertIsSuccessfulDeployStackResult: () => assertIsSuccessfulDeployStackResult,
  buildDestroyWorkGraph: () => buildDestroyWorkGraph,
  buildLogicalToPathMap: () => buildLogicalToPathMap,
  cached: () => cached2,
  cappedExponentialBackoff: () => cappedExponentialBackoff,
  contextFromSettings: () => contextFromSettings,
  credentialsAboutToExpire: () => credentialsAboutToExpire,
  defaultCliUserAgent: () => defaultCliUserAgent,
  determineAllowCrossAccountAssetPublishing: () => determineAllowCrossAccountAssetPublishing,
  execInChildProcess: () => execInChildProcess,
  findCloudWatchLogGroups: () => findCloudWatchLogGroups,
  findConstructLibraryVersion: () => findConstructLibraryVersion,
  formatSdkLoggerContent: () => formatSdkLoggerContent,
  frameworkSupportsContextOverflow: () => frameworkSupportsContextOverflow,
  getBootstrapStackInfo: () => getBootstrapStackInfo,
  guessExecutable: () => guessExecutable,
  initContextProviderSdk: () => initContextProviderSdk,
  legacyBootstrapTemplate: () => legacyBootstrapTemplate,
  loadCurrentTemplate: () => loadCurrentTemplate,
  loadCurrentTemplateWithNestedStacks: () => loadCurrentTemplateWithNestedStacks,
  loadTree: () => loadTree,
  makeBodyParameter: () => makeBodyParameter,
  parametersFromSynthOptions: () => parametersFromSynthOptions,
  persistableContext: () => persistableContext,
  prepareDefaultEnvironment: () => prepareDefaultEnvironment,
  refreshStacks: () => refreshStacks,
  removeNonImportResources: () => removeNonImportResources,
  restUrlFromManifest: () => restUrlFromManifest,
  sdkRequestHandler: () => sdkRequestHandler,
  setSdkTracing: () => setSdkTracing,
  settingsFromSynthOptions: () => settingsFromSynthOptions,
  some: () => some,
  spaceAvailableForContext: () => spaceAvailableForContext,
  synthParametersFromSettings: () => synthParametersFromSettings,
  writeContextToEnv: () => writeContextToEnv
});
var init_api = __esm({
  "lib/api/index.ts"() {
    "use strict";
    init_bootstrap3();
    init_cloudformation3();
    init_cloud_assembly4();
    init_deployments3();
    init_aws_auth2();
    init_cloud_assembly4();
    init_notices3();
    init_diff3();
    init_io();
    init_logs_monitor3();
    init_resource_import();
    init_orphaner();
    init_rwlock();
    init_toolkit_info();
    init_tree();
    init_work_graph2();
    init_garbage_collection();
  }
});

// ../../node_modules/readdirp/esm/index.js
function readdirp(root32, options = {}) {
  let type = options.entryType || options.type;
  if (type === "both")
    type = EntryTypes.FILE_DIR_TYPE;
  if (type)
    options.type = type;
  if (!root32) {
    throw new Error("readdirp: root argument is required. Usage: readdirp(root, options)");
  } else if (typeof root32 !== "string") {
    throw new TypeError("readdirp: root argument must be a string. Usage: readdirp(root, options)");
  } else if (type && !ALL_TYPES.includes(type)) {
    throw new Error(`readdirp: Invalid type passed. Use one of ${ALL_TYPES.join(", ")}`);
  }
  options.root = root32;
  return new ReaddirpStream(options);
}
var import_promises8, import_node_stream29, import_node_path21, EntryTypes, defaultOptions, RECURSIVE_ERROR_CODE, NORMAL_FLOW_ERRORS, ALL_TYPES, DIR_TYPES, FILE_TYPES, isNormalFlowError, wantBigintFsStats, emptyFn, normalizeFilter, ReaddirpStream;
var init_esm = __esm({
  "../../node_modules/readdirp/esm/index.js"() {
    import_promises8 = require("node:fs/promises");
    import_node_stream29 = require("node:stream");
    import_node_path21 = require("node:path");
    EntryTypes = {
      FILE_TYPE: "files",
      DIR_TYPE: "directories",
      FILE_DIR_TYPE: "files_directories",
      EVERYTHING_TYPE: "all"
    };
    defaultOptions = {
      root: ".",
      fileFilter: /* @__PURE__ */ __name((_entryInfo) => true, "fileFilter"),
      directoryFilter: /* @__PURE__ */ __name((_entryInfo) => true, "directoryFilter"),
      type: EntryTypes.FILE_TYPE,
      lstat: false,
      depth: 2147483648,
      alwaysStat: false,
      highWaterMark: 4096
    };
    Object.freeze(defaultOptions);
    RECURSIVE_ERROR_CODE = "READDIRP_RECURSIVE_ERROR";
    NORMAL_FLOW_ERRORS = /* @__PURE__ */ new Set(["ENOENT", "EPERM", "EACCES", "ELOOP", RECURSIVE_ERROR_CODE]);
    ALL_TYPES = [
      EntryTypes.DIR_TYPE,
      EntryTypes.EVERYTHING_TYPE,
      EntryTypes.FILE_DIR_TYPE,
      EntryTypes.FILE_TYPE
    ];
    DIR_TYPES = /* @__PURE__ */ new Set([
      EntryTypes.DIR_TYPE,
      EntryTypes.EVERYTHING_TYPE,
      EntryTypes.FILE_DIR_TYPE
    ]);
    FILE_TYPES = /* @__PURE__ */ new Set([
      EntryTypes.EVERYTHING_TYPE,
      EntryTypes.FILE_DIR_TYPE,
      EntryTypes.FILE_TYPE
    ]);
    isNormalFlowError = /* @__PURE__ */ __name((error4) => NORMAL_FLOW_ERRORS.has(error4.code), "isNormalFlowError");
    wantBigintFsStats = process.platform === "win32";
    emptyFn = /* @__PURE__ */ __name((_entryInfo) => true, "emptyFn");
    normalizeFilter = /* @__PURE__ */ __name((filter) => {
      if (filter === void 0)
        return emptyFn;
      if (typeof filter === "function")
        return filter;
      if (typeof filter === "string") {
        const fl = filter.trim();
        return (entry) => entry.basename === fl;
      }
      if (Array.isArray(filter)) {
        const trItems = filter.map((item) => item.trim());
        return (entry) => trItems.some((f32) => entry.basename === f32);
      }
      return emptyFn;
    }, "normalizeFilter");
    ReaddirpStream = class extends import_node_stream29.Readable {
      static {
        __name(this, "ReaddirpStream");
      }
      constructor(options = {}) {
        super({
          objectMode: true,
          autoDestroy: true,
          highWaterMark: options.highWaterMark
        });
        const opts = { ...defaultOptions, ...options };
        const { root: root32, type } = opts;
        this._fileFilter = normalizeFilter(opts.fileFilter);
        this._directoryFilter = normalizeFilter(opts.directoryFilter);
        const statMethod = opts.lstat ? import_promises8.lstat : import_promises8.stat;
        if (wantBigintFsStats) {
          this._stat = (path47) => statMethod(path47, { bigint: true });
        } else {
          this._stat = statMethod;
        }
        this._maxDepth = opts.depth ?? defaultOptions.depth;
        this._wantsDir = type ? DIR_TYPES.has(type) : false;
        this._wantsFile = type ? FILE_TYPES.has(type) : false;
        this._wantsEverything = type === EntryTypes.EVERYTHING_TYPE;
        this._root = (0, import_node_path21.resolve)(root32);
        this._isDirent = !opts.alwaysStat;
        this._statsProp = this._isDirent ? "dirent" : "stats";
        this._rdOptions = { encoding: "utf8", withFileTypes: this._isDirent };
        this.parents = [this._exploreDir(root32, 1)];
        this.reading = false;
        this.parent = void 0;
      }
      async _read(batch) {
        if (this.reading)
          return;
        this.reading = true;
        try {
          while (!this.destroyed && batch > 0) {
            const par = this.parent;
            const fil = par && par.files;
            if (fil && fil.length > 0) {
              const { path: path47, depth } = par;
              const slice = fil.splice(0, batch).map((dirent) => this._formatEntry(dirent, path47));
              const awaited = await Promise.all(slice);
              for (const entry of awaited) {
                if (!entry)
                  continue;
                if (this.destroyed)
                  return;
                const entryType = await this._getEntryType(entry);
                if (entryType === "directory" && this._directoryFilter(entry)) {
                  if (depth <= this._maxDepth) {
                    this.parents.push(this._exploreDir(entry.fullPath, depth + 1));
                  }
                  if (this._wantsDir) {
                    this.push(entry);
                    batch--;
                  }
                } else if ((entryType === "file" || this._includeAsFile(entry)) && this._fileFilter(entry)) {
                  if (this._wantsFile) {
                    this.push(entry);
                    batch--;
                  }
                }
              }
            } else {
              const parent = this.parents.pop();
              if (!parent) {
                this.push(null);
                break;
              }
              this.parent = await parent;
              if (this.destroyed)
                return;
            }
          }
        } catch (error4) {
          this.destroy(error4);
        } finally {
          this.reading = false;
        }
      }
      async _exploreDir(path47, depth) {
        let files;
        try {
          files = await (0, import_promises8.readdir)(path47, this._rdOptions);
        } catch (error4) {
          this._onError(error4);
        }
        return { files, depth, path: path47 };
      }
      async _formatEntry(dirent, path47) {
        let entry;
        const basename5 = this._isDirent ? dirent.name : dirent;
        try {
          const fullPath = (0, import_node_path21.resolve)((0, import_node_path21.join)(path47, basename5));
          entry = { path: (0, import_node_path21.relative)(this._root, fullPath), fullPath, basename: basename5 };
          entry[this._statsProp] = this._isDirent ? dirent : await this._stat(fullPath);
        } catch (err) {
          this._onError(err);
          return;
        }
        return entry;
      }
      _onError(err) {
        if (isNormalFlowError(err) && !this.destroyed) {
          this.emit("warn", err);
        } else {
          this.destroy(err);
        }
      }
      async _getEntryType(entry) {
        if (!entry && this._statsProp in entry) {
          return "";
        }
        const stats = entry[this._statsProp];
        if (stats.isFile())
          return "file";
        if (stats.isDirectory())
          return "directory";
        if (stats && stats.isSymbolicLink()) {
          const full = entry.fullPath;
          try {
            const entryRealPath = await (0, import_promises8.realpath)(full);
            const entryRealPathStats = await (0, import_promises8.lstat)(entryRealPath);
            if (entryRealPathStats.isFile()) {
              return "file";
            }
            if (entryRealPathStats.isDirectory()) {
              const len = entryRealPath.length;
              if (full.startsWith(entryRealPath) && full.substr(len, 1) === import_node_path21.sep) {
                const recursiveError = new Error(`Circular symlink detected: "${full}" points to "${entryRealPath}"`);
                recursiveError.code = RECURSIVE_ERROR_CODE;
                return this._onError(recursiveError);
              }
              return "directory";
            }
          } catch (error4) {
            this._onError(error4);
            return "";
          }
        }
      }
      _includeAsFile(entry) {
        const stats = entry && entry[this._statsProp];
        return stats && this._wantsEverything && !stats.isDirectory();
      }
    };
    __name(readdirp, "readdirp");
  }
});

// ../../node_modules/chokidar/esm/handler.js
function createFsWatchInstance(path47, options, listener, errHandler, emitRaw) {
  const handleEvent = /* @__PURE__ */ __name((rawEvent, evPath) => {
    listener(path47);
    emitRaw(rawEvent, evPath, { watchedPath: path47 });
    if (evPath && path47 !== evPath) {
      fsWatchBroadcast(sysPath.resolve(path47, evPath), KEY_LISTENERS, sysPath.join(path47, evPath));
    }
  }, "handleEvent");
  try {
    return (0, import_fs5.watch)(path47, {
      persistent: options.persistent
    }, handleEvent);
  } catch (error4) {
    errHandler(error4);
    return void 0;
  }
}
var import_fs5, import_promises9, sysPath, import_os, STR_DATA, STR_END, STR_CLOSE, EMPTY_FN, pl, isWindows, isMacos, isLinux, isFreeBSD, isIBMi, EVENTS, EV, THROTTLE_MODE_WATCH, statMethods, KEY_LISTENERS, KEY_ERR, KEY_RAW, HANDLER_KEYS, binaryExtensions, isBinaryPath, foreach, addAndConvert, clearItem, delFromSet, isEmptySet, FsWatchInstances, fsWatchBroadcast, setFsWatchListener, FsWatchFileInstances, setFsWatchFileListener, NodeFsHandler;
var init_handler = __esm({
  "../../node_modules/chokidar/esm/handler.js"() {
    import_fs5 = require("fs");
    import_promises9 = require("fs/promises");
    sysPath = __toESM(require("path"), 1);
    import_os = require("os");
    STR_DATA = "data";
    STR_END = "end";
    STR_CLOSE = "close";
    EMPTY_FN = /* @__PURE__ */ __name(() => {
    }, "EMPTY_FN");
    pl = process.platform;
    isWindows = pl === "win32";
    isMacos = pl === "darwin";
    isLinux = pl === "linux";
    isFreeBSD = pl === "freebsd";
    isIBMi = (0, import_os.type)() === "OS400";
    EVENTS = {
      ALL: "all",
      READY: "ready",
      ADD: "add",
      CHANGE: "change",
      ADD_DIR: "addDir",
      UNLINK: "unlink",
      UNLINK_DIR: "unlinkDir",
      RAW: "raw",
      ERROR: "error"
    };
    EV = EVENTS;
    THROTTLE_MODE_WATCH = "watch";
    statMethods = { lstat: import_promises9.lstat, stat: import_promises9.stat };
    KEY_LISTENERS = "listeners";
    KEY_ERR = "errHandlers";
    KEY_RAW = "rawEmitters";
    HANDLER_KEYS = [KEY_LISTENERS, KEY_ERR, KEY_RAW];
    binaryExtensions = /* @__PURE__ */ new Set([
      "3dm",
      "3ds",
      "3g2",
      "3gp",
      "7z",
      "a",
      "aac",
      "adp",
      "afdesign",
      "afphoto",
      "afpub",
      "ai",
      "aif",
      "aiff",
      "alz",
      "ape",
      "apk",
      "appimage",
      "ar",
      "arj",
      "asf",
      "au",
      "avi",
      "bak",
      "baml",
      "bh",
      "bin",
      "bk",
      "bmp",
      "btif",
      "bz2",
      "bzip2",
      "cab",
      "caf",
      "cgm",
      "class",
      "cmx",
      "cpio",
      "cr2",
      "cur",
      "dat",
      "dcm",
      "deb",
      "dex",
      "djvu",
      "dll",
      "dmg",
      "dng",
      "doc",
      "docm",
      "docx",
      "dot",
      "dotm",
      "dra",
      "DS_Store",
      "dsk",
      "dts",
      "dtshd",
      "dvb",
      "dwg",
      "dxf",
      "ecelp4800",
      "ecelp7470",
      "ecelp9600",
      "egg",
      "eol",
      "eot",
      "epub",
      "exe",
      "f4v",
      "fbs",
      "fh",
      "fla",
      "flac",
      "flatpak",
      "fli",
      "flv",
      "fpx",
      "fst",
      "fvt",
      "g3",
      "gh",
      "gif",
      "graffle",
      "gz",
      "gzip",
      "h261",
      "h263",
      "h264",
      "icns",
      "ico",
      "ief",
      "img",
      "ipa",
      "iso",
      "jar",
      "jpeg",
      "jpg",
      "jpgv",
      "jpm",
      "jxr",
      "key",
      "ktx",
      "lha",
      "lib",
      "lvp",
      "lz",
      "lzh",
      "lzma",
      "lzo",
      "m3u",
      "m4a",
      "m4v",
      "mar",
      "mdi",
      "mht",
      "mid",
      "midi",
      "mj2",
      "mka",
      "mkv",
      "mmr",
      "mng",
      "mobi",
      "mov",
      "movie",
      "mp3",
      "mp4",
      "mp4a",
      "mpeg",
      "mpg",
      "mpga",
      "mxu",
      "nef",
      "npx",
      "numbers",
      "nupkg",
      "o",
      "odp",
      "ods",
      "odt",
      "oga",
      "ogg",
      "ogv",
      "otf",
      "ott",
      "pages",
      "pbm",
      "pcx",
      "pdb",
      "pdf",
      "pea",
      "pgm",
      "pic",
      "png",
      "pnm",
      "pot",
      "potm",
      "potx",
      "ppa",
      "ppam",
      "ppm",
      "pps",
      "ppsm",
      "ppsx",
      "ppt",
      "pptm",
      "pptx",
      "psd",
      "pya",
      "pyc",
      "pyo",
      "pyv",
      "qt",
      "rar",
      "ras",
      "raw",
      "resources",
      "rgb",
      "rip",
      "rlc",
      "rmf",
      "rmvb",
      "rpm",
      "rtf",
      "rz",
      "s3m",
      "s7z",
      "scpt",
      "sgi",
      "shar",
      "snap",
      "sil",
      "sketch",
      "slk",
      "smv",
      "snk",
      "so",
      "stl",
      "suo",
      "sub",
      "swf",
      "tar",
      "tbz",
      "tbz2",
      "tga",
      "tgz",
      "thmx",
      "tif",
      "tiff",
      "tlz",
      "ttc",
      "ttf",
      "txz",
      "udf",
      "uvh",
      "uvi",
      "uvm",
      "uvp",
      "uvs",
      "uvu",
      "viv",
      "vob",
      "war",
      "wav",
      "wax",
      "wbmp",
      "wdp",
      "weba",
      "webm",
      "webp",
      "whl",
      "wim",
      "wm",
      "wma",
      "wmv",
      "wmx",
      "woff",
      "woff2",
      "wrm",
      "wvx",
      "xbm",
      "xif",
      "xla",
      "xlam",
      "xls",
      "xlsb",
      "xlsm",
      "xlsx",
      "xlt",
      "xltm",
      "xltx",
      "xm",
      "xmind",
      "xpi",
      "xpm",
      "xwd",
      "xz",
      "z",
      "zip",
      "zipx"
    ]);
    isBinaryPath = /* @__PURE__ */ __name((filePath) => binaryExtensions.has(sysPath.extname(filePath).slice(1).toLowerCase()), "isBinaryPath");
    foreach = /* @__PURE__ */ __name((val, fn) => {
      if (val instanceof Set) {
        val.forEach(fn);
      } else {
        fn(val);
      }
    }, "foreach");
    addAndConvert = /* @__PURE__ */ __name((main, prop, item) => {
      let container = main[prop];
      if (!(container instanceof Set)) {
        main[prop] = container = /* @__PURE__ */ new Set([container]);
      }
      container.add(item);
    }, "addAndConvert");
    clearItem = /* @__PURE__ */ __name((cont) => (key) => {
      const set = cont[key];
      if (set instanceof Set) {
        set.clear();
      } else {
        delete cont[key];
      }
    }, "clearItem");
    delFromSet = /* @__PURE__ */ __name((main, prop, item) => {
      const container = main[prop];
      if (container instanceof Set) {
        container.delete(item);
      } else if (container === item) {
        delete main[prop];
      }
    }, "delFromSet");
    isEmptySet = /* @__PURE__ */ __name((val) => val instanceof Set ? val.size === 0 : !val, "isEmptySet");
    FsWatchInstances = /* @__PURE__ */ new Map();
    __name(createFsWatchInstance, "createFsWatchInstance");
    fsWatchBroadcast = /* @__PURE__ */ __name((fullPath, listenerType, val1, val2, val3) => {
      const cont = FsWatchInstances.get(fullPath);
      if (!cont)
        return;
      foreach(cont[listenerType], (listener) => {
        listener(val1, val2, val3);
      });
    }, "fsWatchBroadcast");
    setFsWatchListener = /* @__PURE__ */ __name((path47, fullPath, options, handlers) => {
      const { listener, errHandler, rawEmitter } = handlers;
      let cont = FsWatchInstances.get(fullPath);
      let watcher;
      if (!options.persistent) {
        watcher = createFsWatchInstance(path47, options, listener, errHandler, rawEmitter);
        if (!watcher)
          return;
        return watcher.close.bind(watcher);
      }
      if (cont) {
        addAndConvert(cont, KEY_LISTENERS, listener);
        addAndConvert(cont, KEY_ERR, errHandler);
        addAndConvert(cont, KEY_RAW, rawEmitter);
      } else {
        watcher = createFsWatchInstance(
          path47,
          options,
          fsWatchBroadcast.bind(null, fullPath, KEY_LISTENERS),
          errHandler,
          // no need to use broadcast here
          fsWatchBroadcast.bind(null, fullPath, KEY_RAW)
        );
        if (!watcher)
          return;
        watcher.on(EV.ERROR, async (error4) => {
          const broadcastErr = fsWatchBroadcast.bind(null, fullPath, KEY_ERR);
          if (cont)
            cont.watcherUnusable = true;
          if (isWindows && error4.code === "EPERM") {
            try {
              const fd = await (0, import_promises9.open)(path47, "r");
              await fd.close();
              broadcastErr(error4);
            } catch (err) {
            }
          } else {
            broadcastErr(error4);
          }
        });
        cont = {
          listeners: listener,
          errHandlers: errHandler,
          rawEmitters: rawEmitter,
          watcher
        };
        FsWatchInstances.set(fullPath, cont);
      }
      return () => {
        delFromSet(cont, KEY_LISTENERS, listener);
        delFromSet(cont, KEY_ERR, errHandler);
        delFromSet(cont, KEY_RAW, rawEmitter);
        if (isEmptySet(cont.listeners)) {
          cont.watcher.close();
          FsWatchInstances.delete(fullPath);
          HANDLER_KEYS.forEach(clearItem(cont));
          cont.watcher = void 0;
          Object.freeze(cont);
        }
      };
    }, "setFsWatchListener");
    FsWatchFileInstances = /* @__PURE__ */ new Map();
    setFsWatchFileListener = /* @__PURE__ */ __name((path47, fullPath, options, handlers) => {
      const { listener, rawEmitter } = handlers;
      let cont = FsWatchFileInstances.get(fullPath);
      const copts = cont && cont.options;
      if (copts && (copts.persistent < options.persistent || copts.interval > options.interval)) {
        (0, import_fs5.unwatchFile)(fullPath);
        cont = void 0;
      }
      if (cont) {
        addAndConvert(cont, KEY_LISTENERS, listener);
        addAndConvert(cont, KEY_RAW, rawEmitter);
      } else {
        cont = {
          listeners: listener,
          rawEmitters: rawEmitter,
          options,
          watcher: (0, import_fs5.watchFile)(fullPath, options, (curr, prev) => {
            foreach(cont.rawEmitters, (rawEmitter2) => {
              rawEmitter2(EV.CHANGE, fullPath, { curr, prev });
            });
            const currmtime = curr.mtimeMs;
            if (curr.size !== prev.size || currmtime > prev.mtimeMs || currmtime === 0) {
              foreach(cont.listeners, (listener2) => listener2(path47, curr));
            }
          })
        };
        FsWatchFileInstances.set(fullPath, cont);
      }
      return () => {
        delFromSet(cont, KEY_LISTENERS, listener);
        delFromSet(cont, KEY_RAW, rawEmitter);
        if (isEmptySet(cont.listeners)) {
          FsWatchFileInstances.delete(fullPath);
          (0, import_fs5.unwatchFile)(fullPath);
          cont.options = cont.watcher = void 0;
          Object.freeze(cont);
        }
      };
    }, "setFsWatchFileListener");
    NodeFsHandler = class {
      static {
        __name(this, "NodeFsHandler");
      }
      constructor(fsW) {
        this.fsw = fsW;
        this._boundHandleError = (error4) => fsW._handleError(error4);
      }
      /**
       * Watch file for changes with fs_watchFile or fs_watch.
       * @param path to file or dir
       * @param listener on fs change
       * @returns closer for the watcher instance
       */
      _watchWithNodeFs(path47, listener) {
        const opts = this.fsw.options;
        const directory = sysPath.dirname(path47);
        const basename5 = sysPath.basename(path47);
        const parent = this.fsw._getWatchedDir(directory);
        parent.add(basename5);
        const absolutePath = sysPath.resolve(path47);
        const options = {
          persistent: opts.persistent
        };
        if (!listener)
          listener = EMPTY_FN;
        let closer;
        if (opts.usePolling) {
          const enableBin = opts.interval !== opts.binaryInterval;
          options.interval = enableBin && isBinaryPath(basename5) ? opts.binaryInterval : opts.interval;
          closer = setFsWatchFileListener(path47, absolutePath, options, {
            listener,
            rawEmitter: this.fsw._emitRaw
          });
        } else {
          closer = setFsWatchListener(path47, absolutePath, options, {
            listener,
            errHandler: this._boundHandleError,
            rawEmitter: this.fsw._emitRaw
          });
        }
        return closer;
      }
      /**
       * Watch a file and emit add event if warranted.
       * @returns closer for the watcher instance
       */
      _handleFile(file, stats, initialAdd) {
        if (this.fsw.closed) {
          return;
        }
        const dirname14 = sysPath.dirname(file);
        const basename5 = sysPath.basename(file);
        const parent = this.fsw._getWatchedDir(dirname14);
        let prevStats = stats;
        if (parent.has(basename5))
          return;
        const listener = /* @__PURE__ */ __name(async (path47, newStats) => {
          if (!this.fsw._throttle(THROTTLE_MODE_WATCH, file, 5))
            return;
          if (!newStats || newStats.mtimeMs === 0) {
            try {
              const newStats2 = await (0, import_promises9.stat)(file);
              if (this.fsw.closed)
                return;
              const at = newStats2.atimeMs;
              const mt = newStats2.mtimeMs;
              if (!at || at <= mt || mt !== prevStats.mtimeMs) {
                this.fsw._emit(EV.CHANGE, file, newStats2);
              }
              if ((isMacos || isLinux || isFreeBSD) && prevStats.ino !== newStats2.ino) {
                this.fsw._closeFile(path47);
                prevStats = newStats2;
                const closer2 = this._watchWithNodeFs(file, listener);
                if (closer2)
                  this.fsw._addPathCloser(path47, closer2);
              } else {
                prevStats = newStats2;
              }
            } catch (error4) {
              this.fsw._remove(dirname14, basename5);
            }
          } else if (parent.has(basename5)) {
            const at = newStats.atimeMs;
            const mt = newStats.mtimeMs;
            if (!at || at <= mt || mt !== prevStats.mtimeMs) {
              this.fsw._emit(EV.CHANGE, file, newStats);
            }
            prevStats = newStats;
          }
        }, "listener");
        const closer = this._watchWithNodeFs(file, listener);
        if (!(initialAdd && this.fsw.options.ignoreInitial) && this.fsw._isntIgnored(file)) {
          if (!this.fsw._throttle(EV.ADD, file, 0))
            return;
          this.fsw._emit(EV.ADD, file, stats);
        }
        return closer;
      }
      /**
       * Handle symlinks encountered while reading a dir.
       * @param entry returned by readdirp
       * @param directory path of dir being read
       * @param path of this item
       * @param item basename of this item
       * @returns true if no more processing is needed for this entry.
       */
      async _handleSymlink(entry, directory, path47, item) {
        if (this.fsw.closed) {
          return;
        }
        const full = entry.fullPath;
        const dir = this.fsw._getWatchedDir(directory);
        if (!this.fsw.options.followSymlinks) {
          this.fsw._incrReadyCount();
          let linkPath;
          try {
            linkPath = await (0, import_promises9.realpath)(path47);
          } catch (e32) {
            this.fsw._emitReady();
            return true;
          }
          if (this.fsw.closed)
            return;
          if (dir.has(item)) {
            if (this.fsw._symlinkPaths.get(full) !== linkPath) {
              this.fsw._symlinkPaths.set(full, linkPath);
              this.fsw._emit(EV.CHANGE, path47, entry.stats);
            }
          } else {
            dir.add(item);
            this.fsw._symlinkPaths.set(full, linkPath);
            this.fsw._emit(EV.ADD, path47, entry.stats);
          }
          this.fsw._emitReady();
          return true;
        }
        if (this.fsw._symlinkPaths.has(full)) {
          return true;
        }
        this.fsw._symlinkPaths.set(full, true);
      }
      _handleRead(directory, initialAdd, wh, target, dir, depth, throttler) {
        directory = sysPath.join(directory, "");
        throttler = this.fsw._throttle("readdir", directory, 1e3);
        if (!throttler)
          return;
        const previous = this.fsw._getWatchedDir(wh.path);
        const current = /* @__PURE__ */ new Set();
        let stream = this.fsw._readdirp(directory, {
          fileFilter: /* @__PURE__ */ __name((entry) => wh.filterPath(entry), "fileFilter"),
          directoryFilter: /* @__PURE__ */ __name((entry) => wh.filterDir(entry), "directoryFilter")
        });
        if (!stream)
          return;
        stream.on(STR_DATA, async (entry) => {
          if (this.fsw.closed) {
            stream = void 0;
            return;
          }
          const item = entry.path;
          let path47 = sysPath.join(directory, item);
          current.add(item);
          if (entry.stats.isSymbolicLink() && await this._handleSymlink(entry, directory, path47, item)) {
            return;
          }
          if (this.fsw.closed) {
            stream = void 0;
            return;
          }
          if (item === target || !target && !previous.has(item)) {
            this.fsw._incrReadyCount();
            path47 = sysPath.join(dir, sysPath.relative(dir, path47));
            this._addToNodeFs(path47, initialAdd, wh, depth + 1);
          }
        }).on(EV.ERROR, this._boundHandleError);
        return new Promise((resolve13, reject) => {
          if (!stream)
            return reject();
          stream.once(STR_END, () => {
            if (this.fsw.closed) {
              stream = void 0;
              return;
            }
            const wasThrottled = throttler ? throttler.clear() : false;
            resolve13(void 0);
            previous.getChildren().filter((item) => {
              return item !== directory && !current.has(item);
            }).forEach((item) => {
              this.fsw._remove(directory, item);
            });
            stream = void 0;
            if (wasThrottled)
              this._handleRead(directory, false, wh, target, dir, depth, throttler);
          });
        });
      }
      /**
       * Read directory to add / remove files from `@watched` list and re-read it on change.
       * @param dir fs path
       * @param stats
       * @param initialAdd
       * @param depth relative to user-supplied path
       * @param target child path targeted for watch
       * @param wh Common watch helpers for this path
       * @param realpath
       * @returns closer for the watcher instance.
       */
      async _handleDir(dir, stats, initialAdd, depth, target, wh, realpath2) {
        const parentDir = this.fsw._getWatchedDir(sysPath.dirname(dir));
        const tracked = parentDir.has(sysPath.basename(dir));
        if (!(initialAdd && this.fsw.options.ignoreInitial) && !target && !tracked) {
          this.fsw._emit(EV.ADD_DIR, dir, stats);
        }
        parentDir.add(sysPath.basename(dir));
        this.fsw._getWatchedDir(dir);
        let throttler;
        let closer;
        const oDepth = this.fsw.options.depth;
        if ((oDepth == null || depth <= oDepth) && !this.fsw._symlinkPaths.has(realpath2)) {
          if (!target) {
            await this._handleRead(dir, initialAdd, wh, target, dir, depth, throttler);
            if (this.fsw.closed)
              return;
          }
          closer = this._watchWithNodeFs(dir, (dirPath, stats2) => {
            if (stats2 && stats2.mtimeMs === 0)
              return;
            this._handleRead(dirPath, false, wh, target, dir, depth, throttler);
          });
        }
        return closer;
      }
      /**
       * Handle added file, directory, or glob pattern.
       * Delegates call to _handleFile / _handleDir after checks.
       * @param path to file or ir
       * @param initialAdd was the file added at watch instantiation?
       * @param priorWh depth relative to user-supplied path
       * @param depth Child path actually targeted for watch
       * @param target Child path actually targeted for watch
       */
      async _addToNodeFs(path47, initialAdd, priorWh, depth, target) {
        const ready = this.fsw._emitReady;
        if (this.fsw._isIgnored(path47) || this.fsw.closed) {
          ready();
          return false;
        }
        const wh = this.fsw._getWatchHelpers(path47);
        if (priorWh) {
          wh.filterPath = (entry) => priorWh.filterPath(entry);
          wh.filterDir = (entry) => priorWh.filterDir(entry);
        }
        try {
          const stats = await statMethods[wh.statMethod](wh.watchPath);
          if (this.fsw.closed)
            return;
          if (this.fsw._isIgnored(wh.watchPath, stats)) {
            ready();
            return false;
          }
          const follow = this.fsw.options.followSymlinks;
          let closer;
          if (stats.isDirectory()) {
            const absPath = sysPath.resolve(path47);
            const targetPath = follow ? await (0, import_promises9.realpath)(path47) : path47;
            if (this.fsw.closed)
              return;
            closer = await this._handleDir(wh.watchPath, stats, initialAdd, depth, target, wh, targetPath);
            if (this.fsw.closed)
              return;
            if (absPath !== targetPath && targetPath !== void 0) {
              this.fsw._symlinkPaths.set(absPath, targetPath);
            }
          } else if (stats.isSymbolicLink()) {
            const targetPath = follow ? await (0, import_promises9.realpath)(path47) : path47;
            if (this.fsw.closed)
              return;
            const parent = sysPath.dirname(wh.watchPath);
            this.fsw._getWatchedDir(parent).add(wh.watchPath);
            this.fsw._emit(EV.ADD, wh.watchPath, stats);
            closer = await this._handleDir(parent, stats, initialAdd, depth, path47, wh, targetPath);
            if (this.fsw.closed)
              return;
            if (targetPath !== void 0) {
              this.fsw._symlinkPaths.set(sysPath.resolve(path47), targetPath);
            }
          } else {
            closer = this._handleFile(wh.watchPath, stats, initialAdd);
          }
          ready();
          if (closer)
            this.fsw._addPathCloser(path47, closer);
          return false;
        } catch (error4) {
          if (this.fsw._handleError(error4)) {
            ready();
            return path47;
          }
        }
      }
    };
  }
});

// ../../node_modules/chokidar/esm/index.js
function arrify(item) {
  return Array.isArray(item) ? item : [item];
}
function createPattern(matcher) {
  if (typeof matcher === "function")
    return matcher;
  if (typeof matcher === "string")
    return (string) => matcher === string;
  if (matcher instanceof RegExp)
    return (string) => matcher.test(string);
  if (typeof matcher === "object" && matcher !== null) {
    return (string) => {
      if (matcher.path === string)
        return true;
      if (matcher.recursive) {
        const relative5 = sysPath2.relative(matcher.path, string);
        if (!relative5) {
          return false;
        }
        return !relative5.startsWith("..") && !sysPath2.isAbsolute(relative5);
      }
      return false;
    };
  }
  return () => false;
}
function normalizePath(path47) {
  if (typeof path47 !== "string")
    throw new Error("string expected");
  path47 = sysPath2.normalize(path47);
  path47 = path47.replace(/\\/g, "/");
  let prepend = false;
  if (path47.startsWith("//"))
    prepend = true;
  const DOUBLE_SLASH_RE2 = /\/\//;
  while (path47.match(DOUBLE_SLASH_RE2))
    path47 = path47.replace(DOUBLE_SLASH_RE2, "/");
  if (prepend)
    path47 = "/" + path47;
  return path47;
}
function matchPatterns(patterns, testString, stats) {
  const path47 = normalizePath(testString);
  for (let index = 0; index < patterns.length; index++) {
    const pattern = patterns[index];
    if (pattern(path47, stats)) {
      return true;
    }
  }
  return false;
}
function anymatch(matchers, testString) {
  if (matchers == null) {
    throw new TypeError("anymatch: specify first argument");
  }
  const matchersArray = arrify(matchers);
  const patterns = matchersArray.map((matcher) => createPattern(matcher));
  if (testString == null) {
    return (testString2, stats) => {
      return matchPatterns(patterns, testString2, stats);
    };
  }
  return matchPatterns(patterns, testString);
}
function watch(paths, options = {}) {
  const watcher = new FSWatcher(options);
  watcher.add(paths);
  return watcher;
}
var import_fs6, import_promises10, import_events, sysPath2, SLASH, SLASH_SLASH, ONE_DOT, TWO_DOTS, STRING_TYPE, BACK_SLASH_RE, DOUBLE_SLASH_RE, DOT_RE, REPLACER_RE, isMatcherObject, unifyPaths, toUnix, normalizePathToUnix, normalizeIgnored, getAbsolutePath, EMPTY_SET, DirEntry, STAT_METHOD_F, STAT_METHOD_L, WatchHelper, FSWatcher;
var init_esm2 = __esm({
  "../../node_modules/chokidar/esm/index.js"() {
    import_fs6 = require("fs");
    import_promises10 = require("fs/promises");
    import_events = require("events");
    sysPath2 = __toESM(require("path"), 1);
    init_esm();
    init_handler();
    SLASH = "/";
    SLASH_SLASH = "//";
    ONE_DOT = ".";
    TWO_DOTS = "..";
    STRING_TYPE = "string";
    BACK_SLASH_RE = /\\/g;
    DOUBLE_SLASH_RE = /\/\//;
    DOT_RE = /\..*\.(sw[px])$|~$|\.subl.*\.tmp/;
    REPLACER_RE = /^\.[/\\]/;
    __name(arrify, "arrify");
    isMatcherObject = /* @__PURE__ */ __name((matcher) => typeof matcher === "object" && matcher !== null && !(matcher instanceof RegExp), "isMatcherObject");
    __name(createPattern, "createPattern");
    __name(normalizePath, "normalizePath");
    __name(matchPatterns, "matchPatterns");
    __name(anymatch, "anymatch");
    unifyPaths = /* @__PURE__ */ __name((paths_) => {
      const paths = arrify(paths_).flat();
      if (!paths.every((p10) => typeof p10 === STRING_TYPE)) {
        throw new TypeError(`Non-string provided as watch path: ${paths}`);
      }
      return paths.map(normalizePathToUnix);
    }, "unifyPaths");
    toUnix = /* @__PURE__ */ __name((string) => {
      let str = string.replace(BACK_SLASH_RE, SLASH);
      let prepend = false;
      if (str.startsWith(SLASH_SLASH)) {
        prepend = true;
      }
      while (str.match(DOUBLE_SLASH_RE)) {
        str = str.replace(DOUBLE_SLASH_RE, SLASH);
      }
      if (prepend) {
        str = SLASH + str;
      }
      return str;
    }, "toUnix");
    normalizePathToUnix = /* @__PURE__ */ __name((path47) => toUnix(sysPath2.normalize(toUnix(path47))), "normalizePathToUnix");
    normalizeIgnored = /* @__PURE__ */ __name((cwd = "") => (path47) => {
      if (typeof path47 === "string") {
        return normalizePathToUnix(sysPath2.isAbsolute(path47) ? path47 : sysPath2.join(cwd, path47));
      } else {
        return path47;
      }
    }, "normalizeIgnored");
    getAbsolutePath = /* @__PURE__ */ __name((path47, cwd) => {
      if (sysPath2.isAbsolute(path47)) {
        return path47;
      }
      return sysPath2.join(cwd, path47);
    }, "getAbsolutePath");
    EMPTY_SET = Object.freeze(/* @__PURE__ */ new Set());
    DirEntry = class {
      static {
        __name(this, "DirEntry");
      }
      constructor(dir, removeWatcher) {
        this.path = dir;
        this._removeWatcher = removeWatcher;
        this.items = /* @__PURE__ */ new Set();
      }
      add(item) {
        const { items } = this;
        if (!items)
          return;
        if (item !== ONE_DOT && item !== TWO_DOTS)
          items.add(item);
      }
      async remove(item) {
        const { items } = this;
        if (!items)
          return;
        items.delete(item);
        if (items.size > 0)
          return;
        const dir = this.path;
        try {
          await (0, import_promises10.readdir)(dir);
        } catch (err) {
          if (this._removeWatcher) {
            this._removeWatcher(sysPath2.dirname(dir), sysPath2.basename(dir));
          }
        }
      }
      has(item) {
        const { items } = this;
        if (!items)
          return;
        return items.has(item);
      }
      getChildren() {
        const { items } = this;
        if (!items)
          return [];
        return [...items.values()];
      }
      dispose() {
        this.items.clear();
        this.path = "";
        this._removeWatcher = EMPTY_FN;
        this.items = EMPTY_SET;
        Object.freeze(this);
      }
    };
    STAT_METHOD_F = "stat";
    STAT_METHOD_L = "lstat";
    WatchHelper = class {
      static {
        __name(this, "WatchHelper");
      }
      constructor(path47, follow, fsw) {
        this.fsw = fsw;
        const watchPath = path47;
        this.path = path47 = path47.replace(REPLACER_RE, "");
        this.watchPath = watchPath;
        this.fullWatchPath = sysPath2.resolve(watchPath);
        this.dirParts = [];
        this.dirParts.forEach((parts) => {
          if (parts.length > 1)
            parts.pop();
        });
        this.followSymlinks = follow;
        this.statMethod = follow ? STAT_METHOD_F : STAT_METHOD_L;
      }
      entryPath(entry) {
        return sysPath2.join(this.watchPath, sysPath2.relative(this.watchPath, entry.fullPath));
      }
      filterPath(entry) {
        const { stats } = entry;
        if (stats && stats.isSymbolicLink())
          return this.filterDir(entry);
        const resolvedPath7 = this.entryPath(entry);
        return this.fsw._isntIgnored(resolvedPath7, stats) && this.fsw._hasReadPermissions(stats);
      }
      filterDir(entry) {
        return this.fsw._isntIgnored(this.entryPath(entry), entry.stats);
      }
    };
    FSWatcher = class extends import_events.EventEmitter {
      static {
        __name(this, "FSWatcher");
      }
      // Not indenting methods for history sake; for now.
      constructor(_opts = {}) {
        super();
        this.closed = false;
        this._closers = /* @__PURE__ */ new Map();
        this._ignoredPaths = /* @__PURE__ */ new Set();
        this._throttled = /* @__PURE__ */ new Map();
        this._streams = /* @__PURE__ */ new Set();
        this._symlinkPaths = /* @__PURE__ */ new Map();
        this._watched = /* @__PURE__ */ new Map();
        this._pendingWrites = /* @__PURE__ */ new Map();
        this._pendingUnlinks = /* @__PURE__ */ new Map();
        this._readyCount = 0;
        this._readyEmitted = false;
        const awf = _opts.awaitWriteFinish;
        const DEF_AWF = { stabilityThreshold: 2e3, pollInterval: 100 };
        const opts = {
          // Defaults
          persistent: true,
          ignoreInitial: false,
          ignorePermissionErrors: false,
          interval: 100,
          binaryInterval: 300,
          followSymlinks: true,
          usePolling: false,
          // useAsync: false,
          atomic: true,
          // NOTE: overwritten later (depends on usePolling)
          ..._opts,
          // Change format
          ignored: _opts.ignored ? arrify(_opts.ignored) : arrify([]),
          awaitWriteFinish: awf === true ? DEF_AWF : typeof awf === "object" ? { ...DEF_AWF, ...awf } : false
        };
        if (isIBMi)
          opts.usePolling = true;
        if (opts.atomic === void 0)
          opts.atomic = !opts.usePolling;
        const envPoll = process.env.CHOKIDAR_USEPOLLING;
        if (envPoll !== void 0) {
          const envLower = envPoll.toLowerCase();
          if (envLower === "false" || envLower === "0")
            opts.usePolling = false;
          else if (envLower === "true" || envLower === "1")
            opts.usePolling = true;
          else
            opts.usePolling = !!envLower;
        }
        const envInterval = process.env.CHOKIDAR_INTERVAL;
        if (envInterval)
          opts.interval = Number.parseInt(envInterval, 10);
        let readyCalls = 0;
        this._emitReady = () => {
          readyCalls++;
          if (readyCalls >= this._readyCount) {
            this._emitReady = EMPTY_FN;
            this._readyEmitted = true;
            process.nextTick(() => this.emit(EVENTS.READY));
          }
        };
        this._emitRaw = (...args) => this.emit(EVENTS.RAW, ...args);
        this._boundRemove = this._remove.bind(this);
        this.options = opts;
        this._nodeFsHandler = new NodeFsHandler(this);
        Object.freeze(opts);
      }
      _addIgnoredPath(matcher) {
        if (isMatcherObject(matcher)) {
          for (const ignored of this._ignoredPaths) {
            if (isMatcherObject(ignored) && ignored.path === matcher.path && ignored.recursive === matcher.recursive) {
              return;
            }
          }
        }
        this._ignoredPaths.add(matcher);
      }
      _removeIgnoredPath(matcher) {
        this._ignoredPaths.delete(matcher);
        if (typeof matcher === "string") {
          for (const ignored of this._ignoredPaths) {
            if (isMatcherObject(ignored) && ignored.path === matcher) {
              this._ignoredPaths.delete(ignored);
            }
          }
        }
      }
      // Public methods
      /**
       * Adds paths to be watched on an existing FSWatcher instance.
       * @param paths_ file or file list. Other arguments are unused
       */
      add(paths_, _origAdd, _internal) {
        const { cwd } = this.options;
        this.closed = false;
        this._closePromise = void 0;
        let paths = unifyPaths(paths_);
        if (cwd) {
          paths = paths.map((path47) => {
            const absPath = getAbsolutePath(path47, cwd);
            return absPath;
          });
        }
        paths.forEach((path47) => {
          this._removeIgnoredPath(path47);
        });
        this._userIgnored = void 0;
        if (!this._readyCount)
          this._readyCount = 0;
        this._readyCount += paths.length;
        Promise.all(paths.map(async (path47) => {
          const res = await this._nodeFsHandler._addToNodeFs(path47, !_internal, void 0, 0, _origAdd);
          if (res)
            this._emitReady();
          return res;
        })).then((results) => {
          if (this.closed)
            return;
          results.forEach((item) => {
            if (item)
              this.add(sysPath2.dirname(item), sysPath2.basename(_origAdd || item));
          });
        });
        return this;
      }
      /**
       * Close watchers or start ignoring events from specified paths.
       */
      unwatch(paths_) {
        if (this.closed)
          return this;
        const paths = unifyPaths(paths_);
        const { cwd } = this.options;
        paths.forEach((path47) => {
          if (!sysPath2.isAbsolute(path47) && !this._closers.has(path47)) {
            if (cwd)
              path47 = sysPath2.join(cwd, path47);
            path47 = sysPath2.resolve(path47);
          }
          this._closePath(path47);
          this._addIgnoredPath(path47);
          if (this._watched.has(path47)) {
            this._addIgnoredPath({
              path: path47,
              recursive: true
            });
          }
          this._userIgnored = void 0;
        });
        return this;
      }
      /**
       * Close watchers and remove all listeners from watched paths.
       */
      close() {
        if (this._closePromise) {
          return this._closePromise;
        }
        this.closed = true;
        this.removeAllListeners();
        const closers = [];
        this._closers.forEach((closerList) => closerList.forEach((closer) => {
          const promise = closer();
          if (promise instanceof Promise)
            closers.push(promise);
        }));
        this._streams.forEach((stream) => stream.destroy());
        this._userIgnored = void 0;
        this._readyCount = 0;
        this._readyEmitted = false;
        this._watched.forEach((dirent) => dirent.dispose());
        this._closers.clear();
        this._watched.clear();
        this._streams.clear();
        this._symlinkPaths.clear();
        this._throttled.clear();
        this._closePromise = closers.length ? Promise.all(closers).then(() => void 0) : Promise.resolve();
        return this._closePromise;
      }
      /**
       * Expose list of watched paths
       * @returns for chaining
       */
      getWatched() {
        const watchList = {};
        this._watched.forEach((entry, dir) => {
          const key = this.options.cwd ? sysPath2.relative(this.options.cwd, dir) : dir;
          const index = key || ONE_DOT;
          watchList[index] = entry.getChildren().sort();
        });
        return watchList;
      }
      emitWithAll(event, args) {
        this.emit(event, ...args);
        if (event !== EVENTS.ERROR)
          this.emit(EVENTS.ALL, event, ...args);
      }
      // Common helpers
      // --------------
      /**
       * Normalize and emit events.
       * Calling _emit DOES NOT MEAN emit() would be called!
       * @param event Type of event
       * @param path File or directory path
       * @param stats arguments to be passed with event
       * @returns the error if defined, otherwise the value of the FSWatcher instance's `closed` flag
       */
      async _emit(event, path47, stats) {
        if (this.closed)
          return;
        const opts = this.options;
        if (isWindows)
          path47 = sysPath2.normalize(path47);
        if (opts.cwd)
          path47 = sysPath2.relative(opts.cwd, path47);
        const args = [path47];
        if (stats != null)
          args.push(stats);
        const awf = opts.awaitWriteFinish;
        let pw;
        if (awf && (pw = this._pendingWrites.get(path47))) {
          pw.lastChange = /* @__PURE__ */ new Date();
          return this;
        }
        if (opts.atomic) {
          if (event === EVENTS.UNLINK) {
            this._pendingUnlinks.set(path47, [event, ...args]);
            setTimeout(() => {
              this._pendingUnlinks.forEach((entry, path48) => {
                this.emit(...entry);
                this.emit(EVENTS.ALL, ...entry);
                this._pendingUnlinks.delete(path48);
              });
            }, typeof opts.atomic === "number" ? opts.atomic : 100);
            return this;
          }
          if (event === EVENTS.ADD && this._pendingUnlinks.has(path47)) {
            event = EVENTS.CHANGE;
            this._pendingUnlinks.delete(path47);
          }
        }
        if (awf && (event === EVENTS.ADD || event === EVENTS.CHANGE) && this._readyEmitted) {
          const awfEmit = /* @__PURE__ */ __name((err, stats2) => {
            if (err) {
              event = EVENTS.ERROR;
              args[0] = err;
              this.emitWithAll(event, args);
            } else if (stats2) {
              if (args.length > 1) {
                args[1] = stats2;
              } else {
                args.push(stats2);
              }
              this.emitWithAll(event, args);
            }
          }, "awfEmit");
          this._awaitWriteFinish(path47, awf.stabilityThreshold, event, awfEmit);
          return this;
        }
        if (event === EVENTS.CHANGE) {
          const isThrottled = !this._throttle(EVENTS.CHANGE, path47, 50);
          if (isThrottled)
            return this;
        }
        if (opts.alwaysStat && stats === void 0 && (event === EVENTS.ADD || event === EVENTS.ADD_DIR || event === EVENTS.CHANGE)) {
          const fullPath = opts.cwd ? sysPath2.join(opts.cwd, path47) : path47;
          let stats2;
          try {
            stats2 = await (0, import_promises10.stat)(fullPath);
          } catch (err) {
          }
          if (!stats2 || this.closed)
            return;
          args.push(stats2);
        }
        this.emitWithAll(event, args);
        return this;
      }
      /**
       * Common handler for errors
       * @returns The error if defined, otherwise the value of the FSWatcher instance's `closed` flag
       */
      _handleError(error4) {
        const code = error4 && error4.code;
        if (error4 && code !== "ENOENT" && code !== "ENOTDIR" && (!this.options.ignorePermissionErrors || code !== "EPERM" && code !== "EACCES")) {
          this.emit(EVENTS.ERROR, error4);
        }
        return error4 || this.closed;
      }
      /**
       * Helper utility for throttling
       * @param actionType type being throttled
       * @param path being acted upon
       * @param timeout duration of time to suppress duplicate actions
       * @returns tracking object or false if action should be suppressed
       */
      _throttle(actionType, path47, timeout) {
        if (!this._throttled.has(actionType)) {
          this._throttled.set(actionType, /* @__PURE__ */ new Map());
        }
        const action = this._throttled.get(actionType);
        if (!action)
          throw new Error("invalid throttle");
        const actionPath = action.get(path47);
        if (actionPath) {
          actionPath.count++;
          return false;
        }
        let timeoutObject;
        const clear = /* @__PURE__ */ __name(() => {
          const item = action.get(path47);
          const count = item ? item.count : 0;
          action.delete(path47);
          clearTimeout(timeoutObject);
          if (item)
            clearTimeout(item.timeoutObject);
          return count;
        }, "clear");
        timeoutObject = setTimeout(clear, timeout);
        const thr = { timeoutObject, clear, count: 0 };
        action.set(path47, thr);
        return thr;
      }
      _incrReadyCount() {
        return this._readyCount++;
      }
      /**
       * Awaits write operation to finish.
       * Polls a newly created file for size variations. When files size does not change for 'threshold' milliseconds calls callback.
       * @param path being acted upon
       * @param threshold Time in milliseconds a file size must be fixed before acknowledging write OP is finished
       * @param event
       * @param awfEmit Callback to be called when ready for event to be emitted.
       */
      _awaitWriteFinish(path47, threshold, event, awfEmit) {
        const awf = this.options.awaitWriteFinish;
        if (typeof awf !== "object")
          return;
        const pollInterval = awf.pollInterval;
        let timeoutHandler;
        let fullPath = path47;
        if (this.options.cwd && !sysPath2.isAbsolute(path47)) {
          fullPath = sysPath2.join(this.options.cwd, path47);
        }
        const now = /* @__PURE__ */ new Date();
        const writes = this._pendingWrites;
        function awaitWriteFinishFn(prevStat) {
          (0, import_fs6.stat)(fullPath, (err, curStat) => {
            if (err || !writes.has(path47)) {
              if (err && err.code !== "ENOENT")
                awfEmit(err);
              return;
            }
            const now2 = Number(/* @__PURE__ */ new Date());
            if (prevStat && curStat.size !== prevStat.size) {
              writes.get(path47).lastChange = now2;
            }
            const pw = writes.get(path47);
            const df = now2 - pw.lastChange;
            if (df >= threshold) {
              writes.delete(path47);
              awfEmit(void 0, curStat);
            } else {
              timeoutHandler = setTimeout(awaitWriteFinishFn, pollInterval, curStat);
            }
          });
        }
        __name(awaitWriteFinishFn, "awaitWriteFinishFn");
        if (!writes.has(path47)) {
          writes.set(path47, {
            lastChange: now,
            cancelWait: /* @__PURE__ */ __name(() => {
              writes.delete(path47);
              clearTimeout(timeoutHandler);
              return event;
            }, "cancelWait")
          });
          timeoutHandler = setTimeout(awaitWriteFinishFn, pollInterval);
        }
      }
      /**
       * Determines whether user has asked to ignore this path.
       */
      _isIgnored(path47, stats) {
        if (this.options.atomic && DOT_RE.test(path47))
          return true;
        if (!this._userIgnored) {
          const { cwd } = this.options;
          const ign = this.options.ignored;
          const ignored = (ign || []).map(normalizeIgnored(cwd));
          const ignoredPaths = [...this._ignoredPaths];
          const list3 = [...ignoredPaths.map(normalizeIgnored(cwd)), ...ignored];
          this._userIgnored = anymatch(list3, void 0);
        }
        return this._userIgnored(path47, stats);
      }
      _isntIgnored(path47, stat8) {
        return !this._isIgnored(path47, stat8);
      }
      /**
       * Provides a set of common helpers and properties relating to symlink handling.
       * @param path file or directory pattern being watched
       */
      _getWatchHelpers(path47) {
        return new WatchHelper(path47, this.options.followSymlinks, this);
      }
      // Directory helpers
      // -----------------
      /**
       * Provides directory tracking objects
       * @param directory path of the directory
       */
      _getWatchedDir(directory) {
        const dir = sysPath2.resolve(directory);
        if (!this._watched.has(dir))
          this._watched.set(dir, new DirEntry(dir, this._boundRemove));
        return this._watched.get(dir);
      }
      // File helpers
      // ------------
      /**
       * Check for read permissions: https://stackoverflow.com/a/11781404/1358405
       */
      _hasReadPermissions(stats) {
        if (this.options.ignorePermissionErrors)
          return true;
        return Boolean(Number(stats.mode) & 256);
      }
      /**
       * Handles emitting unlink events for
       * files and directories, and via recursion, for
       * files and directories within directories that are unlinked
       * @param directory within which the following item is located
       * @param item      base path of item/directory
       */
      _remove(directory, item, isDirectory) {
        const path47 = sysPath2.join(directory, item);
        const fullPath = sysPath2.resolve(path47);
        isDirectory = isDirectory != null ? isDirectory : this._watched.has(path47) || this._watched.has(fullPath);
        if (!this._throttle("remove", path47, 100))
          return;
        if (!isDirectory && this._watched.size === 1) {
          this.add(directory, item, true);
        }
        const wp = this._getWatchedDir(path47);
        const nestedDirectoryChildren = wp.getChildren();
        nestedDirectoryChildren.forEach((nested) => this._remove(path47, nested));
        const parent = this._getWatchedDir(directory);
        const wasTracked = parent.has(item);
        parent.remove(item);
        if (this._symlinkPaths.has(fullPath)) {
          this._symlinkPaths.delete(fullPath);
        }
        let relPath = path47;
        if (this.options.cwd)
          relPath = sysPath2.relative(this.options.cwd, path47);
        if (this.options.awaitWriteFinish && this._pendingWrites.has(relPath)) {
          const event = this._pendingWrites.get(relPath).cancelWait();
          if (event === EVENTS.ADD)
            return;
        }
        this._watched.delete(path47);
        this._watched.delete(fullPath);
        const eventName = isDirectory ? EVENTS.UNLINK_DIR : EVENTS.UNLINK;
        if (wasTracked && !this._isIgnored(path47))
          this._emit(eventName, path47);
        this._closePath(path47);
      }
      /**
       * Closes all watchers for a path
       */
      _closePath(path47) {
        this._closeFile(path47);
        const dir = sysPath2.dirname(path47);
        this._getWatchedDir(dir).remove(sysPath2.basename(path47));
      }
      /**
       * Closes only file-specific watchers
       */
      _closeFile(path47) {
        const closers = this._closers.get(path47);
        if (!closers)
          return;
        closers.forEach((closer) => closer());
        this._closers.delete(path47);
      }
      _addPathCloser(path47, closer) {
        if (!closer)
          return;
        let list3 = this._closers.get(path47);
        if (!list3) {
          list3 = [];
          this._closers.set(path47, list3);
        }
        list3.push(closer);
      }
      _readdirp(root32, opts) {
        if (this.closed)
          return;
        const options = { type: EVENTS.ALL, alwaysStat: true, lstat: true, ...opts, depth: 0 };
        let stream = readdirp(root32, options);
        this._streams.add(stream);
        stream.once(STR_CLOSE, () => {
          stream = void 0;
        });
        stream.once(STR_END, () => {
          if (stream) {
            this._streams.delete(stream);
            stream = void 0;
          }
        });
        return stream;
      }
    };
    __name(watch, "watch");
  }
});

// ../@aws-cdk/toolkit-lib/lib/private/activity-printer/base.ts
var ActivityPrinterBase;
var init_base = __esm({
  "../@aws-cdk/toolkit-lib/lib/private/activity-printer/base.ts"() {
    "use strict";
    init_private();
    init_util3();
    ActivityPrinterBase = class {
      constructor(props) {
        this.props = props;
        this.stream = props.stream;
      }
      props;
      static {
        __name(this, "ActivityPrinterBase");
      }
      static TIMESTAMP_WIDTH = 12;
      static STATUS_WIDTH = 23;
      /**
       * Stream to write to
       */
      stream;
      /**
       * The with of the "resource type" column.
       */
      resourceTypeColumnWidth = maxResourceTypeLength({});
      /**
       * A list of resource IDs which are currently being processed
       */
      resourcesInProgress = {};
      stackProgress;
      rollingBack = false;
      failures = new Array();
      isStackUpdate = false;
      hookFailureMap = /* @__PURE__ */ new Map();
      /**
       * Receive a stack activity message
       */
      notify(msg) {
        switch (true) {
          case IO.CDK_TOOLKIT_I5501.is(msg):
            this.isStackUpdate = msg.data?.isStackUpdate ?? false;
            this.start(msg.data);
            break;
          case IO.CDK_TOOLKIT_I5502.is(msg):
            this.activity(msg.data);
            break;
          case IO.CDK_TOOLKIT_I5503.is(msg):
            this.stop();
            break;
          default:
            break;
        }
      }
      start({ stack }) {
        this.resourceTypeColumnWidth = maxResourceTypeLength(stack.template);
        this.resourcesInProgress = {};
        this.stackProgress = void 0;
        this.rollingBack = false;
        this.failures.length = 0;
        this.hookFailureMap.clear();
      }
      activity(activity) {
        this.addActivity(activity);
        this.print();
      }
      stop() {
        this.print();
      }
      addActivity(activity) {
        const status = activity.event.ResourceStatus;
        const hookStatus = activity.event.HookStatus;
        const hookType = activity.event.HookType;
        if (!status || !activity.event.LogicalResourceId) {
          return;
        }
        this.stackProgress = activity.progress;
        if (status === "ROLLBACK_IN_PROGRESS" || status === "UPDATE_ROLLBACK_IN_PROGRESS") {
          this.rollingBack = true;
        }
        if (status.endsWith("_IN_PROGRESS")) {
          this.resourcesInProgress[activity.event.LogicalResourceId] = activity;
        }
        if (isErrorEvent(activity.event)) {
          if (!isCancellationEvent(activity.event) && !isRootStackEvent(activity.event)) {
            this.failures.push(activity);
          }
        }
        if (status.endsWith("_COMPLETE") || status.endsWith("_FAILED")) {
          delete this.resourcesInProgress[activity.event.LogicalResourceId];
        }
        if (hookStatus !== void 0 && hookStatus.endsWith("_COMPLETE_FAILED") && activity.event.LogicalResourceId !== void 0 && hookType !== void 0) {
          if (this.hookFailureMap.has(activity.event.LogicalResourceId)) {
            this.hookFailureMap.get(activity.event.LogicalResourceId)?.set(hookType, activity.event.HookStatusReason ?? "");
          } else {
            this.hookFailureMap.set(activity.event.LogicalResourceId, /* @__PURE__ */ new Map());
            this.hookFailureMap.get(activity.event.LogicalResourceId)?.set(hookType, activity.event.HookStatusReason ?? "");
          }
        }
      }
      failureReason(activity) {
        const resourceStatusReason = activity.event.ResourceStatusReason ?? "";
        const logicalResourceId = activity.event.LogicalResourceId ?? "";
        const hookFailureReasonMap = this.hookFailureMap.get(logicalResourceId);
        if (hookFailureReasonMap !== void 0) {
          for (const hookType of hookFailureReasonMap.keys()) {
            if (resourceStatusReason.includes(hookType)) {
              return resourceStatusReason + " : " + hookFailureReasonMap.get(hookType);
            }
          }
        }
        return resourceStatusReason;
      }
      /**
       * Is the activity a meta activity for the stack itself.
       */
      isActivityForTheStack(activity) {
        return activity.event.PhysicalResourceId === activity.event.StackId;
      }
      /**
       * During a stack update, DELETE_FAILED events are skippable: CloudFormation
       * will eventually skip them and complete the update.
       */
      isProvisionalFailure(activity) {
        return this.isStackUpdate && activity.event.ResourceStatus === "DELETE_FAILED";
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/private/activity-printer/history.ts
function colorFromStatusResult(status) {
  if (!status) {
    return chalk20.reset;
  }
  if (status.indexOf("FAILED") !== -1) {
    return chalk20.red;
  }
  if (status.indexOf("ROLLBACK") !== -1) {
    return chalk20.yellow;
  }
  if (status.indexOf("COMPLETE") !== -1) {
    return chalk20.green;
  }
  return chalk20.reset;
}
var util7, chalk20, HistoryActivityPrinter;
var init_history = __esm({
  "../@aws-cdk/toolkit-lib/lib/private/activity-printer/history.ts"() {
    "use strict";
    util7 = __toESM(require("util"));
    chalk20 = __toESM(require_source());
    init_base();
    init_util3();
    HistoryActivityPrinter = class _HistoryActivityPrinter extends ActivityPrinterBase {
      static {
        __name(this, "HistoryActivityPrinter");
      }
      /**
       * Last time we printed something to the console.
       *
       * Used to measure timeout for progress reporting.
       */
      lastPrintTime = Date.now();
      lastPrinted;
      /**
       * Number of ms of change absence before we tell the user about the resources that are currently in progress.
       */
      inProgressDelay = 3e4;
      printable = new Array();
      constructor(props) {
        super(props);
      }
      activity(activity) {
        this.printable.push(activity);
        super.activity(activity);
      }
      stop() {
        super.stop();
        const realFailures = this.failures.filter(
          (f32) => !this.isActivityForTheStack(f32) && !this.isProvisionalFailure(f32)
        );
        if (realFailures.length > 0) {
          this.stream.write("\nFailed resources:\n");
          for (const failure of realFailures) {
            this.printOne(failure, false);
          }
        }
        if (this.failures.some((f32) => this.isProvisionalFailure(f32))) {
          this.stream.write(chalk20.yellow("\n \u26A0\uFE0F  Some resources failed to delete but were skipped. These resources may still exist and could incur charges. Clean them up manually.\n"));
        }
      }
      print() {
        for (const activity of this.printable) {
          this.printOne(activity);
          this.lastPrinted = activity;
        }
        this.printable.splice(0, this.printable.length);
        this.printInProgress(this.lastPrinted?.progress.formatted);
      }
      printOne(activity, progress) {
        const event = activity.event;
        const provisional = this.isProvisionalFailure(activity);
        const color = provisional ? chalk20.yellow : colorFromStatusResult(event.ResourceStatus);
        let reasonColor = chalk20.cyan;
        let stackTrace = "";
        const metadata = activity.metadata;
        if (!provisional && event.ResourceStatus && event.ResourceStatus.indexOf("FAILED") !== -1) {
          if (progress == void 0 || progress) {
            event.ResourceStatusReason = event.ResourceStatusReason ? this.failureReason(activity) : "";
          }
          if (metadata) {
            stackTrace = metadata.entry.trace ? `
	${metadata.entry.trace.join("\n	\\_ ")}` : "";
          }
          reasonColor = chalk20.red;
        }
        const resourceName = metadata ? metadata.constructPath : event.LogicalResourceId || "";
        const logicalId = resourceName !== event.LogicalResourceId ? `(${event.LogicalResourceId}) ` : "";
        const statusText = provisional ? `${(event.ResourceStatus || "").slice(0, _HistoryActivityPrinter.STATUS_WIDTH)} (skipped)` : (event.ResourceStatus || "").slice(0, _HistoryActivityPrinter.STATUS_WIDTH);
        this.stream.write(
          util7.format(
            "%s | %s%s | %s | %s | %s %s%s%s\n",
            event.StackName,
            progress !== false ? `${activity.progress.formatted} | ` : "",
            new Date(event.Timestamp).toLocaleTimeString(),
            color(padRight(_HistoryActivityPrinter.STATUS_WIDTH, statusText)),
            padRight(this.resourceTypeColumnWidth, event.ResourceType || ""),
            color(chalk20.bold(resourceName)),
            logicalId,
            provisional ? "(this will take a few minutes to recover)" : reasonColor(chalk20.bold(event.ResourceStatusReason ? event.ResourceStatusReason : "")),
            provisional ? "" : reasonColor(stackTrace)
          )
        );
        this.lastPrintTime = Date.now();
      }
      /**
       * If some resources are taking a while to create, notify the user about what's currently in progress
       */
      printInProgress(progress) {
        if (!progress || Date.now() < this.lastPrintTime + this.inProgressDelay) {
          return;
        }
        if (Object.keys(this.resourcesInProgress).length > 0) {
          this.stream.write(
            util7.format(
              "%s Currently in progress: %s\n",
              progress,
              chalk20.bold(Object.keys(this.resourcesInProgress).join(", "))
            )
          );
        }
        this.lastPrintTime = Infinity;
      }
    };
    __name(colorFromStatusResult, "colorFromStatusResult");
  }
});

// ../../node_modules/wrap-ansi/index.js
var require_wrap_ansi = __commonJS({
  "../../node_modules/wrap-ansi/index.js"(exports2, module2) {
    "use strict";
    var stringWidth2 = require_string_width();
    var stripAnsi2 = require_strip_ansi();
    var ansiStyles = require_ansi_styles();
    var ESCAPES = /* @__PURE__ */ new Set([
      "\x1B",
      "\x9B"
    ]);
    var END_CODE = 39;
    var ANSI_ESCAPE_BELL = "\x07";
    var ANSI_CSI = "[";
    var ANSI_OSC = "]";
    var ANSI_SGR_TERMINATOR = "m";
    var ANSI_ESCAPE_LINK = `${ANSI_OSC}8;;`;
    var wrapAnsi2 = /* @__PURE__ */ __name((code) => `${ESCAPES.values().next().value}${ANSI_CSI}${code}${ANSI_SGR_TERMINATOR}`, "wrapAnsi");
    var wrapAnsiHyperlink = /* @__PURE__ */ __name((uri) => `${ESCAPES.values().next().value}${ANSI_ESCAPE_LINK}${uri}${ANSI_ESCAPE_BELL}`, "wrapAnsiHyperlink");
    var wordLengths = /* @__PURE__ */ __name((string) => string.split(" ").map((character) => stringWidth2(character)), "wordLengths");
    var wrapWord = /* @__PURE__ */ __name((rows, word, columns) => {
      const characters = [...word];
      let isInsideEscape = false;
      let isInsideLinkEscape = false;
      let visible = stringWidth2(stripAnsi2(rows[rows.length - 1]));
      for (const [index, character] of characters.entries()) {
        const characterLength = stringWidth2(character);
        if (visible + characterLength <= columns) {
          rows[rows.length - 1] += character;
        } else {
          rows.push(character);
          visible = 0;
        }
        if (ESCAPES.has(character)) {
          isInsideEscape = true;
          isInsideLinkEscape = characters.slice(index + 1).join("").startsWith(ANSI_ESCAPE_LINK);
        }
        if (isInsideEscape) {
          if (isInsideLinkEscape) {
            if (character === ANSI_ESCAPE_BELL) {
              isInsideEscape = false;
              isInsideLinkEscape = false;
            }
          } else if (character === ANSI_SGR_TERMINATOR) {
            isInsideEscape = false;
          }
          continue;
        }
        visible += characterLength;
        if (visible === columns && index < characters.length - 1) {
          rows.push("");
          visible = 0;
        }
      }
      if (!visible && rows[rows.length - 1].length > 0 && rows.length > 1) {
        rows[rows.length - 2] += rows.pop();
      }
    }, "wrapWord");
    var stringVisibleTrimSpacesRight = /* @__PURE__ */ __name((string) => {
      const words = string.split(" ");
      let last = words.length;
      while (last > 0) {
        if (stringWidth2(words[last - 1]) > 0) {
          break;
        }
        last--;
      }
      if (last === words.length) {
        return string;
      }
      return words.slice(0, last).join(" ") + words.slice(last).join("");
    }, "stringVisibleTrimSpacesRight");
    var exec5 = /* @__PURE__ */ __name((string, columns, options = {}) => {
      if (options.trim !== false && string.trim() === "") {
        return "";
      }
      let returnValue = "";
      let escapeCode;
      let escapeUrl;
      const lengths = wordLengths(string);
      let rows = [""];
      for (const [index, word] of string.split(" ").entries()) {
        if (options.trim !== false) {
          rows[rows.length - 1] = rows[rows.length - 1].trimStart();
        }
        let rowLength = stringWidth2(rows[rows.length - 1]);
        if (index !== 0) {
          if (rowLength >= columns && (options.wordWrap === false || options.trim === false)) {
            rows.push("");
            rowLength = 0;
          }
          if (rowLength > 0 || options.trim === false) {
            rows[rows.length - 1] += " ";
            rowLength++;
          }
        }
        if (options.hard && lengths[index] > columns) {
          const remainingColumns = columns - rowLength;
          const breaksStartingThisLine = 1 + Math.floor((lengths[index] - remainingColumns - 1) / columns);
          const breaksStartingNextLine = Math.floor((lengths[index] - 1) / columns);
          if (breaksStartingNextLine < breaksStartingThisLine) {
            rows.push("");
          }
          wrapWord(rows, word, columns);
          continue;
        }
        if (rowLength + lengths[index] > columns && rowLength > 0 && lengths[index] > 0) {
          if (options.wordWrap === false && rowLength < columns) {
            wrapWord(rows, word, columns);
            continue;
          }
          rows.push("");
        }
        if (rowLength + lengths[index] > columns && options.wordWrap === false) {
          wrapWord(rows, word, columns);
          continue;
        }
        rows[rows.length - 1] += word;
      }
      if (options.trim !== false) {
        rows = rows.map(stringVisibleTrimSpacesRight);
      }
      const pre = [...rows.join("\n")];
      for (const [index, character] of pre.entries()) {
        returnValue += character;
        if (ESCAPES.has(character)) {
          const { groups } = new RegExp(`(?:\\${ANSI_CSI}(?<code>\\d+)m|\\${ANSI_ESCAPE_LINK}(?<uri>.*)${ANSI_ESCAPE_BELL})`).exec(pre.slice(index).join("")) || { groups: {} };
          if (groups.code !== void 0) {
            const code2 = Number.parseFloat(groups.code);
            escapeCode = code2 === END_CODE ? void 0 : code2;
          } else if (groups.uri !== void 0) {
            escapeUrl = groups.uri.length === 0 ? void 0 : groups.uri;
          }
        }
        const code = ansiStyles.codes.get(Number(escapeCode));
        if (pre[index + 1] === "\n") {
          if (escapeUrl) {
            returnValue += wrapAnsiHyperlink("");
          }
          if (escapeCode && code) {
            returnValue += wrapAnsi2(code);
          }
        } else if (character === "\n") {
          if (escapeCode && code) {
            returnValue += wrapAnsi2(escapeCode);
          }
          if (escapeUrl) {
            returnValue += wrapAnsiHyperlink(escapeUrl);
          }
        }
      }
      return returnValue;
    }, "exec");
    module2.exports = (string, columns, options) => {
      return String(string).normalize().replace(/\r\n/g, "\n").split("\n").map((line) => exec5(line, columns, options)).join("\n");
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/private/activity-printer/display.ts
function cursorUp(n10) {
  n10 = typeof n10 === "number" ? n10 : 1;
  return n10 > 0 ? ESC + "[" + n10 + "A" : "";
}
function cll() {
  return ESC + "[K";
}
function terminalWrap(width, lines) {
  if (width === void 0) {
    return lines;
  }
  return lines.flatMap((line) => wrapAnsi(line, width - 1, {
    hard: true,
    trim: true,
    wordWrap: false
  }).split("\n"));
}
function expandNewlines(lines) {
  return lines.flatMap((line) => line.split("\n"));
}
function getMaxBlockHeight(windowHeight, lastHeight, lines) {
  if (windowHeight === void 0) {
    return Math.max(lines.length, lastHeight);
  }
  return lines.length < windowHeight ? lines.length : windowHeight - 1;
}
var wrapAnsi, RewritableBlock, ESC;
var init_display = __esm({
  "../@aws-cdk/toolkit-lib/lib/private/activity-printer/display.ts"() {
    "use strict";
    wrapAnsi = require_wrap_ansi();
    RewritableBlock = class {
      constructor(stream) {
        this.stream = stream;
      }
      stream;
      static {
        __name(this, "RewritableBlock");
      }
      lastHeight = 0;
      trailingEmptyLines = 0;
      get width() {
        return this.stream.columns;
      }
      get height() {
        return this.stream.rows;
      }
      displayLines(lines) {
        lines = terminalWrap(this.width, expandNewlines(lines));
        lines = lines.slice(0, getMaxBlockHeight(this.height, this.lastHeight, lines));
        this.stream.write(cursorUp(this.lastHeight));
        for (const line of lines) {
          this.stream.write(cll() + line + "\n");
        }
        this.trailingEmptyLines = Math.max(0, this.lastHeight - lines.length);
        for (let i32 = 0; i32 < this.trailingEmptyLines; i32++) {
          this.stream.write(cll() + "\n");
        }
        this.lastHeight = Math.max(this.lastHeight, lines.length);
      }
      removeEmptyLines() {
        this.stream.write(cursorUp(this.trailingEmptyLines));
      }
    };
    ESC = "\x1B";
    __name(cursorUp, "cursorUp");
    __name(cll, "cll");
    __name(terminalWrap, "terminalWrap");
    __name(expandNewlines, "expandNewlines");
    __name(getMaxBlockHeight, "getMaxBlockHeight");
  }
});

// ../@aws-cdk/toolkit-lib/lib/private/activity-printer/current.ts
function colorFromStatusActivity(status) {
  if (!status) {
    return chalk21.reset;
  }
  if (status.endsWith("_FAILED")) {
    return chalk21.red;
  }
  if (status.startsWith("CREATE_") || status.startsWith("UPDATE_") || status.startsWith("IMPORT_")) {
    return chalk21.green;
  }
  if (status.indexOf("ROLLBACK_") !== -1) {
    return chalk21.yellow;
  }
  if (status.startsWith("DELETE_")) {
    return chalk21.yellow;
  }
  return chalk21.reset;
}
function shorten(maxWidth, p10) {
  if (p10.length <= maxWidth) {
    return p10;
  }
  const half = Math.floor((maxWidth - 3) / 2);
  return p10.slice(0, half) + "..." + p10.slice(-half);
}
var util8, chalk21, CurrentActivityPrinter, FULL_BLOCK, PARTIAL_BLOCK, MAX_PROGRESSBAR_WIDTH, MIN_PROGRESSBAR_WIDTH, PROGRESSBAR_EXTRA_SPACE;
var init_current = __esm({
  "../@aws-cdk/toolkit-lib/lib/private/activity-printer/current.ts"() {
    "use strict";
    util8 = __toESM(require("util"));
    chalk21 = __toESM(require_source());
    init_base();
    init_display();
    init_util3();
    CurrentActivityPrinter = class _CurrentActivityPrinter extends ActivityPrinterBase {
      static {
        __name(this, "CurrentActivityPrinter");
      }
      /**
       * Continuously write to the same output block.
       */
      block;
      constructor(props) {
        super(props);
        this.block = new RewritableBlock(this.stream);
      }
      print() {
        const lines = [];
        const progressWidth = Math.max(
          Math.min((this.block.width ?? 80) - PROGRESSBAR_EXTRA_SPACE - 1, MAX_PROGRESSBAR_WIDTH),
          MIN_PROGRESSBAR_WIDTH
        );
        const prog = this.progressBar(progressWidth);
        if (prog) {
          lines.push("  " + prog, "");
        }
        const toPrint = [...this.failures, ...Object.values(this.resourcesInProgress)];
        toPrint.sort((a32, b32) => a32.event.Timestamp.getTime() - b32.event.Timestamp.getTime());
        lines.push(
          ...toPrint.map((res) => {
            const provisional = this.isProvisionalFailure(res);
            const color = provisional ? chalk21.yellow : colorFromStatusActivity(res.event.ResourceStatus);
            const resourceName = res.metadata?.constructPath ?? res.event.LogicalResourceId ?? "";
            const statusText = provisional ? `${(res.event.ResourceStatus || "").slice(0, _CurrentActivityPrinter.STATUS_WIDTH)} (skipped)` : (res.event.ResourceStatus || "").slice(0, _CurrentActivityPrinter.STATUS_WIDTH);
            return util8.format(
              "%s | %s | %s | %s%s",
              padLeft(_CurrentActivityPrinter.TIMESTAMP_WIDTH, new Date(res.event.Timestamp).toLocaleTimeString()),
              color(padRight(_CurrentActivityPrinter.STATUS_WIDTH, statusText)),
              padRight(this.resourceTypeColumnWidth, res.event.ResourceType || ""),
              color(chalk21.bold(shorten(40, resourceName))),
              provisional ? " (this will take a few minutes to recover)" : this.failureReasonOnNextLine(res)
            );
          })
        );
        this.block.displayLines(lines);
      }
      stop() {
        super.stop();
        const lines = new Array();
        for (const failure of this.failures) {
          if (this.isActivityForTheStack(failure) || this.isProvisionalFailure(failure)) {
            continue;
          }
          lines.push(
            util8.format(
              chalk21.red("%s | %s | %s | %s%s") + "\n",
              padLeft(_CurrentActivityPrinter.TIMESTAMP_WIDTH, new Date(failure.event.Timestamp).toLocaleTimeString()),
              padRight(_CurrentActivityPrinter.STATUS_WIDTH, (failure.event.ResourceStatus || "").slice(0, _CurrentActivityPrinter.STATUS_WIDTH)),
              padRight(this.resourceTypeColumnWidth, failure.event.ResourceType || ""),
              shorten(40, failure.event.LogicalResourceId ?? ""),
              this.failureReasonOnNextLine(failure)
            )
          );
          const trace2 = failure.metadata?.entry?.trace;
          if (trace2) {
            lines.push(chalk21.red(`	${trace2.join("\n	\\_ ")}
`));
          }
        }
        if (this.failures.some((f32) => this.isProvisionalFailure(f32))) {
          lines.push(chalk21.yellow("\n \u26A0\uFE0F  Some resources failed to delete but were skipped. These resources may still exist and could incur charges. Clean them up manually.\n"));
        }
        this.block.displayLines(lines);
        this.block.removeEmptyLines();
      }
      progressBar(width) {
        if (!this.stackProgress || !this.stackProgress.total) {
          return "";
        }
        const fraction = Math.min(this.stackProgress.completed / this.stackProgress.total, 1);
        const innerWidth = Math.max(1, width - 2);
        const chars6 = innerWidth * fraction;
        const remainder = chars6 - Math.floor(chars6);
        const fullChars = FULL_BLOCK.repeat(Math.floor(chars6));
        const partialChar = PARTIAL_BLOCK[Math.floor(remainder * PARTIAL_BLOCK.length)];
        const filler = "\xB7".repeat(innerWidth - Math.floor(chars6) - (partialChar ? 1 : 0));
        const color = this.rollingBack ? chalk21.yellow : chalk21.green;
        return "[" + color(fullChars + partialChar) + filler + `] (${this.stackProgress.completed}/${this.stackProgress.total})`;
      }
      failureReasonOnNextLine(activity) {
        return isErrorEvent(activity.event) ? `
${" ".repeat(_CurrentActivityPrinter.TIMESTAMP_WIDTH + _CurrentActivityPrinter.STATUS_WIDTH + 6)}${chalk21.red(this.failureReason(activity) ?? "")}` : "";
      }
    };
    FULL_BLOCK = "\u2588";
    PARTIAL_BLOCK = ["", "\u258F", "\u258E", "\u258D", "\u258C", "\u258B", "\u258A", "\u2589"];
    MAX_PROGRESSBAR_WIDTH = 60;
    MIN_PROGRESSBAR_WIDTH = 10;
    PROGRESSBAR_EXTRA_SPACE = 2 + 2 + 4 + 6;
    __name(colorFromStatusActivity, "colorFromStatusActivity");
    __name(shorten, "shorten");
  }
});

// ../@aws-cdk/toolkit-lib/lib/private/activity-printer/index.ts
var init_activity_printer = __esm({
  "../@aws-cdk/toolkit-lib/lib/private/activity-printer/index.ts"() {
    "use strict";
    init_base();
    init_history();
    init_current();
  }
});

// ../@aws-cdk/toolkit-lib/lib/util/shell-env.ts
function isCI() {
  return process.env.CI !== void 0 && process.env.CI !== "false" && process.env.CI !== "0";
}
function isTTY() {
  return process.stdout.isTTY ?? false;
}
var init_shell_env = __esm({
  "../@aws-cdk/toolkit-lib/lib/util/shell-env.ts"() {
    "use strict";
    __name(isCI, "isCI");
    __name(isTTY, "isTTY");
  }
});

// ../@aws-cdk/toolkit-lib/lib/toolkit/non-interactive-io-host.ts
function isStackActivity(msg) {
  return msg.code && [
    "CDK_TOOLKIT_I5501",
    "CDK_TOOLKIT_I5502",
    "CDK_TOOLKIT_I5503"
  ].includes(msg.code);
}
var chalk22, NonInteractiveIoHost, styleMap;
var init_non_interactive_io_host = __esm({
  "../@aws-cdk/toolkit-lib/lib/toolkit/non-interactive-io-host.ts"() {
    "use strict";
    chalk22 = __toESM(require_source());
    init_private();
    init_activity_printer();
    init_shell_env();
    NonInteractiveIoHost = class {
      static {
        __name(this, "NonInteractiveIoHost");
      }
      /**
       * Whether the IoHost is running in CI mode.
       *
       * In CI mode, all non-error output goes to stdout instead of stderr.
       */
      isCI;
      /**
       * Whether the host can use interactions and message styling.
       */
      isTTY;
      /**
       * The current threshold.
       *
       * Messages with a lower priority level will be ignored.
       */
      logLevel;
      // Stack Activity Printer
      activityPrinter;
      constructor(props = {}) {
        this.logLevel = props.logLevel ?? "info";
        this.isTTY = props.isTTY ?? isTTY();
        this.isCI = props.isCI ?? isCI();
        this.activityPrinter = new HistoryActivityPrinter({
          stream: this.selectStreamFromLevel("info")
        });
      }
      /**
       * Notifies the host of a message.
       * The caller waits until the notification completes.
       */
      async notify(msg) {
        if (isStackActivity(msg)) {
          return this.activityPrinter.notify(msg);
        }
        if (!isMessageRelevantForLevel(msg, this.logLevel)) {
          return;
        }
        const output = this.formatMessage(msg);
        const stream = this.selectStream(msg);
        stream?.write(output);
      }
      /**
       * Determines the output stream, based on message and configuration.
       */
      selectStream(msg) {
        return this.selectStreamFromLevel(msg.level);
      }
      /**
       * Determines the output stream, based on message level and configuration.
       */
      selectStreamFromLevel(level) {
        switch (level) {
          case "error":
            return process.stderr;
          case "result":
            return process.stdout;
          default:
            return this.isCI ? process.stdout : process.stderr;
        }
      }
      /**
       * Notifies the host of a message that requires a response.
       *
       * If the host does not return a response the suggested
       * default response from the input message will be used.
       */
      async requestResponse(msg) {
        await this.notify(msg);
        return msg.defaultResponse;
      }
      /**
       * Formats a message for console output with optional color support
       */
      formatMessage(msg) {
        let message_text = this.isTTY ? styleMap[msg.level](msg.message) : msg.message;
        return (msg.level === "debug" || msg.level === "trace" ? `[${this.formatTime(msg.time)}] ${message_text}` : message_text) + "\n";
      }
      /**
       * Formats date to HH:MM:SS
       */
      formatTime(d32) {
        const pad = /* @__PURE__ */ __name((n10) => n10.toString().padStart(2, "0"), "pad");
        return `${pad(d32.getHours())}:${pad(d32.getMinutes())}:${pad(d32.getSeconds())}`;
      }
    };
    styleMap = {
      error: chalk22.red,
      warn: chalk22.yellow,
      result: chalk22.reset,
      info: chalk22.reset,
      debug: chalk22.gray,
      trace: chalk22.gray
    };
    __name(isStackActivity, "isStackActivity");
  }
});

// ../@aws-cdk/toolkit-lib/lib/toolkit/private/index.ts
async function assemblyFromSource(ioHelper, assemblySource, cache32 = true) {
  if (assemblySource instanceof StackAssembly) {
    return assemblySource;
  }
  if (cache32) {
    return new StackAssembly(new CachedCloudAssembly(await assemblySource.produce()), ioHelper);
  }
  return new StackAssembly(await assemblySource.produce(), ioHelper);
}
var init_private5 = __esm({
  "../@aws-cdk/toolkit-lib/lib/toolkit/private/index.ts"() {
    "use strict";
    init_cloud_assembly3();
    init_private3();
    __name(assemblyFromSource, "assemblyFromSource");
  }
});

// ../@aws-cdk/toolkit-lib/lib/actions/bootstrap/private/helpers.ts
function environmentsFromDescriptors(envSpecs) {
  const ret = new Array();
  for (const spec of envSpecs) {
    const parts = spec.replace(/^aws:\/\//, "").split("/");
    if (parts.length !== 2) {
      throw new ToolkitError("InvalidEnvironmentFormat", `Expected environment name in format 'aws://<account>/<region>', got: ${spec}`);
    }
    ret.push({
      name: spec,
      account: parts[0],
      region: parts[1]
    });
  }
  return ret;
}
var init_helpers3 = __esm({
  "../@aws-cdk/toolkit-lib/lib/actions/bootstrap/private/helpers.ts"() {
    "use strict";
    init_toolkit_error();
    __name(environmentsFromDescriptors, "environmentsFromDescriptors");
  }
});

// ../@aws-cdk/toolkit-lib/lib/actions/bootstrap/private/index.ts
var init_private6 = __esm({
  "../@aws-cdk/toolkit-lib/lib/actions/bootstrap/private/index.ts"() {
    "use strict";
    init_helpers3();
  }
});

// ../@aws-cdk/toolkit-lib/lib/actions/bootstrap/index.ts
var path31, BootstrapEnvironments, BootstrapStackParameters, BootstrapSource, BootstrapTemplate;
var init_bootstrap4 = __esm({
  "../@aws-cdk/toolkit-lib/lib/actions/bootstrap/index.ts"() {
    "use strict";
    path31 = __toESM(require("path"));
    init_private6();
    init_private3();
    init_private();
    init_private5();
    init_util3();
    BootstrapEnvironments = class _BootstrapEnvironments {
      constructor(envProvider) {
        this.envProvider = envProvider;
      }
      envProvider;
      static {
        __name(this, "BootstrapEnvironments");
      }
      /**
       * Create from a list of environment descriptors
       * List of strings like `['aws://012345678912/us-east-1', 'aws://234567890123/eu-west-1']`
       */
      static fromList(environments) {
        return new _BootstrapEnvironments(environmentsFromDescriptors(environments));
      }
      /**
       * Create from a cloud assembly source
       */
      static fromCloudAssemblySource(cx) {
        return new _BootstrapEnvironments(async (ioHost) => {
          var _stack = [];
          try {
            const ioHelper = asIoHelper(ioHost, "bootstrap");
            const assembly = __using(_stack, await assemblyFromSource(ioHelper, cx), true);
            const stackCollection = await assembly.selectStacksV2(ALL_STACKS);
            return stackCollection.stackArtifacts.map((stack) => stack.environment);
          } catch (_) {
            var _error = _, _hasError = true;
          } finally {
            var _promise = __callDispose(_stack, _error, _hasError);
            _promise && await _promise;
          }
        });
      }
      /**
       * Compute the bootstrap enviornments
       *
       * @internal
       */
      async getEnvironments(ioHost) {
        if (Array.isArray(this.envProvider)) {
          return this.envProvider;
        }
        return this.envProvider(ioHost);
      }
    };
    BootstrapStackParameters = class _BootstrapStackParameters {
      static {
        __name(this, "BootstrapStackParameters");
      }
      /**
       * Use only existing parameters on the stack.
       */
      static onlyExisting() {
        return new _BootstrapStackParameters({}, true);
      }
      /**
       * Use exactly these parameters and remove any other existing parameters from the stack.
       */
      static exactly(params) {
        return new _BootstrapStackParameters(params, false);
      }
      /**
       * Define additional parameters for the stack, while keeping existing parameters for unspecified values.
       */
      static withExisting(params) {
        return new _BootstrapStackParameters(params, true);
      }
      /**
       * The parameters as a Map for easy access and manipulation
       */
      parameters;
      keepExistingParameters;
      constructor(params, usePreviousParameters = true) {
        this.keepExistingParameters = usePreviousParameters;
        this.parameters = params;
      }
    };
    BootstrapSource = class {
      static {
        __name(this, "BootstrapSource");
      }
      /**
       * Use the default bootstrap template
       */
      static default() {
        return { source: "default" };
      }
      /**
       * Use a custom bootstrap template
       */
      static customTemplate(templateFile) {
        return {
          source: "custom",
          templateFile
        };
      }
    };
    BootstrapTemplate = class _BootstrapTemplate {
      constructor(template) {
        this.template = template;
      }
      template;
      static {
        __name(this, "BootstrapTemplate");
      }
      /**
       * Load a bootstrap template from a source
       *
       * @param source - The bootstrap template source configuration
       * @returns A BootstrapTemplate instance
       */
      static async fromSource(source = { source: "default" }) {
        let template;
        switch (source.source) {
          case "custom":
            template = await loadStructuredFile(source.templateFile);
            break;
          case "default":
            template = await loadStructuredFile(path31.join(bundledPackageRootDir(__dirname), "lib", "api", "bootstrap", "bootstrap-template.yaml"));
            break;
        }
        return new _BootstrapTemplate(template);
      }
      /**
       * Serialize the template as YAML
       *
       * @returns The template as a YAML string
       */
      asYAML() {
        return serializeStructure(this.template, false);
      }
      /**
       * Serialize the template as JSON
       *
       * @returns The template as a JSON string
       */
      asJSON() {
        return serializeStructure(this.template, true);
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/actions/deploy/index.ts
var AssetBuildTime, StackParameters;
var init_deploy3 = __esm({
  "../@aws-cdk/toolkit-lib/lib/actions/deploy/index.ts"() {
    "use strict";
    AssetBuildTime = /* @__PURE__ */ ((AssetBuildTime3) => {
      AssetBuildTime3["ALL_BEFORE_DEPLOY"] = "all-before-deploy";
      AssetBuildTime3["JUST_IN_TIME"] = "just-in-time";
      return AssetBuildTime3;
    })(AssetBuildTime || {});
    StackParameters = class _StackParameters {
      static {
        __name(this, "StackParameters");
      }
      /**
       * Use only existing parameters on the stack.
       */
      static onlyExisting() {
        return new _StackParameters({}, true);
      }
      /**
       * Use exactly these parameters and remove any other existing parameters from the stack.
       */
      static exactly(params) {
        return new _StackParameters(params, false);
      }
      /**
       * Define additional parameters for the stack, while keeping existing parameters for unspecified values.
       */
      static withExisting(params) {
        return new _StackParameters(params, true);
      }
      parameters;
      keepExistingParameters;
      constructor(params, usePreviousParameters = true) {
        this.keepExistingParameters = usePreviousParameters;
        this.parameters = new Map(Object.entries(params));
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/actions/deploy/private/deploy-options.ts
var init_deploy_options = __esm({
  "../@aws-cdk/toolkit-lib/lib/actions/deploy/private/deploy-options.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/actions/deploy/private/helpers.ts
function buildParameterMap(parameters) {
  const parameterMap = {};
  parameterMap["*"] = {};
  const entries = parameters?.entries() ?? [];
  for (const [key, value] of entries) {
    const [stack, parameter] = key.split(":", 2);
    if (!parameter) {
      parameterMap["*"][stack] = value;
    } else {
      if (!parameterMap[stack]) {
        parameterMap[stack] = {};
      }
      parameterMap[stack][parameter] = value;
    }
  }
  return parameterMap;
}
async function removePublishedAssetsFromWorkGraph(graph, deployments, options) {
  await graph.removeUnnecessaryAssets((assetNode) => deployments.isSingleAssetPublished(assetNode.assetManifest, assetNode.asset, {
    stack: assetNode.parentStack,
    roleArn: options.roleArn,
    stackName: assetNode.parentStack.stackName
  }));
}
var init_helpers4 = __esm({
  "../@aws-cdk/toolkit-lib/lib/actions/deploy/private/helpers.ts"() {
    "use strict";
    __name(buildParameterMap, "buildParameterMap");
    __name(removePublishedAssetsFromWorkGraph, "removePublishedAssetsFromWorkGraph");
  }
});

// ../@aws-cdk/toolkit-lib/lib/actions/deploy/private/index.ts
var init_private7 = __esm({
  "../@aws-cdk/toolkit-lib/lib/actions/deploy/private/index.ts"() {
    "use strict";
    init_deploy_options();
    init_deployment_method();
    init_helpers4();
  }
});

// ../@aws-cdk/toolkit-lib/lib/actions/diff/index.ts
var DiffMethod;
var init_diff4 = __esm({
  "../@aws-cdk/toolkit-lib/lib/actions/diff/index.ts"() {
    "use strict";
    DiffMethod = class _DiffMethod {
      constructor(method, options) {
        this.method = method;
        this.options = options;
      }
      method;
      options;
      static {
        __name(this, "DiffMethod");
      }
      /**
       * Use a changeset to compute the diff.
       *
       * This will create, analyze, and subsequently delete a changeset against the CloudFormation stack.
       */
      static ChangeSet(options = {}) {
        return new class extends _DiffMethod {
          options;
          constructor(opts) {
            super("change-set", opts);
            this.options = opts;
          }
        }(options);
      }
      static TemplateOnly(options = {}) {
        return new class extends _DiffMethod {
          options;
          constructor(opts) {
            super("template-only", opts);
            this.options = opts;
          }
        }(options);
      }
      /**
       * Use a local template file to compute the diff.
       */
      static LocalFile(path47) {
        return new class extends _DiffMethod {
          options;
          constructor(opts) {
            super("local-file", opts);
            this.options = opts;
          }
        }({ path: path47 });
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/refactoring/cloudformation.ts
var ResourceLocation, ResourceMapping;
var init_cloudformation4 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/refactoring/cloudformation.ts"() {
    "use strict";
    ResourceLocation = class {
      constructor(stack, logicalResourceId) {
        this.stack = stack;
        this.logicalResourceId = logicalResourceId;
      }
      stack;
      logicalResourceId;
      static {
        __name(this, "ResourceLocation");
      }
      toPath() {
        const resource = this.stack.template.Resources?.[this.logicalResourceId];
        const result2 = resource?.Metadata?.["aws:cdk:path"];
        if (result2 != null) {
          return result2;
        }
        return this.toLocationString();
      }
      toLocationString() {
        return `${this.stack.stackName}.${this.logicalResourceId}`;
      }
      getType() {
        const resource = this.stack.template.Resources?.[this.logicalResourceId ?? ""];
        return resource?.Type ?? "Unknown";
      }
      equalTo(other) {
        return this.logicalResourceId === other.logicalResourceId && this.stack.stackName === other.stack.stackName;
      }
      get stackName() {
        return this.stack.stackName;
      }
    };
    ResourceMapping = class {
      constructor(source, destination) {
        this.source = source;
        this.destination = destination;
      }
      source;
      destination;
      static {
        __name(this, "ResourceMapping");
      }
      toTypedMapping() {
        return {
          // the type is the same in both source and destination,
          // so we can use either one
          type: this.source.getType(),
          sourcePath: this.source.toPath(),
          destinationPath: this.destination.toPath()
        };
      }
      toCloudFormation() {
        return {
          Source: {
            StackName: this.source.stack.stackName,
            LogicalResourceId: this.source.logicalResourceId
          },
          Destination: {
            StackName: this.destination.stack.stackName,
            LogicalResourceId: this.destination.logicalResourceId
          }
        };
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/refactoring/graph.ts
var ResourceGraph;
var init_graph = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/refactoring/graph.ts"() {
    "use strict";
    init_toolkit_error();
    ResourceGraph = class _ResourceGraph {
      static {
        __name(this, "ResourceGraph");
      }
      static fromStacks(stacks) {
        const exports2 = Object.fromEntries(
          stacks.flatMap(
            (s) => Object.values(s.template.Outputs ?? {}).filter((o10) => o10.Export != null && typeof o10.Export.Name === "string").map(
              (o10) => [o10.Export.Name, { stackName: s.stackName, value: o10.Value }]
            )
          )
        );
        const resources = Object.fromEntries(
          stacks.flatMap(
            (s) => Object.entries(s.template.Resources ?? {}).map(
              ([id, res]) => [`${s.stackName}.${id}`, res]
            )
          )
        );
        const edges = {};
        const reverseEdges = {};
        for (const id of Object.keys(resources)) {
          edges[id] = /* @__PURE__ */ new Set();
          reverseEdges[id] = /* @__PURE__ */ new Set();
        }
        const findDependencies = /* @__PURE__ */ __name((stackName, value) => {
          if (!value || typeof value !== "object") return [];
          if (Array.isArray(value)) {
            return value.flatMap((res) => findDependencies(stackName, res));
          }
          if ("Ref" in value) {
            return [`${stackName}.${value.Ref}`];
          }
          if ("Fn::GetAtt" in value) {
            const refTarget = Array.isArray(value["Fn::GetAtt"]) ? value["Fn::GetAtt"][0] : value["Fn::GetAtt"].split(".")[0];
            return [`${stackName}.${refTarget}`];
          }
          if ("Fn::ImportValue" in value) {
            const exp = exports2[value["Fn::ImportValue"]];
            if (exp != null) {
              const v = exp.value;
              if (v != null && typeof v === "object") {
                if ("Fn::GetAtt" in v) {
                  const id = Array.isArray(v["Fn::GetAtt"]) ? v["Fn::GetAtt"][0] : v["Fn::GetAtt"].split(".")[0];
                  return [`${exp.stackName}.${id}`];
                }
                if ("Ref" in v) {
                  return [`${exp.stackName}.${v.Ref}`];
                }
              }
              return [`${exp.stackName}.${v}`];
            }
          }
          const result2 = [];
          if ("DependsOn" in value) {
            if (Array.isArray(value.DependsOn)) {
              result2.push(...value.DependsOn.map((r32) => `${stackName}.${r32}`));
            } else {
              result2.push(`${stackName}.${value.DependsOn}`);
            }
          }
          result2.push(...Object.values(value).flatMap((res) => findDependencies(stackName, res)));
          return result2;
        }, "findDependencies");
        for (const [id, res] of Object.entries(resources)) {
          const stackName = id.split(".")[0];
          const deps = findDependencies(stackName, res || {});
          for (const dep of deps) {
            if (dep in resources && dep !== id) {
              edges[id].add(dep);
              reverseEdges[dep].add(id);
            }
          }
        }
        return new _ResourceGraph(edges, reverseEdges);
      }
      edges = {};
      reverseEdges = {};
      constructor(edges, reverseEdges) {
        this.edges = edges;
        this.reverseEdges = reverseEdges;
      }
      /**
       * Returns the sorted nodes in topological order.
       */
      get sortedNodes() {
        const result2 = [];
        const outDegree = Object.keys(this.edges).reduce((acc, k32) => {
          acc[k32] = this.edges[k32].size;
          return acc;
        }, {});
        const queue = Object.keys(outDegree).filter((k32) => outDegree[k32] === 0);
        while (queue.length > 0) {
          const node = queue.shift();
          result2.push(node);
          for (const nxt of this.reverseEdges[node]) {
            outDegree[nxt]--;
            if (outDegree[nxt] === 0) {
              queue.push(nxt);
            }
          }
        }
        return result2;
      }
      inNeighbors(node) {
        if (!(node in this.edges)) {
          throw new ToolkitError("RefactorGraphNodeNotFound", `Node ${node} not found in the graph`);
        }
        return Array.from(this.reverseEdges[node] || []);
      }
      outNeighbors(node) {
        if (!(node in this.edges)) {
          throw new ToolkitError("RefactorGraphNodeNotFound", `Node ${node} not found in the graph`);
        }
        return Array.from(this.edges[node] || []);
      }
      /**
       * Returns another graph with the same nodes, but with the edges inverted
       */
      opposite() {
        return new _ResourceGraph(this.reverseEdges, this.edges);
      }
    };
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/refactoring/digest.ts
function computeResourceDigests(stacks, direction = "direct") {
  const exports2 = Object.fromEntries(
    stacks.flatMap(
      (s) => Object.values(s.template.Outputs ?? {}).filter((o10) => o10.Export != null && typeof o10.Export.Name === "string").map(
        (o10) => [o10.Export.Name, { stackName: s.stackName, value: o10.Value }]
      )
    )
  );
  const resources = Object.fromEntries(
    stacks.flatMap((s) => {
      return Object.entries(s.template.Resources ?? {}).filter(([_, res]) => res.Type !== "AWS::CDK::Metadata").map(([id, res]) => [`${s.stackName}.${id}`, res]);
    })
  );
  const graph = direction == "direct" ? ResourceGraph.fromStacks(stacks) : ResourceGraph.fromStacks(stacks).opposite();
  return computeDigestsInTopologicalOrder(graph, resources, exports2);
}
function computeDigestsInTopologicalOrder(graph, resources, exports2) {
  const nodes32 = graph.sortedNodes.filter((n10) => resources[n10] != null);
  const result2 = {};
  for (const id of nodes32) {
    const resource = resources[id];
    const depDigests = Array.from(graph.outNeighbors(id)).map((d32) => result2[d32]);
    const propertiesHash = hashObject(stripReferences(stripConstructPath(resource), exports2));
    const toHash = resource.Type + propertiesHash + depDigests.join("");
    result2[id] = crypto3.createHash("sha256").update(toHash).digest("hex");
  }
  return result2;
}
function hashObject(obj) {
  const hash = crypto3.createHash("sha256");
  function addToHash(value) {
    if (value == null) {
      addToHash("null");
    } else if (typeof value === "object") {
      if (Array.isArray(value)) {
        value.forEach(addToHash);
      } else {
        Object.keys(value).sort().forEach((key) => {
          hash.update(key);
          addToHash(value[key]);
        });
      }
    } else {
      hash.update(typeof value + value.toString());
    }
  }
  __name(addToHash, "addToHash");
  addToHash(obj);
  return hash.digest("hex");
}
function stripReferences(value, exports2) {
  if (!value || typeof value !== "object") return value;
  if (Array.isArray(value)) {
    return value.map((x) => stripReferences(x, exports2));
  }
  if ("Ref" in value) {
    return { __cloud_ref__: "Ref" };
  }
  if ("Fn::GetAtt" in value) {
    return { __cloud_ref__: "Fn::GetAtt" };
  }
  if ("DependsOn" in value) {
    return { __cloud_ref__: "DependsOn" };
  }
  if ("Fn::ImportValue" in value) {
    const exp = exports2[value["Fn::ImportValue"]];
    if (exp != null) {
      const v = exp.value;
      if (v != null && typeof v === "object") {
        if ("Ref" in v) {
          return { __cloud_ref__: "Ref" };
        } else if ("Fn::GetAtt" in v) {
          return { __cloud_ref__: "Fn::GetAtt" };
        }
      } else {
        return v;
      }
    }
  }
  const result2 = {};
  for (const [k32, v] of Object.entries(value)) {
    result2[k32] = stripReferences(v, exports2);
  }
  return result2;
}
function stripConstructPath(resource) {
  if (resource?.Metadata?.["aws:cdk:path"] == null) {
    return resource;
  }
  const copy2 = JSON.parse(JSON.stringify(resource));
  delete copy2.Metadata["aws:cdk:path"];
  return copy2;
}
var crypto3;
var init_digest = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/refactoring/digest.ts"() {
    "use strict";
    crypto3 = __toESM(require("node:crypto"));
    init_graph();
    __name(computeResourceDigests, "computeResourceDigests");
    __name(computeDigestsInTopologicalOrder, "computeDigestsInTopologicalOrder");
    __name(hashObject, "hashObject");
    __name(stripReferences, "stripReferences");
    __name(stripConstructPath, "stripConstructPath");
  }
});

// ../@aws-cdk/toolkit-lib/lib/util/concurrency.ts
var pLimit4;
var init_concurrency = __esm({
  "../@aws-cdk/toolkit-lib/lib/util/concurrency.ts"() {
    "use strict";
    pLimit4 = require_p_limit();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/refactoring/context.ts
function structuralOverrides(deployedStacks, localStacks) {
  const moves = resourceMoves(deployedStacks, localStacks, "opposite", true);
  const [nonAmbiguousMoves] = partitionByAmbiguity([], moves);
  return resourceMappings(nonAmbiguousMoves);
}
function resourceMoves(before, after, direction = "direct", ignoreModifications = false) {
  const digestsBefore = resourceDigests(before, direction);
  const digestsAfter = resourceDigests(after, direction);
  if (!(ignoreModifications || isomorphic(digestsBefore, digestsAfter))) {
    const message2 = ["A refactor operation cannot add, remove or update resources. Only resource moves and renames are allowed."];
    const locationsForDigests = /* @__PURE__ */ __name((a32, b32) => {
      return Array.from(setDiff(new Set(Object.keys(a32)), new Set(Object.keys(b32)))).flatMap((k32) => a32[k32]);
    }, "locationsForDigests");
    const formatList = /* @__PURE__ */ __name((locs, icon) => locs.map((x) => `  [${icon}] ${x.toPath()}`).sort().join("\n"), "formatList");
    const stackNames = /* @__PURE__ */ __name((stacks) => stacks.length === 0 ? "NONE" : stacks.map((s) => s.stackName).sort().join(", "), "stackNames");
    const onlyDeployedLocs = locationsForDigests(digestsBefore, digestsAfter);
    const onlyLocalLocs = locationsForDigests(digestsAfter, digestsBefore);
    const onlyDeployedPaths = new Set(onlyDeployedLocs.map((l20) => l20.toPath()));
    const onlyLocalPaths = new Set(onlyLocalLocs.map((l20) => l20.toPath()));
    const differentPaths = new Set(Array.from(onlyDeployedPaths).filter((p10) => onlyLocalPaths.has(p10)));
    const onlyDeployed = formatList(onlyDeployedLocs.filter((l20) => !differentPaths.has(l20.toPath())), "-");
    const onlyLocal = formatList(onlyLocalLocs.filter((l20) => !differentPaths.has(l20.toPath())), "+");
    const different = formatList([...onlyDeployedLocs, ...onlyLocalLocs].filter((l20) => differentPaths.has(l20.toPath())), "~");
    if (onlyDeployed.length > 0) {
      message2.push(`The following resources are present only in the AWS environment:
${onlyDeployed}`);
    }
    if (onlyLocal.length > 0) {
      message2.push(`
The following resources are present only in your CDK application:
${onlyLocal}`);
    }
    if (different.length > 0) {
      message2.push(`
The following resources are different in your CDK application and the AWS environment:
${different}`);
    }
    message2.push("");
    message2.push("The following stacks were used in the comparison:");
    message2.push(`  - Deployed: ${stackNames(before)}`);
    message2.push(`  - Local: ${stackNames(after)}`);
    message2.push("");
    message2.push("Hint: by default, only deployed stacks that have the same name as a local stack are included.");
    message2.push("If you want to include additional deployed stacks for comparison, re-run the command with the option '--additional-stack-name=<STACK>' for each stack.");
    throw new ToolkitError("RefactorResourceMismatch", message2.join("\n"));
  }
  return Object.values(removeUnmovedResources(zip(digestsBefore, digestsAfter)));
}
function isomorphic(a32, b32) {
  const sameKeys = equalSets(new Set(Object.keys(a32)), new Set(Object.keys(b32)));
  return sameKeys && Object.entries(a32).every(([digest, locations]) => locations.length === b32[digest].length);
}
function removeUnmovedResources(moves) {
  const result2 = {};
  for (const [hash, [before, after]] of Object.entries(moves)) {
    const common = before.filter((b32) => after.some((a32) => a32.equalTo(b32)));
    result2[hash] = [
      before.filter((b32) => !common.some((c32) => b32.equalTo(c32))),
      after.filter((a32) => !common.some((c32) => a32.equalTo(c32)))
    ];
  }
  return result2;
}
function zip(m1, m22) {
  const result2 = {};
  for (const [hash, locations] of Object.entries(m1)) {
    if (hash in m22) {
      result2[hash] = [locations, m22[hash]];
    } else {
      result2[hash] = [locations, []];
    }
  }
  for (const [hash, locations] of Object.entries(m22)) {
    if (!(hash in m1)) {
      result2[hash] = [[], locations];
    }
  }
  return result2;
}
function resourceDigests(stacks, direction) {
  const stacksByName = /* @__PURE__ */ new Map();
  for (const stack of stacks) {
    stacksByName.set(stack.stackName, stack);
  }
  const digests = computeResourceDigests(stacks, direction);
  return groupByKey(
    Object.entries(digests).map(([loc, digest]) => {
      const [stackName, logicalId] = loc.split(".");
      const location = new ResourceLocation(stacksByName.get(stackName), logicalId);
      return [digest, location];
    })
  );
  function groupByKey(entries) {
    const result2 = {};
    for (const [key, value] of entries) {
      if (key in result2) {
        result2[key].push(value);
      } else {
        result2[key] = [value];
      }
    }
    return result2;
  }
  __name(groupByKey, "groupByKey");
}
function isAmbiguousMove(move) {
  const [pre, post] = move;
  return pre.length > 0 && post.length > 0 && (pre.length > 1 || post.length > 1);
}
function resourceMappings(movements) {
  return movements.filter(([pre, post]) => pre.length === 1 && post.length === 1 && !pre[0].equalTo(post[0])).map(([pre, post]) => new ResourceMapping(pre[0], post[0]));
}
function partitionByAmbiguity(overrides, moves) {
  const ambiguous = [];
  const nonAmbiguous = [];
  for (let move of moves) {
    if (!isAmbiguousMove(move)) {
      nonAmbiguous.push(move);
    } else {
      for (const override of overrides) {
        const resolvedMove = resolve13(override, move);
        if (resolvedMove != null) {
          nonAmbiguous.push(resolvedMove);
          move = remove2(override, move);
        }
      }
      if (!isAmbiguousMove(move)) {
        nonAmbiguous.push(move);
      } else {
        ambiguous.push(move);
      }
    }
  }
  function resolve13(override, move) {
    const [pre, post] = move;
    const source = pre.find((loc) => loc.equalTo(override.source));
    const destination = post.find((loc) => loc.equalTo(override.destination));
    return source && destination ? [[source], [destination]] : void 0;
  }
  __name(resolve13, "resolve");
  function remove2(override, move) {
    const [pre, post] = move;
    return [
      pre.filter((loc) => !loc.equalTo(override.source)),
      post.filter((loc) => !loc.equalTo(override.destination))
    ];
  }
  __name(remove2, "remove");
  return [nonAmbiguous, ambiguous];
}
async function replaceAwsPlaceholders2(object, aws) {
  let partition4 = /* @__PURE__ */ __name(async () => {
    const p10 = await aws.discoverPartition();
    partition4 = /* @__PURE__ */ __name(() => Promise.resolve(p10), "partition");
    return p10;
  }, "partition");
  let account = /* @__PURE__ */ __name(async () => {
    const a32 = await aws.discoverCurrentAccount();
    account = /* @__PURE__ */ __name(() => Promise.resolve(a32), "account");
    return a32;
  }, "account");
  return import_cloud_assembly_api14.EnvironmentPlaceholders.replaceAsync(object, {
    async region() {
      return object.region ?? aws.discoverDefaultRegion();
    },
    async accountId() {
      return (await account()).accountId;
    },
    async partition() {
      return partition4();
    }
  });
}
var import_cdk_assets_lib5, import_cloud_assembly_api14, RefactoringContext;
var init_context3 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/refactoring/context.ts"() {
    "use strict";
    import_cdk_assets_lib5 = __toESM(require_lib5());
    import_cloud_assembly_api14 = __toESM(require_lib3());
    init_cloudformation4();
    init_digest();
    init_toolkit_error();
    init_sets();
    init_environment2();
    init_plugin2();
    RefactoringContext = class {
      static {
        __name(this, "RefactoringContext");
      }
      _mappings = [];
      ambiguousMoves = [];
      localStacks;
      assumeRoleArn;
      environment;
      constructor(props) {
        this.environment = props.environment;
        const moves = resourceMoves(props.deployedStacks, props.localStacks, "direct", props.ignoreModifications);
        const additionalOverrides = structuralOverrides(props.deployedStacks, props.localStacks);
        const overrides = (props.overrides ?? []).concat(additionalOverrides);
        const [nonAmbiguousMoves, ambiguousMoves] = partitionByAmbiguity(overrides, moves);
        this.ambiguousMoves = ambiguousMoves;
        this.localStacks = props.localStacks;
        this.assumeRoleArn = props.assumeRoleArn;
        this._mappings = resourceMappings(nonAmbiguousMoves);
      }
      get ambiguousPaths() {
        return this.ambiguousMoves.map(([a32, b32]) => [convert(a32), convert(b32)]);
        function convert(locations) {
          return locations.map((l20) => l20.toPath());
        }
        __name(convert, "convert");
      }
      get mappings() {
        return this._mappings;
      }
      async execute(stackDefinitions, sdkProvider, ioHelper) {
        if (this.mappings.length === 0) {
          return;
        }
        const assumeRoleArn = this.assumeRoleArn ?? await this.findRoleToAssume(sdkProvider);
        const sdk = (await sdkProvider.forEnvironment(this.environment, 1 /* ForWriting */, {
          assumeRoleArn
        })).sdk;
        await this.checkBootstrapVersion(sdk, ioHelper);
        const cfn = sdk.cloudFormation();
        const mappings = this.mappings;
        const input = {
          ResourceMappings: mappings.map((m20) => m20.toCloudFormation()),
          StackDefinitions: stackDefinitions
        };
        const refactor = await cfn.createStackRefactor(input);
        await cfn.waitUntilStackRefactorCreateComplete({
          StackRefactorId: refactor.StackRefactorId
        });
        await cfn.executeStackRefactor({
          StackRefactorId: refactor.StackRefactorId
        });
        await cfn.waitUntilStackRefactorExecuteComplete({
          StackRefactorId: refactor.StackRefactorId
        });
      }
      async checkBootstrapVersion(sdk, ioHelper) {
        const environmentResourcesRegistry = new EnvironmentResourcesRegistry();
        const envResources = environmentResourcesRegistry.for(this.environment, sdk, ioHelper);
        let bootstrapVersion = void 0;
        try {
          bootstrapVersion = (await envResources.lookupToolkit()).version;
        } catch (e32) {
        }
        if (bootstrapVersion != null && bootstrapVersion < 28) {
          const environment = `aws://${this.environment.account}/${this.environment.region}`;
          throw new ToolkitError(
            "BootstrapVersionTooLow",
            `The CDK toolkit stack in environment ${environment} doesn't support refactoring. Please run 'cdk bootstrap ${environment}' to update it.`
          );
        }
      }
      async findRoleToAssume(sdkProvider) {
        const env3 = this.environment;
        const roleArns = new Set(
          this.localStacks.filter((s) => s.environment.account === env3.account && s.environment.region === env3.region).map((s) => s.assumeRoleArn)
        );
        if (roleArns.size === 0) {
          return void 0;
        }
        if (roleArns.size !== 1) {
          throw new ToolkitError(
            "MultipleDeploymentRoles",
            `Multiple stacks in environment aws://${env3.account}/${env3.region} have different deployment role ARNs. Cannot proceed.`
          );
        }
        const arn = Array.from(roleArns)[0];
        if (arn != null) {
          const resolvedEnv = await sdkProvider.resolveEnvironment(env3);
          const region = resolvedEnv.region;
          return (await replaceAwsPlaceholders2({ region, assumeRoleArn: arn }, new import_cdk_assets_lib5.DefaultAwsClient())).assumeRoleArn;
        }
        return void 0;
      }
    };
    __name(structuralOverrides, "structuralOverrides");
    __name(resourceMoves, "resourceMoves");
    __name(isomorphic, "isomorphic");
    __name(removeUnmovedResources, "removeUnmovedResources");
    __name(zip, "zip");
    __name(resourceDigests, "resourceDigests");
    __name(isAmbiguousMove, "isAmbiguousMove");
    __name(resourceMappings, "resourceMappings");
    __name(partitionByAmbiguity, "partitionByAmbiguity");
    __name(replaceAwsPlaceholders2, "replaceAwsPlaceholders");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/refactoring/index.ts
async function getDeployedStacksByNames(sdkProvider, environment, stackNames) {
  const cfn = (await sdkProvider.forEnvironment(environment, 0 /* ForReading */)).sdk.cloudFormation();
  const normalize4 = /* @__PURE__ */ __name(async (stackName) => {
    const templateCommandOutput = await cfn.getTemplate({ StackName: stackName });
    const template = deserializeStructure(templateCommandOutput.TemplateBody ?? "{}");
    return {
      environment,
      stackName,
      template
    };
  }, "normalize");
  const limit = pLimit4(20);
  return Promise.all(stackNames.map((s) => limit(() => normalize4(s))));
}
async function listStacks(sdkProvider, environment) {
  const cfn = (await sdkProvider.forEnvironment(environment, 0 /* ForReading */)).sdk.cloudFormation();
  return cfn.paginatedListStacks({
    StackStatusFilter: [
      "CREATE_COMPLETE",
      "UPDATE_COMPLETE",
      "UPDATE_ROLLBACK_COMPLETE",
      "IMPORT_COMPLETE",
      "ROLLBACK_COMPLETE"
    ]
  });
}
function formatEnvironmentSectionHeader2(environment) {
  const env3 = `aws://${environment.account}/${environment.region}`;
  return formatToStream((stream) => (0, import_cloudformation_diff2.formatEnvironmentSectionHeader)(stream, env3));
}
function formatTypedMappings2(mappings) {
  return formatToStream((stream) => (0, import_cloudformation_diff2.formatTypedMappings)(stream, mappings));
}
function formatAmbiguousMappings2(paths) {
  return formatToStream((stream) => (0, import_cloudformation_diff2.formatAmbiguousMappings)(stream, paths));
}
function formatToStream(cb) {
  const stream = new StringWriteStream();
  cb(stream);
  return stream.toString();
}
async function groupStacks(sdkProvider, localStacks, additionalStackNames) {
  const environments = /* @__PURE__ */ new Map();
  for (const stack of localStacks) {
    const environment = await sdkProvider.resolveEnvironment(stack.environment);
    const key = hashObject(environment);
    environments.set(key, environment);
  }
  const localByEnvironment = await indexBy(
    localStacks,
    async (s) => hashObject(await sdkProvider.resolveEnvironment(s.environment))
  );
  const groups = [];
  for (let key of localByEnvironment.keys()) {
    const local = localByEnvironment.get(key);
    const hasLocalCounterpart = /* @__PURE__ */ __name((stackName) => local.some((l20) => l20.stackName === stackName), "hasLocalCounterpart");
    const wasExplicitlyProvided = /* @__PURE__ */ __name((stackName) => additionalStackNames.includes(stackName), "wasExplicitlyProvided");
    const environment = environments.get(key);
    const stackSummaries = await listStacks(sdkProvider, environment);
    const stackNames = stackSummaries.map((s) => s.StackName).filter((s) => hasLocalCounterpart(s) || wasExplicitlyProvided(s));
    const deployedStacks = await getDeployedStacksByNames(sdkProvider, environment, stackNames);
    groups.push({
      environment,
      deployedStacks,
      localStacks: local
    });
  }
  return groups;
}
var import_cloudformation_diff2;
var init_refactoring = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/refactoring/index.ts"() {
    "use strict";
    import_cloudformation_diff2 = __toESM(require_lib9());
    init_util3();
    init_plugin2();
    init_streams();
    init_cloudformation4();
    init_digest();
    init_toolkit_error();
    init_concurrency();
    init_context3();
    __name(getDeployedStacksByNames, "getDeployedStacksByNames");
    __name(listStacks, "listStacks");
    __name(formatEnvironmentSectionHeader2, "formatEnvironmentSectionHeader");
    __name(formatTypedMappings2, "formatTypedMappings");
    __name(formatAmbiguousMappings2, "formatAmbiguousMappings");
    __name(formatToStream, "formatToStream");
    __name(groupStacks, "groupStacks");
  }
});

// ../@aws-cdk/toolkit-lib/lib/actions/refactor/private/mapping-helpers.ts
function parseMappingGroups(s) {
  const mappingGroups = doParse();
  for (let group7 of mappingGroups) {
    const destinations = /* @__PURE__ */ new Set();
    for (const destination of Object.values(group7.resources)) {
      if (destinations.has(destination)) {
        throw new ToolkitError(
          "DuplicateDestinationResource",
          `Duplicate destination resource '${destination}' in environment ${group7.account}/${group7.region}`
        );
      }
      destinations.add(destination);
    }
  }
  return mappingGroups;
  function doParse() {
    const content = JSON.parse(s);
    if (content.environments || !Array.isArray(content.environments)) {
      return content.environments;
    } else {
      throw new ToolkitError("MissingEnvironmentsArray", "Expected an 'environments' array");
    }
  }
  __name(doParse, "doParse");
}
async function mappingsByEnvironment(stackArtifacts, sdkProvider, ignoreModifications) {
  const groups = await groupStacks(sdkProvider, stackArtifacts, []);
  return groups.map((group7) => {
    const context = new RefactoringContext({
      ...group7,
      ignoreModifications
    });
    return {
      environment: context.environment,
      mappings: Object.fromEntries(
        context.mappings.map((m20) => [m20.source.toLocationString(), m20.destination.toLocationString()])
      )
    };
  });
}
var init_mapping_helpers = __esm({
  "../@aws-cdk/toolkit-lib/lib/actions/refactor/private/mapping-helpers.ts"() {
    "use strict";
    init_refactoring();
    init_toolkit_error();
    __name(parseMappingGroups, "parseMappingGroups");
    __name(mappingsByEnvironment, "mappingsByEnvironment");
  }
});

// ../@aws-cdk/toolkit-lib/lib/actions/diff/private/helpers.ts
function prepareDiff(ioHelper, stacks, deployments, sdkProvider, options) {
  switch (options.method?.method ?? DiffMethod.ChangeSet().method) {
    case "local-file":
      return localFileDiff(stacks, options);
    case "template-only":
      return cfnDiff2(ioHelper, stacks, deployments, options, sdkProvider, false);
    case "change-set":
      return cfnDiff2(ioHelper, stacks, deployments, options, sdkProvider, true);
    default:
      throw new ToolkitError("UnknownDiffMethod", formatErrorMessage(`Unknown diff method ${options.method}`));
  }
}
async function localFileDiff(stacks, options) {
  const methodOptions = options.method?.options ?? {};
  if (stacks.stackCount !== 1) {
    throw new ToolkitError(
      "SingleStackRequired",
      "Can only select one stack when comparing to fixed template. Use --exclusively to avoid selecting multiple stacks."
    );
  }
  if (!await fs33.pathExists(methodOptions.path)) {
    throw new ToolkitError("TemplateFileNotFound", `There is no file at ${methodOptions.path}`);
  }
  const file = fs33.readFileSync(methodOptions.path).toString();
  const template = deserializeStructure(file);
  return [{
    oldTemplate: template,
    newTemplate: stacks.firstStack
  }];
}
async function cfnDiff2(ioHelper, stacks, deployments, options, sdkProvider, includeChangeSet) {
  const templateInfos = [];
  const methodOptions = options.method?.options ?? {};
  const allMappings = options.includeMoves ? await mappingsByEnvironment(stacks.stackArtifacts, sdkProvider, true) : [];
  for (const stack of stacks.stackArtifacts) {
    const templateWithNestedStacks = await deployments.readCurrentTemplateWithNestedStacks(
      stack,
      methodOptions.compareAgainstProcessedTemplate
    );
    const currentTemplate = templateWithNestedStacks.deployedRootTemplate;
    const nestedStacks = templateWithNestedStacks.nestedStacks;
    const migrator = new ResourceMigrator({ deployments, ioHelper });
    const resourcesToImport = await migrator.tryGetResources(await deployments.resolveEnvironment(stack));
    if (resourcesToImport) {
      removeNonImportResources(stack);
    }
    const changeSet = includeChangeSet ? await createDiffChangeSet(ioHelper, {
      deployments,
      stack,
      sdkProvider,
      resourcesToImport,
      parameters: methodOptions.parameters ?? {},
      failOnError: !(methodOptions.fallbackToTemplate ?? true),
      importExistingResources: methodOptions.importExistingResources,
      uuid: (0, import_node_crypto17.randomUUID)(),
      willExecute: false
    }) : void 0;
    if (changeSet) {
      await attachNestedChangeSetData(deployments, stack, changeSet, nestedStacks);
    }
    const mappings = allMappings.find(
      (m20) => m20.environment.region === stack.environment.region && m20.environment.account === stack.environment.account
    )?.mappings ?? {};
    templateInfos.push({
      oldTemplate: currentTemplate,
      newTemplate: stack,
      isImport: !!resourcesToImport,
      nestedStacks,
      changeSet,
      mappings
    });
  }
  return templateInfos;
}
async function attachNestedChangeSetData(deployments, stack, rootChangeSet, nestedStacks) {
  const env3 = await deployments.envs.accessStackForReadOnlyStackOperations(stack);
  const cfn = env3.sdk.cloudFormation();
  for (const change of rootChangeSet.Changes ?? []) {
    const rc = change.ResourceChange;
    if (rc?.ResourceType !== "AWS::CloudFormation::Stack" || !rc.ChangeSetId || !rc.LogicalResourceId) {
      continue;
    }
    const nested = nestedStacks[rc.LogicalResourceId];
    if (!nested) {
      continue;
    }
    const nestedChangeSet = await cfn.describeChangeSet({
      ChangeSetName: rc.ChangeSetId,
      StackName: rc.PhysicalResourceId ?? rc.LogicalResourceId
    });
    nestedStacks[rc.LogicalResourceId] = {
      ...nested,
      changeSet: nestedChangeSet
    };
    if (nestedChangeSet && Object.keys(nested.nestedStackTemplates).length > 0) {
      await attachNestedChangeSetData(deployments, stack, nestedChangeSet, nested.nestedStackTemplates);
    }
  }
}
function appendObject(obj1, obj2) {
  for (const key in obj2) {
    obj1[key] = obj2[key];
  }
  return obj1;
}
var import_node_crypto17, fs33;
var init_helpers5 = __esm({
  "../@aws-cdk/toolkit-lib/lib/actions/diff/private/helpers.ts"() {
    "use strict";
    import_node_crypto17 = require("node:crypto");
    fs33 = __toESM(require_lib4());
    init_diff4();
    init_cfn_api();
    init_resource_import();
    init_toolkit_error();
    init_util3();
    init_mapping_helpers();
    __name(prepareDiff, "prepareDiff");
    __name(localFileDiff, "localFileDiff");
    __name(cfnDiff2, "cfnDiff");
    __name(attachNestedChangeSetData, "attachNestedChangeSetData");
    __name(appendObject, "appendObject");
  }
});

// ../@aws-cdk/toolkit-lib/lib/actions/diff/private/index.ts
var init_private8 = __esm({
  "../@aws-cdk/toolkit-lib/lib/actions/diff/private/index.ts"() {
    "use strict";
    init_helpers5();
  }
});

// ../@aws-cdk/toolkit-lib/lib/toolkit/private/count-assembly-results.ts
function countAssemblyResults(span, assembly) {
  const stacksRecursively = assembly.stacksRecursively;
  span.incCounter("stacks", stacksRecursively.length);
  span.incCounter("assemblies", asmCount(assembly));
  span.incCounter("errorAnns", sum3(stacksRecursively.map((s) => s.messages.filter((m20) => m20.level === import_cloud_assembly_api15.SynthesisMessageLevel.ERROR).length)));
  span.incCounter("warnings", sum3(stacksRecursively.map((s) => s.messages.filter((m20) => m20.level === import_cloud_assembly_api15.SynthesisMessageLevel.WARNING).length)));
  const annotationErrorCodes = stacksRecursively.flatMap((s) => Object.values(s.metadata).flatMap((ms) => ms.filter((m20) => m20.type === ANNOTATION_ERROR_CODE_TYPE)));
  for (const annotationErrorCode of annotationErrorCodes) {
    span.incCounter(`errorAnn:${annotationErrorCode.data}`);
  }
  function asmCount(x) {
    return 1 + x.nestedAssemblies.reduce((acc, asm) => acc + asmCount(asm.nestedAssembly), 0);
  }
  __name(asmCount, "asmCount");
}
function sum3(xs) {
  return xs.reduce((a32, b32) => a32 + b32, 0);
}
var import_cloud_assembly_api15, ANNOTATION_ERROR_CODE_TYPE;
var init_count_assembly_results = __esm({
  "../@aws-cdk/toolkit-lib/lib/toolkit/private/count-assembly-results.ts"() {
    "use strict";
    import_cloud_assembly_api15 = __toESM(require_lib3());
    __name(countAssemblyResults, "countAssemblyResults");
    __name(sum3, "sum");
    ANNOTATION_ERROR_CODE_TYPE = "aws:cdk:error-code";
  }
});

// ../@aws-cdk/toolkit-lib/lib/actions/watch/private/helpers.ts
var WATCH_EXCLUDE_DEFAULTS;
var init_helpers6 = __esm({
  "../@aws-cdk/toolkit-lib/lib/actions/watch/private/helpers.ts"() {
    "use strict";
    WATCH_EXCLUDE_DEFAULTS = [
      // CDK
      "README.md",
      "cdk*.json",
      // JS
      "package*.json",
      "yarn.lock",
      "pnpm-lock.yaml",
      "bun.lockb",
      "bun.lock",
      "deno.lock",
      // TS
      "tsconfig*.json",
      "**/*.d.ts",
      "test",
      // Python
      "requirements*.txt",
      "source.bat",
      "**/__init__.py",
      "**/__pycache__",
      "tests",
      // C# & F#
      "**/*.sln",
      "**/*.csproj",
      "**/*.fsproj",
      // Go
      "go.mod",
      "go.sum",
      "**/*test.go"
    ];
  }
});

// ../@aws-cdk/toolkit-lib/lib/actions/watch/private/index.ts
var init_private9 = __esm({
  "../@aws-cdk/toolkit-lib/lib/actions/watch/private/index.ts"() {
    "use strict";
    init_helpers6();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/hotswap/index.ts
var init_hotswap2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/hotswap/index.ts"() {
    "use strict";
    init_common9();
    init_hotswap_deployments();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/network-detector/index.ts
var init_network_detector2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/network-detector/index.ts"() {
    "use strict";
    init_network_detector();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/tags/tags.ts
var init_tags = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/tags/tags.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/tags/index.ts
var tags_exports = {};
var init_tags2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/tags/index.ts"() {
    "use strict";
    init_tags();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/drift/drift-formatter.ts
var import_node_util6, import_cloudformation_diff3, import_client_cloudformation6, chalk23, DriftFormatter, ADDITION3, CONTEXT2, UPDATE3, REMOVAL3;
var init_drift_formatter = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/drift/drift-formatter.ts"() {
    "use strict";
    import_node_util6 = require("node:util");
    import_cloudformation_diff3 = __toESM(require_lib9());
    import_client_cloudformation6 = __toESM(require_dist_cjs140());
    chalk23 = __toESM(require_source());
    init_logical_id_map();
    DriftFormatter = class {
      static {
        __name(this, "DriftFormatter");
      }
      stackName;
      stack;
      resourceDriftResults;
      allStackResources;
      constructor(props) {
        this.stack = props.stack;
        this.stackName = props.stack.displayName ?? props.stack.stackName;
        this.resourceDriftResults = props.resourceDrifts;
        this.allStackResources = /* @__PURE__ */ new Map();
        Object.keys(this.stack.template.Resources || {}).forEach((id) => {
          const resource = this.stack.template.Resources[id];
          if (resource.Type === "AWS::CDK::Metadata") {
            return;
          }
          this.allStackResources.set(id, resource.Type);
        });
      }
      /**
       * Format the stack drift detection results
       */
      formatStackDrift() {
        const formatterOutput = this.formatStackDriftChanges(buildLogicalToPathMap(this.stack).toPath);
        const actualDrifts = this.resourceDriftResults.filter((d32) => (d32.StackResourceDriftStatus === "MODIFIED" || d32.StackResourceDriftStatus === "DELETED") && d32.ResourceType !== "AWS::CDK::Metadata");
        const stackHeader = (0, import_node_util6.format)(`Stack ${chalk23.bold(this.stackName)}
`);
        if (actualDrifts.length === 0) {
          const finalResult2 = chalk23.green("No drift detected\n");
          return {
            numResourcesWithDrift: 0,
            numResourcesUnchecked: this.allStackResources.size - this.resourceDriftResults.length,
            stackHeader,
            unchecked: formatterOutput.unchecked,
            summary: finalResult2
          };
        }
        const finalResult = chalk23.yellow(`
${actualDrifts.length} resource${actualDrifts.length === 1 ? "" : "s"} ${actualDrifts.length === 1 ? "has" : "have"} drifted from their expected configuration
`);
        return {
          numResourcesWithDrift: actualDrifts.length,
          numResourcesUnchecked: this.allStackResources.size - this.resourceDriftResults.length,
          stackHeader,
          unchanged: formatterOutput.unchanged,
          unchecked: formatterOutput.unchecked,
          modified: formatterOutput.modified,
          deleted: formatterOutput.deleted,
          summary: finalResult
        };
      }
      /**
       * Renders stack drift information
       *
       * @param logicalToPathMap - A map from logical ID to construct path
       */
      formatStackDriftChanges(logicalToPathMap = {}) {
        if (this.resourceDriftResults.length === 0) {
          return {};
        }
        let unchanged;
        let unchecked;
        let modified;
        let deleted;
        const drifts = this.resourceDriftResults;
        const unchangedResources = drifts.filter((d32) => d32.StackResourceDriftStatus === import_client_cloudformation6.StackResourceDriftStatus.IN_SYNC);
        if (unchangedResources.length > 0) {
          unchanged = this.printSectionHeader("Resources In Sync");
          for (const drift of unchangedResources) {
            if (!drift.LogicalResourceId || !drift.ResourceType) continue;
            unchanged += `${CONTEXT2} ${chalk23.cyan(drift.ResourceType)} ${this.formatLogicalId(logicalToPathMap, drift.LogicalResourceId)}
`;
          }
          unchanged += this.printSectionFooter();
        }
        const uncheckedResources = Array.from(this.allStackResources.keys()).filter((logicalId) => {
          const drift = drifts.find((d32) => d32.LogicalResourceId === logicalId);
          return !drift || drift.StackResourceDriftStatus === import_client_cloudformation6.StackResourceDriftStatus.UNKNOWN;
        });
        if (uncheckedResources.length > 0) {
          unchecked = this.printSectionHeader("Unchecked Resources");
          for (const logicalId of uncheckedResources) {
            const resourceType = this.allStackResources.get(logicalId);
            unchecked += `${CONTEXT2} ${chalk23.cyan(resourceType)} ${this.formatLogicalId(logicalToPathMap, logicalId)}
`;
          }
          unchecked += this.printSectionFooter();
        }
        const modifiedResources = drifts.filter((d32) => d32.StackResourceDriftStatus === import_client_cloudformation6.StackResourceDriftStatus.MODIFIED && d32.ResourceType !== "AWS::CDK::Metadata");
        if (modifiedResources.length > 0) {
          modified = this.printSectionHeader("Modified Resources");
          for (const drift of modifiedResources) {
            if (!drift.LogicalResourceId || !drift.ResourceType) continue;
            modified += `${UPDATE3} ${chalk23.cyan(drift.ResourceType)} ${this.formatLogicalId(logicalToPathMap, drift.LogicalResourceId)}
`;
            if (drift.PropertyDifferences) {
              const propDiffs = drift.PropertyDifferences;
              for (let i32 = 0; i32 < propDiffs.length; i32++) {
                const diff = propDiffs[i32];
                if (!diff.PropertyPath) continue;
                const difference2 = new import_cloudformation_diff3.Difference(diff.ExpectedValue, diff.ActualValue);
                modified += this.formatTreeDiff(diff.PropertyPath, difference2, i32 === propDiffs.length - 1);
              }
            }
          }
          modified += this.printSectionFooter();
        }
        const deletedResources = drifts.filter((d32) => d32.StackResourceDriftStatus === import_client_cloudformation6.StackResourceDriftStatus.DELETED && d32.ResourceType !== "AWS::CDK::Metadata");
        if (deletedResources.length > 0) {
          deleted = this.printSectionHeader("Deleted Resources");
          for (const drift of deletedResources) {
            if (!drift.LogicalResourceId || !drift.ResourceType) continue;
            deleted += `${REMOVAL3} ${chalk23.cyan(drift.ResourceType)} ${this.formatLogicalId(logicalToPathMap, drift.LogicalResourceId)}
`;
          }
          deleted += this.printSectionFooter();
        }
        return { unchanged, unchecked, modified, deleted };
      }
      formatLogicalId(logicalToPathMap, logicalId) {
        const path47 = logicalToPathMap[logicalId];
        if (!path47) return logicalId;
        let normalizedPath = path47;
        if (normalizedPath.startsWith("/")) {
          normalizedPath = normalizedPath.slice(1);
        }
        let parts = normalizedPath.split("/");
        if (parts.length > 1) {
          parts = parts.slice(1);
          if (parts.length > 1) {
            const last = parts[parts.length - 1];
            if (last === "Resource" || last === "Default") {
              parts = parts.slice(0, parts.length - 1);
            }
          }
          normalizedPath = parts.join("/");
        }
        return `${normalizedPath} ${chalk23.gray(logicalId)}`;
      }
      printSectionHeader(title) {
        return `${chalk23.underline(chalk23.bold(title))}
`;
      }
      printSectionFooter() {
        return "\n";
      }
      formatTreeDiff(propertyPath, difference2, isLast) {
        let result2 = (0, import_node_util6.format)(
          " %s\u2500 %s %s\n",
          isLast ? "\u2514" : "\u251C",
          difference2.isAddition ? ADDITION3 : difference2.isRemoval ? REMOVAL3 : UPDATE3,
          propertyPath
        );
        if (difference2.isUpdate) {
          result2 += (0, import_node_util6.format)("     \u251C\u2500 %s %s\n", REMOVAL3, chalk23.red(difference2.oldValue));
          result2 += (0, import_node_util6.format)("     \u2514\u2500 %s %s\n", ADDITION3, chalk23.green(difference2.newValue));
        }
        return result2;
      }
    };
    ADDITION3 = chalk23.green("[+]");
    CONTEXT2 = chalk23.grey("[ ]");
    UPDATE3 = chalk23.yellow("[~]");
    REMOVAL3 = chalk23.red("[-]");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/drift/drift.ts
async function detectStackDrift(cfn, ioHelper, stackName) {
  const driftDetection = await cfn.detectStackDrift({
    StackName: stackName
  });
  await ioHelper.defaults.trace(
    (0, import_node_util7.format)("Detecting drift with ID %s for stack %s...", driftDetection.StackDriftDetectionId, stackName)
  );
  const driftStatus = await waitForDriftDetection(cfn, ioHelper, driftDetection.StackDriftDetectionId);
  if (driftStatus?.StackDriftStatus === "UNKNOWN") {
    await ioHelper.defaults.trace(
      `Stack drift status is UNKNOWN. This may occur when CloudFormation is unable to detect drift for at least one resource and all other resources are IN_SYNC.
Reason: ${formatReason(driftStatus.DetectionStatusReason)}`
    );
  }
  const driftResults = await cfn.describeStackResourceDrifts({
    StackName: stackName
  });
  const unknownResources = driftResults.StackResourceDrifts?.filter(
    (drift) => drift.StackResourceDriftStatus === "UNKNOWN"
  );
  if (unknownResources && unknownResources.length > 0) {
    await ioHelper.defaults.trace(
      "Some resources have UNKNOWN drift status. This may be due to insufficient permissions or throttling:\n" + unknownResources.map(
        (r32) => `  - ${r32.LogicalResourceId}: ${formatReason(r32.DriftStatusReason)}`
      ).join("\n")
    );
  }
  return driftResults;
}
async function waitForDriftDetection(cfn, ioHelper, driftDetectionId) {
  const maxWaitForDrift = 3e5;
  const timeBetweenOutputs = 1e4;
  const timeBetweenApiCalls = 2e3;
  const deadline = Date.now() + maxWaitForDrift;
  let checkIn = Date.now() + timeBetweenOutputs;
  while (true) {
    const response = await cfn.describeStackDriftDetectionStatus({
      StackDriftDetectionId: driftDetectionId
    });
    if (response.DetectionStatus === "DETECTION_COMPLETE") {
      return response;
    }
    if (response.DetectionStatus === "DETECTION_FAILED") {
      throw new ToolkitError("DriftDetectionFailed", `Drift detection failed: ${formatReason(response.DetectionStatusReason)}`);
    }
    if (Date.now() > deadline) {
      throw new ToolkitError("DriftDetectionTimeout", `Drift detection failed: Timed out after ${maxWaitForDrift / 1e3} seconds.`);
    }
    if (Date.now() > checkIn) {
      await ioHelper.defaults.trace("Waiting for drift detection to complete...");
      checkIn = Date.now() + timeBetweenOutputs;
    }
    await new Promise((resolve13) => setTimeout(resolve13, timeBetweenApiCalls));
  }
}
var import_node_util7;
var init_drift2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/drift/drift.ts"() {
    "use strict";
    import_node_util7 = require("node:util");
    init_toolkit_error();
    init_string_manipulation();
    __name(detectStackDrift, "detectStackDrift");
    __name(waitForDriftDetection, "waitForDriftDetection");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/drift/index.ts
var init_drift3 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/drift/index.ts"() {
    "use strict";
    init_drift_formatter();
    init_drift2();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/source-tracing/types.ts
var init_types14 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/source-tracing/types.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/source-tracing/index.ts
var source_tracing_exports = {};
var init_source_tracing2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/source-tracing/index.ts"() {
    "use strict";
    init_types14();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/index.ts
var init_api2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/index.ts"() {
    "use strict";
    init_aws_auth();
    init_bootstrap2();
    init_cloud_assembly3();
    init_cloudformation2();
    init_context2();
    init_deployments2();
    init_diff3();
    init_environment2();
    init_garbage_collection();
    init_hotswap2();
    init_io();
    init_logs_monitor3();
    init_network_detector2();
    init_notices2();
    init_plugin2();
    init_refactoring();
    init_resource_import();
    init_rwlock();
    init_settings();
    init_stack_events();
    init_toolkit_info();
    init_work_graph2();
    init_tree();
    init_tags2();
    init_drift3();
    init_source_tracing2();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/refactoring/stack-definitions.ts
async function generateStackDefinitions(mappings, deployedStacks, localStacks, environment, sdkProvider, ioHelper) {
  const deployedStackMap = new Map(deployedStacks.map((s) => [s.stackName, s]));
  for (const localStack of localStacks) {
    const deployedStack = deployedStackMap.get(localStack.stackName);
    const localTemplate = localStack.template;
    const deployedTemplate = deployedStack?.template;
    if (deployedTemplate?.Resources?.CDKMetadata != null) {
      localTemplate.Resources = localTemplate.Resources ?? {};
      localTemplate.Resources.CDKMetadata = deployedTemplate.Resources.CDKMetadata;
    } else {
      delete localTemplate.Resources?.CDKMetadata;
    }
  }
  const stacksToProcess = localStacks.filter((localStack) => {
    const deployedStack = deployedStackMap.get(localStack.stackName);
    return !deployedStack || !deepEqual4(localStack.template, deployedStack.template);
  });
  for (let mapping of mappings) {
    const stackName = mapping.source.stackName;
    if (!localStacks.some((s) => s.stackName === stackName)) {
      const deployedStack = deployedStackMap.get(stackName);
      delete deployedStack?.template.Resources?.[mapping.source.logicalResourceId];
      delete deployedStack?.template.Outputs;
      if (deployedStack && !stacksToProcess.some((s) => s.stackName === stackName)) {
        stacksToProcess.push(deployedStack);
      }
    }
  }
  for (const stack of stacksToProcess) {
    if (!deployedStacks.some((deployed) => deployed.stackName === stack.stackName)) {
      if ("Rules" in stack.template) {
        delete stack.template.Rules;
      }
      if ("Parameters" in stack.template) {
        delete stack.template.Parameters;
      }
    }
  }
  const hasLargeTemplates = stacksToProcess.some(
    (stack) => JSON.stringify(stack.template).length > LARGE_TEMPLATE_SIZE_BYTES
  );
  if (!hasLargeTemplates) {
    return stacksToProcess.map((stack) => ({
      StackName: stack.stackName,
      TemplateBody: JSON.stringify(stack.template)
    }));
  }
  const sdk = (await sdkProvider.forEnvironment(environment, 1 /* ForWriting */)).sdk;
  const environmentResourcesRegistry = new EnvironmentResourcesRegistry();
  const envResources = environmentResourcesRegistry.for(environment, sdk, ioHelper);
  const toolkitInfo = await envResources.lookupToolkit();
  if (!toolkitInfo.found) {
    const largeStack = stacksToProcess.find(
      (stack) => JSON.stringify(stack.template).length > LARGE_TEMPLATE_SIZE_BYTES
    );
    const templateSize = Math.round(JSON.stringify(largeStack.template).length / 1024);
    await ioHelper.defaults.error(
      util9.format(
        `The template for stack "${largeStack.stackName}" is ${templateSize}KiB. Templates larger than ${LARGE_TEMPLATE_SIZE_KB2}KiB must be uploaded to S3.
Run the following command in order to setup an S3 bucket in this environment, and then re-refactor:

`,
        chalk24.blue(`	$ cdk bootstrap ${environment.name}
`)
      )
    );
    throw new ToolkitError("TemplateTooLargeToRefactor", 'Template too large to refactor ("cdk bootstrap" is required)');
  }
  const stackDefinitions = [];
  for (const stack of stacksToProcess) {
    const templateJson = JSON.stringify(stack.template);
    if (templateJson.length <= LARGE_TEMPLATE_SIZE_BYTES) {
      stackDefinitions.push({
        StackName: stack.stackName,
        TemplateBody: templateJson
      });
      continue;
    }
    const templateHash = contentHash(templateJson);
    const key = `cdk-refactor/${stack.stackName}/${templateHash}.json`;
    const s3 = sdk.s3();
    await s3.upload({
      Bucket: toolkitInfo.bucketName,
      Key: key,
      Body: templateJson,
      ContentType: "application/json"
    });
    const templateURL = `${toolkitInfo.bucketUrl}/${key}`;
    await ioHelper.defaults.debug(`Storing template for stack ${stack.stackName} in S3 at: ${templateURL}`);
    stackDefinitions.push({
      StackName: stack.stackName,
      TemplateURL: templateURL
    });
  }
  return stackDefinitions;
}
var util9, chalk24, deepEqual4, LARGE_TEMPLATE_SIZE_KB2, LARGE_TEMPLATE_SIZE_BYTES;
var init_stack_definitions = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/refactoring/stack-definitions.ts"() {
    "use strict";
    util9 = __toESM(require("node:util"));
    chalk24 = __toESM(require_source());
    init_toolkit_error();
    init_util3();
    init_environment2();
    init_plugin2();
    deepEqual4 = require_fast_deep_equal();
    LARGE_TEMPLATE_SIZE_KB2 = 50;
    LARGE_TEMPLATE_SIZE_BYTES = LARGE_TEMPLATE_SIZE_KB2 * 1024;
    __name(generateStackDefinitions, "generateStackDefinitions");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/tags/private/util.ts
function tagsForStack(stack) {
  return Object.entries(stack.tags).map(([Key, Value]) => ({ Key, Value }));
}
var init_util8 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/tags/private/util.ts"() {
    "use strict";
    __name(tagsForStack, "tagsForStack");
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/tags/private/index.ts
var init_private10 = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/tags/private/index.ts"() {
    "use strict";
    init_util8();
  }
});

// ../@aws-cdk/toolkit-lib/lib/api/validate/validate-formatting.ts
function hostMessageFromValidation(fileRoot, result2) {
  return IO.CDK_TOOLKIT_E9600.msg(formatValidateResult(fileRoot, result2), result2);
}
function formatValidateResult(fileRoot, result2) {
  return formatValidationReports(fileRoot, result2.pluginReports).join("\n\n");
}
function formatValidationReports(fileRoot, reports) {
  const successfullyExecutedPlugins = reports.filter((r32) => isPluginFailure(r32) === void 0);
  const pluginFailures = reports.map(isPluginFailure).filter((e32) => e32 !== void 0);
  const violations = flattenViolations(successfullyExecutedPlugins);
  violations.sort((a32, b32) => {
    const aOrder = SEVERITY_ORDER[a32.severity.toLowerCase()] ?? 4;
    const bOrder = SEVERITY_ORDER[b32.severity.toLowerCase()] ?? 4;
    return aOrder - bOrder;
  });
  return [
    ...pluginFailures.map(formatPluginFailure),
    ...violations.map((v) => formatViolationBlock(fileRoot, v))
  ];
}
function flattenViolations(reports) {
  return reports.flatMap((report) => {
    const pluginName = report.pluginName;
    return report.violations.flatMap((violation) => {
      return violation.violatingConstructs.map((construct) => ({
        severity: normalizeSeverity(violation.severity),
        description: violation.description,
        ruleName: violation.ruleName,
        pluginName,
        construct,
        suggestedFix: violation.suggestedFix,
        ruleMetadata: violation.ruleMetadata
      }));
    });
  });
}
function normalizeSeverity(severity, customSeverity) {
  switch (severity) {
    case "fatal":
    case "error":
    case "warning":
    case "info":
      return severity.toUpperCase();
    case "custom":
      return customSeverity ?? "INFO";
  }
}
function formatViolationBlock(fileRoot, v) {
  const lines = [];
  const location = sourceLocation(fileRoot, v.construct.stackTraces);
  if (location) {
    lines.push(chalk25.underline(sanitize(location)));
  }
  lines.push([
    chalk25.bold(getSeverityColor(v.severity)(sanitize(v.severity))),
    chalk25.bold(stripAckTag(sanitize(v.description))),
    chalk25.grey(`(${sanitize(v.pluginName)})`)
  ].join(" "));
  const constructInfo = formatConstructInfo(fileRoot, v.construct);
  lines.push(`   ${constructInfo}`);
  if (v.suggestedFix) {
    lines.push(`   Suggested fix: ${sanitize(v.suggestedFix).replace(/\n/g, "\n   ")}`);
  }
  if (isSuppressibleViolation(v)) {
    const ackId = `${sanitize(v.pluginName)}::${sanitize(v.ruleName)}`.replace(/ /g, "-");
    lines.push(`   ${chalk25.grey(`Acknowledge with '${ackId}'`)}`);
  } else {
    lines.push(`   ${chalk25.grey(`Rule ${sanitize(v.ruleName)}`)}`);
  }
  return lines.join("\n");
}
function getSeverityColor(severity) {
  switch (severity.toLowerCase()) {
    case "fatal":
      return chalk25.red;
    case "error":
      return chalk25.ansi256(208);
    case "warning":
      return chalk25.yellow;
    default:
      return chalk25.blue;
  }
}
function formatPluginFailure(f32) {
  return `${chalk25.ansi256(208)("ERROR")} ${sanitize(f32.error)}`;
}
function formatConstructInfo(fileRoot, construct) {
  const parts = [];
  const logicalId = sanitize(construct.cloudFormationResource?.logicalId);
  if (construct.constructPath) {
    const cPath = sanitize(construct.constructPath);
    parts.push(logicalId ? `${chalk25.bold(cPath)} (${logicalId})` : chalk25.bold(cPath));
  } else {
    if (construct.cloudFormationResource?.templatePath) {
      parts.push(humanFriendlyFilename(fileRoot, sanitize(construct.cloudFormationResource.templatePath)));
    }
    if (logicalId) {
      parts.push(chalk25.bold(logicalId));
    }
  }
  if (construct.constructFqn) {
    parts.push(chalk25.grey(sanitize(construct.constructFqn)));
  }
  return parts.join(" ");
}
function stripAckTag(description) {
  return description.replace(/\s*\[ack:\s*[^\]]+\]\s*/g, "").trim();
}
function sourceLocation(fileRoot, stackTraces) {
  for (const trace2 of stackTraces ?? []) {
    const frame = getLeafLocation(trace2);
    if (frame && frame.fileName) {
      return `${humanFriendlyFilename(fileRoot, frame.fileName)}:${frame.sourceLocation}`;
    }
  }
  return void 0;
}
function getLeafLocation(stackTrace) {
  const frames = stackTrace.split("\n");
  if (frames.length === 0) return void 0;
  const userFrame = frames.find((f32) => !f32.includes("node_modules") && !f32.includes("aws-cdk-lib"));
  const frame = (userFrame ?? frames[0]).trim();
  const match = frame.match(/\((.+)\)$/) || frame.match(/at\s+(.+)$/);
  const location = match ? match[1] : frame;
  return { fileName: location.split(":")[0], sourceLocation: location.split(":").slice(1).join(":") };
}
function sanitize(s) {
  return (s ?? "").replace(CONTROL_CHARS, "\uFFFD");
}
function humanFriendlyFilename(root32, filename) {
  const absPath = filename;
  const relPath = path32.relative(root32, filename);
  return relPath.length < absPath.length ? relPath : absPath;
}
function isPluginFailure(r32) {
  if (r32.conclusion === "success" || r32.violations.length > 0 || !r32.metadata?.error) {
    return void 0;
  }
  return { error: r32.metadata.error };
}
function isSuppressibleViolation(violation) {
  const isFatal = violation.severity?.toLowerCase() === "fatal";
  const isErrorAnnotation = violation.ruleMetadata?.["cdk:annotation"] && violation.severity?.toLowerCase() === "error";
  return !isFatal && !isErrorAnnotation;
}
var path32, chalk25, CONTROL_CHARS, SEVERITY_ORDER;
var init_validate_formatting = __esm({
  "../@aws-cdk/toolkit-lib/lib/api/validate/validate-formatting.ts"() {
    "use strict";
    path32 = __toESM(require("node:path"));
    chalk25 = __toESM(require_source());
    init_private();
    __name(hostMessageFromValidation, "hostMessageFromValidation");
    __name(formatValidateResult, "formatValidateResult");
    __name(formatValidationReports, "formatValidationReports");
    __name(flattenViolations, "flattenViolations");
    __name(normalizeSeverity, "normalizeSeverity");
    __name(formatViolationBlock, "formatViolationBlock");
    __name(getSeverityColor, "getSeverityColor");
    __name(formatPluginFailure, "formatPluginFailure");
    __name(formatConstructInfo, "formatConstructInfo");
    __name(stripAckTag, "stripAckTag");
    __name(sourceLocation, "sourceLocation");
    __name(getLeafLocation, "getLeafLocation");
    CONTROL_CHARS = /[\x00-\x08\x0B-\x1F\x7F\x9B]/g;
    __name(sanitize, "sanitize");
    SEVERITY_ORDER = {
      fatal: 0,
      error: 1,
      warning: 2,
      info: 3
    };
    __name(humanFriendlyFilename, "humanFriendlyFilename");
    __name(isPluginFailure, "isPluginFailure");
    __name(isSuppressibleViolation, "isSuppressibleViolation");
  }
});

// ../@aws-cdk/toolkit-lib/lib/util/promises.ts
function promiseWithResolvers() {
  let resolve13, reject;
  const promise = new Promise((res, rej) => {
    resolve13 = res;
    reject = rej;
  });
  return { promise, resolve: resolve13, reject };
}
var init_promises = __esm({
  "../@aws-cdk/toolkit-lib/lib/util/promises.ts"() {
    "use strict";
    __name(promiseWithResolvers, "promiseWithResolvers");
  }
});

// ../@aws-cdk/toolkit-lib/lib/toolkit/private/collect-annotation-report.ts
function collectAnnotationReport(stacks) {
  const ruleMap = /* @__PURE__ */ new Map();
  for (const stack of stacks.stackArtifacts) {
    for (const entry of stack.messages) {
      let severity;
      switch (entry.level) {
        case cxapi9.SynthesisMessageLevel.WARNING:
          severity = "warning";
          break;
        case cxapi9.SynthesisMessageLevel.ERROR:
          severity = "error";
          break;
        case cxapi9.SynthesisMessageLevel.INFO:
          severity = "info";
          break;
      }
      const { message: message2, ruleName } = splitDescriptionAndId(String(entry.entry.data));
      const ruleKey = `${ruleName}|${severity}|${message2}`;
      let violation = ruleMap.get(ruleKey);
      if (!violation) {
        violation = {
          ruleName: ruleName ?? `${severity}-annotation`,
          description: message2,
          severity,
          violatingConstructs: [],
          ruleMetadata: {
            "cdk:annotation": "true"
          }
        };
        ruleMap.set(ruleKey, violation);
      }
      violation.violatingConstructs.push({
        constructPath: entry.id.replace(/^\//, "")
        // remove leading slash
        // TODO: see if this information can be obtained from tree.json
        // cloudFormationResource
        // constructFqn:
        // libraryVersion
        // TODO: see if we can get this from metadata stack traces. We may need to re-enable them for
        // annotations in the core library. Otherwise we should probably get a stack trace to the resource itself.
        // stackTraces
      });
    }
  }
  const violations = Array.from(ruleMap.values());
  const hasErrors = violations.some((v) => v.severity === "error");
  return {
    pluginName: ANNOTATION_PLUGIN_NAME,
    conclusion: hasErrors ? "failure" : "success",
    violations
  };
}
function splitDescriptionAndId(message2) {
  const ackMatch = message2.match(/\[ack: ([^\]]+)\]/);
  if (ackMatch) {
    return { message: message2.replace(ackMatch[0], "").trim(), ruleName: ackMatch[1] };
  }
  const idMatch = message2.match(/\(([^()]+::[^()]+)\)$/);
  if (idMatch) {
    return { message: message2.replace(idMatch[0], "").trim(), ruleName: idMatch[1] };
  }
  return { message: message2 };
}
var cxapi9, ANNOTATION_PLUGIN_NAME;
var init_collect_annotation_report = __esm({
  "../@aws-cdk/toolkit-lib/lib/toolkit/private/collect-annotation-report.ts"() {
    "use strict";
    cxapi9 = __toESM(require_lib3());
    ANNOTATION_PLUGIN_NAME = "Construct Annotations";
    __name(collectAnnotationReport, "collectAnnotationReport");
    __name(splitDescriptionAndId, "splitDescriptionAndId");
  }
});

// ../@aws-cdk/toolkit-lib/lib/toolkit/private/validation-report.ts
async function obtainUnifiedValidationReport(assembly, stacks) {
  const ret = [];
  const reportPath = path33.join(assembly.directory, VALIDATION_REPORT_FILE);
  if (await fs34.pathExists(reportPath)) {
    const selectedStackIds = new Set(stacks.hierarchicalIds);
    const report = import_cloud_assembly_schema5.Manifest.loadValidationReport(reportPath);
    const filteredReports = filterReportsByStacks(report.pluginReports, selectedStackIds);
    ret.push(...filteredReports);
  }
  const alreadyHasAnnotations = ret.some((r32) => r32.pluginName === CONSTRUCT_ANNOTATIONS_PLUGINNAME);
  if (!alreadyHasAnnotations) {
    const annotationReport = collectAnnotationReport(stacks);
    if (annotationReport.violations.length > 0 || annotationReport.conclusion === "failure") {
      ret.push(annotationReport);
    }
  }
  return ret;
}
function combineConclusions(reports) {
  const reportHasFailures = reports.some((r32) => r32.conclusion === "failure");
  return reportHasFailures ? "failure" : "success";
}
async function throwIfValidationFailures(assembly, stacks, failAt, ioHelper) {
  const pluginReports = await obtainUnifiedValidationReport(assembly, stacks);
  if (pluginReports.length === 0) {
    return;
  }
  const conclusion = combineConclusions(pluginReports);
  const result2 = { conclusion, pluginReports };
  await ioHelper.notify(hostMessageFromValidation(process.cwd(), result2));
  switch (failAt) {
    case "error":
      if (conclusion === "failure") {
        const error4 = AssemblyError.withStacks("Synthesis finished with errors", stacks.stackArtifacts);
        error4.attachSynthesisErrorCode("AnnotationErrors");
        throw error4;
      }
      break;
    case "warn":
      if (conclusion === "failure" || hasWarnings(pluginReports)) {
        const error4 = AssemblyError.withStacks("Synthesis finished with warnings (--strict mode)", stacks.stackArtifacts);
        error4.attachSynthesisErrorCode("StrictAnnotationWarnings");
        throw error4;
      }
      break;
    case "none":
      break;
  }
}
function hasWarnings(reports) {
  return reports.some((r32) => r32.violations.some((v) => v.severity === "warning"));
}
function filterReportsByStacks(reports, selectedStackIds) {
  return reports.map((report) => {
    const filteredViolations = report.violations.filter((violation) => {
      if (violation.violatingConstructs.length === 0) return true;
      return violation.violatingConstructs.some(
        (c32) => selectedStackIds.has(c32.constructPath?.split("/")[0] ?? "")
      );
    }).map((violation) => {
      if (violation.violatingConstructs.length === 0) return violation;
      return {
        ...violation,
        violatingConstructs: violation.violatingConstructs.filter(
          (c32) => selectedStackIds.has(c32.constructPath?.split("/")[0] ?? "")
        )
      };
    });
    return {
      ...report,
      violations: filteredViolations,
      conclusion: filteredViolations.length > 0 ? report.conclusion : "success"
    };
  });
}
var path33, import_cloud_assembly_schema5, fs34, VALIDATION_REPORT_FILE, CONSTRUCT_ANNOTATIONS_PLUGINNAME;
var init_validation_report = __esm({
  "../@aws-cdk/toolkit-lib/lib/toolkit/private/validation-report.ts"() {
    "use strict";
    path33 = __toESM(require("path"));
    import_cloud_assembly_schema5 = __toESM(require_lib2());
    fs34 = __toESM(require_lib4());
    init_collect_annotation_report();
    init_validate_formatting();
    init_toolkit_error();
    VALIDATION_REPORT_FILE = "validation-report.json";
    CONSTRUCT_ANNOTATIONS_PLUGINNAME = "Construct Annotations";
    __name(obtainUnifiedValidationReport, "obtainUnifiedValidationReport");
    __name(combineConclusions, "combineConclusions");
    __name(throwIfValidationFailures, "throwIfValidationFailures");
    __name(hasWarnings, "hasWarnings");
    __name(filterReportsByStacks, "filterReportsByStacks");
  }
});

// ../@aws-cdk/toolkit-lib/lib/toolkit/toolkit.ts
function isFileEvent(event) {
  return FILE_EVENTS.includes(event);
}
function stacksOpt(o10) {
  return o10.stacks ?? ALL_STACKS;
}
async function synthAndMeasure(ioHelper, cx, selectStacks) {
  const synthSpan = await ioHelper.span(SPAN.SYNTH_ASSEMBLY).begin({ stacks: selectStacks });
  try {
    const ret = await assemblyFromSource(synthSpan.asHelper, cx);
    countAssemblyResults(synthSpan, ret.assembly);
    const synthDuration = await synthSpan.end({});
    return Object.assign(ret, { synthDuration });
  } catch (error4) {
    await synthSpan.end({ error: error4 });
    throw error4;
  }
}
function zeroTime() {
  return { asMs: 0, asSec: 0 };
}
var import_dispose_polyfill7, import_node_crypto18, path34, cxapi10, import_cloud_assembly_schema6, chalk26, fs35, FILE_EVENTS, Toolkit;
var init_toolkit = __esm({
  "../@aws-cdk/toolkit-lib/lib/toolkit/toolkit.ts"() {
    "use strict";
    import_dispose_polyfill7 = __toESM(require_dispose_polyfill());
    import_node_crypto18 = require("node:crypto");
    path34 = __toESM(require("node:path"));
    cxapi10 = __toESM(require_lib3());
    import_cloud_assembly_schema6 = __toESM(require_lib2());
    chalk26 = __toESM(require_source());
    init_esm2();
    init_handler();
    fs35 = __toESM(require_lib4());
    init_non_interactive_io_host();
    init_private5();
    init_toolkit_error();
    init_bootstrap4();
    init_deploy3();
    init_private7();
    init_private8();
    init_count_assembly_results();
    init_private9();
    init_api2();
    init_aws_auth();
    init_awscli_compatible();
    init_private2();
    init_bootstrap2();
    init_cloud_assembly3();
    init_private3();
    init_disposable_box();
    init_source_builder();
    init_deployments2();
    init_cfn_api();
    init_diagnosis_formatting();
    init_stack_diagnoser();
    init_diff3();
    init_drift3();
    init_drift_formatter();
    init_private();
    init_logs_monitor3();
    init_orphaner();
    init_helpers2();
    init_plugin2();
    init_refactoring();
    init_cloudformation4();
    init_context3();
    init_stack_definitions();
    init_resource_import();
    init_stack_source_tracing();
    init_private10();
    init_toolkit_info();
    init_validate_formatting();
    init_work_graph2();
    init_payloads();
    init_util3();
    init_concurrency();
    init_glob_matcher();
    init_promises();
    init_validation_report();
    FILE_EVENTS = [EVENTS.ADD, EVENTS.ADD_DIR, EVENTS.CHANGE, EVENTS.UNLINK, EVENTS.UNLINK_DIR];
    __name(isFileEvent, "isFileEvent");
    Toolkit = class extends CloudAssemblySourceBuilder {
      constructor(props = {}) {
        super();
        this.props = props;
        this.toolkitStackName = props.toolkitStackName ?? DEFAULT_TOOLKIT_STACK_NAME;
        this.assemblyFailureAt = props.assemblyFailureAt ?? "error";
        this.pluginHost = props.pluginHost ?? new PluginHost();
        let ioHost = props.ioHost ?? new NonInteractiveIoHost();
        if (props.emojis === false) {
          ioHost = withoutEmojis(ioHost);
        }
        if (props.color === false) {
          ioHost = withoutColor(ioHost);
        }
        this.ioHost = withTrimmedWhitespace(ioHost);
        this.baseCredentials = props.sdkConfig?.baseCredentials ?? BaseCredentials.awsCliCompatible();
        this.unstableFeatures = props.unstableFeatures ?? [];
      }
      props;
      static {
        __name(this, "Toolkit");
      }
      /**
       * The toolkit stack name used for bootstrapping resources.
       */
      toolkitStackName;
      /**
       * The IoHost of this Toolkit
       */
      ioHost;
      /**
       * The plugin host for loading and managing plugins
       */
      pluginHost;
      /**
       * Cache of the internal SDK Provider instance
       */
      sdkProviderCache;
      baseCredentials;
      unstableFeatures;
      assemblyFailureAt;
      /**
       * Access to the AWS SDK
       * @internal
       */
      async sdkProvider(action) {
        if (!this.sdkProviderCache) {
          const ioHelper = asIoHelper(this.ioHost, action);
          const clientConfig = {
            requestHandler: sdkRequestHandler(this.props.sdkConfig?.httpOptions?.agent)
          };
          const config2 = await this.baseCredentials.sdkBaseConfig(ioHelper, clientConfig);
          this.sdkProviderCache = new SdkProvider(config2.credentialProvider, config2.defaultRegion, {
            ioHelper,
            logger: new IoHostSdkLogger(ioHelper),
            pluginHost: this.pluginHost,
            requestHandler: clientConfig.requestHandler
          });
        }
        return this.sdkProviderCache;
      }
      /**
       * Helper to provide the CloudAssemblySourceBuilder with required toolkit services
       * @internal
       */
      async sourceBuilderServices() {
        return {
          ioHelper: asIoHelper(this.ioHost, "assembly"),
          sdkProvider: await this.sdkProvider("assembly"),
          pluginHost: this.pluginHost
        };
      }
      /**
       * Bootstrap Action
       */
      async bootstrap(environments, options = {}) {
        const startTime = Date.now();
        const results = [];
        const ioHelper = asIoHelper(this.ioHost, "bootstrap");
        const bootstrapEnvironments = await environments.getEnvironments(this.ioHost);
        const source = options.source ?? BootstrapSource.default();
        const parameters = options.parameters;
        const bootstrapper = new Bootstrapper(source, ioHelper);
        const sdkProvider = await this.sdkProvider("bootstrap");
        const limit = pLimit4(20);
        await Promise.all(bootstrapEnvironments.map((environment, currentIdx) => limit(async () => {
          const bootstrapSpan = await ioHelper.span(SPAN.BOOTSTRAP_SINGLE).begin(`${chalk26.bold(environment.name)}: bootstrapping...`, {
            total: bootstrapEnvironments.length,
            current: currentIdx + 1,
            environment
          });
          try {
            const bootstrapResult = await bootstrapper.bootstrapEnvironment(
              environment,
              sdkProvider,
              {
                ...options,
                toolkitStackName: this.toolkitStackName,
                source,
                parameters: parameters?.parameters,
                usePreviousParameters: parameters?.keepExistingParameters
              }
            );
            const message2 = bootstrapResult.noOp ? ` \u2705  ${environment.name} (no changes)` : ` \u2705  ${environment.name}`;
            await ioHelper.notify(IO.CDK_TOOLKIT_I9900.msg(chalk26.green("\n" + message2), { environment }));
            const envTime = await bootstrapSpan.end();
            const result2 = {
              environment,
              status: bootstrapResult.noOp ? "no-op" : "success",
              duration: envTime.asMs
            };
            results.push(result2);
          } catch (e32) {
            await ioHelper.notify(IO.CDK_TOOLKIT_E9900.msg(`
 \u274C  ${chalk26.bold(environment.name)} failed: ${formatErrorMessage(e32)}`, { error: e32 }));
            throw e32;
          }
        })));
        return {
          environments: results,
          duration: Date.now() - startTime
        };
      }
      /**
       * Synth Action
       *
       * The caller assumes ownership of the `CachedCloudAssembly` and is responsible for calling `dispose()` on
       * it after use.
       */
      async synth(cx, options = {}) {
        var _stack = [];
        try {
          const ioHelper = asIoHelper(this.ioHost, "synth");
          const assembly = __using(_stack, new AsyncDisposableBox(await synthAndMeasure(ioHelper, cx, stacksOpt(options))), true);
          const stacks = await assembly.value.selectStacksV2(stacksOpt(options));
          const autoValidateStacks = options.validateStacks ? [assembly.value.selectStacksForValidation()] : [];
          await throwIfValidationFailures(assembly.value, stacks.concat(...autoValidateStacks), this.assemblyFailureAt, ioHelper);
          const message2 = `Successfully synthesized to ${chalk26.blue(path34.resolve(stacks.assembly.directory))}`;
          const assemblyData = {
            assemblyDirectory: stacks.assembly.directory,
            stacksCount: stacks.stackCount,
            stackIds: stacks.hierarchicalIds
          };
          if (stacks.stackCount === 1) {
            const firstStack = stacks.firstStack;
            const template = firstStack.template;
            const obscuredTemplate = obscureTemplate(template);
            await ioHelper.notify(IO.CDK_TOOLKIT_I1901.msg(message2, {
              ...assemblyData,
              stack: {
                stackName: firstStack.stackName,
                hierarchicalId: firstStack.hierarchicalId,
                template,
                stringifiedJson: serializeStructure(obscuredTemplate, true),
                stringifiedYaml: serializeStructure(obscuredTemplate, false)
              }
            }));
          } else {
            await ioHelper.notify(IO.CDK_TOOLKIT_I1902.msg(chalk26.green(message2), assemblyData));
            await ioHelper.defaults.info(`Supply a stack id (${stacks.stackArtifacts.map((s) => chalk26.green(s.hierarchicalId)).join(", ")}) to display its template.`);
          }
          return new CachedCloudAssembly(assembly.take());
        } catch (_) {
          var _error = _, _hasError = true;
        } finally {
          var _promise = __callDispose(_stack, _error, _hasError);
          _promise && await _promise;
        }
      }
      /**
       * Diff Action
       */
      async diff(cx, options = {}) {
        var _stack = [];
        try {
          const ioHelper = asIoHelper(this.ioHost, "diff");
          const selectStacks = stacksOpt(options);
          const assembly = __using(_stack, await synthAndMeasure(ioHelper, cx, selectStacks), true);
          const stacks = await assembly.selectStacksV2(selectStacks);
          const diffSpan = await ioHelper.span(SPAN.DIFF_STACK).begin({ stacks: selectStacks });
          const deployments = await this.deploymentsForAction("diff");
          const strict = !!options.strict;
          const contextLines = options.contextLines || 3;
          let diffs = 0;
          let securityDiffs = 0;
          const templateInfos = await prepareDiff(diffSpan.asHelper, stacks, deployments, await this.sdkProvider("diff"), options);
          const templateDiffs = {};
          for (const templateInfo of templateInfos) {
            const formatter = new DiffFormatter({ templateInfo });
            const stackDiff = formatter.formatStackDiff({ strict, contextLines });
            const securityDiff = formatter.formatSecurityDiff();
            const formattedSecurityDiff = securityDiff.permissionChangeType !== "none" /* NONE */ ? stackDiff.formattedDiff : void 0;
            if (securityDiff.permissionChangeType == "broadening" /* BROADENING */) {
              const warningMessage = "This deployment will make potentially sensitive changes according to your current security approval level.\nPlease confirm you intend to make the following modifications:\n";
              await diffSpan.defaults.warn(warningMessage);
              await diffSpan.defaults.info(securityDiff.formattedDiff);
            }
            diffs += stackDiff.numStacksWithChanges;
            securityDiffs += securityDiff.numStacksWithChanges;
            appendObject(templateDiffs, formatter.diffs);
            await diffSpan.notify(IO.CDK_TOOLKIT_I4002.msg(stackDiff.formattedDiff, {
              stack: templateInfo.newTemplate,
              diffs: formatter.diffs,
              numStacksWithChanges: stackDiff.numStacksWithChanges,
              numStacksWithSecurityChanges: securityDiff.numStacksWithChanges,
              permissionChanges: securityDiff.permissionChangeType,
              formattedDiff: {
                diff: stackDiff.formattedDiff,
                security: formattedSecurityDiff
              }
            }));
          }
          await diffSpan.end(`\u2728 Number of stacks with differences: ${diffs}`, {
            numStacksWithChanges: diffs,
            numStacksWithSecurityChanges: securityDiffs,
            diffs: templateDiffs
          });
          return templateDiffs;
        } catch (_) {
          var _error = _, _hasError = true;
        } finally {
          var _promise = __callDispose(_stack, _error, _hasError);
          _promise && await _promise;
        }
      }
      /**
       * Drift Action
       */
      async drift(cx, options = {}) {
        var _stack = [];
        try {
          const ioHelper = asIoHelper(this.ioHost, "drift");
          const selectStacks = stacksOpt(options);
          const assembly = __using(_stack, await synthAndMeasure(ioHelper, cx, selectStacks), true);
          const stacks = await assembly.selectStacksV2(selectStacks);
          const driftSpan = await ioHelper.span(SPAN.DRIFT_APP).begin({ stacks: selectStacks });
          const allDriftResults = {};
          const unavailableDrifts = [];
          const sdkProvider = await this.sdkProvider("drift");
          for (const stack of stacks.stackArtifacts) {
            const cfn = (await sdkProvider.forEnvironment(stack.environment, 0 /* ForReading */)).sdk.cloudFormation();
            const driftResults = await detectStackDrift(cfn, driftSpan.asHelper, stack.stackName);
            if (!driftResults.StackResourceDrifts) {
              const stackName = stack.displayName ?? stack.stackName;
              unavailableDrifts.push(stackName);
              await driftSpan.notify(IO.CDK_TOOLKIT_W4591.msg(`${stackName}: No drift results available`, { stack }));
              continue;
            }
            const formatter = new DriftFormatter({ stack, resourceDrifts: driftResults.StackResourceDrifts });
            const driftOutput = formatter.formatStackDrift();
            const stackDrift = {
              numResourcesWithDrift: driftOutput.numResourcesWithDrift,
              numResourcesUnchecked: driftOutput.numResourcesUnchecked,
              formattedDrift: {
                unchanged: driftOutput.unchanged,
                unchecked: driftOutput.unchecked,
                modified: driftOutput.modified,
                deleted: driftOutput.deleted
              }
            };
            allDriftResults[formatter.stackName] = stackDrift;
            await driftSpan.defaults.info(driftOutput.stackHeader);
            if (driftOutput.unchanged) {
              await driftSpan.defaults.debug(driftOutput.unchanged);
            }
            if (driftOutput.unchecked) {
              await driftSpan.defaults.debug(driftOutput.unchecked);
            }
            if (driftOutput.modified) {
              await driftSpan.defaults.info(driftOutput.modified);
            }
            if (driftOutput.deleted) {
              await driftSpan.defaults.info(driftOutput.deleted);
            }
            await driftSpan.notify(IO.CDK_TOOLKIT_I4590.msg(driftOutput.summary, {
              stack,
              drift: stackDrift
            }));
          }
          const totalDrifts = Object.values(allDriftResults).reduce((total, current) => total + (current.numResourcesWithDrift ?? 0), 0);
          const totalUnchecked = Object.values(allDriftResults).reduce((total, current) => total + (current.numResourcesUnchecked ?? 0), 0);
          await driftSpan.end(`
\u2728  Number of resources with drift: ${totalDrifts}${totalUnchecked ? ` (${totalUnchecked} unchecked)` : ""}`);
          if (unavailableDrifts.length) {
            await driftSpan.defaults.warn(`
\u26A0\uFE0F  Failed to check drift for ${unavailableDrifts.length} stack(s). Check log for more details.`);
          }
          return allDriftResults;
        } catch (_) {
          var _error = _, _hasError = true;
        } finally {
          var _promise = __callDispose(_stack, _error, _hasError);
          _promise && await _promise;
        }
      }
      /**
       * Publish Assets Action
       *
       * Publishes assets for the selected stacks without deploying
       */
      async publishAssets(cx, options = {}) {
        var _stack = [];
        try {
          this.requireUnstableFeature("publish-assets");
          const ioHelper = asIoHelper(this.ioHost, "publish-assets");
          const selectStacks = stacksOpt(options);
          const assembly = __using(_stack, await synthAndMeasure(ioHelper, cx, selectStacks), true);
          const stackCollection = await assembly.selectStacksV2(selectStacks);
          await throwIfValidationFailures(assembly, stackCollection, this.assemblyFailureAt, ioHelper);
          if (stackCollection.stackCount === 0) {
            await ioHelper.notify(IO.CDK_TOOLKIT_E5001.msg("No stacks selected"));
            return {
              publishedAssets: []
            };
          }
          const deployments = await this.deploymentsForAction("publish-assets");
          const stacks = stackCollection.stackArtifacts;
          const stacksAndTheirAssetManifests = stacks.flatMap((stack) => [
            stack,
            ...stack.dependencies.filter((x) => cxapi10.AssetManifestArtifact.isAssetManifestArtifact(x))
          ]);
          const workGraph = new WorkGraphBuilder(
            ioHelper,
            true
            // prebuild all assets
          ).build(stacksAndTheirAssetManifests);
          if (!options.force) {
            await removePublishedAssetsFromWorkGraph(workGraph, deployments, options);
          }
          const assetNodes = Object.values(workGraph.nodes).filter((n10) => n10.type === "asset-publish");
          if (assetNodes.length === 0) {
            await ioHelper.notify(IO.CDK_TOOLKIT_I9400.msg(chalk26.green("\n\u2728  All assets are already published\n")));
            return {
              publishedAssets: []
            };
          }
          const assets = assetNodes.map((n10) => n10.asset);
          await ioHelper.notify(IO.CDK_TOOLKIT_I9401.msg("Publishing assets", { assets }));
          const concurrency = options.concurrency ?? 4;
          const graphConcurrency = {
            "stack": 1,
            "asset-build": concurrency,
            "asset-publish": concurrency,
            "marker": 1
          };
          await workGraph.doParallel(graphConcurrency, {
            // No-op: we're only publishing assets, not deploying
            deployStack: WorkGraph.NOOP,
            buildAsset: this.createBuildAssetFunction(ioHelper, deployments, void 0),
            publishAsset: this.createPublishAssetFunction(ioHelper, deployments, void 0, options.force),
            marker: WorkGraph.NOOP
          });
          await ioHelper.notify(IO.CDK_TOOLKIT_I9402.msg(chalk26.green("\n\u2728  Assets published successfully\n"), { assets }));
          return {
            publishedAssets: assets
          };
        } catch (_) {
          var _error = _, _hasError = true;
        } finally {
          var _promise = __callDispose(_stack, _error, _hasError);
          _promise && await _promise;
        }
      }
      /**
       * List Action
       *
       * List selected stacks and their dependencies
       */
      async list(cx, options = {}) {
        var _stack = [];
        try {
          const ioHelper = asIoHelper(this.ioHost, "list");
          const selectStacks = stacksOpt(options);
          const assembly = __using(_stack, await synthAndMeasure(ioHelper, cx, selectStacks), true);
          const stackCollection = await assembly.selectStacksV2(selectStacks);
          const stacks = stackCollection.withDependencies();
          const message2 = stacks.map((s) => s.id).join("\n");
          await ioHelper.notify(IO.CDK_TOOLKIT_I2901.msg(message2, { stacks }));
          return stacks;
        } catch (_) {
          var _error = _, _hasError = true;
        } finally {
          var _promise = __callDispose(_stack, _error, _hasError);
          _promise && await _promise;
        }
      }
      /**
       * Try to find the root causes for deployment failures of the given stacks.
       *
       * Both emits the diagnosis results over the IO host as they are coming in, as well
       * as returns all of them as the result of the function.
       *
       * NOTE: The Cloud Assembly Source **should** be configured with `debug: true` to add
       * the maximum number of diagnostics.
       */
      async diagnose(cx, options = {}) {
        var _stack = [];
        try {
          this.requireUnstableFeature("diagnose");
          const ioHelper = asIoHelper(this.ioHost, "diagnose");
          const selectStacks = stacksOpt(options);
          const assembly = __using(_stack, await synthAndMeasure(ioHelper, cx, selectStacks), true);
          const stackCollection = await assembly.selectStacksV2(selectStacks);
          const envs = new EnvironmentAccess(await this.sdkProvider("diagnose"), options.toolkitStackName ?? DEFAULT_TOOLKIT_STACK_NAME, ioHelper);
          const limit = pLimit4(options.concurrency ?? 10);
          const stacks = await Promise.all(stackCollection.stackArtifacts.map((stack) => limit(async () => {
            const stackEnv = await envs.accessStackForLookupBestEffort(stack);
            const diagnoser = new CloudFormationStackDiagnoser({
              sdk: stackEnv.sdk,
              envResources: stackEnv.resources,
              sourceTracer: new StackArtifactSourceTracer(stack),
              ioHelper,
              topLevelStackHierarchicalId: stack.hierarchicalId,
              additionalExplorationSdkProvider: /* @__PURE__ */ __name(() => Promise.resolve(stackEnv.sdk), "additionalExplorationSdkProvider")
            });
            const diagnosis = await diagnoser.diagnoseFromFresh(stack.stackName);
            const ret = {
              stackName: stack.stackName,
              hierarchicalId: stack.hierarchicalId,
              result: diagnosis
            };
            await this.ioHost.notify({
              action: "diagnose",
              ...hostMessageFromDiagnosis(ret)
            });
            return ret;
          })));
          return { stacks };
        } catch (_) {
          var _error = _, _hasError = true;
        } finally {
          var _promise = __callDispose(_stack, _error, _hasError);
          _promise && await _promise;
        }
      }
      /**
       * Validate Action
       *
       * Synthesizes the CDK app and reads the policy validation report
       * from the cloud assembly output directory.
       */
      async validate(cx, options = {}) {
        var _stack = [];
        try {
          const ioHelper = asIoHelper(this.ioHost, "validate");
          const selectStacks = stacksOpt(options);
          const assembly = __using(_stack, await synthAndMeasure(ioHelper, cx, selectStacks), true);
          const stacks = await assembly.selectStacksV2(selectStacks);
          const reports = await obtainUnifiedValidationReport(assembly, stacks);
          if (options.online ?? true) {
            const deployments = await this.deploymentsForAction("validate");
            const onlineReport = await this.validateOnline(ioHelper, stacks, deployments);
            if (onlineReport) {
              reports.push(onlineReport);
            }
          }
          const hasAnyViolations = reports.some((report) => report.violations && report.violations.length > 0);
          const result2 = {
            conclusion: combineConclusions(reports),
            title: void 0,
            pluginReports: reports
          };
          if (!hasAnyViolations) {
            await ioHelper.notify(IO.CDK_TOOLKIT_I9600.msg("Validation did not find any problems.", result2));
          } else {
            await ioHelper.notify(hostMessageFromValidation(process.cwd(), result2));
          }
          return result2;
        } catch (_) {
          var _error = _, _hasError = true;
        } finally {
          var _promise = __callDispose(_stack, _error, _hasError);
          _promise && await _promise;
        }
      }
      async validateOnline(ioHelper, stacks, deployments) {
        const violations = [];
        for (const stack of stacks.stackArtifacts) {
          try {
            const report = await createValidationChangeSet(ioHelper, {
              deployments,
              stack,
              parameters: {},
              uuid: (0, import_node_crypto18.randomUUID)(),
              willExecute: false,
              failOnError: true
            });
            if (report.diagnosis.type === "problem") {
              for (const problem of report.diagnosis.problems) {
                violations.push({
                  ruleName: problem.errorCode ?? "CloudFormationValidation",
                  description: problem.message.replace(/\s*\(at\s+\/Resources\/[^)]+\)\s*$/, ""),
                  severity: "fatal",
                  violatingConstructs: [{
                    constructPath: problem.sourceTrace?.constructPath ?? (problem.logicalId ? `${stack.hierarchicalId}/${problem.logicalId}` : stack.hierarchicalId),
                    cloudFormationResource: problem.logicalId ? {
                      templatePath: `${stack.stackName}.template.json`,
                      logicalId: problem.logicalId
                    } : void 0,
                    stackTraces: problem.sourceTrace?.creationStackTrace ? [problem.sourceTrace.creationStackTrace.join("\n")] : void 0
                  }]
                });
              }
            }
          } catch (e32) {
            await ioHelper.notify(IO.CDK_TOOLKIT_W9602.msg(`Online validation could not be completed for stack '${stack.hierarchicalId}': ${e32.message}`));
          }
        }
        if (violations.length === 0) {
          return void 0;
        }
        return {
          pluginName: "CloudFormation",
          conclusion: "failure",
          violations
        };
      }
      /**
       * Deploy Action
       *
       * Deploys the selected stacks into an AWS account
       */
      async deploy(cx, options = {}) {
        var _stack = [];
        try {
          const ioHelper = asIoHelper(this.ioHost, "deploy");
          const assembly = __using(_stack, await synthAndMeasure(ioHelper, cx, stacksOpt(options)), true);
          return await this._deploy(assembly, "deploy", assembly.synthDuration, options);
        } catch (_) {
          var _error = _, _hasError = true;
        } finally {
          var _promise = __callDispose(_stack, _error, _hasError);
          _promise && await _promise;
        }
      }
      /**
       * Helper to allow deploy being called as part of the watch action.
       */
      async _deploy(assembly, action, synthDuration, options = {}) {
        const ioHelper = asIoHelper(this.ioHost, action);
        const selectStacks = stacksOpt(options);
        const stackCollection = await assembly.selectStacksV2(selectStacks);
        await throwIfValidationFailures(assembly, stackCollection, this.assemblyFailureAt, ioHelper);
        const ret = {
          stacks: []
        };
        if (stackCollection.stackCount === 0) {
          await ioHelper.notify(IO.CDK_TOOLKIT_E5001.msg("This app contains no stacks"));
          return ret;
        }
        const deployments = await this.deploymentsForAction("deploy");
        if (!isExecuteChangeSetDeployment(options.deploymentMethod)) {
          const migrator = new ResourceMigrator({ deployments, ioHelper });
          await migrator.tryMigrateResources(stackCollection, options);
        }
        const parameterMap = buildParameterMap(options.parameters?.parameters);
        if (options.deploymentMethod?.method === "hotswap") {
          await ioHelper.notify(IO.CDK_TOOLKIT_W5400.msg([
            "\u26A0\uFE0F Hotswap deployments deliberately introduce CloudFormation drift to speed up deployments",
            "\u26A0\uFE0F They should only be used for development - never use them for your production Stacks!"
          ].join("\n")));
        }
        const stacks = stackCollection.stackArtifacts;
        const stackOutputs = {};
        const outputsFile = options.outputsFile;
        const { buildAsset, publishAsset } = (() => {
          if (isExecuteChangeSetDeployment(options.deploymentMethod)) {
            return {
              buildAsset: WorkGraph.NOOP,
              publishAsset: WorkGraph.NOOP
            };
          }
          return {
            buildAsset: this.createBuildAssetFunction(ioHelper, deployments, options.roleArn),
            publishAsset: this.createPublishAssetFunction(ioHelper, deployments, options.roleArn, options.forceAssetPublishing)
          };
        })();
        const deployStack2 = /* @__PURE__ */ __name(async (stackNode) => {
          const stack = stackNode.stack;
          if (stackCollection.stackCount !== 1) {
            await ioHelper.defaults.info(chalk26.bold(stack.displayName));
          }
          if (!stack.environment) {
            throw new ToolkitError(
              "StackEnvironmentMissing",
              `Stack ${stack.displayName} does not define an environment, and AWS credentials could not be obtained from standard locations or no region was configured.`
            );
          }
          const resourceCount = Object.keys(stack.template.Resources || {}).length;
          if (resourceCount === 0) {
            const stackExists = await deployments.stackExists({ stack });
            if (!stackExists) {
              return ioHelper.notify(IO.CDK_TOOLKIT_W5021.msg(`${chalk26.bold(stack.displayName)}: stack has no resources, skipping deployment.`));
            }
            await ioHelper.notify(IO.CDK_TOOLKIT_W5022.msg(`${chalk26.bold(stack.displayName)}: stack has no resources, deleting existing stack.`));
            await this._destroy(assembly, "deploy", {
              stacks: { patterns: [stack.hierarchicalId], strategy: "pattern-must-match-single" /* PATTERN_MUST_MATCH_SINGLE */ },
              roleArn: options.roleArn
            });
            return;
          }
          const currentTemplate = await deployments.readCurrentTemplate(stack);
          const notificationArns = !!options.notificationArns || !!stack.notificationArns ? (options.notificationArns ?? []).concat(stack.notificationArns ?? []) : void 0;
          for (const notificationArn of notificationArns ?? []) {
            if (!validateSnsTopicArn(notificationArn)) {
              throw new ToolkitError("InvalidSnsTopicArn", `Notification arn ${notificationArn} is not a valid arn for an SNS topic`);
            }
          }
          const sharedDeployOptions = {
            stack,
            deployName: stack.stackName,
            roleArn: options.roleArn,
            toolkitStackName: this.toolkitStackName,
            reuseAssets: options.reuseAssets,
            tags: options.tags?.length ? options.tags : tagsForStack(stack),
            forceDeployment: options.forceDeployment,
            parameters: Object.assign({}, parameterMap["*"], parameterMap[stack.stackName]),
            usePreviousParameters: options.parameters?.keepExistingParameters,
            rollback: options.rollback,
            notificationArns,
            extraUserAgent: options.extraUserAgent,
            assetParallelism: options.assetParallelism
          };
          const prepareResult = isChangeSetDeployment(options.deploymentMethod) ? await deployments.prepareStack({
            ...sharedDeployOptions,
            deploymentMethod: options.deploymentMethod,
            cleanupOnNoOp: isExecutingChangeSetDeployment(options.deploymentMethod)
          }) : void 0;
          if (!prepareResult?.noOp) {
            const diffChangeSet = isExecuteChangeSetDeployment(options.deploymentMethod) ? await deployments.describeChangeSet(stack, options.deploymentMethod.changeSetName, prepareResult?.stackArn) : prepareResult?.changeSet;
            const formatter = new DiffFormatter({
              templateInfo: {
                oldTemplate: currentTemplate,
                newTemplate: stack,
                changeSet: diffChangeSet
              }
            });
            const securityDiff = formatter.formatSecurityDiff();
            const stackDiff = formatter.formatStackDiff();
            const hasSecurityChanges = securityDiff.permissionChangeType !== "none" /* NONE */;
            const deployMotivation = hasSecurityChanges ? '"--require-approval" is enabled and stack includes security-sensitive updates.' : '"--require-approval" is enabled and stack includes updates.';
            const diffOutput2 = hasSecurityChanges ? securityDiff.formattedDiff : stackDiff.formattedDiff;
            const deployQuestion = `${diffOutput2}

${deployMotivation}
Do you wish to deploy these changes`;
            const deployConfirmed = await ioHelper.requestResponse(IO.CDK_TOOLKIT_I5060.req(deployQuestion, {
              motivation: deployMotivation,
              concurrency,
              permissionChangeType: securityDiff.permissionChangeType,
              templateDiffs: formatter.diffs
            }));
            if (!deployConfirmed) {
              if (prepareResult?.changeSet?.ChangeSetName) {
                await deployments.cleanupChangeSet(stack, prepareResult.changeSet.ChangeSetName);
              }
              throw new ToolkitError("DeployAborted", "Aborted by user");
            }
          }
          const stackIndex = stacks.indexOf(stack) + 1;
          const deploySpan = await ioHelper.span(SPAN.DEPLOY_STACK).begin(`${chalk26.bold(stack.displayName)}: deploying... [${stackIndex}/${stackCollection.stackCount}]`, {
            total: stackCollection.stackCount,
            current: stackIndex,
            stack
          });
          deploySpan.incCounter("resources", resourceCount);
          let deployDuration;
          try {
            const prepareIsFinal = prepareResult && (prepareResult.noOp || isNonExecutingChangeSetDeployment(options.deploymentMethod));
            let deployResult = prepareIsFinal ? prepareResult : void 0;
            let rollback = options.rollback;
            let iteration = 0;
            while (!deployResult) {
              if (++iteration > 2) {
                throw new ToolkitError("DeployLoopUnstable", "This loop should have stabilized in 2 iterations, but didn't. If you are seeing this error, please report it at https://github.com/aws/aws-cdk/issues/new/choose");
              }
              const r32 = await deployments.deployStack({
                ...sharedDeployOptions,
                // On the first iteration, execute the prepared change set.
                // On retries (after rollback), create a new change set since the old one is gone.
                deploymentMethod: iteration === 1 && isExecutingChangeSetDeployment(options.deploymentMethod) ? toExecuteChangeSetDeployment(options.deploymentMethod) : options.deploymentMethod,
                rollback
              });
              switch (r32.type) {
                case "did-deploy-stack":
                  deployResult = r32;
                  break;
                case "failpaused-need-rollback-first": {
                  const motivation = r32.reason === "replacement" ? `Stack is in a paused fail state (${r32.status}) and change includes a replacement which cannot be deployed with "--no-rollback"` : `Stack is in a paused fail state (${r32.status}) and command line arguments do not include "--no-rollback"`;
                  const question2 = `${motivation}. Perform a regular deployment`;
                  const confirmed = await ioHelper.requestResponse(IO.CDK_TOOLKIT_I5050.req(question2, {
                    motivation,
                    concurrency
                  }));
                  if (!confirmed) {
                    throw new ToolkitError("RollbackAborted", "Aborted by user");
                  }
                  await this._rollback(assembly, action, {
                    stacks: {
                      patterns: [stack.hierarchicalId],
                      strategy: "pattern-must-match-single" /* PATTERN_MUST_MATCH_SINGLE */
                    },
                    orphanFailedResources: options.orphanFailedResourcesDuringRollback
                  });
                  rollback = true;
                  break;
                }
                case "replacement-requires-rollback": {
                  const motivation = 'Change includes a replacement which cannot be deployed with "--no-rollback"';
                  const question2 = `${motivation}. Perform a regular deployment`;
                  const confirmed = await ioHelper.requestResponse(IO.CDK_TOOLKIT_I5050.req(question2, {
                    motivation,
                    concurrency
                  }));
                  if (!confirmed) {
                    throw new ToolkitError("ReplacementRollbackAborted", "Aborted by user");
                  }
                  rollback = true;
                  break;
                }
                default:
                  throw new ToolkitError("UnexpectedDeployResult", `Unexpected result type from deployStack: ${JSON.stringify(r32)}. If you are seeing this error, please report it at https://github.com/aws/aws-cdk/issues/new/choose`);
              }
            }
            const message2 = deployResult.noOp ? ` \u2705  ${stack.displayName} (no changes)` : ` \u2705  ${stack.displayName}`;
            await ioHelper.notify(IO.CDK_TOOLKIT_I5900.msg(chalk26.green("\n" + message2), deployResult));
            deployDuration = await deploySpan.timing(IO.CDK_TOOLKIT_I5000);
            if (Object.keys(deployResult.outputs).length > 0) {
              const buffer = ["Outputs:"];
              stackOutputs[stack.stackName] = deployResult.outputs;
              for (const name of Object.keys(deployResult.outputs).sort()) {
                const value = deployResult.outputs[name];
                buffer.push(`${chalk26.cyan(stack.id)}.${chalk26.cyan(name)} = ${chalk26.underline(chalk26.cyan(value))}`);
              }
              await ioHelper.notify(IO.CDK_TOOLKIT_I5901.msg(buffer.join("\n")));
            }
            await ioHelper.notify(IO.CDK_TOOLKIT_I5901.msg(`Stack ARN:
${deployResult.stackArn}`));
            ret.stacks.push({
              stackName: stack.stackName,
              environment: {
                account: stack.environment.account,
                region: stack.environment.region
              },
              stackArn: deployResult.stackArn,
              outputs: deployResult.outputs,
              hierarchicalId: stack.hierarchicalId,
              deleteFailures: deployResult.deleteFailures
            });
          } catch (e32) {
            const code = ToolkitError.isToolkitError(e32) ? e32.name : "DeployStackFailed";
            const newMessage = [`\u274C  ${chalk26.bold(stack.stackName)} failed:`, ...e32.name ? [`${e32.name}:`] : [], e32.message].join(" ");
            throw new ToolkitError(code, newMessage);
          } finally {
            if (options.traceLogs) {
              const cloudWatchLogMonitor = options.cloudWatchLogMonitor ?? new CloudWatchLogEventMonitor({ ioHelper });
              const foundLogGroupsResult = await findCloudWatchLogGroups(await this.sdkProvider("deploy"), ioHelper, stack);
              cloudWatchLogMonitor.addLogGroups(
                foundLogGroupsResult.env,
                foundLogGroupsResult.sdk,
                foundLogGroupsResult.logGroupNames
              );
              await ioHelper.notify(IO.CDK_TOOLKIT_I5031.msg(`The following log groups are added: ${foundLogGroupsResult.logGroupNames}`));
            }
            if (outputsFile) {
              fs35.ensureFileSync(outputsFile);
              await fs35.writeJson(outputsFile, stackOutputs, {
                spaces: 2,
                encoding: "utf8"
              });
            }
          }
          const duration = synthDuration.asMs + (deployDuration?.asMs ?? 0);
          await deploySpan.end(`
\u2728  Total time: ${formatTime(duration)}s
`, { duration });
        }, "deployStack");
        const assetBuildTime = options.assetBuildTime ?? "all-before-deploy" /* ALL_BEFORE_DEPLOY */;
        const prebuildAssets = assetBuildTime === "all-before-deploy" /* ALL_BEFORE_DEPLOY */;
        const concurrency = options.concurrency || 1;
        const stacksAndTheirAssetManifests = stacks.flatMap((stack) => [
          stack,
          ...stack.dependencies.filter((x) => cxapi10.AssetManifestArtifact.isAssetManifestArtifact(x))
        ]);
        const workGraph = new WorkGraphBuilder(ioHelper, prebuildAssets).build(stacksAndTheirAssetManifests);
        if (!options.forceAssetPublishing) {
          await removePublishedAssetsFromWorkGraph(workGraph, deployments, options);
        }
        const graphConcurrency = {
          "stack": concurrency,
          "asset-build": options.assetParallelism ?? true ? options.assetBuildConcurrency ?? 1 : 1,
          // This will be CPU-bound/memory bound, mostly matters for Docker builds
          "asset-publish": options.assetParallelism ?? true ? 8 : 1,
          // This will be I/O-bound, 8 in parallel seems reasonable
          "marker": 1
        };
        await workGraph.doParallel(graphConcurrency, {
          deployStack: deployStack2,
          buildAsset,
          publishAsset,
          // Markers are only used for telemetry, and the toolkit-lib isn't currently collecting any, so NOOP is fine.
          marker: WorkGraph.NOOP
        });
        return ret;
      }
      /**
       * Watch Action
       *
       * Continuously observe project files and deploy the selected stacks
       * automatically when changes are detected. Defaults to hotswap deployments.
       *
       * This function returns immediately, starting a watcher in the background.
       */
      async watch(cx, options = {}) {
        var _stack = [];
        try {
          const ioHelper = asIoHelper(this.ioHost, "watch");
          const assembly = __using(_stack, await assemblyFromSource(ioHelper, cx, false), true);
          const rootDir = options.watchDir ?? process.cwd();
          const watchIncludes = options.include ?? [];
          if (watchIncludes.length <= 0) {
            watchIncludes.push("**");
          }
          const watchExcludes = options.exclude ?? [...WATCH_EXCLUDE_DEFAULTS];
          const relativeOutDir = path34.relative(rootDir, assembly.directory);
          if (Boolean(relativeOutDir && !relativeOutDir.startsWith(".." + path34.sep) && !path34.isAbsolute(relativeOutDir))) {
            watchExcludes.push(`${relativeOutDir}/**`);
          }
          watchExcludes.push(".*", "**/.*");
          watchExcludes.push("**/.*/**");
          watchExcludes.push("**/node_modules/**");
          await ioHelper.notify(IO.CDK_TOOLKIT_I5310.msg([
            `root directory used for 'watch' is: ${rootDir}`,
            `'include' patterns for 'watch': ${JSON.stringify(watchIncludes)}`,
            `'exclude' patterns for 'watch': ${JSON.stringify(watchExcludes)}`
          ].join("\n"), {
            watchDir: rootDir,
            includes: watchIncludes,
            excludes: watchExcludes
          }));
          let latch = "pre-ready";
          const cloudWatchLogMonitor = options.traceLogs ? new CloudWatchLogEventMonitor({ ioHelper }) : void 0;
          const deployAndWatch = /* @__PURE__ */ __name(async () => {
            latch = "deploying";
            await cloudWatchLogMonitor?.deactivate();
            await this.invokeDeployFromWatch(assembly, options, cloudWatchLogMonitor);
            while (latch === "queued") {
              latch = "deploying";
              await ioHelper.notify(IO.CDK_TOOLKIT_I5315.msg("Detected file changes during deployment. Invoking 'cdk deploy' again"));
              await this.invokeDeployFromWatch(assembly, options, cloudWatchLogMonitor);
            }
            latch = "open";
            await cloudWatchLogMonitor?.activate();
          }, "deployAndWatch");
          const shouldIgnore = createIgnoreMatcher({
            include: watchIncludes,
            exclude: watchExcludes,
            rootDir
          });
          const watcher = watch(".", {
            ignored: shouldIgnore,
            cwd: rootDir
          }).on("ready", async () => {
            latch = "open";
            await ioHelper.defaults.debug("'watch' received the 'ready' event. From now on, all file changes will trigger a deployment");
            await ioHelper.notify(IO.CDK_TOOLKIT_I5314.msg("Triggering initial 'cdk deploy'"));
            await deployAndWatch();
          }).on("all", async (event, filePath) => {
            if (!isFileEvent(event)) {
              return;
            }
            const watchEvent = {
              event,
              path: filePath
            };
            if (latch === "pre-ready") {
              await ioHelper.notify(IO.CDK_TOOLKIT_I5311.msg(`'watch' is observing ${event === "addDir" ? "directory" : "the file"} '${filePath}' for changes`, watchEvent));
            } else if (latch === "open") {
              await ioHelper.notify(IO.CDK_TOOLKIT_I5312.msg(`Detected change to '${filePath}' (type: ${event}). Triggering 'cdk deploy'`, watchEvent));
              await deployAndWatch();
            } else {
              latch = "queued";
              await ioHelper.notify(IO.CDK_TOOLKIT_I5313.msg(
                `Detected change to '${filePath}' (type: ${event}) while 'cdk deploy' is still running. Will queue for another deployment after this one finishes'`,
                watchEvent
              ));
            }
          });
          const stoppedPromise = promiseWithResolvers();
          return {
            async dispose() {
              await cloudWatchLogMonitor?.deactivate();
              await watcher.close();
              stoppedPromise.resolve();
              return stoppedPromise.promise;
            },
            async waitForEnd() {
              return stoppedPromise.promise;
            },
            async [Symbol.asyncDispose]() {
              return this.dispose();
            }
          };
        } catch (_) {
          var _error = _, _hasError = true;
        } finally {
          var _promise = __callDispose(_stack, _error, _hasError);
          _promise && await _promise;
        }
      }
      /**
       * Rollback Action
       *
       * Rolls back the selected stacks.
       */
      async rollback(cx, options = {}) {
        var _stack = [];
        try {
          const ioHelper = asIoHelper(this.ioHost, "rollback");
          const assembly = __using(_stack, await synthAndMeasure(ioHelper, cx, stacksOpt(options)), true);
          return await this._rollback(assembly, "rollback", options);
        } catch (_) {
          var _error = _, _hasError = true;
        } finally {
          var _promise = __callDispose(_stack, _error, _hasError);
          _promise && await _promise;
        }
      }
      /**
       * Helper to allow rollback being called as part of the deploy or watch action.
       */
      async _rollback(assembly, action, options) {
        const selectStacks = stacksOpt(options);
        const ioHelper = asIoHelper(this.ioHost, action);
        const stacks = await assembly.selectStacksV2(selectStacks);
        await throwIfValidationFailures(assembly, stacks, this.assemblyFailureAt, ioHelper);
        const ret = {
          stacks: []
        };
        if (stacks.stackCount === 0) {
          await ioHelper.notify(IO.CDK_TOOLKIT_E6001.msg("No stacks selected"));
          return ret;
        }
        let anyRollbackable = false;
        for (const [index, stack] of stacks.stackArtifacts.entries()) {
          const rollbackSpan = await ioHelper.span(SPAN.ROLLBACK_STACK).begin(`Rolling back ${chalk26.bold(stack.displayName)}`, {
            total: stacks.stackCount,
            current: index + 1,
            stack
          });
          const deployments = await this.deploymentsForAction("rollback");
          try {
            const stackResult = await deployments.rollbackStack({
              stack,
              roleArn: options.roleArn,
              toolkitStackName: this.toolkitStackName,
              orphanFailedResources: options.orphanFailedResources,
              validateBootstrapStackVersion: options.validateBootstrapStackVersion,
              orphanLogicalIds: options.orphanLogicalIds
            });
            if (!stackResult.notInRollbackableState) {
              anyRollbackable = true;
            }
            await rollbackSpan.end();
            ret.stacks.push({
              environment: {
                account: stack.environment.account,
                region: stack.environment.region
              },
              stackName: stack.stackName,
              stackArn: stackResult.stackArn,
              result: stackResult.notInRollbackableState ? "already-stable" : "rolled-back"
            });
          } catch (e32) {
            await ioHelper.notify(IO.CDK_TOOLKIT_E6900.msg(`
 \u274C  ${chalk26.bold(stack.displayName)} failed: ${formatErrorMessage(e32)}`, { error: e32 }));
            throw ToolkitError.withCause("RollbackFailed", "Rollback failed (use --force to orphan failing resources)", e32);
          }
        }
        if (!anyRollbackable) {
          throw new ToolkitError("NoRollbackableStacks", "No stacks were in a state that could be rolled back");
        }
        return ret;
      }
      /**
       * Orphan Action. Detaches resources from a CloudFormation stack without deleting them.
       */
      async orphan(cx, options) {
        var _stack = [];
        try {
          this.requireUnstableFeature("orphan");
          const ioHelper = asIoHelper(this.ioHost, "orphan");
          const parsed = parseAndValidateConstructPaths(options.constructPaths);
          const assembly = __using(_stack, await synthAndMeasure(ioHelper, cx, ALL_STACKS), true);
          const allStacks = await assembly.selectStacksV2(ALL_STACKS);
          const stack = allStacks.stackArtifacts.find((s) => s.hierarchicalId === parsed.stackId);
          if (!stack) {
            throw new ToolkitError(
              "StackNotFound",
              `No stack found with construct ID '${parsed.stackId}'. Available stacks: ${allStacks.stackArtifacts.map((s) => s.hierarchicalId).join(", ")}`
            );
          }
          const deployments = await this.deploymentsForAction("orphan");
          const orphaner = new ResourceOrphaner({
            deployments,
            ioHelper,
            roleArn: options.roleArn,
            toolkitStackName: options.toolkitStackName ?? this.toolkitStackName
          });
          const plan = await orphaner.makePlan(stack, parsed.constructPaths);
          const resourceLines = plan.orphanedResources.map((r32) => `  ${r32.logicalId} (${r32.resourceType}) - ${r32.cdkPath}`).join("\n");
          await ioHelper.defaults.info(
            `Stack: ${plan.stackName}
Resources to orphan (${plan.orphanedResources.length}):
` + resourceLines
          );
          const confirmed = await ioHelper.requestResponse(IO.CDK_TOOLKIT_I8810.req(
            "Do you wish to orphan these resources? This will perform 3 CloudFormation deployments.",
            {
              motivation: "User confirmation is needed before orphaning resources"
            }
          ));
          if (!confirmed) {
            throw new ToolkitError("OrphanAborted", "Aborted by user");
          }
          const result2 = await plan.execute();
          const mappingJson = Object.keys(result2.resourceMapping).length > 0 ? ` --resource-mapping-inline '${JSON.stringify(result2.resourceMapping)}'` : "";
          await ioHelper.defaults.info(
            `\u2705 Resources orphaned from ${plan.stackName}

Next steps:
  1. Update your CDK code to use the new resource type
  2. cdk import${mappingJson}`
          );
        } catch (_) {
          var _error = _, _hasError = true;
        } finally {
          var _promise = __callDispose(_stack, _error, _hasError);
          _promise && await _promise;
        }
      }
      /**
       * Refactor Action. Moves resources from one location (stack + logical ID) to another.
       */
      async refactor(cx, options = {}) {
        var _stack = [];
        try {
          this.requireUnstableFeature("refactor");
          const ioHelper = asIoHelper(this.ioHost, "refactor");
          const assembly = __using(_stack, await synthAndMeasure(ioHelper, cx, stacksOpt(options)), true);
          return await this._refactor(assembly, ioHelper, cx, options);
        } catch (_) {
          var _error = _, _hasError = true;
        } finally {
          var _promise = __callDispose(_stack, _error, _hasError);
          _promise && await _promise;
        }
      }
      async _refactor(assembly, ioHelper, cx, options = {}) {
        const sdkProvider = await this.sdkProvider("refactor");
        const selectedStacks = await assembly.selectStacksV2(stacksOpt(options));
        const groups = await groupStacks(sdkProvider, selectedStacks.stackArtifacts, options.additionalStackNames ?? []);
        for (let { environment, localStacks, deployedStacks } of groups) {
          await ioHelper.defaults.info(formatEnvironmentSectionHeader2(environment));
          const newStacks = localStacks.filter((s) => !deployedStacks.map((t) => t.stackName).includes(s.stackName));
          if (newStacks.length > 0) {
            let message2 = `The following stack${newStacks.length === 1 ? " is" : "s are"} new: ${newStacks.map((s) => s.stackName).join(", ")}
`;
            message2 += "Creation of new stacks is not yet supported by the refactor command. ";
            message2 += "Please deploy any new stacks separately before refactoring your stacks.";
            await ioHelper.defaults.error(chalk26.red(message2));
            continue;
          }
          try {
            const context = new RefactoringContext({
              environment,
              deployedStacks,
              localStacks,
              assumeRoleArn: options.roleArn,
              overrides: getOverrides(environment, deployedStacks, localStacks)
            });
            const mappings = context.mappings;
            if (mappings.length === 0 && context.ambiguousPaths.length === 0) {
              await ioHelper.defaults.info("Nothing to refactor.");
              continue;
            }
            const typedMappings = mappings.map((m20) => m20.toTypedMapping()).filter((m20) => m20.type !== "AWS::CDK::Metadata");
            let refactorMessage = formatTypedMappings2(typedMappings);
            const refactorResult = { typedMappings };
            const stackDefinitions = await generateStackDefinitions(mappings, deployedStacks, localStacks, environment, sdkProvider, ioHelper);
            if (context.ambiguousPaths.length > 0) {
              const paths = context.ambiguousPaths;
              refactorMessage += "\n" + formatAmbiguousMappings2(paths);
              refactorResult.ambiguousPaths = paths;
            }
            await ioHelper.notify(IO.CDK_TOOLKIT_I8900.msg(refactorMessage, refactorResult));
            if (options.dryRun || context.mappings.length === 0 || context.ambiguousPaths.length > 0) {
              continue;
            }
            if (process.stdout.isTTY && !await confirm3(options.force ?? false)) {
              await ioHelper.defaults.info(chalk26.red(`Refactoring canceled for environment aws://${environment.account}/${environment.region}
`));
              continue;
            }
            await ioHelper.defaults.info("Refactoring...");
            await context.execute(stackDefinitions, sdkProvider, ioHelper);
            await ioHelper.defaults.info("\u2705  Stack refactor complete");
            await ioHelper.defaults.info("Deploying updated stacks to finalize refactor...");
            await this.deploy(cx, {
              stacks: ALL_STACKS,
              forceDeployment: true
            });
          } catch (e32) {
            const message2 = `\u274C  Refactor failed: ${formatError(e32)}`;
            await ioHelper.notify(IO.CDK_TOOLKIT_E8900.msg(message2, { error: e32 }));
            await ioHelper.defaults.debug(e32.message);
          }
        }
        function getOverrides(environment, deployedStacks, localStacks) {
          const mappingGroup = options.overrides?.find((g32) => g32.region === environment.region && g32.account === environment.account);
          return mappingGroup == null ? [] : Object.entries(mappingGroup.resources ?? {}).map(([source, destination]) => new ResourceMapping(
            getResourceLocation(source, deployedStacks),
            getResourceLocation(destination, localStacks)
          ));
        }
        __name(getOverrides, "getOverrides");
        function getResourceLocation(location, stacks) {
          for (let stack of stacks) {
            const [stackName, logicalId] = location.split(".");
            if (stackName != null && logicalId != null && stack.stackName === stackName && stack.template.Resources?.[logicalId] != null) {
              return new ResourceLocation(stack, logicalId);
            } else {
              const resourceEntry = Object.entries(stack.template.Resources ?? {}).find(([_, r32]) => r32.Metadata?.["aws:cdk:path"] === location);
              if (resourceEntry != null) {
                return new ResourceLocation(stack, resourceEntry[0]);
              }
            }
          }
          throw new ToolkitError("ResourceLocationNotFound", `Cannot find resource in location ${location}`);
        }
        __name(getResourceLocation, "getResourceLocation");
        async function confirm3(force) {
          if (force) {
            return true;
          }
          const question2 = "Do you wish to refactor these resources?";
          return ioHelper.requestResponse(IO.CDK_TOOLKIT_I8910.req(question2, {
            motivation: "User input is needed"
          }));
        }
        __name(confirm3, "confirm");
        function formatError(error4) {
          try {
            const payload3 = JSON.parse(error4.message);
            const messages = [];
            if (payload3.reason?.StatusReason) {
              messages.push(`Refactor creation: [${payload3.reason?.Status}] ${payload3.reason.StatusReason}`);
            }
            if (payload3.reason?.ExecutionStatusReason) {
              messages.push(`Refactor execution: [${payload3.reason?.Status}] ${payload3.reason.ExecutionStatusReason}`);
            }
            return messages.length > 0 ? messages.join("\n") : `Unknown error (Stack refactor ID: ${payload3.reason?.StackRefactorId ?? "unknown"})`;
          } catch (e32) {
            return formatErrorMessage(error4);
          }
        }
        __name(formatError, "formatError");
      }
      /**
       * Destroy Action
       *
       * Destroys the selected Stacks.
       */
      async destroy(cx, options = {}) {
        var _stack = [];
        try {
          const ioHelper = asIoHelper(this.ioHost, "destroy");
          const assembly = __using(_stack, await synthAndMeasure(ioHelper, cx, stacksOpt(options)), true);
          return await this._destroy(assembly, "destroy", options);
        } catch (_) {
          var _error = _, _hasError = true;
        } finally {
          var _promise = __callDispose(_stack, _error, _hasError);
          _promise && await _promise;
        }
      }
      /**
       * Helper to allow destroy being called as part of the deploy action.
       */
      async _destroy(assembly, action, options) {
        const selectStacks = stacksOpt(options);
        const ioHelper = asIoHelper(this.ioHost, action);
        const stacks = await assembly.selectStacksV2(selectStacks);
        const ret = {
          stacks: []
        };
        const motivation = "Destroying stacks is an irreversible action";
        const question2 = `Are you sure you want to delete: ${chalk26.red(stacks.hierarchicalIds.join(", "))}`;
        const confirmed = await ioHelper.requestResponse(IO.CDK_TOOLKIT_I7010.req(question2, { motivation }));
        if (!confirmed) {
          await ioHelper.notify(IO.CDK_TOOLKIT_E7010.msg("Aborted by user"));
          return ret;
        }
        const concurrency = options.concurrency || 1;
        let destroyCount = 0;
        const destroySpan = await ioHelper.span(SPAN.DESTROY_ACTION).begin({
          stacks: stacks.stackArtifacts
        });
        try {
          const destroyStack2 = /* @__PURE__ */ __name(async (stackNode) => {
            const stack = stackNode.stack;
            destroyCount++;
            try {
              const singleDestroySpan = await ioHelper.span(SPAN.DESTROY_STACK).begin(chalk26.green(`${chalk26.blue(stack.displayName)}: destroying... [${destroyCount}/${stacks.stackCount}]`), {
                total: stacks.stackCount,
                current: destroyCount,
                stack
              });
              const deployments = await this.deploymentsForAction(action);
              const result2 = await deployments.destroyStack({
                stack,
                deployName: stack.stackName,
                roleArn: options.roleArn
              });
              ret.stacks.push({
                environment: {
                  account: stack.environment.account,
                  region: stack.environment.region
                },
                stackName: stack.stackName,
                stackArn: result2.stackArn,
                stackExisted: result2.stackArn !== void 0
              });
              await ioHelper.notify(IO.CDK_TOOLKIT_I7900.msg(chalk26.green(`
 \u2705  ${chalk26.blue(stack.displayName)}: ${action}ed`), stack));
              await singleDestroySpan.end();
            } catch (e32) {
              await ioHelper.notify(IO.CDK_TOOLKIT_E7900.msg(`
 \u274C  ${chalk26.blue(stack.displayName)}: ${action} failed ${e32}`, { error: e32 }));
              throw e32;
            }
          }, "destroyStack");
          const workGraph = buildDestroyWorkGraph(stacks.stackArtifacts, ioHelper);
          await workGraph.processStacks(concurrency, destroyStack2);
          return ret;
        } finally {
          await destroySpan.end();
        }
      }
      /**
       * Create a deployments class
       */
      async deploymentsForAction(action) {
        return new Deployments({
          sdkProvider: await this.sdkProvider(action),
          toolkitStackName: this.toolkitStackName,
          ioHelper: asIoHelper(this.ioHost, action)
        });
      }
      async invokeDeployFromWatch(assembly, options, cloudWatchLogMonitor) {
        const deploymentMethod = options.deploymentMethod ?? { method: "hotswap" };
        const deployOptions = {
          ...options,
          cloudWatchLogMonitor,
          deploymentMethod,
          extraUserAgent: `cdk-watch/hotswap-${deploymentMethod.method === "hotswap" ? "on" : "off"}`
        };
        try {
          await this._deploy(assembly, "watch", zeroTime(), deployOptions);
        } catch {
        }
      }
      /**
       * Retrieve feature flag information from the cloud assembly
       */
      async flags(cx) {
        var _stack = [];
        try {
          this.requireUnstableFeature("flags");
          const ioHelper = asIoHelper(this.ioHost, "flags");
          const assembly = __using(_stack, await assemblyFromSource(ioHelper, cx), true);
          const artifacts = Object.values(assembly.cloudAssembly.manifest.artifacts ?? {});
          const featureFlagReports = artifacts.filter((a32) => a32.type === import_cloud_assembly_schema6.ArtifactType.FEATURE_FLAG_REPORT);
          const flags = featureFlagReports.flatMap((report) => {
            const properties = report.properties;
            const moduleName = properties.module;
            const flagsWithUnconfiguredBehavesLike = Object.entries(properties.flags).filter(([_2, flagInfo]) => flagInfo.unconfiguredBehavesLike != void 0);
            const shouldIncludeUnconfiguredBehavesLike = flagsWithUnconfiguredBehavesLike.length > 0;
            return Object.entries(properties.flags).map(([flagName, flagInfo]) => {
              const baseFlag = {
                module: moduleName,
                name: flagName,
                recommendedValue: flagInfo.recommendedValue,
                userValue: flagInfo.userValue ?? void 0,
                explanation: flagInfo.explanation ?? ""
              };
              if (shouldIncludeUnconfiguredBehavesLike) {
                return {
                  ...baseFlag,
                  unconfiguredBehavesLike: {
                    v2: flagInfo.unconfiguredBehavesLike?.v2 ?? false
                  }
                };
              }
              return baseFlag;
            });
          });
          return flags;
        } catch (_) {
          var _error = _, _hasError = true;
        } finally {
          var _promise = __callDispose(_stack, _error, _hasError);
          _promise && await _promise;
        }
      }
      requireUnstableFeature(requestedFeature) {
        if (!this.unstableFeatures.includes(requestedFeature)) {
          throw new ToolkitError("UnstableFeatureNotEnabled", `Unstable feature '${requestedFeature}' is not enabled. Please enable it under 'unstableFeatures' (currently enabled: ${this.unstableFeatures})`);
        }
      }
      /**
       * Create a buildAsset function for use in WorkGraph
       */
      createBuildAssetFunction(ioHelper, deployments, roleArn) {
        return async (assetNode) => {
          const buildAssetSpan = await ioHelper.span(SPAN.BUILD_ASSET).begin({
            asset: assetNode.asset
          });
          await deployments.buildSingleAsset(
            assetNode.assetManifestArtifact,
            assetNode.assetManifest,
            assetNode.asset,
            {
              stack: assetNode.parentStack,
              roleArn,
              stackName: assetNode.parentStack.stackName
            }
          );
          await buildAssetSpan.end();
        };
      }
      /**
       * Create a publishAsset function for use in WorkGraph
       */
      createPublishAssetFunction(ioHelper, deployments, roleArn, forcePublish) {
        return async (assetNode) => {
          const publishAssetSpan = await ioHelper.span(SPAN.PUBLISH_ASSET).begin({
            asset: assetNode.asset
          });
          await deployments.publishSingleAsset(assetNode.assetManifest, assetNode.asset, {
            stack: assetNode.parentStack,
            roleArn,
            stackName: assetNode.parentStack.stackName,
            forcePublish
          });
          await publishAssetSpan.end();
        };
      }
    };
    __name(stacksOpt, "stacksOpt");
    __name(synthAndMeasure, "synthAndMeasure");
    __name(zeroTime, "zeroTime");
  }
});

// ../@aws-cdk/toolkit-lib/lib/toolkit/types.ts
var init_types15 = __esm({
  "../@aws-cdk/toolkit-lib/lib/toolkit/types.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/toolkit/index.ts
var toolkit_exports = {};
__export(toolkit_exports, {
  NonInteractiveIoHost: () => NonInteractiveIoHost,
  Toolkit: () => Toolkit
});
var init_toolkit2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/toolkit/index.ts"() {
    "use strict";
    init_toolkit();
    init_non_interactive_io_host();
    init_types15();
  }
});

// ../@aws-cdk/toolkit-lib/lib/actions/destroy/index.ts
var init_destroy3 = __esm({
  "../@aws-cdk/toolkit-lib/lib/actions/destroy/index.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/actions/drift/index.ts
var init_drift4 = __esm({
  "../@aws-cdk/toolkit-lib/lib/actions/drift/index.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/actions/list/index.ts
var init_list2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/actions/list/index.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/actions/orphan/index.ts
var init_orphan = __esm({
  "../@aws-cdk/toolkit-lib/lib/actions/orphan/index.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/actions/publish-assets/index.ts
var init_publish_assets2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/actions/publish-assets/index.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/actions/refactor/index.ts
var init_refactor2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/actions/refactor/index.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/actions/rollback/index.ts
var init_rollback2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/actions/rollback/index.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/actions/synth/index.ts
var init_synth2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/actions/synth/index.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/actions/watch/index.ts
var init_watch2 = __esm({
  "../@aws-cdk/toolkit-lib/lib/actions/watch/index.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/actions/diagnose/index.ts
var init_diagnose = __esm({
  "../@aws-cdk/toolkit-lib/lib/actions/diagnose/index.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/actions/validate/index.ts
var init_validate3 = __esm({
  "../@aws-cdk/toolkit-lib/lib/actions/validate/index.ts"() {
    "use strict";
  }
});

// ../@aws-cdk/toolkit-lib/lib/actions/index.ts
var actions_exports = {};
__export(actions_exports, {
  AssetBuildTime: () => AssetBuildTime,
  BootstrapEnvironments: () => BootstrapEnvironments,
  BootstrapSource: () => BootstrapSource,
  BootstrapStackParameters: () => BootstrapStackParameters,
  BootstrapTemplate: () => BootstrapTemplate,
  DiffMethod: () => DiffMethod,
  StackParameters: () => StackParameters
});
var init_actions = __esm({
  "../@aws-cdk/toolkit-lib/lib/actions/index.ts"() {
    "use strict";
    init_bootstrap4();
    init_deploy3();
    init_destroy3();
    init_diff4();
    init_drift4();
    init_list2();
    init_orphan();
    init_publish_assets2();
    init_refactor2();
    init_rollback2();
    init_synth2();
    init_watch2();
    init_diagnose();
    init_validate3();
  }
});

// ../@aws-cdk/toolkit-lib/lib/index.js
var require_lib12 = __commonJS({
  "../@aws-cdk/toolkit-lib/lib/index.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __exportStar3 = exports2 && exports2.__exportStar || function(m20, exports3) {
      for (var p10 in m20) if (p10 !== "default" && !Object.prototype.hasOwnProperty.call(exports3, p10)) __createBinding3(exports3, m20, p10);
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    require_dispose_polyfill();
    __exportStar3((init_toolkit2(), __toCommonJS(toolkit_exports)), exports2);
    __exportStar3((init_toolkit_error(), __toCommonJS(toolkit_error_exports)), exports2);
    __exportStar3((init_actions(), __toCommonJS(actions_exports)), exports2);
    __exportStar3((init_payloads(), __toCommonJS(payloads_exports)), exports2);
    __exportStar3((init_aws_auth(), __toCommonJS(aws_auth_exports)), exports2);
    __exportStar3((init_cloud_assembly3(), __toCommonJS(cloud_assembly_exports3)), exports2);
    __exportStar3((init_io(), __toCommonJS(io_exports)), exports2);
    __exportStar3((init_tags2(), __toCommonJS(tags_exports)), exports2);
    __exportStar3((init_plugin2(), __toCommonJS(plugin_exports)), exports2);
    __exportStar3((init_source_tracing2(), __toCommonJS(source_tracing_exports)), exports2);
  }
});

// lib/util.ts
var init_util9 = __esm({
  "lib/util.ts"() {
    "use strict";
    init_util3();
  }
});

// ../../node_modules/promptly/node_modules/mute-stream/mute.js
var require_mute = __commonJS({
  "../../node_modules/promptly/node_modules/mute-stream/mute.js"(exports2, module2) {
    var Stream = require("stream");
    module2.exports = MuteStream;
    function MuteStream(opts) {
      Stream.apply(this);
      opts = opts || {};
      this.writable = this.readable = true;
      this.muted = false;
      this.on("pipe", this._onpipe);
      this.replace = opts.replace;
      this._prompt = opts.prompt || null;
      this._hadControl = false;
    }
    __name(MuteStream, "MuteStream");
    MuteStream.prototype = Object.create(Stream.prototype);
    Object.defineProperty(MuteStream.prototype, "constructor", {
      value: MuteStream,
      enumerable: false
    });
    MuteStream.prototype.mute = function() {
      this.muted = true;
    };
    MuteStream.prototype.unmute = function() {
      this.muted = false;
    };
    Object.defineProperty(MuteStream.prototype, "_onpipe", {
      value: onPipe,
      enumerable: false,
      writable: true,
      configurable: true
    });
    function onPipe(src) {
      this._src = src;
    }
    __name(onPipe, "onPipe");
    Object.defineProperty(MuteStream.prototype, "isTTY", {
      get: getIsTTY,
      set: setIsTTY,
      enumerable: true,
      configurable: true
    });
    function getIsTTY() {
      return this._dest ? this._dest.isTTY : this._src ? this._src.isTTY : false;
    }
    __name(getIsTTY, "getIsTTY");
    function setIsTTY(isTTY2) {
      Object.defineProperty(this, "isTTY", {
        value: isTTY2,
        enumerable: true,
        writable: true,
        configurable: true
      });
    }
    __name(setIsTTY, "setIsTTY");
    Object.defineProperty(MuteStream.prototype, "rows", {
      get: /* @__PURE__ */ __name(function() {
        return this._dest ? this._dest.rows : this._src ? this._src.rows : void 0;
      }, "get"),
      enumerable: true,
      configurable: true
    });
    Object.defineProperty(MuteStream.prototype, "columns", {
      get: /* @__PURE__ */ __name(function() {
        return this._dest ? this._dest.columns : this._src ? this._src.columns : void 0;
      }, "get"),
      enumerable: true,
      configurable: true
    });
    MuteStream.prototype.pipe = function(dest, options) {
      this._dest = dest;
      return Stream.prototype.pipe.call(this, dest, options);
    };
    MuteStream.prototype.pause = function() {
      if (this._src) return this._src.pause();
    };
    MuteStream.prototype.resume = function() {
      if (this._src) return this._src.resume();
    };
    MuteStream.prototype.write = function(c32) {
      if (this.muted) {
        if (!this.replace) return true;
        if (c32.match(/^\u001b/)) {
          if (c32.indexOf(this._prompt) === 0) {
            c32 = c32.substr(this._prompt.length);
            c32 = c32.replace(/./g, this.replace);
            c32 = this._prompt + c32;
          }
          this._hadControl = true;
          return this.emit("data", c32);
        } else {
          if (this._prompt && this._hadControl && c32.indexOf(this._prompt) === 0) {
            this._hadControl = false;
            this.emit("data", this._prompt);
            c32 = c32.substr(this._prompt.length);
          }
          c32 = c32.toString().replace(/./g, this.replace);
        }
      }
      this.emit("data", c32);
    };
    MuteStream.prototype.end = function(c32) {
      if (this.muted) {
        if (c32 && this.replace) {
          c32 = c32.toString().replace(/./g, this.replace);
        } else {
          c32 = null;
        }
      }
      if (c32) this.emit("data", c32);
      this.emit("end");
    };
    function proxy(fn) {
      return function() {
        var d32 = this._dest;
        var s = this._src;
        if (d32 && d32[fn]) d32[fn].apply(d32, arguments);
        if (s && s[fn]) s[fn].apply(s, arguments);
      };
    }
    __name(proxy, "proxy");
    MuteStream.prototype.destroy = proxy("destroy");
    MuteStream.prototype.destroySoon = proxy("destroySoon");
    MuteStream.prototype.close = proxy("close");
  }
});

// ../../node_modules/promptly/node_modules/read/lib/read.js
var require_read = __commonJS({
  "../../node_modules/promptly/node_modules/read/lib/read.js"(exports2, module2) {
    module2.exports = read;
    var readline = require("readline");
    var Mute = require_mute();
    function read(opts, cb) {
      if (opts.num) {
        throw new Error("read() no longer accepts a char number limit");
      }
      if (typeof opts.default !== "undefined" && typeof opts.default !== "string" && typeof opts.default !== "number") {
        throw new Error("default value must be string or number");
      }
      var input = opts.input || process.stdin;
      var output = opts.output || process.stdout;
      var prompt2 = (opts.prompt || "").trim() + " ";
      var silent = opts.silent;
      var editDef = false;
      var timeout = opts.timeout;
      var def = opts.default || "";
      if (def) {
        if (silent) {
          prompt2 += "(<default hidden>) ";
        } else if (opts.edit) {
          editDef = true;
        } else {
          prompt2 += "(" + def + ") ";
        }
      }
      var terminal = !!(opts.terminal || output.isTTY);
      var m20 = new Mute({ replace: opts.replace, prompt: prompt2 });
      m20.pipe(output, { end: false });
      output = m20;
      var rlOpts = { input, output, terminal };
      if (process.version.match(/^v0\.6/)) {
        var rl = readline.createInterface(rlOpts.input, rlOpts.output);
      } else {
        var rl = readline.createInterface(rlOpts);
      }
      output.unmute();
      rl.setPrompt(prompt2);
      rl.prompt();
      if (silent) {
        output.mute();
      } else if (editDef) {
        rl.line = def;
        rl.cursor = def.length;
        rl._refreshLine();
      }
      var called = false;
      rl.on("line", onLine);
      rl.on("error", onError);
      rl.on("SIGINT", function() {
        rl.close();
        onError(new Error("canceled"));
      });
      var timer;
      if (timeout) {
        timer = setTimeout(function() {
          onError(new Error("timed out"));
        }, timeout);
      }
      function done() {
        called = true;
        rl.close();
        if (process.version.match(/^v0\.6/)) {
          rl.input.removeAllListeners("data");
          rl.input.removeAllListeners("keypress");
          rl.input.pause();
        }
        clearTimeout(timer);
        output.mute();
        output.end();
      }
      __name(done, "done");
      function onError(er) {
        if (called) return;
        done();
        return cb(er);
      }
      __name(onError, "onError");
      function onLine(line) {
        if (called) return;
        if (silent && terminal) {
          output.unmute();
          output.write("\r\n");
        }
        done();
        line = line.replace(/\r?\n$/, "");
        var isDefault = !!(editDef && line === def);
        if (def && !line) {
          isDefault = true;
          line = def;
        }
        cb(null, line, isDefault);
      }
      __name(onLine, "onLine");
    }
    __name(read, "read");
  }
});

// ../../node_modules/promptly/lib/prompt.js
var require_prompt = __commonJS({
  "../../node_modules/promptly/lib/prompt.js"(exports2, module2) {
    "use strict";
    var { EOL } = require("os");
    var { promisify: promisify4 } = require("util");
    var read = promisify4(require_read());
    async function prompt2(message2, options) {
      let value;
      try {
        value = await read({
          prompt: message2,
          silent: options.silent,
          replace: options.replace,
          input: options.input,
          output: options.output,
          timeout: options.timeout
        });
      } catch (err) {
        if (err.message !== "timed out" || options.default === void 0 || !options.useDefaultOnTimeout) {
          throw Object.assign(new Error(err.message), { code: "TIMEDOUT" });
        }
        value = options.default;
      }
      if (options.trim) {
        value = value.trim();
      }
      if (!value) {
        if (options.default === void 0) {
          return prompt2(message2, options);
        }
        value = options.default;
      }
      try {
        for (const i32 in options.validator) {
          value = await options.validator[i32](value);
        }
      } catch (err) {
        if (options.retry) {
          err.message && options.output.write(err.message + EOL);
          return prompt2(message2, options);
        }
        throw err;
      }
      return value;
    }
    __name(prompt2, "prompt");
    module2.exports = prompt2;
  }
});

// ../../node_modules/promptly/lib/getOptions.js
var require_getOptions = __commonJS({
  "../../node_modules/promptly/lib/getOptions.js"(exports2, module2) {
    "use strict";
    function getOptions(options) {
      options = {
        // Own options
        validator: void 0,
        retry: true,
        trim: true,
        default: void 0,
        useDefaultOnTimeout: false,
        // `read` package options
        silent: false,
        replace: "",
        input: process.stdin,
        output: process.stdout,
        timeout: 0,
        ...options
      };
      if (options.default !== void 0 && typeof options.default !== "string") {
        throw new Error("The default option value must be a string");
      }
      if (!Array.isArray(options.validator)) {
        options.validator = options.validator ? [options.validator] : [];
      }
      return options;
    }
    __name(getOptions, "getOptions");
    module2.exports = getOptions;
  }
});

// ../../node_modules/promptly/index.js
var require_promptly = __commonJS({
  "../../node_modules/promptly/index.js"(exports2, module2) {
    "use strict";
    var prompt2 = require_prompt();
    var getOptions = require_getOptions();
    var promptly2 = module2.exports;
    promptly2.prompt = (message2, options) => {
      options = getOptions(options);
      return prompt2(message2, options);
    };
    promptly2.password = (message2, options) => {
      options = getOptions({
        silent: true,
        // Hide password chars
        trim: false,
        // Do not trim so that spaces can be part of the password
        default: "",
        // Allow empty passwords
        ...options
      });
      return prompt2(message2, options);
    };
    promptly2.confirm = (message2, options) => {
      options = getOptions({
        trim: false,
        // Do not trim so that only exact matches pass the validator
        ...options
      });
      options.validator.unshift((value) => {
        value = value.toLowerCase();
        switch (value) {
          case "y":
          case "yes":
          case "1":
            return true;
          case "n":
          case "no":
          case "0":
            return false;
          default:
            throw new Error(`Invalid choice: ${value}`);
        }
      });
      return prompt2(message2, options);
    };
    promptly2.choose = (message2, choices, options) => {
      options = getOptions({
        trim: false,
        // Do not trim so that only exact matches pass the validator
        ...options
      });
      options.validator.unshift((value) => {
        const index = choices.findIndex((choice) => value == choice);
        if (index === -1) {
          throw new Error(`Invalid choice: ${value}`);
        }
        return choices[index];
      });
      return prompt2(message2, options);
    };
  }
});

// lib/api-private.ts
var init_api_private = __esm({
  "lib/api-private.ts"() {
    "use strict";
    init_deploy_stack();
    init_cfn_api();
    init_glob_matcher();
    init_private();
    init_private10();
    init_activity_printer();
    init_borrowed_assembly();
    init_count_assembly_results();
    init_validation_report();
  }
});

// lib/commands/deploy.ts
var init_deploy4 = __esm({
  "lib/commands/deploy.ts"() {
    "use strict";
  }
});

// lib/cli/telemetry/collect-telemetry.ts
function canCollectTelemetry(args, context) {
  if (["true", "1"].includes(process.env.CDK_DISABLE_CLI_TELEMETRY ?? "") || ["false", false].includes(context.get("cli-telemetry")) || args["version-reporting"] !== void 0 && !args["version-reporting"] || /* aliased with telemetry option */
  args._[0] === "cli-telemetry" && args.disable) {
    return false;
  }
  return true;
}
var init_collect_telemetry = __esm({
  "lib/cli/telemetry/collect-telemetry.ts"() {
    "use strict";
    __name(canCollectTelemetry, "canCollectTelemetry");
  }
});

// lib/cli/telemetry/error.ts
function cdkCliErrorName(err) {
  const spec = firstSpecificCause(err);
  if (spec) {
    return spec;
  }
  if (import_toolkit_lib.ToolkitError.isToolkitError(err)) {
    return err.name;
  }
  return UNKNOWN_ERROR_CODE;
}
function firstSpecificCause(error4) {
  const ret = specificErrorCode(error4);
  if (ret) {
    return ret;
  }
  if (error4.cause && error4.cause instanceof Error) {
    return firstSpecificCause(error4.cause);
  }
  return void 0;
}
function specificErrorCode(err) {
  if (import_smithy_client261.ServiceException.isInstance(err)) {
    return `sdk:${err.name}`;
  }
  if (import_toolkit_lib.ToolkitError.isDeploymentError(err)) {
    return `deploy:${err.deploymentErrorCode ?? import_toolkit_lib.DeploymentErrorCodes.UNKNOWN_ERROR}`;
  }
  if (import_toolkit_lib.ToolkitError.isAssemblyError(err) && err.synthErrorCode) {
    return `synth:${err.synthErrorCode}`;
  }
  const standardErrorNames = [import_toolkit_lib.ToolkitError.name, import_toolkit_lib.AuthenticationError.name, import_toolkit_lib.AssemblyError.name, import_toolkit_lib.ContextProviderError.name];
  if (import_toolkit_lib.ToolkitError.isToolkitError(err) && !standardErrorNames.includes(err.name)) {
    return err.name;
  }
  return void 0;
}
var import_toolkit_lib, import_smithy_client261, USER_INTERRUPTED_CODE, UNKNOWN_ERROR_CODE;
var init_error2 = __esm({
  "lib/cli/telemetry/error.ts"() {
    "use strict";
    import_toolkit_lib = __toESM(require_lib12());
    import_smithy_client261 = __toESM(require_dist_cjs34());
    USER_INTERRUPTED_CODE = "UserInterrupted";
    UNKNOWN_ERROR_CODE = "UnknownError";
    __name(cdkCliErrorName, "cdkCliErrorName");
    __name(firstSpecificCause, "firstSpecificCause");
    __name(specificErrorCode, "specificErrorCode");
  }
});

// lib/cli/telemetry/messages.ts
var CLI_PRIVATE_IO, CLI_PRIVATE_SPAN;
var init_messages2 = __esm({
  "lib/cli/telemetry/messages.ts"() {
    "use strict";
    init_api_private();
    CLI_PRIVATE_IO = {
      CDK_CLI_I1000: trace({
        code: "CDK_CLI_I1000",
        description: "Cloud Execution is starting",
        interface: "EventStart"
      }),
      CDK_CLI_I1001: trace({
        code: "CDK_CLI_I1001",
        description: "Cloud Executable Result",
        interface: "EventResult"
      }),
      CDK_CLI_I2000: trace({
        code: "CDK_CLI_I2000",
        description: "Command has started",
        interface: "EventStart"
      }),
      CDK_CLI_I2001: trace({
        code: "CDK_CLI_I2001",
        description: "Command has finished executing",
        interface: "EventResult"
      }),
      CDK_CLI_I3000: trace({
        code: "CDK_CLI_I3000",
        description: "Deploy has started",
        interface: "EventStart"
      }),
      CDK_CLI_I3001: trace({
        code: "CDK_CLI_I3001",
        description: "Deploy has finished",
        interface: "EventResult"
      }),
      CDK_CLI_I3002: trace({
        code: "CDK_CLI_I3002",
        description: "Start asset building and publishing",
        interface: "EventStart"
      }),
      CDK_CLI_I3003: trace({
        code: "CDK_CLI_I3003",
        description: "Finished asset building and publishing",
        interface: "EventResult"
      })
    };
    CLI_PRIVATE_SPAN = {
      SYNTH_ASSEMBLY: {
        name: "Synthesis",
        start: CLI_PRIVATE_IO.CDK_CLI_I1000,
        end: CLI_PRIVATE_IO.CDK_CLI_I1001
      },
      COMMAND: {
        name: "Command",
        start: CLI_PRIVATE_IO.CDK_CLI_I2000,
        end: CLI_PRIVATE_IO.CDK_CLI_I2001
      },
      DEPLOY: {
        name: "Deploy",
        start: CLI_PRIVATE_IO.CDK_CLI_I3000,
        end: CLI_PRIVATE_IO.CDK_CLI_I3001
      },
      ASSET: {
        name: "Asset",
        start: CLI_PRIVATE_IO.CDK_CLI_I3002,
        end: CLI_PRIVATE_IO.CDK_CLI_I3003
      }
    };
  }
});

// lib/cli/telemetry/installation-id.ts
async function getOrCreateInstallationId(ioHelper) {
  const installationIdPath = path35.join(cdkCacheDir(), "installation-id.json");
  try {
    if (fs36.existsSync(installationIdPath)) {
      const cachedId = fs36.readFileSync(installationIdPath, "utf-8").trim();
      const UUID_REGEX = /^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$/i;
      if (UUID_REGEX.test(cachedId)) {
        return cachedId;
      }
    }
    const newId = (0, import_node_crypto19.randomUUID)();
    try {
      await ensureCacheDir();
      fs36.writeFileSync(installationIdPath, newId);
    } catch (e32) {
      await ioHelper.defaults.trace(`Failed to write installation ID to ${installationIdPath}: ${e32}`);
    }
    return newId;
  } catch (e32) {
    await ioHelper.defaults.trace(`Error getting installation ID: ${e32}`);
    return (0, import_node_crypto19.randomUUID)();
  }
}
async function ensureCacheDir() {
  await fs36.promises.mkdir(cdkCacheDir(), { recursive: true });
}
var import_node_crypto19, fs36, path35;
var init_installation_id = __esm({
  "lib/cli/telemetry/installation-id.ts"() {
    "use strict";
    import_node_crypto19 = require("node:crypto");
    fs36 = __toESM(require("node:fs"));
    path35 = __toESM(require("node:path"));
    init_util9();
    __name(getOrCreateInstallationId, "getOrCreateInstallationId");
    __name(ensureCacheDir, "ensureCacheDir");
  }
});

// lib/cli/telemetry/library-version.ts
async function getLibraryVersion(ioHelper) {
  try {
    const command = `node -e 'process.stdout.write(require.resolve("aws-cdk-lib"))'`;
    const { stdout } = await (0, import_util68.promisify)(import_child_process.exec)(command);
    if (!fs37.existsSync(stdout)) {
      await ioHelper.defaults.trace('Could not get CDK Library Version: require.resolve("aws-cdk-lib") did not return a file path');
      return;
    }
    const pathToPackageJson = path36.join(path36.dirname(stdout), "package.json");
    const packageJson = fs37.readJSONSync(pathToPackageJson);
    if (!packageJson.version) {
      await ioHelper.defaults.trace("Could not get CDK Library Version: package.json does not have version field");
      return;
    }
    return packageJson.version;
  } catch (e32) {
    await ioHelper.defaults.trace(`Could not get CDK Library Version: ${e32}`);
    return;
  }
}
var import_child_process, path36, import_util68, fs37;
var init_library_version = __esm({
  "lib/cli/telemetry/library-version.ts"() {
    "use strict";
    import_child_process = require("child_process");
    path36 = __toESM(require("path"));
    import_util68 = require("util");
    fs37 = __toESM(require_lib4());
    __name(getLibraryVersion, "getLibraryVersion");
  }
});

// lib/cli/telemetry/feature-flags.ts
var FeatureFlag;
var init_feature_flags = __esm({
  "lib/cli/telemetry/feature-flags.ts"() {
    "use strict";
    FeatureFlag = /* @__PURE__ */ ((FeatureFlag2) => {
      FeatureFlag2["CORE_NEW_STYLE_STACK_SYNTHESIS"] = "@aws-cdk/core:newStyleStackSynthesis";
      FeatureFlag2["CORE_STACK_RELATIVE_EXPORTS"] = "@aws-cdk/core:stackRelativeExports";
      FeatureFlag2["RDS_LOWERCASE_DB_IDENTIFIER"] = "@aws-cdk/aws-rds:lowercaseDbIdentifier";
      FeatureFlag2["APIGATEWAY_USAGE_PLAN_KEY_ORDER_INSENSITIVE_ID"] = "@aws-cdk/aws-apigateway:usagePlanKeyOrderInsensitiveId";
      FeatureFlag2["LAMBDA_RECOGNIZE_VERSION_PROPS"] = "@aws-cdk/aws-lambda:recognizeVersionProps";
      FeatureFlag2["CLOUDFRONT_DEFAULT_SECURITY_POLICY_TLS_V1_2_2021"] = "@aws-cdk/aws-cloudfront:defaultSecurityPolicyTLSv1.2_2021";
      FeatureFlag2["CORE_TARGET_PARTITIONS"] = "@aws-cdk/core:target-partitions";
      FeatureFlag2["ECS_SERVICE_EXTENSIONS_ENABLE_DEFAULT_LOG_DRIVER"] = "@aws-cdk-containers/ecs-service-extensions:enableDefaultLogDriver";
      FeatureFlag2["EC2_UNIQUE_IMDSV2_TEMPLATE_NAME"] = "@aws-cdk/aws-ec2:uniqueImdsv2TemplateName";
      FeatureFlag2["IAM_MINIMIZE_POLICIES"] = "@aws-cdk/aws-iam:minimizePolicies";
      FeatureFlag2["CORE_CHECK_SECRET_USAGE"] = "@aws-cdk/core:checkSecretUsage";
      FeatureFlag2["LAMBDA_RECOGNIZE_LAYER_VERSION"] = "@aws-cdk/aws-lambda:recognizeLayerVersion";
      FeatureFlag2["CORE_VALIDATE_SNAPSHOT_REMOVAL_POLICY"] = "@aws-cdk/core:validateSnapshotRemovalPolicy";
      FeatureFlag2["CODEPIPELINE_CROSS_ACCOUNT_KEY_ALIAS_STACK_SAFE_RESOURCE_NAME"] = "@aws-cdk/aws-codepipeline:crossAccountKeyAliasStackSafeResourceName";
      FeatureFlag2["S3_CREATE_DEFAULT_LOGGING_POLICY"] = "@aws-cdk/aws-s3:createDefaultLoggingPolicy";
      FeatureFlag2["SNS_SUBSCRIPTIONS_RESTRICT_SQS_DECRYPTION"] = "@aws-cdk/aws-sns-subscriptions:restrictSqsDescryption";
      FeatureFlag2["ECS_ARN_FORMAT_INCLUDES_CLUSTER_NAME"] = "@aws-cdk/aws-ecs:arnFormatIncludesClusterName";
      FeatureFlag2["APIGATEWAY_DISABLE_CLOUD_WATCH_ROLE"] = "@aws-cdk/aws-apigateway:disableCloudWatchRole";
      FeatureFlag2["CORE_ENABLE_PARTITION_LITERALS"] = "@aws-cdk/core:enablePartitionLiterals";
      FeatureFlag2["ECS_DISABLE_EXPLICIT_DEPLOYMENT_CONTROLLER_FOR_CIRCUIT_BREAKER"] = "@aws-cdk/aws-ecs:disableExplicitDeploymentControllerForCircuitBreaker";
      FeatureFlag2["EVENTS_EVENTS_TARGET_QUEUE_SAME_ACCOUNT"] = "@aws-cdk/aws-events:eventsTargetQueueSameAccount";
      FeatureFlag2["IAM_IMPORTED_ROLE_STACK_SAFE_DEFAULT_POLICY_NAME"] = "@aws-cdk/aws-iam:importedRoleStackSafeDefaultPolicyName";
      FeatureFlag2["S3_SERVER_ACCESS_LOGS_USE_BUCKET_POLICY"] = "@aws-cdk/aws-s3:serverAccessLogsUseBucketPolicy";
      FeatureFlag2["CUSTOMRESOURCES_INSTALL_LATEST_AWS_SDK_DEFAULT"] = "@aws-cdk/customresources:installLatestAwsSdkDefault";
      FeatureFlag2["ROUTE53_PATTERNS_USE_CERTIFICATE"] = "@aws-cdk/aws-route53-patterns:useCertificate";
      FeatureFlag2["CODEDEPLOY_REMOVE_ALARMS_FROM_DEPLOYMENT_GROUP"] = "@aws-cdk/aws-codedeploy:removeAlarmsFromDeploymentGroup";
      FeatureFlag2["RDS_DATABASE_PROXY_UNIQUE_RESOURCE_NAME"] = "@aws-cdk/aws-rds:databaseProxyUniqueResourceName";
      FeatureFlag2["APIGATEWAY_AUTHORIZER_CHANGE_DEPLOYMENT_LOGICAL_ID"] = "@aws-cdk/aws-apigateway:authorizerChangeDeploymentLogicalId";
      FeatureFlag2["EC2_LAUNCH_TEMPLATE_DEFAULT_USER_DATA"] = "@aws-cdk/aws-ec2:launchTemplateDefaultUserData";
      FeatureFlag2["SECRETSMANAGER_USE_ATTACHED_SECRET_RESOURCE_POLICY_FOR_SECRET_TARGET_ATTACHMENTS"] = "@aws-cdk/aws-secretsmanager:useAttachedSecretResourcePolicyForSecretTargetAttachments";
      FeatureFlag2["REDSHIFT_COLUMN_ID"] = "@aws-cdk/aws-redshift:columnId";
      FeatureFlag2["STEPFUNCTIONS_TASKS_ENABLE_EMR_SERVICE_POLICY_V2"] = "@aws-cdk/aws-stepfunctions-tasks:enableEmrServicePolicyV2";
      FeatureFlag2["APIGATEWAY_REQUEST_VALIDATOR_UNIQUE_ID"] = "@aws-cdk/aws-apigateway:requestValidatorUniqueId";
      FeatureFlag2["EC2_RESTRICT_DEFAULT_SECURITY_GROUP"] = "@aws-cdk/aws-ec2:restrictDefaultSecurityGroup";
      FeatureFlag2["KMS_ALIAS_NAME_REF"] = "@aws-cdk/aws-kms:aliasNameRef";
      FeatureFlag2["CORE_INCLUDE_PREFIX_IN_UNIQUE_NAME_GENERATION"] = "@aws-cdk/core:includePrefixInUniqueNameGeneration";
      FeatureFlag2["AUTOSCALING_GENERATE_LAUNCH_TEMPLATE_INSTEAD_OF_LAUNCH_CONFIG"] = "@aws-cdk/aws-autoscaling:generateLaunchTemplateInsteadOfLaunchConfig";
      FeatureFlag2["OPENSEARCHSERVICE_ENABLE_OPENSEARCH_MULTI_AZ_WITH_STANDBY"] = "@aws-cdk/aws-opensearchservice:enableOpensearchMultiAzWithStandby";
      FeatureFlag2["EFS_DENY_ANONYMOUS_ACCESS"] = "@aws-cdk/aws-efs:denyAnonymousAccess";
      FeatureFlag2["EFS_MOUNT_TARGET_ORDER_INSENSITIVE_LOGICAL_ID"] = "@aws-cdk/aws-efs:mountTargetOrderInsensitiveLogicalId";
      FeatureFlag2["LAMBDA_NODEJS_USE_LATEST_RUNTIME_VERSION"] = "@aws-cdk/aws-lambda-nodejs:useLatestRuntimeVersion";
      FeatureFlag2["APPSYNC_USE_ARN_FOR_SOURCE_API_ASSOCIATION_IDENTIFIER"] = "@aws-cdk/aws-appsync:useArnForSourceApiAssociationIdentifier";
      FeatureFlag2["RDS_AURORA_CLUSTER_CHANGE_SCOPE_OF_INSTANCE_PARAMETER_GROUP_WITH_EACH_PARAMETERS"] = "@aws-cdk/aws-rds:auroraClusterChangeScopeOfInstanceParameterGroupWithEachParameters";
      FeatureFlag2["RDS_PREVENT_RENDERING_DEPRECATED_CREDENTIALS"] = "@aws-cdk/aws-rds:preventRenderingDeprecatedCredentials";
      FeatureFlag2["CODEPIPELINE_ACTIONS_USE_NEW_DEFAULT_BRANCH_FOR_CODE_COMMIT_SOURCE"] = "@aws-cdk/aws-codepipeline-actions:useNewDefaultBranchForCodeCommitSource";
      FeatureFlag2["CLOUDWATCH_ACTIONS_CHANGE_LAMBDA_PERMISSION_LOGICAL_ID_FOR_LAMBDA_ACTION"] = "@aws-cdk/aws-cloudwatch-actions:changeLambdaPermissionLogicalIdForLambdaAction";
      FeatureFlag2["CODEPIPELINE_CROSS_ACCOUNT_KEYS_DEFAULT_VALUE_TO_FALSE"] = "@aws-cdk/aws-codepipeline:crossAccountKeysDefaultValueToFalse";
      FeatureFlag2["CODEPIPELINE_DEFAULT_PIPELINE_TYPE_TO_V2"] = "@aws-cdk/aws-codepipeline:defaultPipelineTypeToV2";
      FeatureFlag2["KMS_REDUCE_CROSS_ACCOUNT_REGION_POLICY_SCOPE"] = "@aws-cdk/aws-kms:reduceCrossAccountRegionPolicyScope";
      FeatureFlag2["EKS_NODEGROUP_NAME_ATTRIBUTE"] = "@aws-cdk/aws-eks:nodegroupNameAttribute";
      FeatureFlag2["EC2_EBS_DEFAULT_GP3_VOLUME"] = "@aws-cdk/aws-ec2:ebsDefaultGp3Volume";
      FeatureFlag2["PIPELINES_REDUCE_ASSET_ROLE_TRUST_SCOPE"] = "@aws-cdk/pipelines:reduceAssetRoleTrustScope";
      FeatureFlag2["ECS_REMOVE_DEFAULT_DEPLOYMENT_ALARM"] = "@aws-cdk/aws-ecs:removeDefaultDeploymentAlarm";
      FeatureFlag2["CUSTOM_RESOURCES_LOG_API_RESPONSE_DATA_PROPERTY_TRUE_DEFAULT"] = "@aws-cdk/custom-resources:logApiResponseDataPropertyTrueDefault";
      FeatureFlag2["S3_KEEP_NOTIFICATION_IN_IMPORTED_BUCKET"] = "@aws-cdk/aws-s3:keepNotificationInImportedBucket";
      FeatureFlag2["STEPFUNCTIONS_TASKS_USE_NEW_S3_URI_PARAMETERS_FOR_BEDROCK_INVOKE_MODEL_TASK"] = "@aws-cdk/aws-stepfunctions-tasks:useNewS3UriParametersForBedrockInvokeModelTask";
      FeatureFlag2["ECS_REDUCE_EC2_FARGATE_CLOUD_WATCH_PERMISSIONS"] = "@aws-cdk/aws-ecs:reduceEc2FargateCloudWatchPermissions";
      FeatureFlag2["EC2_EC2_SUM_TIMEOUT_ENABLED"] = "@aws-cdk/aws-ec2:ec2SumTimeoutEnabled";
      FeatureFlag2["APPSYNC_APP_SYNC_GRAPHQL_API_SCOPE_LAMBDA_PERMISSION"] = "@aws-cdk/aws-appsync:appSyncGraphQLAPIScopeLambdaPermission";
      FeatureFlag2["LAMBDA_NODEJS_SDK_V3_EXCLUDE_SMITHY_PACKAGES"] = "@aws-cdk/aws-lambda-nodejs:sdkV3ExcludeSmithyPackages";
      FeatureFlag2["RDS_SET_CORRECT_VALUE_FOR_DATABASE_INSTANCE_READ_REPLICA_INSTANCE_RESOURCE_ID"] = "@aws-cdk/aws-rds:setCorrectValueForDatabaseInstanceReadReplicaInstanceResourceId";
      FeatureFlag2["CORE_CFN_INCLUDE_REJECT_COMPLEX_RESOURCE_UPDATE_CREATE_POLICY_INTRINSICS"] = "@aws-cdk/core:cfnIncludeRejectComplexResourceUpdateCreatePolicyIntrinsics";
      FeatureFlag2["STEPFUNCTIONS_TASKS_FIX_RUN_ECS_TASK_POLICY"] = "@aws-cdk/aws-stepfunctions-tasks:fixRunEcsTaskPolicy";
      FeatureFlag2["DYNAMODB_RESOURCE_POLICY_PER_REPLICA"] = "@aws-cdk/aws-dynamodb:resourcePolicyPerReplica";
      FeatureFlag2["EC2_BASTION_HOST_USE_AMAZON_LINUX_2023_BY_DEFAULT"] = "@aws-cdk/aws-ec2:bastionHostUseAmazonLinux2023ByDefault";
      FeatureFlag2["CORE_ASPECT_STABILIZATION"] = "@aws-cdk/core:aspectStabilization";
      FeatureFlag2["ROUTE53_TARGETS_USER_POOL_DOMAIN_NAME_METHOD_WITHOUT_CUSTOM_RESOURCE"] = "@aws-cdk/aws-route53-targets:userPoolDomainNameMethodWithoutCustomResource";
      FeatureFlag2["ECS_DISABLE_ECS_IMDS_BLOCKING"] = "@aws-cdk/aws-ecs:disableEcsImdsBlocking";
      FeatureFlag2["ECS_ENABLE_IMDS_BLOCKING_DEPRECATED_FEATURE"] = "@aws-cdk/aws-ecs:enableImdsBlockingDeprecatedFeature";
      FeatureFlag2["ELASTICLOADBALANCINGV2_ALB_DUALSTACK_WITHOUT_PUBLIC_IPV4_SECURITY_GROUP_RULES_DEFAULT"] = "@aws-cdk/aws-elasticloadbalancingV2:albDualstackWithoutPublicIpv4SecurityGroupRulesDefault";
      FeatureFlag2["IAM_OIDC_REJECT_UNAUTHORIZED_CONNECTIONS"] = "@aws-cdk/aws-iam:oidcRejectUnauthorizedConnections";
      FeatureFlag2["CORE_ENABLE_ADDITIONAL_METADATA_COLLECTION"] = "@aws-cdk/core:enableAdditionalMetadataCollection";
      FeatureFlag2["LAMBDA_CREATE_NEW_POLICIES_WITH_ADD_TO_ROLE_POLICY"] = "@aws-cdk/aws-lambda:createNewPoliciesWithAddToRolePolicy";
      FeatureFlag2["S3_SET_UNIQUE_REPLICATION_ROLE_NAME"] = "@aws-cdk/aws-s3:setUniqueReplicationRoleName";
      FeatureFlag2["PIPELINES_REDUCE_STAGE_ROLE_TRUST_SCOPE"] = "@aws-cdk/pipelines:reduceStageRoleTrustScope";
      FeatureFlag2["EVENTS_REQUIRE_EVENT_BUS_POLICY_SID"] = "@aws-cdk/aws-events:requireEventBusPolicySid";
      FeatureFlag2["DYNAMODB_RETAIN_TABLE_REPLICA"] = "@aws-cdk/aws-dynamodb:retainTableReplica";
      FeatureFlag2["COGNITO_LOG_USER_POOL_CLIENT_SECRET_VALUE"] = "@aws-cdk/cognito:logUserPoolClientSecretValue";
      FeatureFlag2["STEPFUNCTIONS_USE_DISTRIBUTED_MAP_RESULT_WRITER_V2"] = "@aws-cdk/aws-stepfunctions:useDistributedMapResultWriterV2";
      FeatureFlag2["PIPELINES_REDUCE_CROSS_ACCOUNT_ACTION_ROLE_TRUST_SCOPE"] = "@aws-cdk/pipelines:reduceCrossAccountActionRoleTrustScope";
      FeatureFlag2["CORE_ASPECT_PRIORITIES_MUTATING"] = "@aws-cdk/core:aspectPrioritiesMutating";
      FeatureFlag2["S3_NOTIFICATIONS_ADD_S3_TRUST_KEY_POLICY_FOR_SNS_SUBSCRIPTIONS"] = "@aws-cdk/s3-notifications:addS3TrustKeyPolicyForSnsSubscriptions";
      FeatureFlag2["EC2_ALPHA_USE_RESOURCE_ID_FOR_VPC_V2_MIGRATION"] = "@aws-cdk/aws-ec2-alpha:useResourceIdForVpcV2Migration";
      FeatureFlag2["EC2_REQUIRE_PRIVATE_SUBNETS_FOR_EGRESS_ONLY_INTERNET_GATEWAY"] = "@aws-cdk/aws-ec2:requirePrivateSubnetsForEgressOnlyInternetGateway";
      FeatureFlag2["S3_PUBLIC_ACCESS_BLOCKED_BY_DEFAULT"] = "@aws-cdk/aws-s3:publicAccessBlockedByDefault";
      FeatureFlag2["LAMBDA_USE_CDK_MANAGED_LOG_GROUP"] = "@aws-cdk/aws-lambda:useCdkManagedLogGroup";
      FeatureFlag2["KMS_APPLY_IMPORTED_ALIAS_PERMISSIONS_TO_PRINCIPAL"] = "@aws-cdk/aws-kms:applyImportedAliasPermissionsToPrincipal";
      FeatureFlag2["CORE_EXPLICIT_STACK_TAGS"] = "@aws-cdk/core:explicitStackTags";
      return FeatureFlag2;
    })(FeatureFlag || {});
  }
});

// lib/cli/cli-type-registry.json
var require_cli_type_registry = __commonJS({
  "lib/cli/cli-type-registry.json"(exports2, module2) {
    module2.exports = {
      globalOptions: {
        app: {
          type: "string",
          alias: "a",
          desc: 'REQUIRED WHEN RUNNING APP: command-line for executing your app or a cloud assembly directory (e.g. "node bin/my-app.js"). Can also be specified in cdk.json or ~/.cdk.json',
          requiresArg: true
        },
        build: {
          type: "string",
          desc: "Command-line for a pre-synth build"
        },
        context: {
          type: "array",
          alias: "c",
          desc: "Add contextual string parameter (KEY=VALUE)"
        },
        plugin: {
          type: "array",
          alias: "p",
          desc: "Name or path of a node package that extend the CDK features. Can be specified multiple times"
        },
        trace: {
          type: "boolean",
          desc: "Print trace for stack warnings"
        },
        strict: {
          type: "boolean",
          desc: "Do not construct stacks with warnings"
        },
        lookups: {
          type: "boolean",
          desc: "Perform context lookups (synthesis fails if this is disabled and context lookups need to be performed)",
          default: true
        },
        "ignore-errors": {
          type: "boolean",
          default: false,
          desc: "Ignores synthesis errors, which will likely produce an invalid output"
        },
        json: {
          type: "boolean",
          alias: "j",
          desc: "Use JSON output instead of YAML when templates are printed to STDOUT",
          default: false
        },
        verbose: {
          type: "boolean",
          alias: "v",
          desc: "Show debug logs (specify multiple times to increase verbosity)",
          default: false,
          count: true
        },
        debug: {
          type: "boolean",
          default: false,
          implies: [
            "debug-app",
            "debug-cli"
          ],
          desc: "Produce more detailed output to help diagnose unexpected behavior for the CDK app and CDK CLI. Note that this will significantly slow down synthesis time."
        },
        "debug-app": {
          type: "boolean",
          default: false,
          desc: "Debug the CDK app. Logs additional information during synthesis, such as creation stack traces and sets the CDK_DEBUG environment variable. Will slow down synthesis."
        },
        "debug-cli": {
          type: "boolean",
          default: false,
          desc: "Debug the CDK CLI itself."
        },
        profile: {
          type: "string",
          desc: "Use the indicated AWS profile as the default environment",
          requiresArg: true
        },
        region: {
          type: "string",
          desc: "Use the indicated AWS region as the default region",
          requiresArg: true
        },
        proxy: {
          type: "string",
          desc: "Use the indicated proxy. Will read from HTTPS_PROXY environment variable if not specified",
          requiresArg: true
        },
        "ca-bundle-path": {
          type: "string",
          desc: "Path to CA certificate to use when validating HTTPS requests. Will read from AWS_CA_BUNDLE environment variable if not specified",
          requiresArg: true
        },
        ec2creds: {
          type: "boolean",
          alias: "i",
          desc: "Force trying to fetch EC2 instance credentials. Default: guess EC2 instance status"
        },
        "version-reporting": {
          type: "boolean",
          desc: 'Disable CLI telemetry and do not include the "AWS::CDK::Metadata" resource in synthesized templates (enabled by default)',
          alias: "telemetry"
        },
        "path-metadata": {
          type: "boolean",
          desc: 'Include "aws:cdk:path" CloudFormation metadata for each resource (enabled by default)'
        },
        "asset-metadata": {
          type: "boolean",
          desc: 'Include "aws:asset:*" CloudFormation metadata for resources that uses assets (enabled by default)'
        },
        "role-arn": {
          type: "string",
          alias: "r",
          desc: "ARN of Role to use when invoking CloudFormation",
          requiresArg: true
        },
        staging: {
          type: "boolean",
          desc: "Copy assets to the output directory (use --no-staging to disable the copy of assets which allows local debugging via the SAM CLI to reference the original source files)",
          default: true
        },
        output: {
          type: "string",
          alias: "o",
          desc: "Emits the synthesized cloud assembly into a directory (default: cdk.out)",
          requiresArg: true
        },
        notices: {
          type: "boolean",
          desc: "Show relevant notices"
        },
        "no-color": {
          type: "boolean",
          desc: "Removes colors and other style from console output",
          default: false
        },
        color: {
          type: "boolean",
          desc: "Force colored output even when stdout is not a TTY"
        },
        ci: {
          type: "boolean",
          desc: "Force CI detection. If CI=true then logs will be sent to stdout instead of stderr"
        },
        unstable: {
          type: "array",
          desc: "Opt in to unstable features. The flag indicates that the scope and API of a feature might still change. Otherwise the feature is generally production ready and fully supported. Can be specified multiple times.",
          default: []
        },
        "telemetry-file": {
          type: "string",
          desc: "Send telemetry data to a local file."
        },
        yes: {
          type: "boolean",
          alias: "y",
          desc: "Automatically answer interactive prompts with the recommended response. This includes confirming actions.",
          default: false
        }
      },
      commands: {
        list: {
          arg: {
            name: "STACKS",
            variadic: true
          },
          aliases: [
            "ls"
          ],
          description: "Lists all stacks in the app",
          options: {
            long: {
              type: "boolean",
              default: false,
              alias: "l",
              desc: "Display environment information for each stack"
            },
            "show-dependencies": {
              type: "boolean",
              default: false,
              alias: "d",
              desc: "Display stack dependency information for each stack"
            }
          }
        },
        synth: {
          arg: {
            name: "STACKS",
            variadic: true
          },
          aliases: [
            "synthesize"
          ],
          description: "Synthesizes and prints the CloudFormation template for this stack",
          options: {
            exclusively: {
              type: "boolean",
              alias: "e",
              desc: "Only synthesize requested stacks, don't include dependencies"
            },
            validation: {
              type: "boolean",
              desc: 'After synthesis, validate stacks with the "validateOnSynth" attribute set (can also be controlled with CDK_VALIDATION)',
              default: true
            },
            quiet: {
              type: "boolean",
              alias: "q",
              desc: "Do not output CloudFormation Template to stdout",
              default: false
            }
          }
        },
        bootstrap: {
          arg: {
            name: "ENVIRONMENTS",
            variadic: true
          },
          description: "Deploys the CDK toolkit stack into an AWS environment",
          options: {
            "bootstrap-bucket-name": {
              type: "string",
              alias: [
                "b",
                "toolkit-bucket-name"
              ],
              desc: "The name of the CDK toolkit bucket; bucket will be created and must not exist"
            },
            "bootstrap-kms-key-id": {
              type: "string",
              desc: "AWS KMS master key ID used for the SSE-KMS encryption (specify AWS_MANAGED_KEY to use an AWS-managed key)",
              conflicts: "bootstrap-customer-key"
            },
            "example-permissions-boundary": {
              type: "boolean",
              alias: "epb",
              desc: "Use the example permissions boundary.",
              conflicts: "custom-permissions-boundary"
            },
            "custom-permissions-boundary": {
              type: "string",
              alias: "cpb",
              desc: "Use the permissions boundary specified by name.",
              conflicts: "example-permissions-boundary"
            },
            "bootstrap-customer-key": {
              type: "boolean",
              desc: "Create a Customer Master Key (CMK) for the bootstrap bucket (you will be charged but can customize permissions, modern bootstrapping only)",
              conflicts: "bootstrap-kms-key-id"
            },
            qualifier: {
              type: "string",
              desc: "String which must be unique for each bootstrap stack. You must configure it on your CDK app if you change this from the default."
            },
            "public-access-block-configuration": {
              type: "boolean",
              desc: "Block public access configuration on CDK toolkit bucket (enabled by default) "
            },
            "deny-external-id": {
              type: "boolean",
              desc: "Block AssumeRole access to all boostrapped roles if an ExternalId is provided (enabled by default) "
            },
            tags: {
              type: "array",
              alias: "t",
              desc: "Tags to add for the stack (KEY=VALUE)",
              default: []
            },
            execute: {
              type: "boolean",
              desc: "Whether to execute the change set (--no-execute will NOT execute the change set)",
              default: true
            },
            trust: {
              type: "array",
              desc: "The AWS account IDs that should be trusted to perform deployments into this environment (may be repeated, modern bootstrapping only)",
              default: []
            },
            "trust-for-lookup": {
              type: "array",
              desc: "The AWS account IDs that should be trusted to look up values in this environment (may be repeated, modern bootstrapping only)",
              default: []
            },
            untrust: {
              type: "array",
              desc: "The AWS account IDs that should not be trusted by this environment (may be repeated, modern bootstrapping only)",
              default: []
            },
            "cloudformation-execution-policies": {
              type: "array",
              desc: "The Managed Policy ARNs that should be attached to the role performing deployments into this environment (may be repeated, modern bootstrapping only)",
              default: []
            },
            force: {
              alias: "f",
              type: "boolean",
              desc: "Always bootstrap even if it would downgrade template version",
              default: false
            },
            "termination-protection": {
              type: "boolean",
              desc: "Toggle CloudFormation termination protection on the bootstrap stacks"
            },
            "show-template": {
              type: "boolean",
              desc: "Instead of actual bootstrapping, print the current CLI's bootstrapping template to stdout for customization",
              default: false
            },
            "toolkit-stack-name": {
              type: "string",
              desc: "The name of the CDK toolkit stack to create",
              requiresArg: true
            },
            template: {
              type: "string",
              requiresArg: true,
              desc: "Use the template from the given file instead of the built-in one (use --show-template to obtain an example)"
            },
            "previous-parameters": {
              type: "boolean",
              default: true,
              desc: "Use previous values for existing parameters (you must specify all parameters on every deployment if this is disabled)"
            },
            "import-existing-resources": {
              type: "boolean",
              desc: "Whether to import existing resources into the bootstrap stack instead of failing if they already exist",
              default: true
            }
          }
        },
        gc: {
          description: "Garbage collect assets. Options detailed here: https://github.com/aws/aws-cdk-cli/tree/main/packages/aws-cdk#cdk-gc",
          arg: {
            name: "ENVIRONMENTS",
            variadic: true
          },
          options: {
            action: {
              type: "string",
              desc: 'The action (or sub-action) you want to perform. Valid entires are "print", "tag", "delete-tagged", "full".',
              default: "full"
            },
            type: {
              type: "string",
              desc: "Specify either ecr, s3, or all",
              default: "all"
            },
            "rollback-buffer-days": {
              type: "number",
              desc: "Delete assets that have been marked as isolated for this many days",
              default: 0
            },
            "created-buffer-days": {
              type: "number",
              desc: "Never delete assets younger than this (in days)",
              default: 1
            },
            confirm: {
              type: "boolean",
              desc: "Confirm via manual prompt before deletion",
              default: true
            },
            "toolkit-stack-name": {
              type: "string",
              desc: 'The name of the CDK toolkit stack, if different from the default "CDKToolkit"',
              requiresArg: true,
              conflicts: "bootstrap-stack-name"
            },
            "bootstrap-stack-name": {
              type: "string",
              desc: 'The name of the CDK toolkit stack, if different from the default "CDKToolkit" (deprecated, use --toolkit-stack-name)',
              deprecated: "use --toolkit-stack-name",
              requiresArg: true,
              conflicts: "toolkit-stack-name"
            }
          }
        },
        flags: {
          description: "View and toggle feature flags.",
          arg: {
            name: "FLAGNAME",
            variadic: true
          },
          options: {
            value: {
              type: "string",
              desc: "The value the user would like to set the feature flag configuration to",
              requiresArg: true
            },
            set: {
              type: "boolean",
              desc: "Signifies the user would like to modify their feature flag configuration",
              requiresArg: false
            },
            all: {
              type: "boolean",
              desc: "Modify or view all feature flags",
              requiresArg: false
            },
            unconfigured: {
              type: "boolean",
              desc: "Modify unconfigured feature flags",
              requiresArg: false
            },
            recommended: {
              type: "boolean",
              desc: "Change flags to recommended states",
              requiresArg: false
            },
            default: {
              type: "boolean",
              desc: "Change flags to default state",
              requiresArg: false
            },
            interactive: {
              type: "boolean",
              alias: [
                "i"
              ],
              desc: "Interactive option for the flags command"
            },
            safe: {
              type: "boolean",
              desc: "Enable all feature flags that do not impact the user's application",
              requiresArg: false
            },
            concurrency: {
              type: "number",
              alias: [
                "n"
              ],
              desc: "Maximum number of simultaneous synths to execute.",
              default: 4,
              requiresArg: true
            }
          }
        },
        deploy: {
          description: "Deploys the stack(s) named STACKS into your AWS account",
          options: {
            all: {
              type: "boolean",
              desc: "Deploy all available stacks",
              default: false
            },
            "build-exclude": {
              type: "array",
              alias: "E",
              desc: "Do not rebuild asset with the given ID. Can be specified multiple times",
              default: []
            },
            exclusively: {
              type: "boolean",
              alias: "e",
              desc: "Only deploy requested stacks, don't include dependencies"
            },
            "require-approval": {
              type: "string",
              choices: [
                "never",
                "any-change",
                "broadening"
              ],
              desc: "What changes require manual approval"
            },
            "notification-arns": {
              type: "array",
              desc: "ARNs of SNS topics that CloudFormation will notify with stack related events. These will be added to ARNs specified with the 'notificationArns' stack property."
            },
            tags: {
              type: "array",
              alias: "t",
              desc: "Tags to add to the stack (KEY=VALUE), overrides tags from Cloud Assembly (deprecated)"
            },
            execute: {
              type: "boolean",
              desc: "Whether to execute the change set (--no-execute will NOT execute the change set) (deprecated)",
              deprecated: true
            },
            "change-set-name": {
              type: "string",
              desc: "Name of the CloudFormation change set to create (only if method is not direct)"
            },
            method: {
              alias: "m",
              type: "string",
              choices: [
                "direct",
                "change-set",
                "prepare-change-set",
                "execute-change-set"
              ],
              requiresArg: true,
              desc: 'How to perform the deployment. "change-set" (default) creates and executes a change set. "prepare-change-set" creates a change set without executing it. "execute-change-set" executes a previously created change set, bypassing synthesis entirely. "direct" skips change sets for faster deployments but lacks progress information'
            },
            "import-existing-resources": {
              type: "boolean",
              desc: "Indicates if the stack set imports resources that already exist.",
              default: false
            },
            force: {
              alias: "f",
              type: "boolean",
              desc: "Always deploy stack even if templates are identical",
              default: false
            },
            parameters: {
              type: "array",
              desc: "Additional parameters passed to CloudFormation at deploy time (STACK:KEY=VALUE)",
              default: {}
            },
            "outputs-file": {
              type: "string",
              alias: "O",
              desc: "Path to file where stack outputs will be written as JSON",
              requiresArg: true
            },
            "previous-parameters": {
              type: "boolean",
              default: true,
              desc: "Use previous values for existing parameters (you must specify all parameters on every deployment if this is disabled)"
            },
            "toolkit-stack-name": {
              type: "string",
              desc: "The name of the existing CDK toolkit stack (only used for app using legacy synthesis)",
              requiresArg: true
            },
            progress: {
              type: "string",
              choices: [
                "bar",
                "events"
              ],
              desc: "Display mode for stack activity events"
            },
            rollback: {
              type: "boolean",
              desc: "Rollback stack to stable state on failure. Defaults to 'true', iterate more rapidly with --no-rollback or -R. Note: do **not** disable this flag for deployments with resource replacements, as that will always fail",
              negativeAlias: "R"
            },
            hotswap: {
              type: "boolean",
              desc: "Attempts to perform a 'hotswap' deployment, but does not fall back to a full deployment if that is not possible. Instead, changes to any non-hotswappable properties are ignored.Do not use this in production environments"
            },
            "hotswap-fallback": {
              type: "boolean",
              desc: "Attempts to perform a 'hotswap' deployment, which skips CloudFormation and updates the resources directly, and falls back to a full deployment if that is not possible. Do not use this in production environments"
            },
            "hotswap-ecs-minimum-healthy-percent": {
              type: "number",
              desc: "Lower limit on the number of your service's tasks that must remain in the RUNNING state during a deployment, as a percentage of the desiredCount"
            },
            "hotswap-ecs-maximum-healthy-percent": {
              type: "number",
              desc: "Upper limit on the number of your service's tasks that are allowed in the RUNNING or PENDING state during a deployment, as a percentage of the desiredCount"
            },
            "hotswap-ecs-stabilization-timeout-seconds": {
              type: "number",
              desc: "Number of seconds to wait for a single service to reach stable state, where the desiredCount is equal to the runningCount"
            },
            watch: {
              type: "boolean",
              desc: "Continuously observe the project files, and deploy the given stack(s) automatically when changes are detected. Implies --hotswap by default"
            },
            logs: {
              type: "boolean",
              default: true,
              desc: "Show CloudWatch log events from all resources in the selected Stacks in the terminal. 'true' by default, use --no-logs to turn off. Only in effect if specified alongside the '--watch' option"
            },
            concurrency: {
              type: "number",
              desc: "Maximum number of simultaneous deployments (dependency permitting) to execute.",
              default: 1,
              requiresArg: true
            },
            "asset-parallelism": {
              type: "boolean",
              desc: "Whether to build/publish assets in parallel"
            },
            "asset-build-concurrency": {
              type: "number",
              desc: "Maximum number of asset builds to run in parallel",
              default: 1,
              requiresArg: true
            },
            "asset-prebuild": {
              type: "boolean",
              desc: "Whether to build all assets before deploying the first stack (useful for failing Docker builds)",
              default: true
            },
            "ignore-no-stacks": {
              type: "boolean",
              desc: "Whether to deploy if the app contains no stacks",
              default: false
            },
            "revert-drift": {
              type: "boolean",
              desc: "Create a drift-aware change set that brings actual resource states in line with template definitions",
              default: false
            }
          },
          arg: {
            name: "STACKS",
            variadic: true
          }
        },
        validate: {
          description: "Validate synthesized CloudFormation templates against policy rules",
          options: {
            online: {
              type: "boolean",
              desc: "Submit templates to CloudFormation for early validation (requires AWS credentials)",
              default: true
            }
          },
          arg: {
            name: "STACKS",
            variadic: true
          }
        },
        diagnose: {
          description: "Find the root cause(s) of stack deployment failures",
          options: {
            "toolkit-stack-name": {
              type: "string",
              desc: "The name of the existing CDK toolkit stack (only used for app using legacy synthesis)",
              requiresArg: true
            },
            concurrency: {
              type: "number",
              desc: "How many stacks to diagnose in parallel",
              requiresArg: true
            }
          },
          arg: {
            name: "STACKS",
            variadic: true
          }
        },
        rollback: {
          description: "Rolls back the stack(s) named STACKS to their last stable state",
          arg: {
            name: "STACKS",
            variadic: true
          },
          options: {
            all: {
              type: "boolean",
              default: false,
              desc: "Roll back all available stacks"
            },
            "toolkit-stack-name": {
              type: "string",
              desc: "The name of the CDK toolkit stack the environment is bootstrapped with",
              requiresArg: true
            },
            force: {
              alias: "f",
              type: "boolean",
              desc: "Orphan all resources for which the rollback operation fails."
            },
            "validate-bootstrap-version": {
              type: "boolean",
              desc: "Whether to validate the bootstrap stack version. Defaults to 'true', disable with --no-validate-bootstrap-version."
            },
            orphan: {
              type: "array",
              desc: "Orphan the given resources, identified by their logical ID (can be specified multiple times)",
              default: []
            }
          }
        },
        "publish-assets": {
          description: "Publish assets for the given stack(s) without deploying",
          arg: {
            name: "STACKS",
            variadic: true
          },
          options: {
            all: {
              type: "boolean",
              desc: "Publish assets for all available stacks",
              default: false
            },
            exclusively: {
              type: "boolean",
              alias: "e",
              desc: "Only publish assets for requested stacks, don't include dependencies"
            },
            force: {
              type: "boolean",
              alias: "f",
              desc: "Always publish assets, even if they are already published",
              default: false
            },
            concurrency: {
              type: "number",
              desc: "Maximum number of simultaneous asset operations (building and publishing, dependency permitting) to execute.",
              default: 4,
              requiresArg: true
            }
          }
        },
        import: {
          description: "Import existing resource(s) into the given STACK",
          arg: {
            name: "STACK",
            variadic: false
          },
          options: {
            execute: {
              type: "boolean",
              desc: "Whether to execute the change set (--no-execute will NOT execute the change set)",
              default: true
            },
            "change-set-name": {
              type: "string",
              desc: "Name of the CloudFormation change set to create"
            },
            "toolkit-stack-name": {
              type: "string",
              desc: "The name of the CDK toolkit stack to create",
              requiresArg: true
            },
            rollback: {
              type: "boolean",
              desc: "Rollback stack to stable state on failure. Defaults to 'true', iterate more rapidly with --no-rollback or -R. Note: do **not** disable this flag for deployments with resource replacements, as that will always fail"
            },
            force: {
              alias: "f",
              type: "boolean",
              desc: "Do not abort if the template diff includes updates or deletes. This is probably safe but we're not sure, let us know how it goes."
            },
            "record-resource-mapping": {
              type: "string",
              requiresArg: true,
              desc: "If specified, CDK will generate a mapping of existing physical resources to CDK resources to be imported as. The mapping will be written in the given file path. No actual import operation will be performed"
            },
            "resource-mapping": {
              type: "string",
              alias: "m",
              requiresArg: true,
              desc: "If specified, CDK will use the given file to map physical resources to CDK resources for import, instead of interactively asking the user. Can be run from scripts"
            },
            "resource-mapping-inline": {
              type: "string",
              requiresArg: true,
              desc: `Inline JSON resource mapping, e.g. '{"MyResource":{"TableName":"my-table"}}'`
            }
          }
        },
        watch: {
          description: "Shortcut for 'deploy --watch'",
          arg: {
            name: "STACKS",
            variadic: true
          },
          options: {
            "build-exclude": {
              type: "array",
              alias: "E",
              desc: "Do not rebuild asset with the given ID. Can be specified multiple times",
              default: []
            },
            exclusively: {
              type: "boolean",
              alias: "e",
              desc: "Only deploy requested stacks, don't include dependencies"
            },
            "change-set-name": {
              type: "string",
              desc: "Name of the CloudFormation change set to create"
            },
            force: {
              alias: "f",
              type: "boolean",
              desc: "Always deploy stack even if templates are identical",
              default: false
            },
            "toolkit-stack-name": {
              type: "string",
              desc: "The name of the existing CDK toolkit stack (only used for app using legacy synthesis)",
              requiresArg: true
            },
            progress: {
              type: "string",
              choices: [
                "bar",
                "events"
              ],
              desc: "Display mode for stack activity events"
            },
            rollback: {
              type: "boolean",
              desc: "Rollback stack to stable state on failure. Defaults to 'true', iterate more rapidly with --no-rollback or -R. Note: do **not** disable this flag for deployments with resource replacements, as that will always fail",
              negativeAlias: "R"
            },
            hotswap: {
              type: "boolean",
              desc: "Attempts to perform a 'hotswap' deployment, but does not fall back to a full deployment if that is not possible. Instead, changes to any non-hotswappable properties are ignored.'true' by default, use --no-hotswap to turn off"
            },
            "hotswap-fallback": {
              type: "boolean",
              desc: "Attempts to perform a 'hotswap' deployment, which skips CloudFormation and updates the resources directly, and falls back to a full deployment if that is not possible."
            },
            "hotswap-ecs-minimum-healthy-percent": {
              type: "number",
              desc: "Lower limit on the number of your service's tasks that must remain in the RUNNING state during a deployment, as a percentage of the desiredCount"
            },
            "hotswap-ecs-maximum-healthy-percent": {
              type: "number",
              desc: "Upper limit on the number of your service's tasks that are allowed in the RUNNING or PENDING state during a deployment, as a percentage of the desiredCount"
            },
            "hotswap-ecs-stabilization-timeout-seconds": {
              type: "number",
              desc: "Number of seconds to wait for a single service to reach stable state, where the desiredCount is equal to the runningCount"
            },
            logs: {
              type: "boolean",
              default: true,
              desc: "Show CloudWatch log events from all resources in the selected Stacks in the terminal. 'true' by default, use --no-logs to turn off"
            },
            concurrency: {
              type: "number",
              desc: "Maximum number of simultaneous deployments (dependency permitting) to execute.",
              default: 1,
              requiresArg: true
            }
          }
        },
        destroy: {
          description: "Destroy the stack(s) named STACKS",
          arg: {
            name: "STACKS",
            variadic: true
          },
          options: {
            all: {
              type: "boolean",
              default: false,
              desc: "Destroy all available stacks"
            },
            exclusively: {
              type: "boolean",
              alias: "e",
              desc: "Only destroy requested stacks, don't include dependees"
            },
            force: {
              type: "boolean",
              alias: "f",
              desc: "Do not ask for confirmation before destroying the stacks"
            },
            concurrency: {
              type: "number",
              desc: "Maximum number of simultaneous destroys (dependency permitting) to execute.",
              default: 1,
              requiresArg: true
            }
          }
        },
        diff: {
          description: "Compares the specified stack with the deployed stack or a local template file, and returns with status 1 if any difference is found",
          arg: {
            name: "STACKS",
            variadic: true
          },
          options: {
            exclusively: {
              type: "boolean",
              alias: "e",
              desc: "Only diff requested stacks, don't include dependencies"
            },
            "context-lines": {
              type: "number",
              desc: "Number of context lines to include in arbitrary JSON diff rendering",
              default: 3,
              requiresArg: true
            },
            template: {
              type: "string",
              desc: "The path to the CloudFormation template to compare with. Implies --method=template",
              requiresArg: true
            },
            strict: {
              type: "boolean",
              desc: "Do not filter out AWS::CDK::Metadata resources, mangled non-ASCII characters, or the CheckBootstrapVersionRule",
              default: false
            },
            "security-only": {
              type: "boolean",
              desc: "Only diff for broadened security changes",
              default: false
            },
            fail: {
              type: "boolean",
              desc: "Fail with exit code 1 in case of diff"
            },
            processed: {
              type: "boolean",
              desc: "Whether to compare against the template with Transforms already processed",
              default: false
            },
            quiet: {
              type: "boolean",
              alias: "q",
              desc: "Do not print stack name and default message when there is no diff to stdout",
              default: false
            },
            "change-set": {
              type: "boolean",
              alias: "changeset",
              desc: "Whether to create a change set to analyze resource replacements. In this mode, diff will use the deploy role instead of the lookup role.",
              default: true,
              deprecated: "use --method instead"
            },
            method: {
              alias: "m",
              type: "string",
              default: "auto",
              choices: [
                "auto",
                "change-set",
                "template"
              ],
              requiresArg: true,
              desc: 'How to compute the diff. "auto" attempts to create a change set and falls back to template-only on failure. "change-set" creates a change set and fails if it cannot be created. Both use the deploy role instead of the lookup role. "template" compares templates directly and uses the lookup role.'
            },
            "import-existing-resources": {
              type: "boolean",
              desc: "Whether or not the change set imports resources that already exist",
              default: false
            },
            "include-moves": {
              type: "boolean",
              desc: "Whether to include moves in the diff",
              default: false
            }
          }
        },
        drift: {
          description: "Detect drifts in the given CloudFormation stack(s)",
          arg: {
            name: "STACKS",
            variadic: true
          },
          options: {
            fail: {
              type: "boolean",
              desc: "Fail with exit code 1 if drift is detected"
            }
          }
        },
        metadata: {
          description: "Returns all metadata associated with this stack",
          arg: {
            name: "STACK",
            variadic: false
          }
        },
        acknowledge: {
          aliases: [
            "ack"
          ],
          description: "Acknowledge a notice so that it does not show up anymore",
          arg: {
            name: "ID",
            variadic: false
          }
        },
        notices: {
          description: "Returns a list of relevant notices",
          options: {
            unacknowledged: {
              type: "boolean",
              alias: "u",
              default: false,
              desc: "Returns a list of unacknowledged notices"
            }
          }
        },
        init: {
          description: "Create a new, empty CDK project from a template.",
          arg: {
            name: "TEMPLATE",
            variadic: false
          },
          options: {
            language: {
              type: "string",
              alias: "l",
              desc: "The language to be used for the new project (default can be configured in ~/.cdk.json)",
              choices: [
                "csharp",
                "cs",
                "fsharp",
                "fs",
                "go",
                "java",
                "javascript",
                "js",
                "python",
                "py",
                "typescript",
                "ts"
              ]
            },
            list: {
              type: "boolean",
              desc: "List the available templates"
            },
            "generate-only": {
              type: "boolean",
              default: false,
              desc: "If true, only generates project files, without executing additional operations such as setting up a git repo, installing dependencies or compiling the project"
            },
            "lib-version": {
              type: "string",
              alias: "V",
              desc: "The version of the CDK library (aws-cdk-lib) to initialize built-in templates with. Defaults to the version that was current when this CLI was built."
            },
            "from-path": {
              type: "string",
              desc: "Path to a local custom template directory or multi-template repository",
              requiresArg: true,
              conflicts: [
                "lib-version"
              ]
            },
            "template-path": {
              type: "string",
              desc: "Path to a specific template within a multi-template repository",
              requiresArg: true
            },
            "package-manager": {
              type: "string",
              desc: "The package manager to use to install dependencies. Only applicable for TypeScript and JavaScript projects. Defaults to npm in TypeScript and JavaScript projects.",
              choices: [
                "npm",
                "yarn",
                "pnpm",
                "bun"
              ]
            },
            "project-name": {
              type: "string",
              alias: "n",
              desc: "The name of the new project",
              requiresArg: true
            }
          },
          implies: {
            "template-path": "from-path"
          }
        },
        migrate: {
          description: "Migrate existing AWS resources into a CDK app",
          options: {
            "stack-name": {
              type: "string",
              alias: "n",
              desc: "The name assigned to the stack created in the new project. The name of the app will be based off this name as well.",
              requiresArg: true
            },
            language: {
              type: "string",
              default: "typescript",
              alias: "l",
              desc: "The language to be used for the new project",
              choices: [
                "typescript",
                "ts",
                "go",
                "java",
                "python",
                "py",
                "csharp",
                "cs"
              ]
            },
            account: {
              type: "string",
              desc: "The account to retrieve the CloudFormation stack template from"
            },
            region: {
              type: "string",
              desc: "The region to retrieve the CloudFormation stack template from"
            },
            "from-path": {
              type: "string",
              desc: "The path to the CloudFormation template to migrate. Use this for locally stored templates"
            },
            "from-stack": {
              type: "boolean",
              desc: "Use this flag to retrieve the template for an existing CloudFormation stack"
            },
            "output-path": {
              type: "string",
              desc: "The output path for the migrated CDK app"
            },
            "from-scan": {
              type: "string",
              desc: 'Determines if a new scan should be created, or the last successful existing scan should be used \n options are "new" or "most-recent"'
            },
            filter: {
              type: "array",
              desc: 'Filters the resource scan based on the provided criteria in the following format: "key1=value1,key2=value2"\n This field can be passed multiple times for OR style filtering: \n filtering options: \n resource-identifier: A key-value pair that identifies the target resource. i.e. {"ClusterName", "myCluster"}\n resource-type-prefix: A string that represents a type-name prefix. i.e. "AWS::DynamoDB::"\n tag-key: a string that matches resources with at least one tag with the provided key. i.e. "myTagKey"\n tag-value: a string that matches resources with at least one tag with the provided value. i.e. "myTagValue"'
            },
            compress: {
              type: "boolean",
              desc: "Use this flag to zip the generated CDK app"
            }
          }
        },
        context: {
          description: "Manage cached context values",
          options: {
            reset: {
              alias: "e",
              desc: "The context key (or its index) to reset",
              type: "string",
              requiresArg: true
            },
            force: {
              alias: "f",
              desc: "Ignore missing key error",
              type: "boolean",
              default: false
            },
            clear: {
              desc: "Clear all context",
              type: "boolean",
              default: false
            }
          }
        },
        docs: {
          aliases: [
            "doc"
          ],
          description: "Opens the reference documentation in a browser",
          options: {
            browser: {
              alias: "b",
              desc: "the command to use to open the browser, using %u as a placeholder for the path of the file to open",
              type: "string"
            }
          }
        },
        doctor: {
          description: "Check your set-up for potential problems"
        },
        orphan: {
          arg: {
            name: "PATHS",
            variadic: true
          },
          description: "Detach resources from a CloudFormation stack without deleting them",
          options: {}
        },
        refactor: {
          description: "Moves resources between stacks or within the same stack",
          options: {
            "additional-stack-name": {
              type: "array",
              requiresArg: true,
              desc: "Names of deployed stacks to be considered for resource comparison."
            },
            "dry-run": {
              type: "boolean",
              desc: "Do not perform any changes, just show what would be done",
              default: false
            },
            "override-file": {
              type: "string",
              requiresArg: true,
              desc: "A file that declares overrides to be applied to the list of mappings computed by the CLI."
            },
            revert: {
              type: "boolean",
              default: false,
              desc: "If specified, the command will revert the refactor operation. This is only valid if a mapping file was provided."
            },
            force: {
              type: "boolean",
              default: false,
              desc: "Whether to do the refactor without asking for confirmation"
            }
          },
          arg: {
            name: "STACKS",
            variadic: true
          }
        },
        "cli-telemetry": {
          description: "Enable or disable anonymous telemetry",
          options: {
            enable: {
              type: "boolean",
              desc: "Enable anonymous telemetry",
              conflicts: "disable"
            },
            disable: {
              type: "boolean",
              desc: "Disable anonymous telemetry",
              conflicts: "enable"
            },
            status: {
              type: "boolean",
              desc: "Report telemetry opt-in/out status",
              conflicts: [
                "enable",
                "disable"
              ]
            }
          }
        }
      }
    };
  }
});

// lib/cli/telemetry/sanitation.ts
function sanitizeCommandLineArguments(argv) {
  const config2 = require_cli_type_registry();
  const command = argv._[0];
  const path47 = [command];
  const parameters = {};
  const globalOptions = Object.keys(config2.globalOptions);
  const commandOptions = Object.keys(config2.commands[command]?.options ?? {});
  const commandArg = config2.commands[command]?.arg;
  for (const argName of Object.keys(argv)) {
    if (argName === commandArg?.name) {
      if (commandArg.variadic) {
        for (let i32 = 0; i32 < argv[argName].length; i32++) {
          path47.push(`$${argName}_${i32 + 1}`);
        }
      } else {
        path47.push(`$${argName}`);
      }
    }
    if (argv[argName] === void 0 || !globalOptions.includes(argName) && !commandOptions.includes(argName)) {
      continue;
    }
    if (isNumberOrBoolean(argv[argName]) || isKnownEnumValue(argName, argv[argName], command, config2)) {
      parameters[argName] = argv[argName];
    } else {
      parameters[argName] = "<redacted>";
    }
  }
  return {
    path: path47,
    parameters
  };
}
function sanitizeContext(context) {
  const sanitizedContext = {};
  for (const [flag, value] of Object.entries(context.all)) {
    if (!isFeatureFlag(flag)) {
      continue;
    }
    const sanitizedValue = isBoolean(value) ? value : value !== "false";
    sanitizedContext[flag] = sanitizedValue;
  }
  return sanitizedContext;
}
function isBoolean(value) {
  return typeof value === "boolean";
}
function isNumberOrBoolean(value) {
  return typeof value === "number" || isBoolean(value);
}
function isKnownEnumValue(name, value, command, config2) {
  const propertyDefiniton = config2.globalOptions[name] ?? config2.commands[command]?.options[name];
  if (propertyDefiniton.type === "string") {
    return propertyDefiniton.choices?.includes(value);
  }
  return false;
}
function isFeatureFlag(flag) {
  return Object.values(FeatureFlag).includes(flag);
}
var init_sanitation = __esm({
  "lib/cli/telemetry/sanitation.ts"() {
    "use strict";
    init_feature_flags();
    __name(sanitizeCommandLineArguments, "sanitizeCommandLineArguments");
    __name(sanitizeContext, "sanitizeContext");
    __name(isBoolean, "isBoolean");
    __name(isNumberOrBoolean, "isNumberOrBoolean");
    __name(isKnownEnumValue, "isKnownEnumValue");
    __name(isFeatureFlag, "isFeatureFlag");
  }
});

// lib/cli/ci-systems.ts
function detectCiSystem() {
  for (const ciSystem of CI_SYSTEMS) {
    if (process.env[ciSystem.detectEnvVar]) {
      return ciSystem;
    }
  }
  return void 0;
}
function ciSystemIsStdErrSafe() {
  const x = detectCiSystem()?.canBeConfiguredToFailOnStdErr;
  return x === void 0 ? void 0 : !x;
}
var CI_SYSTEMS;
var init_ci_systems = __esm({
  "lib/cli/ci-systems.ts"() {
    "use strict";
    CI_SYSTEMS = [
      {
        name: "Azure DevOps",
        // https://learn.microsoft.com/en-us/azure/devops/pipelines/build/variables?view=azure-devops&tabs=yaml
        detectEnvVar: "TF_BUILD",
        canBeConfiguredToFailOnStdErr: true
      },
      {
        name: "TeamCity",
        // https://www.jetbrains.com/help/teamcity/predefined-build-parameters.html
        detectEnvVar: "TEAMCITY_VERSION",
        // Can be configured to fail on stderr, when using a PowerShell task
        canBeConfiguredToFailOnStdErr: true
      },
      {
        name: "GitHub Actions",
        // https://docs.github.com/en/actions/writing-workflows/choosing-what-your-workflow-does/store-information-in-variables#default-environment-variables
        detectEnvVar: "GITHUB_ACTION",
        canBeConfiguredToFailOnStdErr: false
      },
      {
        name: "CodeBuild",
        // https://docs.aws.amazon.com/codebuild/latest/userguide/build-env-ref-env-vars.html
        detectEnvVar: "CODEBUILD_BUILD_ID",
        canBeConfiguredToFailOnStdErr: false
      },
      {
        name: "CircleCI",
        // https://circleci.com/docs/variables/#built-in-environment-variables
        detectEnvVar: "CIRCLECI",
        canBeConfiguredToFailOnStdErr: false
      },
      {
        name: "Jenkins",
        // https://www.jenkins.io/doc/book/pipeline/jenkinsfile/#using-environment-variables
        detectEnvVar: "EXECUTOR_NUMBER",
        canBeConfiguredToFailOnStdErr: false
      }
    ];
    __name(detectCiSystem, "detectCiSystem");
    __name(ciSystemIsStdErrSafe, "ciSystemIsStdErrSafe");
  }
});

// lib/cli/util/ci.ts
function isCI2() {
  return process.env.CI !== void 0 && process.env.CI !== "false" && process.env.CI !== "0";
}
var init_ci = __esm({
  "lib/cli/util/ci.ts"() {
    "use strict";
    __name(isCI2, "isCI");
  }
});

// lib/cli/root-dir.ts
function cliRootDir(fail) {
  function _rootDir(dirname14) {
    const manifestPath = path37.join(dirname14, "package.json");
    if (fs38.existsSync(manifestPath)) {
      return dirname14;
    }
    if (path37.dirname(dirname14) === dirname14) {
      if (fail ?? true) {
        throw new import_toolkit_lib2.ToolkitError("PackageManifestNotFound", "Unable to find package manifest");
      }
      return void 0;
    }
    return _rootDir(path37.dirname(dirname14));
  }
  __name(_rootDir, "_rootDir");
  return _rootDir(__dirname);
}
var fs38, path37, import_toolkit_lib2;
var init_root_dir = __esm({
  "lib/cli/root-dir.ts"() {
    "use strict";
    fs38 = __toESM(require("fs"));
    path37 = __toESM(require("path"));
    import_toolkit_lib2 = __toESM(require_lib12());
    __name(cliRootDir, "cliRootDir");
  }
});

// lib/cli/version.ts
function versionWithBuild() {
  return `${versionNumber2()} (build ${commit()})`;
}
function isDeveloperBuildVersion() {
  return versionNumber2() === "0.0.0";
}
function versionNumber2() {
  return require(path38.join(cliRootDir(), "package.json")).version.replace(/\+[0-9a-f]+$/, "");
}
function commit() {
  return require(path38.join(cliRootDir(), "build-info.json")).commit;
}
var path38;
var init_version = __esm({
  "lib/cli/version.ts"() {
    "use strict";
    path38 = __toESM(require("path"));
    init_root_dir();
    __name(versionWithBuild, "versionWithBuild");
    __name(isDeveloperBuildVersion, "isDeveloperBuildVersion");
    __name(versionNumber2, "versionNumber");
    __name(commit, "commit");
  }
});

// lib/cli/telemetry/telemetry-state.ts
async function withTelemetryState(block) {
  const state13 = await loadTelemetryState();
  const oldState = JSON.stringify(state13);
  const ret = block(state13);
  if (JSON.stringify(ret) !== oldState) {
    await writeTelemetryState(state13);
  }
  return ret;
}
async function loadTelemetryState() {
  try {
    return JSON.parse(await fs39.readFile(TELEMETRY_STATE_PATH, "utf-8"));
  } catch (e32) {
    if (e32.code === "ENOENT") {
      return {};
    }
    throw e32;
  }
}
async function writeTelemetryState(state13) {
  await ensureCacheDir();
  await fs39.writeFile(TELEMETRY_STATE_PATH, JSON.stringify(state13, void 0, 2), "utf-8");
}
var fs39, path39, TELEMETRY_STATE_PATH;
var init_telemetry_state = __esm({
  "lib/cli/telemetry/telemetry-state.ts"() {
    "use strict";
    fs39 = __toESM(require("fs/promises"));
    path39 = __toESM(require("path"));
    init_installation_id();
    init_util9();
    __name(withTelemetryState, "withTelemetryState");
    __name(loadTelemetryState, "loadTelemetryState");
    __name(writeTelemetryState, "writeTelemetryState");
    TELEMETRY_STATE_PATH = path39.join(cdkCacheDir(), "telemetry-state.json");
  }
});

// lib/cli/telemetry/session.ts
function getState(error4) {
  if (error4) {
    return isAbortedError(error4) ? "ABORTED" : "FAILED";
  }
  return "SUCCEEDED";
}
function isAbortedError(error4) {
  if (error4?.name === "ToolkitError" && error4?.message?.includes(ABORTED_ERROR_MESSAGE)) {
    return true;
  }
  return false;
}
function mutable(x) {
  return x;
}
function isValidWrapperUserAgent(value) {
  if (!value) return false;
  const parts = value.split("/");
  if (parts.length !== 3) return false;
  const [name, _version, mode] = parts;
  if (!VALID_USER_AGENTS.includes(name)) return false;
  return mode === "sandbox" || mode === "production";
}
var import_node_crypto20, import_toolkit_lib3, ABORTED_ERROR_MESSAGE, VALID_USER_AGENTS, TelemetrySession;
var init_session = __esm({
  "lib/cli/telemetry/session.ts"() {
    "use strict";
    import_node_crypto20 = require("node:crypto");
    import_toolkit_lib3 = __toESM(require_lib12());
    init_installation_id();
    init_library_version();
    init_sanitation();
    init_ci_systems();
    init_messages2();
    init_ci();
    init_version();
    init_error2();
    init_telemetry_state();
    ABORTED_ERROR_MESSAGE = "__CDK-Toolkit__Aborted";
    VALID_USER_AGENTS = ["aws-blocks"];
    TelemetrySession = class {
      constructor(props) {
        this.props = props;
        this.count = 0;
        this.ioHost = props.ioHost;
        this.client = props.client;
      }
      static {
        __name(this, "TelemetrySession");
      }
      /**
       * The span that represents the CLI invocation.
       *
       * In the code, this span is named COMMAND but the matching event type
       * in telemetry will be INVOKE.
       *
       * Will be emitted exactly once, at the end of the CLI operation.
       */
      get commandSpan() {
        return this._commandSpan;
      }
      async begin() {
        const { path: path47, parameters } = sanitizeCommandLineArguments(this.props.arguments);
        this._sessionInfo = {
          identifiers: {
            installationId: await getOrCreateInstallationId(this.ioHost.asIoHelper()),
            sessionId: (0, import_node_crypto20.randomUUID)(),
            telemetryVersion: "2.0",
            cdkCliVersion: versionNumber2(),
            cdkLibraryVersion: await getLibraryVersion(this.ioHost.asIoHelper())
          },
          event: {
            command: {
              path: path47,
              parameters,
              config: {
                context: sanitizeContext(this.props.context),
                ...isValidWrapperUserAgent(process.env.CDK_CLI_USERAGENT) ? { cdkCliUserAgent: { [process.env.CDK_CLI_USERAGENT]: true } } : {}
              }
            }
          },
          environment: {
            ci: isCI2() || Boolean(detectCiSystem()),
            os: {
              platform: process.platform,
              release: process.release.name
            },
            nodeVersion: process.version
          },
          project: {}
        };
        process.on("SIGINT", async () => {
          try {
            await this.end({
              name: USER_INTERRUPTED_CODE,
              message: ABORTED_ERROR_MESSAGE
            });
          } catch (e32) {
            await this.ioHost.defaults.trace(`Ending Telemetry failed: ${e32.message}`);
          }
          process.exit(1);
        });
        this._commandSpan = await this.ioHost.asIoHelper().span(CLI_PRIVATE_SPAN.COMMAND).begin({});
      }
      async attachRegion(region) {
        this.sessionInfo.identifiers = {
          ...this.sessionInfo.identifiers,
          region
        };
      }
      /**
       * Attach a language guess
       */
      attachLanguage(language) {
        if (!this._sessionInfo) {
          return;
        }
        if (language) {
          mutable(this.sessionInfo.project).language = language;
        }
      }
      /**
       * Attach our best guess at running under an agent or not
       */
      attachAgent(isAgent) {
        if (!this._sessionInfo) {
          return;
        }
        mutable(this.sessionInfo.environment).agent = isAgent;
      }
      /**
       * Temporarily attach counters for the next event operation.
       *
       * They may be committed to the sent telemetry later.
       */
      attachCountersToNextEvent(counters) {
        this._nextEventCounters = counters;
      }
      /**
       * Set the load time (will be emitted with the COMMAND span)
       */
      attachLoadTime(loadTime) {
        this.loadTime = loadTime;
        this._commandSpan?.addTimer("load", loadTime);
      }
      /**
       * Mark when the actual CLI operation starts
       *
       * Emitted as part of the COMMAND span.
       */
      markOperationStart() {
        if (this.loadTime) {
          this._commandSpan?.addTimer("init", performance.now() - this.loadTime);
        }
      }
      /**
       * Attach the CDK library version
       *
       * By default the telemetry will guess at the CDK library version if it so
       * happens that the CDK project is an NPM project and the CDK CLI is executed
       * in the root of NPM project with `aws-cdk-lib` available in `node_modules`.
       * This may succeed or may fail.
       *
       * Once we have produced and loaded the cloud assembly more accurate
       * information becomes available that we can add in.
       */
      attachCdkLibVersion(libVersion) {
        if (!this._sessionInfo) {
          return;
        }
        mutable(this.sessionInfo.identifiers).cdkLibraryVersion = libVersion;
      }
      /**
       * When the command is complete, so is the CliIoHost. Ends the span of the entire CliIoHost
       * and notifies with an optional error message in the data.
       */
      async end(error4) {
        await this._commandSpan?.end({ error: error4 });
        this._commandSpan = void 0;
        await this.client.flush();
      }
      async emit(event) {
        this.count += 1;
        const counters = {
          ...this._nextEventCounters,
          ...event.counters
        };
        this._nextEventCounters = void 0;
        if (event.eventType == "DEPLOY") {
          await this.trackDeployStatistics(event.error === void 0, counters);
        }
        return this.client.emit({
          event: {
            command: this.sessionInfo.event.command,
            state: getState(event.error),
            eventType: event.eventType
          },
          identifiers: {
            ...this.sessionInfo.identifiers,
            eventId: `${this.sessionInfo.identifiers.sessionId}:${this.count}`,
            timestamp: (/* @__PURE__ */ new Date()).toISOString()
          },
          environment: this.sessionInfo.environment,
          project: this.sessionInfo.project,
          duration: {
            total: event.duration
          },
          ...event.error ? {
            error: {
              name: event.error.name
            }
          } : {},
          ...Object.keys(counters).length > 0 ? { counters } : {}
        });
      }
      /**
       * This is a DEPLOY event, track some additional statistics about it
       *
       * We use this to measure things about deployment failures, such as the number of
       * failed DEPLOY events in a sequence.
       */
      async trackDeployStatistics(isSuccessful, counters) {
        await withTelemetryState((state13) => {
          const recentFailures = state13.sequentialDeploymentFailures ?? 0;
          if (isSuccessful) {
            state13.sequentialDeploymentFailures = 0;
          } else {
            state13.sequentialDeploymentFailures = recentFailures + 1;
          }
          counters.sequentialDeploymentFailures = state13.sequentialDeploymentFailures;
        });
      }
      get sessionInfo() {
        if (!this._sessionInfo) {
          throw new import_toolkit_lib3.ToolkitError("SessionNotInitialized", "Session Info not initialized. Call begin() first.");
        }
        return this._sessionInfo;
      }
    };
    __name(getState, "getState");
    __name(isAbortedError, "isAbortedError");
    __name(mutable, "mutable");
    __name(isValidWrapperUserAgent, "isValidWrapperUserAgent");
  }
});

// lib/api/network-detector.ts
var init_network_detector3 = __esm({
  "lib/api/network-detector.ts"() {
    "use strict";
    init_network_detector2();
  }
});

// lib/cli/telemetry/sink/endpoint-sink.ts
function doRequest(url, data3, agent) {
  return new Promise((ok, ko) => {
    const payload3 = JSON.stringify(data3);
    const req = (0, import_https.request)({
      hostname: url.hostname,
      port: url.port || null,
      path: url.pathname,
      method: "POST",
      headers: {
        "content-type": "application/json",
        "content-length": payload3.length
      },
      agent,
      timeout: REQUEST_ATTEMPT_TIMEOUT_MS
    }, ok);
    req.on("error", ko);
    req.on("timeout", () => {
      const error4 = new import_toolkit_lib4.ToolkitError("RequestTimeout", `Timeout after ${REQUEST_ATTEMPT_TIMEOUT_MS}ms, aborting request`);
      req.destroy(error4);
    });
    req.end(payload3);
  });
}
var import_https, import_toolkit_lib4, REQUEST_ATTEMPT_TIMEOUT_MS, EndpointTelemetrySink;
var init_endpoint_sink = __esm({
  "lib/cli/telemetry/sink/endpoint-sink.ts"() {
    "use strict";
    import_https = require("https");
    import_toolkit_lib4 = __toESM(require_lib12());
    init_network_detector3();
    init_api_private();
    REQUEST_ATTEMPT_TIMEOUT_MS = 500;
    EndpointTelemetrySink = class {
      constructor(props) {
        this.events = [];
        this.endpoint = new URL(props.endpoint);
        if (!this.endpoint.hostname || !this.endpoint.pathname) {
          throw new import_toolkit_lib4.ToolkitError("MalformedEndpoint", `Telemetry Endpoint malformed. Received hostname: ${this.endpoint.hostname}, pathname: ${this.endpoint.pathname}`);
        }
        this.ioHelper = IoHelper.fromActionAwareIoHost(props.ioHost);
        this.agent = props.agent;
        setInterval(() => this.flush(), 3e4).unref();
      }
      static {
        __name(this, "EndpointTelemetrySink");
      }
      /**
       * Add an event to the collection.
       */
      async emit(event) {
        try {
          this.events.push(event);
        } catch (e32) {
          await this.ioHelper.defaults.trace(`Failed to add telemetry event: ${e32.message}`);
        }
      }
      async flush() {
        try {
          if (this.events.length === 0) {
            return;
          }
          const res = await this.https(this.endpoint, { events: this.events });
          if (res) {
            this.events = [];
          }
        } catch (e32) {
          await this.ioHelper.defaults.trace(`Failed to send telemetry event: ${e32.message}`);
        }
      }
      /**
       * Returns true if telemetry successfully posted, false otherwise.
       */
      async https(url, body) {
        const hasConnectivity = await NetworkDetector.hasConnectivity(this.agent);
        if (!hasConnectivity) {
          await this.ioHelper.defaults.trace("No internet connectivity detected, skipping telemetry");
          return false;
        }
        try {
          const res = await doRequest(url, body, this.agent);
          if (res.statusCode && res.statusCode >= 200 && res.statusCode < 300) {
            await this.ioHelper.defaults.trace("Telemetry Sent Successfully");
            return true;
          }
          await this.ioHelper.defaults.trace(`Telemetry Unsuccessful: POST ${url.hostname}${url.pathname}: ${res.statusCode}:${res.statusMessage}`);
          return false;
        } catch (e32) {
          await this.ioHelper.defaults.trace(`Telemetry Error: POST ${url.hostname}${url.pathname}: ${JSON.stringify(e32)}`);
          return false;
        }
      }
    };
    __name(doRequest, "doRequest");
  }
});

// lib/cli/telemetry/sink/file-sink.ts
var import_toolkit_lib5, fs40, FileTelemetrySink;
var init_file_sink = __esm({
  "lib/cli/telemetry/sink/file-sink.ts"() {
    "use strict";
    import_toolkit_lib5 = __toESM(require_lib12());
    fs40 = __toESM(require_lib4());
    init_api_private();
    FileTelemetrySink = class {
      static {
        __name(this, "FileTelemetrySink");
      }
      /**
       * Create a new FileTelemetryClient
       */
      constructor(props) {
        this.ioHelper = IoHelper.fromActionAwareIoHost(props.ioHost);
        this.logFilePath = props.logFilePath;
        if (fs40.existsSync(this.logFilePath)) {
          throw new import_toolkit_lib5.ToolkitError("TelemetryFileExists", `Telemetry file already exists at ${this.logFilePath}`);
        }
        fs40.ensureFileSync(this.logFilePath);
        fs40.writeJsonSync(this.logFilePath, []);
      }
      /**
       * Emit an event.
       */
      async emit(event) {
        try {
          const json = fs40.readJsonSync(this.logFilePath);
          json.push(event);
          fs40.writeJSONSync(this.logFilePath, json, { spaces: 2 });
        } catch (e32) {
          await this.ioHelper.defaults.trace(`Failed to add telemetry event: ${e32.message}`);
        }
      }
      async flush() {
        return;
      }
    };
  }
});

// lib/cli/telemetry/sink/funnel.ts
var import_toolkit_lib6, Funnel;
var init_funnel = __esm({
  "lib/cli/telemetry/sink/funnel.ts"() {
    "use strict";
    import_toolkit_lib6 = __toESM(require_lib12());
    Funnel = class {
      static {
        __name(this, "Funnel");
      }
      constructor(props) {
        if (props.sinks.length > 5) {
          throw new import_toolkit_lib6.ToolkitError("MaxSinksExceeded", `Funnel class supports a maximum of 5 parallel sinks, got ${props.sinks.length} sinks.`);
        }
        this.sinks = props.sinks;
      }
      async emit(event) {
        await Promise.all(this.sinks.map((sink) => sink.emit(event)));
      }
      async flush() {
        await Promise.all(this.sinks.map((sink) => sink.flush()));
      }
    };
  }
});

// lib/cli/io-host/cli-io-host.ts
function isPromptableRequest(msg) {
  return isConfirmationPrompt(msg) || typeof msg.defaultResponse === "string" || typeof msg.defaultResponse === "number";
}
function isConfirmationPrompt(msg) {
  return typeof msg.defaultResponse === "boolean";
}
function extractPromptInfo(msg) {
  const isNumber = typeof msg.defaultResponse === "number";
  const defaultResponse = util10.format(msg.defaultResponse);
  return {
    default: defaultResponse,
    defaultDesc: "defaultDescription" in msg && msg.defaultDescription ? util10.format(msg.defaultDescription) : defaultResponse,
    convertAnswer: isNumber ? (v) => Number(v) : (v) => String(v)
  };
}
function targetStreamObject(x) {
  switch (x) {
    case "stderr":
      return process.stderr;
    case "stdout":
      return process.stdout;
    case "drop":
      return void 0;
  }
}
function isNoticesMessage(msg) {
  return IO.CDK_TOOLKIT_I0100.is(msg) || IO.CDK_TOOLKIT_W0101.is(msg) || IO.CDK_TOOLKIT_E0101.is(msg) || IO.CDK_TOOLKIT_I0101.is(msg);
}
function eventFromMessage(msg) {
  if (CLI_PRIVATE_IO.CDK_CLI_I1001.is(msg)) {
    return eventResult("SYNTH", msg);
  }
  if (CLI_PRIVATE_IO.CDK_CLI_I2001.is(msg)) {
    return eventResult("INVOKE", msg);
  }
  if (CLI_PRIVATE_IO.CDK_CLI_I3001.is(msg)) {
    return eventResult("DEPLOY", msg);
  }
  if (CLI_PRIVATE_IO.CDK_CLI_I3003.is(msg)) {
    return eventResult("ASSET", msg);
  }
  if (IO.CDK_TOOLKIT_I5410.is(msg)) {
    return hotswapToEventResult(msg.data);
  }
  return void 0;
  function eventResult(eventType, m20) {
    return {
      eventType,
      duration: m20.data.duration,
      error: m20.data.error,
      counters: m20.data.counters
    };
  }
  __name(eventResult, "eventResult");
}
function hotswapToEventResult(result2) {
  const nonHotswappableResources = {};
  for (const { subject } of result2.nonHotswappableChanges) {
    if ("resourceType" in subject) {
      const keys = "rejectedProperties" in subject && subject.rejectedProperties ? subject.rejectedProperties.map((p10) => `hotswapFallback:${subject.resourceType}#${p10}`) : [`hotswapFallback:${subject.resourceType}`];
      for (const key of keys) {
        nonHotswappableResources[key] = (nonHotswappableResources[key] ?? 0) + 1;
      }
    }
  }
  return {
    eventType: "HOTSWAP",
    duration: result2.duration,
    ...result2.error ? {
      error: {
        name: cdkCliErrorName(result2.error)
      }
    } : {},
    counters: {
      hotswapped: result2.hotswapped ? 1 : 0,
      hotswapFallback: result2.hotswapFallback ? 1 : 0,
      hotswappableChanges: result2.hotswappableChanges.length,
      nonHotswappableChanges: result2.nonHotswappableChanges.length,
      ...nonHotswappableResources
    }
  };
}
var util10, import_cloud_assembly_schema7, import_toolkit_lib7, chalk27, promptly, CliIoHost, styleMap2;
var init_cli_io_host = __esm({
  "lib/cli/io-host/cli-io-host.ts"() {
    "use strict";
    util10 = __toESM(require("node:util"));
    import_cloud_assembly_schema7 = __toESM(require_lib2());
    import_toolkit_lib7 = __toESM(require_lib12());
    chalk27 = __toESM(require_source());
    promptly = __toESM(require_promptly());
    init_api_private();
    init_deploy4();
    init_collect_telemetry();
    init_error2();
    init_messages2();
    init_session();
    init_endpoint_sink();
    init_file_sink();
    init_funnel();
    init_ci();
    CliIoHost = class _CliIoHost {
      constructor(props = {}) {
        /**
         * Configure the target stream for notices
         *
         * (Not a setter because there's no need for additional logic when this value
         * is changed yet)
         */
        this.noticesDestination = "stderr";
        this._progress = "bar" /* BAR */;
        // Corked Logging
        this.corkedCounter = 0;
        this.corkedLoggingBuffer = [];
        // Message listeners, keyed by message code. See `on`/`once`/`rewrite`/`rewriteOnce`.
        this.messageListeners = /* @__PURE__ */ new Map();
        this.currentAction = props.currentAction ?? "none";
        this.isTTY = props.isTTY ?? process.stdout.isTTY ?? false;
        this.logLevel = props.logLevel ?? "info";
        this.isCI = props.isCI ?? isCI2();
        this.requireDeployApproval = props.requireDeployApproval ?? import_cloud_assembly_schema7.RequireApproval.BROADENING;
        this.stackProgress = props.stackProgress ?? "bar" /* BAR */;
        this.autoRespond = props.autoRespond ?? false;
        this.routeStackActivityToPrinter();
      }
      static {
        __name(this, "CliIoHost");
      }
      /**
       * Returns the singleton instance
       */
      static instance(props = {}, forceNew = false) {
        if (forceNew || !_CliIoHost._instance) {
          _CliIoHost._instance = new _CliIoHost(props);
        }
        return _CliIoHost._instance;
      }
      /**
       * Returns the singleton instance if it exists
       */
      static get() {
        return _CliIoHost._instance;
      }
      async startTelemetry(args, context, proxyAgent) {
        const config2 = require_cli_type_registry();
        const validCommands = Object.keys(config2.commands);
        const cmd = args._[0];
        if (!validCommands.includes(cmd)) {
          await this.asIoHelper().defaults.trace(`Session instantiated with an invalid command (${cmd}). Not starting telemetry.`);
          return;
        }
        let sinks = [];
        const telemetryFilePath = args["telemetry-file"];
        if (telemetryFilePath) {
          try {
            sinks.push(new FileTelemetrySink({
              ioHost: this,
              logFilePath: telemetryFilePath
            }));
            await this.asIoHelper().defaults.trace("File Telemetry connected");
          } catch (e32) {
            await this.asIoHelper().defaults.trace(`File Telemetry instantiation failed: ${e32.message}`);
          }
        }
        const telemetryEndpoint = process.env.TELEMETRY_ENDPOINT ?? "https://cdk-cli-telemetry.us-east-1.api.aws/metrics";
        if (canCollectTelemetry(args, context) && telemetryEndpoint) {
          try {
            sinks.push(new EndpointTelemetrySink({
              ioHost: this,
              agent: proxyAgent,
              endpoint: telemetryEndpoint
            }));
            await this.asIoHelper().defaults.trace("Endpoint Telemetry connected");
          } catch (e32) {
            await this.asIoHelper().defaults.trace(`Endpoint Telemetry instantiation failed: ${e32.message}`);
          }
        } else {
          await this.asIoHelper().defaults.trace("Endpoint Telemetry NOT connected");
        }
        if (sinks.length > 0) {
          this.telemetry = new TelemetrySession({
            ioHost: this,
            client: new Funnel({ sinks }),
            arguments: args,
            context
          });
        }
        await this.telemetry?.begin();
      }
      /**
       * Update the stackProgress preference.
       */
      set stackProgress(type) {
        this._progress = type;
      }
      /**
       * Gets the stackProgress value.
       *
       * This takes into account other state of the ioHost,
       * like if isTTY and isCI.
       */
      get stackProgress() {
        if (this._progress === "events" /* EVENTS */) {
          return this._progress;
        }
        const verboseLogging = isMessageRelevantForLevel({ level: "debug" }, this.logLevel);
        if (verboseLogging) {
          return "events" /* EVENTS */;
        }
        const isWindows2 = process.platform === "win32";
        if (isWindows2) {
          return "events" /* EVENTS */;
        }
        const fancyOutputAvailable = this.isTTY && !this.isCI;
        if (!fancyOutputAvailable) {
          return "events" /* EVENTS */;
        }
        return this._progress;
      }
      get defaults() {
        return this.asIoHelper().defaults;
      }
      asIoHelper() {
        return asIoHelper(this, this.currentAction);
      }
      /**
       * Executes a block of code with corked logging. All log messages during execution
       * are buffered and only written when all nested cork blocks complete (when CORK_COUNTER reaches 0).
       * The corking is bound to the specific instance of the CliIoHost.
       *
       * @param block - Async function to execute with corked logging
       * @returns Promise that resolves with the block's return value
       */
      async withCorkedLogging(block) {
        this.corkedCounter++;
        try {
          return await block();
        } finally {
          this.corkedCounter--;
          if (this.corkedCounter === 0) {
            for (const ioMessage of this.corkedLoggingBuffer) {
              await this.notify(ioMessage);
            }
            this.corkedLoggingBuffer.splice(0);
          }
        }
      }
      /**
       * Register a listener that is invoked for every message with the given code.
       *
       * The listener may return a `MessageListenerResult` to update the message
       * text and/or prevent the default processing (writing it to a stream);
       * returning nothing leaves the message untouched. Returns a function that
       * removes the listener again.
       *
       * @example
       * const dispose = ioHost.on(IO.CDK_TOOLKIT_I2901, (msg) => {
       *   myCount += msg.data.stacks.length;
       * });
       */
      on(code, listener) {
        return this.addMessageListener(code.code, { once: false, fn: listener });
      }
      /**
       * Like `on`, but the listener is automatically removed after it has been
       * invoked once.
       */
      once(code, listener) {
        return this.addMessageListener(code.code, { once: true, fn: listener });
      }
      /**
       * Register a formatter that replaces the printed text of messages with the
       * given code. This lets a caller define _how_ a toolkit message is presented
       * without the IoHost needing to know about it.
       *
       * Syntactic sugar for an `on` listener that returns `{ message }`. Returns a
       * function that removes the formatter again.
       *
       * @example
       * const dispose = ioHost.rewrite(IO.CDK_TOOLKIT_I2901, (msg) =>
       *   serializeStructure(msg.data.stacks, true));
       */
      rewrite(code, formatter) {
        return this.on(code, (msg) => ({ message: formatter(msg) }));
      }
      /**
       * Like `rewrite`, but the formatter is automatically removed after it has
       * been applied once.
       */
      rewriteOnce(code, formatter) {
        return this.once(code, (msg) => ({ message: formatter(msg) }));
      }
      /**
       * Add a listener to the registry and return a function that removes it.
       */
      addMessageListener(code, listener) {
        const listeners = this.messageListeners.get(code) ?? [];
        listeners.push(listener);
        this.messageListeners.set(code, listeners);
        return () => {
          const index = listeners.indexOf(listener);
          if (index >= 0) {
            listeners.splice(index, 1);
          }
        };
      }
      /**
       * Run all registered listeners for a message's code, in registration order.
       *
       * A listener may update the message text (which is passed on to subsequent
       * listeners and the rest of the pipeline) and/or request that the default
       * processing be skipped. `once` listeners are removed after they have run.
       *
       * Returns the (possibly text-updated) message and whether any listener
       * prevented the default processing.
       */
      applyMessageListeners(msg) {
        let current = msg;
        let preventDefault = false;
        const listeners = msg.code ? this.messageListeners.get(msg.code) : void 0;
        if (listeners && listeners.length > 0) {
          for (const listener of [...listeners]) {
            const result2 = listener.fn(current);
            if (listener.once) {
              const index = listeners.indexOf(listener);
              if (index >= 0) {
                listeners.splice(index, 1);
              }
            }
            if (result2) {
              if (result2.message !== void 0) {
                current = { ...current, message: result2.message };
              }
              if (result2.preventDefault) {
                preventDefault = true;
              }
            }
          }
        }
        return { message: current, preventDefault };
      }
      /**
       * Notifies the host of a message.
       * The caller waits until the notification completes.
       */
      async notify(msg) {
        await this.maybeEmitTelemetry(msg);
        const { message: message2, preventDefault } = this.applyMessageListeners(msg);
        if (preventDefault) {
          return;
        }
        if (!isMessageRelevantForLevel(message2, this.logLevel)) {
          return;
        }
        if (this.corkedCounter > 0) {
          this.corkedLoggingBuffer.push(message2);
          return;
        }
        const output = this.formatMessage(message2);
        const stream = this.selectStream(message2);
        stream?.write(output);
      }
      async maybeEmitTelemetry(msg) {
        try {
          const telemetryEvent = eventFromMessage(msg);
          if (telemetryEvent) {
            await this.telemetry?.emit(telemetryEvent);
          }
        } catch (e32) {
          await this.defaults.trace(`Emit Telemetry Failed ${e32.message}`);
        }
      }
      /**
       * Route stack-activity messages to the activity printer (progress bar or
       * event list) rather than writing them to a stream.
       *
       * Implemented as listeners that handle the message via the printer and
       * prevent the default processing, so the rest of the pipeline does not also
       * emit them. The printer is created lazily on the first stack-activity message.
       */
      routeStackActivityToPrinter() {
        const route = /* @__PURE__ */ __name((msg) => {
          if (!this.activityPrinter) {
            this.activityPrinter = this.makeActivityPrinter();
          }
          this.activityPrinter.notify(msg);
          return { preventDefault: true };
        }, "route");
        this.on(IO.CDK_TOOLKIT_I5501, route);
        this.on(IO.CDK_TOOLKIT_I5502, route);
        this.on(IO.CDK_TOOLKIT_I5503, route);
      }
      /**
       * Detect special messages encode information about whether or not
       * they require approval
       */
      skipApprovalStep(msg) {
        const approvalToolkitCodes = ["CDK_TOOLKIT_I5060"];
        if (!(msg.code && approvalToolkitCodes.includes(msg.code))) {
          return false;
        }
        switch (this.requireDeployApproval) {
          // Never require approval
          case import_cloud_assembly_schema7.RequireApproval.NEVER:
            return true;
          // Always require approval
          case import_cloud_assembly_schema7.RequireApproval.ANYCHANGE:
            return false;
          // Require approval if changes include broadening permissions
          case import_cloud_assembly_schema7.RequireApproval.BROADENING:
            return ["none", "non-broadening"].includes(msg.data?.permissionChangeType);
        }
      }
      /**
       * Determines the output stream, based on message and configuration.
       */
      selectStream(msg) {
        if (isNoticesMessage(msg)) {
          return targetStreamObject(this.noticesDestination);
        }
        return this.selectStreamFromLevel(msg.level);
      }
      /**
       * Determines the output stream, based on message level and configuration.
       */
      selectStreamFromLevel(level) {
        switch (level) {
          case "error":
            return process.stderr;
          case "result":
            return process.stdout;
          default:
            return this.isCI ? process.stdout : process.stderr;
        }
      }
      /**
       * Notifies the host of a message that requires a response.
       *
       * If the host does not return a response the suggested
       * default response from the input message will be used.
       */
      async requestResponse(msg) {
        if (!isPromptableRequest(msg)) {
          await this.notify(msg);
          return msg.defaultResponse;
        }
        const response = await this.withCorkedLogging(async () => {
          const data3 = msg.data ?? {};
          const motivation = data3.motivation ?? "User input is needed";
          const concurrency = data3.concurrency ?? 0;
          const responseDescription = data3.responseDescription;
          if (this.skipApprovalStep(msg)) {
            return true;
          }
          if (this.autoRespond) {
            if (isConfirmationPrompt(msg)) {
              await this.notify({
                ...msg,
                message: `${chalk27.cyan(msg.message)} (auto-confirmed)`
              });
              return true;
            }
            if (msg.defaultResponse) {
              await this.notify({
                ...msg,
                message: `${chalk27.cyan(msg.message)} (auto-responded with default: ${util10.format(msg.defaultResponse)})`
              });
              return msg.defaultResponse;
            }
          }
          if (!this.isTTY) {
            throw new import_toolkit_lib7.ToolkitError("TtyNotAttached", `${motivation}, but terminal (TTY) is not attached so we are unable to get a confirmation from the user`);
          }
          if (concurrency > 1) {
            throw new import_toolkit_lib7.ToolkitError("ConcurrencyConflict", `${motivation}, but concurrency is greater than 1 so we are unable to get a confirmation from the user`);
          }
          if (isConfirmationPrompt(msg)) {
            const confirmed = await promptly.confirm(`${chalk27.cyan(msg.message)} (y/n)`);
            if (!confirmed) {
              throw new import_toolkit_lib7.ToolkitError("AbortedByUser", "Aborted by user");
            }
            return confirmed;
          }
          const prompt2 = extractPromptInfo(msg);
          const desc = responseDescription ?? prompt2.default;
          const answer = await promptly.prompt(`${chalk27.cyan(msg.message)}${desc ? ` (${desc})` : ""}`, {
            default: prompt2.default,
            trim: true
          });
          return prompt2.convertAnswer(answer);
        });
        return response;
      }
      /**
       * Formats a message for console output with optional color support
       */
      formatMessage(msg) {
        let message_text = this.isTTY ? styleMap2[msg.level](msg.message) : msg.message;
        return (msg.level === "debug" || msg.level === "trace" ? `[${this.formatTime(msg.time)}] ${message_text}` : message_text) + "\n";
      }
      /**
       * Formats date to HH:MM:SS
       */
      formatTime(d32) {
        const pad = /* @__PURE__ */ __name((n10) => n10.toString().padStart(2, "0"), "pad");
        return `${pad(d32.getHours())}:${pad(d32.getMinutes())}:${pad(d32.getSeconds())}`;
      }
      /**
       * Get an instance of the ActivityPrinter
       */
      makeActivityPrinter() {
        const props = {
          stream: this.selectStreamFromLevel("info")
        };
        switch (this.stackProgress) {
          case "events" /* EVENTS */:
            return new HistoryActivityPrinter(props);
          case "bar" /* BAR */:
            return new CurrentActivityPrinter(props);
        }
      }
    };
    __name(isPromptableRequest, "isPromptableRequest");
    __name(isConfirmationPrompt, "isConfirmationPrompt");
    __name(extractPromptInfo, "extractPromptInfo");
    styleMap2 = {
      error: chalk27.red,
      warn: chalk27.yellow,
      result: chalk27.reset,
      info: chalk27.reset,
      debug: chalk27.gray,
      trace: chalk27.gray
    };
    __name(targetStreamObject, "targetStreamObject");
    __name(isNoticesMessage, "isNoticesMessage");
    __name(eventFromMessage, "eventFromMessage");
    __name(hotswapToEventResult, "hotswapToEventResult");
  }
});

// lib/cli/io-host/index.ts
var init_io_host2 = __esm({
  "lib/cli/io-host/index.ts"() {
    "use strict";
    init_cli_io_host();
  }
});

// lib/api/context.ts
var init_context4 = __esm({
  "lib/api/context.ts"() {
    "use strict";
    init_context2();
  }
});

// lib/api/settings.ts
var init_settings2 = __esm({
  "lib/api/settings.ts"() {
    "use strict";
    init_settings();
  }
});

// lib/cli/user-configuration.ts
async function loadAndLog(ioHelper, fileName) {
  const ret = await settingsFromFile2(ioHelper, fileName);
  if (!ret.empty) {
    await ioHelper.defaults.debug(fileName + ":", JSON.stringify(ret.all, void 0, 2));
  }
  return ret;
}
async function settingsFromFile2(ioHelper, fileName) {
  let settings;
  const expanded = expandHomeDir2(fileName);
  if (await fs41.pathExists(expanded)) {
    const data3 = await fs41.readJson(expanded);
    settings = new Settings(data3);
  } else {
    settings = new Settings();
  }
  prohibitContextKeys(settings, ["default-account", "default-region"], fileName);
  await warnAboutContextKey(ioHelper, settings, "aws:", fileName);
  return settings;
}
function prohibitContextKeys(settings, keys, fileName) {
  const context = settings.get(["context"]);
  if (!context || typeof context !== "object") {
    return;
  }
  for (const key of keys) {
    if (key in context) {
      throw new import_toolkit_lib8.ToolkitError(
        "UnsupportedContextKey",
        `The 'context.${key}' key was found in ${fs_path2.resolve(
          fileName
        )}, but it is no longer supported. Please remove it.`
      );
    }
  }
}
async function warnAboutContextKey(ioHelper, settings, prefix, fileName) {
  const context = settings.get(["context"]);
  if (!context || typeof context !== "object") {
    return;
  }
  for (const contextKey of Object.keys(context)) {
    if (contextKey.startsWith(prefix)) {
      await ioHelper.defaults.warning(
        `A reserved context key ('context.${prefix}') key was found in ${fs_path2.resolve(
          fileName
        )}, it might cause surprising behavior and should be removed.`
      );
    }
  }
}
function expandHomeDir2(x) {
  if (x.startsWith("~")) {
    return fs_path2.join(os11.homedir(), x.slice(1));
  }
  return x;
}
async function commandLineArgumentsToSettings(ioHelper, argv) {
  const context = await parseStringContextListToObject(ioHelper, argv);
  const tags = await parseStringTagsListToObject(ioHelper, expectStringList(argv.tags));
  let bundlingStacks;
  if (BUNDLING_COMMANDS.includes(argv._[0])) {
    bundlingStacks = argv.exclusively ? argv.STACKS ?? ["**"] : ["**"];
  } else {
    bundlingStacks = [];
  }
  return new Settings({
    app: argv.app,
    browser: argv.browser,
    build: argv.build,
    caBundlePath: argv.caBundlePath,
    context,
    // The `--debug` implication (both debug targets) is resolved during argument
    // parsing, so here we only read the resolved per-target flags.
    debugApp: argv.debugApp,
    debugCli: argv.debugCli,
    verbose: argv.verbose,
    tags,
    language: argv.language,
    pathMetadata: argv.pathMetadata,
    assetMetadata: argv.assetMetadata,
    profile: argv.profile,
    region: argv.region,
    plugin: argv.plugin,
    requireApproval: argv.requireApproval,
    toolkitStackName: argv.toolkitStackName,
    toolkitBucket: {
      bucketName: argv.bootstrapBucketName,
      kmsKeyId: argv.bootstrapKmsKeyId
    },
    versionReporting: argv.versionReporting,
    staging: argv.staging,
    output: argv.output,
    outputsFile: argv.outputsFile,
    progress: argv.progress,
    proxy: argv.proxy,
    bundlingStacks,
    lookups: argv.lookups,
    rollback: argv.rollback,
    notices: argv.notices,
    assetParallelism: argv["asset-parallelism"],
    assetBuildConcurrency: argv["asset-build-concurrency"],
    assetPrebuild: argv["asset-prebuild"],
    ignoreNoStacks: argv["ignore-no-stacks"],
    hotswap: {
      ecs: {
        minimumHealthyPercent: argv.hotswapEcsMinimumHealthyPercent,
        maximumHealthyPercent: argv.hotswapEcsMaximumHealthyPercent,
        stabilizationTimeoutSeconds: argv.hotswapEcsStabilizationTimeoutSeconds
      }
    },
    unstable: argv.unstable
  });
}
function expectStringList(x) {
  if (x === void 0) {
    return void 0;
  }
  if (!Array.isArray(x)) {
    throw new import_toolkit_lib8.ToolkitError("ExpectedArray", `Expected array, got '${x}'`);
  }
  const nonStrings = x.filter((e32) => typeof e32 !== "string");
  if (nonStrings.length > 0) {
    throw new import_toolkit_lib8.ToolkitError("ExpectedStringList", `Expected list of strings, found ${nonStrings}`);
  }
  return x;
}
async function parseStringContextListToObject(ioHelper, argv) {
  const context = {};
  for (const assignment of argv.context || []) {
    const parts = assignment.split(/=(.*)/, 2);
    if (parts.length === 2) {
      await ioHelper.defaults.debug("CLI argument context: %s=%s", parts[0], parts[1]);
      if (parts[0].match(/^aws:.+/)) {
        throw new import_toolkit_lib8.ToolkitError(
          "ReservedContextPrefix",
          `User-provided context cannot use keys prefixed with 'aws:', but ${parts[0]} was provided.`
        );
      }
      context[parts[0]] = parts[1];
    } else {
      await ioHelper.defaults.warn(
        "Context argument is not an assignment (key=value): %s",
        assignment
      );
    }
  }
  return context;
}
async function parseStringTagsListToObject(ioHelper, argTags) {
  if (argTags === void 0) {
    return void 0;
  }
  if (argTags.length === 0) {
    return void 0;
  }
  const nonEmptyTags = argTags.filter((t) => t !== "");
  if (nonEmptyTags.length === 0) {
    return [];
  }
  const tags = [];
  for (const assignment of nonEmptyTags) {
    const parts = assignment.split(/=(.*)/, 2);
    if (parts.length === 2) {
      await ioHelper.defaults.debug("CLI argument tags: %s=%s", parts[0], parts[1]);
      tags.push({
        Key: parts[0],
        Value: parts[1]
      });
    } else {
      await ioHelper.defaults.warn("Tags argument is not an assignment (key=value): %s", assignment);
    }
  }
  return tags.length > 0 ? tags : void 0;
}
var os11, fs_path2, import_toolkit_lib8, fs41, PROJECT_CONFIG, USER_DEFAULTS, CONTEXT_KEY, BUNDLING_COMMANDS, Configuration;
var init_user_configuration = __esm({
  "lib/cli/user-configuration.ts"() {
    "use strict";
    os11 = __toESM(require("os"));
    fs_path2 = __toESM(require("path"));
    import_toolkit_lib8 = __toESM(require_lib12());
    fs41 = __toESM(require_lib4());
    init_context4();
    init_settings2();
    init_context4();
    PROJECT_CONFIG = "cdk.json";
    USER_DEFAULTS = "~/.cdk.json";
    CONTEXT_KEY = "context";
    BUNDLING_COMMANDS = [
      "deploy" /* DEPLOY */,
      "diff" /* DIFF */,
      "synth" /* SYNTH */,
      "synthesize" /* SYNTHESIZE */,
      "watch" /* WATCH */,
      "import" /* IMPORT */,
      "publish-assets" /* PUBLISH_ASSETS */
    ];
    Configuration = class _Configuration {
      constructor(ioHelper, commandLineArguments) {
        this.settings = new Settings();
        this.context = new Context();
        this.defaultConfig = new Settings({
          versionReporting: true,
          assetMetadata: true,
          pathMetadata: true,
          output: "cdk.out"
        });
        this.loaded = false;
        this.ioHelper = ioHelper;
        this.commandLineArguments = commandLineArguments;
        this.commandLineContext = this.commandLineArguments.subSettings([CONTEXT_KEY]).makeReadOnly();
      }
      static {
        __name(this, "Configuration");
      }
      /**
       * Creates user configuration from commandLineArguments
       */
      static async fromArgs(ioHelper, args) {
        const commandLineArguments = args ? await commandLineArgumentsToSettings(ioHelper, args) : new Settings();
        return new _Configuration(ioHelper, commandLineArguments);
      }
      /**
       * Creates user configuration from commandLineArguments and loads
       */
      static async fromArgsAndFiles(ioHelper, props = {}) {
        const configuration = await _Configuration.fromArgs(ioHelper, props.commandLineArguments);
        return configuration.loadConfigFiles(props.readUserContext ?? true);
      }
      get projectConfig() {
        if (!this._projectConfig) {
          throw new import_toolkit_lib8.ToolkitError("ConfigNotLoaded", "#load has not been called yet!");
        }
        return this._projectConfig;
      }
      get projectContext() {
        if (!this._projectContext) {
          throw new import_toolkit_lib8.ToolkitError("ConfigNotLoaded", "#load has not been called yet!");
        }
        return this._projectContext;
      }
      /**
       * Load all config
       */
      async loadConfigFiles(readUserContext) {
        const userConfig = await loadAndLog(this.ioHelper, USER_DEFAULTS);
        this._projectConfig = await loadAndLog(this.ioHelper, PROJECT_CONFIG);
        this._projectContext = await loadAndLog(this.ioHelper, PROJECT_CONTEXT);
        if (userConfig.get(["build"])) {
          throw new import_toolkit_lib8.ToolkitError(
            "BuildKeyInUserConfig",
            "The `build` key cannot be specified in the user config (~/.cdk.json), specify it in the project config (cdk.json) instead"
          );
        }
        const contextSources = [
          { bag: this.commandLineContext },
          {
            fileName: PROJECT_CONFIG,
            bag: this.projectConfig.subSettings([CONTEXT_KEY]).makeReadOnly()
          },
          { fileName: PROJECT_CONTEXT, bag: this.projectContext }
        ];
        if (readUserContext) {
          contextSources.push({
            fileName: USER_DEFAULTS,
            bag: userConfig.subSettings([CONTEXT_KEY]).makeReadOnly()
          });
        }
        this.context = new Context(...contextSources);
        const mergedSettings = this.defaultConfig.merge(userConfig).merge(this.projectConfig).merge(this.commandLineArguments);
        if (mergedSettings.get(["debug"])) {
          mergedSettings.set(["debugApp"], true);
          mergedSettings.set(["debugCli"], true);
        }
        this.settings = mergedSettings.makeReadOnly();
        await this.ioHelper.defaults.debug("merged settings:", this.settings.all);
        this.loaded = true;
        return this;
      }
      /**
       * Save the project context
       */
      async saveContext() {
        if (!this.loaded) {
          return this;
        }
        await this.projectContext.save(PROJECT_CONTEXT);
        return this;
      }
    };
    __name(loadAndLog, "loadAndLog");
    __name(settingsFromFile2, "settingsFromFile");
    __name(prohibitContextKeys, "prohibitContextKeys");
    __name(warnAboutContextKey, "warnAboutContextKey");
    __name(expandHomeDir2, "expandHomeDir");
    __name(commandLineArgumentsToSettings, "commandLineArgumentsToSettings");
    __name(expectStringList, "expectStringList");
    __name(parseStringContextListToObject, "parseStringContextListToObject");
    __name(parseStringTagsListToObject, "parseStringTagsListToObject");
  }
});

// lib/api/deploy-private.ts
var init_deploy_private = __esm({
  "lib/api/deploy-private.ts"() {
    "use strict";
    init_deployment_method();
  }
});

// lib/api/refactor.ts
var init_refactor3 = __esm({
  "lib/api/refactor.ts"() {
    "use strict";
    init_mapping_helpers();
  }
});

// lib/commands/list-stacks.ts
function formatStackList(stacks, options = {}) {
  const json = options.json ?? false;
  if (options.long && options.showDeps) {
    const full = stacks.map((stack) => ({
      id: stack.id,
      name: stack.name,
      environment: stack.environment,
      dependencies: stack.dependencies
    }));
    return serializeStructure(full, json);
  }
  if (options.showDeps) {
    const stackDeps = stacks.map((stack) => ({
      id: stack.id,
      dependencies: stack.dependencies
    }));
    return serializeStructure(stackDeps, json);
  }
  if (options.long) {
    const long = stacks.map((stack) => ({
      id: stack.id,
      name: stack.name,
      environment: stack.environment
    }));
    return serializeStructure(long, json);
  }
  return stacks.map((stack) => stack.id).join("\n");
}
var init_list_stacks = __esm({
  "lib/commands/list-stacks.ts"() {
    "use strict";
    init_util9();
    __name(formatStackList, "formatStackList");
  }
});

// ../../node_modules/cdk-from-cfn/index.js
var require_cdk_from_cfn = __commonJS({
  "../../node_modules/cdk-from-cfn/index.js"(exports2) {
    function supported_languages2() {
      const ret = wasm.supported_languages();
      var v1 = getArrayJsValueFromWasm0(ret[0], ret[1]).slice();
      wasm.__wbindgen_free(ret[0], ret[1] * 4, 4);
      return v1;
    }
    __name(supported_languages2, "supported_languages");
    exports2.supported_languages = supported_languages2;
    function transmute2(template, language, class_name, class_type) {
      let deferred6_0;
      let deferred6_1;
      try {
        const ptr0 = passStringToWasm0(template, wasm.__wbindgen_malloc, wasm.__wbindgen_realloc);
        const len0 = WASM_VECTOR_LEN;
        const ptr1 = passStringToWasm0(language, wasm.__wbindgen_malloc, wasm.__wbindgen_realloc);
        const len1 = WASM_VECTOR_LEN;
        const ptr2 = passStringToWasm0(class_name, wasm.__wbindgen_malloc, wasm.__wbindgen_realloc);
        const len2 = WASM_VECTOR_LEN;
        var ptr3 = isLikeNone(class_type) ? 0 : passStringToWasm0(class_type, wasm.__wbindgen_malloc, wasm.__wbindgen_realloc);
        var len3 = WASM_VECTOR_LEN;
        const ret = wasm.transmute(ptr0, len0, ptr1, len1, ptr2, len2, ptr3, len3);
        var ptr5 = ret[0];
        var len5 = ret[1];
        if (ret[3]) {
          ptr5 = 0;
          len5 = 0;
          throw takeFromExternrefTable0(ret[2]);
        }
        deferred6_0 = ptr5;
        deferred6_1 = len5;
        return getStringFromWasm0(ptr5, len5);
      } finally {
        wasm.__wbindgen_free(deferred6_0, deferred6_1, 1);
      }
    }
    __name(transmute2, "transmute");
    exports2.transmute = transmute2;
    function wasm_init() {
      wasm.wasm_init();
    }
    __name(wasm_init, "wasm_init");
    exports2.wasm_init = wasm_init;
    function __wbg_get_imports() {
      const import0 = {
        __proto__: null,
        __wbg_Error_3639a60ed15f87e7: /* @__PURE__ */ __name(function(arg0, arg1) {
          const ret = Error(getStringFromWasm0(arg0, arg1));
          return ret;
        }, "__wbg_Error_3639a60ed15f87e7"),
        __wbg_error_a6fa202b58aa1cd3: /* @__PURE__ */ __name(function(arg0, arg1) {
          let deferred0_0;
          let deferred0_1;
          try {
            deferred0_0 = arg0;
            deferred0_1 = arg1;
            console.error(getStringFromWasm0(arg0, arg1));
          } finally {
            wasm.__wbindgen_free(deferred0_0, deferred0_1, 1);
          }
        }, "__wbg_error_a6fa202b58aa1cd3"),
        __wbg_new_227d7c05414eb861: /* @__PURE__ */ __name(function() {
          const ret = new Error();
          return ret;
        }, "__wbg_new_227d7c05414eb861"),
        __wbg_stack_3b0d974bbf31e44f: /* @__PURE__ */ __name(function(arg0, arg1) {
          const ret = arg1.stack;
          const ptr1 = passStringToWasm0(ret, wasm.__wbindgen_malloc, wasm.__wbindgen_realloc);
          const len1 = WASM_VECTOR_LEN;
          getDataViewMemory0().setInt32(arg0 + 4 * 1, len1, true);
          getDataViewMemory0().setInt32(arg0 + 4 * 0, ptr1, true);
        }, "__wbg_stack_3b0d974bbf31e44f"),
        __wbindgen_cast_0000000000000001: /* @__PURE__ */ __name(function(arg0, arg1) {
          const ret = getStringFromWasm0(arg0, arg1);
          return ret;
        }, "__wbindgen_cast_0000000000000001"),
        __wbindgen_init_externref_table: /* @__PURE__ */ __name(function() {
          const table3 = wasm.__wbindgen_externrefs;
          const offset = table3.grow(4);
          table3.set(0, void 0);
          table3.set(offset + 0, void 0);
          table3.set(offset + 1, null);
          table3.set(offset + 2, true);
          table3.set(offset + 3, false);
        }, "__wbindgen_init_externref_table")
      };
      return {
        __proto__: null,
        "./index_bg.js": import0
      };
    }
    __name(__wbg_get_imports, "__wbg_get_imports");
    function getArrayJsValueFromWasm0(ptr, len) {
      ptr = ptr >>> 0;
      const mem = getDataViewMemory0();
      const result2 = [];
      for (let i32 = ptr; i32 < ptr + 4 * len; i32 += 4) {
        result2.push(wasm.__wbindgen_externrefs.get(mem.getUint32(i32, true)));
      }
      wasm.__externref_drop_slice(ptr, len);
      return result2;
    }
    __name(getArrayJsValueFromWasm0, "getArrayJsValueFromWasm0");
    var cachedDataViewMemory0 = null;
    function getDataViewMemory0() {
      if (cachedDataViewMemory0 === null || cachedDataViewMemory0.buffer.detached === true || cachedDataViewMemory0.buffer.detached === void 0 && cachedDataViewMemory0.buffer !== wasm.memory.buffer) {
        cachedDataViewMemory0 = new DataView(wasm.memory.buffer);
      }
      return cachedDataViewMemory0;
    }
    __name(getDataViewMemory0, "getDataViewMemory0");
    function getStringFromWasm0(ptr, len) {
      return decodeText(ptr >>> 0, len);
    }
    __name(getStringFromWasm0, "getStringFromWasm0");
    var cachedUint8ArrayMemory0 = null;
    function getUint8ArrayMemory0() {
      if (cachedUint8ArrayMemory0 === null || cachedUint8ArrayMemory0.byteLength === 0) {
        cachedUint8ArrayMemory0 = new Uint8Array(wasm.memory.buffer);
      }
      return cachedUint8ArrayMemory0;
    }
    __name(getUint8ArrayMemory0, "getUint8ArrayMemory0");
    function isLikeNone(x) {
      return x === void 0 || x === null;
    }
    __name(isLikeNone, "isLikeNone");
    function passStringToWasm0(arg, malloc, realloc) {
      if (realloc === void 0) {
        const buf = cachedTextEncoder.encode(arg);
        const ptr2 = malloc(buf.length, 1) >>> 0;
        getUint8ArrayMemory0().subarray(ptr2, ptr2 + buf.length).set(buf);
        WASM_VECTOR_LEN = buf.length;
        return ptr2;
      }
      let len = arg.length;
      let ptr = malloc(len, 1) >>> 0;
      const mem = getUint8ArrayMemory0();
      let offset = 0;
      for (; offset < len; offset++) {
        const code = arg.charCodeAt(offset);
        if (code > 127) break;
        mem[ptr + offset] = code;
      }
      if (offset !== len) {
        if (offset !== 0) {
          arg = arg.slice(offset);
        }
        ptr = realloc(ptr, len, len = offset + arg.length * 3, 1) >>> 0;
        const view = getUint8ArrayMemory0().subarray(ptr + offset, ptr + len);
        const ret = cachedTextEncoder.encodeInto(arg, view);
        offset += ret.written;
        ptr = realloc(ptr, len, offset, 1) >>> 0;
      }
      WASM_VECTOR_LEN = offset;
      return ptr;
    }
    __name(passStringToWasm0, "passStringToWasm0");
    function takeFromExternrefTable0(idx) {
      const value = wasm.__wbindgen_externrefs.get(idx);
      wasm.__externref_table_dealloc(idx);
      return value;
    }
    __name(takeFromExternrefTable0, "takeFromExternrefTable0");
    var cachedTextDecoder = new TextDecoder("utf-8", { ignoreBOM: true, fatal: true });
    cachedTextDecoder.decode();
    function decodeText(ptr, len) {
      return cachedTextDecoder.decode(getUint8ArrayMemory0().subarray(ptr, ptr + len));
    }
    __name(decodeText, "decodeText");
    var cachedTextEncoder = new TextEncoder();
    if (!("encodeInto" in cachedTextEncoder)) {
      cachedTextEncoder.encodeInto = function(arg, view) {
        const buf = cachedTextEncoder.encode(arg);
        view.set(buf);
        return {
          read: arg.length,
          written: buf.length
        };
      };
    }
    var WASM_VECTOR_LEN = 0;
    var wasmPath = `${__dirname}/index_bg.wasm`;
    var wasmBytes = require("fs").readFileSync(wasmPath);
    var wasmModule = new WebAssembly.Module(wasmBytes);
    var wasmInstance = new WebAssembly.Instance(wasmModule, __wbg_get_imports());
    var wasm = wasmInstance.exports;
    wasm.__wbindgen_start();
  }
});

// lib/commands/init/os.ts
async function shell2(ioHelper, command) {
  const commandLine = renderCommandLine2(command);
  await ioHelper.defaults.debug(`Executing ${chalk28.blue(commandLine)}`);
  const child = child_process3.spawn(command[0], renderArguments(command.slice(1)), {
    // Need this for Windows where we want .cmd and .bat to be found as well.
    shell: true,
    stdio: ["ignore", "pipe", "inherit"]
  });
  return new Promise((resolve13, reject) => {
    const stdout = new Array();
    child.stdout.on("data", (chunk) => {
      process.stdout.write(chunk);
      stdout.push(chunk);
    });
    child.once("error", reject);
    child.once("exit", (code) => {
      if (code === 0) {
        resolve13(Buffer.from(stdout).toString("utf-8"));
      } else {
        reject(new import_toolkit_lib9.ToolkitError("CommandFailed", `${commandLine} exited with error code ${code}`));
      }
    });
  });
}
function renderCommandLine2(cmd) {
  return renderArguments(cmd).join(" ");
}
function renderArguments(cmd) {
  if (process.platform !== "win32") {
    return doRender2(cmd, hasAnyChars2(" ", "\\", "!", '"', "'", "&", "$"), posixEscape2);
  } else {
    return doRender2(cmd, hasAnyChars2(" ", '"', "&", "^", "%"), windowsEscape2);
  }
}
function doRender2(cmd, needsEscaping, doEscape) {
  return cmd.map((x) => needsEscaping(x) ? doEscape(x) : x);
}
function hasAnyChars2(...chars6) {
  return (str) => {
    return chars6.some((c32) => str.indexOf(c32) !== -1);
  };
}
function posixEscape2(x) {
  x = x.replace(/'/g, `'"'"'`);
  return `'${x}'`;
}
function windowsEscape2(x) {
  x = `"${x}"`;
  const shellMeta = /* @__PURE__ */ new Set(['"', "&", "^", "%"]);
  return x.split("").map((c32) => shellMeta.has(x) ? "^" + c32 : c32).join("");
}
var child_process3, import_toolkit_lib9, chalk28;
var init_os = __esm({
  "lib/commands/init/os.ts"() {
    "use strict";
    child_process3 = __toESM(require("child_process"));
    import_toolkit_lib9 = __toESM(require_lib12());
    chalk28 = __toESM(require_source());
    __name(shell2, "shell");
    __name(renderCommandLine2, "renderCommandLine");
    __name(renderArguments, "renderArguments");
    __name(doRender2, "doRender");
    __name(hasAnyChars2, "hasAnyChars");
    __name(posixEscape2, "posixEscape");
    __name(windowsEscape2, "windowsEscape");
  }
});

// lib/commands/init/init-hooks.ts
async function invokeBuiltinHooks(ioHelper, target, context) {
  switch (target.language) {
    case "csharp":
      if (["app", "sample-app"].includes(target.templateName)) {
        return dotnetAddProject(ioHelper, target.targetDirectory, context);
      }
      break;
    case "fsharp":
      if (["app", "sample-app"].includes(target.templateName)) {
        return dotnetAddProject(ioHelper, target.targetDirectory, context, "fsproj");
      }
      break;
    case "python":
      await context.substitutePlaceholdersIn("requirements.txt");
      break;
    case "java":
      await context.substitutePlaceholdersIn("pom.xml");
      break;
    case "javascript":
    case "typescript":
      await context.substitutePlaceholdersIn("package.json", "README.md");
  }
}
async function dotnetAddProject(ioHelper, targetDirectory, context, ext = "csproj") {
  const pname = context.placeholder("name.PascalCased");
  const slnPath = path40.join(targetDirectory, "src", `${pname}.sln`);
  const csprojPath = path40.join(targetDirectory, "src", pname, `${pname}.${ext}`);
  const MAX_ATTEMPTS = 3;
  for (let attempt = 1; ; attempt++) {
    try {
      await shell2(ioHelper, ["dotnet", "sln", slnPath, "add", csprojPath]);
      return;
    } catch (e32) {
      if (attempt === MAX_ATTEMPTS) {
        throw new import_toolkit_lib10.ToolkitError("DotnetSlnAddFailed", `Could not add project ${pname}.${ext} to solution ${pname}.sln. ${formatErrorMessage(e32)}`);
      }
      await new Promise((resolve13) => setTimeout(resolve13, 1e3));
    }
  }
}
var path40, import_toolkit_lib10;
var init_init_hooks = __esm({
  "lib/commands/init/init-hooks.ts"() {
    "use strict";
    path40 = __toESM(require("path"));
    import_toolkit_lib10 = __toESM(require_lib12());
    init_os();
    init_util9();
    __name(invokeBuiltinHooks, "invokeBuiltinHooks");
    __name(dotnetAddProject, "dotnetAddProject");
  }
});

// lib/commands/language.ts
function getLanguageFromAlias(alias) {
  return SUPPORTED_LANGUAGES.find((l20) => l20.alias === alias || l20.name === alias)?.name;
}
function getLanguageExtensions(language) {
  return SUPPORTED_LANGUAGES.find((l20) => l20.name === language || l20.alias === language)?.extensions ?? [];
}
var SUPPORTED_LANGUAGES;
var init_language = __esm({
  "lib/commands/language.ts"() {
    "use strict";
    SUPPORTED_LANGUAGES = [
      { name: "csharp", alias: "cs", extensions: [".cs"] },
      { name: "fsharp", alias: "fs", extensions: [".fs"] },
      { name: "go", alias: "go", extensions: [".go"] },
      { name: "java", alias: "java", extensions: [".java"] },
      { name: "javascript", alias: "js", extensions: [".js"] },
      { name: "python", alias: "py", extensions: [".py"] },
      { name: "typescript", alias: "ts", extensions: [".ts", ".js"] }
    ];
    __name(getLanguageFromAlias, "getLanguageFromAlias");
    __name(getLanguageExtensions, "getLanguageExtensions");
  }
});

// lib/commands/init/package-manager.ts
var JS_PACKAGE_MANAGERS, getPmCmdPrefix;
var init_package_manager = __esm({
  "lib/commands/init/package-manager.ts"() {
    "use strict";
    JS_PACKAGE_MANAGERS = [
      { name: "npm", commandPrefix: "npm run" },
      { name: "yarn", commandPrefix: "yarn" },
      { name: "pnpm", commandPrefix: "pnpm" },
      { name: "bun", commandPrefix: "bun run" }
    ];
    getPmCmdPrefix = /* @__PURE__ */ __name((packageManager) => {
      return JS_PACKAGE_MANAGERS.find((pm) => pm.name === packageManager).commandPrefix;
    }, "getPmCmdPrefix");
  }
});

// ../../node_modules/camelcase/index.js
var require_camelcase = __commonJS({
  "../../node_modules/camelcase/index.js"(exports2, module2) {
    "use strict";
    var UPPERCASE = /[\p{Lu}]/u;
    var LOWERCASE = /[\p{Ll}]/u;
    var LEADING_CAPITAL = /^[\p{Lu}](?![\p{Lu}])/gu;
    var IDENTIFIER = /([\p{Alpha}\p{N}_]|$)/u;
    var SEPARATORS = /[_.\- ]+/;
    var LEADING_SEPARATORS = new RegExp("^" + SEPARATORS.source);
    var SEPARATORS_AND_IDENTIFIER = new RegExp(SEPARATORS.source + IDENTIFIER.source, "gu");
    var NUMBERS_AND_IDENTIFIER = new RegExp("\\d+" + IDENTIFIER.source, "gu");
    var preserveCamelCase = /* @__PURE__ */ __name((string, toLowerCase, toUpperCase) => {
      let isLastCharLower = false;
      let isLastCharUpper = false;
      let isLastLastCharUpper = false;
      for (let i32 = 0; i32 < string.length; i32++) {
        const character = string[i32];
        if (isLastCharLower && UPPERCASE.test(character)) {
          string = string.slice(0, i32) + "-" + string.slice(i32);
          isLastCharLower = false;
          isLastLastCharUpper = isLastCharUpper;
          isLastCharUpper = true;
          i32++;
        } else if (isLastCharUpper && isLastLastCharUpper && LOWERCASE.test(character)) {
          string = string.slice(0, i32 - 1) + "-" + string.slice(i32 - 1);
          isLastLastCharUpper = isLastCharUpper;
          isLastCharUpper = false;
          isLastCharLower = true;
        } else {
          isLastCharLower = toLowerCase(character) === character && toUpperCase(character) !== character;
          isLastLastCharUpper = isLastCharUpper;
          isLastCharUpper = toUpperCase(character) === character && toLowerCase(character) !== character;
        }
      }
      return string;
    }, "preserveCamelCase");
    var preserveConsecutiveUppercase = /* @__PURE__ */ __name((input, toLowerCase) => {
      LEADING_CAPITAL.lastIndex = 0;
      return input.replace(LEADING_CAPITAL, (m1) => toLowerCase(m1));
    }, "preserveConsecutiveUppercase");
    var postProcess = /* @__PURE__ */ __name((input, toUpperCase) => {
      SEPARATORS_AND_IDENTIFIER.lastIndex = 0;
      NUMBERS_AND_IDENTIFIER.lastIndex = 0;
      return input.replace(SEPARATORS_AND_IDENTIFIER, (_, identifier) => toUpperCase(identifier)).replace(NUMBERS_AND_IDENTIFIER, (m20) => toUpperCase(m20));
    }, "postProcess");
    var camelCase3 = /* @__PURE__ */ __name((input, options) => {
      if (!(typeof input === "string" || Array.isArray(input))) {
        throw new TypeError("Expected the input to be `string | string[]`");
      }
      options = {
        pascalCase: false,
        preserveConsecutiveUppercase: false,
        ...options
      };
      if (Array.isArray(input)) {
        input = input.map((x) => x.trim()).filter((x) => x.length).join("-");
      } else {
        input = input.trim();
      }
      if (input.length === 0) {
        return "";
      }
      const toLowerCase = options.locale === false ? (string) => string.toLowerCase() : (string) => string.toLocaleLowerCase(options.locale);
      const toUpperCase = options.locale === false ? (string) => string.toUpperCase() : (string) => string.toLocaleUpperCase(options.locale);
      if (input.length === 1) {
        return options.pascalCase ? toUpperCase(input) : toLowerCase(input);
      }
      const hasUpperCase = input !== toLowerCase(input);
      if (hasUpperCase) {
        input = preserveCamelCase(input, toLowerCase, toUpperCase);
      }
      input = input.replace(LEADING_SEPARATORS, "");
      if (options.preserveConsecutiveUppercase) {
        input = preserveConsecutiveUppercase(input, toLowerCase);
      } else {
        input = toLowerCase(input);
      }
      if (options.pascalCase) {
        input = toUpperCase(input.charAt(0)) + input.slice(1);
      }
      return postProcess(input, toUpperCase);
    }, "camelCase");
    module2.exports = camelCase3;
    module2.exports.default = camelCase3;
  }
});

// ../../node_modules/decamelize/index.js
var require_decamelize = __commonJS({
  "../../node_modules/decamelize/index.js"(exports2, module2) {
    "use strict";
    var handlePreserveConsecutiveUppercase = /* @__PURE__ */ __name((decamelized, separator) => {
      decamelized = decamelized.replace(
        /((?<![\p{Uppercase_Letter}\d])[\p{Uppercase_Letter}\d](?![\p{Uppercase_Letter}\d]))/gu,
        ($0) => {
          return $0.toLowerCase();
        }
      );
      return decamelized.replace(
        new RegExp("(\\p{Uppercase_Letter}+)(\\p{Uppercase_Letter}\\p{Lowercase_Letter}+)", "gu"),
        (_, $1, $2) => {
          return $1 + separator + $2.toLowerCase();
        }
      );
    }, "handlePreserveConsecutiveUppercase");
    module2.exports = (text, {
      separator = "_",
      preserveConsecutiveUppercase = false
    } = {}) => {
      if (!(typeof text === "string" && typeof separator === "string")) {
        throw new TypeError(
          "The `text` and `separator` arguments should be of type `string`"
        );
      }
      if (text.length < 2) {
        return preserveConsecutiveUppercase ? text : text.toLowerCase();
      }
      const replacement = `$1${separator}$2`;
      const decamelized = text.replace(
        new RegExp("([\\p{Lowercase_Letter}\\d])(\\p{Uppercase_Letter})", "gu"),
        replacement
      );
      if (preserveConsecutiveUppercase) {
        return handlePreserveConsecutiveUppercase(decamelized, separator);
      }
      return decamelized.replace(
        new RegExp("(\\p{Uppercase_Letter})(\\p{Uppercase_Letter}\\p{Lowercase_Letter}+)", "gu"),
        replacement
      ).toLowerCase();
    };
  }
});

// lib/commands/init/init.ts
async function cliInit(options) {
  await ensureValidCliInitOptions(options, options.ioHelper);
  const ioHelper = options.ioHelper;
  const canUseNetwork = options.canUseNetwork ?? true;
  const generateOnly = options.generateOnly ?? false;
  const workDir = options.workDir ?? process.cwd();
  if (!options.fromPath && !options.type && !options.language) {
    await printAvailableTemplates(ioHelper);
    return;
  }
  let template;
  if (options.fromPath) {
    template = await loadLocalTemplate(options.fromPath, options.templatePath);
  } else {
    template = await loadBuiltinTemplate(ioHelper, options.type, options.language);
  }
  const language = await resolveLanguage(ioHelper, template, options.language, options.type);
  await initializeProject(
    ioHelper,
    template,
    language,
    canUseNetwork,
    generateOnly,
    workDir,
    options.projectName,
    options.stackName,
    options.migrate,
    options.libVersion,
    options.packageManager
  );
}
async function ensureValidCliInitOptions(options, ioHelper) {
  if (options.packageManager && !["javascript", "typescript"].includes(options.language ?? "")) {
    await ioHelper.defaults.warn(`--package-manager option is only applicable for JavaScript and TypeScript projects. Ignoring the provided value: ${options.packageManager}`);
  }
}
async function loadLocalTemplate(fromPath, templatePath) {
  try {
    let actualTemplatePath = fromPath;
    if (templatePath) {
      actualTemplatePath = path41.join(fromPath, templatePath);
      if (!await fs42.pathExists(actualTemplatePath)) {
        throw new import_toolkit_lib11.ToolkitError("TemplatePathNotFound", `Template path does not exist: ${actualTemplatePath}`);
      }
    }
    const template = await InitTemplate.fromPath(actualTemplatePath);
    if (template.languages.length === 0) {
      if (!templatePath) {
        const availableTemplates = await findPotentialTemplates(fromPath);
        if (availableTemplates.length > 0) {
          throw new import_toolkit_lib11.ToolkitError(
            "TemplatePathRequired",
            "Use --template-path to specify which template to use."
          );
        }
      }
      throw new import_toolkit_lib11.ToolkitError("NoLanguageDirectory", "Custom template must contain at least one language directory");
    }
    return template;
  } catch (error4) {
    const displayPath = templatePath ? `${fromPath}/${templatePath}` : fromPath;
    throw new import_toolkit_lib11.ToolkitError("TemplateLoadFailed", `Failed to load template from path: ${displayPath}. ${error4.message}`);
  }
}
async function loadBuiltinTemplate(ioHelper, type, language) {
  const templateType = type || "default";
  const template = (await availableInitTemplates()).find((t) => t.hasName(templateType));
  if (!template) {
    await printAvailableTemplates(ioHelper, language);
    throw new import_toolkit_lib11.ToolkitError("UnknownTemplate", `Unknown init template: ${templateType}`);
  }
  return template;
}
async function resolveLanguage(ioHelper, template, requestedLanguage, type) {
  return (async () => {
    if (requestedLanguage) {
      return requestedLanguage;
    }
    if (template.languages.length === 1) {
      const templateLanguage = template.languages[0];
      if (template.templateType !== "custom" /* CUSTOM */) {
        await ioHelper.defaults.warn(
          `No --language was provided, but '${type || template.name}' supports only '${templateLanguage}', so defaulting to --language=${templateLanguage}`
        );
      }
      return templateLanguage;
    }
    await ioHelper.defaults.info(
      `Available languages for ${chalk29.green(type || template.name)}: ${template.languages.map((l20) => chalk29.blue(l20)).join(", ")}`
    );
    throw new import_toolkit_lib11.ToolkitError("NoLanguageSelected", "No language was selected");
  })();
}
async function findPotentialTemplates(repositoryPath) {
  const entries = await fs42.readdir(repositoryPath, { withFileTypes: true });
  const templateValidationPromises = entries.filter((entry) => entry.isDirectory() && !entry.name.startsWith(".")).map(async (entry) => {
    try {
      const templatePath = path41.join(repositoryPath, entry.name);
      const { languages } = await getLanguageDirectories(templatePath);
      return languages.length > 0 ? entry.name : null;
    } catch (error4) {
      return null;
    }
  });
  const validationResults = await Promise.all(templateValidationPromises);
  return validationResults.filter((templateName) => templateName !== null);
}
async function getLanguageDirectories(templatePath) {
  try {
    const entries = await fs42.readdir(templatePath, { withFileTypes: true });
    const languageValidationPromises = entries.filter((directoryEntry) => directoryEntry.isDirectory() && SUPPORTED_LANGUAGE_NAMES.includes(directoryEntry.name)).map(async (directoryEntry) => {
      const languageDirectoryPath = path41.join(templatePath, directoryEntry.name);
      try {
        const hasValidLanguageFiles = await hasLanguageFiles(languageDirectoryPath, getLanguageExtensions(directoryEntry.name));
        return hasValidLanguageFiles ? directoryEntry.name : null;
      } catch (error4) {
        throw new import_toolkit_lib11.ToolkitError("LanguageDirectoryReadFailed", `Cannot read language directory '${directoryEntry.name}': ${error4.message}`);
      }
    });
    const validationResults = await Promise.all(languageValidationPromises);
    return {
      languages: validationResults.filter((languageName) => languageName !== null),
      entries
    };
  } catch (error4) {
    throw new import_toolkit_lib11.ToolkitError("TemplateDirectoryReadFailed", `Cannot read template directory '${templatePath}': ${error4.message}`);
  }
}
async function hasLanguageFiles(directoryPath, extensions) {
  const dirsToCheck = [directoryPath];
  while (dirsToCheck.length > 0) {
    const currentDir = dirsToCheck.pop();
    try {
      const entries = await fs42.readdir(currentDir, { withFileTypes: true });
      for (const entry of entries) {
        if (entry.isFile() && extensions.some((ext) => entry.name.endsWith(ext))) {
          return true;
        } else if (entry.isDirectory()) {
          dirsToCheck.push(path41.join(currentDir, entry.name));
        }
      }
    } catch (error4) {
      throw error4;
    }
  }
  return false;
}
function pythonExecutable() {
  let python = "python3";
  if (process.platform === "win32") {
    python = "python";
  }
  return python;
}
function expandPlaceholders(template, language, project, packageManager) {
  const cdkCliVersion = project.versions["aws-cdk"];
  let cdkVersion = project.versions["aws-cdk-lib"];
  let constructsVersion = project.versions.constructs;
  switch (language) {
    case "java":
      cdkVersion = rangeFromSemver(cdkVersion, "bracket");
      constructsVersion = rangeFromSemver(constructsVersion, "bracket");
      break;
    case "csharp":
    case "fsharp":
      cdkVersion = rangeFromSemver(cdkVersion, "bracket");
      constructsVersion = rangeFromSemver(constructsVersion, "major.*");
      break;
    case "python":
      cdkVersion = rangeFromSemver(cdkVersion, "pep");
      constructsVersion = rangeFromSemver(constructsVersion, "pep");
      break;
    case "go":
      cdkVersion = stripCaret(cdkVersion);
      constructsVersion = stripCaret(constructsVersion);
      break;
  }
  return template.replace(/%name%/g, project.name).replace(/%stackname%/, project.stackName ?? "%name.PascalCased%Stack").replace(
    /%PascalNameSpace%/,
    project.stackName ? camelCase(project.stackName + "Stack", { pascalCase: true }) : "%name.PascalCased%"
  ).replace(
    /%PascalStackProps%/,
    project.stackName ? camelCase(project.stackName, { pascalCase: true }) + "StackProps" : "StackProps"
  ).replace(/%name\.camelCased%/g, camelCase(project.name)).replace(/%name\.PascalCased%/g, camelCase(project.name, { pascalCase: true })).replace(/%cdk-version%/g, cdkVersion).replace(/%cdk-cli-version%/g, cdkCliVersion).replace(/%constructs-version%/g, constructsVersion).replace(/%cdk-home%/g, cdkHomeDir()).replace(/%name\.PythonModule%/g, project.name.replace(/-/g, "_")).replace(/%python-executable%/g, pythonExecutable()).replace(/%name\.StackName%/g, project.name.replace(/[^A-Za-z0-9-]/g, "-")).replace(/%pm-cmd%/g, getPmCmdPrefix(packageManager ?? "npm"));
}
async function availableInitTemplates() {
  try {
    const templatesDir = path41.join(cliRootDir(), "lib", "init-templates");
    const templateNames = await listDirectory(templatesDir);
    const templatePromises = templateNames.map(
      (templateName) => InitTemplate.fromName(templatesDir, templateName)
    );
    return await Promise.all(templatePromises);
  } catch (error4) {
    if (error4.code === "ENOENT" || error4.code === "EACCES") {
      return [];
    }
    throw error4;
  }
}
async function listDirectory(dirPath) {
  return (await fs42.readdir(dirPath)).filter((p10) => !p10.startsWith(".")).filter((p10) => !(p10 === "LICENSE")).filter((p10) => !(p10 === INFO_DOT_JSON)).sort();
}
async function printAvailableTemplates(ioHelper, language) {
  await ioHelper.defaults.info("Available templates:");
  for (const template of await availableInitTemplates()) {
    if (language && template.languages.indexOf(language) === -1) {
      continue;
    }
    await ioHelper.defaults.info(`* ${chalk29.green(template.name)}: ${template.description}`);
    const languageArg = language ? chalk29.bold(language) : template.languages.length > 1 ? `[${template.languages.map((t) => chalk29.bold(t)).join("|")}]` : chalk29.bold(template.languages[0]);
    await ioHelper.defaults.info(`   \u2514\u2500 ${chalk29.blue(`cdk init ${chalk29.bold(template.name)} --language=${languageArg}`)}`);
  }
}
async function initializeProject(ioHelper, template, language, canUseNetwork, generateOnly, workDir, projectName, stackName, migrate, cdkVersion, packageManager) {
  await assertIsEmptyDirectory(workDir);
  await ioHelper.defaults.info(`Applying project template ${chalk29.green(template.name)} for ${chalk29.blue(language)}`);
  await template.install(ioHelper, language, workDir, projectName, stackName, cdkVersion, packageManager);
  if (migrate) {
    await template.addMigrateContext(workDir);
  }
  if (await fs42.pathExists(`${workDir}/README.md`)) {
    const readme = await fs42.readFile(`${workDir}/README.md`, { encoding: "utf-8" });
    await ioHelper.defaults.info(chalk29.green(readme));
  }
  if (!generateOnly) {
    await initializeGitRepository(ioHelper, workDir);
    await postInstall(ioHelper, language, canUseNetwork, workDir, packageManager);
  }
  await ioHelper.defaults.info("\u2705 All done!");
}
async function assertIsEmptyDirectory(workDir) {
  try {
    const stats = await fs42.stat(workDir);
    if (!stats.isDirectory()) {
      throw new import_toolkit_lib11.ToolkitError("PathNotDirectory", `Path exists but is not a directory: ${workDir}`);
    }
    const files = await fs42.readdir(workDir);
    const visibleFiles = files.filter((f32) => !f32.startsWith("."));
    if (visibleFiles.length > 0) {
      throw new import_toolkit_lib11.ToolkitError(
        "DirectoryNotEmpty",
        `\`cdk init\` cannot be run in a non-empty directory!
Found ${visibleFiles.length} visible files in ${workDir}:
` + visibleFiles.map((f32) => `  - ${f32}`).join("\n")
      );
    }
  } catch (e32) {
    if (e32.code === "ENOENT") {
      throw new import_toolkit_lib11.ToolkitError(
        "DirectoryNotFound",
        `Directory does not exist: ${workDir}
Please create the directory first using: mkdir -p ` + workDir
      );
    }
    throw new import_toolkit_lib11.ToolkitError("DirectoryValidationFailed", `Failed to validate directory ${workDir}: ${e32.message}`);
  }
}
async function initializeGitRepository(ioHelper, workDir) {
  if (await isInGitRepository(workDir)) {
    return;
  }
  await ioHelper.defaults.info("Initializing a new git repository...");
  try {
    await execute(ioHelper, "git", ["init"], { cwd: workDir });
    await execute(ioHelper, "git", ["add", "."], { cwd: workDir });
    await execute(ioHelper, "git", ["commit", '--message="Initial commit"', "--no-gpg-sign"], { cwd: workDir });
  } catch {
    await ioHelper.defaults.warn("Unable to initialize git repository for your project.");
  }
}
async function postInstall(ioHelper, language, canUseNetwork, workDir, packageManager) {
  switch (language) {
    case "javascript":
      return postInstallJavascript(ioHelper, canUseNetwork, workDir, packageManager);
    case "typescript":
      return postInstallTypescript(ioHelper, canUseNetwork, workDir, packageManager);
    case "java":
      return postInstallJava(ioHelper, canUseNetwork, workDir);
    case "python":
      return postInstallPython(ioHelper, workDir);
    case "go":
      return postInstallGo(ioHelper, canUseNetwork, workDir);
    case "csharp":
      return postInstallCSharp(ioHelper, canUseNetwork, workDir);
    case "fsharp":
      return postInstallFSharp(ioHelper, canUseNetwork, workDir);
  }
}
async function postInstallJavascript(ioHelper, canUseNetwork, cwd, packageManager) {
  return postInstallTypescript(ioHelper, canUseNetwork, cwd, packageManager);
}
async function postInstallTypescript(ioHelper, canUseNetwork, cwd, packageManager) {
  const command = packageManager ?? "npm";
  if (!canUseNetwork) {
    await ioHelper.defaults.warn(`Please run '${command} install'!`);
    return;
  }
  await ioHelper.defaults.info(`Executing ${chalk29.green(`${command} install`)}...`);
  try {
    await execute(ioHelper, command, ["install"], { cwd });
  } catch (e32) {
    await ioHelper.defaults.warn(`${command} install failed: ` + formatErrorMessage(e32));
  }
}
async function postInstallJava(ioHelper, canUseNetwork, cwd) {
  const hasGradleBuild = await fs42.pathExists(path41.join(cwd, "build.gradle"));
  const hasMavenPom = await fs42.pathExists(path41.join(cwd, "pom.xml"));
  if (hasGradleBuild) {
    const gradleWarning = "Please run './gradlew build'!";
    if (!canUseNetwork) {
      await ioHelper.defaults.warn(gradleWarning);
      return;
    }
    await ioHelper.defaults.info("Executing './gradlew build'");
    try {
      await execute(ioHelper, "./gradlew", ["build"], { cwd });
    } catch {
      await ioHelper.defaults.warn("Unable to build Gradle project");
      await ioHelper.defaults.warn(gradleWarning);
    }
  } else if (hasMavenPom) {
    const mvnPackageWarning = "Please run 'mvn package'!";
    if (!canUseNetwork) {
      await ioHelper.defaults.warn(mvnPackageWarning);
      return;
    }
    await ioHelper.defaults.info("Executing 'mvn package'");
    try {
      await execute(ioHelper, "mvn", ["package"], { cwd });
    } catch {
      await ioHelper.defaults.warn("Unable to package compiled code as JAR");
      await ioHelper.defaults.warn(mvnPackageWarning);
    }
  } else {
    await ioHelper.defaults.warn("No build.gradle or pom.xml found. Please set up your build system manually.");
  }
}
async function postInstallPython(ioHelper, cwd) {
  const python = pythonExecutable();
  const hasRequirements = await fs42.pathExists(path41.join(cwd, "requirements.txt"));
  if (hasRequirements) {
    await ioHelper.defaults.info(`Executing ${chalk29.green("Creating virtualenv...")}`);
    try {
      await execute(ioHelper, python, ["-m", "venv", ".venv"], { cwd });
      await ioHelper.defaults.info(`Executing ${chalk29.green("Installing dependencies...")}`);
      const pipPath = process.platform === "win32" ? ".venv\\Scripts\\pip" : ".venv/bin/pip";
      await execute(ioHelper, pipPath, ["install", "-r", "requirements.txt"], { cwd });
    } catch {
      await ioHelper.defaults.warn("Unable to create virtualenv or install dependencies automatically");
      await ioHelper.defaults.warn(`Please run '${python} -m venv .venv && .venv/bin/pip install -r requirements.txt'!`);
    }
  } else {
    await ioHelper.defaults.warn("No requirements.txt found. Please set up your Python environment manually.");
  }
}
async function postInstallGo(ioHelper, canUseNetwork, cwd) {
  if (!canUseNetwork) {
    await ioHelper.defaults.warn("Please run 'go mod tidy'!");
    return;
  }
  await ioHelper.defaults.info(`Executing ${chalk29.green("go mod tidy")}...`);
  try {
    await execute(ioHelper, "go", ["mod", "tidy"], { cwd });
  } catch (e32) {
    await ioHelper.defaults.warn("'go mod tidy' failed: " + formatErrorMessage(e32));
  }
}
async function postInstallCSharp(ioHelper, canUseNetwork, cwd) {
  const solutionDir = path41.join(cwd, "src");
  const dotnetWarning = "Please run 'cd src && dotnet restore && dotnet build'!";
  if (!canUseNetwork) {
    await ioHelper.defaults.warn(dotnetWarning);
    return;
  }
  await ioHelper.defaults.info(`Executing ${chalk29.green("dotnet restore")}...`);
  try {
    await execute(ioHelper, "dotnet", ["restore"], { cwd: solutionDir });
    await ioHelper.defaults.info(`Executing ${chalk29.green("dotnet build")}...`);
    await execute(ioHelper, "dotnet", ["build"], { cwd: solutionDir });
  } catch (e32) {
    await ioHelper.defaults.warn("Unable to restore/build .NET project: " + formatErrorMessage(e32));
    await ioHelper.defaults.warn(dotnetWarning);
  }
}
async function postInstallFSharp(ioHelper, canUseNetwork, cwd) {
  return postInstallCSharp(ioHelper, canUseNetwork, cwd);
}
async function isInGitRepository(dir) {
  while (true) {
    if (await fs42.pathExists(path41.join(dir, ".git"))) {
      return true;
    }
    if (isRoot(dir)) {
      return false;
    }
    dir = path41.dirname(dir);
  }
}
function isRoot(dir) {
  return path41.dirname(dir) === dir;
}
async function execute(ioHelper, cmd, args, { cwd }) {
  const child = childProcess.spawn(cmd, args, {
    cwd,
    shell: true,
    stdio: ["ignore", "pipe", "inherit"]
  });
  let stdout = "";
  child.stdout.on("data", (chunk) => stdout += chunk.toString());
  return new Promise((ok, fail) => {
    child.once("error", (err) => fail(err));
    child.once("exit", (status) => {
      if (status === 0) {
        return ok(stdout);
      } else {
        return fail(new import_toolkit_lib11.ToolkitError("CommandFailed", `${cmd} exited with status ${status}`));
      }
    });
  }).catch(async (err) => {
    await ioHelper.defaults.error(stdout);
    throw err;
  });
}
async function loadInitVersions() {
  const initVersionFile = path41.join(cliRootDir(), "lib", "init-templates", ".init-version.json");
  const contents = JSON.parse(await fs42.readFile(initVersionFile, { encoding: "utf-8" }));
  const ret = {
    "aws-cdk-lib": contents["aws-cdk-lib"],
    "constructs": contents.constructs,
    "aws-cdk": versionNumber2()
  };
  for (const [key, value] of Object.entries(ret)) {
    if (!value) {
      throw new import_toolkit_lib11.ToolkitError("MissingInitVersion", `Missing init version from ${initVersionFile}: ${key}`);
    }
  }
  return ret;
}
async function currentlyRecommendedAwsCdkLibFlags() {
  const recommendedFlagsFile = path41.join(cliRootDir(), "lib", "init-templates", ".recommended-feature-flags.json");
  const flags = JSON.parse(await fs42.readFile(recommendedFlagsFile, { encoding: "utf-8" }));
  const sortedKeys = Object.keys(flags).sort();
  return Object.fromEntries(sortedKeys.map((k32) => [k32, flags[k32]]));
}
var childProcess, path41, import_toolkit_lib11, chalk29, fs42, camelCase, decamelize, SUPPORTED_LANGUAGE_NAMES, INFO_DOT_JSON, InitTemplate;
var init_init = __esm({
  "lib/commands/init/init.ts"() {
    "use strict";
    childProcess = __toESM(require("child_process"));
    path41 = __toESM(require("path"));
    import_toolkit_lib11 = __toESM(require_lib12());
    chalk29 = __toESM(require_source());
    fs42 = __toESM(require_lib4());
    init_init_hooks();
    init_root_dir();
    init_version();
    init_util9();
    init_language();
    init_package_manager();
    camelCase = require_camelcase();
    decamelize = require_decamelize();
    SUPPORTED_LANGUAGE_NAMES = SUPPORTED_LANGUAGES.map((l20) => l20.name);
    __name(cliInit, "cliInit");
    __name(ensureValidCliInitOptions, "ensureValidCliInitOptions");
    __name(loadLocalTemplate, "loadLocalTemplate");
    __name(loadBuiltinTemplate, "loadBuiltinTemplate");
    __name(resolveLanguage, "resolveLanguage");
    __name(findPotentialTemplates, "findPotentialTemplates");
    __name(getLanguageDirectories, "getLanguageDirectories");
    __name(hasLanguageFiles, "hasLanguageFiles");
    __name(pythonExecutable, "pythonExecutable");
    INFO_DOT_JSON = "info.json";
    InitTemplate = class _InitTemplate {
      constructor(basePath, name, languages, initInfo, templateType) {
        this.basePath = basePath;
        this.name = name;
        this.languages = languages;
        this.aliases = /* @__PURE__ */ new Set();
        this.templateType = templateType;
        if (templateType === "builtin" /* BUILT_IN */ && initInfo) {
          this.description = initInfo.description;
          for (const alias of initInfo.aliases || []) {
            this.aliases.add(alias);
          }
        }
      }
      static {
        __name(this, "InitTemplate");
      }
      static async fromName(templatesDir, name) {
        const basePath = path41.join(templatesDir, name);
        const languages = await listDirectory(basePath);
        const initInfo = await fs42.readJson(path41.join(basePath, INFO_DOT_JSON));
        return new _InitTemplate(basePath, name, languages, initInfo, "builtin" /* BUILT_IN */);
      }
      static async fromPath(templatePath) {
        const basePath = path41.resolve(templatePath);
        if (!await fs42.pathExists(basePath)) {
          throw new import_toolkit_lib11.ToolkitError("TemplatePathNotFound", `Template path does not exist: ${basePath}`);
        }
        let templateSourcePath = basePath;
        let { languages, entries } = await getLanguageDirectories(basePath);
        if (languages.length === 0) {
          const languageDirs = entries.filter(
            (entry) => entry.isDirectory() && SUPPORTED_LANGUAGE_NAMES.includes(entry.name)
          );
          if (languageDirs.length === 1) {
            const langDir = languageDirs[0].name;
            templateSourcePath = path41.join(basePath, langDir);
            const hasValidFiles = await hasLanguageFiles(templateSourcePath, getLanguageExtensions(langDir));
            if (!hasValidFiles) {
              throw new import_toolkit_lib11.ToolkitError("InvalidLanguageFiles", `Found '${langDir}' directory but it doesn't contain the expected language files. Ensure the template contains ${langDir} source files.`);
            }
          }
        }
        const name = path41.basename(basePath);
        return new _InitTemplate(templateSourcePath, name, languages, null, "custom" /* CUSTOM */);
      }
      /**
       * @param name - the name that is being checked
       * @returns ``true`` if ``name`` is the name of this template or an alias of it.
       */
      hasName(name) {
        return name === this.name || this.aliases.has(name);
      }
      /**
       * Creates a new instance of this ``InitTemplate`` for a given language to a specified folder.
       *
       * @param language - the language to instantiate this template with
       * @param targetDirectory - the directory where the template is to be instantiated into
       * @param stackName - the name of the stack to create
       * @default undefined
       * @param libVersion - the version of the CDK library to use
       * @default undefined
       */
      async install(ioHelper, language, targetDirectory, projectName, stackName, libVersion, packageManager) {
        if (this.languages.indexOf(language) === -1) {
          await ioHelper.defaults.error(
            `The ${chalk29.blue(language)} language is not supported for ${chalk29.green(this.name)} (it supports: ${this.languages.map((l20) => chalk29.blue(l20)).join(", ")})`
          );
          throw new import_toolkit_lib11.ToolkitError("UnsupportedLanguage", `Unsupported language: ${language}`);
        }
        const projectInfo = {
          name: projectName ? decamelize(projectName) : decamelize(path41.basename(path41.resolve(targetDirectory))),
          stackName,
          versions: await loadInitVersions()
        };
        if (libVersion) {
          projectInfo.versions["aws-cdk-lib"] = libVersion;
        }
        let sourceDirectory = path41.join(this.basePath, language);
        if (this.templateType === "custom" /* CUSTOM */ && this.languages.length === 1 && path41.basename(this.basePath) === language) {
          sourceDirectory = this.basePath;
        }
        if (this.templateType === "custom" /* CUSTOM */) {
          await this.installFilesWithoutProcessing(sourceDirectory, targetDirectory);
        } else {
          await this.installFiles(sourceDirectory, targetDirectory, language, projectInfo, packageManager);
          await this.applyFutureFlags(targetDirectory);
          await invokeBuiltinHooks(
            ioHelper,
            { targetDirectory, language, templateName: this.name },
            {
              substitutePlaceholdersIn: /* @__PURE__ */ __name(async (...fileNames) => {
                const fileProcessingPromises = fileNames.map(async (fileName) => {
                  const fullPath = path41.join(targetDirectory, fileName);
                  const template = await fs42.readFile(fullPath, { encoding: "utf-8" });
                  await fs42.writeFile(fullPath, expandPlaceholders(template, language, projectInfo, packageManager));
                });
                await Promise.all(fileProcessingPromises);
              }, "substitutePlaceholdersIn"),
              placeholder: /* @__PURE__ */ __name((ph) => expandPlaceholders(`%${ph}%`, language, projectInfo, packageManager), "placeholder")
            }
          );
        }
      }
      async installFiles(sourceDirectory, targetDirectory, language, project, packageManager) {
        for (const file of await fs42.readdir(sourceDirectory)) {
          const fromFile = path41.join(sourceDirectory, file);
          const toFile = path41.join(targetDirectory, expandPlaceholders(file, language, project, packageManager));
          if ((await fs42.stat(fromFile)).isDirectory()) {
            await fs42.mkdir(toFile);
            await this.installFiles(fromFile, toFile, language, project, packageManager);
            continue;
          } else if (file.match(/^.*\.template\.[^.]+$/)) {
            await this.installProcessed(fromFile, toFile.replace(/\.template(\.[^.]+)$/, "$1"), language, project, packageManager);
            continue;
          } else if (file.match(/^.*\.hook\.(d.)?[^.]+$/)) {
            continue;
          } else {
            await fs42.copy(fromFile, toFile);
          }
        }
      }
      async installProcessed(templatePath, toFile, language, project, packageManager) {
        const template = await fs42.readFile(templatePath, { encoding: "utf-8" });
        await fs42.writeFile(toFile, expandPlaceholders(template, language, project, packageManager));
      }
      /**
       * Copy template files without processing placeholders (for custom templates)
       */
      async installFilesWithoutProcessing(sourceDirectory, targetDirectory) {
        await fs42.copy(sourceDirectory, targetDirectory, {
          filter: /* @__PURE__ */ __name((src) => {
            const filename = path41.basename(src);
            return !filename.match(/^.*\.hook\.(d.)?[^.]+$/);
          }, "filter")
        });
      }
      /**
       * Adds context variables to `cdk.json` in the generated project directory to
       * enable future behavior for new projects.
       */
      async applyFutureFlags(projectDir) {
        const cdkJson = path41.join(projectDir, "cdk.json");
        if (!await fs42.pathExists(cdkJson)) {
          return;
        }
        const config2 = await fs42.readJson(cdkJson);
        config2.context = {
          ...config2.context,
          ...await currentlyRecommendedAwsCdkLibFlags()
        };
        await fs42.writeJson(cdkJson, config2, { spaces: 2 });
      }
      async addMigrateContext(projectDir) {
        const cdkJson = path41.join(projectDir, "cdk.json");
        if (!await fs42.pathExists(cdkJson)) {
          return;
        }
        const config2 = await fs42.readJson(cdkJson);
        config2.context = {
          ...config2.context,
          "cdk-migrate": true
        };
        await fs42.writeJson(cdkJson, config2, { spaces: 2 });
      }
    };
    __name(expandPlaceholders, "expandPlaceholders");
    __name(availableInitTemplates, "availableInitTemplates");
    __name(listDirectory, "listDirectory");
    __name(printAvailableTemplates, "printAvailableTemplates");
    __name(initializeProject, "initializeProject");
    __name(assertIsEmptyDirectory, "assertIsEmptyDirectory");
    __name(initializeGitRepository, "initializeGitRepository");
    __name(postInstall, "postInstall");
    __name(postInstallJavascript, "postInstallJavascript");
    __name(postInstallTypescript, "postInstallTypescript");
    __name(postInstallJava, "postInstallJava");
    __name(postInstallPython, "postInstallPython");
    __name(postInstallGo, "postInstallGo");
    __name(postInstallCSharp, "postInstallCSharp");
    __name(postInstallFSharp, "postInstallFSharp");
    __name(isInGitRepository, "isInGitRepository");
    __name(isRoot, "isRoot");
    __name(execute, "execute");
    __name(loadInitVersions, "loadInitVersions");
    __name(currentlyRecommendedAwsCdkLibFlags, "currentlyRecommendedAwsCdkLibFlags");
  }
});

// lib/commands/init/index.ts
var init_init2 = __esm({
  "lib/commands/init/index.ts"() {
    "use strict";
    init_init();
  }
});

// lib/api/plugin.ts
var init_plugin3 = __esm({
  "lib/api/plugin.ts"() {
    "use strict";
    init_plugin2();
  }
});

// lib/commands/migrate.ts
async function generateCdkApp(ioHelper, stackName, stack, language, outputPath, compress) {
  const resolvedOutputPath = path42.join(outputPath ?? process.cwd(), stackName);
  const formattedStackName = decamelize2(stackName);
  try {
    fs43.rmSync(resolvedOutputPath, { recursive: true, force: true });
    fs43.mkdirSync(resolvedOutputPath, { recursive: true });
    const generateOnly = compress;
    await cliInit({
      ioHelper,
      type: "app",
      language,
      canUseNetwork: true,
      generateOnly,
      workDir: resolvedOutputPath,
      stackName,
      migrate: true
    });
    let stackFileName;
    switch (language) {
      case "typescript":
        stackFileName = `${resolvedOutputPath}/lib/${formattedStackName}-stack.ts`;
        break;
      case "java":
        stackFileName = `${resolvedOutputPath}/src/main/java/com/myorg/${camelCase2(formattedStackName, { pascalCase: true })}Stack.java`;
        break;
      case "python":
        stackFileName = `${resolvedOutputPath}/${formattedStackName.replace(/-/g, "_")}/${formattedStackName.replace(/-/g, "_")}_stack.py`;
        break;
      case "csharp":
        stackFileName = `${resolvedOutputPath}/src/${camelCase2(formattedStackName, { pascalCase: true })}/${camelCase2(formattedStackName, { pascalCase: true })}Stack.cs`;
        break;
      case "go":
        stackFileName = `${resolvedOutputPath}/${formattedStackName}.go`;
        break;
      default:
        throw new import_toolkit_lib12.ToolkitError(
          "UnsupportedMigrateLanguage",
          `${language} is not supported by CDK Migrate. Please choose from: ${MIGRATE_SUPPORTED_LANGUAGES.join(", ")}`
        );
    }
    fs43.writeFileSync(stackFileName, stack);
    if (compress) {
      await (0, import_zip.zipDirectory)(resolvedOutputPath, `${resolvedOutputPath}.zip`);
      fs43.rmSync(resolvedOutputPath, { recursive: true, force: true });
    }
  } catch (error4) {
    fs43.rmSync(resolvedOutputPath, { recursive: true, force: true });
    throw error4;
  }
}
function generateStack(template, stackName, language) {
  const formattedStackName = `${camelCase2(decamelize2(stackName), { pascalCase: true })}Stack`;
  try {
    return cdk_from_cfn.transmute(template, language, formattedStackName);
  } catch (e32) {
    throw new import_toolkit_lib12.ToolkitError("StackGenerationFailed", `${formattedStackName} could not be generated because ${e32.message}`);
  }
}
function readFromPath(inputPath) {
  let readFile15;
  try {
    readFile15 = fs43.readFileSync(inputPath, "utf8");
  } catch (e32) {
    throw new import_toolkit_lib12.ToolkitError("InvalidPath", `'${inputPath}' is not a valid path.`);
  }
  if (readFile15 == "") {
    throw new import_toolkit_lib12.ToolkitError("EmptyTemplateFile", `Cloudformation template filepath: '${inputPath}' is an empty file.`);
  }
  return readFile15;
}
async function readFromStack(stackName, sdkProvider, environment) {
  const cloudFormation = (await sdkProvider.forEnvironment(environment, 0 /* ForReading */)).sdk.cloudFormation();
  const stack = await CloudFormationStack.lookup(cloudFormation, stackName, true);
  if (stack.stackStatus.isDeploySuccess || stack.stackStatus.isRollbackSuccess) {
    return JSON.stringify(await stack.template());
  } else {
    throw new import_toolkit_lib12.ToolkitError(
      "UnhealthyStackStatus",
      `Stack '${stackName}' in account ${environment.account} and region ${environment.region} has a status of '${stack.stackStatus.name}' due to '${stack.stackStatus.reason}'. The stack cannot be migrated until it is in a healthy state.`
    );
  }
}
async function generateTemplate(options) {
  const cfn = new CfnTemplateGeneratorProvider(await buildCfnClient(options.sdkProvider, options.environment), options.ioHelper);
  const ioHelper = options.ioHelper;
  const scanId = await findLastSuccessfulScan(cfn, options);
  const curScan = await cfn.describeResourceScan(scanId);
  if (curScan.Status == "IN_PROGRESS" /* IN_PROGRESS */) {
    await ioHelper.defaults.info("Resource scan in progress. Please wait, this can take 10 minutes or longer.");
    await scanProgressBar(ioHelper, scanId, cfn);
  }
  await displayTimeDiff(ioHelper, /* @__PURE__ */ new Date(), new Date(curScan.StartTime));
  let resources = await cfn.listResourceScanResources(scanId, options.filters);
  await ioHelper.defaults.info("finding related resources.");
  let relatedResources = await cfn.getResourceScanRelatedResources(scanId, resources);
  await ioHelper.defaults.info(`Found ${relatedResources.length} resources.`);
  await ioHelper.defaults.info("Generating CFN template from scanned resources.");
  const templateArn = (await cfn.createGeneratedTemplate(options.stackName, relatedResources)).GeneratedTemplateId;
  let generatedTemplate = await cfn.describeGeneratedTemplate(templateArn);
  await ioHelper.defaults.info("Please wait, template creation in progress. This may take a couple minutes.");
  while (generatedTemplate.Status !== "COMPLETE" /* COMPLETE */ && generatedTemplate.Status !== "FAILED" /* FAILED */) {
    await printDots(`[${generatedTemplate.Status}] Template Creation in Progress`, 400);
    generatedTemplate = await cfn.describeGeneratedTemplate(templateArn);
  }
  await ioHelper.defaults.info("\nTemplate successfully generated!");
  return buildGeneratedTemplateOutput(
    generatedTemplate,
    (await cfn.getGeneratedTemplate(templateArn)).TemplateBody,
    templateArn
  );
}
async function findLastSuccessfulScan(cfn, options) {
  const ioHelper = options.ioHelper;
  let resourceScanSummaries = [];
  const clientRequestToken = `cdk-migrate-${options.environment.account}-${options.environment.region}`;
  if (options.fromScan === 0 /* NEW */) {
    await ioHelper.defaults.info(`Starting new scan for account ${options.environment.account} in region ${options.environment.region}`);
    try {
      await cfn.startResourceScan(clientRequestToken);
      resourceScanSummaries = (await cfn.listResourceScans()).ResourceScanSummaries;
    } catch (e32) {
      await ioHelper.defaults.info(`Scan failed to start due to error '${e32.message}', defaulting to latest scan.`);
    }
  } else {
    resourceScanSummaries = (await cfn.listResourceScans()).ResourceScanSummaries;
    await cfn.checkForResourceScan(resourceScanSummaries, options, clientRequestToken);
  }
  resourceScanSummaries = (await cfn.listResourceScans()).ResourceScanSummaries;
  let scanId = resourceScanSummaries[0].ResourceScanId;
  for (const summary of resourceScanSummaries) {
    if (summary.Status !== "FAILED" /* FAILED */) {
      scanId = summary.ResourceScanId;
      break;
    }
  }
  return scanId;
}
function parseFilters(filters) {
  if (!filters) {
    return {
      "resource-identifier": void 0,
      "resource-type-prefix": void 0,
      "tag-key": void 0,
      "tag-value": void 0
    };
  }
  const filterShorthands = {
    "identifier": "resource-identifier" /* RESOURCE_IDENTIFIER */,
    "id": "resource-identifier" /* RESOURCE_IDENTIFIER */,
    "type": "resource-type-prefix" /* RESOURCE_TYPE_PREFIX */,
    "type-prefix": "resource-type-prefix" /* RESOURCE_TYPE_PREFIX */
  };
  const filterList = filters.split(",");
  let filterMap = {
    ["resource-identifier" /* RESOURCE_IDENTIFIER */]: void 0,
    ["resource-type-prefix" /* RESOURCE_TYPE_PREFIX */]: void 0,
    ["tag-key" /* TAG_KEY */]: void 0,
    ["tag-value" /* TAG_VALUE */]: void 0
  };
  for (const fil of filterList) {
    const filter = fil.split("=");
    let filterKey = filter[0];
    const filterValue = filter[1];
    if (filterKey in filterShorthands) {
      filterKey = filterShorthands[filterKey];
    }
    if (Object.values(FilterType).includes(filterKey)) {
      filterMap[filterKey] = filterValue;
    } else {
      throw new import_toolkit_lib12.ToolkitError("InvalidFilter", `Invalid filter: ${filterKey}`);
    }
  }
  return filterMap;
}
function chunks(list3, chunkSize) {
  const chunkedList = [];
  for (let i32 = 0; i32 < list3.length; i32 += chunkSize) {
    chunkedList.push(list3.slice(i32, i32 + chunkSize));
  }
  return chunkedList;
}
function setEnvironment(account, region) {
  return {
    account: account ?? import_cloud_assembly_api16.UNKNOWN_ACCOUNT,
    region: region ?? import_cloud_assembly_api16.UNKNOWN_REGION,
    name: "cdk-migrate-env"
  };
}
function parseSourceOptions(fromPath, fromStack, stackName) {
  if (fromPath && fromStack) {
    throw new import_toolkit_lib12.ToolkitError("ConflictingSourceOptions", "Only one of `--from-path` or `--from-stack` may be provided.");
  }
  if (!stackName) {
    throw new import_toolkit_lib12.ToolkitError("MissingStackName", "`--stack-name` is a required field.");
  }
  if (!fromPath && !fromStack) {
    return { source: "scan" /* SCAN */ };
  }
  if (fromPath) {
    return { source: "path" /* PATH */, templatePath: fromPath };
  }
  return { source: "stack" /* STACK */, stackName };
}
function excludeManaged(resourceList) {
  return resourceList.filter((r32) => !r32.ManagedByStack).map((r32) => ({
    ResourceType: r32.ResourceType,
    ResourceIdentifier: r32.ResourceIdentifier
  }));
}
function resourceIdentifiers(resourceList) {
  const identifiers = [];
  resourceList.forEach((r32) => {
    const identifier = {
      ResourceType: r32.ResourceType,
      ResourceIdentifier: r32.ResourceIdentifier
    };
    identifiers.push(identifier);
  });
  return identifiers;
}
async function scanProgressBar(ioHelper, scanId, cfn) {
  let curProgress = 0.5;
  let curScan = {
    Status: "IN_PROGRESS" /* IN_PROGRESS */,
    $metadata: {}
  };
  while (curScan.Status == "IN_PROGRESS" /* IN_PROGRESS */) {
    curScan = await cfn.describeResourceScan(scanId);
    curProgress = curScan.PercentageCompleted ?? curProgress;
    printBar(30, curProgress);
    await new Promise((resolve13) => setTimeout(resolve13, 2e3));
  }
  await ioHelper.defaults.info("\n\u2705 Scan Complete!");
}
function printBar(width, progress) {
  if (!process.env.MIGRATE_INTEG_TEST) {
    const FULL_BLOCK2 = "\u2588";
    const PARTIAL_BLOCK2 = ["", "\u258F", "\u258E", "\u258D", "\u258C", "\u258B", "\u258A", "\u2589"];
    const fraction = Math.min(progress / 100, 1);
    const innerWidth = Math.max(1, width - 2);
    const chars6 = innerWidth * fraction;
    const remainder = chars6 - Math.floor(chars6);
    const fullChars = FULL_BLOCK2.repeat(Math.floor(chars6));
    const partialChar = PARTIAL_BLOCK2[Math.floor(remainder * PARTIAL_BLOCK2.length)];
    const filler = "\xB7".repeat(innerWidth - Math.floor(chars6) - (partialChar ? 1 : 0));
    const color = chalk30.green;
    rewriteLine("[" + color(fullChars + partialChar) + filler + `] (${progress}%)`);
  }
}
async function printDots(message2, timeoutx4) {
  if (!process.env.MIGRATE_INTEG_TEST) {
    rewriteLine(message2 + " .");
    await new Promise((resolve13) => setTimeout(resolve13, timeoutx4));
    rewriteLine(message2 + " ..");
    await new Promise((resolve13) => setTimeout(resolve13, timeoutx4));
    rewriteLine(message2 + " ...");
    await new Promise((resolve13) => setTimeout(resolve13, timeoutx4));
    rewriteLine(message2);
    await new Promise((resolve13) => setTimeout(resolve13, timeoutx4));
  }
}
function rewriteLine(message2) {
  process.stdout.clearLine(0);
  process.stdout.cursorTo(0);
  process.stdout.write(message2);
}
async function displayTimeDiff(ioHelper, time1, time22) {
  const diff = Math.abs(time1.getTime() - time22.getTime());
  const days = Math.floor(diff / (1e3 * 60 * 60 * 24));
  const hours = Math.floor(diff % (1e3 * 60 * 60 * 24) / (1e3 * 60 * 60));
  const minutes = Math.floor(diff % (1e3 * 60 * 60) / (1e3 * 60));
  await ioHelper.defaults.info(`Using the latest successful scan which is ${days} days, ${hours} hours, and ${minutes} minutes old.`);
}
function writeMigrateJsonFile(outputPath, stackName, migrateJson) {
  const outputToJson = {
    "//": "This file is generated by cdk migrate. It will be automatically deleted after the first successful deployment of this app to the environment of the original resources.",
    "Source": migrateJson.source,
    "Resources": migrateJson.resources
  };
  fs43.writeFileSync(
    `${path42.join(outputPath ?? process.cwd(), stackName)}/migrate.json`,
    JSON.stringify(outputToJson, null, 2)
  );
}
function getMigrateScanType(scanType) {
  switch (scanType) {
    case "new":
      return 0 /* NEW */;
    case "most-recent":
      return 1 /* MOST_RECENT */;
    case "":
      return 2 /* DEFAULT */;
    case void 0:
      return 2 /* DEFAULT */;
    default:
      throw new import_toolkit_lib12.ToolkitError("UnknownScanType", `Unknown scan type: ${scanType}`);
  }
}
function isThereAWarning(generatedTemplateOutput) {
  if (generatedTemplateOutput.resources) {
    for (const resource of generatedTemplateOutput.resources) {
      if (resource.Warnings && resource.Warnings.length > 0) {
        return true;
      }
    }
  }
  return false;
}
function buildGeneratedTemplateOutput(generatedTemplateSummary, templateBody, source) {
  const resources = generatedTemplateSummary.Resources;
  const migrateJson = {
    templateBody,
    source,
    resources: generatedTemplateSummary.Resources.map((r32) => ({
      ResourceType: r32.ResourceType,
      LogicalResourceId: r32.LogicalResourceId,
      ResourceIdentifier: r32.ResourceIdentifier
    }))
  };
  const templateId = generatedTemplateSummary.GeneratedTemplateId;
  return {
    migrateJson,
    resources,
    templateId
  };
}
async function buildCfnClient(sdkProvider, environment) {
  const sdk = (await sdkProvider.forEnvironment(environment, 0 /* ForReading */)).sdk;
  sdk.appendCustomUserAgent("cdk-migrate");
  return sdk.cloudFormation();
}
function appendWarningsToReadme(filepath, resources) {
  const readme = fs43.readFileSync(filepath, "utf8");
  const lines = readme.split("\n");
  const index = lines.findIndex((line) => line.trim() === "Enjoy!");
  let linesToAdd = ["\n## Warnings"];
  linesToAdd.push("### Write-only properties");
  linesToAdd.push(
    "Write-only properties are resource property values that can be written to but can't be read by AWS CloudFormation or CDK Migrate. For more information, see [IaC generator and write-only properties](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/generate-IaC-write-only-properties.html)."
  );
  linesToAdd.push("\n");
  linesToAdd.push(
    "Write-only properties discovered during migration are organized here by resource ID and categorized by write-only property type. Resolve write-only properties by providing property values in your CDK app. For guidance, see [Resolve write-only properties](https://docs.aws.amazon.com/cdk/v2/guide/migrate.html#migrate-resources-writeonly)."
  );
  for (const resource of resources) {
    if (resource.Warnings && resource.Warnings.length > 0) {
      linesToAdd.push(`### ${resource.LogicalResourceId}`);
      for (const warning2 of resource.Warnings) {
        linesToAdd.push(`- **${warning2.Type}**: `);
        for (const property of warning2.Properties) {
          linesToAdd.push(`  - ${property.PropertyPath}: ${property.Description}`);
        }
      }
    }
  }
  lines.splice(index, 0, ...linesToAdd);
  fs43.writeFileSync(filepath, lines.join("\n"));
}
function deduplicateResources(resources) {
  let uniqueResources = {};
  for (const resource of resources) {
    const key = Object.keys(resource.ResourceIdentifier)[0];
    const uniqueIdentifer = `${resource.ResourceType}:${key}:${resource.ResourceIdentifier[key]}`;
    uniqueResources[uniqueIdentifer] = resource;
  }
  return Object.values(uniqueResources);
}
var fs43, path42, import_cloud_assembly_api16, import_zip, import_toolkit_lib12, cdk_from_cfn, chalk30, camelCase2, decamelize2, MIGRATE_SUPPORTED_LANGUAGES, FilterType, CfnTemplateGeneratorProvider;
var init_migrate = __esm({
  "lib/commands/migrate.ts"() {
    "use strict";
    fs43 = __toESM(require("fs"));
    path42 = __toESM(require("path"));
    import_cloud_assembly_api16 = __toESM(require_lib3());
    import_zip = __toESM(require_zip());
    import_toolkit_lib12 = __toESM(require_lib12());
    cdk_from_cfn = __toESM(require_cdk_from_cfn());
    chalk30 = __toESM(require_source());
    init_init2();
    init_cloudformation3();
    init_plugin3();
    camelCase2 = require_camelcase();
    decamelize2 = require_decamelize();
    MIGRATE_SUPPORTED_LANGUAGES = cdk_from_cfn.supported_languages();
    __name(generateCdkApp, "generateCdkApp");
    __name(generateStack, "generateStack");
    __name(readFromPath, "readFromPath");
    __name(readFromStack, "readFromStack");
    __name(generateTemplate, "generateTemplate");
    __name(findLastSuccessfulScan, "findLastSuccessfulScan");
    __name(parseFilters, "parseFilters");
    __name(chunks, "chunks");
    __name(setEnvironment, "setEnvironment");
    FilterType = /* @__PURE__ */ ((FilterType2) => {
      FilterType2["RESOURCE_IDENTIFIER"] = "resource-identifier";
      FilterType2["RESOURCE_TYPE_PREFIX"] = "resource-type-prefix";
      FilterType2["TAG_KEY"] = "tag-key";
      FilterType2["TAG_VALUE"] = "tag-value";
      return FilterType2;
    })(FilterType || {});
    __name(parseSourceOptions, "parseSourceOptions");
    __name(excludeManaged, "excludeManaged");
    __name(resourceIdentifiers, "resourceIdentifiers");
    __name(scanProgressBar, "scanProgressBar");
    __name(printBar, "printBar");
    __name(printDots, "printDots");
    __name(rewriteLine, "rewriteLine");
    __name(displayTimeDiff, "displayTimeDiff");
    __name(writeMigrateJsonFile, "writeMigrateJsonFile");
    __name(getMigrateScanType, "getMigrateScanType");
    __name(isThereAWarning, "isThereAWarning");
    __name(buildGeneratedTemplateOutput, "buildGeneratedTemplateOutput");
    __name(buildCfnClient, "buildCfnClient");
    __name(appendWarningsToReadme, "appendWarningsToReadme");
    __name(deduplicateResources, "deduplicateResources");
    CfnTemplateGeneratorProvider = class {
      static {
        __name(this, "CfnTemplateGeneratorProvider");
      }
      constructor(cfn, ioHelper) {
        this.cfn = cfn;
        this.ioHelper = ioHelper;
      }
      async checkForResourceScan(resourceScanSummaries, options, clientRequestToken) {
        if (!resourceScanSummaries || resourceScanSummaries.length === 0) {
          if (options.fromScan === 1 /* MOST_RECENT */) {
            throw new import_toolkit_lib12.ToolkitError(
              "NoScansFound",
              "No scans found. Please either start a new scan with the `--from-scan` new or do not specify a `--from-scan` option."
            );
          } else {
            await this.ioHelper.defaults.info("No scans found. Initiating a new resource scan.");
            await this.startResourceScan(clientRequestToken);
          }
        }
      }
      /**
       * Retrieves a tokenized list of resources and their associated scan. If a token is present the function
       * will loop through all pages and combine them into a single list of ScannedRelatedResources
       *
       * @param scanId - scan id for the to list resources for
       * @param resources - A list of resources to find related resources for
       */
      async getResourceScanRelatedResources(scanId, resources) {
        let relatedResourceList = resources;
        for (const chunk of chunks(resources, 100)) {
          const res = await this.cfn.listResourceScanRelatedResources({
            ResourceScanId: scanId,
            Resources: chunk
          });
          relatedResourceList.push(...res.RelatedResources ?? []);
          let nextToken = res.NextToken;
          while (nextToken) {
            const nextRelatedResources = await this.cfn.listResourceScanRelatedResources({
              ResourceScanId: scanId,
              Resources: resourceIdentifiers(resources),
              NextToken: nextToken
            });
            nextToken = nextRelatedResources.NextToken;
            relatedResourceList.push(...nextRelatedResources.RelatedResources ?? []);
          }
        }
        relatedResourceList = deduplicateResources(relatedResourceList);
        return process.env.MIGRATE_INTEG_TEST ? resourceIdentifiers(relatedResourceList) : resourceIdentifiers(excludeManaged(relatedResourceList));
      }
      /**
       * Kicks off a scan of a customers account, returning the scan id. A scan can take
       * 10 minutes or longer to complete. However this will return a scan id as soon as
       * the scan has begun.
       *
       * @returns A string representing the scan id
       */
      async startResourceScan(requestToken) {
        return (await this.cfn.startResourceScan({
          ClientRequestToken: requestToken
        })).ResourceScanId;
      }
      /**
       * Gets the most recent scans a customer has completed
       *
       * @returns a list of resource scan summaries
       */
      async listResourceScans() {
        return this.cfn.listResourceScans();
      }
      /**
       * Retrieves a tokenized list of resources from a resource scan. If a token is present, this function
       * will loop through all pages and combine them into a single list of ScannedResource[].
       * Additionally will apply any filters provided by the customer.
       *
       * @param scanId - scan id for the to list resources for
       * @param filters - a string of filters in the format of key1=value1,key2=value2
       * @returns a combined list of all resources from the scan
       */
      async listResourceScanResources(scanId, filters = []) {
        let resourceList = [];
        let resourceScanInputs;
        if (filters.length > 0) {
          await this.ioHelper.defaults.info("Applying filters to resource scan.");
          for (const filter of filters) {
            const filterList = parseFilters(filter);
            resourceScanInputs = {
              ResourceScanId: scanId,
              ResourceIdentifier: filterList["resource-identifier" /* RESOURCE_IDENTIFIER */],
              ResourceTypePrefix: filterList["resource-type-prefix" /* RESOURCE_TYPE_PREFIX */],
              TagKey: filterList["tag-key" /* TAG_KEY */],
              TagValue: filterList["tag-value" /* TAG_VALUE */]
            };
            const resources = await this.cfn.listResourceScanResources(resourceScanInputs);
            resourceList = resourceList.concat(resources.Resources ?? []);
            let nextToken = resources.NextToken;
            while (nextToken) {
              resourceScanInputs.NextToken = nextToken;
              const nextResources = await this.cfn.listResourceScanResources(resourceScanInputs);
              nextToken = nextResources.NextToken;
              resourceList = resourceList.concat(nextResources.Resources ?? []);
            }
          }
        } else {
          await this.ioHelper.defaults.info("No filters provided. Retrieving all resources from scan.");
          resourceScanInputs = {
            ResourceScanId: scanId
          };
          const resources = await this.cfn.listResourceScanResources(resourceScanInputs);
          resourceList = resourceList.concat(resources.Resources ?? []);
          let nextToken = resources.NextToken;
          while (nextToken) {
            resourceScanInputs.NextToken = nextToken;
            const nextResources = await this.cfn.listResourceScanResources(resourceScanInputs);
            nextToken = nextResources.NextToken;
            resourceList = resourceList.concat(nextResources.Resources ?? []);
          }
        }
        if (resourceList.length === 0) {
          throw new import_toolkit_lib12.ToolkitError("NoResourcesFound", `No resources found with filters ${filters.join(" ")}. Please try again with different filters.`);
        }
        resourceList = deduplicateResources(resourceList);
        return process.env.MIGRATE_INTEG_TEST ? resourceIdentifiers(resourceList) : resourceIdentifiers(excludeManaged(resourceList));
      }
      /**
       * Retrieves information about a resource scan.
       *
       * @param scanId - scan id for the to list resources for
       * @returns information about the scan
       */
      async describeResourceScan(scanId) {
        return this.cfn.describeResourceScan({
          ResourceScanId: scanId
        });
      }
      /**
       * Describes the current status of the template being generated.
       *
       * @param templateId - A string representing the template id
       * @returns DescribeGeneratedTemplateOutput an object containing the template status and results
       */
      async describeGeneratedTemplate(templateId) {
        const generatedTemplate = await this.cfn.describeGeneratedTemplate({
          GeneratedTemplateName: templateId
        });
        if (generatedTemplate.Status == "FAILED" /* FAILED */) {
          throw new import_toolkit_lib12.ToolkitError("TemplateGenerationFailed", generatedTemplate.StatusReason);
        }
        return generatedTemplate;
      }
      /**
       * Retrieves a completed generated cloudformation template from the template generator.
       *
       * @param templateId - A string representing the template id
       * @param cloudFormation - The CloudFormation sdk client to use
       * @returns DescribeGeneratedTemplateOutput an object containing the template status and body
       */
      async getGeneratedTemplate(templateId) {
        return this.cfn.getGeneratedTemplate({
          GeneratedTemplateName: templateId
        });
      }
      /**
       * Kicks off a template generation for a set of resources.
       *
       * @param stackName - The name of the stack
       * @param resources - A list of resources to generate the template from
       * @returns CreateGeneratedTemplateOutput an object containing the template arn to query on later
       */
      async createGeneratedTemplate(stackName, resources) {
        const createTemplateOutput = await this.cfn.createGeneratedTemplate({
          Resources: resources,
          GeneratedTemplateName: stackName
        });
        if (createTemplateOutput.GeneratedTemplateId === void 0) {
          throw new import_toolkit_lib12.ToolkitError("MissingTemplateArn", "CreateGeneratedTemplate failed to return an Arn.");
        }
        return createTemplateOutput;
      }
      /**
       * Deletes a generated template from the template generator.
       *
       * @param templateArn - The arn of the template to delete
       * @returns A promise that resolves when the template has been deleted
       */
      async deleteGeneratedTemplate(templateArn) {
        await this.cfn.deleteGeneratedTemplate({
          GeneratedTemplateName: templateArn
        });
      }
    };
  }
});

// lib/cxapp/cloud-assembly.ts
var import_toolkit_lib13, import_picomatch2, semver4, CloudAssembly5;
var init_cloud_assembly5 = __esm({
  "lib/cxapp/cloud-assembly.ts"() {
    "use strict";
    import_toolkit_lib13 = __toESM(require_lib12());
    import_picomatch2 = __toESM(require_picomatch4());
    semver4 = __toESM(require_semver4());
    init_cloud_assembly4();
    init_util9();
    CloudAssembly5 = class _CloudAssembly extends BaseStackAssembly {
      static {
        __name(this, "CloudAssembly");
      }
      async selectStacks(selector, options) {
        const asm = this.assembly;
        const topLevelStacks = asm.stacks;
        const stacks = semver4.major(asm.version) < 10 ? asm.stacks : asm.stacksRecursively;
        const allTopLevel = selector.allTopLevel ?? false;
        const patterns = _CloudAssembly.sanitizePatterns(selector.patterns);
        if (stacks.length === 0) {
          if (options.ignoreNoStacks) {
            return new StackCollection(this, []);
          }
          throw new import_toolkit_lib13.ToolkitError("NoStacks", "This app contains no stacks");
        }
        if (allTopLevel) {
          return this.selectTopLevelStacks(stacks, topLevelStacks, options.extend);
        } else if (patterns.length > 0) {
          return this.selectMatchingStacks(stacks, patterns, options.extend);
        } else {
          return this.selectDefaultStacks(stacks, topLevelStacks, options.defaultBehavior);
        }
      }
      async selectTopLevelStacks(stacks, topLevelStacks, extend = 0 /* None */) {
        if (topLevelStacks.length > 0) {
          return this.extendStacks(topLevelStacks, stacks, extend);
        } else {
          throw new import_toolkit_lib13.ToolkitError("NoStackInMainAssembly", 'No stack found in the main cloud assembly. Use "list" to print manifest');
        }
      }
      async selectMatchingStacks(stacks, patterns, extend = 0 /* None */) {
        const matchingPattern = /* @__PURE__ */ __name((pattern) => (stack) => (0, import_picomatch2.isMatch)(stack.hierarchicalId, pattern), "matchingPattern");
        const matchedStacks = flatten2(patterns.map((pattern) => stacks.filter(matchingPattern(pattern))));
        return this.extendStacks(matchedStacks, stacks, extend);
      }
      selectDefaultStacks(stacks, topLevelStacks, defaultSelection) {
        switch (defaultSelection) {
          case "main" /* MainAssembly */:
            return new StackCollection(this, topLevelStacks);
          case "all" /* AllStacks */:
            return new StackCollection(this, stacks);
          case "none" /* None */:
            return new StackCollection(this, []);
          case "single" /* OnlySingle */:
            if (topLevelStacks.length === 1) {
              return new StackCollection(this, topLevelStacks);
            } else {
              throw new import_toolkit_lib13.ToolkitError("NoSelectorGiven", `Since this app includes more than a single stack, specify which stacks to use (wildcards are supported) or specify \`--all\`
Stacks: ${stacks.map((x) => x.hierarchicalId).join(" \xB7 ")}`);
            }
          default:
            throw new import_toolkit_lib13.ToolkitError("InvalidDefaultBehavior", `invalid default behavior: ${defaultSelection}`);
        }
      }
    };
  }
});

// lib/cli/singleton-plugin-host.ts
var GLOBAL_PLUGIN_HOST;
var init_singleton_plugin_host = __esm({
  "lib/cli/singleton-plugin-host.ts"() {
    "use strict";
    init_plugin3();
    GLOBAL_PLUGIN_HOST = new PluginHost();
  }
});

// lib/context-providers.ts
var init_context_providers2 = __esm({
  "lib/context-providers.ts"() {
    "use strict";
    init_context_providers();
  }
});

// lib/cxapp/cloud-executable.ts
function missingContextKeys2(missing) {
  return new Set((missing || []).map((m20) => m20.key));
}
function setsEqual(a32, b32) {
  if (a32.size !== b32.size) {
    return false;
  }
  for (const x of a32) {
    if (!b32.has(x)) {
      return false;
    }
  }
  return true;
}
var import_toolkit_lib14, CloudExecutable;
var init_cloud_executable = __esm({
  "lib/cxapp/cloud-executable.ts"() {
    "use strict";
    import_toolkit_lib14 = __toESM(require_lib12());
    init_cloud_assembly5();
    init_api_private();
    init_singleton_plugin_host();
    init_error2();
    init_messages2();
    init_context_providers2();
    CloudExecutable = class {
      constructor(props) {
        this.props = props;
      }
      static {
        __name(this, "CloudExecutable");
      }
      async produce() {
        const synthesisResult = await this.synthesize(true);
        return new BorrowedAssembly(synthesisResult.assembly);
      }
      /**
       * Return whether there is an app command from the configuration
       */
      get hasApp() {
        return !!this.props.configuration.settings.get(["app"]);
      }
      /**
       * Switch on debugging for the cloud executable.
       *
       * This will cause it to log more stack traces and other information that will make error
       * reports more useful (at the cost of increased execution time).
       */
      switchOnDebugging() {
        this.props.configuration.settings.temporarilyMutable((settings) => {
          settings.set(["debug"], true);
        });
      }
      /**
       * Synthesize a set of stacks.
       *
       * @param cacheCloudAssembly - whether to cache the Cloud Assembly after it has been first synthesized.
       *   This is 'true' by default, and only set to 'false' for 'cdk watch',
       *   which needs to re-synthesize the Assembly each time it detects a change to the project files
       */
      async synthesize(cacheCloudAssembly = true) {
        if (!this._cloudAssembly || !cacheCloudAssembly) {
          this._cloudAssembly = await this.doSynthesize();
        }
        return this._cloudAssembly;
      }
      async doSynthesize() {
        let previouslyMissingKeys;
        const synthSpan = await this.props.ioHelper.span(CLI_PRIVATE_SPAN.SYNTH_ASSEMBLY).begin({});
        let error4;
        try {
          while (true) {
            const assembly = await this.props.synthesizer(this.props.sdkProvider, this.props.configuration);
            if (assembly.manifest.missing && assembly.manifest.missing.length > 0) {
              const missingKeys = missingContextKeys2(assembly.manifest.missing);
              if (!this.canLookup) {
                throw new import_toolkit_lib14.ToolkitError(
                  "ContextLookupsDisabled",
                  `Context lookups have been disabled. Make sure all necessary context is already in 'cdk.context.json' by running 'cdk synth' on a machine with sufficient AWS credentials and committing the result. Missing context keys: '${Array.from(missingKeys).join(", ")}'`
                );
              }
              let tryLookup = true;
              if (previouslyMissingKeys && setsEqual(missingKeys, previouslyMissingKeys)) {
                await this.props.ioHelper.defaults.debug("Not making progress trying to resolve environmental context. Giving up.");
                tryLookup = false;
              }
              previouslyMissingKeys = missingKeys;
              if (tryLookup) {
                const lookupsTimer = synthSpan.startTimer("lookups");
                try {
                  await this.props.ioHelper.defaults.debug("Some context information is missing. Fetching...");
                  const updates = await provideContextValues(
                    assembly.manifest.missing,
                    this.props.sdkProvider,
                    GLOBAL_PLUGIN_HOST,
                    this.props.ioHelper
                  );
                  for (const [key, value] of Object.entries(updates)) {
                    this.props.configuration.context.set(key, value);
                  }
                  await this.props.configuration.saveContext();
                } finally {
                  lookupsTimer.stop();
                }
                continue;
              }
            }
            countAssemblyResults(synthSpan, assembly);
            return new CloudAssembly5(assembly, this.props.ioHelper);
          }
        } catch (e32) {
          error4 = {
            name: cdkCliErrorName(e32)
          };
          throw e32;
        } finally {
          await synthSpan.end({ error: error4 });
        }
      }
      get canLookup() {
        return !!(this.props.configuration.settings.get(["lookups"]) ?? true);
      }
    };
    __name(missingContextKeys2, "missingContextKeys");
    __name(setsEqual, "setsEqual");
  }
});

// lib/cxapp/environments.ts
function looksLikeGlob(environment) {
  return environment.indexOf("*") > -1;
}
async function globEnvironmentsFromStacks(stacks, environmentGlobs, sdk) {
  if (environmentGlobs.length === 0) {
    return [];
  }
  const availableEnvironments = new Array();
  for (const stack of stacks.stackArtifacts) {
    const actual = await sdk.resolveEnvironment(stack.environment);
    availableEnvironments.push(actual);
  }
  const environments = distinct(availableEnvironments).filter((env3) => environmentGlobs.find((glob) => (0, import_picomatch3.isMatch)(env3.name, glob)));
  if (environments.length === 0) {
    const globs = JSON.stringify(environmentGlobs);
    const envList = availableEnvironments.length > 0 ? availableEnvironments.map((env3) => env3.name).join(", ") : "<none>";
    throw new import_toolkit_lib15.ToolkitError("NoEnvironmentsFound", `No environments were found when selecting across ${globs} (available: ${envList})`);
  }
  return environments;
}
function environmentsFromDescriptors2(envSpecs) {
  const ret = new Array();
  for (const spec of envSpecs) {
    const parts = spec.replace(/^aws:\/\//, "").split("/");
    if (parts.length !== 2) {
      throw new import_toolkit_lib15.ToolkitError("InvalidEnvironmentFormat", `Expected environment name in format 'aws://<account>/<region>', got: ${spec}`);
    }
    ret.push({
      name: spec,
      account: parts[0],
      region: parts[1]
    });
  }
  return ret;
}
function distinct(envs) {
  const unique = {};
  for (const env3 of envs) {
    const id = `${env3.account || "default"}/${env3.region || "default"}`;
    if (id in unique) {
      continue;
    }
    unique[id] = env3;
  }
  return Object.values(unique);
}
var import_toolkit_lib15, import_picomatch3;
var init_environments = __esm({
  "lib/cxapp/environments.ts"() {
    "use strict";
    import_toolkit_lib15 = __toESM(require_lib12());
    import_picomatch3 = __toESM(require_picomatch4());
    __name(looksLikeGlob, "looksLikeGlob");
    __name(globEnvironmentsFromStacks, "globEnvironmentsFromStacks");
    __name(environmentsFromDescriptors2, "environmentsFromDescriptors");
    __name(distinct, "distinct");
  }
});

// lib/cli/util/fs-util.ts
async function tryReadJson(fileName) {
  try {
    return JSON.parse(await fs44.readFile(fileName, "utf-8"));
  } catch (e32) {
    if (e32.code === "ENOENT") {
      return void 0;
    }
    throw e32;
  }
}
var fs44;
var init_fs_util = __esm({
  "lib/cli/util/fs-util.ts"() {
    "use strict";
    fs44 = __toESM(require("fs/promises"));
    __name(tryReadJson, "tryReadJson");
  }
});

// lib/cxapp/exec.ts
async function execProgram(aws, ioHelper, config2) {
  const debugFn = /* @__PURE__ */ __name((msg) => ioHelper.defaults.debug(msg), "debugFn");
  let errorFile;
  const params = synthParametersFromSettings(config2.settings);
  const context = {
    ...config2.context.all,
    ...params.context
  };
  await debugFn((0, import_util74.format)("context:", context));
  if (params.env.CDK_DEBUG === "true") {
    await ioHelper.defaults.info("\u{1F50D} Synthesizing with debug information. This may take a bit longer.");
  }
  const env3 = noUndefined2({
    // Versioning, outdir, default account and region
    ...await prepareDefaultEnvironment(aws, debugFn),
    // Environment variables derived from settings
    ...params.env
  });
  const build = config2.settings.get(["build"]);
  if (build) {
    await exec5(build);
  }
  let app = config2.settings.get(["app"]);
  if (!app) {
    throw new import_toolkit_lib16.ToolkitError("AppRequired", `--app is required either in command-line, in ${PROJECT_CONFIG} or in ${USER_DEFAULTS}`);
  }
  if (await fs45.pathExists(app) && (await fs45.stat(app)).isDirectory()) {
    await debugFn("--app points to a cloud assembly, so we bypass synth");
    const lock = await new RWLock(app).acquireRead();
    return { assembly: createAssembly(app), lock };
  }
  if (Array.isArray(app)) {
    app = app.join(" ");
  }
  const commandLine = await guessExecutable(app, debugFn);
  const outdir = config2.settings.get(["output"]);
  if (!outdir) {
    throw new import_toolkit_lib16.ToolkitError("OutputRequired", "unexpected: --output is required");
  }
  if (typeof outdir !== "string") {
    throw new import_toolkit_lib16.ToolkitError("OutputNotString", `--output takes a string, got ${JSON.stringify(outdir)}`);
  }
  try {
    await fs45.mkdirp(outdir);
  } catch (error4) {
    throw new import_toolkit_lib16.ToolkitError("OutputDirCreateFailed", `Could not create output directory ${outdir} (${error4.message})`);
  }
  await debugFn(`outdir: ${outdir}`);
  env3[cxapi11.OUTDIR_ENV] = outdir;
  env3[cxapi11.CLI_ASM_VERSION_ENV] = cxschema11.Manifest.version();
  env3[cxapi11.CLI_VERSION_ENV] = versionNumber2();
  const writerLock = await new RWLock(outdir).acquireWrite();
  errorFile = path43.join(outdir, "error.txt");
  await fs45.promises.rm(errorFile, { force: true });
  env3.CDK_ERROR_FILE = errorFile;
  const perfCountersFile = path43.join(outdir, "performance-counters.json");
  await fs45.promises.rm(perfCountersFile, { force: true });
  env3.CDK_PERF_COUNTERS_FILE = perfCountersFile;
  await debugFn((0, import_util74.format)("env:", env3));
  const cleanupTemp = writeContextToEnv(env3, context, "add-process-env-later");
  try {
    await exec5(commandLine);
    const assembly = createAssembly(outdir);
    const perfCounters = await tryReadJson(perfCountersFile);
    return {
      assembly,
      lock: await writerLock.convertToReaderLock(),
      perfCounters: typeof perfCounters === "object" && typeof perfCounters.counters === "object" ? perfCounters.counters : void 0
    };
  } catch (e32) {
    await writerLock.release();
    throw e32;
  } finally {
    await cleanupTemp();
  }
  async function exec5(commandAndArgs) {
    try {
      return await execInChildProcess(commandAndArgs, {
        env: {
          ...process.env,
          ...env3
        },
        errorCodeFile: errorFile,
        // Not capturing the stdout/stderr of the CDK app. It must remain attached to a terminal
        // if the parent process is attached to a terminal.
        captureOutput: false
      });
    } catch (e32) {
      await debugFn(`failed command: ${commandAndArgs}`);
      throw e32;
    }
  }
  __name(exec5, "exec");
}
function createAssembly(appDir) {
  try {
    return new import_cloud_assembly_api17.CloudAssembly(appDir, {
      // We sort as we deploy
      topoSort: false
    });
  } catch (error4) {
    if (error4.message.includes(cxschema11.VERSION_MISMATCH)) {
      throw new import_toolkit_lib16.ToolkitError("CliVersionMismatch", `This CDK CLI is not compatible with the CDK library used by your application. Please upgrade the CLI to the latest version.
(${error4.message})`);
    }
    throw error4;
  }
}
function noUndefined2(xs) {
  return Object.fromEntries(Object.entries(xs).filter(([_, v]) => v !== void 0));
}
var path43, import_util74, import_cloud_assembly_api17, cxschema11, cxapi11, import_toolkit_lib16, fs45;
var init_exec2 = __esm({
  "lib/cxapp/exec.ts"() {
    "use strict";
    path43 = __toESM(require("path"));
    import_util74 = require("util");
    import_cloud_assembly_api17 = __toESM(require_lib3());
    cxschema11 = __toESM(require_lib2());
    cxapi11 = __toESM(require_lib11());
    import_toolkit_lib16 = __toESM(require_lib12());
    fs45 = __toESM(require_lib4());
    init_api();
    init_user_configuration();
    init_fs_util();
    init_version();
    __name(execProgram, "execProgram");
    __name(createAssembly, "createAssembly");
    __name(noUndefined2, "noUndefined");
  }
});

// lib/cxapp/index.ts
var init_cxapp = __esm({
  "lib/cxapp/index.ts"() {
    "use strict";
    init_cloud_assembly5();
    init_cloud_executable();
    init_environments();
    init_exec2();
  }
});

// ../../node_modules/p-queue/node_modules/eventemitter3/index.js
var require_eventemitter3 = __commonJS({
  "../../node_modules/p-queue/node_modules/eventemitter3/index.js"(exports2, module2) {
    "use strict";
    var has = Object.prototype.hasOwnProperty;
    var prefix = "~";
    function Events() {
    }
    __name(Events, "Events");
    if (Object.create) {
      Events.prototype = /* @__PURE__ */ Object.create(null);
      if (!new Events().__proto__) prefix = false;
    }
    function EE(fn, context, once) {
      this.fn = fn;
      this.context = context;
      this.once = once || false;
    }
    __name(EE, "EE");
    function addListener(emitter, event, fn, context, once) {
      if (typeof fn !== "function") {
        throw new TypeError("The listener must be a function");
      }
      var listener = new EE(fn, context || emitter, once), evt = prefix ? prefix + event : event;
      if (!emitter._events[evt]) emitter._events[evt] = listener, emitter._eventsCount++;
      else if (!emitter._events[evt].fn) emitter._events[evt].push(listener);
      else emitter._events[evt] = [emitter._events[evt], listener];
      return emitter;
    }
    __name(addListener, "addListener");
    function clearEvent(emitter, evt) {
      if (--emitter._eventsCount === 0) emitter._events = new Events();
      else delete emitter._events[evt];
    }
    __name(clearEvent, "clearEvent");
    function EventEmitter2() {
      this._events = new Events();
      this._eventsCount = 0;
    }
    __name(EventEmitter2, "EventEmitter");
    EventEmitter2.prototype.eventNames = /* @__PURE__ */ __name(function eventNames() {
      var names = [], events, name;
      if (this._eventsCount === 0) return names;
      for (name in events = this._events) {
        if (has.call(events, name)) names.push(prefix ? name.slice(1) : name);
      }
      if (Object.getOwnPropertySymbols) {
        return names.concat(Object.getOwnPropertySymbols(events));
      }
      return names;
    }, "eventNames");
    EventEmitter2.prototype.listeners = /* @__PURE__ */ __name(function listeners(event) {
      var evt = prefix ? prefix + event : event, handlers = this._events[evt];
      if (!handlers) return [];
      if (handlers.fn) return [handlers.fn];
      for (var i32 = 0, l20 = handlers.length, ee = new Array(l20); i32 < l20; i32++) {
        ee[i32] = handlers[i32].fn;
      }
      return ee;
    }, "listeners");
    EventEmitter2.prototype.listenerCount = /* @__PURE__ */ __name(function listenerCount(event) {
      var evt = prefix ? prefix + event : event, listeners = this._events[evt];
      if (!listeners) return 0;
      if (listeners.fn) return 1;
      return listeners.length;
    }, "listenerCount");
    EventEmitter2.prototype.emit = /* @__PURE__ */ __name(function emit(event, a1, a210, a32, a42, a52) {
      var evt = prefix ? prefix + event : event;
      if (!this._events[evt]) return false;
      var listeners = this._events[evt], len = arguments.length, args, i32;
      if (listeners.fn) {
        if (listeners.once) this.removeListener(event, listeners.fn, void 0, true);
        switch (len) {
          case 1:
            return listeners.fn.call(listeners.context), true;
          case 2:
            return listeners.fn.call(listeners.context, a1), true;
          case 3:
            return listeners.fn.call(listeners.context, a1, a210), true;
          case 4:
            return listeners.fn.call(listeners.context, a1, a210, a32), true;
          case 5:
            return listeners.fn.call(listeners.context, a1, a210, a32, a42), true;
          case 6:
            return listeners.fn.call(listeners.context, a1, a210, a32, a42, a52), true;
        }
        for (i32 = 1, args = new Array(len - 1); i32 < len; i32++) {
          args[i32 - 1] = arguments[i32];
        }
        listeners.fn.apply(listeners.context, args);
      } else {
        var length = listeners.length, j32;
        for (i32 = 0; i32 < length; i32++) {
          if (listeners[i32].once) this.removeListener(event, listeners[i32].fn, void 0, true);
          switch (len) {
            case 1:
              listeners[i32].fn.call(listeners[i32].context);
              break;
            case 2:
              listeners[i32].fn.call(listeners[i32].context, a1);
              break;
            case 3:
              listeners[i32].fn.call(listeners[i32].context, a1, a210);
              break;
            case 4:
              listeners[i32].fn.call(listeners[i32].context, a1, a210, a32);
              break;
            default:
              if (!args) for (j32 = 1, args = new Array(len - 1); j32 < len; j32++) {
                args[j32 - 1] = arguments[j32];
              }
              listeners[i32].fn.apply(listeners[i32].context, args);
          }
        }
      }
      return true;
    }, "emit");
    EventEmitter2.prototype.on = /* @__PURE__ */ __name(function on(event, fn, context) {
      return addListener(this, event, fn, context, false);
    }, "on");
    EventEmitter2.prototype.once = /* @__PURE__ */ __name(function once(event, fn, context) {
      return addListener(this, event, fn, context, true);
    }, "once");
    EventEmitter2.prototype.removeListener = /* @__PURE__ */ __name(function removeListener(event, fn, context, once) {
      var evt = prefix ? prefix + event : event;
      if (!this._events[evt]) return this;
      if (!fn) {
        clearEvent(this, evt);
        return this;
      }
      var listeners = this._events[evt];
      if (listeners.fn) {
        if (listeners.fn === fn && (!once || listeners.once) && (!context || listeners.context === context)) {
          clearEvent(this, evt);
        }
      } else {
        for (var i32 = 0, events = [], length = listeners.length; i32 < length; i32++) {
          if (listeners[i32].fn !== fn || once && !listeners[i32].once || context && listeners[i32].context !== context) {
            events.push(listeners[i32]);
          }
        }
        if (events.length) this._events[evt] = events.length === 1 ? events[0] : events;
        else clearEvent(this, evt);
      }
      return this;
    }, "removeListener");
    EventEmitter2.prototype.removeAllListeners = /* @__PURE__ */ __name(function removeAllListeners(event) {
      var evt;
      if (event) {
        evt = prefix ? prefix + event : event;
        if (this._events[evt]) clearEvent(this, evt);
      } else {
        this._events = new Events();
        this._eventsCount = 0;
      }
      return this;
    }, "removeAllListeners");
    EventEmitter2.prototype.off = EventEmitter2.prototype.removeListener;
    EventEmitter2.prototype.addListener = EventEmitter2.prototype.on;
    EventEmitter2.prefixed = prefix;
    EventEmitter2.EventEmitter = EventEmitter2;
    if ("undefined" !== typeof module2) {
      module2.exports = EventEmitter2;
    }
  }
});

// ../../node_modules/p-finally/index.js
var require_p_finally = __commonJS({
  "../../node_modules/p-finally/index.js"(exports2, module2) {
    "use strict";
    module2.exports = (promise, onFinally) => {
      onFinally = onFinally || (() => {
      });
      return promise.then(
        (val) => new Promise((resolve13) => {
          resolve13(onFinally());
        }).then(() => val),
        (err) => new Promise((resolve13) => {
          resolve13(onFinally());
        }).then(() => {
          throw err;
        })
      );
    };
  }
});

// ../../node_modules/p-timeout/index.js
var require_p_timeout = __commonJS({
  "../../node_modules/p-timeout/index.js"(exports2, module2) {
    "use strict";
    var pFinally = require_p_finally();
    var TimeoutError = class extends Error {
      static {
        __name(this, "TimeoutError");
      }
      constructor(message2) {
        super(message2);
        this.name = "TimeoutError";
      }
    };
    var pTimeout = /* @__PURE__ */ __name((promise, milliseconds, fallback2) => new Promise((resolve13, reject) => {
      if (typeof milliseconds !== "number" || milliseconds < 0) {
        throw new TypeError("Expected `milliseconds` to be a positive number");
      }
      if (milliseconds === Infinity) {
        resolve13(promise);
        return;
      }
      const timer = setTimeout(() => {
        if (typeof fallback2 === "function") {
          try {
            resolve13(fallback2());
          } catch (error4) {
            reject(error4);
          }
          return;
        }
        const message2 = typeof fallback2 === "string" ? fallback2 : `Promise timed out after ${milliseconds} milliseconds`;
        const timeoutError = fallback2 instanceof Error ? fallback2 : new TimeoutError(message2);
        if (typeof promise.cancel === "function") {
          promise.cancel();
        }
        reject(timeoutError);
      }, milliseconds);
      pFinally(
        // eslint-disable-next-line promise/prefer-await-to-then
        promise.then(resolve13, reject),
        () => {
          clearTimeout(timer);
        }
      );
    }), "pTimeout");
    module2.exports = pTimeout;
    module2.exports.default = pTimeout;
    module2.exports.TimeoutError = TimeoutError;
  }
});

// ../../node_modules/p-queue/dist/lower-bound.js
var require_lower_bound = __commonJS({
  "../../node_modules/p-queue/dist/lower-bound.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    function lowerBound(array, value, comparator) {
      let first = 0;
      let count = array.length;
      while (count > 0) {
        const step = count / 2 | 0;
        let it = first + step;
        if (comparator(array[it], value) <= 0) {
          first = ++it;
          count -= step + 1;
        } else {
          count = step;
        }
      }
      return first;
    }
    __name(lowerBound, "lowerBound");
    exports2.default = lowerBound;
  }
});

// ../../node_modules/p-queue/dist/priority-queue.js
var require_priority_queue = __commonJS({
  "../../node_modules/p-queue/dist/priority-queue.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var lower_bound_1 = require_lower_bound();
    var PriorityQueue = class {
      static {
        __name(this, "PriorityQueue");
      }
      constructor() {
        this._queue = [];
      }
      enqueue(run, options) {
        options = Object.assign({ priority: 0 }, options);
        const element = {
          priority: options.priority,
          run
        };
        if (this.size && this._queue[this.size - 1].priority >= options.priority) {
          this._queue.push(element);
          return;
        }
        const index = lower_bound_1.default(this._queue, element, (a32, b32) => b32.priority - a32.priority);
        this._queue.splice(index, 0, element);
      }
      dequeue() {
        const item = this._queue.shift();
        return item === null || item === void 0 ? void 0 : item.run;
      }
      filter(options) {
        return this._queue.filter((element) => element.priority === options.priority).map((element) => element.run);
      }
      get size() {
        return this._queue.length;
      }
    };
    exports2.default = PriorityQueue;
  }
});

// ../../node_modules/p-queue/dist/index.js
var require_dist3 = __commonJS({
  "../../node_modules/p-queue/dist/index.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var EventEmitter2 = require_eventemitter3();
    var p_timeout_1 = require_p_timeout();
    var priority_queue_1 = require_priority_queue();
    var empty = /* @__PURE__ */ __name(() => {
    }, "empty");
    var timeoutError = new p_timeout_1.TimeoutError();
    var PQueue2 = class extends EventEmitter2 {
      static {
        __name(this, "PQueue");
      }
      constructor(options) {
        var _a10, _b, _c32, _d;
        super();
        this._intervalCount = 0;
        this._intervalEnd = 0;
        this._pendingCount = 0;
        this._resolveEmpty = empty;
        this._resolveIdle = empty;
        options = Object.assign({ carryoverConcurrencyCount: false, intervalCap: Infinity, interval: 0, concurrency: Infinity, autoStart: true, queueClass: priority_queue_1.default }, options);
        if (!(typeof options.intervalCap === "number" && options.intervalCap >= 1)) {
          throw new TypeError(`Expected \`intervalCap\` to be a number from 1 and up, got \`${(_b = (_a10 = options.intervalCap) === null || _a10 === void 0 ? void 0 : _a10.toString()) !== null && _b !== void 0 ? _b : ""}\` (${typeof options.intervalCap})`);
        }
        if (options.interval === void 0 || !(Number.isFinite(options.interval) && options.interval >= 0)) {
          throw new TypeError(`Expected \`interval\` to be a finite number >= 0, got \`${(_d = (_c32 = options.interval) === null || _c32 === void 0 ? void 0 : _c32.toString()) !== null && _d !== void 0 ? _d : ""}\` (${typeof options.interval})`);
        }
        this._carryoverConcurrencyCount = options.carryoverConcurrencyCount;
        this._isIntervalIgnored = options.intervalCap === Infinity || options.interval === 0;
        this._intervalCap = options.intervalCap;
        this._interval = options.interval;
        this._queue = new options.queueClass();
        this._queueClass = options.queueClass;
        this.concurrency = options.concurrency;
        this._timeout = options.timeout;
        this._throwOnTimeout = options.throwOnTimeout === true;
        this._isPaused = options.autoStart === false;
      }
      get _doesIntervalAllowAnother() {
        return this._isIntervalIgnored || this._intervalCount < this._intervalCap;
      }
      get _doesConcurrentAllowAnother() {
        return this._pendingCount < this._concurrency;
      }
      _next() {
        this._pendingCount--;
        this._tryToStartAnother();
        this.emit("next");
      }
      _resolvePromises() {
        this._resolveEmpty();
        this._resolveEmpty = empty;
        if (this._pendingCount === 0) {
          this._resolveIdle();
          this._resolveIdle = empty;
          this.emit("idle");
        }
      }
      _onResumeInterval() {
        this._onInterval();
        this._initializeIntervalIfNeeded();
        this._timeoutId = void 0;
      }
      _isIntervalPaused() {
        const now = Date.now();
        if (this._intervalId === void 0) {
          const delay = this._intervalEnd - now;
          if (delay < 0) {
            this._intervalCount = this._carryoverConcurrencyCount ? this._pendingCount : 0;
          } else {
            if (this._timeoutId === void 0) {
              this._timeoutId = setTimeout(() => {
                this._onResumeInterval();
              }, delay);
            }
            return true;
          }
        }
        return false;
      }
      _tryToStartAnother() {
        if (this._queue.size === 0) {
          if (this._intervalId) {
            clearInterval(this._intervalId);
          }
          this._intervalId = void 0;
          this._resolvePromises();
          return false;
        }
        if (!this._isPaused) {
          const canInitializeInterval = !this._isIntervalPaused();
          if (this._doesIntervalAllowAnother && this._doesConcurrentAllowAnother) {
            const job = this._queue.dequeue();
            if (!job) {
              return false;
            }
            this.emit("active");
            job();
            if (canInitializeInterval) {
              this._initializeIntervalIfNeeded();
            }
            return true;
          }
        }
        return false;
      }
      _initializeIntervalIfNeeded() {
        if (this._isIntervalIgnored || this._intervalId !== void 0) {
          return;
        }
        this._intervalId = setInterval(() => {
          this._onInterval();
        }, this._interval);
        this._intervalEnd = Date.now() + this._interval;
      }
      _onInterval() {
        if (this._intervalCount === 0 && this._pendingCount === 0 && this._intervalId) {
          clearInterval(this._intervalId);
          this._intervalId = void 0;
        }
        this._intervalCount = this._carryoverConcurrencyCount ? this._pendingCount : 0;
        this._processQueue();
      }
      /**
      Executes all queued functions until it reaches the limit.
      */
      _processQueue() {
        while (this._tryToStartAnother()) {
        }
      }
      get concurrency() {
        return this._concurrency;
      }
      set concurrency(newConcurrency) {
        if (!(typeof newConcurrency === "number" && newConcurrency >= 1)) {
          throw new TypeError(`Expected \`concurrency\` to be a number from 1 and up, got \`${newConcurrency}\` (${typeof newConcurrency})`);
        }
        this._concurrency = newConcurrency;
        this._processQueue();
      }
      /**
      Adds a sync or async task to the queue. Always returns a promise.
      */
      async add(fn, options = {}) {
        return new Promise((resolve13, reject) => {
          const run = /* @__PURE__ */ __name(async () => {
            this._pendingCount++;
            this._intervalCount++;
            try {
              const operation3 = this._timeout === void 0 && options.timeout === void 0 ? fn() : p_timeout_1.default(Promise.resolve(fn()), options.timeout === void 0 ? this._timeout : options.timeout, () => {
                if (options.throwOnTimeout === void 0 ? this._throwOnTimeout : options.throwOnTimeout) {
                  reject(timeoutError);
                }
                return void 0;
              });
              resolve13(await operation3);
            } catch (error4) {
              reject(error4);
            }
            this._next();
          }, "run");
          this._queue.enqueue(run, options);
          this._tryToStartAnother();
          this.emit("add");
        });
      }
      /**
          Same as `.add()`, but accepts an array of sync or async functions.
      
          @returns A promise that resolves when all functions are resolved.
          */
      async addAll(functions, options) {
        return Promise.all(functions.map(async (function_) => this.add(function_, options)));
      }
      /**
      Start (or resume) executing enqueued tasks within concurrency limit. No need to call this if queue is not paused (via `options.autoStart = false` or by `.pause()` method.)
      */
      start() {
        if (!this._isPaused) {
          return this;
        }
        this._isPaused = false;
        this._processQueue();
        return this;
      }
      /**
      Put queue execution on hold.
      */
      pause() {
        this._isPaused = true;
      }
      /**
      Clear the queue.
      */
      clear() {
        this._queue = new this._queueClass();
      }
      /**
          Can be called multiple times. Useful if you for example add additional items at a later time.
      
          @returns A promise that settles when the queue becomes empty.
          */
      async onEmpty() {
        if (this._queue.size === 0) {
          return;
        }
        return new Promise((resolve13) => {
          const existingResolve = this._resolveEmpty;
          this._resolveEmpty = () => {
            existingResolve();
            resolve13();
          };
        });
      }
      /**
          The difference with `.onEmpty` is that `.onIdle` guarantees that all work from the queue has finished. `.onEmpty` merely signals that the queue is empty, but it could mean that some promises haven't completed yet.
      
          @returns A promise that settles when the queue becomes empty, and all promises have completed; `queue.size === 0 && queue.pending === 0`.
          */
      async onIdle() {
        if (this._pendingCount === 0 && this._queue.size === 0) {
          return;
        }
        return new Promise((resolve13) => {
          const existingResolve = this._resolveIdle;
          this._resolveIdle = () => {
            existingResolve();
            resolve13();
          };
        });
      }
      /**
      Size of the queue.
      */
      get size() {
        return this._queue.size;
      }
      /**
          Size of the queue, filtered by the given options.
      
          For example, this can be used to find the number of items remaining in the queue with a specific priority level.
          */
      sizeBy(options) {
        return this._queue.filter(options).length;
      }
      /**
      Number of pending promises.
      */
      get pending() {
        return this._pendingCount;
      }
      /**
      Whether the queue is currently paused.
      */
      get isPaused() {
        return this._isPaused;
      }
      get timeout() {
        return this._timeout;
      }
      /**
      Set the timeout for future operations.
      */
      set timeout(milliseconds) {
        this._timeout = milliseconds;
      }
    };
    exports2.default = PQueue2;
  }
});

// lib/commands/flags/obsolete-flags.ts
var OBSOLETE_FLAGS;
var init_obsolete_flags = __esm({
  "lib/commands/flags/obsolete-flags.ts"() {
    "use strict";
    OBSOLETE_FLAGS = [
      "@aws-cdk/core:enableStackNameDuplicates",
      "@aws-cdk/aws-s3:grantWriteWithoutAcl",
      "@aws-cdk/aws-kms:defaultKeyPolicies"
    ];
  }
});

// lib/commands/flags/operations.ts
function isEffectiveValueEqualToRecommended(flag) {
  return String(effectiveValue(flag)) === String(flag.recommendedValue);
}
function effectiveValue(flag) {
  return flag.userValue ?? defaultValue(flag);
}
function defaultValue(flag) {
  return flag.unconfiguredBehavesLike?.v2 ?? false;
}
var os12, path44, import_cloudformation_diff4, import_toolkit_lib17, chalk31, fs46, import_p_queue, FlagOperations;
var init_operations = __esm({
  "lib/commands/flags/operations.ts"() {
    "use strict";
    os12 = __toESM(require("os"));
    path44 = __toESM(require("path"));
    import_cloudformation_diff4 = __toESM(require_lib9());
    import_toolkit_lib17 = __toESM(require_lib12());
    chalk31 = __toESM(require_source());
    fs46 = __toESM(require_lib4());
    import_p_queue = __toESM(require_dist3());
    init_obsolete_flags();
    init_api();
    FlagOperations = class _FlagOperations {
      constructor(flags, toolkit, ioHelper, cliContextValues = {}) {
        this.flags = flags;
        this.toolkit = toolkit;
        this.ioHelper = ioHelper;
        this.cliContextValues = cliContextValues;
        this.app = "";
        this.baseContextValues = {};
        this.allStacks = [];
        this.queue = new import_p_queue.default({ concurrency: 4 });
      }
      static {
        __name(this, "FlagOperations");
      }
      /**
       * Returns only those feature flags that need configuration
       *
       * That is those flags:
       * - That are unconfigured
       * - That are not obsolete
       * - Whose default value is different from the recommended value
       *
       * The default value being equal to the recommended value sounds odd, but
       * crops up in a number of situtations:
       *
       * - Security-related fixes that we want to force on people, but want to
       *   give them a flag to back out of the changes if they really need to.
       * - Flags that changed their default value in the most recent major
       *   version.
       * - Flags that we've introduced at some point in the past, but have gone
       *   back on.
       */
      static filterNeedsAttention(flags) {
        return flags.filter((flag) => !OBSOLETE_FLAGS.includes(flag.name)).filter((flag) => flag.userValue === void 0).filter((flag) => defaultValue(flag) !== flag.recommendedValue);
      }
      /** Main entry point that routes to either flag setting or display operations */
      async execute(params) {
        if (params.set) {
          if (params.FLAGNAME && params.value) {
            await this.setFlag(params);
          } else {
            await this.setMultipleFlags(params);
          }
        } else {
          await this.displayFlags(params);
        }
      }
      /** Sets a single specific flag with validation and user confirmation */
      async setFlag(params) {
        const flagName = params.FLAGNAME[0];
        const flag = this.flags.find((f32) => f32.name === flagName);
        if (!flag) {
          await this.ioHelper.defaults.error("Flag not found.");
          return;
        }
        if (!this.isBooleanFlag(flag)) {
          await this.ioHelper.defaults.error(`Flag '${flagName}' is not a boolean flag. Only boolean flags are currently supported.`);
          return;
        }
        const prototypeSuccess = await this.prototypeChanges([flagName], params);
        if (prototypeSuccess) {
          await this.handleUserResponse([flagName], params);
        }
      }
      /** Sets multiple flags (all or unconfigured) with validation and user confirmation */
      async setMultipleFlags(params) {
        if (params.default && !this.flags.some((f32) => f32.unconfiguredBehavesLike)) {
          await this.ioHelper.defaults.error("The --default options are not compatible with the AWS CDK library used by your application. Please upgrade to 2.212.0 or above.");
          return;
        }
        const flagsToSet = this.getFlagsToSet(params);
        const prototypeSuccess = await this.prototypeChanges(flagsToSet, params);
        if (prototypeSuccess) {
          await this.handleUserResponse(flagsToSet, params);
        }
      }
      /** Determines which flags should be set based on the provided parameters */
      getFlagsToSet(params) {
        if (params.all && params.default) {
          return this.flags.filter((flag) => this.isBooleanFlag(flag)).map((flag) => flag.name);
        } else if (params.all) {
          return this.flags.filter((flag) => flag.userValue === void 0 || !isEffectiveValueEqualToRecommended(flag)).filter((flag) => this.isBooleanFlag(flag)).map((flag) => flag.name);
        } else {
          return this.flags.filter((flag) => flag.userValue === void 0).filter((flag) => this.isBooleanFlag(flag)).map((flag) => flag.name);
        }
      }
      /** Sets flags that don't cause template changes */
      async setSafeFlags(params) {
        const cdkJson = await JSON.parse(await fs46.readFile(path44.join(process.cwd(), "cdk.json"), "utf-8"));
        this.app = params.app || cdkJson.app;
        const isUsingTsNode = this.app.includes("ts-node");
        if (isUsingTsNode && !this.app.includes("-T") && !this.app.includes("--transpileOnly")) {
          await this.ioHelper.defaults.info(`Repeated synths with ts-node will type-check the application on every synth. Add --transpileOnly to cdk.json's "app" command to make this operation faster.`);
        }
        const unconfiguredFlags = this.flags.filter((flag) => flag.userValue === void 0 && this.isBooleanFlag(flag));
        if (unconfiguredFlags.length === 0) {
          await this.ioHelper.defaults.info("All feature flags are configured.");
          return;
        }
        await this.initializeSafetyCheck();
        const safeFlags = await this.batchTestFlags(unconfiguredFlags);
        await this.cleanupSafetyCheck();
        if (safeFlags.length > 0) {
          await this.ioHelper.defaults.info("Flags that can be set without template changes:");
          for (const flag of safeFlags) {
            await this.ioHelper.defaults.info(`- ${flag.name} -> ${flag.recommendedValue}`);
          }
          await this.handleUserResponse(safeFlags.map((flag) => flag.name), { ...params, recommended: true });
        } else {
          await this.ioHelper.defaults.info("No more flags can be set without causing template changes.");
        }
      }
      /** Initializes the safety check by reading context and synthesizing baseline templates */
      async initializeSafetyCheck() {
        const baseContext = new import_toolkit_lib17.CdkAppMultiContext(process.cwd());
        this.baseContextValues = { ...await baseContext.read(), ...this.cliContextValues };
        this.baselineTempDir = fs46.mkdtempSync(path44.join(os12.tmpdir(), "cdk-baseline-"));
        const mergedContext = new import_toolkit_lib17.MemoryContext(this.baseContextValues);
        const baseSource = await this.toolkit.fromCdkApp(this.app, {
          contextStore: mergedContext,
          outdir: this.baselineTempDir
        });
        const baseCx = await this.toolkit.synth(baseSource);
        const baseAssembly = baseCx.cloudAssembly;
        this.allStacks = baseAssembly.stacksRecursively;
        this.queue = new import_p_queue.default({ concurrency: 4 });
      }
      /** Cleans up temporary directories created during safety checks */
      async cleanupSafetyCheck() {
        if (this.baselineTempDir) {
          await fs46.remove(this.baselineTempDir);
          this.baselineTempDir = void 0;
        }
      }
      /** Tests multiple flags together and isolates unsafe ones using binary search */
      async batchTestFlags(flags) {
        if (flags.length === 0) return [];
        const allFlagsContext = { ...this.baseContextValues };
        flags.forEach((flag) => {
          allFlagsContext[flag.name] = flag.recommendedValue;
        });
        const allSafe = await this.testBatch(allFlagsContext);
        if (allSafe) return flags;
        return this.isolateUnsafeFlags(flags);
      }
      /** Tests if a set of context values causes template changes by synthesizing and diffing */
      async testBatch(contextValues) {
        const testContext = new import_toolkit_lib17.MemoryContext(contextValues);
        const tempDir = fs46.mkdtempSync(path44.join(os12.tmpdir(), "cdk-test-"));
        const testSource = await this.toolkit.fromCdkApp(this.app, {
          contextStore: testContext,
          outdir: tempDir
        });
        const testCx = await this.toolkit.synth(testSource);
        try {
          for (const stack of this.allStacks) {
            const templatePath = stack.templateFullPath;
            const diff = await this.toolkit.diff(testCx, {
              method: import_toolkit_lib17.DiffMethod.LocalFile(templatePath),
              stacks: {
                strategy: "pattern-must-match-single" /* PATTERN_MUST_MATCH_SINGLE */,
                patterns: [stack.hierarchicalId]
              }
            });
            for (const stackDiff of Object.values(diff)) {
              if (stackDiff.differenceCount > 0) {
                return false;
              }
            }
          }
          return true;
        } finally {
          await fs46.remove(tempDir);
        }
      }
      /** Uses binary search to isolate which flags are safe to set without template changes */
      async isolateUnsafeFlags(flags) {
        const safeFlags = [];
        const processBatch = /* @__PURE__ */ __name(async (batch, contextValues) => {
          if (batch.length === 1) {
            const isSafe = await this.testBatch(
              { ...contextValues, [batch[0].name]: batch[0].recommendedValue }
            );
            if (isSafe) safeFlags.push(batch[0]);
            return;
          }
          const batchContext = { ...contextValues };
          batch.forEach((flag) => {
            batchContext[flag.name] = flag.recommendedValue;
          });
          const isSafeBatch = await this.testBatch(batchContext);
          if (isSafeBatch) {
            safeFlags.push(...batch);
            return;
          }
          const mid = Math.floor(batch.length / 2);
          const left = batch.slice(0, mid);
          const right = batch.slice(mid);
          void this.queue.add(() => processBatch(left, contextValues));
          void this.queue.add(() => processBatch(right, contextValues));
        }, "processBatch");
        void this.queue.add(() => processBatch(flags, this.baseContextValues));
        await this.queue.onIdle();
        return safeFlags;
      }
      /** Prototypes flag changes by synthesizing templates and showing diffs to the user */
      async prototypeChanges(flagNames, params) {
        const baseContext = new import_toolkit_lib17.CdkAppMultiContext(process.cwd());
        const baseContextValues = { ...await baseContext.read(), ...this.cliContextValues };
        const memoryContext = new import_toolkit_lib17.MemoryContext(baseContextValues);
        const cdkJson = await JSON.parse(await fs46.readFile(path44.join(process.cwd(), "cdk.json"), "utf-8"));
        const app = cdkJson.app;
        const source = await this.toolkit.fromCdkApp(app, {
          contextStore: memoryContext,
          outdir: fs46.mkdtempSync(path44.join(os12.tmpdir(), "cdk-original-"))
        });
        const updateObj = await this.buildUpdateObject(flagNames, params, baseContextValues);
        if (!updateObj) return false;
        await memoryContext.update(updateObj);
        const cx = await this.toolkit.synth(source);
        const assembly = cx.cloudAssembly;
        const modifiedSource = await this.toolkit.fromCdkApp(app, {
          contextStore: memoryContext,
          outdir: fs46.mkdtempSync(path44.join(os12.tmpdir(), "cdk-temp-"))
        });
        const modifiedCx = await this.toolkit.synth(modifiedSource);
        const allStacks = assembly.stacksRecursively;
        for (const stack of allStacks) {
          const templatePath = stack.templateFullPath;
          await this.toolkit.diff(modifiedCx, {
            method: import_toolkit_lib17.DiffMethod.LocalFile(templatePath),
            stacks: {
              strategy: "pattern-must-match-single" /* PATTERN_MUST_MATCH_SINGLE */,
              patterns: [stack.hierarchicalId]
            }
          });
        }
        await this.displayFlagChanges(updateObj, baseContextValues);
        return true;
      }
      /** Displays a summary of flag changes showing old and new values */
      async displayFlagChanges(updateObj, baseContextValues) {
        await this.ioHelper.defaults.info("\nFlag changes:");
        for (const [flagName, newValue] of Object.entries(updateObj)) {
          const currentValue = baseContextValues[flagName];
          const currentDisplay = currentValue === void 0 ? "<unset>" : String(currentValue);
          await this.ioHelper.defaults.info(`  ${flagName}: ${currentDisplay} \u2192 ${newValue}`);
        }
      }
      /** Builds the update object with new flag values based on parameters and current context */
      async buildUpdateObject(flagNames, params, baseContextValues) {
        const updateObj = {};
        if (flagNames.length === 1 && params.value !== void 0) {
          const flagName = flagNames[0];
          const boolValue = params.value === "true";
          if (baseContextValues[flagName] === boolValue) {
            await this.ioHelper.defaults.info("Flag is already set to the specified value. No changes needed.");
            return null;
          }
          updateObj[flagName] = boolValue;
        } else {
          for (const flagName of flagNames) {
            const flag = this.flags.find((f32) => f32.name === flagName);
            if (!flag) {
              await this.ioHelper.defaults.error(`Flag ${flagName} not found.`);
              return null;
            }
            const newValue = params.recommended ? flag.recommendedValue : String(defaultValue(flag)) === "true";
            updateObj[flagName] = newValue;
          }
        }
        return updateObj;
      }
      /** Prompts user for confirmation and applies changes if accepted */
      async handleUserResponse(flagNames, params) {
        const userAccepted = await this.ioHelper.requestResponse({
          time: /* @__PURE__ */ new Date(),
          level: "info",
          code: "CDK_TOOLKIT_I9300",
          message: "Do you want to accept these changes?",
          data: {
            flagNames,
            responseDescription: 'Enter "y" to apply changes or "n" to cancel'
          },
          defaultResponse: false
        });
        if (userAccepted) {
          await this.modifyValues(flagNames, params);
          await this.ioHelper.defaults.info("Flag value(s) updated successfully.");
        } else {
          await this.ioHelper.defaults.info("Operation cancelled");
        }
        await this.cleanupTempDirectories();
      }
      /** Removes temporary directories created during flag operations */
      async cleanupTempDirectories() {
        const originalDir = path44.join(process.cwd(), "original");
        const tempDir = path44.join(process.cwd(), "temp");
        await fs46.remove(originalDir);
        await fs46.remove(tempDir);
      }
      /** Actually modifies the cdk.json file with the new flag values */
      async modifyValues(flagNames, params) {
        const cdkJsonPath = path44.join(process.cwd(), "cdk.json");
        const cdkJsonContent = await fs46.readFile(cdkJsonPath, "utf-8");
        const cdkJson = JSON.parse(cdkJsonContent);
        if (flagNames.length === 1 && !params.safe && !params.all) {
          const boolValue = params.value === "true";
          cdkJson.context[String(flagNames[0])] = boolValue;
          await this.ioHelper.defaults.info(`Setting flag '${flagNames}' to: ${boolValue}`);
        } else {
          for (const flagName of flagNames) {
            const flag = this.flags.find((f32) => f32.name === flagName);
            const newValue = params.recommended || params.safe ? flag.recommendedValue : String(defaultValue(flag)) === "true";
            cdkJson.context[flagName] = newValue;
          }
        }
        await fs46.writeFile(cdkJsonPath, JSON.stringify(cdkJson, null, 2), "utf-8");
      }
      /** Displays flags in a table format, either specific flags or filtered by criteria */
      async displayFlags(params) {
        const { FLAGNAME, all } = params;
        if (FLAGNAME && FLAGNAME.length > 0) {
          await this.displaySpecificFlags(FLAGNAME);
          return;
        }
        const [flagsToDisplay, header] = all ? [this.flags, "All feature flags"] : [_FlagOperations.filterNeedsAttention(this.flags), "Unconfigured feature flags"];
        await this.ioHelper.defaults.info(header);
        await this.displayFlagTable(flagsToDisplay);
        if (!all && flagsToDisplay.length === 0) {
          await this.ioHelper.defaults.info("");
          await this.ioHelper.defaults.info("\u2705 All feature flags are already set to their recommended values.");
          await this.ioHelper.defaults.info("Use 'cdk flags --all --unstable=flags' to see all flags and their current values.");
        }
      }
      /** Displays detailed information for specific flags matching the given names */
      async displaySpecificFlags(flagNames) {
        const matchingFlags = this.flags.filter((f32) => flagNames.some((searchTerm) => f32.name.toLowerCase().includes(searchTerm.toLowerCase())));
        if (matchingFlags.length === 0) {
          await this.ioHelper.defaults.error(`Flag matching "${flagNames.join(", ")}" not found.`);
          return;
        }
        if (matchingFlags.length === 1) {
          const flag = matchingFlags[0];
          await this.ioHelper.defaults.info(`Flag name: ${flag.name}`);
          await this.ioHelper.defaults.info(`Description: ${flag.explanation}`);
          await this.ioHelper.defaults.info(`Recommended value: ${flag.recommendedValue}`);
          await this.ioHelper.defaults.info(`Default value: ${defaultValue(flag)}`);
          await this.ioHelper.defaults.info(`User value: ${flag.userValue}`);
          await this.ioHelper.defaults.info(`Effective value: ${effectiveValue(flag)}`);
          return;
        }
        await this.ioHelper.defaults.info(`Found ${matchingFlags.length} flags matching "${flagNames.join(", ")}"`);
        await this.displayFlagTable(matchingFlags);
      }
      /** Returns sort order for flags */
      getFlagSortOrder(flag) {
        if (flag.userValue === void 0) return 3;
        if (isEffectiveValueEqualToRecommended(flag)) return 1;
        return 2;
      }
      /** Displays flags in a formatted table grouped by module and sorted */
      async displayFlagTable(flags) {
        const sortedFlags = [...flags].sort((a32, b32) => {
          const orderA = this.getFlagSortOrder(a32);
          const orderB = this.getFlagSortOrder(b32);
          if (orderA !== orderB) return orderA - orderB;
          if (a32.module !== b32.module) return a32.module.localeCompare(b32.module);
          return a32.name.localeCompare(b32.name);
        });
        const rows = [["Feature Flag", "Recommended", "User", "Effective"]];
        let currentModule = "";
        sortedFlags.forEach((flag) => {
          if (flag.module !== currentModule) {
            rows.push([chalk31.bold(`Module: ${flag.module}`), "", "", ""]);
            currentModule = flag.module;
          }
          rows.push([
            `  ${flag.name}`,
            String(flag.recommendedValue),
            flag.userValue === void 0 ? "<unset>" : String(flag.userValue),
            String(effectiveValue(flag))
          ]);
        });
        const formattedTable = (0, import_cloudformation_diff4.formatTable)(rows, void 0, true);
        await this.ioHelper.defaults.info(formattedTable);
      }
      /** Checks if a flag has a boolean recommended value */
      isBooleanFlag(flag) {
        const recommended = flag.recommendedValue;
        return typeof recommended === "boolean" || recommended === "true" || recommended === "false";
      }
      /** Shows helpful usage examples and available command options */
      async displayHelpMessage() {
        await this.ioHelper.defaults.info("\n" + chalk31.bold("Available options:"));
        await this.ioHelper.defaults.info("  cdk flags --interactive     # Interactive menu to manage flags");
        await this.ioHelper.defaults.info("  cdk flags --all             # Show all flags (including configured ones)");
        await this.ioHelper.defaults.info("  cdk flags --set --all --recommended    # Set all flags to recommended values");
        await this.ioHelper.defaults.info("  cdk flags --set --all --default       # Set all flags to default values");
        await this.ioHelper.defaults.info("  cdk flags --set --unconfigured --recommended  # Set unconfigured flags to recommended");
        await this.ioHelper.defaults.info("  cdk flags --set <flag-name> --value <true|false>  # Set specific flag");
        await this.ioHelper.defaults.info("  cdk flags --safe            # Safely set flags that don't change templates");
      }
    };
    __name(isEffectiveValueEqualToRecommended, "isEffectiveValueEqualToRecommended");
    __name(effectiveValue, "effectiveValue");
    __name(defaultValue, "defaultValue");
  }
});

// lib/cli/cdk-toolkit.ts
function isFileEvent2(event) {
  return FILE_EVENTS2.includes(event);
}
async function printSerializedObject(ioHelper, obj, json) {
  await ioHelper.defaults.result(serializeStructure(obj, json));
}
function buildParameterMap2(parameters) {
  const parameterMap = { "*": {} };
  for (const key in parameters) {
    if (parameters.hasOwnProperty(key)) {
      const [stack, parameter] = key.split(":", 2);
      if (!parameter) {
        parameterMap["*"][stack] = parameters[key];
      } else {
        if (!parameterMap[stack]) {
          parameterMap[stack] = {};
        }
        parameterMap[stack][parameter] = parameters[key];
      }
    }
  }
  return parameterMap;
}
async function askUserConfirmation(ioHost, req) {
  await ioHost.withCorkedLogging(async () => {
    await ioHost.asIoHelper().requestResponse(req);
  });
}
async function displayFlagsMessage(ioHost, toolkit, cloudExecutable) {
  const flags = await toolkit.flags(cloudExecutable);
  if (flags.every((flag) => flag.unconfiguredBehavesLike === void 0)) {
    return;
  }
  const unconfiguredFlags = FlagOperations.filterNeedsAttention(flags);
  const numUnconfigured = unconfiguredFlags.length;
  if (numUnconfigured > 0) {
    await ioHost.defaults.warn(`${numUnconfigured} feature flags are not configured. Run 'cdk flags --unstable=flags' to learn more.`);
  }
}
function requiresApproval(requireApproval, permissionChangeType) {
  return requireApproval === import_cloud_assembly_schema8.RequireApproval.ANYCHANGE || requireApproval === import_cloud_assembly_schema8.RequireApproval.BROADENING && permissionChangeType === import_toolkit_lib18.PermissionChangeType.BROADENING;
}
var import_node_crypto21, path45, import_node_util8, cxapi12, import_cloud_assembly_schema8, import_toolkit_lib18, chalk32, fs47, pLimit5, FILE_EVENTS2, InternalToolkit, CdkToolkit, WorkGraphDeploymentActions;
var init_cdk_toolkit = __esm({
  "lib/cli/cdk-toolkit.ts"() {
    "use strict";
    import_node_crypto21 = require("node:crypto");
    path45 = __toESM(require("node:path"));
    import_node_util8 = require("node:util");
    cxapi12 = __toESM(require_lib3());
    import_cloud_assembly_schema8 = __toESM(require_lib2());
    import_toolkit_lib18 = __toESM(require_lib12());
    chalk32 = __toESM(require_source());
    init_esm2();
    init_handler();
    fs47 = __toESM(require_lib4());
    init_io_host2();
    init_user_configuration();
    init_api_private();
    init_api();
    init_bootstrap3();
    init_cloud_assembly4();
    init_deploy_private();
    init_refactor3();
    init_deploy4();
    init_list_stacks();
    init_migrate();
    init_cxapp();
    init_util9();
    init_collect_telemetry();
    init_error2();
    init_messages2();
    init_operations();
    pLimit5 = require_p_limit();
    FILE_EVENTS2 = [EVENTS.ADD, EVENTS.ADD_DIR, EVENTS.CHANGE, EVENTS.UNLINK, EVENTS.UNLINK_DIR];
    __name(isFileEvent2, "isFileEvent");
    InternalToolkit = class extends import_toolkit_lib18.Toolkit {
      static {
        __name(this, "InternalToolkit");
      }
      constructor(sdkProvider, options) {
        super(options);
        this._sdkProvider = sdkProvider;
      }
      /**
       * Access to the AWS SDK
       * @internal
       */
      async sdkProvider(_action) {
        return this._sdkProvider;
      }
    };
    CdkToolkit = class {
      constructor(props) {
        this.props = props;
        this.ioHost = props.ioHost ?? CliIoHost.instance();
        this.toolkitStackName = props.toolkitStackName ?? DEFAULT_TOOLKIT_STACK_NAME;
        const iPromiseUnstablenessIsCheckedByTheCli = {
          "publish-assets": true,
          "diagnose": true,
          "flags": true,
          "orphan": true,
          "refactor": true,
          "validate": true
        };
        this.toolkit = new InternalToolkit(props.sdkProvider, {
          assemblyFailureAt: this.validateMetadataFailAt(),
          color: true,
          emojis: true,
          ioHost: this.ioHost,
          toolkitStackName: this.toolkitStackName,
          unstableFeatures: Object.keys(iPromiseUnstablenessIsCheckedByTheCli)
        });
      }
      static {
        __name(this, "CdkToolkit");
      }
      async metadata(stackName, json) {
        const stacks = await this.selectSingleStackByName(stackName);
        await printSerializedObject(this.ioHost.asIoHelper(), stacks.firstStack.metadata ?? {}, json);
      }
      async acknowledge(noticeId) {
        const acks = new Set(this.props.configuration.context.get("acknowledged-issue-numbers") ?? []);
        acks.add(Number(noticeId));
        this.props.configuration.context.set("acknowledged-issue-numbers", Array.from(acks));
        await this.props.configuration.saveContext();
      }
      async cliTelemetryStatus(args) {
        const canCollect = canCollectTelemetry(args, this.props.configuration.context);
        if (canCollect) {
          await this.ioHost.asIoHelper().defaults.info("CLI Telemetry is enabled. See https://docs.aws.amazon.com/cdk/v2/guide/cli-telemetry.html for ways to disable.");
        } else {
          await this.ioHost.asIoHelper().defaults.info("CLI Telemetry is disabled. See https://docs.aws.amazon.com/cdk/v2/guide/cli-telemetry.html for ways to enable.");
        }
      }
      async cliTelemetry(enable) {
        this.props.configuration.context.set("cli-telemetry", enable);
        await this.props.configuration.saveContext();
        await this.ioHost.asIoHelper().defaults.info(`Telemetry ${enable ? "enabled" : "disabled"}`);
      }
      async diff(options) {
        const stacks = await this.selectStacksForDiff(options.stackNames, options.exclusively);
        const strict = !!options.strict;
        const contextLines = options.contextLines || 3;
        const quiet = options.quiet || false;
        let diffs = 0;
        const parameterMap = buildParameterMap2(options.parameters);
        if (options.templatePath !== void 0) {
          if (stacks.stackCount !== 1) {
            throw new import_toolkit_lib18.ToolkitError(
              "SingleStackRequired",
              "Can only select one stack when comparing to fixed template. Use --exclusively to avoid selecting multiple stacks."
            );
          }
          if (!await fs47.pathExists(options.templatePath)) {
            throw new import_toolkit_lib18.ToolkitError("TemplateNotFound", `There is no file at ${options.templatePath}`);
          }
          if (options.importExistingResources) {
            throw new import_toolkit_lib18.ToolkitError(
              "ImportWithTemplatePath",
              "Can only use --import-existing-resources flag when comparing against deployed stacks."
            );
          }
          const template = deserializeStructure(await fs47.readFile(options.templatePath, { encoding: "utf-8" }));
          const formatter = new DiffFormatter({
            templateInfo: {
              oldTemplate: template,
              newTemplate: stacks.firstStack
            }
          });
          if (options.securityOnly) {
            const securityDiff = formatter.formatSecurityDiff({ quiet });
            if (securityDiff.permissionChangeType === import_toolkit_lib18.PermissionChangeType.BROADENING) {
              await this.ioHost.asIoHelper().defaults.warn("This deployment will make potentially sensitive changes according to your current security approval level.\nPlease confirm you intend to make the following modifications:\n");
              await this.ioHost.asIoHelper().defaults.info(securityDiff.formattedDiff);
              diffs += securityDiff.numStacksWithChanges;
            }
          } else {
            const diff = formatter.formatStackDiff({
              strict,
              contextLines,
              quiet
            });
            diffs = diff.numStacksWithChanges;
            await this.ioHost.asIoHelper().defaults.info(diff.formattedDiff);
          }
        } else {
          const allMappings = options.includeMoves ? await mappingsByEnvironment(stacks.stackArtifacts, this.props.sdkProvider, true) : [];
          for (const stack of stacks.stackArtifacts) {
            const templateWithNestedStacks = await this.props.deployments.readCurrentTemplateWithNestedStacks(
              stack,
              options.compareAgainstProcessedTemplate
            );
            const currentTemplate = templateWithNestedStacks.deployedRootTemplate;
            const nestedStacks = templateWithNestedStacks.nestedStacks;
            const migrator = new ResourceMigrator({
              deployments: this.props.deployments,
              ioHelper: asIoHelper(this.ioHost, "diff")
            });
            const resourcesToImport = await migrator.tryGetResources(await this.props.deployments.resolveEnvironment(stack));
            if (resourcesToImport) {
              removeNonImportResources(stack);
            }
            const changeSet = options.method !== "template" ? await this.tryCreateDiffChangeSet(stack, options, parameterMap, resourcesToImport, quiet) : void 0;
            const mappings = allMappings.find(
              (m20) => m20.environment.region === stack.environment.region && m20.environment.account === stack.environment.account
            )?.mappings ?? {};
            const formatter = new DiffFormatter({
              templateInfo: {
                oldTemplate: currentTemplate,
                newTemplate: stack,
                changeSet,
                isImport: !!resourcesToImport,
                nestedStacks,
                mappings
              }
            });
            if (options.securityOnly) {
              const securityDiff = formatter.formatSecurityDiff({ quiet });
              if (securityDiff.permissionChangeType === import_toolkit_lib18.PermissionChangeType.BROADENING) {
                await this.ioHost.asIoHelper().defaults.warn("This deployment will make potentially sensitive changes according to your current security approval level.\nPlease confirm you intend to make the following modifications:\n");
                await this.ioHost.asIoHelper().defaults.info(securityDiff.formattedDiff);
                diffs += securityDiff.numStacksWithChanges;
              }
            } else {
              const diff = formatter.formatStackDiff({
                strict,
                contextLines,
                quiet
              });
              await this.ioHost.asIoHelper().defaults.info(diff.formattedDiff);
              diffs += diff.numStacksWithChanges;
            }
          }
        }
        await this.ioHost.asIoHelper().defaults.info((0, import_node_util8.format)("\n\u2728  Number of stacks with differences: %s\n", diffs));
        return diffs && options.fail ? 1 : 0;
      }
      /**
       * Try to create a diff changeset for the given stack.
       * Returns undefined if the stack cannot be accessed and changeSetOnly is not set.
       */
      async tryCreateDiffChangeSet(stack, options, parameterMap, resourcesToImport, quiet) {
        try {
          void await this.props.deployments.stackExists({
            stack,
            deployName: stack.stackName,
            tryLookupRole: true
          });
        } catch (e32) {
          if (options.method === "change-set") {
            throw import_toolkit_lib18.ToolkitError.withCause("DescribeStacksFailed", `Could not access stack '${stack.stackName}'. Please check your permissions or use '--method=auto' to allow falling back to a template diff.`, e32);
          }
          await this.ioHost.asIoHelper().defaults.debug(formatErrorMessage(e32));
          if (!quiet) {
            await this.ioHost.asIoHelper().defaults.info(
              `Could not access stack '${stack.stackName}', falling back to template diff. Use '--method=change-set' to fail instead. Run with -v to see the reason.
`
            );
          }
          return void 0;
        }
        return cfn_api_exports.createDiffChangeSet(asIoHelper(this.ioHost, "diff"), {
          stack,
          uuid: (0, import_node_crypto21.randomUUID)(),
          deployments: this.props.deployments,
          willExecute: false,
          sdkProvider: this.props.sdkProvider,
          parameters: Object.assign({}, parameterMap["*"], parameterMap[stack.stackName]),
          resourcesToImport,
          importExistingResources: options.importExistingResources,
          failOnError: options.method === "change-set"
        });
      }
      async deploy(options) {
        if (options.watch) {
          return this.watch(options);
        }
        if (options.progress) {
          this.ioHost.stackProgress = options.progress;
        }
        const requireApproval = options.requireApproval ?? import_cloud_assembly_schema8.RequireApproval.BROADENING;
        this.ioHost.requireDeployApproval = requireApproval;
        if (options.deploymentMethod?.method === "execute-change-set") {
          await this.toolkit.deploy(this.props.cloudExecutable, {
            deploymentMethod: options.deploymentMethod,
            stacks: {
              patterns: options.selector.patterns,
              strategy: "pattern-must-match-single" /* PATTERN_MUST_MATCH_SINGLE */,
              expand: "none" /* NONE */
            },
            roleArn: options.roleArn,
            forceDeployment: options.force,
            rollback: options.rollback,
            reuseAssets: options.reuseAssets,
            concurrency: options.concurrency,
            traceLogs: options.traceLogs,
            notificationArns: options.notificationArns,
            tags: options.tags,
            outputsFile: options.outputsFile,
            assetParallelism: options.assetParallelism,
            assetBuildConcurrency: options.assetBuildConcurrency,
            assetBuildTime: options.assetBuildTime,
            parameters: void 0
            // parameters are only set during change set creation, so this is explicitly unset because change set already exists
          });
          return;
        }
        const startSynthTime = (/* @__PURE__ */ new Date()).getTime();
        const stackCollection = await this.selectStacksForDeploy(
          options.selector,
          options.exclusively,
          options.cacheCloudAssembly,
          options.ignoreNoStacks
        );
        const elapsedSynthTime = (/* @__PURE__ */ new Date()).getTime() - startSynthTime;
        await this.ioHost.asIoHelper().defaults.info(`
\u2728  Synthesis time: ${formatTime(elapsedSynthTime)}s
`);
        if (stackCollection.stackCount === 0) {
          await this.ioHost.asIoHelper().defaults.error("This app contains no stacks");
          return;
        }
        const migrator = new ResourceMigrator({
          deployments: this.props.deployments,
          ioHelper: asIoHelper(this.ioHost, "deploy")
        });
        await migrator.tryMigrateResources(stackCollection, {
          toolkitStackName: this.toolkitStackName,
          ...options
        });
        if (options.deploymentMethod?.method === "hotswap") {
          await this.ioHost.asIoHelper().defaults.warn(
            "\u26A0\uFE0F The --hotswap and --hotswap-fallback flags deliberately introduce CloudFormation drift to speed up deployments"
          );
          await this.ioHost.asIoHelper().defaults.warn("\u26A0\uFE0F They should only be used for development - never use them for your production Stacks!\n");
        }
        const stacks = stackCollection.stackArtifacts;
        const assetBuildTime = options.assetBuildTime ?? "all-before-deploy" /* ALL_BEFORE_DEPLOY */;
        const prebuildAssets = assetBuildTime === "all-before-deploy" /* ALL_BEFORE_DEPLOY */;
        const concurrency = options.concurrency || 1;
        if (concurrency > 1) {
          this.ioHost.stackProgress = "events" /* EVENTS */;
          if (options.progress && options.progress != "events" /* EVENTS */) {
            await this.ioHost.asIoHelper().defaults.warn('\u26A0\uFE0F The --concurrency flag only supports --progress "events". Switching to "events".');
          }
        }
        const stacksAndTheirAssetManifests = stacks.flatMap((stack) => [
          stack,
          ...stack.dependencies.filter((x) => cxapi12.AssetManifestArtifact.isAssetManifestArtifact(x))
        ]);
        const workGraph = new WorkGraphBuilder(
          asIoHelper(this.ioHost, "deploy"),
          prebuildAssets
        ).build(stacksAndTheirAssetManifests);
        if (!options.force) {
          await this.removePublishedAssets(workGraph, options);
        }
        const graphConcurrency = {
          "stack": concurrency,
          "asset-build": options.assetParallelism ?? true ? options.assetBuildConcurrency ?? 1 : 1,
          // This will be CPU-bound/memory bound, mostly matters for Docker builds
          "asset-publish": options.assetParallelism ?? true ? 8 : 1,
          // This will be I/O-bound, 8 in parallel seems reasonable
          "marker": 1
        };
        const deploymentActions = new WorkGraphDeploymentActions(this.props.deployments, this.ioHost, this, {
          roleArn: options.roleArn,
          force: options.force,
          stackCount: stackCollection.stackCount,
          notificationArns: options.notificationArns,
          deploymentMethod: options.deploymentMethod,
          toolkitStackName: this.toolkitStackName,
          reuseAssets: options.reuseAssets,
          tags: options.tags,
          parameters: options.parameters,
          usePreviousParameters: options.usePreviousParameters,
          rollback: options.rollback,
          concurrency,
          requireApproval,
          assetParallelism: options.assetParallelism,
          extraUserAgent: options.extraUserAgent,
          cloudWatchLogMonitor: options.cloudWatchLogMonitor,
          sdkProvider: this.props.sdkProvider
        });
        const startDeployTime = Date.now();
        await workGraph.doParallel(graphConcurrency, deploymentActions);
        if (options.outputsFile) {
          await deploymentActions.writeOutputs(options.outputsFile);
        }
        this.ioHost.telemetry?.commandSpan?.addTimer("totalDeployTime", Date.now() - startDeployTime);
        await this.ioHost.asIoHelper().defaults.info(`
\u2728  Total time: ${formatTime(Date.now() - startSynthTime)}s
`);
      }
      /**
       * Detect infrastructure drift for the given stack(s)
       */
      async drift(options) {
        const driftResults = await this.toolkit.drift(this.props.cloudExecutable, {
          stacks: {
            patterns: options.selector.patterns,
            strategy: options.selector.patterns.length > 0 ? "pattern-match" /* PATTERN_MATCH */ : "all-stacks" /* ALL_STACKS */
          }
        });
        const totalDrifts = Object.values(driftResults).reduce((total, current) => total + (current.numResourcesWithDrift ?? 0), 0);
        return totalDrifts > 0 && options.fail ? 1 : 0;
      }
      /**
       * Validate synthesized templates against policy rules
       */
      async validate(options) {
        this.props.cloudExecutable.switchOnDebugging();
        const result2 = await this.toolkit.validate(this.props.cloudExecutable, options);
        return result2.conclusion === "failure" ? 1 : 0;
      }
      /**
       * Diagnose errors
       */
      async diagnose(options) {
        this.props.cloudExecutable.switchOnDebugging();
        const results = await this.toolkit.diagnose(this.props.cloudExecutable, options);
        if (results.stacks.some((s) => s.result.type !== "no-problem")) {
          return 1;
        }
        return 0;
      }
      /**
       * Roll back the given stack or stacks.
       */
      async rollback(options) {
        const startSynthTime = (/* @__PURE__ */ new Date()).getTime();
        const stackCollection = await this.selectStacksForDeploy(options.selector, true);
        const elapsedSynthTime = (/* @__PURE__ */ new Date()).getTime() - startSynthTime;
        await this.ioHost.asIoHelper().defaults.info(`
\u2728  Synthesis time: ${formatTime(elapsedSynthTime)}s
`);
        if (stackCollection.stackCount === 0) {
          await this.ioHost.asIoHelper().defaults.error("No stacks selected");
          return;
        }
        let anyRollbackable = false;
        for (const stack of stackCollection.stackArtifacts) {
          await this.ioHost.asIoHelper().defaults.info("Rolling back %s", chalk32.bold(stack.displayName));
          const startRollbackTime = (/* @__PURE__ */ new Date()).getTime();
          try {
            const result2 = await this.props.deployments.rollbackStack({
              stack,
              roleArn: options.roleArn,
              toolkitStackName: options.toolkitStackName,
              orphanFailedResources: options.force,
              validateBootstrapStackVersion: options.validateBootstrapStackVersion,
              orphanLogicalIds: options.orphanLogicalIds
            });
            if (!result2.notInRollbackableState) {
              anyRollbackable = true;
            }
            const elapsedRollbackTime = (/* @__PURE__ */ new Date()).getTime() - startRollbackTime;
            await this.ioHost.asIoHelper().defaults.info(`
\u2728  Rollback time: ${formatTime(elapsedRollbackTime).toString()}s
`);
          } catch (e32) {
            await this.ioHost.asIoHelper().defaults.error("\n \u274C  %s failed: %s", chalk32.bold(stack.displayName), formatErrorMessage(e32));
            throw new import_toolkit_lib18.ToolkitError("RollbackFailed", "Rollback failed (use --force to orphan failing resources)");
          }
        }
        if (!anyRollbackable) {
          throw new import_toolkit_lib18.ToolkitError("NoRollbackableStacks", "No stacks were in a state that could be rolled back");
        }
      }
      async publishAssets(options) {
        await this.toolkit.publishAssets(this.props.cloudExecutable, options);
      }
      async watch(options) {
        const rootDir = path45.dirname(path45.resolve(PROJECT_CONFIG));
        const ioHelper = asIoHelper(this.ioHost, "watch");
        await this.ioHost.asIoHelper().defaults.debug("root directory used for 'watch' is: %s", rootDir);
        const watchSettings = this.props.configuration.settings.get(["watch"]);
        if (!watchSettings) {
          throw new import_toolkit_lib18.ToolkitError(
            "WatchConfigMissing",
            `Cannot use the 'watch' command without specifying at least one directory to monitor. Make sure to add a "watch" key to your cdk.json`
          );
        }
        const watchIncludes = this.patternsArrayForWatch(watchSettings.include, {
          defaultPattern: "**",
          returnDefaultIfEmpty: true
        });
        await this.ioHost.asIoHelper().defaults.debug("'include' patterns for 'watch': %s", watchIncludes);
        const outputDir = this.props.configuration.settings.get(["output"]);
        const watchExcludes = this.patternsArrayForWatch(watchSettings.exclude, {
          defaultPattern: "",
          returnDefaultIfEmpty: false
        }).concat(`${outputDir}/**`, "**/.*", "**/.*/**", "**/node_modules/**");
        await this.ioHost.asIoHelper().defaults.debug("'exclude' patterns for 'watch': %s", watchExcludes);
        let latch = "pre-ready";
        const cloudWatchLogMonitor = options.traceLogs ? new CloudWatchLogEventMonitor({
          ioHelper
        }) : void 0;
        const deployAndWatch = /* @__PURE__ */ __name(async () => {
          latch = "deploying";
          await cloudWatchLogMonitor?.deactivate();
          await this.invokeDeployFromWatch(options, cloudWatchLogMonitor);
          while (latch === "queued") {
            latch = "deploying";
            await this.ioHost.asIoHelper().defaults.info("Detected file changes during deployment. Invoking 'cdk deploy' again");
            await this.invokeDeployFromWatch(options, cloudWatchLogMonitor);
          }
          latch = "open";
          await cloudWatchLogMonitor?.activate();
        }, "deployAndWatch");
        const shouldIgnore = createIgnoreMatcher({
          include: watchIncludes,
          exclude: watchExcludes,
          rootDir
        });
        watch(".", {
          ignored: shouldIgnore,
          cwd: rootDir
        }).on("ready", async () => {
          latch = "open";
          await this.ioHost.asIoHelper().defaults.debug("'watch' received the 'ready' event. From now on, all file changes will trigger a deployment");
          await this.ioHost.asIoHelper().defaults.info("Triggering initial 'cdk deploy'");
          await deployAndWatch();
        }).on("all", async (event, filePath) => {
          if (!isFileEvent2(event)) {
            return;
          }
          if (latch === "pre-ready") {
            await this.ioHost.asIoHelper().defaults.info(`'watch' is observing ${event === "addDir" ? "directory" : "the file"} '%s' for changes`, filePath);
          } else if (latch === "open") {
            await this.ioHost.asIoHelper().defaults.info("Detected change to '%s' (type: %s). Triggering 'cdk deploy'", filePath, event);
            await deployAndWatch();
          } else {
            latch = "queued";
            await this.ioHost.asIoHelper().defaults.info(
              "Detected change to '%s' (type: %s) while 'cdk deploy' is still running. Will queue for another deployment after this one finishes",
              filePath,
              event
            );
          }
        });
      }
      async orphan(options) {
        await this.toolkit.orphan(this.props.cloudExecutable, {
          constructPaths: options.constructPath,
          roleArn: options.roleArn,
          toolkitStackName: options.toolkitStackName
        });
      }
      async import(options) {
        const stacks = await this.selectStacksForDeploy(options.selector, true, true, false);
        if (options.progress) {
          this.ioHost.stackProgress = options.progress;
        }
        if (stacks.stackCount > 1) {
          throw new import_toolkit_lib18.ToolkitError(
            "AmbiguousStackSelection",
            `Stack selection is ambiguous, please choose a specific stack for import [${stacks.stackArtifacts.map((x) => x.id).join(", ")}]`
          );
        }
        if (!process.stdout.isTTY && !options.resourceMappingFile && !options.resourceMappingInline) {
          throw new import_toolkit_lib18.ToolkitError("ResourceMappingRequired", "--resource-mapping or --resource-mapping-inline is required when input is not a terminal");
        }
        const stack = stacks.stackArtifacts[0];
        await this.ioHost.asIoHelper().defaults.info(chalk32.bold(stack.displayName));
        const resourceImporter = new ResourceImporter(stack, {
          deployments: this.props.deployments,
          ioHelper: asIoHelper(this.ioHost, "import")
        });
        const { additions, hasNonAdditions, diffFormatter } = await resourceImporter.discoverImportableResources(options.force);
        if (hasNonAdditions && !options.force) {
          const ioHelper = this.ioHost.asIoHelper();
          await ioHelper.defaults.info(
            `The following resources have pending updates that will be reconciled with a ${chalk32.blueBright("cdk deploy")} after import:`
          );
          const { formattedDiff } = diffFormatter.formatStackDiff();
          await ioHelper.defaults.info(formattedDiff);
          const confirmed = await ioHelper.requestResponse(IO.CDK_TOOLKIT_I7010.req("Perform import?", { motivation: "Confirm import with pending drift" }));
          if (!confirmed) {
            await ioHelper.defaults.info("Import cancelled.");
            return;
          }
        }
        if (additions.length === 0) {
          await this.ioHost.asIoHelper().defaults.warn(
            "%s: no new resources compared to the currently deployed stack, skipping import.",
            chalk32.bold(stack.displayName)
          );
          return;
        }
        let actualImport;
        if (options.resourceMappingInline) {
          actualImport = await resourceImporter.loadResourceIdentifiers(additions, options.resourceMappingInline);
        } else if (options.resourceMappingFile) {
          actualImport = await resourceImporter.loadResourceIdentifiersFromFile(additions, options.resourceMappingFile);
        } else {
          actualImport = await resourceImporter.askForResourceIdentifiers(additions);
        }
        if (actualImport.importResources.length === 0) {
          await this.ioHost.asIoHelper().defaults.warn("No resources selected for import.");
          return;
        }
        if (options.recordResourceMapping) {
          const outputFile = options.recordResourceMapping;
          fs47.ensureFileSync(outputFile);
          await fs47.writeJson(outputFile, actualImport.resourceMap, {
            spaces: 2,
            encoding: "utf8"
          });
          await this.ioHost.asIoHelper().defaults.info("%s: mapping file written.", outputFile);
          return;
        }
        await this.ioHost.asIoHelper().defaults.info("%s: importing resources into stack...", chalk32.bold(stack.displayName));
        const tags = tagsForStack(stack);
        await resourceImporter.importResourcesFromMap(actualImport, {
          roleArn: options.roleArn,
          tags,
          deploymentMethod: options.deploymentMethod,
          usePreviousParameters: true,
          rollback: options.rollback
        });
        if (actualImport.importResources.length < additions.length) {
          await this.ioHost.asIoHelper().defaults.warn(
            `Some resources were skipped. Run another ${chalk32.blueBright("cdk import")} or a ${chalk32.blueBright("cdk deploy")} to bring the stack up-to-date with your CDK app definition.`
          );
        } else if (hasNonAdditions) {
          if (options.force) {
            await this.ioHost.asIoHelper().defaults.info(
              `Import complete. Run ${chalk32.blueBright("cdk deploy")} to update the stack to match your CDK app.`
            );
          } else {
            const deployNow = await this.ioHost.asIoHelper().requestResponse(
              IO.CDK_TOOLKIT_I7010.req(`Finish with a ${chalk32.blueBright("cdk deploy")} now?`, { motivation: "Update stack to match CDK app after import" })
            );
            if (deployNow) {
              await this.deploy({
                selector: options.selector,
                toolkitStackName: options.toolkitStackName,
                roleArn: options.roleArn,
                deploymentMethod: options.deploymentMethod
              });
            } else {
              await this.ioHost.asIoHelper().defaults.info(
                `Import complete. Remember to run ${chalk32.blueBright("cdk deploy")} to update the stack to match your CDK app.`
              );
            }
          }
        } else {
          await this.ioHost.asIoHelper().defaults.info(
            `Import operation complete. We recommend you run a ${chalk32.blueBright("drift detection")} operation to confirm your CDK app resource definitions are up-to-date. Read more here: ` + chalk32.underline.blueBright(
              "https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/detect-drift-stack.html"
            )
          );
        }
      }
      async destroy(options) {
        const ioHelper = this.ioHost.asIoHelper();
        const stacks = await this.selectStacksForDestroy(options.selector, options.exclusively);
        if (!options.force) {
          const motivation = "Destroying stacks is an irreversible action";
          const question2 = `Are you sure you want to delete: ${chalk32.blue(stacks.stackArtifacts.map((s) => s.hierarchicalId).join(", "))}`;
          try {
            await ioHelper.requestResponse(IO.CDK_TOOLKIT_I7010.req(question2, { motivation }));
          } catch (err) {
            if (!import_toolkit_lib18.ToolkitError.isToolkitError(err) || err.message != "Aborted by user") {
              throw err;
            }
            await ioHelper.notify(IO.CDK_TOOLKIT_E7010.msg(err.message));
            return;
          }
        }
        const concurrency = options.concurrency || 1;
        const action = options.fromDeploy ? "deploy" : "destroy";
        let destroyCount = 0;
        if (concurrency > 1) {
          this.ioHost.stackProgress = "events" /* EVENTS */;
        }
        const destroyStack2 = /* @__PURE__ */ __name(async (stackNode) => {
          const stack = stackNode.stack;
          destroyCount++;
          await ioHelper.defaults.info(chalk32.green("%s: destroying... [%s/%s]"), chalk32.blue(stack.displayName), destroyCount, stacks.stackCount);
          try {
            await this.props.deployments.destroyStack({
              stack,
              deployName: stack.stackName,
              roleArn: options.roleArn
            });
            await ioHelper.defaults.info(chalk32.green(`
 \u2705  %s: ${action}ed`), chalk32.blue(stack.displayName));
          } catch (e32) {
            await ioHelper.defaults.error(`
 \u274C  %s: ${action} failed`, chalk32.blue(stack.displayName), e32);
            throw e32;
          }
        }, "destroyStack");
        const workGraph = buildDestroyWorkGraph(stacks.stackArtifacts, ioHelper);
        await workGraph.processStacks(concurrency, destroyStack2);
      }
      async list(selectors, options = {}) {
        this.ioHost.rewriteOnce(IO.CDK_TOOLKIT_I2901, (msg) => formatStackList(msg.data.stacks, options));
        if (options.json) {
          this.ioHost.once(IO.CDK_TOOLKIT_I1000, () => ({ preventDefault: true }));
        }
        await this.toolkit.list(this.props.cloudExecutable, {
          stacks: selectors.length > 0 ? { patterns: selectors, strategy: "pattern-match" /* PATTERN_MATCH */, expand: "upstream" /* UPSTREAM */ } : void 0
        });
        return 0;
      }
      /**
       * Synthesize the given set of stacks (called when the user runs 'cdk synth')
       *
       * INPUT: Stack names can be supplied using a glob filter. If no stacks are
       * given, all stacks from the application are implicitly selected.
       *
       * OUTPUT: If more than one stack ends up being selected, an output directory
       * should be supplied, where the templates will be written.
       */
      async synth(stackNames, exclusively, quiet, autoValidate, json) {
        const stacks = await this.selectStacksForDiff(stackNames, exclusively, autoValidate);
        if (stacks.stackCount === 1) {
          if (!quiet) {
            await printSerializedObject(this.ioHost.asIoHelper(), obscureTemplate(stacks.firstStack.template), json ?? false);
          }
          if (quiet || !this.ioHost.isCI) {
            await displayFlagsMessage(this.ioHost.asIoHelper(), this.toolkit, this.props.cloudExecutable);
          }
          return void 0;
        }
        await this.ioHost.asIoHelper().defaults.info(chalk32.green(`Successfully synthesized to ${chalk32.blue(path45.resolve(stacks.assembly.directory))}`));
        await this.ioHost.asIoHelper().defaults.info(
          `Supply a stack id (${stacks.stackArtifacts.map((s) => chalk32.green(s.hierarchicalId)).join(", ")}) to display its template.`
        );
        await displayFlagsMessage(this.ioHost.asIoHelper(), this.toolkit, this.props.cloudExecutable);
        return void 0;
      }
      /**
       * Bootstrap the CDK Toolkit stack in the accounts used by the specified stack(s).
       *
       * @param userEnvironmentSpecs - environment names that need to have toolkit support
       *             provisioned, as a glob filter. If none is provided, all stacks are implicitly selected.
       * @param options - The name, role ARN, bootstrapping parameters, etc. to be used for the CDK Toolkit stack.
       */
      async bootstrap(userEnvironmentSpecs, options) {
        const bootstrapper = new Bootstrapper(options.source, asIoHelper(this.ioHost, "bootstrap"));
        const environments = await this.defineEnvironments(userEnvironmentSpecs);
        const limit = pLimit5(20);
        await Promise.all(environments.map((environment) => limit(async () => {
          await this.ioHost.asIoHelper().defaults.info(chalk32.green(" \u23F3  Bootstrapping environment %s..."), chalk32.blue(environment.name));
          try {
            const result2 = await bootstrapper.bootstrapEnvironment(environment, this.props.sdkProvider, options);
            const message2 = result2.noOp ? " \u2705  Environment %s bootstrapped (no changes)." : " \u2705  Environment %s bootstrapped.";
            await this.ioHost.asIoHelper().defaults.info(chalk32.green(message2), chalk32.blue(environment.name));
          } catch (e32) {
            await this.ioHost.asIoHelper().defaults.error(" \u274C  Environment %s failed bootstrapping: %s", chalk32.blue(environment.name), e32);
            throw e32;
          }
        })));
      }
      /**
       * Garbage collects assets from a CDK app's environment
       * @param options - Options for Garbage Collection
       */
      async garbageCollect(userEnvironmentSpecs, options) {
        const environments = await this.defineEnvironments(userEnvironmentSpecs);
        for (const environment of environments) {
          await this.ioHost.asIoHelper().defaults.info(chalk32.green(" \u23F3  Garbage Collecting environment %s..."), chalk32.blue(environment.name));
          const gc = new GarbageCollector({
            sdkProvider: this.props.sdkProvider,
            ioHelper: asIoHelper(this.ioHost, "gc"),
            resolvedEnvironment: environment,
            bootstrapStackName: options.bootstrapStackName,
            rollbackBufferDays: options.rollbackBufferDays,
            createdBufferDays: options.createdBufferDays,
            action: options.action ?? "full",
            type: options.type ?? "all",
            confirm: options.confirm ?? true
          });
          await gc.garbageCollect();
        }
      }
      async defineEnvironments(userEnvironmentSpecs) {
        const environmentSpecs = userEnvironmentSpecs.length > 0 ? [...userEnvironmentSpecs] : ["**"];
        const globSpecs = partition(environmentSpecs, looksLikeGlob);
        if (globSpecs.length > 0 && !this.props.cloudExecutable.hasApp) {
          if (userEnvironmentSpecs.length > 0) {
            throw new import_toolkit_lib18.ToolkitError(
              "InvalidEnvironmentGlob",
              `'${globSpecs}' is not an environment name. Specify an environment name like 'aws://123456789012/us-east-1', or run in a directory with 'cdk.json' to use wildcards.`
            );
          } else {
            throw new import_toolkit_lib18.ToolkitError(
              "EnvironmentRequired",
              "Specify an environment name like 'aws://123456789012/us-east-1', or run in a directory with 'cdk.json'."
            );
          }
        }
        const environments = [...environmentsFromDescriptors2(environmentSpecs)];
        if (this.props.cloudExecutable.hasApp) {
          environments.push(
            ...await globEnvironmentsFromStacks(await this.selectStacksForList([]), globSpecs, this.props.sdkProvider)
          );
        }
        return environments;
      }
      /**
       * Migrates a CloudFormation stack/template to a CDK app
       * @param options - Options for CDK app creation
       */
      async migrate(options) {
        await this.ioHost.asIoHelper().defaults.warn("This command is an experimental feature.");
        const language = options.language?.toLowerCase() ?? "typescript";
        const environment = setEnvironment(options.account, options.region);
        let generateTemplateOutput;
        let cfn;
        let templateToDelete;
        try {
          const scanType = parseSourceOptions(options.fromPath, options.fromStack, options.stackName).source;
          if (scanType == "scan" /* SCAN */) {
            generateTemplateOutput = await generateTemplate({
              stackName: options.stackName,
              filters: options.filter,
              fromScan: options.fromScan,
              sdkProvider: this.props.sdkProvider,
              environment,
              ioHelper: this.ioHost.asIoHelper()
            });
            templateToDelete = generateTemplateOutput.templateId;
          } else if (scanType == "path" /* PATH */) {
            const templateBody = readFromPath(options.fromPath);
            const parsedTemplate = deserializeStructure(templateBody);
            const templateId = parsedTemplate.Metadata?.AWSToolsMetrics?.IaC_Generator?.toString();
            if (templateId) {
              cfn = new CfnTemplateGeneratorProvider(await buildCfnClient(this.props.sdkProvider, environment), this.ioHost.asIoHelper());
              const generatedTemplateSummary = await cfn.describeGeneratedTemplate(templateId);
              generateTemplateOutput = buildGeneratedTemplateOutput(
                generatedTemplateSummary,
                templateBody,
                generatedTemplateSummary.GeneratedTemplateId
              );
            } else {
              generateTemplateOutput = {
                migrateJson: {
                  templateBody,
                  source: "localfile"
                }
              };
            }
          } else if (scanType == "stack" /* STACK */) {
            const template = await readFromStack(options.stackName, this.props.sdkProvider, environment);
            if (!template) {
              throw new import_toolkit_lib18.ToolkitError("StackTemplateNotFound", `No template found for stack-name: ${options.stackName}`);
            }
            generateTemplateOutput = {
              migrateJson: {
                templateBody: template,
                source: options.stackName
              }
            };
          } else {
            throw new import_toolkit_lib18.ToolkitError("InvalidSourceOption", `Invalid source option provided: ${scanType}`);
          }
          const stack = generateStack(generateTemplateOutput.migrateJson.templateBody, options.stackName, language);
          await this.ioHost.asIoHelper().defaults.info(chalk32.green(" \u23F3  Generating CDK app for %s..."), chalk32.blue(options.stackName));
          await generateCdkApp(this.ioHost.asIoHelper(), options.stackName, stack, language, options.outputPath, options.compress);
          if (generateTemplateOutput) {
            writeMigrateJsonFile(options.outputPath, options.stackName, generateTemplateOutput.migrateJson);
          }
          if (isThereAWarning(generateTemplateOutput)) {
            await this.ioHost.asIoHelper().defaults.warn(
              " \u26A0\uFE0F  Some resources could not be migrated completely. Please review the README.md file for more information."
            );
            appendWarningsToReadme(
              `${path45.join(options.outputPath ?? process.cwd(), options.stackName)}/README.md`,
              generateTemplateOutput.resources
            );
          }
        } catch (e32) {
          await this.ioHost.asIoHelper().defaults.error(" \u274C  Migrate failed for `%s`: %s", options.stackName, e32.message);
          throw e32;
        } finally {
          if (templateToDelete) {
            if (!cfn) {
              cfn = new CfnTemplateGeneratorProvider(await buildCfnClient(this.props.sdkProvider, environment), this.ioHost.asIoHelper());
            }
            if (!process.env.MIGRATE_INTEG_TEST) {
              await cfn.deleteGeneratedTemplate(templateToDelete);
            }
          }
        }
      }
      async refactor(options) {
        if (options.revert && !options.overrideFile) {
          throw new import_toolkit_lib18.ToolkitError("RevertRequiresOverrideFile", "The --revert option can only be used with the --override-file option.");
        }
        try {
          const patterns = options.stacks?.patterns ?? [];
          await this.toolkit.refactor(this.props.cloudExecutable, {
            dryRun: options.dryRun,
            stacks: {
              patterns,
              strategy: patterns.length > 0 ? "pattern-match" /* PATTERN_MATCH */ : "all-stacks" /* ALL_STACKS */
            },
            force: options.force,
            additionalStackNames: options.additionalStackNames,
            overrides: readOverrides(options.overrideFile, options.revert),
            roleArn: options.roleArn
          });
        } catch (e32) {
          await this.ioHost.asIoHelper().defaults.error(e32.message);
          throw e32;
        }
        return 0;
        function readOverrides(filePath, revert = false) {
          if (filePath == null) {
            return [];
          }
          if (!fs47.pathExistsSync(filePath)) {
            throw new import_toolkit_lib18.ToolkitError("MappingFileNotFound", `The mapping file ${filePath} does not exist`);
          }
          const groups = parseMappingGroups(fs47.readFileSync(filePath).toString("utf-8"));
          return revert ? groups.map((group7) => ({
            ...group7,
            resources: Object.fromEntries(Object.entries(group7.resources ?? {}).map(([src, dst]) => [dst, src]))
          })) : groups;
        }
        __name(readOverrides, "readOverrides");
      }
      async selectStacksForList(patterns) {
        const assembly = await this.assembly();
        const stacks = await assembly.selectStacks({ patterns }, { defaultBehavior: "all" /* AllStacks */ });
        return stacks;
      }
      async selectStacksForDeploy(selector, exclusively, cacheCloudAssembly, ignoreNoStacks) {
        const assembly = await this.assembly(cacheCloudAssembly);
        const stacks = await assembly.selectStacks(selector, {
          extend: exclusively ? 0 /* None */ : 1 /* Upstream */,
          defaultBehavior: "single" /* OnlySingle */,
          ignoreNoStacks
        });
        this.validateStacksSelected(stacks, selector.patterns);
        await this.validateStacks(assembly, stacks);
        return stacks;
      }
      async selectStacksForDiff(stackNames, exclusively, autoValidate) {
        const assembly = await this.assembly();
        const selectedForDiff = await assembly.selectStacks(
          { patterns: stackNames },
          {
            extend: exclusively ? 0 /* None */ : 1 /* Upstream */,
            defaultBehavior: "main" /* MainAssembly */
          }
        );
        const allStacks = await this.selectStacksForList([]);
        const autoValidateStacks = autoValidate ? allStacks.filter((art) => art.validateOnSynth ?? false) : new StackCollection(assembly, []);
        this.validateStacksSelected(selectedForDiff.concat(autoValidateStacks), stackNames);
        await this.validateStacks(assembly, selectedForDiff.concat(autoValidateStacks));
        return selectedForDiff;
      }
      async selectStacksForDestroy(selector, exclusively) {
        const assembly = await this.assembly();
        const stacks = await assembly.selectStacks(selector, {
          extend: exclusively ? 0 /* None */ : 2 /* Downstream */,
          defaultBehavior: "single" /* OnlySingle */
        });
        return stacks;
      }
      /**
       * Validate the stacks for errors and warnings according to the CLI's current settings
       */
      async validateStacks(assembly, stacks) {
        const failAt = this.validateMetadataFailAt();
        await throwIfValidationFailures(assembly, stacks, failAt, this.ioHost.asIoHelper());
      }
      validateMetadataFailAt() {
        let failAt = "error";
        if (this.props.ignoreErrors) {
          failAt = "none";
        }
        if (this.props.strict) {
          failAt = "warn";
        }
        return failAt;
      }
      /**
       * Validate that if a user specified a stack name there exists at least 1 stack selected
       */
      validateStacksSelected(stacks, stackNames) {
        if (stackNames.length != 0 && stacks.stackCount == 0) {
          throw new import_toolkit_lib18.ToolkitError("NoStacksMatched", `No stacks match the name(s) ${stackNames}`);
        }
      }
      /**
       * Select a single stack by its name
       */
      async selectSingleStackByName(stackName) {
        const assembly = await this.assembly();
        const stacks = await assembly.selectStacks(
          { patterns: [stackName] },
          {
            extend: 0 /* None */,
            defaultBehavior: "none" /* None */
          }
        );
        if (stacks.stackCount > 1) {
          throw new import_toolkit_lib18.ToolkitError("MultipleStacksMatched", `This command requires exactly one stack and we matched more than one: ${stacks.stackIds}`);
        }
        return assembly.stackById(stacks.firstStack.id);
      }
      assembly(cacheCloudAssembly) {
        return this.props.cloudExecutable.synthesize(cacheCloudAssembly);
      }
      patternsArrayForWatch(patterns, options) {
        const patternsArray = patterns !== void 0 ? Array.isArray(patterns) ? patterns : [patterns] : [];
        return patternsArray.length > 0 ? patternsArray : options.returnDefaultIfEmpty ? [options.defaultPattern] : [];
      }
      async invokeDeployFromWatch(options, cloudWatchLogMonitor) {
        const deployOptions = {
          ...options,
          requireApproval: import_cloud_assembly_schema8.RequireApproval.NEVER,
          // if 'watch' is called by invoking 'cdk deploy --watch',
          // we need to make sure to not call 'deploy' with 'watch' again,
          // as that would lead to a cycle
          watch: false,
          cloudWatchLogMonitor,
          cacheCloudAssembly: false,
          extraUserAgent: `cdk-watch/hotswap-${options.deploymentMethod?.method === "hotswap" ? "on" : "off"}`,
          concurrency: options.concurrency
        };
        try {
          await this.deploy(deployOptions);
        } catch {
        }
      }
      /**
       * Remove the asset publishing and building from the work graph for assets that are already in place
       */
      async removePublishedAssets(graph, options) {
        await graph.removeUnnecessaryAssets((assetNode) => this.props.deployments.isSingleAssetPublished(assetNode.assetManifest, assetNode.asset, {
          stack: assetNode.parentStack,
          roleArn: options.roleArn,
          stackName: assetNode.parentStack.stackName
        }));
      }
    };
    __name(printSerializedObject, "printSerializedObject");
    __name(buildParameterMap2, "buildParameterMap");
    __name(askUserConfirmation, "askUserConfirmation");
    __name(displayFlagsMessage, "displayFlagsMessage");
    WorkGraphDeploymentActions = class {
      constructor(deployments, ioHost, stackOperations, options) {
        this.deployments = deployments;
        this.ioHost = ioHost;
        this.stackOperations = stackOperations;
        this.options = options;
        this.stackOutputs = {};
        this.assetSpans = {};
        this.stackCounter = 1;
      }
      static {
        __name(this, "WorkGraphDeploymentActions");
      }
      async marker(markerNode) {
        switch (markerNode.marker.type) {
          case "start-asset": {
            const assetSpan = await this.obtainSpan(markerNode.marker.asset);
            if (markerNode.marker.asset.type === "file") {
              this.ioHost.telemetry?.commandSpan?.incCounter("fileAsset");
              assetSpan.incCounter("fileAsset");
            } else if (markerNode.marker.asset.type === "docker") {
              this.ioHost.telemetry?.commandSpan?.incCounter("dockerAsset");
              assetSpan.incCounter("dockerAsset");
            }
            break;
          }
          case "end-asset": {
            const assetSpan = await this.obtainSpan(markerNode.marker.asset);
            await assetSpan.end({});
            break;
          }
        }
      }
      async obtainSpan(assetEntry) {
        const span = this.assetSpans[assetEntry.id.assetId];
        if (span) {
          return span;
        }
        const assetSpan = await this.ioHost.asIoHelper().span(CLI_PRIVATE_SPAN.ASSET).begin({});
        this.assetSpans[assetEntry.id.assetId] = assetSpan;
        return assetSpan;
      }
      async buildAsset(assetNode) {
        var _stack = [];
        try {
          const _invokeTimer = __using(_stack, this.ioHost.telemetry?.commandSpan?.startTimer("buildAssetST"));
          const _assetTimer = __using(_stack, (await this.obtainSpan(assetNode.asset)).startTimer("buildAsset"));
          await this.deployments.buildSingleAsset(
            assetNode.assetManifestArtifact,
            assetNode.assetManifest,
            assetNode.asset,
            {
              stack: assetNode.parentStack,
              roleArn: this.options.roleArn,
              stackName: assetNode.parentStack.stackName
            }
          );
        } catch (_) {
          var _error = _, _hasError = true;
        } finally {
          __callDispose(_stack, _error, _hasError);
        }
      }
      async publishAsset(assetNode) {
        var _stack = [];
        try {
          const _invokeTimer = __using(_stack, this.ioHost.telemetry?.commandSpan?.startTimer("publishAssetST"));
          const _assetTimer = __using(_stack, (await this.obtainSpan(assetNode.asset)).startTimer("publishAsset"));
          await this.deployments.publishSingleAsset(assetNode.assetManifest, assetNode.asset, {
            stack: assetNode.parentStack,
            roleArn: this.options.roleArn,
            stackName: assetNode.parentStack.stackName,
            forcePublish: this.options.force
          });
        } catch (_) {
          var _error = _, _hasError = true;
        } finally {
          __callDispose(_stack, _error, _hasError);
        }
      }
      async deployStack(stackNode) {
        this.ioHost.telemetry?.commandSpan?.incCounter("totalDeployedStacks");
        const stack = stackNode.stack;
        if (this.options.stackCount !== 1) {
          await this.ioHost.asIoHelper().defaults.info(chalk32.bold(stack.displayName));
        }
        if (!stack.environment) {
          throw new import_toolkit_lib18.ToolkitError(
            "MissingEnvironment",
            `Stack ${stack.displayName} does not define an environment, and AWS credentials could not be obtained from standard locations or no region was configured.`
          );
        }
        const resourceCount = Object.keys(stack.template.Resources || {}).length;
        if (resourceCount === 0) {
          if (!await this.deployments.stackExists({ stack })) {
            await this.ioHost.asIoHelper().defaults.warn("%s: stack has no resources, skipping deployment.", chalk32.bold(stack.displayName));
          } else {
            await this.ioHost.asIoHelper().defaults.warn("%s: stack has no resources, deleting existing stack.", chalk32.bold(stack.displayName));
            await this.stackOperations.destroy({
              selector: { patterns: [stack.hierarchicalId] },
              exclusively: true,
              force: true,
              roleArn: this.options.roleArn,
              fromDeploy: true
            });
          }
          return;
        }
        const notificationArns = !!this.options.notificationArns || !!stack.notificationArns ? (this.options.notificationArns ?? []).concat(stack.notificationArns ?? []) : void 0;
        for (const notificationArn of notificationArns ?? []) {
          if (!validateSnsTopicArn(notificationArn)) {
            throw new import_toolkit_lib18.ToolkitError("InvalidSnsTopicArn", `Notification arn ${notificationArn} is not a valid arn for an SNS topic`);
          }
        }
        const parameterMap = buildParameterMap2(this.options.parameters);
        const sharedDeployOptions = {
          stack,
          deployName: stack.stackName,
          roleArn: this.options.roleArn,
          toolkitStackName: this.options.toolkitStackName,
          reuseAssets: this.options.reuseAssets,
          tags: this.options.tags?.length ? this.options.tags : tagsForStack(stack),
          forceDeployment: this.options.force,
          parameters: Object.assign({}, parameterMap["*"], parameterMap[stack.stackName]),
          usePreviousParameters: this.options.usePreviousParameters,
          rollback: this.options.rollback,
          notificationArns,
          extraUserAgent: this.options.extraUserAgent,
          assetParallelism: this.options.assetParallelism
        };
        const prepareResult = isChangeSetDeployment(this.options.deploymentMethod) ? await this.deployments.prepareStack({
          ...sharedDeployOptions,
          deploymentMethod: this.options.deploymentMethod,
          cleanupOnNoOp: isExecutingChangeSetDeployment(this.options.deploymentMethod)
        }) : void 0;
        if (this.options.requireApproval !== import_cloud_assembly_schema8.RequireApproval.NEVER && !prepareResult?.noOp) {
          const currentTemplate = await this.deployments.readCurrentTemplate(stack);
          const formatter = new DiffFormatter({
            templateInfo: {
              oldTemplate: currentTemplate,
              newTemplate: stack,
              changeSet: prepareResult?.changeSet
            }
          });
          const securityDiff = formatter.formatSecurityDiff();
          if (requiresApproval(this.options.requireApproval, securityDiff.permissionChangeType)) {
            const hasSecurityChanges = securityDiff.permissionChangeType !== import_toolkit_lib18.PermissionChangeType.NONE;
            const motivation = hasSecurityChanges ? '"--require-approval" is enabled and stack includes security-sensitive updates' : `"--require-approval" is set to '${import_cloud_assembly_schema8.RequireApproval.ANYCHANGE}'`;
            const diffOutput2 = hasSecurityChanges ? securityDiff.formattedDiff : formatter.formatStackDiff().formattedDiff;
            await this.ioHost.asIoHelper().defaults.info(diffOutput2);
            try {
              await askUserConfirmation(
                this.ioHost,
                IO.CDK_TOOLKIT_I5060.req(`${motivation}: Do you wish to deploy these changes?`, {
                  motivation,
                  concurrency: this.options.concurrency,
                  permissionChangeType: securityDiff.permissionChangeType,
                  templateDiffs: formatter.diffs
                })
              );
            } catch (e32) {
              if (prepareResult?.changeSet?.ChangeSetName) {
                await this.deployments.cleanupChangeSet(stack, prepareResult.changeSet.ChangeSetName);
              }
              throw e32;
            }
          }
        }
        const stackIndex = this.stackCounter++;
        await this.ioHost.asIoHelper().defaults.info(`${chalk32.bold(stack.displayName)}: deploying... [${stackIndex}/${this.options.stackCount}]`);
        const startDeployTime = (/* @__PURE__ */ new Date()).getTime();
        const deploySpan = await this.ioHost.asIoHelper().span(CLI_PRIVATE_SPAN.DEPLOY).begin({});
        deploySpan.incCounter("resources", resourceCount);
        this.ioHost.telemetry?.commandSpan?.incCounter("totalDeployedResources", resourceCount);
        let error4;
        let elapsedDeployTime = 0;
        try {
          const prepareIsFinal = prepareResult && (prepareResult.noOp || isNonExecutingChangeSetDeployment(this.options.deploymentMethod));
          let deployResult = prepareIsFinal ? prepareResult : void 0;
          let rollback = this.options.rollback;
          let iteration = 0;
          while (!deployResult) {
            if (++iteration > 2) {
              throw new import_toolkit_lib18.ToolkitError("DeployLoopUnstable", "This loop should have stabilized in 2 iterations, but didn't. If you are seeing this error, please report it at https://github.com/aws/aws-cdk/issues/new/choose");
            }
            const r32 = await this.deployments.deployStack({
              ...sharedDeployOptions,
              // On the first iteration, execute the prepared change set.
              // On retries (after rollback), create a new change set since the old one is gone.
              deploymentMethod: iteration === 1 && isExecutingChangeSetDeployment(this.options.deploymentMethod) ? toExecuteChangeSetDeployment(this.options.deploymentMethod) : this.options.deploymentMethod,
              rollback
            });
            switch (r32.type) {
              case "did-deploy-stack":
                deployResult = r32;
                break;
              case "failpaused-need-rollback-first": {
                const motivation = r32.reason === "replacement" ? `Stack is in a paused fail state (${r32.status}) and change includes a replacement which cannot be deployed with "--no-rollback"` : `Stack is in a paused fail state (${r32.status}) and command line arguments do not include "--no-rollback"`;
                if (this.options.force) {
                  await this.ioHost.asIoHelper().defaults.warn(`${motivation}. Rolling back first (--force).`);
                } else {
                  await askUserConfirmation(
                    this.ioHost,
                    IO.CDK_TOOLKIT_I5050.req(`${motivation}. Roll back first and then proceed with deployment`, {
                      motivation,
                      concurrency: this.options.concurrency
                    })
                  );
                }
                await this.stackOperations.rollback({
                  selector: { patterns: [stack.hierarchicalId] },
                  toolkitStackName: this.options.toolkitStackName,
                  force: this.options.force
                });
                rollback = true;
                break;
              }
              case "replacement-requires-rollback": {
                const motivation = 'Change includes a replacement which cannot be deployed with "--no-rollback"';
                if (this.options.force) {
                  await this.ioHost.asIoHelper().defaults.warn(`${motivation}. Proceeding with regular deployment (--force).`);
                } else {
                  await askUserConfirmation(
                    this.ioHost,
                    IO.CDK_TOOLKIT_I5050.req(`${motivation}. Perform a regular deployment`, {
                      concurrency: this.options.concurrency,
                      motivation
                    })
                  );
                }
                rollback = true;
                break;
              }
              default:
                throw new import_toolkit_lib18.ToolkitError("UnexpectedDeployResult", `Unexpected result type from deployStack: ${JSON.stringify(r32)}. If you are seeing this error, please report it at https://github.com/aws/aws-cdk/issues/new/choose`);
            }
          }
          const message2 = deployResult.noOp ? " \u2705  %s (no changes)" : " \u2705  %s";
          await this.ioHost.asIoHelper().defaults.info(chalk32.green("\n" + message2), stack.displayName);
          elapsedDeployTime = (/* @__PURE__ */ new Date()).getTime() - startDeployTime;
          await this.ioHost.asIoHelper().defaults.info(`
\u2728  Deployment time: ${formatTime(elapsedDeployTime)}s
`);
          if (Object.keys(deployResult.outputs).length > 0) {
            await this.ioHost.asIoHelper().defaults.info("Outputs:");
            this.stackOutputs[stack.stackName] = deployResult.outputs;
          }
          for (const name of Object.keys(deployResult.outputs).sort()) {
            const value = deployResult.outputs[name];
            await this.ioHost.asIoHelper().defaults.info(`${chalk32.cyan(stack.id)}.${chalk32.cyan(name)} = ${chalk32.underline(chalk32.cyan(value))}`);
          }
          await this.ioHost.asIoHelper().defaults.info("Stack ARN:");
          await this.ioHost.asIoHelper().defaults.result(deployResult.stackArn);
        } catch (e32) {
          const code = import_toolkit_lib18.ToolkitError.isToolkitError(e32) ? e32.name : "DeployStackFailed";
          const newMessage = [`\u274C  ${chalk32.bold(stack.stackName)} failed:`, ...e32.name ? [`${e32.name}:`] : [], e32.message].join(" ");
          const wrappedError = new import_toolkit_lib18.ToolkitError(code, newMessage);
          error4 = {
            name: cdkCliErrorName(wrappedError)
          };
          throw wrappedError;
        } finally {
          await deploySpan.end({ error: error4 });
          if (this.options.cloudWatchLogMonitor) {
            const foundLogGroupsResult = await findCloudWatchLogGroups(this.options.sdkProvider, asIoHelper(this.ioHost, "deploy"), stack);
            this.options.cloudWatchLogMonitor.addLogGroups(
              foundLogGroupsResult.env,
              foundLogGroupsResult.sdk,
              foundLogGroupsResult.logGroupNames
            );
          }
        }
      }
      async writeOutputs(outputsFile) {
        fs47.ensureFileSync(outputsFile);
        await fs47.writeJson(outputsFile, this.stackOutputs, {
          spaces: 2,
          encoding: "utf8"
        });
      }
    };
    __name(requiresApproval, "requiresApproval");
  }
});

// lib/cli/util/console-formatters.ts
function formatAsBanner(msgs) {
  const printLen = /* @__PURE__ */ __name((str) => stripAnsi(str).length, "printLen");
  if (msgs.length === 0) {
    return [];
  }
  const leftPad = "*** ";
  const rightPad = " ***";
  const bannerWidth = printLen(leftPad) + printLen(rightPad) + msgs.reduce((acc, msg) => Math.max(acc, printLen(msg)), 0);
  const bannerLines = [];
  bannerLines.push("*".repeat(bannerWidth));
  msgs.forEach((msg) => {
    const padding = " ".repeat(bannerWidth - (printLen(msg) + printLen(leftPad) + printLen(rightPad)));
    bannerLines.push("".concat(leftPad, msg, padding, rightPad));
  });
  bannerLines.push("*".repeat(bannerWidth));
  return bannerLines;
}
var stripAnsi;
var init_console_formatters = __esm({
  "lib/cli/util/console-formatters.ts"() {
    "use strict";
    stripAnsi = require_strip_ansi();
    __name(formatAsBanner, "formatAsBanner");
  }
});

// lib/cli/util/npm.ts
async function execNpmView(currentVersion) {
  try {
    const [latestResult, currentResult] = await Promise.all([
      exec2("npm view aws-cdk@latest version", { timeout: 3e3 }),
      exec2(`npm view aws-cdk@${currentVersion} name version deprecated --json`, { timeout: 3e3 })
    ]);
    if (latestResult.stderr && latestResult.stderr.trim().length > 0) {
      throw new import_toolkit_lib19.ToolkitError("NpmViewLatestFailed", `npm view command for latest version failed: ${latestResult.stderr.trim()}`);
    }
    if (currentResult.stderr && currentResult.stderr.trim().length > 0) {
      throw new import_toolkit_lib19.ToolkitError("NpmViewCurrentFailed", `npm view command for current version failed: ${currentResult.stderr.trim()}`);
    }
    const latestVersion = latestResult.stdout.trim();
    const currentInfo = JSON.parse(currentResult.stdout);
    return {
      latestVersion,
      deprecated: currentInfo.deprecated
    };
  } catch (err) {
    throw err;
  }
}
var import_child_process2, import_util76, import_toolkit_lib19, exec2;
var init_npm = __esm({
  "lib/cli/util/npm.ts"() {
    "use strict";
    import_child_process2 = require("child_process");
    import_util76 = require("util");
    import_toolkit_lib19 = __toESM(require_lib12());
    exec2 = (0, import_util76.promisify)(import_child_process2.exec);
    __name(execNpmView, "execNpmView");
  }
});

// lib/cli/display-version.ts
async function getVersionMessages(currentVersion, cacheFile) {
  if (!await cacheFile.hasExpired()) {
    return [];
  }
  const packageInfo = await execNpmView(currentVersion);
  const latestVersion = packageInfo.latestVersion;
  await cacheFile.update(JSON.stringify(packageInfo));
  if (semver5.eq(latestVersion, currentVersion)) {
    return [];
  }
  const versionMessage = [
    packageInfo.deprecated ? `${chalk33.red(packageInfo.deprecated)}` : void 0,
    `Newer version of CDK is available [${chalk33.green(latestVersion)}]`,
    getMajorVersionUpgradeMessage(currentVersion),
    "Upgrade recommended (npm install -g aws-cdk)"
  ].filter(Boolean);
  return versionMessage;
}
function getMajorVersionUpgradeMessage(currentVersion) {
  const currentMajorVersion = semver5.major(currentVersion);
  if (UPGRADE_DOCUMENTATION_LINKS[currentMajorVersion]) {
    return `Information about upgrading from version ${currentMajorVersion}.x to version ${currentMajorVersion + 1}.x is available here: ${UPGRADE_DOCUMENTATION_LINKS[currentMajorVersion]}`;
  }
}
function shouldDisplayVersionMessage() {
  return !!process.stdout.isTTY && !process.env.CDK_DISABLE_VERSION_CHECK;
}
async function displayVersionMessage(ioHelper, currentVersion = versionNumber(), versionCheckCache) {
  try {
    const versionMessages = await getVersionMessages(currentVersion, versionCheckCache ?? new VersionCheckTTL());
    for (const e32 of formatAsBanner(versionMessages)) {
      await ioHelper.defaults.info(e32);
    }
  } catch (err) {
    await ioHelper.defaults.debug(`Could not run version check - ${err.message}`);
  }
}
var path46, import_toolkit_lib20, chalk33, fs48, semver5, ONE_DAY_IN_SECONDS, UPGRADE_DOCUMENTATION_LINKS, VersionCheckTTL;
var init_display_version = __esm({
  "lib/cli/display-version.ts"() {
    "use strict";
    path46 = __toESM(require("path"));
    import_toolkit_lib20 = __toESM(require_lib12());
    chalk33 = __toESM(require_source());
    fs48 = __toESM(require_lib4());
    semver5 = __toESM(require_semver4());
    init_util9();
    init_console_formatters();
    init_npm();
    ONE_DAY_IN_SECONDS = 1 * 24 * 60 * 60;
    UPGRADE_DOCUMENTATION_LINKS = {
      1: "https://docs.aws.amazon.com/cdk/v2/guide/migrating-v2.html"
    };
    VersionCheckTTL = class _VersionCheckTTL {
      static {
        __name(this, "VersionCheckTTL");
      }
      static timestampFilePath() {
        return path46.join(cdkCacheDir(), "repo-version-ttl");
      }
      constructor(file, ttlSecs) {
        this.file = file || _VersionCheckTTL.timestampFilePath();
        try {
          fs48.mkdirsSync(path46.dirname(this.file));
          fs48.accessSync(path46.dirname(this.file), fs48.constants.W_OK);
        } catch {
          throw new import_toolkit_lib20.ToolkitError("DirectoryNotWritable", `Directory (${path46.dirname(this.file)}) is not writable.`);
        }
        this.ttlSecs = ttlSecs || ONE_DAY_IN_SECONDS;
      }
      async hasExpired() {
        try {
          const lastCheckTime = (await fs48.stat(this.file)).mtimeMs;
          const today = (/* @__PURE__ */ new Date()).getTime();
          if ((today - lastCheckTime) / 1e3 > this.ttlSecs) {
            return true;
          }
          return false;
        } catch (err) {
          if (err.code === "ENOENT") {
            return true;
          } else {
            throw err;
          }
        }
      }
      async update(latestVersion) {
        if (!latestVersion) {
          latestVersion = "";
        }
        await fs48.writeFile(this.file, latestVersion);
      }
    };
    __name(getVersionMessages, "getVersionMessages");
    __name(getMajorVersionUpgradeMessage, "getMajorVersionUpgradeMessage");
    __name(shouldDisplayVersionMessage, "shouldDisplayVersionMessage");
    __name(displayVersionMessage, "displayVersionMessage");
  }
});

// lib/cli/util/yargs-helpers.ts
function yargsNegativeAlias(negativeAlias, optionToNegate) {
  return (argv) => {
    if (negativeAlias in argv && argv[negativeAlias]) {
      argv[optionToNegate] = false;
    }
    return argv;
  };
}
function yargsImplies(flag, impliedOptions) {
  return (argv) => {
    if (argv[flag]) {
      for (const implied of impliedOptions) {
        argv[implied] = true;
      }
    }
    return argv;
  };
}
function cliVersion() {
  return versionWithBuild();
}
function browserForPlatform() {
  switch (process.platform) {
    case "darwin":
      return "open %u";
    case "win32":
      return "start %u";
    default:
      return "xdg-open %u";
  }
}
var init_yargs_helpers = __esm({
  "lib/cli/util/yargs-helpers.ts"() {
    "use strict";
    init_version();
    init_ci();
    __name(yargsNegativeAlias, "yargsNegativeAlias");
    __name(yargsImplies, "yargsImplies");
    __name(cliVersion, "cliVersion");
    __name(browserForPlatform, "browserForPlatform");
  }
});

// node_modules/yargs/build/lib/common-types.js
var require_common_types = __commonJS({
  "node_modules/yargs/build/lib/common-types.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.objectKeys = exports2.assertSingleKey = exports2.assertNotStrictEqual = void 0;
    var assert_1 = require("assert");
    function assertNotStrictEqual(actual, expected, message2) {
      assert_1.notStrictEqual(actual, expected, message2);
    }
    __name(assertNotStrictEqual, "assertNotStrictEqual");
    exports2.assertNotStrictEqual = assertNotStrictEqual;
    function assertSingleKey(actual) {
      assert_1.strictEqual(typeof actual, "string");
    }
    __name(assertSingleKey, "assertSingleKey");
    exports2.assertSingleKey = assertSingleKey;
    function objectKeys(object) {
      return Object.keys(object);
    }
    __name(objectKeys, "objectKeys");
    exports2.objectKeys = objectKeys;
  }
});

// node_modules/yargs/build/lib/is-promise.js
var require_is_promise = __commonJS({
  "node_modules/yargs/build/lib/is-promise.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isPromise = void 0;
    function isPromise(maybePromise) {
      return !!maybePromise && !!maybePromise.then && typeof maybePromise.then === "function";
    }
    __name(isPromise, "isPromise");
    exports2.isPromise = isPromise;
  }
});

// node_modules/yargs/build/lib/yerror.js
var require_yerror = __commonJS({
  "node_modules/yargs/build/lib/yerror.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.YError = void 0;
    var YError = class _YError extends Error {
      static {
        __name(this, "YError");
      }
      constructor(msg) {
        super(msg || "yargs error");
        this.name = "YError";
        Error.captureStackTrace(this, _YError);
      }
    };
    exports2.YError = YError;
  }
});

// node_modules/yargs/build/lib/parse-command.js
var require_parse_command = __commonJS({
  "node_modules/yargs/build/lib/parse-command.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.parseCommand = void 0;
    function parseCommand(cmd) {
      const extraSpacesStrippedCommand = cmd.replace(/\s{2,}/g, " ");
      const splitCommand = extraSpacesStrippedCommand.split(/\s+(?![^[]*]|[^<]*>)/);
      const bregex = /\.*[\][<>]/g;
      const firstCommand = splitCommand.shift();
      if (!firstCommand)
        throw new Error(`No command found in: ${cmd}`);
      const parsedCommand = {
        cmd: firstCommand.replace(bregex, ""),
        demanded: [],
        optional: []
      };
      splitCommand.forEach((cmd2, i32) => {
        let variadic = false;
        cmd2 = cmd2.replace(/\s/g, "");
        if (/\.+[\]>]/.test(cmd2) && i32 === splitCommand.length - 1)
          variadic = true;
        if (/^\[/.test(cmd2)) {
          parsedCommand.optional.push({
            cmd: cmd2.replace(bregex, "").split("|"),
            variadic
          });
        } else {
          parsedCommand.demanded.push({
            cmd: cmd2.replace(bregex, "").split("|"),
            variadic
          });
        }
      });
      return parsedCommand;
    }
    __name(parseCommand, "parseCommand");
    exports2.parseCommand = parseCommand;
  }
});

// node_modules/yargs/build/lib/argsert.js
var require_argsert = __commonJS({
  "node_modules/yargs/build/lib/argsert.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.argsert = void 0;
    var yerror_1 = require_yerror();
    var parse_command_1 = require_parse_command();
    var positionName = ["first", "second", "third", "fourth", "fifth", "sixth"];
    function argsert(arg1, arg2, arg3) {
      function parseArgs2() {
        return typeof arg1 === "object" ? [{ demanded: [], optional: [] }, arg1, arg2] : [parse_command_1.parseCommand(`cmd ${arg1}`), arg2, arg3];
      }
      __name(parseArgs2, "parseArgs");
      try {
        let position = 0;
        let [parsed, callerArguments, length] = parseArgs2();
        const args = [].slice.call(callerArguments);
        while (args.length && args[args.length - 1] === void 0)
          args.pop();
        length = length || args.length;
        if (length < parsed.demanded.length) {
          throw new yerror_1.YError(`Not enough arguments provided. Expected ${parsed.demanded.length} but received ${args.length}.`);
        }
        const totalCommands = parsed.demanded.length + parsed.optional.length;
        if (length > totalCommands) {
          throw new yerror_1.YError(`Too many arguments provided. Expected max ${totalCommands} but received ${length}.`);
        }
        parsed.demanded.forEach((demanded) => {
          const arg = args.shift();
          const observedType = guessType(arg);
          const matchingTypes = demanded.cmd.filter((type) => type === observedType || type === "*");
          if (matchingTypes.length === 0)
            argumentTypeError(observedType, demanded.cmd, position);
          position += 1;
        });
        parsed.optional.forEach((optional) => {
          if (args.length === 0)
            return;
          const arg = args.shift();
          const observedType = guessType(arg);
          const matchingTypes = optional.cmd.filter((type) => type === observedType || type === "*");
          if (matchingTypes.length === 0)
            argumentTypeError(observedType, optional.cmd, position);
          position += 1;
        });
      } catch (err) {
        console.warn(err.stack);
      }
    }
    __name(argsert, "argsert");
    exports2.argsert = argsert;
    function guessType(arg) {
      if (Array.isArray(arg)) {
        return "array";
      } else if (arg === null) {
        return "null";
      }
      return typeof arg;
    }
    __name(guessType, "guessType");
    function argumentTypeError(observedType, allowedTypes, position) {
      throw new yerror_1.YError(`Invalid ${positionName[position] || "manyith"} argument. Expected ${allowedTypes.join(" or ")} but received ${observedType}.`);
    }
    __name(argumentTypeError, "argumentTypeError");
  }
});

// node_modules/yargs/build/lib/middleware.js
var require_middleware = __commonJS({
  "node_modules/yargs/build/lib/middleware.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.applyMiddleware = exports2.commandMiddlewareFactory = exports2.globalMiddlewareFactory = void 0;
    var argsert_1 = require_argsert();
    var is_promise_1 = require_is_promise();
    function globalMiddlewareFactory(globalMiddleware, context) {
      return function(callback, applyBeforeValidation = false) {
        argsert_1.argsert("<array|function> [boolean]", [callback, applyBeforeValidation], arguments.length);
        if (Array.isArray(callback)) {
          for (let i32 = 0; i32 < callback.length; i32++) {
            if (typeof callback[i32] !== "function") {
              throw Error("middleware must be a function");
            }
            callback[i32].applyBeforeValidation = applyBeforeValidation;
          }
          Array.prototype.push.apply(globalMiddleware, callback);
        } else if (typeof callback === "function") {
          callback.applyBeforeValidation = applyBeforeValidation;
          globalMiddleware.push(callback);
        }
        return context;
      };
    }
    __name(globalMiddlewareFactory, "globalMiddlewareFactory");
    exports2.globalMiddlewareFactory = globalMiddlewareFactory;
    function commandMiddlewareFactory(commandMiddleware) {
      if (!commandMiddleware)
        return [];
      return commandMiddleware.map((middleware) => {
        middleware.applyBeforeValidation = false;
        return middleware;
      });
    }
    __name(commandMiddlewareFactory, "commandMiddlewareFactory");
    exports2.commandMiddlewareFactory = commandMiddlewareFactory;
    function applyMiddleware(argv, yargs2, middlewares, beforeValidation) {
      const beforeValidationError = new Error("middleware cannot return a promise when applyBeforeValidation is true");
      return middlewares.reduce((acc, middleware) => {
        if (middleware.applyBeforeValidation !== beforeValidation) {
          return acc;
        }
        if (is_promise_1.isPromise(acc)) {
          return acc.then((initialObj) => Promise.all([initialObj, middleware(initialObj, yargs2)])).then(([initialObj, middlewareObj]) => Object.assign(initialObj, middlewareObj));
        } else {
          const result2 = middleware(acc, yargs2);
          if (beforeValidation && is_promise_1.isPromise(result2))
            throw beforeValidationError;
          return is_promise_1.isPromise(result2) ? result2.then((middlewareObj) => Object.assign(acc, middlewareObj)) : Object.assign(acc, result2);
        }
      }, argv);
    }
    __name(applyMiddleware, "applyMiddleware");
    exports2.applyMiddleware = applyMiddleware;
  }
});

// ../../node_modules/require-directory/index.js
var require_require_directory = __commonJS({
  "../../node_modules/require-directory/index.js"(exports2, module2) {
    "use strict";
    var fs51 = require("fs");
    var join59 = require("path").join;
    var resolve13 = require("path").resolve;
    var dirname14 = require("path").dirname;
    var defaultOptions2 = {
      extensions: ["js", "json", "coffee"],
      recurse: true,
      rename: /* @__PURE__ */ __name(function(name) {
        return name;
      }, "rename"),
      visit: /* @__PURE__ */ __name(function(obj) {
        return obj;
      }, "visit")
    };
    function checkFileInclusion(path47, filename, options) {
      return (
        // verify file has valid extension
        new RegExp("\\.(" + options.extensions.join("|") + ")$", "i").test(filename) && // if options.include is a RegExp, evaluate it and make sure the path passes
        !(options.include && options.include instanceof RegExp && !options.include.test(path47)) && // if options.include is a function, evaluate it and make sure the path passes
        !(options.include && typeof options.include === "function" && !options.include(path47, filename)) && // if options.exclude is a RegExp, evaluate it and make sure the path doesn't pass
        !(options.exclude && options.exclude instanceof RegExp && options.exclude.test(path47)) && // if options.exclude is a function, evaluate it and make sure the path doesn't pass
        !(options.exclude && typeof options.exclude === "function" && options.exclude(path47, filename))
      );
    }
    __name(checkFileInclusion, "checkFileInclusion");
    function requireDirectory(m20, path47, options) {
      var retval = {};
      if (path47 && !options && typeof path47 !== "string") {
        options = path47;
        path47 = null;
      }
      options = options || {};
      for (var prop in defaultOptions2) {
        if (typeof options[prop] === "undefined") {
          options[prop] = defaultOptions2[prop];
        }
      }
      path47 = !path47 ? dirname14(m20.filename) : resolve13(dirname14(m20.filename), path47);
      fs51.readdirSync(path47).forEach(function(filename) {
        var joined = join59(path47, filename), files, key, obj;
        if (fs51.statSync(joined).isDirectory() && options.recurse) {
          files = requireDirectory(m20, joined, options);
          if (Object.keys(files).length) {
            retval[options.rename(filename, joined, filename)] = files;
          }
        } else {
          if (joined !== m20.filename && checkFileInclusion(joined, filename, options)) {
            key = filename.substring(0, filename.lastIndexOf("."));
            obj = m20.require(joined);
            retval[options.rename(key, joined, filename)] = options.visit(obj, joined, filename) || obj;
          }
        }
      });
      return retval;
    }
    __name(requireDirectory, "requireDirectory");
    module2.exports = requireDirectory;
    module2.exports.defaults = defaultOptions2;
  }
});

// ../../node_modules/which-module/index.js
var require_which_module = __commonJS({
  "../../node_modules/which-module/index.js"(exports2, module2) {
    "use strict";
    module2.exports = /* @__PURE__ */ __name(function whichModule(exported) {
      for (var i32 = 0, files = Object.keys(require.cache), mod; i32 < files.length; i32++) {
        mod = require.cache[files[i32]];
        if (mod.exports === exported) return mod;
      }
      return null;
    }, "whichModule");
  }
});

// node_modules/yargs-parser/node_modules/camelcase/index.js
var require_camelcase2 = __commonJS({
  "node_modules/yargs-parser/node_modules/camelcase/index.js"(exports2, module2) {
    "use strict";
    var preserveCamelCase = /* @__PURE__ */ __name((string) => {
      let isLastCharLower = false;
      let isLastCharUpper = false;
      let isLastLastCharUpper = false;
      for (let i32 = 0; i32 < string.length; i32++) {
        const character = string[i32];
        if (isLastCharLower && /[a-zA-Z]/.test(character) && character.toUpperCase() === character) {
          string = string.slice(0, i32) + "-" + string.slice(i32);
          isLastCharLower = false;
          isLastLastCharUpper = isLastCharUpper;
          isLastCharUpper = true;
          i32++;
        } else if (isLastCharUpper && isLastLastCharUpper && /[a-zA-Z]/.test(character) && character.toLowerCase() === character) {
          string = string.slice(0, i32 - 1) + "-" + string.slice(i32 - 1);
          isLastLastCharUpper = isLastCharUpper;
          isLastCharUpper = false;
          isLastCharLower = true;
        } else {
          isLastCharLower = character.toLowerCase() === character && character.toUpperCase() !== character;
          isLastLastCharUpper = isLastCharUpper;
          isLastCharUpper = character.toUpperCase() === character && character.toLowerCase() !== character;
        }
      }
      return string;
    }, "preserveCamelCase");
    var camelCase3 = /* @__PURE__ */ __name((input, options) => {
      if (!(typeof input === "string" || Array.isArray(input))) {
        throw new TypeError("Expected the input to be `string | string[]`");
      }
      options = Object.assign({
        pascalCase: false
      }, options);
      const postProcess = /* @__PURE__ */ __name((x) => options.pascalCase ? x.charAt(0).toUpperCase() + x.slice(1) : x, "postProcess");
      if (Array.isArray(input)) {
        input = input.map((x) => x.trim()).filter((x) => x.length).join("-");
      } else {
        input = input.trim();
      }
      if (input.length === 0) {
        return "";
      }
      if (input.length === 1) {
        return options.pascalCase ? input.toUpperCase() : input.toLowerCase();
      }
      const hasUpperCase = input !== input.toLowerCase();
      if (hasUpperCase) {
        input = preserveCamelCase(input);
      }
      input = input.replace(/^[_.\- ]+/, "").toLowerCase().replace(/[_.\- ]+(\w|$)/g, (_, p1) => p1.toUpperCase()).replace(/\d+(\w|$)/g, (m20) => m20.toUpperCase());
      return postProcess(input);
    }, "camelCase");
    module2.exports = camelCase3;
    module2.exports.default = camelCase3;
  }
});

// node_modules/yargs-parser/node_modules/decamelize/index.js
var require_decamelize2 = __commonJS({
  "node_modules/yargs-parser/node_modules/decamelize/index.js"(exports2, module2) {
    "use strict";
    module2.exports = function(str, sep7) {
      if (typeof str !== "string") {
        throw new TypeError("Expected a string");
      }
      sep7 = typeof sep7 === "undefined" ? "_" : sep7;
      return str.replace(/([a-z\d])([A-Z])/g, "$1" + sep7 + "$2").replace(/([A-Z]+)([A-Z][a-z\d]+)/g, "$1" + sep7 + "$2").toLowerCase();
    };
  }
});

// node_modules/yargs-parser/lib/tokenize-arg-string.js
var require_tokenize_arg_string = __commonJS({
  "node_modules/yargs-parser/lib/tokenize-arg-string.js"(exports2, module2) {
    module2.exports = function(argString) {
      if (Array.isArray(argString)) {
        return argString.map((e32) => typeof e32 !== "string" ? e32 + "" : e32);
      }
      argString = argString.trim();
      let i32 = 0;
      let prevC = null;
      let c32 = null;
      let opening = null;
      const args = [];
      for (let ii = 0; ii < argString.length; ii++) {
        prevC = c32;
        c32 = argString.charAt(ii);
        if (c32 === " " && !opening) {
          if (!(prevC === " ")) {
            i32++;
          }
          continue;
        }
        if (c32 === opening) {
          opening = null;
        } else if ((c32 === "'" || c32 === '"') && !opening) {
          opening = c32;
        }
        if (!args[i32]) args[i32] = "";
        args[i32] += c32;
      }
      return args;
    };
  }
});

// node_modules/yargs-parser/index.js
var require_yargs_parser = __commonJS({
  "node_modules/yargs-parser/index.js"(exports2, module2) {
    var camelCase3 = require_camelcase2();
    var decamelize3 = require_decamelize2();
    var path47 = require("path");
    var tokenizeArgString = require_tokenize_arg_string();
    var util11 = require("util");
    function parse2(args, opts) {
      opts = Object.assign(/* @__PURE__ */ Object.create(null), opts);
      args = tokenizeArgString(args);
      const aliases = combineAliases(Object.assign(/* @__PURE__ */ Object.create(null), opts.alias));
      const configuration = Object.assign({
        "boolean-negation": true,
        "camel-case-expansion": true,
        "combine-arrays": false,
        "dot-notation": true,
        "duplicate-arguments-array": true,
        "flatten-duplicate-arrays": true,
        "greedy-arrays": true,
        "halt-at-non-option": false,
        "nargs-eats-options": false,
        "negation-prefix": "no-",
        "parse-numbers": true,
        "populate--": false,
        "set-placeholder-key": false,
        "short-option-groups": true,
        "strip-aliased": false,
        "strip-dashed": false,
        "unknown-options-as-args": false
      }, opts.configuration);
      const defaults = Object.assign(/* @__PURE__ */ Object.create(null), opts.default);
      const configObjects = opts.configObjects || [];
      const envPrefix = opts.envPrefix;
      const notFlagsOption = configuration["populate--"];
      const notFlagsArgv = notFlagsOption ? "--" : "_";
      const newAliases = /* @__PURE__ */ Object.create(null);
      const defaulted = /* @__PURE__ */ Object.create(null);
      const __ = opts.__ || util11.format;
      const flags = {
        aliases: /* @__PURE__ */ Object.create(null),
        arrays: /* @__PURE__ */ Object.create(null),
        bools: /* @__PURE__ */ Object.create(null),
        strings: /* @__PURE__ */ Object.create(null),
        numbers: /* @__PURE__ */ Object.create(null),
        counts: /* @__PURE__ */ Object.create(null),
        normalize: /* @__PURE__ */ Object.create(null),
        configs: /* @__PURE__ */ Object.create(null),
        nargs: /* @__PURE__ */ Object.create(null),
        coercions: /* @__PURE__ */ Object.create(null),
        keys: []
      };
      const negative = /^-([0-9]+(\.[0-9]+)?|\.[0-9]+)$/;
      const negatedBoolean = new RegExp("^--" + configuration["negation-prefix"] + "(.+)");
      [].concat(opts.array).filter(Boolean).forEach(function(opt) {
        const key = opt.key || opt;
        const assignment = Object.keys(opt).map(function(key2) {
          return {
            boolean: "bools",
            string: "strings",
            number: "numbers"
          }[key2];
        }).filter(Boolean).pop();
        if (assignment) {
          flags[assignment][key] = true;
        }
        flags.arrays[key] = true;
        flags.keys.push(key);
      });
      [].concat(opts.boolean).filter(Boolean).forEach(function(key) {
        flags.bools[key] = true;
        flags.keys.push(key);
      });
      [].concat(opts.string).filter(Boolean).forEach(function(key) {
        flags.strings[key] = true;
        flags.keys.push(key);
      });
      [].concat(opts.number).filter(Boolean).forEach(function(key) {
        flags.numbers[key] = true;
        flags.keys.push(key);
      });
      [].concat(opts.count).filter(Boolean).forEach(function(key) {
        flags.counts[key] = true;
        flags.keys.push(key);
      });
      [].concat(opts.normalize).filter(Boolean).forEach(function(key) {
        flags.normalize[key] = true;
        flags.keys.push(key);
      });
      Object.keys(opts.narg || {}).forEach(function(k32) {
        flags.nargs[k32] = opts.narg[k32];
        flags.keys.push(k32);
      });
      Object.keys(opts.coerce || {}).forEach(function(k32) {
        flags.coercions[k32] = opts.coerce[k32];
        flags.keys.push(k32);
      });
      if (Array.isArray(opts.config) || typeof opts.config === "string") {
        ;
        [].concat(opts.config).filter(Boolean).forEach(function(key) {
          flags.configs[key] = true;
        });
      } else {
        Object.keys(opts.config || {}).forEach(function(k32) {
          flags.configs[k32] = opts.config[k32];
        });
      }
      extendAliases(opts.key, aliases, opts.default, flags.arrays);
      Object.keys(defaults).forEach(function(key) {
        (flags.aliases[key] || []).forEach(function(alias) {
          defaults[alias] = defaults[key];
        });
      });
      let error4 = null;
      checkConfiguration();
      let notFlags = [];
      const argv = Object.assign(/* @__PURE__ */ Object.create(null), { _: [] });
      const argvReturn = {};
      for (let i32 = 0; i32 < args.length; i32++) {
        const arg = args[i32];
        let broken;
        let key;
        let letters;
        let m20;
        let next;
        let value;
        if (arg !== "--" && isUnknownOptionAsArg(arg)) {
          argv._.push(arg);
        } else if (arg.match(/^--.+=/) || !configuration["short-option-groups"] && arg.match(/^-.+=/)) {
          m20 = arg.match(/^--?([^=]+)=([\s\S]*)$/);
          if (checkAllAliases(m20[1], flags.arrays)) {
            i32 = eatArray(i32, m20[1], args, m20[2]);
          } else if (checkAllAliases(m20[1], flags.nargs) !== false) {
            i32 = eatNargs(i32, m20[1], args, m20[2]);
          } else {
            setArg(m20[1], m20[2]);
          }
        } else if (arg.match(negatedBoolean) && configuration["boolean-negation"]) {
          key = arg.match(negatedBoolean)[1];
          setArg(key, checkAllAliases(key, flags.arrays) ? [false] : false);
        } else if (arg.match(/^--.+/) || !configuration["short-option-groups"] && arg.match(/^-[^-]+/)) {
          key = arg.match(/^--?(.+)/)[1];
          if (checkAllAliases(key, flags.arrays)) {
            i32 = eatArray(i32, key, args);
          } else if (checkAllAliases(key, flags.nargs) !== false) {
            i32 = eatNargs(i32, key, args);
          } else {
            next = args[i32 + 1];
            if (next !== void 0 && (!next.match(/^-/) || next.match(negative)) && !checkAllAliases(key, flags.bools) && !checkAllAliases(key, flags.counts)) {
              setArg(key, next);
              i32++;
            } else if (/^(true|false)$/.test(next)) {
              setArg(key, next);
              i32++;
            } else {
              setArg(key, defaultValue2(key));
            }
          }
        } else if (arg.match(/^-.\..+=/)) {
          m20 = arg.match(/^-([^=]+)=([\s\S]*)$/);
          setArg(m20[1], m20[2]);
        } else if (arg.match(/^-.\..+/) && !arg.match(negative)) {
          next = args[i32 + 1];
          key = arg.match(/^-(.\..+)/)[1];
          if (next !== void 0 && !next.match(/^-/) && !checkAllAliases(key, flags.bools) && !checkAllAliases(key, flags.counts)) {
            setArg(key, next);
            i32++;
          } else {
            setArg(key, defaultValue2(key));
          }
        } else if (arg.match(/^-[^-]+/) && !arg.match(negative)) {
          letters = arg.slice(1, -1).split("");
          broken = false;
          for (let j32 = 0; j32 < letters.length; j32++) {
            next = arg.slice(j32 + 2);
            if (letters[j32 + 1] && letters[j32 + 1] === "=") {
              value = arg.slice(j32 + 3);
              key = letters[j32];
              if (checkAllAliases(key, flags.arrays)) {
                i32 = eatArray(i32, key, args, value);
              } else if (checkAllAliases(key, flags.nargs) !== false) {
                i32 = eatNargs(i32, key, args, value);
              } else {
                setArg(key, value);
              }
              broken = true;
              break;
            }
            if (next === "-") {
              setArg(letters[j32], next);
              continue;
            }
            if (/[A-Za-z]/.test(letters[j32]) && /^-?\d+(\.\d*)?(e-?\d+)?$/.test(next)) {
              setArg(letters[j32], next);
              broken = true;
              break;
            }
            if (letters[j32 + 1] && letters[j32 + 1].match(/\W/)) {
              setArg(letters[j32], next);
              broken = true;
              break;
            } else {
              setArg(letters[j32], defaultValue2(letters[j32]));
            }
          }
          key = arg.slice(-1)[0];
          if (!broken && key !== "-") {
            if (checkAllAliases(key, flags.arrays)) {
              i32 = eatArray(i32, key, args);
            } else if (checkAllAliases(key, flags.nargs) !== false) {
              i32 = eatNargs(i32, key, args);
            } else {
              next = args[i32 + 1];
              if (next !== void 0 && (!/^(-|--)[^-]/.test(next) || next.match(negative)) && !checkAllAliases(key, flags.bools) && !checkAllAliases(key, flags.counts)) {
                setArg(key, next);
                i32++;
              } else if (/^(true|false)$/.test(next)) {
                setArg(key, next);
                i32++;
              } else {
                setArg(key, defaultValue2(key));
              }
            }
          }
        } else if (arg.match(/^-[0-9]$/) && arg.match(negative) && checkAllAliases(arg.slice(1), flags.bools)) {
          key = arg.slice(1);
          setArg(key, defaultValue2(key));
        } else if (arg === "--") {
          notFlags = args.slice(i32 + 1);
          break;
        } else if (configuration["halt-at-non-option"]) {
          notFlags = args.slice(i32);
          break;
        } else {
          argv._.push(maybeCoerceNumber("_", arg));
        }
      }
      applyEnvVars(argv, true);
      applyEnvVars(argv, false);
      setConfig(argv);
      setConfigObjects();
      applyDefaultsAndAliases(argv, flags.aliases, defaults, true);
      applyCoercions(argv);
      if (configuration["set-placeholder-key"]) setPlaceholderKeys(argv);
      Object.keys(flags.counts).forEach(function(key) {
        if (!hasKey(argv, key.split("."))) setArg(key, 0);
      });
      if (notFlagsOption && notFlags.length) argv[notFlagsArgv] = [];
      notFlags.forEach(function(key) {
        argv[notFlagsArgv].push(key);
      });
      if (configuration["camel-case-expansion"] && configuration["strip-dashed"]) {
        Object.keys(argv).filter((key) => key !== "--" && key.includes("-")).forEach((key) => {
          delete argv[key];
        });
      }
      if (configuration["strip-aliased"]) {
        ;
        [].concat(...Object.keys(aliases).map((k32) => aliases[k32])).forEach((alias) => {
          if (configuration["camel-case-expansion"]) {
            delete argv[alias.split(".").map((prop) => camelCase3(prop)).join(".")];
          }
          delete argv[alias];
        });
      }
      function eatNargs(i32, key, args2, argAfterEqualSign) {
        let ii;
        let toEat = checkAllAliases(key, flags.nargs);
        toEat = isNaN(toEat) ? 1 : toEat;
        if (toEat === 0) {
          if (!isUndefined(argAfterEqualSign)) {
            error4 = Error(__("Argument unexpected for: %s", key));
          }
          setArg(key, defaultValue2(key));
          return i32;
        }
        let available = isUndefined(argAfterEqualSign) ? 0 : 1;
        if (configuration["nargs-eats-options"]) {
          if (args2.length - (i32 + 1) + available < toEat) {
            error4 = Error(__("Not enough arguments following: %s", key));
          }
          available = toEat;
        } else {
          for (ii = i32 + 1; ii < args2.length; ii++) {
            if (!args2[ii].match(/^-[^0-9]/) || args2[ii].match(negative) || isUnknownOptionAsArg(args2[ii])) available++;
            else break;
          }
          if (available < toEat) error4 = Error(__("Not enough arguments following: %s", key));
        }
        let consumed = Math.min(available, toEat);
        if (!isUndefined(argAfterEqualSign) && consumed > 0) {
          setArg(key, argAfterEqualSign);
          consumed--;
        }
        for (ii = i32 + 1; ii < consumed + i32 + 1; ii++) {
          setArg(key, args2[ii]);
        }
        return i32 + consumed;
      }
      __name(eatNargs, "eatNargs");
      function eatArray(i32, key, args2, argAfterEqualSign) {
        let argsToSet = [];
        let next = argAfterEqualSign || args2[i32 + 1];
        const nargsCount = checkAllAliases(key, flags.nargs);
        if (checkAllAliases(key, flags.bools) && !/^(true|false)$/.test(next)) {
          argsToSet.push(true);
        } else if (isUndefined(next) || isUndefined(argAfterEqualSign) && /^-/.test(next) && !negative.test(next) && !isUnknownOptionAsArg(next)) {
          if (defaults[key] !== void 0) {
            const defVal = defaults[key];
            argsToSet = Array.isArray(defVal) ? defVal : [defVal];
          }
        } else {
          if (!isUndefined(argAfterEqualSign)) {
            argsToSet.push(processValue(key, argAfterEqualSign));
          }
          for (let ii = i32 + 1; ii < args2.length; ii++) {
            if (!configuration["greedy-arrays"] && argsToSet.length > 0 || nargsCount && argsToSet.length >= nargsCount) break;
            next = args2[ii];
            if (/^-/.test(next) && !negative.test(next) && !isUnknownOptionAsArg(next)) break;
            i32 = ii;
            argsToSet.push(processValue(key, next));
          }
        }
        if (nargsCount && argsToSet.length < nargsCount || isNaN(nargsCount) && argsToSet.length === 0) {
          error4 = Error(__("Not enough arguments following: %s", key));
        }
        setArg(key, argsToSet);
        return i32;
      }
      __name(eatArray, "eatArray");
      function setArg(key, val) {
        if (/-/.test(key) && configuration["camel-case-expansion"]) {
          const alias = key.split(".").map(function(prop) {
            return camelCase3(prop);
          }).join(".");
          addNewAlias(key, alias);
        }
        const value = processValue(key, val);
        const splitKey = key.split(".");
        setKey(argv, splitKey, value);
        if (flags.aliases[key]) {
          flags.aliases[key].forEach(function(x) {
            x = x.split(".");
            setKey(argv, x, value);
          });
        }
        if (splitKey.length > 1 && configuration["dot-notation"]) {
          ;
          (flags.aliases[splitKey[0]] || []).forEach(function(x) {
            x = x.split(".");
            const a32 = [].concat(splitKey);
            a32.shift();
            x = x.concat(a32);
            if (!(flags.aliases[key] || []).includes(x.join("."))) {
              setKey(argv, x, value);
            }
          });
        }
        if (checkAllAliases(key, flags.normalize) && !checkAllAliases(key, flags.arrays)) {
          const keys = [key].concat(flags.aliases[key] || []);
          keys.forEach(function(key2) {
            Object.defineProperty(argvReturn, key2, {
              enumerable: true,
              get() {
                return val;
              },
              set(value2) {
                val = typeof value2 === "string" ? path47.normalize(value2) : value2;
              }
            });
          });
        }
      }
      __name(setArg, "setArg");
      function addNewAlias(key, alias) {
        if (!(flags.aliases[key] && flags.aliases[key].length)) {
          flags.aliases[key] = [alias];
          newAliases[alias] = true;
        }
        if (!(flags.aliases[alias] && flags.aliases[alias].length)) {
          addNewAlias(alias, key);
        }
      }
      __name(addNewAlias, "addNewAlias");
      function processValue(key, val) {
        if (typeof val === "string" && (val[0] === "'" || val[0] === '"') && val[val.length - 1] === val[0]) {
          val = val.substring(1, val.length - 1);
        }
        if (checkAllAliases(key, flags.bools) || checkAllAliases(key, flags.counts)) {
          if (typeof val === "string") val = val === "true";
        }
        let value = Array.isArray(val) ? val.map(function(v) {
          return maybeCoerceNumber(key, v);
        }) : maybeCoerceNumber(key, val);
        if (checkAllAliases(key, flags.counts) && (isUndefined(value) || typeof value === "boolean")) {
          value = increment;
        }
        if (checkAllAliases(key, flags.normalize) && checkAllAliases(key, flags.arrays)) {
          if (Array.isArray(val)) value = val.map(path47.normalize);
          else value = path47.normalize(val);
        }
        return value;
      }
      __name(processValue, "processValue");
      function maybeCoerceNumber(key, value) {
        if (!checkAllAliases(key, flags.strings) && !checkAllAliases(key, flags.bools) && !Array.isArray(value)) {
          const shouldCoerceNumber = isNumber(value) && configuration["parse-numbers"] && Number.isSafeInteger(Math.floor(value));
          if (shouldCoerceNumber || !isUndefined(value) && checkAllAliases(key, flags.numbers)) value = Number(value);
        }
        return value;
      }
      __name(maybeCoerceNumber, "maybeCoerceNumber");
      function setConfig(argv2) {
        const configLookup = /* @__PURE__ */ Object.create(null);
        applyDefaultsAndAliases(configLookup, flags.aliases, defaults);
        Object.keys(flags.configs).forEach(function(configKey) {
          const configPath = argv2[configKey] || configLookup[configKey];
          if (configPath) {
            try {
              let config2 = null;
              const resolvedConfigPath = path47.resolve(process.cwd(), configPath);
              if (typeof flags.configs[configKey] === "function") {
                try {
                  config2 = flags.configs[configKey](resolvedConfigPath);
                } catch (e32) {
                  config2 = e32;
                }
                if (config2 instanceof Error) {
                  error4 = config2;
                  return;
                }
              } else {
                config2 = require(resolvedConfigPath);
              }
              setConfigObject(config2);
            } catch (ex) {
              if (argv2[configKey]) error4 = Error(__("Invalid JSON config file: %s", configPath));
            }
          }
        });
      }
      __name(setConfig, "setConfig");
      function setConfigObject(config2, prev) {
        Object.keys(config2).forEach(function(key) {
          const value = config2[key];
          const fullKey = prev ? prev + "." + key : key;
          if (typeof value === "object" && value !== null && !Array.isArray(value) && configuration["dot-notation"]) {
            setConfigObject(value, fullKey);
          } else {
            if (!hasKey(argv, fullKey.split(".")) || checkAllAliases(fullKey, flags.arrays) && configuration["combine-arrays"]) {
              setArg(fullKey, value);
            }
          }
        });
      }
      __name(setConfigObject, "setConfigObject");
      function setConfigObjects() {
        if (typeof configObjects === "undefined") return;
        configObjects.forEach(function(configObject) {
          setConfigObject(configObject);
        });
      }
      __name(setConfigObjects, "setConfigObjects");
      function applyEnvVars(argv2, configOnly) {
        if (typeof envPrefix === "undefined") return;
        const prefix = typeof envPrefix === "string" ? envPrefix : "";
        Object.keys(process.env).forEach(function(envVar) {
          if (prefix === "" || envVar.lastIndexOf(prefix, 0) === 0) {
            const keys = envVar.split("__").map(function(key, i32) {
              if (i32 === 0) {
                key = key.substring(prefix.length);
              }
              return camelCase3(key);
            });
            if ((configOnly && flags.configs[keys.join(".")] || !configOnly) && !hasKey(argv2, keys)) {
              setArg(keys.join("."), process.env[envVar]);
            }
          }
        });
      }
      __name(applyEnvVars, "applyEnvVars");
      function applyCoercions(argv2) {
        let coerce2;
        const applied = /* @__PURE__ */ new Set();
        Object.keys(argv2).forEach(function(key) {
          if (!applied.has(key)) {
            coerce2 = checkAllAliases(key, flags.coercions);
            if (typeof coerce2 === "function") {
              try {
                const value = maybeCoerceNumber(key, coerce2(argv2[key]));
                [].concat(flags.aliases[key] || [], key).forEach((ali) => {
                  applied.add(ali);
                  argv2[ali] = value;
                });
              } catch (err) {
                error4 = err;
              }
            }
          }
        });
      }
      __name(applyCoercions, "applyCoercions");
      function setPlaceholderKeys(argv2) {
        flags.keys.forEach((key) => {
          if (~key.indexOf(".")) return;
          if (typeof argv2[key] === "undefined") argv2[key] = void 0;
        });
        return argv2;
      }
      __name(setPlaceholderKeys, "setPlaceholderKeys");
      function applyDefaultsAndAliases(obj, aliases2, defaults2, canLog = false) {
        Object.keys(defaults2).forEach(function(key) {
          if (!hasKey(obj, key.split("."))) {
            setKey(obj, key.split("."), defaults2[key]);
            if (canLog) defaulted[key] = true;
            (aliases2[key] || []).forEach(function(x) {
              if (hasKey(obj, x.split("."))) return;
              setKey(obj, x.split("."), defaults2[key]);
            });
          }
        });
      }
      __name(applyDefaultsAndAliases, "applyDefaultsAndAliases");
      function hasKey(obj, keys) {
        let o10 = obj;
        if (!configuration["dot-notation"]) keys = [keys.join(".")];
        keys.slice(0, -1).forEach(function(key2) {
          o10 = o10[key2] || {};
        });
        const key = keys[keys.length - 1];
        if (typeof o10 !== "object") return false;
        else return key in o10;
      }
      __name(hasKey, "hasKey");
      function setKey(obj, keys, value) {
        let o10 = obj;
        if (!configuration["dot-notation"]) keys = [keys.join(".")];
        keys.slice(0, -1).forEach(function(key2, index) {
          key2 = sanitizeKey(key2);
          if (typeof o10 === "object" && o10[key2] === void 0) {
            o10[key2] = {};
          }
          if (typeof o10[key2] !== "object" || Array.isArray(o10[key2])) {
            if (Array.isArray(o10[key2])) {
              o10[key2].push({});
            } else {
              o10[key2] = [o10[key2], {}];
            }
            o10 = o10[key2][o10[key2].length - 1];
          } else {
            o10 = o10[key2];
          }
        });
        const key = sanitizeKey(keys[keys.length - 1]);
        const isTypeArray = checkAllAliases(keys.join("."), flags.arrays);
        const isValueArray = Array.isArray(value);
        let duplicate = configuration["duplicate-arguments-array"];
        if (!duplicate && checkAllAliases(key, flags.nargs)) {
          duplicate = true;
          if (!isUndefined(o10[key]) && flags.nargs[key] === 1 || Array.isArray(o10[key]) && o10[key].length === flags.nargs[key]) {
            o10[key] = void 0;
          }
        }
        if (value === increment) {
          o10[key] = increment(o10[key]);
        } else if (Array.isArray(o10[key])) {
          if (duplicate && isTypeArray && isValueArray) {
            o10[key] = configuration["flatten-duplicate-arrays"] ? o10[key].concat(value) : (Array.isArray(o10[key][0]) ? o10[key] : [o10[key]]).concat([value]);
          } else if (!duplicate && Boolean(isTypeArray) === Boolean(isValueArray)) {
            o10[key] = value;
          } else {
            o10[key] = o10[key].concat([value]);
          }
        } else if (o10[key] === void 0 && isTypeArray) {
          o10[key] = isValueArray ? value : [value];
        } else if (duplicate && !(o10[key] === void 0 || checkAllAliases(key, flags.counts) || checkAllAliases(key, flags.bools))) {
          o10[key] = [o10[key], value];
        } else {
          o10[key] = value;
        }
      }
      __name(setKey, "setKey");
      function extendAliases(...args2) {
        args2.forEach(function(obj) {
          Object.keys(obj || {}).forEach(function(key) {
            if (flags.aliases[key]) return;
            flags.aliases[key] = [].concat(aliases[key] || []);
            flags.aliases[key].concat(key).forEach(function(x) {
              if (/-/.test(x) && configuration["camel-case-expansion"]) {
                const c32 = camelCase3(x);
                if (c32 !== key && flags.aliases[key].indexOf(c32) === -1) {
                  flags.aliases[key].push(c32);
                  newAliases[c32] = true;
                }
              }
            });
            flags.aliases[key].concat(key).forEach(function(x) {
              if (x.length > 1 && /[A-Z]/.test(x) && configuration["camel-case-expansion"]) {
                const c32 = decamelize3(x, "-");
                if (c32 !== key && flags.aliases[key].indexOf(c32) === -1) {
                  flags.aliases[key].push(c32);
                  newAliases[c32] = true;
                }
              }
            });
            flags.aliases[key].forEach(function(x) {
              flags.aliases[x] = [key].concat(flags.aliases[key].filter(function(y) {
                return x !== y;
              }));
            });
          });
        });
      }
      __name(extendAliases, "extendAliases");
      function checkAllAliases(key, flag) {
        const toCheck = [].concat(flags.aliases[key] || [], key);
        const keys = Object.keys(flag);
        const setAlias = toCheck.find((key2) => keys.includes(key2));
        return setAlias ? flag[setAlias] : false;
      }
      __name(checkAllAliases, "checkAllAliases");
      function hasAnyFlag(key) {
        const toCheck = [].concat(Object.keys(flags).map((k32) => flags[k32]));
        return toCheck.some(function(flag) {
          return Array.isArray(flag) ? flag.includes(key) : flag[key];
        });
      }
      __name(hasAnyFlag, "hasAnyFlag");
      function hasFlagsMatching(arg, ...patterns) {
        const toCheck = [].concat(...patterns);
        return toCheck.some(function(pattern) {
          const match = arg.match(pattern);
          return match && hasAnyFlag(match[1]);
        });
      }
      __name(hasFlagsMatching, "hasFlagsMatching");
      function hasAllShortFlags(arg) {
        if (arg.match(negative) || !arg.match(/^-[^-]+/)) {
          return false;
        }
        let hasAllFlags = true;
        let next;
        const letters = arg.slice(1).split("");
        for (let j32 = 0; j32 < letters.length; j32++) {
          next = arg.slice(j32 + 2);
          if (!hasAnyFlag(letters[j32])) {
            hasAllFlags = false;
            break;
          }
          if (letters[j32 + 1] && letters[j32 + 1] === "=" || next === "-" || /[A-Za-z]/.test(letters[j32]) && /^-?\d+(\.\d*)?(e-?\d+)?$/.test(next) || letters[j32 + 1] && letters[j32 + 1].match(/\W/)) {
            break;
          }
        }
        return hasAllFlags;
      }
      __name(hasAllShortFlags, "hasAllShortFlags");
      function isUnknownOptionAsArg(arg) {
        return configuration["unknown-options-as-args"] && isUnknownOption(arg);
      }
      __name(isUnknownOptionAsArg, "isUnknownOptionAsArg");
      function isUnknownOption(arg) {
        if (arg.match(negative)) {
          return false;
        }
        if (hasAllShortFlags(arg)) {
          return false;
        }
        const flagWithEquals = /^-+([^=]+?)=[\s\S]*$/;
        const normalFlag = /^-+([^=]+?)$/;
        const flagEndingInHyphen = /^-+([^=]+?)-$/;
        const flagEndingInDigits = /^-+([^=]+?\d+)$/;
        const flagEndingInNonWordCharacters = /^-+([^=]+?)\W+.*$/;
        return !hasFlagsMatching(arg, flagWithEquals, negatedBoolean, normalFlag, flagEndingInHyphen, flagEndingInDigits, flagEndingInNonWordCharacters);
      }
      __name(isUnknownOption, "isUnknownOption");
      function defaultValue2(key) {
        if (!checkAllAliases(key, flags.bools) && !checkAllAliases(key, flags.counts) && `${key}` in defaults) {
          return defaults[key];
        } else {
          return defaultForType(guessType(key));
        }
      }
      __name(defaultValue2, "defaultValue");
      function defaultForType(type) {
        const def = {
          boolean: true,
          string: "",
          number: void 0,
          array: []
        };
        return def[type];
      }
      __name(defaultForType, "defaultForType");
      function guessType(key) {
        let type = "boolean";
        if (checkAllAliases(key, flags.strings)) type = "string";
        else if (checkAllAliases(key, flags.numbers)) type = "number";
        else if (checkAllAliases(key, flags.bools)) type = "boolean";
        else if (checkAllAliases(key, flags.arrays)) type = "array";
        return type;
      }
      __name(guessType, "guessType");
      function isNumber(x) {
        if (x === null || x === void 0) return false;
        if (typeof x === "number") return true;
        if (/^0x[0-9a-f]+$/i.test(x)) return true;
        if (x.length > 1 && x[0] === "0") return false;
        return /^[-]?(?:\d+(?:\.\d*)?|\.\d+)(e[-+]?\d+)?$/.test(x);
      }
      __name(isNumber, "isNumber");
      function isUndefined(num) {
        return num === void 0;
      }
      __name(isUndefined, "isUndefined");
      function checkConfiguration() {
        Object.keys(flags.counts).find((key) => {
          if (checkAllAliases(key, flags.arrays)) {
            error4 = Error(__("Invalid configuration: %s, opts.count excludes opts.array.", key));
            return true;
          } else if (checkAllAliases(key, flags.nargs)) {
            error4 = Error(__("Invalid configuration: %s, opts.count excludes opts.narg.", key));
            return true;
          }
        });
      }
      __name(checkConfiguration, "checkConfiguration");
      return {
        argv: Object.assign(argvReturn, argv),
        error: error4,
        aliases: Object.assign({}, flags.aliases),
        newAliases: Object.assign({}, newAliases),
        defaulted: Object.assign({}, defaulted),
        configuration
      };
    }
    __name(parse2, "parse");
    function combineAliases(aliases) {
      const aliasArrays = [];
      const combined = /* @__PURE__ */ Object.create(null);
      let change = true;
      Object.keys(aliases).forEach(function(key) {
        aliasArrays.push(
          [].concat(aliases[key], key)
        );
      });
      while (change) {
        change = false;
        for (let i32 = 0; i32 < aliasArrays.length; i32++) {
          for (let ii = i32 + 1; ii < aliasArrays.length; ii++) {
            const intersect = aliasArrays[i32].filter(function(v) {
              return aliasArrays[ii].indexOf(v) !== -1;
            });
            if (intersect.length) {
              aliasArrays[i32] = aliasArrays[i32].concat(aliasArrays[ii]);
              aliasArrays.splice(ii, 1);
              change = true;
              break;
            }
          }
        }
      }
      aliasArrays.forEach(function(aliasArray) {
        aliasArray = aliasArray.filter(function(v, i32, self2) {
          return self2.indexOf(v) === i32;
        });
        combined[aliasArray.pop()] = aliasArray;
      });
      return combined;
    }
    __name(combineAliases, "combineAliases");
    function increment(orig) {
      return orig !== void 0 ? orig + 1 : 1;
    }
    __name(increment, "increment");
    function Parser(args, opts) {
      const result2 = parse2(args.slice(), opts);
      return result2.argv;
    }
    __name(Parser, "Parser");
    Parser.detailed = function(args, opts) {
      return parse2(args.slice(), opts);
    };
    function sanitizeKey(key) {
      if (key === "__proto__") return "___proto___";
      return key;
    }
    __name(sanitizeKey, "sanitizeKey");
    module2.exports = Parser;
  }
});

// node_modules/yargs/build/lib/command.js
var require_command = __commonJS({
  "node_modules/yargs/build/lib/command.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isCommandBuilderCallback = exports2.isCommandBuilderDefinition = exports2.isCommandHandlerDefinition = exports2.command = void 0;
    var common_types_1 = require_common_types();
    var is_promise_1 = require_is_promise();
    var middleware_1 = require_middleware();
    var parse_command_1 = require_parse_command();
    var path47 = require("path");
    var util_1 = require("util");
    var yargs_1 = require_yargs();
    var requireDirectory = require_require_directory();
    var whichModule = require_which_module();
    var Parser = require_yargs_parser();
    var DEFAULT_MARKER = /(^\*)|(^\$0)/;
    function command(yargs2, usage, validation, globalMiddleware = []) {
      const self2 = {};
      let handlers = {};
      let aliasMap = {};
      let defaultCommand;
      self2.addHandler = /* @__PURE__ */ __name(function addHandler(cmd, description, builder, handler, commandMiddleware, deprecated) {
        let aliases = [];
        const middlewares = middleware_1.commandMiddlewareFactory(commandMiddleware);
        handler = handler || (() => {
        });
        if (Array.isArray(cmd)) {
          aliases = cmd.slice(1);
          cmd = cmd[0];
        } else if (isCommandHandlerDefinition(cmd)) {
          let command2 = Array.isArray(cmd.command) || typeof cmd.command === "string" ? cmd.command : moduleName(cmd);
          if (cmd.aliases)
            command2 = [].concat(command2).concat(cmd.aliases);
          self2.addHandler(command2, extractDesc(cmd), cmd.builder, cmd.handler, cmd.middlewares, cmd.deprecated);
          return;
        }
        if (isCommandBuilderDefinition(builder)) {
          self2.addHandler([cmd].concat(aliases), description, builder.builder, builder.handler, builder.middlewares, builder.deprecated);
          return;
        }
        const parsedCommand = parse_command_1.parseCommand(cmd);
        aliases = aliases.map((alias) => parse_command_1.parseCommand(alias).cmd);
        let isDefault = false;
        const parsedAliases = [parsedCommand.cmd].concat(aliases).filter((c32) => {
          if (DEFAULT_MARKER.test(c32)) {
            isDefault = true;
            return false;
          }
          return true;
        });
        if (parsedAliases.length === 0 && isDefault)
          parsedAliases.push("$0");
        if (isDefault) {
          parsedCommand.cmd = parsedAliases[0];
          aliases = parsedAliases.slice(1);
          cmd = cmd.replace(DEFAULT_MARKER, parsedCommand.cmd);
        }
        aliases.forEach((alias) => {
          aliasMap[alias] = parsedCommand.cmd;
        });
        if (description !== false) {
          usage.command(cmd, description, isDefault, aliases, deprecated);
        }
        handlers[parsedCommand.cmd] = {
          original: cmd,
          description,
          handler,
          builder: builder || {},
          middlewares,
          deprecated,
          demanded: parsedCommand.demanded,
          optional: parsedCommand.optional
        };
        if (isDefault)
          defaultCommand = handlers[parsedCommand.cmd];
      }, "addHandler");
      self2.addDirectory = /* @__PURE__ */ __name(function addDirectory(dir, context, req, callerFile, opts) {
        opts = opts || {};
        if (typeof opts.recurse !== "boolean")
          opts.recurse = false;
        if (!Array.isArray(opts.extensions))
          opts.extensions = ["js"];
        const parentVisit = typeof opts.visit === "function" ? opts.visit : (o10) => o10;
        opts.visit = /* @__PURE__ */ __name(function visit(obj, joined, filename) {
          const visited = parentVisit(obj, joined, filename);
          if (visited) {
            if (~context.files.indexOf(joined))
              return visited;
            context.files.push(joined);
            self2.addHandler(visited);
          }
          return visited;
        }, "visit");
        requireDirectory({ require: req, filename: callerFile }, dir, opts);
      }, "addDirectory");
      function moduleName(obj) {
        const mod = whichModule(obj);
        if (!mod)
          throw new Error(`No command name given for module: ${util_1.inspect(obj)}`);
        return commandFromFilename(mod.filename);
      }
      __name(moduleName, "moduleName");
      function commandFromFilename(filename) {
        return path47.basename(filename, path47.extname(filename));
      }
      __name(commandFromFilename, "commandFromFilename");
      function extractDesc({ describe, description, desc }) {
        for (const test of [describe, description, desc]) {
          if (typeof test === "string" || test === false)
            return test;
          common_types_1.assertNotStrictEqual(test, true);
        }
        return false;
      }
      __name(extractDesc, "extractDesc");
      self2.getCommands = () => Object.keys(handlers).concat(Object.keys(aliasMap));
      self2.getCommandHandlers = () => handlers;
      self2.hasDefaultCommand = () => !!defaultCommand;
      self2.runCommand = /* @__PURE__ */ __name(function runCommand(command2, yargs3, parsed, commandIndex) {
        let aliases = parsed.aliases;
        const commandHandler = handlers[command2] || handlers[aliasMap[command2]] || defaultCommand;
        const currentContext = yargs3.getContext();
        let numFiles = currentContext.files.length;
        const parentCommands = currentContext.commands.slice();
        let innerArgv = parsed.argv;
        let positionalMap = {};
        if (command2) {
          currentContext.commands.push(command2);
          currentContext.fullCommands.push(commandHandler.original);
        }
        const builder = commandHandler.builder;
        if (isCommandBuilderCallback(builder)) {
          const builderOutput = builder(yargs3.reset(parsed.aliases));
          const innerYargs = yargs_1.isYargsInstance(builderOutput) ? builderOutput : yargs3;
          if (shouldUpdateUsage(innerYargs)) {
            innerYargs.getUsageInstance().usage(usageFromParentCommandsCommandHandler(parentCommands, commandHandler), commandHandler.description);
          }
          innerArgv = innerYargs._parseArgs(null, null, true, commandIndex);
          aliases = innerYargs.parsed.aliases;
        } else if (isCommandBuilderOptionDefinitions(builder)) {
          const innerYargs = yargs3.reset(parsed.aliases);
          if (shouldUpdateUsage(innerYargs)) {
            innerYargs.getUsageInstance().usage(usageFromParentCommandsCommandHandler(parentCommands, commandHandler), commandHandler.description);
          }
          Object.keys(commandHandler.builder).forEach((key) => {
            innerYargs.option(key, builder[key]);
          });
          innerArgv = innerYargs._parseArgs(null, null, true, commandIndex);
          aliases = innerYargs.parsed.aliases;
        }
        if (!yargs3._hasOutput()) {
          positionalMap = populatePositionals(commandHandler, innerArgv, currentContext);
        }
        const middlewares = globalMiddleware.slice(0).concat(commandHandler.middlewares);
        middleware_1.applyMiddleware(innerArgv, yargs3, middlewares, true);
        if (!yargs3._hasOutput()) {
          yargs3._runValidation(innerArgv, aliases, positionalMap, yargs3.parsed.error, !command2);
        }
        if (commandHandler.handler && !yargs3._hasOutput()) {
          yargs3._setHasOutput();
          const populateDoubleDash = !!yargs3.getOptions().configuration["populate--"];
          if (!populateDoubleDash)
            yargs3._copyDoubleDash(innerArgv);
          innerArgv = middleware_1.applyMiddleware(innerArgv, yargs3, middlewares, false);
          let handlerResult;
          if (is_promise_1.isPromise(innerArgv)) {
            handlerResult = innerArgv.then((argv) => commandHandler.handler(argv));
          } else {
            handlerResult = commandHandler.handler(innerArgv);
          }
          const handlerFinishCommand = yargs3.getHandlerFinishCommand();
          if (is_promise_1.isPromise(handlerResult)) {
            yargs3.getUsageInstance().cacheHelpMessage();
            handlerResult.then((value) => {
              if (handlerFinishCommand) {
                handlerFinishCommand(value);
              }
            }).catch((error4) => {
              try {
                yargs3.getUsageInstance().fail(null, error4);
              } catch (err) {
              }
            }).then(() => {
              yargs3.getUsageInstance().clearCachedHelpMessage();
            });
          } else {
            if (handlerFinishCommand) {
              handlerFinishCommand(handlerResult);
            }
          }
        }
        if (command2) {
          currentContext.commands.pop();
          currentContext.fullCommands.pop();
        }
        numFiles = currentContext.files.length - numFiles;
        if (numFiles > 0)
          currentContext.files.splice(numFiles * -1, numFiles);
        return innerArgv;
      }, "runCommand");
      function shouldUpdateUsage(yargs3) {
        return !yargs3.getUsageInstance().getUsageDisabled() && yargs3.getUsageInstance().getUsage().length === 0;
      }
      __name(shouldUpdateUsage, "shouldUpdateUsage");
      function usageFromParentCommandsCommandHandler(parentCommands, commandHandler) {
        const c32 = DEFAULT_MARKER.test(commandHandler.original) ? commandHandler.original.replace(DEFAULT_MARKER, "").trim() : commandHandler.original;
        const pc = parentCommands.filter((c33) => {
          return !DEFAULT_MARKER.test(c33);
        });
        pc.push(c32);
        return `$0 ${pc.join(" ")}`;
      }
      __name(usageFromParentCommandsCommandHandler, "usageFromParentCommandsCommandHandler");
      self2.runDefaultBuilderOn = function(yargs3) {
        common_types_1.assertNotStrictEqual(defaultCommand, void 0);
        if (shouldUpdateUsage(yargs3)) {
          const commandString = DEFAULT_MARKER.test(defaultCommand.original) ? defaultCommand.original : defaultCommand.original.replace(/^[^[\]<>]*/, "$0 ");
          yargs3.getUsageInstance().usage(commandString, defaultCommand.description);
        }
        const builder = defaultCommand.builder;
        if (isCommandBuilderCallback(builder)) {
          builder(yargs3);
        } else {
          Object.keys(builder).forEach((key) => {
            yargs3.option(key, builder[key]);
          });
        }
      };
      function populatePositionals(commandHandler, argv, context) {
        argv._ = argv._.slice(context.commands.length);
        const demanded = commandHandler.demanded.slice(0);
        const optional = commandHandler.optional.slice(0);
        const positionalMap = {};
        validation.positionalCount(demanded.length, argv._.length);
        while (demanded.length) {
          const demand = demanded.shift();
          populatePositional(demand, argv, positionalMap);
        }
        while (optional.length) {
          const maybe = optional.shift();
          populatePositional(maybe, argv, positionalMap);
        }
        argv._ = context.commands.concat(argv._);
        postProcessPositionals(argv, positionalMap, self2.cmdToParseOptions(commandHandler.original));
        return positionalMap;
      }
      __name(populatePositionals, "populatePositionals");
      function populatePositional(positional, argv, positionalMap) {
        const cmd = positional.cmd[0];
        if (positional.variadic) {
          positionalMap[cmd] = argv._.splice(0).map(String);
        } else {
          if (argv._.length)
            positionalMap[cmd] = [String(argv._.shift())];
        }
      }
      __name(populatePositional, "populatePositional");
      function postProcessPositionals(argv, positionalMap, parseOptions) {
        const options = Object.assign({}, yargs2.getOptions());
        options.default = Object.assign(parseOptions.default, options.default);
        for (const key of Object.keys(parseOptions.alias)) {
          options.alias[key] = (options.alias[key] || []).concat(parseOptions.alias[key]);
        }
        options.array = options.array.concat(parseOptions.array);
        delete options.config;
        const unparsed = [];
        Object.keys(positionalMap).forEach((key) => {
          positionalMap[key].map((value) => {
            if (options.configuration["unknown-options-as-args"])
              options.key[key] = true;
            unparsed.push(`--${key}`);
            unparsed.push(value);
          });
        });
        if (!unparsed.length)
          return;
        const config2 = Object.assign({}, options.configuration, {
          "populate--": true
        });
        const parsed = Parser.detailed(unparsed, Object.assign({}, options, {
          configuration: config2
        }));
        if (parsed.error) {
          yargs2.getUsageInstance().fail(parsed.error.message, parsed.error);
        } else {
          const positionalKeys = Object.keys(positionalMap);
          Object.keys(positionalMap).forEach((key) => {
            positionalKeys.push(...parsed.aliases[key]);
          });
          Object.keys(parsed.argv).forEach((key) => {
            if (positionalKeys.indexOf(key) !== -1) {
              if (!positionalMap[key])
                positionalMap[key] = parsed.argv[key];
              argv[key] = parsed.argv[key];
            }
          });
        }
      }
      __name(postProcessPositionals, "postProcessPositionals");
      self2.cmdToParseOptions = function(cmdString) {
        const parseOptions = {
          array: [],
          default: {},
          alias: {},
          demand: {}
        };
        const parsed = parse_command_1.parseCommand(cmdString);
        parsed.demanded.forEach((d32) => {
          const [cmd, ...aliases] = d32.cmd;
          if (d32.variadic) {
            parseOptions.array.push(cmd);
            parseOptions.default[cmd] = [];
          }
          parseOptions.alias[cmd] = aliases;
          parseOptions.demand[cmd] = true;
        });
        parsed.optional.forEach((o10) => {
          const [cmd, ...aliases] = o10.cmd;
          if (o10.variadic) {
            parseOptions.array.push(cmd);
            parseOptions.default[cmd] = [];
          }
          parseOptions.alias[cmd] = aliases;
        });
        return parseOptions;
      };
      self2.reset = () => {
        handlers = {};
        aliasMap = {};
        defaultCommand = void 0;
        return self2;
      };
      const frozens = [];
      self2.freeze = () => {
        frozens.push({
          handlers,
          aliasMap,
          defaultCommand
        });
      };
      self2.unfreeze = () => {
        const frozen = frozens.pop();
        common_types_1.assertNotStrictEqual(frozen, void 0);
        ({
          handlers,
          aliasMap,
          defaultCommand
        } = frozen);
      };
      return self2;
    }
    __name(command, "command");
    exports2.command = command;
    function isCommandHandlerDefinition(cmd) {
      return typeof cmd === "object";
    }
    __name(isCommandHandlerDefinition, "isCommandHandlerDefinition");
    exports2.isCommandHandlerDefinition = isCommandHandlerDefinition;
    function isCommandBuilderDefinition(builder) {
      return typeof builder === "object" && !!builder.builder && typeof builder.handler === "function";
    }
    __name(isCommandBuilderDefinition, "isCommandBuilderDefinition");
    exports2.isCommandBuilderDefinition = isCommandBuilderDefinition;
    function isCommandBuilderCallback(builder) {
      return typeof builder === "function";
    }
    __name(isCommandBuilderCallback, "isCommandBuilderCallback");
    exports2.isCommandBuilderCallback = isCommandBuilderCallback;
    function isCommandBuilderOptionDefinitions(builder) {
      return typeof builder === "object";
    }
    __name(isCommandBuilderOptionDefinitions, "isCommandBuilderOptionDefinitions");
  }
});

// node_modules/yargs/build/lib/obj-filter.js
var require_obj_filter = __commonJS({
  "node_modules/yargs/build/lib/obj-filter.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.objFilter = void 0;
    var common_types_1 = require_common_types();
    function objFilter(original = {}, filter = () => true) {
      const obj = {};
      common_types_1.objectKeys(original).forEach((key) => {
        if (filter(key, original[key])) {
          obj[key] = original[key];
        }
      });
      return obj;
    }
    __name(objFilter, "objFilter");
    exports2.objFilter = objFilter;
  }
});

// node_modules/yargs/node_modules/decamelize/index.js
var require_decamelize3 = __commonJS({
  "node_modules/yargs/node_modules/decamelize/index.js"(exports2, module2) {
    "use strict";
    module2.exports = function(str, sep7) {
      if (typeof str !== "string") {
        throw new TypeError("Expected a string");
      }
      sep7 = typeof sep7 === "undefined" ? "_" : sep7;
      return str.replace(/([a-z\d])([A-Z])/g, "$1" + sep7 + "$2").replace(/([A-Z]+)([A-Z][a-z\d]+)/g, "$1" + sep7 + "$2").toLowerCase();
    };
  }
});

// ../../node_modules/set-blocking/index.js
var require_set_blocking = __commonJS({
  "../../node_modules/set-blocking/index.js"(exports2, module2) {
    module2.exports = function(blocking) {
      [process.stdout, process.stderr].forEach(function(stream) {
        if (stream._handle && stream.isTTY && typeof stream._handle.setBlocking === "function") {
          stream._handle.setBlocking(blocking);
        }
      });
    };
  }
});

// node_modules/cliui/node_modules/wrap-ansi/index.js
var require_wrap_ansi2 = __commonJS({
  "node_modules/cliui/node_modules/wrap-ansi/index.js"(exports2, module2) {
    "use strict";
    var stringWidth2 = require_string_width();
    var stripAnsi2 = require_strip_ansi();
    var ansiStyles = require_ansi_styles();
    var ESCAPES = /* @__PURE__ */ new Set([
      "\x1B",
      "\x9B"
    ]);
    var END_CODE = 39;
    var wrapAnsi2 = /* @__PURE__ */ __name((code) => `${ESCAPES.values().next().value}[${code}m`, "wrapAnsi");
    var wordLengths = /* @__PURE__ */ __name((string) => string.split(" ").map((character) => stringWidth2(character)), "wordLengths");
    var wrapWord = /* @__PURE__ */ __name((rows, word, columns) => {
      const characters = [...word];
      let isInsideEscape = false;
      let visible = stringWidth2(stripAnsi2(rows[rows.length - 1]));
      for (const [index, character] of characters.entries()) {
        const characterLength = stringWidth2(character);
        if (visible + characterLength <= columns) {
          rows[rows.length - 1] += character;
        } else {
          rows.push(character);
          visible = 0;
        }
        if (ESCAPES.has(character)) {
          isInsideEscape = true;
        } else if (isInsideEscape && character === "m") {
          isInsideEscape = false;
          continue;
        }
        if (isInsideEscape) {
          continue;
        }
        visible += characterLength;
        if (visible === columns && index < characters.length - 1) {
          rows.push("");
          visible = 0;
        }
      }
      if (!visible && rows[rows.length - 1].length > 0 && rows.length > 1) {
        rows[rows.length - 2] += rows.pop();
      }
    }, "wrapWord");
    var stringVisibleTrimSpacesRight = /* @__PURE__ */ __name((str) => {
      const words = str.split(" ");
      let last = words.length;
      while (last > 0) {
        if (stringWidth2(words[last - 1]) > 0) {
          break;
        }
        last--;
      }
      if (last === words.length) {
        return str;
      }
      return words.slice(0, last).join(" ") + words.slice(last).join("");
    }, "stringVisibleTrimSpacesRight");
    var exec5 = /* @__PURE__ */ __name((string, columns, options = {}) => {
      if (options.trim !== false && string.trim() === "") {
        return "";
      }
      let pre = "";
      let ret = "";
      let escapeCode;
      const lengths = wordLengths(string);
      let rows = [""];
      for (const [index, word] of string.split(" ").entries()) {
        if (options.trim !== false) {
          rows[rows.length - 1] = rows[rows.length - 1].trimLeft();
        }
        let rowLength = stringWidth2(rows[rows.length - 1]);
        if (index !== 0) {
          if (rowLength >= columns && (options.wordWrap === false || options.trim === false)) {
            rows.push("");
            rowLength = 0;
          }
          if (rowLength > 0 || options.trim === false) {
            rows[rows.length - 1] += " ";
            rowLength++;
          }
        }
        if (options.hard && lengths[index] > columns) {
          const remainingColumns = columns - rowLength;
          const breaksStartingThisLine = 1 + Math.floor((lengths[index] - remainingColumns - 1) / columns);
          const breaksStartingNextLine = Math.floor((lengths[index] - 1) / columns);
          if (breaksStartingNextLine < breaksStartingThisLine) {
            rows.push("");
          }
          wrapWord(rows, word, columns);
          continue;
        }
        if (rowLength + lengths[index] > columns && rowLength > 0 && lengths[index] > 0) {
          if (options.wordWrap === false && rowLength < columns) {
            wrapWord(rows, word, columns);
            continue;
          }
          rows.push("");
        }
        if (rowLength + lengths[index] > columns && options.wordWrap === false) {
          wrapWord(rows, word, columns);
          continue;
        }
        rows[rows.length - 1] += word;
      }
      if (options.trim !== false) {
        rows = rows.map(stringVisibleTrimSpacesRight);
      }
      pre = rows.join("\n");
      for (const [index, character] of [...pre].entries()) {
        ret += character;
        if (ESCAPES.has(character)) {
          const code2 = parseFloat(/\d[^m]*/.exec(pre.slice(index, index + 4)));
          escapeCode = code2 === END_CODE ? null : code2;
        }
        const code = ansiStyles.codes.get(Number(escapeCode));
        if (escapeCode && code) {
          if (pre[index + 1] === "\n") {
            ret += wrapAnsi2(code);
          } else if (character === "\n") {
            ret += wrapAnsi2(escapeCode);
          }
        }
      }
      return ret;
    }, "exec");
    module2.exports = (string, columns, options) => {
      return String(string).normalize().replace(/\r\n/g, "\n").split("\n").map((line) => exec5(line, columns, options)).join("\n");
    };
  }
});

// node_modules/cliui/index.js
var require_cliui = __commonJS({
  "node_modules/cliui/index.js"(exports2, module2) {
    "use strict";
    var stringWidth2 = require_string_width();
    var stripAnsi2 = require_strip_ansi();
    var wrap = require_wrap_ansi2();
    var align = {
      right: alignRight,
      center: alignCenter
    };
    var top = 0;
    var right = 1;
    var bottom = 2;
    var left = 3;
    var UI = class {
      static {
        __name(this, "UI");
      }
      constructor(opts) {
        this.width = opts.width;
        this.wrap = opts.wrap;
        this.rows = [];
      }
      span(...args) {
        const cols = this.div(...args);
        cols.span = true;
      }
      resetOutput() {
        this.rows = [];
      }
      div(...args) {
        if (args.length === 0) {
          this.div("");
        }
        if (this.wrap && this._shouldApplyLayoutDSL(...args)) {
          return this._applyLayoutDSL(args[0]);
        }
        const cols = args.map((arg) => {
          if (typeof arg === "string") {
            return this._colFromString(arg);
          }
          return arg;
        });
        this.rows.push(cols);
        return cols;
      }
      _shouldApplyLayoutDSL(...args) {
        return args.length === 1 && typeof args[0] === "string" && /[\t\n]/.test(args[0]);
      }
      _applyLayoutDSL(str) {
        const rows = str.split("\n").map((row) => row.split("	"));
        let leftColumnWidth = 0;
        rows.forEach((columns) => {
          if (columns.length > 1 && stringWidth2(columns[0]) > leftColumnWidth) {
            leftColumnWidth = Math.min(
              Math.floor(this.width * 0.5),
              stringWidth2(columns[0])
            );
          }
        });
        rows.forEach((columns) => {
          this.div(...columns.map((r32, i32) => {
            return {
              text: r32.trim(),
              padding: this._measurePadding(r32),
              width: i32 === 0 && columns.length > 1 ? leftColumnWidth : void 0
            };
          }));
        });
        return this.rows[this.rows.length - 1];
      }
      _colFromString(text) {
        return {
          text,
          padding: this._measurePadding(text)
        };
      }
      _measurePadding(str) {
        const noAnsi = stripAnsi2(str);
        return [0, noAnsi.match(/\s*$/)[0].length, 0, noAnsi.match(/^\s*/)[0].length];
      }
      toString() {
        const lines = [];
        this.rows.forEach((row) => {
          this.rowToString(row, lines);
        });
        return lines.filter((line) => !line.hidden).map((line) => line.text).join("\n");
      }
      rowToString(row, lines) {
        this._rasterize(row).forEach((rrow, r32) => {
          let str = "";
          rrow.forEach((col, c32) => {
            const { width } = row[c32];
            const wrapWidth = this._negatePadding(row[c32]);
            let ts = col;
            if (wrapWidth > stringWidth2(col)) {
              ts += " ".repeat(wrapWidth - stringWidth2(col));
            }
            if (row[c32].align && row[c32].align !== "left" && this.wrap) {
              ts = align[row[c32].align](ts, wrapWidth);
              if (stringWidth2(ts) < wrapWidth) {
                ts += " ".repeat(width - stringWidth2(ts) - 1);
              }
            }
            const padding = row[c32].padding || [0, 0, 0, 0];
            if (padding[left]) {
              str += " ".repeat(padding[left]);
            }
            str += addBorder(row[c32], ts, "| ");
            str += ts;
            str += addBorder(row[c32], ts, " |");
            if (padding[right]) {
              str += " ".repeat(padding[right]);
            }
            if (r32 === 0 && lines.length > 0) {
              str = this._renderInline(str, lines[lines.length - 1]);
            }
          });
          lines.push({
            text: str.replace(/ +$/, ""),
            span: row.span
          });
        });
        return lines;
      }
      // if the full 'source' can render in
      // the target line, do so.
      _renderInline(source, previousLine) {
        const leadingWhitespace = source.match(/^ */)[0].length;
        const target = previousLine.text;
        const targetTextWidth = stringWidth2(target.trimRight());
        if (!previousLine.span) {
          return source;
        }
        if (!this.wrap) {
          previousLine.hidden = true;
          return target + source;
        }
        if (leadingWhitespace < targetTextWidth) {
          return source;
        }
        previousLine.hidden = true;
        return target.trimRight() + " ".repeat(leadingWhitespace - targetTextWidth) + source.trimLeft();
      }
      _rasterize(row) {
        const rrows = [];
        const widths = this._columnWidths(row);
        let wrapped;
        row.forEach((col, c32) => {
          col.width = widths[c32];
          if (this.wrap) {
            wrapped = wrap(col.text, this._negatePadding(col), { hard: true }).split("\n");
          } else {
            wrapped = col.text.split("\n");
          }
          if (col.border) {
            wrapped.unshift("." + "-".repeat(this._negatePadding(col) + 2) + ".");
            wrapped.push("'" + "-".repeat(this._negatePadding(col) + 2) + "'");
          }
          if (col.padding) {
            wrapped.unshift(...new Array(col.padding[top] || 0).fill(""));
            wrapped.push(...new Array(col.padding[bottom] || 0).fill(""));
          }
          wrapped.forEach((str, r32) => {
            if (!rrows[r32]) {
              rrows.push([]);
            }
            const rrow = rrows[r32];
            for (let i32 = 0; i32 < c32; i32++) {
              if (rrow[i32] === void 0) {
                rrow.push("");
              }
            }
            rrow.push(str);
          });
        });
        return rrows;
      }
      _negatePadding(col) {
        let wrapWidth = col.width;
        if (col.padding) {
          wrapWidth -= (col.padding[left] || 0) + (col.padding[right] || 0);
        }
        if (col.border) {
          wrapWidth -= 4;
        }
        return wrapWidth;
      }
      _columnWidths(row) {
        if (!this.wrap) {
          return row.map((col) => {
            return col.width || stringWidth2(col.text);
          });
        }
        let unset = row.length;
        let remainingWidth = this.width;
        const widths = row.map((col) => {
          if (col.width) {
            unset--;
            remainingWidth -= col.width;
            return col.width;
          }
          return void 0;
        });
        const unsetWidth = unset ? Math.floor(remainingWidth / unset) : 0;
        return widths.map((w, i32) => {
          if (w === void 0) {
            return Math.max(unsetWidth, _minWidth(row[i32]));
          }
          return w;
        });
      }
    };
    function addBorder(col, ts, style) {
      if (col.border) {
        if (/[.']-+[.']/.test(ts)) {
          return "";
        }
        if (ts.trim().length !== 0) {
          return style;
        }
        return "  ";
      }
      return "";
    }
    __name(addBorder, "addBorder");
    function _minWidth(col) {
      const padding = col.padding || [];
      const minWidth = 1 + (padding[left] || 0) + (padding[right] || 0);
      if (col.border) {
        return minWidth + 4;
      }
      return minWidth;
    }
    __name(_minWidth, "_minWidth");
    function getWindowWidth() {
      if (typeof process === "object" && process.stdout && process.stdout.columns) {
        return process.stdout.columns;
      }
    }
    __name(getWindowWidth, "getWindowWidth");
    function alignRight(str, width) {
      str = str.trim();
      const strWidth = stringWidth2(str);
      if (strWidth < width) {
        return " ".repeat(width - strWidth) + str;
      }
      return str;
    }
    __name(alignRight, "alignRight");
    function alignCenter(str, width) {
      str = str.trim();
      const strWidth = stringWidth2(str);
      if (strWidth >= width) {
        return str;
      }
      return " ".repeat(width - strWidth >> 1) + str;
    }
    __name(alignCenter, "alignCenter");
    module2.exports = function(opts = {}) {
      return new UI({
        width: opts.width || getWindowWidth() || /* istanbul ignore next */
        80,
        wrap: opts.wrap !== false
      });
    };
  }
});

// node_modules/yargs/build/lib/usage.js
var require_usage = __commonJS({
  "node_modules/yargs/build/lib/usage.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.usage = void 0;
    var common_types_1 = require_common_types();
    var obj_filter_1 = require_obj_filter();
    var path47 = require("path");
    var yerror_1 = require_yerror();
    var decamelize3 = require_decamelize3();
    var setBlocking = require_set_blocking();
    var stringWidth2 = require_string_width();
    function usage(yargs2, y18n) {
      const __ = y18n.__;
      const self2 = {};
      const fails = [];
      self2.failFn = /* @__PURE__ */ __name(function failFn(f32) {
        fails.push(f32);
      }, "failFn");
      let failMessage = null;
      let showHelpOnFail = true;
      self2.showHelpOnFail = /* @__PURE__ */ __name(function showHelpOnFailFn(arg1 = true, arg2) {
        function parseFunctionArgs() {
          return typeof arg1 === "string" ? [true, arg1] : [arg1, arg2];
        }
        __name(parseFunctionArgs, "parseFunctionArgs");
        const [enabled, message2] = parseFunctionArgs();
        failMessage = message2;
        showHelpOnFail = enabled;
        return self2;
      }, "showHelpOnFailFn");
      let failureOutput = false;
      self2.fail = /* @__PURE__ */ __name(function fail(msg, err) {
        const logger5 = yargs2._getLoggerInstance();
        if (fails.length) {
          for (let i32 = fails.length - 1; i32 >= 0; --i32) {
            fails[i32](msg, err, self2);
          }
        } else {
          if (yargs2.getExitProcess())
            setBlocking(true);
          if (!failureOutput) {
            failureOutput = true;
            if (showHelpOnFail) {
              yargs2.showHelp("error");
              logger5.error();
            }
            if (msg || err)
              logger5.error(msg || err);
            if (failMessage) {
              if (msg || err)
                logger5.error("");
              logger5.error(failMessage);
            }
          }
          err = err || new yerror_1.YError(msg);
          if (yargs2.getExitProcess()) {
            return yargs2.exit(1);
          } else if (yargs2._hasParseCallback()) {
            return yargs2.exit(1, err);
          } else {
            throw err;
          }
        }
      }, "fail");
      let usages = [];
      let usageDisabled = false;
      self2.usage = (msg, description) => {
        if (msg === null) {
          usageDisabled = true;
          usages = [];
          return self2;
        }
        usageDisabled = false;
        usages.push([msg, description || ""]);
        return self2;
      };
      self2.getUsage = () => {
        return usages;
      };
      self2.getUsageDisabled = () => {
        return usageDisabled;
      };
      self2.getPositionalGroupName = () => {
        return __("Positionals:");
      };
      let examples = [];
      self2.example = (cmd, description) => {
        examples.push([cmd, description || ""]);
      };
      let commands32 = [];
      self2.command = /* @__PURE__ */ __name(function command(cmd, description, isDefault, aliases, deprecated = false) {
        if (isDefault) {
          commands32 = commands32.map((cmdArray) => {
            cmdArray[2] = false;
            return cmdArray;
          });
        }
        commands32.push([cmd, description || "", isDefault, aliases, deprecated]);
      }, "command");
      self2.getCommands = () => commands32;
      let descriptions = {};
      self2.describe = /* @__PURE__ */ __name(function describe(keyOrKeys, desc) {
        if (Array.isArray(keyOrKeys)) {
          keyOrKeys.forEach((k32) => {
            self2.describe(k32, desc);
          });
        } else if (typeof keyOrKeys === "object") {
          Object.keys(keyOrKeys).forEach((k32) => {
            self2.describe(k32, keyOrKeys[k32]);
          });
        } else {
          descriptions[keyOrKeys] = desc;
        }
      }, "describe");
      self2.getDescriptions = () => descriptions;
      let epilogs = [];
      self2.epilog = (msg) => {
        epilogs.push(msg);
      };
      let wrapSet = false;
      let wrap;
      self2.wrap = (cols) => {
        wrapSet = true;
        wrap = cols;
      };
      function getWrap() {
        if (!wrapSet) {
          wrap = windowWidth();
          wrapSet = true;
        }
        return wrap;
      }
      __name(getWrap, "getWrap");
      const deferY18nLookupPrefix = "__yargsString__:";
      self2.deferY18nLookup = (str) => deferY18nLookupPrefix + str;
      self2.help = /* @__PURE__ */ __name(function help() {
        if (cachedHelpMessage)
          return cachedHelpMessage;
        normalizeAliases();
        const base$0 = yargs2.customScriptName ? yargs2.$0 : path47.basename(yargs2.$0);
        const demandedOptions = yargs2.getDemandedOptions();
        const demandedCommands = yargs2.getDemandedCommands();
        const deprecatedOptions = yargs2.getDeprecatedOptions();
        const groups = yargs2.getGroups();
        const options = yargs2.getOptions();
        let keys = [];
        keys = keys.concat(Object.keys(descriptions));
        keys = keys.concat(Object.keys(demandedOptions));
        keys = keys.concat(Object.keys(demandedCommands));
        keys = keys.concat(Object.keys(options.default));
        keys = keys.filter(filterHiddenOptions);
        keys = Object.keys(keys.reduce((acc, key) => {
          if (key !== "_")
            acc[key] = true;
          return acc;
        }, {}));
        const theWrap = getWrap();
        const ui = require_cliui()({
          width: theWrap,
          wrap: !!theWrap
        });
        if (!usageDisabled) {
          if (usages.length) {
            usages.forEach((usage2) => {
              ui.div(`${usage2[0].replace(/\$0/g, base$0)}`);
              if (usage2[1]) {
                ui.div({ text: `${usage2[1]}`, padding: [1, 0, 0, 0] });
              }
            });
            ui.div();
          } else if (commands32.length) {
            let u = null;
            if (demandedCommands._) {
              u = `${base$0} <${__("command")}>
`;
            } else {
              u = `${base$0} [${__("command")}]
`;
            }
            ui.div(`${u}`);
          }
        }
        if (commands32.length) {
          ui.div(__("Commands:"));
          const context = yargs2.getContext();
          const parentCommands = context.commands.length ? `${context.commands.join(" ")} ` : "";
          if (yargs2.getParserConfiguration()["sort-commands"] === true) {
            commands32 = commands32.sort((a32, b32) => a32[0].localeCompare(b32[0]));
          }
          commands32.forEach((command) => {
            const commandString = `${base$0} ${parentCommands}${command[0].replace(/^\$0 ?/, "")}`;
            ui.span({
              text: commandString,
              padding: [0, 2, 0, 2],
              width: maxWidth(commands32, theWrap, `${base$0}${parentCommands}`) + 4
            }, { text: command[1] });
            const hints = [];
            if (command[2])
              hints.push(`[${__("default")}]`);
            if (command[3] && command[3].length) {
              hints.push(`[${__("aliases:")} ${command[3].join(", ")}]`);
            }
            if (command[4]) {
              if (typeof command[4] === "string") {
                hints.push(`[${__("deprecated: %s", command[4])}]`);
              } else {
                hints.push(`[${__("deprecated")}]`);
              }
            }
            if (hints.length) {
              ui.div({ text: hints.join(" "), padding: [0, 0, 0, 2], align: "right" });
            } else {
              ui.div();
            }
          });
          ui.div();
        }
        const aliasKeys = (Object.keys(options.alias) || []).concat(Object.keys(yargs2.parsed.newAliases) || []);
        keys = keys.filter((key) => !yargs2.parsed.newAliases[key] && aliasKeys.every((alias) => (options.alias[alias] || []).indexOf(key) === -1));
        const defaultGroup = __("Options:");
        if (!groups[defaultGroup])
          groups[defaultGroup] = [];
        addUngroupedKeys(keys, options.alias, groups, defaultGroup);
        Object.keys(groups).forEach((groupName) => {
          if (!groups[groupName].length)
            return;
          const normalizedKeys = groups[groupName].filter(filterHiddenOptions).map((key) => {
            if (~aliasKeys.indexOf(key))
              return key;
            for (let i32 = 0, aliasKey; (aliasKey = aliasKeys[i32]) !== void 0; i32++) {
              if (~(options.alias[aliasKey] || []).indexOf(key))
                return aliasKey;
            }
            return key;
          });
          if (normalizedKeys.length < 1)
            return;
          ui.div(groupName);
          const switches = normalizedKeys.reduce((acc, key) => {
            acc[key] = [key].concat(options.alias[key] || []).map((sw) => {
              if (groupName === self2.getPositionalGroupName())
                return sw;
              else {
                return (
                  // matches yargs-parser logic in which single-digits
                  // aliases declared with a boolean type are now valid
                  (/^[0-9]$/.test(sw) ? ~options.boolean.indexOf(key) ? "-" : "--" : sw.length > 1 ? "--" : "-") + sw
                );
              }
            }).join(", ");
            return acc;
          }, {});
          normalizedKeys.forEach((key) => {
            const kswitch = switches[key];
            let desc = descriptions[key] || "";
            let type = null;
            if (~desc.lastIndexOf(deferY18nLookupPrefix))
              desc = __(desc.substring(deferY18nLookupPrefix.length));
            if (~options.boolean.indexOf(key))
              type = `[${__("boolean")}]`;
            if (~options.count.indexOf(key))
              type = `[${__("count")}]`;
            if (~options.string.indexOf(key))
              type = `[${__("string")}]`;
            if (~options.normalize.indexOf(key))
              type = `[${__("string")}]`;
            if (~options.array.indexOf(key))
              type = `[${__("array")}]`;
            if (~options.number.indexOf(key))
              type = `[${__("number")}]`;
            const deprecatedExtra = /* @__PURE__ */ __name((deprecated) => typeof deprecated === "string" ? `[${__("deprecated: %s", deprecated)}]` : `[${__("deprecated")}]`, "deprecatedExtra");
            const extra = [
              key in deprecatedOptions ? deprecatedExtra(deprecatedOptions[key]) : null,
              type,
              key in demandedOptions ? `[${__("required")}]` : null,
              options.choices && options.choices[key] ? `[${__("choices:")} ${self2.stringifiedValues(options.choices[key])}]` : null,
              defaultString(options.default[key], options.defaultDescription[key])
            ].filter(Boolean).join(" ");
            ui.span({ text: kswitch, padding: [0, 2, 0, 2], width: maxWidth(switches, theWrap) + 4 }, desc);
            if (extra)
              ui.div({ text: extra, padding: [0, 0, 0, 2], align: "right" });
            else
              ui.div();
          });
          ui.div();
        });
        if (examples.length) {
          ui.div(__("Examples:"));
          examples.forEach((example) => {
            example[0] = example[0].replace(/\$0/g, base$0);
          });
          examples.forEach((example) => {
            if (example[1] === "") {
              ui.div({
                text: example[0],
                padding: [0, 2, 0, 2]
              });
            } else {
              ui.div({
                text: example[0],
                padding: [0, 2, 0, 2],
                width: maxWidth(examples, theWrap) + 4
              }, {
                text: example[1]
              });
            }
          });
          ui.div();
        }
        if (epilogs.length > 0) {
          const e32 = epilogs.map((epilog) => epilog.replace(/\$0/g, base$0)).join("\n");
          ui.div(`${e32}
`);
        }
        return ui.toString().replace(/\s*$/, "");
      }, "help");
      function maxWidth(table3, theWrap, modifier) {
        let width = 0;
        if (!Array.isArray(table3)) {
          table3 = Object.values(table3).map((v) => [v]);
        }
        table3.forEach((v) => {
          width = Math.max(stringWidth2(modifier ? `${modifier} ${v[0]}` : v[0]), width);
        });
        if (theWrap)
          width = Math.min(width, parseInt((theWrap * 0.5).toString(), 10));
        return width;
      }
      __name(maxWidth, "maxWidth");
      function normalizeAliases() {
        const demandedOptions = yargs2.getDemandedOptions();
        const options = yargs2.getOptions();
        (Object.keys(options.alias) || []).forEach((key) => {
          options.alias[key].forEach((alias) => {
            if (descriptions[alias])
              self2.describe(key, descriptions[alias]);
            if (alias in demandedOptions)
              yargs2.demandOption(key, demandedOptions[alias]);
            if (~options.boolean.indexOf(alias))
              yargs2.boolean(key);
            if (~options.count.indexOf(alias))
              yargs2.count(key);
            if (~options.string.indexOf(alias))
              yargs2.string(key);
            if (~options.normalize.indexOf(alias))
              yargs2.normalize(key);
            if (~options.array.indexOf(alias))
              yargs2.array(key);
            if (~options.number.indexOf(alias))
              yargs2.number(key);
          });
        });
      }
      __name(normalizeAliases, "normalizeAliases");
      let cachedHelpMessage;
      self2.cacheHelpMessage = function() {
        cachedHelpMessage = this.help();
      };
      self2.clearCachedHelpMessage = function() {
        cachedHelpMessage = void 0;
      };
      function addUngroupedKeys(keys, aliases, groups, defaultGroup) {
        let groupedKeys = [];
        let toCheck = null;
        Object.keys(groups).forEach((group7) => {
          groupedKeys = groupedKeys.concat(groups[group7]);
        });
        keys.forEach((key) => {
          toCheck = [key].concat(aliases[key]);
          if (!toCheck.some((k32) => groupedKeys.indexOf(k32) !== -1)) {
            groups[defaultGroup].push(key);
          }
        });
        return groupedKeys;
      }
      __name(addUngroupedKeys, "addUngroupedKeys");
      function filterHiddenOptions(key) {
        return yargs2.getOptions().hiddenOptions.indexOf(key) < 0 || yargs2.parsed.argv[yargs2.getOptions().showHiddenOpt];
      }
      __name(filterHiddenOptions, "filterHiddenOptions");
      self2.showHelp = (level) => {
        const logger5 = yargs2._getLoggerInstance();
        if (!level)
          level = "error";
        const emit = typeof level === "function" ? level : logger5[level];
        emit(self2.help());
      };
      self2.functionDescription = (fn) => {
        const description = fn.name ? decamelize3(fn.name, "-") : __("generated-value");
        return ["(", description, ")"].join("");
      };
      self2.stringifiedValues = /* @__PURE__ */ __name(function stringifiedValues(values, separator) {
        let string = "";
        const sep7 = separator || ", ";
        const array = [].concat(values);
        if (!values || !array.length)
          return string;
        array.forEach((value) => {
          if (string.length)
            string += sep7;
          string += JSON.stringify(value);
        });
        return string;
      }, "stringifiedValues");
      function defaultString(value, defaultDescription) {
        let string = `[${__("default:")} `;
        if (value === void 0 && !defaultDescription)
          return null;
        if (defaultDescription) {
          string += defaultDescription;
        } else {
          switch (typeof value) {
            case "string":
              string += `"${value}"`;
              break;
            case "object":
              string += JSON.stringify(value);
              break;
            default:
              string += value;
          }
        }
        return `${string}]`;
      }
      __name(defaultString, "defaultString");
      function windowWidth() {
        const maxWidth2 = 80;
        if (typeof process === "object" && process.stdout && process.stdout.columns) {
          return Math.min(maxWidth2, process.stdout.columns);
        } else {
          return maxWidth2;
        }
      }
      __name(windowWidth, "windowWidth");
      let version = null;
      self2.version = (ver) => {
        version = ver;
      };
      self2.showVersion = () => {
        const logger5 = yargs2._getLoggerInstance();
        logger5.log(version);
      };
      self2.reset = /* @__PURE__ */ __name(function reset6(localLookup) {
        failMessage = null;
        failureOutput = false;
        usages = [];
        usageDisabled = false;
        epilogs = [];
        examples = [];
        commands32 = [];
        descriptions = obj_filter_1.objFilter(descriptions, (k32) => !localLookup[k32]);
        return self2;
      }, "reset");
      const frozens = [];
      self2.freeze = /* @__PURE__ */ __name(function freeze() {
        frozens.push({
          failMessage,
          failureOutput,
          usages,
          usageDisabled,
          epilogs,
          examples,
          commands: commands32,
          descriptions
        });
      }, "freeze");
      self2.unfreeze = /* @__PURE__ */ __name(function unfreeze() {
        const frozen = frozens.pop();
        common_types_1.assertNotStrictEqual(frozen, void 0);
        ({
          failMessage,
          failureOutput,
          usages,
          usageDisabled,
          epilogs,
          examples,
          commands: commands32,
          descriptions
        } = frozen);
      }, "unfreeze");
      return self2;
    }
    __name(usage, "usage");
    exports2.usage = usage;
  }
});

// node_modules/yargs/build/lib/completion-templates.js
var require_completion_templates = __commonJS({
  "node_modules/yargs/build/lib/completion-templates.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.completionZshTemplate = exports2.completionShTemplate = void 0;
    exports2.completionShTemplate = `###-begin-{{app_name}}-completions-###
#
# yargs command completion script
#
# Installation: {{app_path}} {{completion_command}} >> ~/.bashrc
#    or {{app_path}} {{completion_command}} >> ~/.bash_profile on OSX.
#
_yargs_completions()
{
    local cur_word args type_list

    cur_word="\${COMP_WORDS[COMP_CWORD]}"
    args=("\${COMP_WORDS[@]}")

    # ask yargs to generate completions.
    type_list=$({{app_path}} --get-yargs-completions "\${args[@]}")

    COMPREPLY=( $(compgen -W "\${type_list}" -- \${cur_word}) )

    # if no match was found, fall back to filename completion
    if [ \${#COMPREPLY[@]} -eq 0 ]; then
      COMPREPLY=()
    fi

    return 0
}
complete -o default -F _yargs_completions {{app_name}}
###-end-{{app_name}}-completions-###
`;
    exports2.completionZshTemplate = `###-begin-{{app_name}}-completions-###
#
# yargs command completion script
#
# Installation: {{app_path}} {{completion_command}} >> ~/.zshrc
#    or {{app_path}} {{completion_command}} >> ~/.zsh_profile on OSX.
#
_{{app_name}}_yargs_completions()
{
  local reply
  local si=$IFS
  IFS=$'
' reply=($(COMP_CWORD="$((CURRENT-1))" COMP_LINE="$BUFFER" COMP_POINT="$CURSOR" {{app_path}} --get-yargs-completions "\${words[@]}"))
  IFS=$si
  _describe 'values' reply
}
compdef _{{app_name}}_yargs_completions {{app_name}}
###-end-{{app_name}}-completions-###
`;
  }
});

// node_modules/yargs/build/lib/completion.js
var require_completion = __commonJS({
  "node_modules/yargs/build/lib/completion.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.completion = void 0;
    var command_1 = require_command();
    var templates = require_completion_templates();
    var is_promise_1 = require_is_promise();
    var parse_command_1 = require_parse_command();
    var path47 = require("path");
    var common_types_1 = require_common_types();
    function completion(yargs2, usage, command) {
      const self2 = {
        completionKey: "get-yargs-completions"
      };
      let aliases;
      self2.setParsed = /* @__PURE__ */ __name(function setParsed(parsed) {
        aliases = parsed.aliases;
      }, "setParsed");
      const zshShell = process.env.SHELL && process.env.SHELL.indexOf("zsh") !== -1 || process.env.ZSH_NAME && process.env.ZSH_NAME.indexOf("zsh") !== -1;
      self2.getCompletion = /* @__PURE__ */ __name(function getCompletion(args, done) {
        const completions = [];
        const current = args.length ? args[args.length - 1] : "";
        const argv = yargs2.parse(args, true);
        const parentCommands = yargs2.getContext().commands;
        function runCompletionFunction(argv2) {
          common_types_1.assertNotStrictEqual(completionFunction, null);
          if (isSyncCompletionFunction(completionFunction)) {
            const result2 = completionFunction(current, argv2);
            if (is_promise_1.isPromise(result2)) {
              return result2.then((list3) => {
                process.nextTick(() => {
                  done(list3);
                });
              }).catch((err) => {
                process.nextTick(() => {
                  throw err;
                });
              });
            }
            return done(result2);
          } else {
            return completionFunction(current, argv2, (completions2) => {
              done(completions2);
            });
          }
        }
        __name(runCompletionFunction, "runCompletionFunction");
        if (completionFunction) {
          return is_promise_1.isPromise(argv) ? argv.then(runCompletionFunction) : runCompletionFunction(argv);
        }
        const handlers = command.getCommandHandlers();
        for (let i32 = 0, ii = args.length; i32 < ii; ++i32) {
          if (handlers[args[i32]] && handlers[args[i32]].builder) {
            const builder = handlers[args[i32]].builder;
            if (command_1.isCommandBuilderCallback(builder)) {
              const y = yargs2.reset();
              builder(y);
              return y.argv;
            }
          }
        }
        if (!current.match(/^-/) && parentCommands[parentCommands.length - 1] !== current) {
          usage.getCommands().forEach((usageCommand) => {
            const commandName = parse_command_1.parseCommand(usageCommand[0]).cmd;
            if (args.indexOf(commandName) === -1) {
              if (!zshShell) {
                completions.push(commandName);
              } else {
                const desc = usageCommand[1] || "";
                completions.push(commandName.replace(/:/g, "\\:") + ":" + desc);
              }
            }
          });
        }
        if (current.match(/^-/) || current === "" && completions.length === 0) {
          const descs = usage.getDescriptions();
          const options = yargs2.getOptions();
          Object.keys(options.key).forEach((key) => {
            const negable = !!options.configuration["boolean-negation"] && options.boolean.includes(key);
            let keyAndAliases = [key].concat(aliases[key] || []);
            if (negable)
              keyAndAliases = keyAndAliases.concat(keyAndAliases.map((key2) => `no-${key2}`));
            function completeOptionKey(key2) {
              const notInArgs = keyAndAliases.every((val) => args.indexOf(`--${val}`) === -1);
              if (notInArgs) {
                const startsByTwoDashes = /* @__PURE__ */ __name((s) => /^--/.test(s), "startsByTwoDashes");
                const isShortOption = /* @__PURE__ */ __name((s) => /^[^0-9]$/.test(s), "isShortOption");
                const dashes = !startsByTwoDashes(current) && isShortOption(key2) ? "-" : "--";
                if (!zshShell) {
                  completions.push(dashes + key2);
                } else {
                  const desc = descs[key2] || "";
                  completions.push(dashes + `${key2.replace(/:/g, "\\:")}:${desc.replace("__yargsString__:", "")}`);
                }
              }
            }
            __name(completeOptionKey, "completeOptionKey");
            completeOptionKey(key);
            if (negable && !!options.default[key])
              completeOptionKey(`no-${key}`);
          });
        }
        done(completions);
      }, "getCompletion");
      self2.generateCompletionScript = /* @__PURE__ */ __name(function generateCompletionScript($0, cmd) {
        let script = zshShell ? templates.completionZshTemplate : templates.completionShTemplate;
        const name = path47.basename($0);
        if ($0.match(/\.js$/))
          $0 = `./${$0}`;
        script = script.replace(/{{app_name}}/g, name);
        script = script.replace(/{{completion_command}}/g, cmd);
        return script.replace(/{{app_path}}/g, $0);
      }, "generateCompletionScript");
      let completionFunction = null;
      self2.registerFunction = (fn) => {
        completionFunction = fn;
      };
      return self2;
    }
    __name(completion, "completion");
    exports2.completion = completion;
    function isSyncCompletionFunction(completionFunction) {
      return completionFunction.length < 3;
    }
    __name(isSyncCompletionFunction, "isSyncCompletionFunction");
  }
});

// node_modules/yargs/build/lib/levenshtein.js
var require_levenshtein = __commonJS({
  "node_modules/yargs/build/lib/levenshtein.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.levenshtein = void 0;
    function levenshtein(a32, b32) {
      if (a32.length === 0)
        return b32.length;
      if (b32.length === 0)
        return a32.length;
      const matrix = [];
      let i32;
      for (i32 = 0; i32 <= b32.length; i32++) {
        matrix[i32] = [i32];
      }
      let j32;
      for (j32 = 0; j32 <= a32.length; j32++) {
        matrix[0][j32] = j32;
      }
      for (i32 = 1; i32 <= b32.length; i32++) {
        for (j32 = 1; j32 <= a32.length; j32++) {
          if (b32.charAt(i32 - 1) === a32.charAt(j32 - 1)) {
            matrix[i32][j32] = matrix[i32 - 1][j32 - 1];
          } else {
            matrix[i32][j32] = Math.min(
              matrix[i32 - 1][j32 - 1] + 1,
              // substitution
              Math.min(
                matrix[i32][j32 - 1] + 1,
                // insertion
                matrix[i32 - 1][j32] + 1
              )
            );
          }
        }
      }
      return matrix[b32.length][a32.length];
    }
    __name(levenshtein, "levenshtein");
    exports2.levenshtein = levenshtein;
  }
});

// node_modules/yargs/build/lib/validation.js
var require_validation = __commonJS({
  "node_modules/yargs/build/lib/validation.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.validation = void 0;
    var argsert_1 = require_argsert();
    var common_types_1 = require_common_types();
    var levenshtein_1 = require_levenshtein();
    var obj_filter_1 = require_obj_filter();
    var specialKeys = ["$0", "--", "_"];
    function validation(yargs2, usage, y18n) {
      const __ = y18n.__;
      const __n = y18n.__n;
      const self2 = {};
      self2.nonOptionCount = /* @__PURE__ */ __name(function nonOptionCount(argv) {
        const demandedCommands = yargs2.getDemandedCommands();
        const _s32 = argv._.length - yargs2.getContext().commands.length;
        if (demandedCommands._ && (_s32 < demandedCommands._.min || _s32 > demandedCommands._.max)) {
          if (_s32 < demandedCommands._.min) {
            if (demandedCommands._.minMsg !== void 0) {
              usage.fail(
                // replace $0 with observed, $1 with expected.
                demandedCommands._.minMsg ? demandedCommands._.minMsg.replace(/\$0/g, _s32.toString()).replace(/\$1/, demandedCommands._.min.toString()) : null
              );
            } else {
              usage.fail(__n("Not enough non-option arguments: got %s, need at least %s", "Not enough non-option arguments: got %s, need at least %s", _s32, _s32, demandedCommands._.min));
            }
          } else if (_s32 > demandedCommands._.max) {
            if (demandedCommands._.maxMsg !== void 0) {
              usage.fail(
                // replace $0 with observed, $1 with expected.
                demandedCommands._.maxMsg ? demandedCommands._.maxMsg.replace(/\$0/g, _s32.toString()).replace(/\$1/, demandedCommands._.max.toString()) : null
              );
            } else {
              usage.fail(__n("Too many non-option arguments: got %s, maximum of %s", "Too many non-option arguments: got %s, maximum of %s", _s32, _s32, demandedCommands._.max));
            }
          }
        }
      }, "nonOptionCount");
      self2.positionalCount = /* @__PURE__ */ __name(function positionalCount(required, observed) {
        if (observed < required) {
          usage.fail(__n("Not enough non-option arguments: got %s, need at least %s", "Not enough non-option arguments: got %s, need at least %s", observed, observed, required));
        }
      }, "positionalCount");
      self2.requiredArguments = /* @__PURE__ */ __name(function requiredArguments(argv) {
        const demandedOptions = yargs2.getDemandedOptions();
        let missing = null;
        for (const key of Object.keys(demandedOptions)) {
          if (!Object.prototype.hasOwnProperty.call(argv, key) || typeof argv[key] === "undefined") {
            missing = missing || {};
            missing[key] = demandedOptions[key];
          }
        }
        if (missing) {
          const customMsgs = [];
          for (const key of Object.keys(missing)) {
            const msg = missing[key];
            if (msg && customMsgs.indexOf(msg) < 0) {
              customMsgs.push(msg);
            }
          }
          const customMsg = customMsgs.length ? `
${customMsgs.join("\n")}` : "";
          usage.fail(__n("Missing required argument: %s", "Missing required arguments: %s", Object.keys(missing).length, Object.keys(missing).join(", ") + customMsg));
        }
      }, "requiredArguments");
      self2.unknownArguments = /* @__PURE__ */ __name(function unknownArguments(argv, aliases, positionalMap, isDefaultCommand) {
        const commandKeys = yargs2.getCommandInstance().getCommands();
        const unknown = [];
        const currentContext = yargs2.getContext();
        Object.keys(argv).forEach((key) => {
          if (specialKeys.indexOf(key) === -1 && !Object.prototype.hasOwnProperty.call(positionalMap, key) && !Object.prototype.hasOwnProperty.call(yargs2._getParseContext(), key) && !self2.isValidAndSomeAliasIsNotNew(key, aliases)) {
            unknown.push(key);
          }
        });
        if (currentContext.commands.length > 0 || commandKeys.length > 0 || isDefaultCommand) {
          argv._.slice(currentContext.commands.length).forEach((key) => {
            if (commandKeys.indexOf(key) === -1) {
              unknown.push(key);
            }
          });
        }
        if (unknown.length > 0) {
          usage.fail(__n("Unknown argument: %s", "Unknown arguments: %s", unknown.length, unknown.join(", ")));
        }
      }, "unknownArguments");
      self2.unknownCommands = /* @__PURE__ */ __name(function unknownCommands(argv) {
        const commandKeys = yargs2.getCommandInstance().getCommands();
        const unknown = [];
        const currentContext = yargs2.getContext();
        if (currentContext.commands.length > 0 || commandKeys.length > 0) {
          argv._.slice(currentContext.commands.length).forEach((key) => {
            if (commandKeys.indexOf(key) === -1) {
              unknown.push(key);
            }
          });
        }
        if (unknown.length > 0) {
          usage.fail(__n("Unknown command: %s", "Unknown commands: %s", unknown.length, unknown.join(", ")));
          return true;
        } else {
          return false;
        }
      }, "unknownCommands");
      self2.isValidAndSomeAliasIsNotNew = /* @__PURE__ */ __name(function isValidAndSomeAliasIsNotNew(key, aliases) {
        if (!Object.prototype.hasOwnProperty.call(aliases, key)) {
          return false;
        }
        const newAliases = yargs2.parsed.newAliases;
        for (const a32 of [key, ...aliases[key]]) {
          if (!Object.prototype.hasOwnProperty.call(newAliases, a32) || !newAliases[key]) {
            return true;
          }
        }
        return false;
      }, "isValidAndSomeAliasIsNotNew");
      self2.limitedChoices = /* @__PURE__ */ __name(function limitedChoices(argv) {
        const options = yargs2.getOptions();
        const invalid = {};
        if (!Object.keys(options.choices).length)
          return;
        Object.keys(argv).forEach((key) => {
          if (specialKeys.indexOf(key) === -1 && Object.prototype.hasOwnProperty.call(options.choices, key)) {
            [].concat(argv[key]).forEach((value) => {
              if (options.choices[key].indexOf(value) === -1 && value !== void 0) {
                invalid[key] = (invalid[key] || []).concat(value);
              }
            });
          }
        });
        const invalidKeys = Object.keys(invalid);
        if (!invalidKeys.length)
          return;
        let msg = __("Invalid values:");
        invalidKeys.forEach((key) => {
          msg += `
  ${__("Argument: %s, Given: %s, Choices: %s", key, usage.stringifiedValues(invalid[key]), usage.stringifiedValues(options.choices[key]))}`;
        });
        usage.fail(msg);
      }, "limitedChoices");
      let checks = [];
      self2.check = /* @__PURE__ */ __name(function check(f32, global2) {
        checks.push({
          func: f32,
          global: global2
        });
      }, "check");
      self2.customChecks = /* @__PURE__ */ __name(function customChecks(argv, aliases) {
        for (let i32 = 0, f32; (f32 = checks[i32]) !== void 0; i32++) {
          const func = f32.func;
          let result2 = null;
          try {
            result2 = func(argv, aliases);
          } catch (err) {
            usage.fail(err.message ? err.message : err, err);
            continue;
          }
          if (!result2) {
            usage.fail(__("Argument check failed: %s", func.toString()));
          } else if (typeof result2 === "string" || result2 instanceof Error) {
            usage.fail(result2.toString(), result2);
          }
        }
      }, "customChecks");
      let implied = {};
      self2.implies = /* @__PURE__ */ __name(function implies(key, value) {
        argsert_1.argsert("<string|object> [array|number|string]", [key, value], arguments.length);
        if (typeof key === "object") {
          Object.keys(key).forEach((k32) => {
            self2.implies(k32, key[k32]);
          });
        } else {
          yargs2.global(key);
          if (!implied[key]) {
            implied[key] = [];
          }
          if (Array.isArray(value)) {
            value.forEach((i32) => self2.implies(key, i32));
          } else {
            common_types_1.assertNotStrictEqual(value, void 0);
            implied[key].push(value);
          }
        }
      }, "implies");
      self2.getImplied = /* @__PURE__ */ __name(function getImplied() {
        return implied;
      }, "getImplied");
      function keyExists(argv, val) {
        const num = Number(val);
        val = isNaN(num) ? val : num;
        if (typeof val === "number") {
          val = argv._.length >= val;
        } else if (val.match(/^--no-.+/)) {
          val = val.match(/^--no-(.+)/)[1];
          val = !argv[val];
        } else {
          val = argv[val];
        }
        return val;
      }
      __name(keyExists, "keyExists");
      self2.implications = /* @__PURE__ */ __name(function implications(argv) {
        const implyFail = [];
        Object.keys(implied).forEach((key) => {
          const origKey = key;
          (implied[key] || []).forEach((value) => {
            let key2 = origKey;
            const origValue = value;
            key2 = keyExists(argv, key2);
            value = keyExists(argv, value);
            if (key2 && !value) {
              implyFail.push(` ${origKey} -> ${origValue}`);
            }
          });
        });
        if (implyFail.length) {
          let msg = `${__("Implications failed:")}
`;
          implyFail.forEach((value) => {
            msg += value;
          });
          usage.fail(msg);
        }
      }, "implications");
      let conflicting = {};
      self2.conflicts = /* @__PURE__ */ __name(function conflicts(key, value) {
        argsert_1.argsert("<string|object> [array|string]", [key, value], arguments.length);
        if (typeof key === "object") {
          Object.keys(key).forEach((k32) => {
            self2.conflicts(k32, key[k32]);
          });
        } else {
          yargs2.global(key);
          if (!conflicting[key]) {
            conflicting[key] = [];
          }
          if (Array.isArray(value)) {
            value.forEach((i32) => self2.conflicts(key, i32));
          } else {
            conflicting[key].push(value);
          }
        }
      }, "conflicts");
      self2.getConflicting = () => conflicting;
      self2.conflicting = /* @__PURE__ */ __name(function conflictingFn(argv) {
        Object.keys(argv).forEach((key) => {
          if (conflicting[key]) {
            conflicting[key].forEach((value) => {
              if (value && argv[key] !== void 0 && argv[value] !== void 0) {
                usage.fail(__("Arguments %s and %s are mutually exclusive", key, value));
              }
            });
          }
        });
      }, "conflictingFn");
      self2.recommendCommands = /* @__PURE__ */ __name(function recommendCommands(cmd, potentialCommands) {
        const threshold = 3;
        potentialCommands = potentialCommands.sort((a32, b32) => b32.length - a32.length);
        let recommended = null;
        let bestDistance = Infinity;
        for (let i32 = 0, candidate; (candidate = potentialCommands[i32]) !== void 0; i32++) {
          const d32 = levenshtein_1.levenshtein(cmd, candidate);
          if (d32 <= threshold && d32 < bestDistance) {
            bestDistance = d32;
            recommended = candidate;
          }
        }
        if (recommended)
          usage.fail(__("Did you mean %s?", recommended));
      }, "recommendCommands");
      self2.reset = /* @__PURE__ */ __name(function reset6(localLookup) {
        implied = obj_filter_1.objFilter(implied, (k32) => !localLookup[k32]);
        conflicting = obj_filter_1.objFilter(conflicting, (k32) => !localLookup[k32]);
        checks = checks.filter((c32) => c32.global);
        return self2;
      }, "reset");
      const frozens = [];
      self2.freeze = /* @__PURE__ */ __name(function freeze() {
        frozens.push({
          implied,
          checks,
          conflicting
        });
      }, "freeze");
      self2.unfreeze = /* @__PURE__ */ __name(function unfreeze() {
        const frozen = frozens.pop();
        common_types_1.assertNotStrictEqual(frozen, void 0);
        ({
          implied,
          checks,
          conflicting
        } = frozen);
      }, "unfreeze");
      return self2;
    }
    __name(validation, "validation");
    exports2.validation = validation;
  }
});

// node_modules/yargs/build/lib/apply-extends.js
var require_apply_extends = __commonJS({
  "node_modules/yargs/build/lib/apply-extends.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.applyExtends = void 0;
    var fs51 = require("fs");
    var path47 = require("path");
    var yerror_1 = require_yerror();
    var previouslyVisitedConfigs = [];
    function checkForCircularExtends(cfgPath) {
      if (previouslyVisitedConfigs.indexOf(cfgPath) > -1) {
        throw new yerror_1.YError(`Circular extended configurations: '${cfgPath}'.`);
      }
    }
    __name(checkForCircularExtends, "checkForCircularExtends");
    function getPathToDefaultConfig(cwd, pathToExtend) {
      return path47.resolve(cwd, pathToExtend);
    }
    __name(getPathToDefaultConfig, "getPathToDefaultConfig");
    function mergeDeep(config1, config2) {
      const target = {};
      function isObject3(obj) {
        return obj && typeof obj === "object" && !Array.isArray(obj);
      }
      __name(isObject3, "isObject");
      Object.assign(target, config1);
      for (const key of Object.keys(config2)) {
        if (isObject3(config2[key]) && isObject3(target[key])) {
          target[key] = mergeDeep(config1[key], config2[key]);
        } else {
          target[key] = config2[key];
        }
      }
      return target;
    }
    __name(mergeDeep, "mergeDeep");
    function applyExtends(config2, cwd, mergeExtends = false) {
      let defaultConfig = {};
      if (Object.prototype.hasOwnProperty.call(config2, "extends")) {
        if (typeof config2.extends !== "string")
          return defaultConfig;
        const isPath = /\.json|\..*rc$/.test(config2.extends);
        let pathToDefault = null;
        if (!isPath) {
          try {
            pathToDefault = require.resolve(config2.extends);
          } catch (err) {
          }
        } else {
          pathToDefault = getPathToDefaultConfig(cwd, config2.extends);
        }
        if (!pathToDefault && !isPath)
          return config2;
        if (!pathToDefault)
          throw new yerror_1.YError(`Unable to find extended config '${config2.extends}' in '${cwd}'.`);
        checkForCircularExtends(pathToDefault);
        previouslyVisitedConfigs.push(pathToDefault);
        defaultConfig = isPath ? JSON.parse(fs51.readFileSync(pathToDefault, "utf8")) : require(config2.extends);
        delete config2.extends;
        defaultConfig = applyExtends(defaultConfig, path47.dirname(pathToDefault), mergeExtends);
      }
      previouslyVisitedConfigs = [];
      return mergeExtends ? mergeDeep(defaultConfig, config2) : Object.assign({}, defaultConfig, config2);
    }
    __name(applyExtends, "applyExtends");
    exports2.applyExtends = applyExtends;
  }
});

// node_modules/yargs/build/lib/process-argv.js
var require_process_argv = __commonJS({
  "node_modules/yargs/build/lib/process-argv.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getProcessArgvBin = exports2.getProcessArgvWithoutBin = void 0;
    function getProcessArgvBinIndex() {
      if (isBundledElectronApp())
        return 0;
      return 1;
    }
    __name(getProcessArgvBinIndex, "getProcessArgvBinIndex");
    function isBundledElectronApp() {
      return isElectronApp() && !process.defaultApp;
    }
    __name(isBundledElectronApp, "isBundledElectronApp");
    function isElectronApp() {
      return !!process.versions.electron;
    }
    __name(isElectronApp, "isElectronApp");
    function getProcessArgvWithoutBin() {
      return process.argv.slice(getProcessArgvBinIndex() + 1);
    }
    __name(getProcessArgvWithoutBin, "getProcessArgvWithoutBin");
    exports2.getProcessArgvWithoutBin = getProcessArgvWithoutBin;
    function getProcessArgvBin() {
      return process.argv[getProcessArgvBinIndex()];
    }
    __name(getProcessArgvBin, "getProcessArgvBin");
    exports2.getProcessArgvBin = getProcessArgvBin;
  }
});

// node_modules/y18n/index.js
var require_y18n = __commonJS({
  "node_modules/y18n/index.js"(exports2, module2) {
    var fs51 = require("fs");
    var path47 = require("path");
    var util11 = require("util");
    function Y18N(opts) {
      opts = opts || {};
      this.directory = opts.directory || "./locales";
      this.updateFiles = typeof opts.updateFiles === "boolean" ? opts.updateFiles : true;
      this.locale = opts.locale || "en";
      this.fallbackToLanguage = typeof opts.fallbackToLanguage === "boolean" ? opts.fallbackToLanguage : true;
      this.cache = /* @__PURE__ */ Object.create(null);
      this.writeQueue = [];
    }
    __name(Y18N, "Y18N");
    Y18N.prototype.__ = function() {
      if (typeof arguments[0] !== "string") {
        return this._taggedLiteral.apply(this, arguments);
      }
      var args = Array.prototype.slice.call(arguments);
      var str = args.shift();
      var cb = /* @__PURE__ */ __name(function() {
      }, "cb");
      if (typeof args[args.length - 1] === "function") cb = args.pop();
      cb = cb || function() {
      };
      if (!this.cache[this.locale]) this._readLocaleFile();
      if (!this.cache[this.locale][str] && this.updateFiles) {
        this.cache[this.locale][str] = str;
        this._enqueueWrite([this.directory, this.locale, cb]);
      } else {
        cb();
      }
      return util11.format.apply(util11, [this.cache[this.locale][str] || str].concat(args));
    };
    Y18N.prototype._taggedLiteral = function(parts) {
      var args = arguments;
      var str = "";
      parts.forEach(function(part, i32) {
        var arg = args[i32 + 1];
        str += part;
        if (typeof arg !== "undefined") {
          str += "%s";
        }
      });
      return this.__.apply(null, [str].concat([].slice.call(arguments, 1)));
    };
    Y18N.prototype._enqueueWrite = function(work) {
      this.writeQueue.push(work);
      if (this.writeQueue.length === 1) this._processWriteQueue();
    };
    Y18N.prototype._processWriteQueue = function() {
      var _this = this;
      var work = this.writeQueue[0];
      var directory = work[0];
      var locale = work[1];
      var cb = work[2];
      var languageFile = this._resolveLocaleFile(directory, locale);
      var serializedLocale = JSON.stringify(this.cache[locale], null, 2);
      fs51.writeFile(languageFile, serializedLocale, "utf-8", function(err) {
        _this.writeQueue.shift();
        if (_this.writeQueue.length > 0) _this._processWriteQueue();
        cb(err);
      });
    };
    Y18N.prototype._readLocaleFile = function() {
      var localeLookup = {};
      var languageFile = this._resolveLocaleFile(this.directory, this.locale);
      try {
        localeLookup = JSON.parse(fs51.readFileSync(languageFile, "utf-8"));
      } catch (err) {
        if (err instanceof SyntaxError) {
          err.message = "syntax error in " + languageFile;
        }
        if (err.code === "ENOENT") localeLookup = {};
        else throw err;
      }
      this.cache[this.locale] = localeLookup;
    };
    Y18N.prototype._resolveLocaleFile = function(directory, locale) {
      var file = path47.resolve(directory, "./", locale + ".json");
      if (this.fallbackToLanguage && !this._fileExistsSync(file) && ~locale.lastIndexOf("_")) {
        var languageFile = path47.resolve(directory, "./", locale.split("_")[0] + ".json");
        if (this._fileExistsSync(languageFile)) file = languageFile;
      }
      return file;
    };
    Y18N.prototype._fileExistsSync = function(file) {
      try {
        return fs51.statSync(file).isFile();
      } catch (err) {
        return false;
      }
    };
    Y18N.prototype.__n = function() {
      var args = Array.prototype.slice.call(arguments);
      var singular = args.shift();
      var plural = args.shift();
      var quantity = args.shift();
      var cb = /* @__PURE__ */ __name(function() {
      }, "cb");
      if (typeof args[args.length - 1] === "function") cb = args.pop();
      if (!this.cache[this.locale]) this._readLocaleFile();
      var str = quantity === 1 ? singular : plural;
      if (this.cache[this.locale][singular]) {
        str = this.cache[this.locale][singular][quantity === 1 ? "one" : "other"];
      }
      if (!this.cache[this.locale][singular] && this.updateFiles) {
        this.cache[this.locale][singular] = {
          one: singular,
          other: plural
        };
        this._enqueueWrite([this.directory, this.locale, cb]);
      } else {
        cb();
      }
      var values = [str];
      if (~str.indexOf("%d")) values.push(quantity);
      return util11.format.apply(util11, values.concat(args));
    };
    Y18N.prototype.setLocale = function(locale) {
      this.locale = locale;
    };
    Y18N.prototype.getLocale = function() {
      return this.locale;
    };
    Y18N.prototype.updateLocale = function(obj) {
      if (!this.cache[this.locale]) this._readLocaleFile();
      for (var key in obj) {
        this.cache[this.locale][key] = obj[key];
      }
    };
    module2.exports = function(opts) {
      var y18n = new Y18N(opts);
      for (var key in y18n) {
        if (typeof y18n[key] === "function") {
          y18n[key] = y18n[key].bind(y18n);
        }
      }
      return y18n;
    };
  }
});

// ../../node_modules/p-try/index.js
var require_p_try = __commonJS({
  "../../node_modules/p-try/index.js"(exports2, module2) {
    "use strict";
    var pTry = /* @__PURE__ */ __name((fn, ...arguments_) => new Promise((resolve13) => {
      resolve13(fn(...arguments_));
    }), "pTry");
    module2.exports = pTry;
    module2.exports.default = pTry;
  }
});

// ../../node_modules/find-up/node_modules/p-limit/index.js
var require_p_limit2 = __commonJS({
  "../../node_modules/find-up/node_modules/p-limit/index.js"(exports2, module2) {
    "use strict";
    var pTry = require_p_try();
    var pLimit6 = /* @__PURE__ */ __name((concurrency) => {
      if (!((Number.isInteger(concurrency) || concurrency === Infinity) && concurrency > 0)) {
        return Promise.reject(new TypeError("Expected `concurrency` to be a number from 1 and up"));
      }
      const queue = [];
      let activeCount = 0;
      const next = /* @__PURE__ */ __name(() => {
        activeCount--;
        if (queue.length > 0) {
          queue.shift()();
        }
      }, "next");
      const run = /* @__PURE__ */ __name((fn, resolve13, ...args) => {
        activeCount++;
        const result2 = pTry(fn, ...args);
        resolve13(result2);
        result2.then(next, next);
      }, "run");
      const enqueue = /* @__PURE__ */ __name((fn, resolve13, ...args) => {
        if (activeCount < concurrency) {
          run(fn, resolve13, ...args);
        } else {
          queue.push(run.bind(null, fn, resolve13, ...args));
        }
      }, "enqueue");
      const generator = /* @__PURE__ */ __name((fn, ...args) => new Promise((resolve13) => enqueue(fn, resolve13, ...args)), "generator");
      Object.defineProperties(generator, {
        activeCount: {
          get: /* @__PURE__ */ __name(() => activeCount, "get")
        },
        pendingCount: {
          get: /* @__PURE__ */ __name(() => queue.length, "get")
        },
        clearQueue: {
          value: /* @__PURE__ */ __name(() => {
            queue.length = 0;
          }, "value")
        }
      });
      return generator;
    }, "pLimit");
    module2.exports = pLimit6;
    module2.exports.default = pLimit6;
  }
});

// ../../node_modules/find-up/node_modules/p-locate/index.js
var require_p_locate = __commonJS({
  "../../node_modules/find-up/node_modules/p-locate/index.js"(exports2, module2) {
    "use strict";
    var pLimit6 = require_p_limit2();
    var EndError = class extends Error {
      static {
        __name(this, "EndError");
      }
      constructor(value) {
        super();
        this.value = value;
      }
    };
    var testElement = /* @__PURE__ */ __name(async (element, tester) => tester(await element), "testElement");
    var finder = /* @__PURE__ */ __name(async (element) => {
      const values = await Promise.all(element);
      if (values[1] === true) {
        throw new EndError(values[0]);
      }
      return false;
    }, "finder");
    var pLocate = /* @__PURE__ */ __name(async (iterable, tester, options) => {
      options = {
        concurrency: Infinity,
        preserveOrder: true,
        ...options
      };
      const limit = pLimit6(options.concurrency);
      const items = [...iterable].map((element) => [element, limit(testElement, element, tester)]);
      const checkLimit = pLimit6(options.preserveOrder ? 1 : Infinity);
      try {
        await Promise.all(items.map((element) => checkLimit(finder, element)));
      } catch (error4) {
        if (error4 instanceof EndError) {
          return error4.value;
        }
        throw error4;
      }
    }, "pLocate");
    module2.exports = pLocate;
    module2.exports.default = pLocate;
  }
});

// ../../node_modules/find-up/node_modules/locate-path/index.js
var require_locate_path = __commonJS({
  "../../node_modules/find-up/node_modules/locate-path/index.js"(exports2, module2) {
    "use strict";
    var path47 = require("path");
    var fs51 = require("fs");
    var { promisify: promisify4 } = require("util");
    var pLocate = require_p_locate();
    var fsStat = promisify4(fs51.stat);
    var fsLStat = promisify4(fs51.lstat);
    var typeMappings = {
      directory: "isDirectory",
      file: "isFile"
    };
    function checkType({ type }) {
      if (type in typeMappings) {
        return;
      }
      throw new Error(`Invalid type specified: ${type}`);
    }
    __name(checkType, "checkType");
    var matchType = /* @__PURE__ */ __name((type, stat8) => type === void 0 || stat8[typeMappings[type]](), "matchType");
    module2.exports = async (paths, options) => {
      options = {
        cwd: process.cwd(),
        type: "file",
        allowSymlinks: true,
        ...options
      };
      checkType(options);
      const statFn = options.allowSymlinks ? fsStat : fsLStat;
      return pLocate(paths, async (path_) => {
        try {
          const stat8 = await statFn(path47.resolve(options.cwd, path_));
          return matchType(options.type, stat8);
        } catch (_) {
          return false;
        }
      }, options);
    };
    module2.exports.sync = (paths, options) => {
      options = {
        cwd: process.cwd(),
        allowSymlinks: true,
        type: "file",
        ...options
      };
      checkType(options);
      const statFn = options.allowSymlinks ? fs51.statSync : fs51.lstatSync;
      for (const path_ of paths) {
        try {
          const stat8 = statFn(path47.resolve(options.cwd, path_));
          if (matchType(options.type, stat8)) {
            return path_;
          }
        } catch (_) {
        }
      }
    };
  }
});

// ../../node_modules/path-exists/index.js
var require_path_exists2 = __commonJS({
  "../../node_modules/path-exists/index.js"(exports2, module2) {
    "use strict";
    var fs51 = require("fs");
    var { promisify: promisify4 } = require("util");
    var pAccess = promisify4(fs51.access);
    module2.exports = async (path47) => {
      try {
        await pAccess(path47);
        return true;
      } catch (_) {
        return false;
      }
    };
    module2.exports.sync = (path47) => {
      try {
        fs51.accessSync(path47);
        return true;
      } catch (_) {
        return false;
      }
    };
  }
});

// ../../node_modules/find-up/index.js
var require_find_up = __commonJS({
  "../../node_modules/find-up/index.js"(exports2, module2) {
    "use strict";
    var path47 = require("path");
    var locatePath = require_locate_path();
    var pathExists9 = require_path_exists2();
    var stop = /* @__PURE__ */ Symbol("findUp.stop");
    module2.exports = async (name, options = {}) => {
      let directory = path47.resolve(options.cwd || "");
      const { root: root32 } = path47.parse(directory);
      const paths = [].concat(name);
      const runMatcher = /* @__PURE__ */ __name(async (locateOptions) => {
        if (typeof name !== "function") {
          return locatePath(paths, locateOptions);
        }
        const foundPath = await name(locateOptions.cwd);
        if (typeof foundPath === "string") {
          return locatePath([foundPath], locateOptions);
        }
        return foundPath;
      }, "runMatcher");
      while (true) {
        const foundPath = await runMatcher({ ...options, cwd: directory });
        if (foundPath === stop) {
          return;
        }
        if (foundPath) {
          return path47.resolve(directory, foundPath);
        }
        if (directory === root32) {
          return;
        }
        directory = path47.dirname(directory);
      }
    };
    module2.exports.sync = (name, options = {}) => {
      let directory = path47.resolve(options.cwd || "");
      const { root: root32 } = path47.parse(directory);
      const paths = [].concat(name);
      const runMatcher = /* @__PURE__ */ __name((locateOptions) => {
        if (typeof name !== "function") {
          return locatePath.sync(paths, locateOptions);
        }
        const foundPath = name(locateOptions.cwd);
        if (typeof foundPath === "string") {
          return locatePath.sync([foundPath], locateOptions);
        }
        return foundPath;
      }, "runMatcher");
      while (true) {
        const foundPath = runMatcher({ ...options, cwd: directory });
        if (foundPath === stop) {
          return;
        }
        if (foundPath) {
          return path47.resolve(directory, foundPath);
        }
        if (directory === root32) {
          return;
        }
        directory = path47.dirname(directory);
      }
    };
    module2.exports.exists = pathExists9;
    module2.exports.sync.exists = pathExists9.sync;
    module2.exports.stop = stop;
  }
});

// ../../node_modules/require-main-filename/index.js
var require_require_main_filename = __commonJS({
  "../../node_modules/require-main-filename/index.js"(exports2, module2) {
    module2.exports = function(_require) {
      _require = _require || require;
      var main = _require.main;
      if (main && isIISNode(main)) return handleIISNode(main);
      else return main ? main.filename : process.cwd();
    };
    function isIISNode(main) {
      return /\\iisnode\\/.test(main.filename);
    }
    __name(isIISNode, "isIISNode");
    function handleIISNode(main) {
      if (!main.children.length) {
        return main.filename;
      } else {
        return main.children[0].filename;
      }
    }
    __name(handleIISNode, "handleIISNode");
  }
});

// ../../node_modules/get-caller-file/index.js
var require_get_caller_file = __commonJS({
  "../../node_modules/get-caller-file/index.js"(exports2, module2) {
    "use strict";
    module2.exports = /* @__PURE__ */ __name(function getCallerFile(position) {
      if (position === void 0) {
        position = 2;
      }
      if (position >= Error.stackTraceLimit) {
        throw new TypeError("getCallerFile(position) requires position be less then Error.stackTraceLimit but position was: `" + position + "` and Error.stackTraceLimit was: `" + Error.stackTraceLimit + "`");
      }
      var oldPrepareStackTrace = Error.prepareStackTrace;
      Error.prepareStackTrace = function(_, stack2) {
        return stack2;
      };
      var stack = new Error().stack;
      Error.prepareStackTrace = oldPrepareStackTrace;
      if (stack !== null && typeof stack === "object") {
        return stack[position] ? stack[position].getFileName() : void 0;
      }
    }, "getCallerFile");
  }
});

// node_modules/yargs/build/lib/yargs.js
var require_yargs = __commonJS({
  "node_modules/yargs/build/lib/yargs.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isYargsInstance = exports2.rebase = exports2.Yargs = void 0;
    var command_1 = require_command();
    var common_types_1 = require_common_types();
    var yerror_1 = require_yerror();
    var usage_1 = require_usage();
    var argsert_1 = require_argsert();
    var fs51 = require("fs");
    var completion_1 = require_completion();
    var path47 = require("path");
    var validation_1 = require_validation();
    var obj_filter_1 = require_obj_filter();
    var apply_extends_1 = require_apply_extends();
    var middleware_1 = require_middleware();
    var processArgv = require_process_argv();
    var is_promise_1 = require_is_promise();
    var Parser = require_yargs_parser();
    var y18nFactory = require_y18n();
    var setBlocking = require_set_blocking();
    var findUp = require_find_up();
    var requireMainFilename = require_require_main_filename();
    function Yargs(processArgs = [], cwd = process.cwd(), parentRequire = require) {
      const self2 = {};
      let command;
      let completion = null;
      let groups = {};
      const globalMiddleware = [];
      let output = "";
      const preservedGroups = {};
      let usage;
      let validation;
      let handlerFinishCommand = null;
      const y18n = y18nFactory({
        directory: path47.resolve(__dirname, "../../locales"),
        updateFiles: false
      });
      self2.middleware = middleware_1.globalMiddlewareFactory(globalMiddleware, self2);
      self2.scriptName = function(scriptName) {
        self2.customScriptName = true;
        self2.$0 = scriptName;
        return self2;
      };
      let default$0;
      if (/\b(node|iojs|electron)(\.exe)?$/.test(process.argv[0])) {
        default$0 = process.argv.slice(1, 2);
      } else {
        default$0 = process.argv.slice(0, 1);
      }
      self2.$0 = default$0.map((x) => {
        const b32 = rebase(cwd, x);
        return x.match(/^(\/|([a-zA-Z]:)?\\)/) && b32.length < x.length ? b32 : x;
      }).join(" ").trim();
      if (process.env._ !== void 0 && processArgv.getProcessArgvBin() === process.env._) {
        self2.$0 = process.env._.replace(`${path47.dirname(process.execPath)}/`, "");
      }
      const context = { resets: -1, commands: [], fullCommands: [], files: [] };
      self2.getContext = () => context;
      let options;
      self2.resetOptions = self2.reset = /* @__PURE__ */ __name(function resetOptions(aliases = {}) {
        context.resets++;
        options = options || {};
        const tmpOptions = {};
        tmpOptions.local = options.local ? options.local : [];
        tmpOptions.configObjects = options.configObjects ? options.configObjects : [];
        const localLookup = {};
        tmpOptions.local.forEach((l20) => {
          localLookup[l20] = true;
          (aliases[l20] || []).forEach((a32) => {
            localLookup[a32] = true;
          });
        });
        Object.assign(preservedGroups, Object.keys(groups).reduce((acc, groupName) => {
          const keys = groups[groupName].filter((key) => !(key in localLookup));
          if (keys.length > 0) {
            acc[groupName] = keys;
          }
          return acc;
        }, {}));
        groups = {};
        const arrayOptions = [
          "array",
          "boolean",
          "string",
          "skipValidation",
          "count",
          "normalize",
          "number",
          "hiddenOptions"
        ];
        const objectOptions = [
          "narg",
          "key",
          "alias",
          "default",
          "defaultDescription",
          "config",
          "choices",
          "demandedOptions",
          "demandedCommands",
          "coerce",
          "deprecatedOptions"
        ];
        arrayOptions.forEach((k32) => {
          tmpOptions[k32] = (options[k32] || []).filter((k33) => !localLookup[k33]);
        });
        objectOptions.forEach((k32) => {
          tmpOptions[k32] = obj_filter_1.objFilter(options[k32], (k33) => !localLookup[k33]);
        });
        tmpOptions.envPrefix = options.envPrefix;
        options = tmpOptions;
        usage = usage ? usage.reset(localLookup) : usage_1.usage(self2, y18n);
        validation = validation ? validation.reset(localLookup) : validation_1.validation(self2, usage, y18n);
        command = command ? command.reset() : command_1.command(self2, usage, validation, globalMiddleware);
        if (!completion)
          completion = completion_1.completion(self2, usage, command);
        completionCommand = null;
        output = "";
        exitError = null;
        hasOutput = false;
        self2.parsed = false;
        return self2;
      }, "resetOptions");
      self2.resetOptions();
      const frozens = [];
      function freeze() {
        frozens.push({
          options,
          configObjects: options.configObjects.slice(0),
          exitProcess,
          groups,
          strict,
          strictCommands,
          completionCommand,
          output,
          exitError,
          hasOutput,
          parsed: self2.parsed,
          parseFn,
          parseContext,
          handlerFinishCommand
        });
        usage.freeze();
        validation.freeze();
        command.freeze();
      }
      __name(freeze, "freeze");
      function unfreeze() {
        const frozen = frozens.pop();
        common_types_1.assertNotStrictEqual(frozen, void 0);
        let configObjects;
        ({
          options,
          configObjects,
          exitProcess,
          groups,
          output,
          exitError,
          hasOutput,
          parsed: self2.parsed,
          strict,
          strictCommands,
          completionCommand,
          parseFn,
          parseContext,
          handlerFinishCommand
        } = frozen);
        options.configObjects = configObjects;
        usage.unfreeze();
        validation.unfreeze();
        command.unfreeze();
      }
      __name(unfreeze, "unfreeze");
      self2.boolean = function(keys) {
        argsert_1.argsert("<array|string>", [keys], arguments.length);
        populateParserHintArray("boolean", keys);
        return self2;
      };
      self2.array = function(keys) {
        argsert_1.argsert("<array|string>", [keys], arguments.length);
        populateParserHintArray("array", keys);
        return self2;
      };
      self2.number = function(keys) {
        argsert_1.argsert("<array|string>", [keys], arguments.length);
        populateParserHintArray("number", keys);
        return self2;
      };
      self2.normalize = function(keys) {
        argsert_1.argsert("<array|string>", [keys], arguments.length);
        populateParserHintArray("normalize", keys);
        return self2;
      };
      self2.count = function(keys) {
        argsert_1.argsert("<array|string>", [keys], arguments.length);
        populateParserHintArray("count", keys);
        return self2;
      };
      self2.string = function(keys) {
        argsert_1.argsert("<array|string>", [keys], arguments.length);
        populateParserHintArray("string", keys);
        return self2;
      };
      self2.requiresArg = function(keys) {
        argsert_1.argsert("<array|string|object> [number]", [keys], arguments.length);
        if (typeof keys === "string" && options.narg[keys]) {
          return self2;
        } else {
          populateParserHintSingleValueDictionary(self2.requiresArg, "narg", keys, NaN);
        }
        return self2;
      };
      self2.skipValidation = function(keys) {
        argsert_1.argsert("<array|string>", [keys], arguments.length);
        populateParserHintArray("skipValidation", keys);
        return self2;
      };
      function populateParserHintArray(type, keys) {
        keys = [].concat(keys);
        keys.forEach((key) => {
          key = sanitizeKey(key);
          options[type].push(key);
        });
      }
      __name(populateParserHintArray, "populateParserHintArray");
      self2.nargs = function(key, value) {
        argsert_1.argsert("<string|object|array> [number]", [key, value], arguments.length);
        populateParserHintSingleValueDictionary(self2.nargs, "narg", key, value);
        return self2;
      };
      self2.choices = function(key, value) {
        argsert_1.argsert("<object|string|array> [string|array]", [key, value], arguments.length);
        populateParserHintArrayDictionary(self2.choices, "choices", key, value);
        return self2;
      };
      self2.alias = function(key, value) {
        argsert_1.argsert("<object|string|array> [string|array]", [key, value], arguments.length);
        populateParserHintArrayDictionary(self2.alias, "alias", key, value);
        return self2;
      };
      self2.default = self2.defaults = function(key, value, defaultDescription) {
        argsert_1.argsert("<object|string|array> [*] [string]", [key, value, defaultDescription], arguments.length);
        if (defaultDescription) {
          common_types_1.assertSingleKey(key);
          options.defaultDescription[key] = defaultDescription;
        }
        if (typeof value === "function") {
          common_types_1.assertSingleKey(key);
          if (!options.defaultDescription[key])
            options.defaultDescription[key] = usage.functionDescription(value);
          value = value.call();
        }
        populateParserHintSingleValueDictionary(self2.default, "default", key, value);
        return self2;
      };
      self2.describe = function(key, desc) {
        argsert_1.argsert("<object|string|array> [string]", [key, desc], arguments.length);
        setKey(key, true);
        usage.describe(key, desc);
        return self2;
      };
      function setKey(key, set) {
        populateParserHintSingleValueDictionary(setKey, "key", key, set);
        return self2;
      }
      __name(setKey, "setKey");
      function demandOption(keys, msg) {
        argsert_1.argsert("<object|string|array> [string]", [keys, msg], arguments.length);
        populateParserHintSingleValueDictionary(self2.demandOption, "demandedOptions", keys, msg);
        return self2;
      }
      __name(demandOption, "demandOption");
      self2.demandOption = demandOption;
      self2.coerce = function(keys, value) {
        argsert_1.argsert("<object|string|array> [function]", [keys, value], arguments.length);
        populateParserHintSingleValueDictionary(self2.coerce, "coerce", keys, value);
        return self2;
      };
      function populateParserHintSingleValueDictionary(builder, type, key, value) {
        populateParserHintDictionary(builder, type, key, value, (type2, key2, value2) => {
          options[type2][key2] = value2;
        });
      }
      __name(populateParserHintSingleValueDictionary, "populateParserHintSingleValueDictionary");
      function populateParserHintArrayDictionary(builder, type, key, value) {
        populateParserHintDictionary(builder, type, key, value, (type2, key2, value2) => {
          options[type2][key2] = (options[type2][key2] || []).concat(value2);
        });
      }
      __name(populateParserHintArrayDictionary, "populateParserHintArrayDictionary");
      function populateParserHintDictionary(builder, type, key, value, singleKeyHandler) {
        if (Array.isArray(key)) {
          key.forEach((k32) => {
            builder(k32, value);
          });
        } else if (/* @__PURE__ */ ((key2) => typeof key2 === "object")(key)) {
          for (const k32 of common_types_1.objectKeys(key)) {
            builder(k32, key[k32]);
          }
        } else {
          singleKeyHandler(type, sanitizeKey(key), value);
        }
      }
      __name(populateParserHintDictionary, "populateParserHintDictionary");
      function sanitizeKey(key) {
        if (key === "__proto__")
          return "___proto___";
        return key;
      }
      __name(sanitizeKey, "sanitizeKey");
      function deleteFromParserHintObject(optionKey) {
        common_types_1.objectKeys(options).forEach((hintKey) => {
          if (/* @__PURE__ */ ((key) => key === "configObjects")(hintKey))
            return;
          const hint = options[hintKey];
          if (Array.isArray(hint)) {
            if (~hint.indexOf(optionKey))
              hint.splice(hint.indexOf(optionKey), 1);
          } else if (typeof hint === "object") {
            delete hint[optionKey];
          }
        });
        delete usage.getDescriptions()[optionKey];
      }
      __name(deleteFromParserHintObject, "deleteFromParserHintObject");
      self2.config = /* @__PURE__ */ __name(function config2(key = "config", msg, parseFn2) {
        argsert_1.argsert("[object|string] [string|function] [function]", [key, msg, parseFn2], arguments.length);
        if (typeof key === "object" && !Array.isArray(key)) {
          key = apply_extends_1.applyExtends(key, cwd, self2.getParserConfiguration()["deep-merge-config"]);
          options.configObjects = (options.configObjects || []).concat(key);
          return self2;
        }
        if (typeof msg === "function") {
          parseFn2 = msg;
          msg = void 0;
        }
        self2.describe(key, msg || usage.deferY18nLookup("Path to JSON config file"));
        (Array.isArray(key) ? key : [key]).forEach((k32) => {
          options.config[k32] = parseFn2 || true;
        });
        return self2;
      }, "config");
      self2.example = function(cmd, description) {
        argsert_1.argsert("<string|array> [string]", [cmd, description], arguments.length);
        if (Array.isArray(cmd)) {
          cmd.forEach((exampleParams) => self2.example(...exampleParams));
        } else {
          usage.example(cmd, description);
        }
        return self2;
      };
      self2.command = function(cmd, description, builder, handler, middlewares, deprecated) {
        argsert_1.argsert("<string|array|object> [string|boolean] [function|object] [function] [array] [boolean|string]", [cmd, description, builder, handler, middlewares, deprecated], arguments.length);
        command.addHandler(cmd, description, builder, handler, middlewares, deprecated);
        return self2;
      };
      self2.commandDir = function(dir, opts) {
        argsert_1.argsert("<string> [object]", [dir, opts], arguments.length);
        const req = parentRequire || require;
        command.addDirectory(dir, self2.getContext(), req, require_get_caller_file()(), opts);
        return self2;
      };
      self2.demand = self2.required = self2.require = /* @__PURE__ */ __name(function demand(keys, max, msg) {
        if (Array.isArray(max)) {
          max.forEach((key) => {
            common_types_1.assertNotStrictEqual(msg, true);
            demandOption(key, msg);
          });
          max = Infinity;
        } else if (typeof max !== "number") {
          msg = max;
          max = Infinity;
        }
        if (typeof keys === "number") {
          common_types_1.assertNotStrictEqual(msg, true);
          self2.demandCommand(keys, max, msg, msg);
        } else if (Array.isArray(keys)) {
          keys.forEach((key) => {
            common_types_1.assertNotStrictEqual(msg, true);
            demandOption(key, msg);
          });
        } else {
          if (typeof msg === "string") {
            demandOption(keys, msg);
          } else if (msg === true || typeof msg === "undefined") {
            demandOption(keys);
          }
        }
        return self2;
      }, "demand");
      self2.demandCommand = /* @__PURE__ */ __name(function demandCommand(min = 1, max, minMsg, maxMsg) {
        argsert_1.argsert("[number] [number|string] [string|null|undefined] [string|null|undefined]", [min, max, minMsg, maxMsg], arguments.length);
        if (typeof max !== "number") {
          minMsg = max;
          max = Infinity;
        }
        self2.global("_", false);
        options.demandedCommands._ = {
          min,
          max,
          minMsg,
          maxMsg
        };
        return self2;
      }, "demandCommand");
      self2.getDemandedOptions = () => {
        argsert_1.argsert([], 0);
        return options.demandedOptions;
      };
      self2.getDemandedCommands = () => {
        argsert_1.argsert([], 0);
        return options.demandedCommands;
      };
      self2.deprecateOption = /* @__PURE__ */ __name(function deprecateOption(option, message2) {
        argsert_1.argsert("<string> [string|boolean]", [option, message2], arguments.length);
        options.deprecatedOptions[option] = message2;
        return self2;
      }, "deprecateOption");
      self2.getDeprecatedOptions = () => {
        argsert_1.argsert([], 0);
        return options.deprecatedOptions;
      };
      self2.implies = function(key, value) {
        argsert_1.argsert("<string|object> [number|string|array]", [key, value], arguments.length);
        validation.implies(key, value);
        return self2;
      };
      self2.conflicts = function(key1, key2) {
        argsert_1.argsert("<string|object> [string|array]", [key1, key2], arguments.length);
        validation.conflicts(key1, key2);
        return self2;
      };
      self2.usage = function(msg, description, builder, handler) {
        argsert_1.argsert("<string|null|undefined> [string|boolean] [function|object] [function]", [msg, description, builder, handler], arguments.length);
        if (description !== void 0) {
          common_types_1.assertNotStrictEqual(msg, null);
          if ((msg || "").match(/^\$0( |$)/)) {
            return self2.command(msg, description, builder, handler);
          } else {
            throw new yerror_1.YError(".usage() description must start with $0 if being used as alias for .command()");
          }
        } else {
          usage.usage(msg);
          return self2;
        }
      };
      self2.epilogue = self2.epilog = function(msg) {
        argsert_1.argsert("<string>", [msg], arguments.length);
        usage.epilog(msg);
        return self2;
      };
      self2.fail = function(f32) {
        argsert_1.argsert("<function>", [f32], arguments.length);
        usage.failFn(f32);
        return self2;
      };
      self2.onFinishCommand = function(f32) {
        argsert_1.argsert("<function>", [f32], arguments.length);
        handlerFinishCommand = f32;
        return self2;
      };
      self2.getHandlerFinishCommand = () => handlerFinishCommand;
      self2.check = function(f32, _global) {
        argsert_1.argsert("<function> [boolean]", [f32, _global], arguments.length);
        validation.check(f32, _global !== false);
        return self2;
      };
      self2.global = /* @__PURE__ */ __name(function global2(globals, global2) {
        argsert_1.argsert("<string|array> [boolean]", [globals, global2], arguments.length);
        globals = [].concat(globals);
        if (global2 !== false) {
          options.local = options.local.filter((l20) => globals.indexOf(l20) === -1);
        } else {
          globals.forEach((g32) => {
            if (options.local.indexOf(g32) === -1)
              options.local.push(g32);
          });
        }
        return self2;
      }, "global");
      self2.pkgConf = /* @__PURE__ */ __name(function pkgConf(key, rootPath) {
        argsert_1.argsert("<string> [string]", [key, rootPath], arguments.length);
        let conf = null;
        const obj = pkgUp(rootPath || cwd);
        if (obj[key] && typeof obj[key] === "object") {
          conf = apply_extends_1.applyExtends(obj[key], rootPath || cwd, self2.getParserConfiguration()["deep-merge-config"]);
          options.configObjects = (options.configObjects || []).concat(conf);
        }
        return self2;
      }, "pkgConf");
      const pkgs = {};
      function pkgUp(rootPath) {
        const npath = rootPath || "*";
        if (pkgs[npath])
          return pkgs[npath];
        let obj = {};
        try {
          let startDir = rootPath || requireMainFilename(parentRequire);
          if (!rootPath && path47.extname(startDir)) {
            startDir = path47.dirname(startDir);
          }
          const pkgJsonPath = findUp.sync("package.json", {
            cwd: startDir
          });
          common_types_1.assertNotStrictEqual(pkgJsonPath, void 0);
          obj = JSON.parse(fs51.readFileSync(pkgJsonPath).toString());
        } catch (noop) {
        }
        pkgs[npath] = obj || {};
        return pkgs[npath];
      }
      __name(pkgUp, "pkgUp");
      let parseFn = null;
      let parseContext = null;
      self2.parse = /* @__PURE__ */ __name(function parse2(args, shortCircuit, _parseFn) {
        argsert_1.argsert("[string|array] [function|boolean|object] [function]", [args, shortCircuit, _parseFn], arguments.length);
        freeze();
        if (typeof args === "undefined") {
          const argv = self2._parseArgs(processArgs);
          const tmpParsed = self2.parsed;
          unfreeze();
          self2.parsed = tmpParsed;
          return argv;
        }
        if (typeof shortCircuit === "object") {
          parseContext = shortCircuit;
          shortCircuit = _parseFn;
        }
        if (typeof shortCircuit === "function") {
          parseFn = shortCircuit;
          shortCircuit = false;
        }
        if (!shortCircuit)
          processArgs = args;
        if (parseFn)
          exitProcess = false;
        const parsed = self2._parseArgs(args, !!shortCircuit);
        completion.setParsed(self2.parsed);
        if (parseFn)
          parseFn(exitError, parsed, output);
        unfreeze();
        return parsed;
      }, "parse");
      self2._getParseContext = () => parseContext || {};
      self2._hasParseCallback = () => !!parseFn;
      self2.option = self2.options = /* @__PURE__ */ __name(function option(key, opt) {
        argsert_1.argsert("<string|object> [object]", [key, opt], arguments.length);
        if (typeof key === "object") {
          Object.keys(key).forEach((k32) => {
            self2.options(k32, key[k32]);
          });
        } else {
          if (typeof opt !== "object") {
            opt = {};
          }
          options.key[key] = true;
          if (opt.alias)
            self2.alias(key, opt.alias);
          const deprecate = opt.deprecate || opt.deprecated;
          if (deprecate) {
            self2.deprecateOption(key, deprecate);
          }
          const demand = opt.demand || opt.required || opt.require;
          if (demand) {
            self2.demand(key, demand);
          }
          if (opt.demandOption) {
            self2.demandOption(key, typeof opt.demandOption === "string" ? opt.demandOption : void 0);
          }
          if (opt.conflicts) {
            self2.conflicts(key, opt.conflicts);
          }
          if ("default" in opt) {
            self2.default(key, opt.default);
          }
          if (opt.implies !== void 0) {
            self2.implies(key, opt.implies);
          }
          if (opt.nargs !== void 0) {
            self2.nargs(key, opt.nargs);
          }
          if (opt.config) {
            self2.config(key, opt.configParser);
          }
          if (opt.normalize) {
            self2.normalize(key);
          }
          if (opt.choices) {
            self2.choices(key, opt.choices);
          }
          if (opt.coerce) {
            self2.coerce(key, opt.coerce);
          }
          if (opt.group) {
            self2.group(key, opt.group);
          }
          if (opt.boolean || opt.type === "boolean") {
            self2.boolean(key);
            if (opt.alias)
              self2.boolean(opt.alias);
          }
          if (opt.array || opt.type === "array") {
            self2.array(key);
            if (opt.alias)
              self2.array(opt.alias);
          }
          if (opt.number || opt.type === "number") {
            self2.number(key);
            if (opt.alias)
              self2.number(opt.alias);
          }
          if (opt.string || opt.type === "string") {
            self2.string(key);
            if (opt.alias)
              self2.string(opt.alias);
          }
          if (opt.count || opt.type === "count") {
            self2.count(key);
          }
          if (typeof opt.global === "boolean") {
            self2.global(key, opt.global);
          }
          if (opt.defaultDescription) {
            options.defaultDescription[key] = opt.defaultDescription;
          }
          if (opt.skipValidation) {
            self2.skipValidation(key);
          }
          const desc = opt.describe || opt.description || opt.desc;
          self2.describe(key, desc);
          if (opt.hidden) {
            self2.hide(key);
          }
          if (opt.requiresArg) {
            self2.requiresArg(key);
          }
        }
        return self2;
      }, "option");
      self2.getOptions = () => options;
      self2.positional = function(key, opts) {
        argsert_1.argsert("<string> <object>", [key, opts], arguments.length);
        if (context.resets === 0) {
          throw new yerror_1.YError(".positional() can only be called in a command's builder function");
        }
        const supportedOpts = [
          "default",
          "defaultDescription",
          "implies",
          "normalize",
          "choices",
          "conflicts",
          "coerce",
          "type",
          "describe",
          "desc",
          "description",
          "alias"
        ];
        opts = obj_filter_1.objFilter(opts, (k32, v) => {
          let accept = supportedOpts.indexOf(k32) !== -1;
          if (k32 === "type" && ["string", "number", "boolean"].indexOf(v) === -1)
            accept = false;
          return accept;
        });
        const fullCommand = context.fullCommands[context.fullCommands.length - 1];
        const parseOptions = fullCommand ? command.cmdToParseOptions(fullCommand) : {
          array: [],
          alias: {},
          default: {},
          demand: {}
        };
        common_types_1.objectKeys(parseOptions).forEach((pk) => {
          const parseOption = parseOptions[pk];
          if (Array.isArray(parseOption)) {
            if (parseOption.indexOf(key) !== -1)
              opts[pk] = true;
          } else {
            if (parseOption[key] && !(pk in opts))
              opts[pk] = parseOption[key];
          }
        });
        self2.group(key, usage.getPositionalGroupName());
        return self2.option(key, opts);
      };
      self2.group = /* @__PURE__ */ __name(function group7(opts, groupName) {
        argsert_1.argsert("<string|array> <string>", [opts, groupName], arguments.length);
        const existing = preservedGroups[groupName] || groups[groupName];
        if (preservedGroups[groupName]) {
          delete preservedGroups[groupName];
        }
        const seen = {};
        groups[groupName] = (existing || []).concat(opts).filter((key) => {
          if (seen[key])
            return false;
          return seen[key] = true;
        });
        return self2;
      }, "group");
      self2.getGroups = () => Object.assign({}, groups, preservedGroups);
      self2.env = function(prefix) {
        argsert_1.argsert("[string|boolean]", [prefix], arguments.length);
        if (prefix === false)
          delete options.envPrefix;
        else
          options.envPrefix = prefix || "";
        return self2;
      };
      self2.wrap = function(cols) {
        argsert_1.argsert("<number|null|undefined>", [cols], arguments.length);
        usage.wrap(cols);
        return self2;
      };
      let strict = false;
      self2.strict = function(enabled) {
        argsert_1.argsert("[boolean]", [enabled], arguments.length);
        strict = enabled !== false;
        return self2;
      };
      self2.getStrict = () => strict;
      let strictCommands = false;
      self2.strictCommands = function(enabled) {
        argsert_1.argsert("[boolean]", [enabled], arguments.length);
        strictCommands = enabled !== false;
        return self2;
      };
      self2.getStrictCommands = () => strictCommands;
      let parserConfig = {};
      self2.parserConfiguration = /* @__PURE__ */ __name(function parserConfiguration(config2) {
        argsert_1.argsert("<object>", [config2], arguments.length);
        parserConfig = config2;
        return self2;
      }, "parserConfiguration");
      self2.getParserConfiguration = () => parserConfig;
      self2.showHelp = function(level) {
        argsert_1.argsert("[string|function]", [level], arguments.length);
        if (!self2.parsed)
          self2._parseArgs(processArgs);
        if (command.hasDefaultCommand()) {
          context.resets++;
          command.runDefaultBuilderOn(self2);
        }
        usage.showHelp(level);
        return self2;
      };
      let versionOpt = null;
      self2.version = /* @__PURE__ */ __name(function version(opt, msg, ver) {
        const defaultVersionOpt = "version";
        argsert_1.argsert("[boolean|string] [string] [string]", [opt, msg, ver], arguments.length);
        if (versionOpt) {
          deleteFromParserHintObject(versionOpt);
          usage.version(void 0);
          versionOpt = null;
        }
        if (arguments.length === 0) {
          ver = guessVersion();
          opt = defaultVersionOpt;
        } else if (arguments.length === 1) {
          if (opt === false) {
            return self2;
          }
          ver = opt;
          opt = defaultVersionOpt;
        } else if (arguments.length === 2) {
          ver = msg;
          msg = void 0;
        }
        versionOpt = typeof opt === "string" ? opt : defaultVersionOpt;
        msg = msg || usage.deferY18nLookup("Show version number");
        usage.version(ver || void 0);
        self2.boolean(versionOpt);
        self2.describe(versionOpt, msg);
        return self2;
      }, "version");
      function guessVersion() {
        const obj = pkgUp();
        return obj.version || "unknown";
      }
      __name(guessVersion, "guessVersion");
      let helpOpt = null;
      self2.addHelpOpt = self2.help = /* @__PURE__ */ __name(function addHelpOpt(opt, msg) {
        const defaultHelpOpt = "help";
        argsert_1.argsert("[string|boolean] [string]", [opt, msg], arguments.length);
        if (helpOpt) {
          deleteFromParserHintObject(helpOpt);
          helpOpt = null;
        }
        if (arguments.length === 1) {
          if (opt === false)
            return self2;
        }
        helpOpt = typeof opt === "string" ? opt : defaultHelpOpt;
        self2.boolean(helpOpt);
        self2.describe(helpOpt, msg || usage.deferY18nLookup("Show help"));
        return self2;
      }, "addHelpOpt");
      const defaultShowHiddenOpt = "show-hidden";
      options.showHiddenOpt = defaultShowHiddenOpt;
      self2.addShowHiddenOpt = self2.showHidden = /* @__PURE__ */ __name(function addShowHiddenOpt(opt, msg) {
        argsert_1.argsert("[string|boolean] [string]", [opt, msg], arguments.length);
        if (arguments.length === 1) {
          if (opt === false)
            return self2;
        }
        const showHiddenOpt = typeof opt === "string" ? opt : defaultShowHiddenOpt;
        self2.boolean(showHiddenOpt);
        self2.describe(showHiddenOpt, msg || usage.deferY18nLookup("Show hidden options"));
        options.showHiddenOpt = showHiddenOpt;
        return self2;
      }, "addShowHiddenOpt");
      self2.hide = /* @__PURE__ */ __name(function hide(key) {
        argsert_1.argsert("<string>", [key], arguments.length);
        options.hiddenOptions.push(key);
        return self2;
      }, "hide");
      self2.showHelpOnFail = /* @__PURE__ */ __name(function showHelpOnFail(enabled, message2) {
        argsert_1.argsert("[boolean|string] [string]", [enabled, message2], arguments.length);
        usage.showHelpOnFail(enabled, message2);
        return self2;
      }, "showHelpOnFail");
      var exitProcess = true;
      self2.exitProcess = function(enabled = true) {
        argsert_1.argsert("[boolean]", [enabled], arguments.length);
        exitProcess = enabled;
        return self2;
      };
      self2.getExitProcess = () => exitProcess;
      var completionCommand = null;
      self2.completion = function(cmd, desc, fn) {
        argsert_1.argsert("[string] [string|boolean|function] [function]", [cmd, desc, fn], arguments.length);
        if (typeof desc === "function") {
          fn = desc;
          desc = void 0;
        }
        completionCommand = cmd || completionCommand || "completion";
        if (!desc && desc !== false) {
          desc = "generate completion script";
        }
        self2.command(completionCommand, desc);
        if (fn)
          completion.registerFunction(fn);
        return self2;
      };
      self2.showCompletionScript = function($0, cmd) {
        argsert_1.argsert("[string] [string]", [$0, cmd], arguments.length);
        $0 = $0 || self2.$0;
        _logger.log(completion.generateCompletionScript($0, cmd || completionCommand || "completion"));
        return self2;
      };
      self2.getCompletion = function(args, done) {
        argsert_1.argsert("<array> <function>", [args, done], arguments.length);
        completion.getCompletion(args, done);
      };
      self2.locale = function(locale) {
        argsert_1.argsert("[string]", [locale], arguments.length);
        if (!locale) {
          guessLocale();
          return y18n.getLocale();
        }
        detectLocale = false;
        y18n.setLocale(locale);
        return self2;
      };
      self2.updateStrings = self2.updateLocale = function(obj) {
        argsert_1.argsert("<object>", [obj], arguments.length);
        detectLocale = false;
        y18n.updateLocale(obj);
        return self2;
      };
      let detectLocale = true;
      self2.detectLocale = function(detect) {
        argsert_1.argsert("<boolean>", [detect], arguments.length);
        detectLocale = detect;
        return self2;
      };
      self2.getDetectLocale = () => detectLocale;
      var hasOutput = false;
      var exitError = null;
      self2.exit = (code, err) => {
        hasOutput = true;
        exitError = err;
        if (exitProcess)
          process.exit(code);
      };
      const _logger = {
        log(...args) {
          if (!self2._hasParseCallback())
            console.log(...args);
          hasOutput = true;
          if (output.length)
            output += "\n";
          output += args.join(" ");
        },
        error(...args) {
          if (!self2._hasParseCallback())
            console.error(...args);
          hasOutput = true;
          if (output.length)
            output += "\n";
          output += args.join(" ");
        }
      };
      self2._getLoggerInstance = () => _logger;
      self2._hasOutput = () => hasOutput;
      self2._setHasOutput = () => {
        hasOutput = true;
      };
      let recommendCommands;
      self2.recommendCommands = function(recommend = true) {
        argsert_1.argsert("[boolean]", [recommend], arguments.length);
        recommendCommands = recommend;
        return self2;
      };
      self2.getUsageInstance = () => usage;
      self2.getValidationInstance = () => validation;
      self2.getCommandInstance = () => command;
      self2.terminalWidth = () => {
        argsert_1.argsert([], 0);
        return typeof process.stdout.columns !== "undefined" ? process.stdout.columns : null;
      };
      Object.defineProperty(self2, "argv", {
        get: /* @__PURE__ */ __name(() => self2._parseArgs(processArgs), "get"),
        enumerable: true
      });
      self2._parseArgs = /* @__PURE__ */ __name(function parseArgs2(args, shortCircuit, _calledFromCommand, commandIndex) {
        let skipValidation = !!_calledFromCommand;
        args = args || processArgs;
        options.__ = y18n.__;
        options.configuration = self2.getParserConfiguration();
        const populateDoubleDash = !!options.configuration["populate--"];
        const config2 = Object.assign({}, options.configuration, {
          "populate--": true
        });
        const parsed = Parser.detailed(args, Object.assign({}, options, {
          configuration: config2
        }));
        let argv = parsed.argv;
        if (parseContext)
          argv = Object.assign({}, argv, parseContext);
        const aliases = parsed.aliases;
        argv.$0 = self2.$0;
        self2.parsed = parsed;
        try {
          guessLocale();
          if (shortCircuit) {
            return populateDoubleDash || _calledFromCommand ? argv : self2._copyDoubleDash(argv);
          }
          if (helpOpt) {
            const helpCmds = [helpOpt].concat(aliases[helpOpt] || []).filter((k32) => k32.length > 1);
            if (~helpCmds.indexOf(argv._[argv._.length - 1])) {
              argv._.pop();
              argv[helpOpt] = true;
            }
          }
          const handlerKeys = command.getCommands();
          const requestCompletions = completion.completionKey in argv;
          const skipRecommendation = argv[helpOpt] || requestCompletions;
          const skipDefaultCommand = skipRecommendation && (handlerKeys.length > 1 || handlerKeys[0] !== "$0");
          if (argv._.length) {
            if (handlerKeys.length) {
              let firstUnknownCommand;
              for (let i32 = commandIndex || 0, cmd; argv._[i32] !== void 0; i32++) {
                cmd = String(argv._[i32]);
                if (~handlerKeys.indexOf(cmd) && cmd !== completionCommand) {
                  const innerArgv = command.runCommand(cmd, self2, parsed, i32 + 1);
                  return populateDoubleDash ? innerArgv : self2._copyDoubleDash(innerArgv);
                } else if (!firstUnknownCommand && cmd !== completionCommand) {
                  firstUnknownCommand = cmd;
                  break;
                }
              }
              if (command.hasDefaultCommand() && !skipDefaultCommand) {
                const innerArgv = command.runCommand(null, self2, parsed);
                return populateDoubleDash ? innerArgv : self2._copyDoubleDash(innerArgv);
              }
              if (recommendCommands && firstUnknownCommand && !skipRecommendation) {
                validation.recommendCommands(firstUnknownCommand, handlerKeys);
              }
            }
            if (completionCommand && ~argv._.indexOf(completionCommand) && !requestCompletions) {
              if (exitProcess)
                setBlocking(true);
              self2.showCompletionScript();
              self2.exit(0);
            }
          } else if (command.hasDefaultCommand() && !skipDefaultCommand) {
            const innerArgv = command.runCommand(null, self2, parsed);
            return populateDoubleDash ? innerArgv : self2._copyDoubleDash(innerArgv);
          }
          if (requestCompletions) {
            if (exitProcess)
              setBlocking(true);
            args = [].concat(args);
            const completionArgs = args.slice(args.indexOf(`--${completion.completionKey}`) + 1);
            completion.getCompletion(completionArgs, (completions) => {
              ;
              (completions || []).forEach((completion2) => {
                _logger.log(completion2);
              });
              self2.exit(0);
            });
            return populateDoubleDash || _calledFromCommand ? argv : self2._copyDoubleDash(argv);
          }
          if (!hasOutput) {
            Object.keys(argv).forEach((key) => {
              if (key === helpOpt && argv[key]) {
                if (exitProcess)
                  setBlocking(true);
                skipValidation = true;
                self2.showHelp("log");
                self2.exit(0);
              } else if (key === versionOpt && argv[key]) {
                if (exitProcess)
                  setBlocking(true);
                skipValidation = true;
                usage.showVersion();
                self2.exit(0);
              }
            });
          }
          if (!skipValidation && options.skipValidation.length > 0) {
            skipValidation = Object.keys(argv).some((key) => options.skipValidation.indexOf(key) >= 0 && argv[key] === true);
          }
          if (!skipValidation) {
            if (parsed.error)
              throw new yerror_1.YError(parsed.error.message);
            if (!requestCompletions) {
              self2._runValidation(argv, aliases, {}, parsed.error);
            }
          }
        } catch (err) {
          if (err instanceof yerror_1.YError)
            usage.fail(err.message, err);
          else
            throw err;
        }
        return populateDoubleDash || _calledFromCommand ? argv : self2._copyDoubleDash(argv);
      }, "parseArgs");
      self2._copyDoubleDash = function(argv) {
        if (is_promise_1.isPromise(argv) || !argv._ || !argv["--"])
          return argv;
        argv._.push.apply(argv._, argv["--"]);
        try {
          delete argv["--"];
        } catch (_err) {
        }
        return argv;
      };
      self2._runValidation = /* @__PURE__ */ __name(function runValidation(argv, aliases, positionalMap, parseErrors, isDefaultCommand = false) {
        if (parseErrors)
          throw new yerror_1.YError(parseErrors.message);
        validation.nonOptionCount(argv);
        validation.requiredArguments(argv);
        let failedStrictCommands = false;
        if (strictCommands) {
          failedStrictCommands = validation.unknownCommands(argv);
        }
        if (strict && !failedStrictCommands) {
          validation.unknownArguments(argv, aliases, positionalMap, isDefaultCommand);
        }
        validation.customChecks(argv, aliases);
        validation.limitedChoices(argv);
        validation.implications(argv);
        validation.conflicting(argv);
      }, "runValidation");
      function guessLocale() {
        if (!detectLocale)
          return;
        const locale = process.env.LC_ALL || process.env.LC_MESSAGES || process.env.LANG || process.env.LANGUAGE || "en_US";
        self2.locale(locale.replace(/[.:].*/, ""));
      }
      __name(guessLocale, "guessLocale");
      self2.help();
      self2.version();
      return self2;
    }
    __name(Yargs, "Yargs");
    exports2.Yargs = Yargs;
    function rebase(base, dir) {
      return path47.relative(base, dir);
    }
    __name(rebase, "rebase");
    exports2.rebase = rebase;
    function isYargsInstance(y) {
      return !!y && typeof y._parseArgs === "function";
    }
    __name(isYargsInstance, "isYargsInstance");
    exports2.isYargsInstance = isYargsInstance;
  }
});

// node_modules/yargs/yargs.js
var require_yargs2 = __commonJS({
  "node_modules/yargs/yargs.js"(exports2, module2) {
    "use strict";
    async function requiresNode8OrGreater() {
    }
    __name(requiresNode8OrGreater, "requiresNode8OrGreater");
    requiresNode8OrGreater();
    var { Yargs, rebase } = require_yargs();
    var Parser = require_yargs_parser();
    exports2 = module2.exports = Yargs;
    exports2.rebase = rebase;
    exports2.Parser = Parser;
  }
});

// node_modules/yargs/index.js
var require_yargs3 = __commonJS({
  "node_modules/yargs/index.js"(exports2, module2) {
    "use strict";
    var yargs2 = require_yargs2();
    var processArgv = require_process_argv();
    Argv(processArgv.getProcessArgvWithoutBin());
    module2.exports = Argv;
    function Argv(processArgs, cwd) {
      const argv = yargs2(processArgs, cwd, require);
      singletonify(argv);
      return argv;
    }
    __name(Argv, "Argv");
    function singletonify(inst) {
      Object.keys(inst).forEach((key) => {
        if (key === "argv") {
          Argv.__defineGetter__(key, inst.__lookupGetter__(key));
        } else if (typeof inst[key] === "function") {
          Argv[key] = inst[key].bind(inst);
        } else {
          Argv.__defineGetter__("$0", () => {
            return inst.$0;
          });
          Argv.__defineGetter__("parsed", () => {
            return inst.parsed;
          });
        }
      });
    }
    __name(singletonify, "singletonify");
  }
});

// lib/cli/parse-command-line-arguments.ts
function parseCommandLineArguments(args) {
  return yargs.env("CDK").usage("Usage: cdk -a <cdk-app> COMMAND").option("app", {
    default: void 0,
    type: "string",
    alias: "a",
    desc: 'REQUIRED WHEN RUNNING APP: command-line for executing your app or a cloud assembly directory (e.g. "node bin/my-app.js"). Can also be specified in cdk.json or ~/.cdk.json',
    requiresArg: true
  }).option("build", {
    default: void 0,
    type: "string",
    desc: "Command-line for a pre-synth build"
  }).option("context", {
    type: "array",
    alias: "c",
    desc: "Add contextual string parameter (KEY=VALUE)",
    nargs: 1,
    requiresArg: true
  }).option("plugin", {
    type: "array",
    alias: "p",
    desc: "Name or path of a node package that extend the CDK features. Can be specified multiple times",
    nargs: 1,
    requiresArg: true
  }).option("trace", {
    default: void 0,
    type: "boolean",
    desc: "Print trace for stack warnings"
  }).option("strict", {
    default: void 0,
    type: "boolean",
    desc: "Do not construct stacks with warnings"
  }).option("lookups", {
    default: true,
    type: "boolean",
    desc: "Perform context lookups (synthesis fails if this is disabled and context lookups need to be performed)"
  }).option("ignore-errors", {
    default: false,
    type: "boolean",
    desc: "Ignores synthesis errors, which will likely produce an invalid output"
  }).option("json", {
    default: false,
    type: "boolean",
    alias: "j",
    desc: "Use JSON output instead of YAML when templates are printed to STDOUT"
  }).option("verbose", {
    default: false,
    type: "boolean",
    alias: "v",
    desc: "Show debug logs (specify multiple times to increase verbosity)",
    count: true
  }).option("debug", {
    default: false,
    type: "boolean",
    desc: "Produce more detailed output to help diagnose unexpected behavior for the CDK app and CDK CLI. Note that this will significantly slow down synthesis time."
  }).middleware(yargsImplies("debug", ["debugApp", "debugCli"]), true).option("debug-app", {
    default: false,
    type: "boolean",
    desc: "Debug the CDK app. Logs additional information during synthesis, such as creation stack traces and sets the CDK_DEBUG environment variable. Will slow down synthesis."
  }).option("debug-cli", {
    default: false,
    type: "boolean",
    desc: "Debug the CDK CLI itself."
  }).option("profile", {
    default: void 0,
    type: "string",
    desc: "Use the indicated AWS profile as the default environment",
    requiresArg: true
  }).option("region", {
    default: void 0,
    type: "string",
    desc: "Use the indicated AWS region as the default region",
    requiresArg: true
  }).option("proxy", {
    default: void 0,
    type: "string",
    desc: "Use the indicated proxy. Will read from HTTPS_PROXY environment variable if not specified",
    requiresArg: true
  }).option("ca-bundle-path", {
    default: void 0,
    type: "string",
    desc: "Path to CA certificate to use when validating HTTPS requests. Will read from AWS_CA_BUNDLE environment variable if not specified",
    requiresArg: true
  }).option("ec2creds", {
    default: void 0,
    type: "boolean",
    alias: "i",
    desc: "Force trying to fetch EC2 instance credentials. Default: guess EC2 instance status"
  }).option("version-reporting", {
    default: void 0,
    type: "boolean",
    desc: 'Disable CLI telemetry and do not include the "AWS::CDK::Metadata" resource in synthesized templates (enabled by default)',
    alias: "telemetry"
  }).option("path-metadata", {
    default: void 0,
    type: "boolean",
    desc: 'Include "aws:cdk:path" CloudFormation metadata for each resource (enabled by default)'
  }).option("asset-metadata", {
    default: void 0,
    type: "boolean",
    desc: 'Include "aws:asset:*" CloudFormation metadata for resources that uses assets (enabled by default)'
  }).option("role-arn", {
    default: void 0,
    type: "string",
    alias: "r",
    desc: "ARN of Role to use when invoking CloudFormation",
    requiresArg: true
  }).option("staging", {
    default: true,
    type: "boolean",
    desc: "Copy assets to the output directory (use --no-staging to disable the copy of assets which allows local debugging via the SAM CLI to reference the original source files)"
  }).option("output", {
    default: void 0,
    type: "string",
    alias: "o",
    desc: "Emits the synthesized cloud assembly into a directory (default: cdk.out)",
    requiresArg: true
  }).option("notices", {
    default: void 0,
    type: "boolean",
    desc: "Show relevant notices"
  }).option("no-color", {
    default: false,
    type: "boolean",
    desc: "Removes colors and other style from console output"
  }).option("color", {
    default: void 0,
    type: "boolean",
    desc: "Force colored output even when stdout is not a TTY"
  }).option("ci", {
    default: isCI2(),
    type: "boolean",
    desc: "Force CI detection. If CI=true then logs will be sent to stdout instead of stderr"
  }).option("unstable", {
    type: "array",
    desc: "Opt in to unstable features. The flag indicates that the scope and API of a feature might still change. Otherwise the feature is generally production ready and fully supported. Can be specified multiple times.",
    default: [],
    nargs: 1,
    requiresArg: true
  }).option("telemetry-file", {
    default: void 0,
    type: "string",
    desc: "Send telemetry data to a local file."
  }).option("yes", {
    default: false,
    type: "boolean",
    alias: "y",
    desc: "Automatically answer interactive prompts with the recommended response. This includes confirming actions."
  }).command(
    ["list [STACKS..]", "ls [STACKS..]"],
    "Lists all stacks in the app",
    (yargs2) => yargs2.option("long", {
      default: false,
      type: "boolean",
      alias: "l",
      desc: "Display environment information for each stack"
    }).option("show-dependencies", {
      default: false,
      type: "boolean",
      alias: "d",
      desc: "Display stack dependency information for each stack"
    })
  ).command(
    ["synth [STACKS..]", "synthesize [STACKS..]"],
    "Synthesizes and prints the CloudFormation template for this stack",
    (yargs2) => yargs2.option("exclusively", {
      default: void 0,
      type: "boolean",
      alias: "e",
      desc: "Only synthesize requested stacks, don't include dependencies"
    }).option("validation", {
      default: true,
      type: "boolean",
      desc: 'After synthesis, validate stacks with the "validateOnSynth" attribute set (can also be controlled with CDK_VALIDATION)'
    }).option("quiet", {
      default: false,
      type: "boolean",
      alias: "q",
      desc: "Do not output CloudFormation Template to stdout"
    })
  ).command(
    "bootstrap [ENVIRONMENTS..]",
    "Deploys the CDK toolkit stack into an AWS environment",
    (yargs2) => yargs2.option("bootstrap-bucket-name", {
      default: void 0,
      type: "string",
      alias: ["b", "toolkit-bucket-name"],
      desc: "The name of the CDK toolkit bucket; bucket will be created and must not exist"
    }).option("bootstrap-kms-key-id", {
      default: void 0,
      type: "string",
      desc: "AWS KMS master key ID used for the SSE-KMS encryption (specify AWS_MANAGED_KEY to use an AWS-managed key)",
      conflicts: "bootstrap-customer-key"
    }).option("example-permissions-boundary", {
      default: void 0,
      type: "boolean",
      alias: "epb",
      desc: "Use the example permissions boundary.",
      conflicts: "custom-permissions-boundary"
    }).option("custom-permissions-boundary", {
      default: void 0,
      type: "string",
      alias: "cpb",
      desc: "Use the permissions boundary specified by name.",
      conflicts: "example-permissions-boundary"
    }).option("bootstrap-customer-key", {
      default: void 0,
      type: "boolean",
      desc: "Create a Customer Master Key (CMK) for the bootstrap bucket (you will be charged but can customize permissions, modern bootstrapping only)",
      conflicts: "bootstrap-kms-key-id"
    }).option("qualifier", {
      default: void 0,
      type: "string",
      desc: "String which must be unique for each bootstrap stack. You must configure it on your CDK app if you change this from the default."
    }).option("public-access-block-configuration", {
      default: void 0,
      type: "boolean",
      desc: "Block public access configuration on CDK toolkit bucket (enabled by default) "
    }).option("deny-external-id", {
      default: void 0,
      type: "boolean",
      desc: "Block AssumeRole access to all boostrapped roles if an ExternalId is provided (enabled by default) "
    }).option("tags", {
      type: "array",
      alias: "t",
      desc: "Tags to add for the stack (KEY=VALUE)",
      default: [],
      nargs: 1,
      requiresArg: true
    }).option("execute", {
      default: true,
      type: "boolean",
      desc: "Whether to execute the change set (--no-execute will NOT execute the change set)"
    }).option("trust", {
      type: "array",
      desc: "The AWS account IDs that should be trusted to perform deployments into this environment (may be repeated, modern bootstrapping only)",
      default: [],
      nargs: 1,
      requiresArg: true
    }).option("trust-for-lookup", {
      type: "array",
      desc: "The AWS account IDs that should be trusted to look up values in this environment (may be repeated, modern bootstrapping only)",
      default: [],
      nargs: 1,
      requiresArg: true
    }).option("untrust", {
      type: "array",
      desc: "The AWS account IDs that should not be trusted by this environment (may be repeated, modern bootstrapping only)",
      default: [],
      nargs: 1,
      requiresArg: true
    }).option("cloudformation-execution-policies", {
      type: "array",
      desc: "The Managed Policy ARNs that should be attached to the role performing deployments into this environment (may be repeated, modern bootstrapping only)",
      default: [],
      nargs: 1,
      requiresArg: true
    }).option("force", {
      default: false,
      alias: "f",
      type: "boolean",
      desc: "Always bootstrap even if it would downgrade template version"
    }).option("termination-protection", {
      default: void 0,
      type: "boolean",
      desc: "Toggle CloudFormation termination protection on the bootstrap stacks"
    }).option("show-template", {
      default: false,
      type: "boolean",
      desc: "Instead of actual bootstrapping, print the current CLI's bootstrapping template to stdout for customization"
    }).option("toolkit-stack-name", {
      default: void 0,
      type: "string",
      desc: "The name of the CDK toolkit stack to create",
      requiresArg: true
    }).option("template", {
      default: void 0,
      type: "string",
      requiresArg: true,
      desc: "Use the template from the given file instead of the built-in one (use --show-template to obtain an example)"
    }).option("previous-parameters", {
      default: true,
      type: "boolean",
      desc: "Use previous values for existing parameters (you must specify all parameters on every deployment if this is disabled)"
    }).option("import-existing-resources", {
      default: true,
      type: "boolean",
      desc: "Whether to import existing resources into the bootstrap stack instead of failing if they already exist"
    })
  ).command(
    "gc [ENVIRONMENTS..]",
    "Garbage collect assets. Options detailed here: https://github.com/aws/aws-cdk-cli/tree/main/packages/aws-cdk#cdk-gc",
    (yargs2) => yargs2.option("action", {
      default: "full",
      type: "string",
      desc: 'The action (or sub-action) you want to perform. Valid entires are "print", "tag", "delete-tagged", "full".'
    }).option("type", {
      default: "all",
      type: "string",
      desc: "Specify either ecr, s3, or all"
    }).option("rollback-buffer-days", {
      default: 0,
      type: "number",
      desc: "Delete assets that have been marked as isolated for this many days"
    }).option("created-buffer-days", {
      default: 1,
      type: "number",
      desc: "Never delete assets younger than this (in days)"
    }).option("confirm", {
      default: true,
      type: "boolean",
      desc: "Confirm via manual prompt before deletion"
    }).option("toolkit-stack-name", {
      default: void 0,
      type: "string",
      desc: 'The name of the CDK toolkit stack, if different from the default "CDKToolkit"',
      requiresArg: true,
      conflicts: "bootstrap-stack-name"
    }).option("bootstrap-stack-name", {
      default: void 0,
      type: "string",
      desc: 'The name of the CDK toolkit stack, if different from the default "CDKToolkit" (deprecated, use --toolkit-stack-name)',
      deprecated: "use --toolkit-stack-name",
      requiresArg: true,
      conflicts: "toolkit-stack-name"
    })
  ).command(
    "flags [FLAGNAME..]",
    "View and toggle feature flags.",
    (yargs2) => yargs2.option("value", {
      default: void 0,
      type: "string",
      desc: "The value the user would like to set the feature flag configuration to",
      requiresArg: true
    }).option("set", {
      default: void 0,
      type: "boolean",
      desc: "Signifies the user would like to modify their feature flag configuration",
      requiresArg: false
    }).option("all", {
      default: void 0,
      type: "boolean",
      desc: "Modify or view all feature flags",
      requiresArg: false
    }).option("unconfigured", {
      default: void 0,
      type: "boolean",
      desc: "Modify unconfigured feature flags",
      requiresArg: false
    }).option("recommended", {
      default: void 0,
      type: "boolean",
      desc: "Change flags to recommended states",
      requiresArg: false
    }).option("default", {
      default: void 0,
      type: "boolean",
      desc: "Change flags to default state",
      requiresArg: false
    }).option("interactive", {
      default: void 0,
      type: "boolean",
      alias: ["i"],
      desc: "Interactive option for the flags command"
    }).option("safe", {
      default: void 0,
      type: "boolean",
      desc: "Enable all feature flags that do not impact the user's application",
      requiresArg: false
    }).option("concurrency", {
      default: 4,
      type: "number",
      alias: ["n"],
      desc: "Maximum number of simultaneous synths to execute.",
      requiresArg: true
    })
  ).command(
    "deploy [STACKS..]",
    "Deploys the stack(s) named STACKS into your AWS account",
    (yargs2) => yargs2.option("all", {
      default: false,
      type: "boolean",
      desc: "Deploy all available stacks"
    }).option("build-exclude", {
      type: "array",
      alias: "E",
      desc: "Do not rebuild asset with the given ID. Can be specified multiple times",
      default: [],
      nargs: 1,
      requiresArg: true
    }).option("exclusively", {
      default: void 0,
      type: "boolean",
      alias: "e",
      desc: "Only deploy requested stacks, don't include dependencies"
    }).option("require-approval", {
      default: void 0,
      type: "string",
      choices: ["never", "any-change", "broadening"],
      desc: "What changes require manual approval"
    }).option("notification-arns", {
      type: "array",
      desc: "ARNs of SNS topics that CloudFormation will notify with stack related events. These will be added to ARNs specified with the 'notificationArns' stack property.",
      nargs: 1,
      requiresArg: true
    }).option("tags", {
      type: "array",
      alias: "t",
      desc: "Tags to add to the stack (KEY=VALUE), overrides tags from Cloud Assembly (deprecated)",
      nargs: 1,
      requiresArg: true
    }).option("execute", {
      default: void 0,
      type: "boolean",
      desc: "Whether to execute the change set (--no-execute will NOT execute the change set) (deprecated)",
      deprecated: true
    }).option("change-set-name", {
      default: void 0,
      type: "string",
      desc: "Name of the CloudFormation change set to create (only if method is not direct)"
    }).option("method", {
      default: void 0,
      alias: "m",
      type: "string",
      choices: ["direct", "change-set", "prepare-change-set", "execute-change-set"],
      requiresArg: true,
      desc: 'How to perform the deployment. "change-set" (default) creates and executes a change set. "prepare-change-set" creates a change set without executing it. "execute-change-set" executes a previously created change set, bypassing synthesis entirely. "direct" skips change sets for faster deployments but lacks progress information'
    }).option("import-existing-resources", {
      default: false,
      type: "boolean",
      desc: "Indicates if the stack set imports resources that already exist."
    }).option("force", {
      default: false,
      alias: "f",
      type: "boolean",
      desc: "Always deploy stack even if templates are identical"
    }).option("parameters", {
      type: "array",
      desc: "Additional parameters passed to CloudFormation at deploy time (STACK:KEY=VALUE)",
      default: {},
      nargs: 1,
      requiresArg: true
    }).option("outputs-file", {
      default: void 0,
      type: "string",
      alias: "O",
      desc: "Path to file where stack outputs will be written as JSON",
      requiresArg: true
    }).option("previous-parameters", {
      default: true,
      type: "boolean",
      desc: "Use previous values for existing parameters (you must specify all parameters on every deployment if this is disabled)"
    }).option("toolkit-stack-name", {
      default: void 0,
      type: "string",
      desc: "The name of the existing CDK toolkit stack (only used for app using legacy synthesis)",
      requiresArg: true
    }).option("progress", {
      default: void 0,
      type: "string",
      choices: ["bar", "events"],
      desc: "Display mode for stack activity events"
    }).option("rollback", {
      default: void 0,
      type: "boolean",
      desc: "Rollback stack to stable state on failure. Defaults to 'true', iterate more rapidly with --no-rollback or -R. Note: do **not** disable this flag for deployments with resource replacements, as that will always fail"
    }).option("R", { type: "boolean", hidden: true }).middleware(yargsNegativeAlias("R", "rollback"), true).option("hotswap", {
      default: void 0,
      type: "boolean",
      desc: "Attempts to perform a 'hotswap' deployment, but does not fall back to a full deployment if that is not possible. Instead, changes to any non-hotswappable properties are ignored.Do not use this in production environments"
    }).option("hotswap-fallback", {
      default: void 0,
      type: "boolean",
      desc: "Attempts to perform a 'hotswap' deployment, which skips CloudFormation and updates the resources directly, and falls back to a full deployment if that is not possible. Do not use this in production environments"
    }).option("hotswap-ecs-minimum-healthy-percent", {
      default: void 0,
      type: "number",
      desc: "Lower limit on the number of your service's tasks that must remain in the RUNNING state during a deployment, as a percentage of the desiredCount"
    }).option("hotswap-ecs-maximum-healthy-percent", {
      default: void 0,
      type: "number",
      desc: "Upper limit on the number of your service's tasks that are allowed in the RUNNING or PENDING state during a deployment, as a percentage of the desiredCount"
    }).option("hotswap-ecs-stabilization-timeout-seconds", {
      default: void 0,
      type: "number",
      desc: "Number of seconds to wait for a single service to reach stable state, where the desiredCount is equal to the runningCount"
    }).option("watch", {
      default: void 0,
      type: "boolean",
      desc: "Continuously observe the project files, and deploy the given stack(s) automatically when changes are detected. Implies --hotswap by default"
    }).option("logs", {
      default: true,
      type: "boolean",
      desc: "Show CloudWatch log events from all resources in the selected Stacks in the terminal. 'true' by default, use --no-logs to turn off. Only in effect if specified alongside the '--watch' option"
    }).option("concurrency", {
      default: 1,
      type: "number",
      desc: "Maximum number of simultaneous deployments (dependency permitting) to execute.",
      requiresArg: true
    }).option("asset-parallelism", {
      default: void 0,
      type: "boolean",
      desc: "Whether to build/publish assets in parallel"
    }).option("asset-build-concurrency", {
      default: 1,
      type: "number",
      desc: "Maximum number of asset builds to run in parallel",
      requiresArg: true
    }).option("asset-prebuild", {
      default: true,
      type: "boolean",
      desc: "Whether to build all assets before deploying the first stack (useful for failing Docker builds)"
    }).option("ignore-no-stacks", {
      default: false,
      type: "boolean",
      desc: "Whether to deploy if the app contains no stacks"
    }).option("revert-drift", {
      default: false,
      type: "boolean",
      desc: "Create a drift-aware change set that brings actual resource states in line with template definitions"
    })
  ).command(
    "validate [STACKS..]",
    "Validate synthesized CloudFormation templates against policy rules",
    (yargs2) => yargs2.option("online", {
      default: true,
      type: "boolean",
      desc: "Submit templates to CloudFormation for early validation (requires AWS credentials)"
    })
  ).command(
    "diagnose [STACKS..]",
    "Find the root cause(s) of stack deployment failures",
    (yargs2) => yargs2.option("toolkit-stack-name", {
      default: void 0,
      type: "string",
      desc: "The name of the existing CDK toolkit stack (only used for app using legacy synthesis)",
      requiresArg: true
    }).option("concurrency", {
      default: void 0,
      type: "number",
      desc: "How many stacks to diagnose in parallel",
      requiresArg: true
    })
  ).command(
    "rollback [STACKS..]",
    "Rolls back the stack(s) named STACKS to their last stable state",
    (yargs2) => yargs2.option("all", {
      default: false,
      type: "boolean",
      desc: "Roll back all available stacks"
    }).option("toolkit-stack-name", {
      default: void 0,
      type: "string",
      desc: "The name of the CDK toolkit stack the environment is bootstrapped with",
      requiresArg: true
    }).option("force", {
      default: void 0,
      alias: "f",
      type: "boolean",
      desc: "Orphan all resources for which the rollback operation fails."
    }).option("validate-bootstrap-version", {
      default: void 0,
      type: "boolean",
      desc: "Whether to validate the bootstrap stack version. Defaults to 'true', disable with --no-validate-bootstrap-version."
    }).option("orphan", {
      type: "array",
      desc: "Orphan the given resources, identified by their logical ID (can be specified multiple times)",
      default: [],
      nargs: 1,
      requiresArg: true
    })
  ).command(
    "publish-assets [STACKS..]",
    "Publish assets for the given stack(s) without deploying",
    (yargs2) => yargs2.option("all", {
      default: false,
      type: "boolean",
      desc: "Publish assets for all available stacks"
    }).option("exclusively", {
      default: void 0,
      type: "boolean",
      alias: "e",
      desc: "Only publish assets for requested stacks, don't include dependencies"
    }).option("force", {
      default: false,
      type: "boolean",
      alias: "f",
      desc: "Always publish assets, even if they are already published"
    }).option("concurrency", {
      default: 4,
      type: "number",
      desc: "Maximum number of simultaneous asset operations (building and publishing, dependency permitting) to execute.",
      requiresArg: true
    })
  ).command(
    "import [STACK]",
    "Import existing resource(s) into the given STACK",
    (yargs2) => yargs2.option("execute", {
      default: true,
      type: "boolean",
      desc: "Whether to execute the change set (--no-execute will NOT execute the change set)"
    }).option("change-set-name", {
      default: void 0,
      type: "string",
      desc: "Name of the CloudFormation change set to create"
    }).option("toolkit-stack-name", {
      default: void 0,
      type: "string",
      desc: "The name of the CDK toolkit stack to create",
      requiresArg: true
    }).option("rollback", {
      default: void 0,
      type: "boolean",
      desc: "Rollback stack to stable state on failure. Defaults to 'true', iterate more rapidly with --no-rollback or -R. Note: do **not** disable this flag for deployments with resource replacements, as that will always fail"
    }).option("force", {
      default: void 0,
      alias: "f",
      type: "boolean",
      desc: "Do not abort if the template diff includes updates or deletes. This is probably safe but we're not sure, let us know how it goes."
    }).option("record-resource-mapping", {
      default: void 0,
      type: "string",
      requiresArg: true,
      desc: "If specified, CDK will generate a mapping of existing physical resources to CDK resources to be imported as. The mapping will be written in the given file path. No actual import operation will be performed"
    }).option("resource-mapping", {
      default: void 0,
      type: "string",
      alias: "m",
      requiresArg: true,
      desc: "If specified, CDK will use the given file to map physical resources to CDK resources for import, instead of interactively asking the user. Can be run from scripts"
    }).option("resource-mapping-inline", {
      default: void 0,
      type: "string",
      requiresArg: true,
      desc: `Inline JSON resource mapping, e.g. '{"MyResource":{"TableName":"my-table"}}'`
    })
  ).command(
    "watch [STACKS..]",
    "Shortcut for 'deploy --watch'",
    (yargs2) => yargs2.option("build-exclude", {
      type: "array",
      alias: "E",
      desc: "Do not rebuild asset with the given ID. Can be specified multiple times",
      default: [],
      nargs: 1,
      requiresArg: true
    }).option("exclusively", {
      default: void 0,
      type: "boolean",
      alias: "e",
      desc: "Only deploy requested stacks, don't include dependencies"
    }).option("change-set-name", {
      default: void 0,
      type: "string",
      desc: "Name of the CloudFormation change set to create"
    }).option("force", {
      default: false,
      alias: "f",
      type: "boolean",
      desc: "Always deploy stack even if templates are identical"
    }).option("toolkit-stack-name", {
      default: void 0,
      type: "string",
      desc: "The name of the existing CDK toolkit stack (only used for app using legacy synthesis)",
      requiresArg: true
    }).option("progress", {
      default: void 0,
      type: "string",
      choices: ["bar", "events"],
      desc: "Display mode for stack activity events"
    }).option("rollback", {
      default: void 0,
      type: "boolean",
      desc: "Rollback stack to stable state on failure. Defaults to 'true', iterate more rapidly with --no-rollback or -R. Note: do **not** disable this flag for deployments with resource replacements, as that will always fail"
    }).option("R", { type: "boolean", hidden: true }).middleware(yargsNegativeAlias("R", "rollback"), true).option("hotswap", {
      default: void 0,
      type: "boolean",
      desc: "Attempts to perform a 'hotswap' deployment, but does not fall back to a full deployment if that is not possible. Instead, changes to any non-hotswappable properties are ignored.'true' by default, use --no-hotswap to turn off"
    }).option("hotswap-fallback", {
      default: void 0,
      type: "boolean",
      desc: "Attempts to perform a 'hotswap' deployment, which skips CloudFormation and updates the resources directly, and falls back to a full deployment if that is not possible."
    }).option("hotswap-ecs-minimum-healthy-percent", {
      default: void 0,
      type: "number",
      desc: "Lower limit on the number of your service's tasks that must remain in the RUNNING state during a deployment, as a percentage of the desiredCount"
    }).option("hotswap-ecs-maximum-healthy-percent", {
      default: void 0,
      type: "number",
      desc: "Upper limit on the number of your service's tasks that are allowed in the RUNNING or PENDING state during a deployment, as a percentage of the desiredCount"
    }).option("hotswap-ecs-stabilization-timeout-seconds", {
      default: void 0,
      type: "number",
      desc: "Number of seconds to wait for a single service to reach stable state, where the desiredCount is equal to the runningCount"
    }).option("logs", {
      default: true,
      type: "boolean",
      desc: "Show CloudWatch log events from all resources in the selected Stacks in the terminal. 'true' by default, use --no-logs to turn off"
    }).option("concurrency", {
      default: 1,
      type: "number",
      desc: "Maximum number of simultaneous deployments (dependency permitting) to execute.",
      requiresArg: true
    })
  ).command(
    "destroy [STACKS..]",
    "Destroy the stack(s) named STACKS",
    (yargs2) => yargs2.option("all", {
      default: false,
      type: "boolean",
      desc: "Destroy all available stacks"
    }).option("exclusively", {
      default: void 0,
      type: "boolean",
      alias: "e",
      desc: "Only destroy requested stacks, don't include dependees"
    }).option("force", {
      default: void 0,
      type: "boolean",
      alias: "f",
      desc: "Do not ask for confirmation before destroying the stacks"
    }).option("concurrency", {
      default: 1,
      type: "number",
      desc: "Maximum number of simultaneous destroys (dependency permitting) to execute.",
      requiresArg: true
    })
  ).command(
    "diff [STACKS..]",
    "Compares the specified stack with the deployed stack or a local template file, and returns with status 1 if any difference is found",
    (yargs2) => yargs2.option("exclusively", {
      default: void 0,
      type: "boolean",
      alias: "e",
      desc: "Only diff requested stacks, don't include dependencies"
    }).option("context-lines", {
      default: 3,
      type: "number",
      desc: "Number of context lines to include in arbitrary JSON diff rendering",
      requiresArg: true
    }).option("template", {
      default: void 0,
      type: "string",
      desc: "The path to the CloudFormation template to compare with. Implies --method=template",
      requiresArg: true
    }).option("strict", {
      default: false,
      type: "boolean",
      desc: "Do not filter out AWS::CDK::Metadata resources, mangled non-ASCII characters, or the CheckBootstrapVersionRule"
    }).option("security-only", {
      default: false,
      type: "boolean",
      desc: "Only diff for broadened security changes"
    }).option("fail", {
      default: void 0,
      type: "boolean",
      desc: "Fail with exit code 1 in case of diff"
    }).option("processed", {
      default: false,
      type: "boolean",
      desc: "Whether to compare against the template with Transforms already processed"
    }).option("quiet", {
      default: false,
      type: "boolean",
      alias: "q",
      desc: "Do not print stack name and default message when there is no diff to stdout"
    }).option("change-set", {
      default: true,
      type: "boolean",
      alias: "changeset",
      desc: "Whether to create a change set to analyze resource replacements. In this mode, diff will use the deploy role instead of the lookup role.",
      deprecated: "use --method instead"
    }).option("method", {
      default: "auto",
      alias: "m",
      type: "string",
      choices: ["auto", "change-set", "template"],
      requiresArg: true,
      desc: 'How to compute the diff. "auto" attempts to create a change set and falls back to template-only on failure. "change-set" creates a change set and fails if it cannot be created. Both use the deploy role instead of the lookup role. "template" compares templates directly and uses the lookup role.'
    }).option("import-existing-resources", {
      default: false,
      type: "boolean",
      desc: "Whether or not the change set imports resources that already exist"
    }).option("include-moves", {
      default: false,
      type: "boolean",
      desc: "Whether to include moves in the diff"
    })
  ).command(
    "drift [STACKS..]",
    "Detect drifts in the given CloudFormation stack(s)",
    (yargs2) => yargs2.option("fail", {
      default: void 0,
      type: "boolean",
      desc: "Fail with exit code 1 if drift is detected"
    })
  ).command("metadata [STACK]", "Returns all metadata associated with this stack").command(["acknowledge [ID]", "ack [ID]"], "Acknowledge a notice so that it does not show up anymore").command(
    "notices",
    "Returns a list of relevant notices",
    (yargs2) => yargs2.option("unacknowledged", {
      default: false,
      type: "boolean",
      alias: "u",
      desc: "Returns a list of unacknowledged notices"
    })
  ).command(
    "init [TEMPLATE]",
    "Create a new, empty CDK project from a template.",
    (yargs2) => yargs2.option("language", {
      default: void 0,
      type: "string",
      alias: "l",
      desc: "The language to be used for the new project (default can be configured in ~/.cdk.json)",
      choices: ["csharp", "cs", "fsharp", "fs", "go", "java", "javascript", "js", "python", "py", "typescript", "ts"]
    }).option("list", {
      default: void 0,
      type: "boolean",
      desc: "List the available templates"
    }).option("generate-only", {
      default: false,
      type: "boolean",
      desc: "If true, only generates project files, without executing additional operations such as setting up a git repo, installing dependencies or compiling the project"
    }).option("lib-version", {
      default: void 0,
      type: "string",
      alias: "V",
      desc: "The version of the CDK library (aws-cdk-lib) to initialize built-in templates with. Defaults to the version that was current when this CLI was built."
    }).option("from-path", {
      default: void 0,
      type: "string",
      desc: "Path to a local custom template directory or multi-template repository",
      requiresArg: true,
      conflicts: ["lib-version"]
    }).option("template-path", {
      default: void 0,
      type: "string",
      desc: "Path to a specific template within a multi-template repository",
      requiresArg: true
    }).option("package-manager", {
      default: void 0,
      type: "string",
      desc: "The package manager to use to install dependencies. Only applicable for TypeScript and JavaScript projects. Defaults to npm in TypeScript and JavaScript projects.",
      choices: ["npm", "yarn", "pnpm", "bun"]
    }).option("project-name", {
      default: void 0,
      type: "string",
      alias: "n",
      desc: "The name of the new project",
      requiresArg: true
    })
  ).command(
    "migrate",
    "Migrate existing AWS resources into a CDK app",
    (yargs2) => yargs2.option("stack-name", {
      default: void 0,
      type: "string",
      alias: "n",
      desc: "The name assigned to the stack created in the new project. The name of the app will be based off this name as well.",
      requiresArg: true
    }).option("language", {
      default: "typescript",
      type: "string",
      alias: "l",
      desc: "The language to be used for the new project",
      choices: ["typescript", "ts", "go", "java", "python", "py", "csharp", "cs"]
    }).option("account", {
      default: void 0,
      type: "string",
      desc: "The account to retrieve the CloudFormation stack template from"
    }).option("region", {
      default: void 0,
      type: "string",
      desc: "The region to retrieve the CloudFormation stack template from"
    }).option("from-path", {
      default: void 0,
      type: "string",
      desc: "The path to the CloudFormation template to migrate. Use this for locally stored templates"
    }).option("from-stack", {
      default: void 0,
      type: "boolean",
      desc: "Use this flag to retrieve the template for an existing CloudFormation stack"
    }).option("output-path", {
      default: void 0,
      type: "string",
      desc: "The output path for the migrated CDK app"
    }).option("from-scan", {
      default: void 0,
      type: "string",
      desc: 'Determines if a new scan should be created, or the last successful existing scan should be used \n options are "new" or "most-recent"'
    }).option("filter", {
      type: "array",
      desc: 'Filters the resource scan based on the provided criteria in the following format: "key1=value1,key2=value2"\n This field can be passed multiple times for OR style filtering: \n filtering options: \n resource-identifier: A key-value pair that identifies the target resource. i.e. {"ClusterName", "myCluster"}\n resource-type-prefix: A string that represents a type-name prefix. i.e. "AWS::DynamoDB::"\n tag-key: a string that matches resources with at least one tag with the provided key. i.e. "myTagKey"\n tag-value: a string that matches resources with at least one tag with the provided value. i.e. "myTagValue"',
      nargs: 1,
      requiresArg: true
    }).option("compress", {
      default: void 0,
      type: "boolean",
      desc: "Use this flag to zip the generated CDK app"
    })
  ).command(
    "context",
    "Manage cached context values",
    (yargs2) => yargs2.option("reset", {
      default: void 0,
      alias: "e",
      desc: "The context key (or its index) to reset",
      type: "string",
      requiresArg: true
    }).option("force", {
      default: false,
      alias: "f",
      desc: "Ignore missing key error",
      type: "boolean"
    }).option("clear", {
      default: false,
      desc: "Clear all context",
      type: "boolean"
    })
  ).command(
    ["docs", "doc"],
    "Opens the reference documentation in a browser",
    (yargs2) => yargs2.option("browser", {
      default: browserForPlatform(),
      alias: "b",
      desc: "the command to use to open the browser, using %u as a placeholder for the path of the file to open",
      type: "string"
    })
  ).command("doctor", "Check your set-up for potential problems").command("orphan [PATHS..]", "Detach resources from a CloudFormation stack without deleting them", (yargs2) => yargs2).command(
    "refactor [STACKS..]",
    "Moves resources between stacks or within the same stack",
    (yargs2) => yargs2.option("additional-stack-name", {
      type: "array",
      requiresArg: true,
      desc: "Names of deployed stacks to be considered for resource comparison.",
      nargs: 1
    }).option("dry-run", {
      default: false,
      type: "boolean",
      desc: "Do not perform any changes, just show what would be done"
    }).option("override-file", {
      default: void 0,
      type: "string",
      requiresArg: true,
      desc: "A file that declares overrides to be applied to the list of mappings computed by the CLI."
    }).option("revert", {
      default: false,
      type: "boolean",
      desc: "If specified, the command will revert the refactor operation. This is only valid if a mapping file was provided."
    }).option("force", {
      default: false,
      type: "boolean",
      desc: "Whether to do the refactor without asking for confirmation"
    })
  ).command(
    "cli-telemetry",
    "Enable or disable anonymous telemetry",
    (yargs2) => yargs2.option("enable", {
      default: void 0,
      type: "boolean",
      desc: "Enable anonymous telemetry",
      conflicts: "disable"
    }).option("disable", {
      default: void 0,
      type: "boolean",
      desc: "Disable anonymous telemetry",
      conflicts: "enable"
    }).option("status", {
      default: void 0,
      type: "boolean",
      desc: "Report telemetry opt-in/out status",
      conflicts: ["enable", "disable"]
    })
  ).version(cliVersion()).demandCommand(1, "").recommendCommands().help().alias("h", "help").epilogue(
    "If your app has a single stack, there is no need to specify the stack name\n\nIf one of cdk.json or ~/.cdk.json exists, options specified there will be used as defaults. Settings in cdk.json take precedence."
  ).parse(args);
}
var yargs;
var init_parse_command_line_arguments = __esm({
  "lib/cli/parse-command-line-arguments.ts"() {
    "use strict";
    init_yargs_helpers();
    __name(parseCommandLineArguments, "parseCommandLineArguments");
    yargs = require_yargs3();
  }
});

// lib/cli/platform-warnings.ts
async function checkForPlatformWarnings(ioHelper) {
  if (await hasDockerCopyBug()) {
    await ioHelper.defaults.warn("`cdk synth` may hang in Docker on Linux 5.6-5.10. See https://github.com/aws/aws-cdk/issues/21379 for workarounds.");
  }
}
async function hasDockerCopyBug() {
  return await runningInDocker() && os13.platform() === "linux" && isVersionBetween(os13.release(), "5.6", "5.10");
}
async function runningInDocker() {
  return fs49.pathExists("/.dockerenv");
}
function isVersionBetween(version, lower, upper) {
  const ver = splitVersion(version);
  const lo = splitVersion(lower);
  const up = splitVersion(upper);
  while (lo.length < ver.length) {
    lo.push(0);
  }
  while (up.length < ver.length) {
    up.push(9999999);
  }
  let n10 = ver.length;
  for (let i32 = 0; i32 < n10; i32++) {
    if (lo[i32] < ver[i32] && ver[i32] < up[i32]) {
      return true;
    }
    if (lo[i32] > ver[i32] || ver[i32] > up[i32]) {
      return false;
    }
  }
  return false;
}
function splitVersion(version) {
  return `${version}`.split(".").map((x) => parseInt(x, 10)).map((x) => isNaN(x) ? 0 : x);
}
var os13, fs49;
var init_platform_warnings = __esm({
  "lib/cli/platform-warnings.ts"() {
    "use strict";
    os13 = __toESM(require("os"));
    fs49 = __toESM(require_lib4());
    __name(checkForPlatformWarnings, "checkForPlatformWarnings");
    __name(hasDockerCopyBug, "hasDockerCopyBug");
    __name(runningInDocker, "runningInDocker");
    __name(isVersionBetween, "isVersionBetween");
    __name(splitVersion, "splitVersion");
  }
});

// lib/cli/pretty-print-error.ts
function prettyPrintError(error4, debug2 = false) {
  const err = ensureError(error4);
  console.error(chalk34.red(err.message));
  if (err.cause) {
    const cause = ensureError(err.cause);
    console.error(chalk34.yellow(cause.message));
    printTrace(cause, debug2);
  }
  printTrace(err, debug2);
}
function printTrace(err, debug2 = false) {
  if (err.stack && debug2) {
    console.debug(chalk34.gray(err.stack));
  }
}
function ensureError(value) {
  if (value instanceof Error) return value;
  let stringified = "[Unable to stringify the thrown value]";
  try {
    stringified = JSON.stringify(value);
  } catch {
  }
  const error4 = new Error(`An unexpected error was thrown: ${stringified}`);
  return error4;
}
var chalk34;
var init_pretty_print_error = __esm({
  "lib/cli/pretty-print-error.ts"() {
    "use strict";
    chalk34 = __toESM(require_source());
    __name(prettyPrintError, "prettyPrintError");
    __name(printTrace, "printTrace");
    __name(ensureError, "ensureError");
  }
});

// ../../node_modules/proxy-agent/node_modules/lru-cache/index.js
var require_lru_cache = __commonJS({
  "../../node_modules/proxy-agent/node_modules/lru-cache/index.js"(exports2, module2) {
    var perf = typeof performance === "object" && performance && typeof performance.now === "function" ? performance : Date;
    var hasAbortController = typeof AbortController === "function";
    var AC = hasAbortController ? AbortController : class AbortController {
      static {
        __name(this, "AbortController");
      }
      constructor() {
        this.signal = new AS();
      }
      abort(reason = new Error("This operation was aborted")) {
        this.signal.reason = this.signal.reason || reason;
        this.signal.aborted = true;
        this.signal.dispatchEvent({
          type: "abort",
          target: this.signal
        });
      }
    };
    var hasAbortSignal = typeof AbortSignal === "function";
    var hasACAbortSignal = typeof AC.AbortSignal === "function";
    var AS = hasAbortSignal ? AbortSignal : hasACAbortSignal ? AC.AbortController : class AbortSignal {
      static {
        __name(this, "AbortSignal");
      }
      constructor() {
        this.reason = void 0;
        this.aborted = false;
        this._listeners = [];
      }
      dispatchEvent(e32) {
        if (e32.type === "abort") {
          this.aborted = true;
          this.onabort(e32);
          this._listeners.forEach((f32) => f32(e32), this);
        }
      }
      onabort() {
      }
      addEventListener(ev, fn) {
        if (ev === "abort") {
          this._listeners.push(fn);
        }
      }
      removeEventListener(ev, fn) {
        if (ev === "abort") {
          this._listeners = this._listeners.filter((f32) => f32 !== fn);
        }
      }
    };
    var warned = /* @__PURE__ */ new Set();
    var deprecatedOption = /* @__PURE__ */ __name((opt, instead) => {
      const code = `LRU_CACHE_OPTION_${opt}`;
      if (shouldWarn(code)) {
        warn2(code, `${opt} option`, `options.${instead}`, LRUCache);
      }
    }, "deprecatedOption");
    var deprecatedMethod = /* @__PURE__ */ __name((method, instead) => {
      const code = `LRU_CACHE_METHOD_${method}`;
      if (shouldWarn(code)) {
        const { prototype } = LRUCache;
        const { get: get4 } = Object.getOwnPropertyDescriptor(prototype, method);
        warn2(code, `${method} method`, `cache.${instead}()`, get4);
      }
    }, "deprecatedMethod");
    var deprecatedProperty = /* @__PURE__ */ __name((field, instead) => {
      const code = `LRU_CACHE_PROPERTY_${field}`;
      if (shouldWarn(code)) {
        const { prototype } = LRUCache;
        const { get: get4 } = Object.getOwnPropertyDescriptor(prototype, field);
        warn2(code, `${field} property`, `cache.${instead}`, get4);
      }
    }, "deprecatedProperty");
    var emitWarning = /* @__PURE__ */ __name((...a32) => {
      typeof process === "object" && process && typeof process.emitWarning === "function" ? process.emitWarning(...a32) : console.error(...a32);
    }, "emitWarning");
    var shouldWarn = /* @__PURE__ */ __name((code) => !warned.has(code), "shouldWarn");
    var warn2 = /* @__PURE__ */ __name((code, what, instead, fn) => {
      warned.add(code);
      const msg = `The ${what} is deprecated. Please use ${instead} instead.`;
      emitWarning(msg, "DeprecationWarning", code, fn);
    }, "warn");
    var isPosInt = /* @__PURE__ */ __name((n10) => n10 && n10 === Math.floor(n10) && n10 > 0 && isFinite(n10), "isPosInt");
    var getUintArray = /* @__PURE__ */ __name((max) => !isPosInt(max) ? null : max <= Math.pow(2, 8) ? Uint8Array : max <= Math.pow(2, 16) ? Uint16Array : max <= Math.pow(2, 32) ? Uint32Array : max <= Number.MAX_SAFE_INTEGER ? ZeroArray : null, "getUintArray");
    var ZeroArray = class extends Array {
      static {
        __name(this, "ZeroArray");
      }
      constructor(size) {
        super(size);
        this.fill(0);
      }
    };
    var Stack = class {
      static {
        __name(this, "Stack");
      }
      constructor(max) {
        if (max === 0) {
          return [];
        }
        const UintArray = getUintArray(max);
        this.heap = new UintArray(max);
        this.length = 0;
      }
      push(n10) {
        this.heap[this.length++] = n10;
      }
      pop() {
        return this.heap[--this.length];
      }
    };
    var LRUCache = class _LRUCache {
      static {
        __name(this, "LRUCache");
      }
      constructor(options = {}) {
        const {
          max = 0,
          ttl,
          ttlResolution = 1,
          ttlAutopurge,
          updateAgeOnGet,
          updateAgeOnHas,
          allowStale,
          dispose,
          disposeAfter,
          noDisposeOnSet,
          noUpdateTTL,
          maxSize = 0,
          maxEntrySize = 0,
          sizeCalculation,
          fetchMethod,
          fetchContext,
          noDeleteOnFetchRejection,
          noDeleteOnStaleGet,
          allowStaleOnFetchRejection,
          allowStaleOnFetchAbort,
          ignoreFetchAbort
        } = options;
        const { length, maxAge, stale } = options instanceof _LRUCache ? {} : options;
        if (max !== 0 && !isPosInt(max)) {
          throw new TypeError("max option must be a nonnegative integer");
        }
        const UintArray = max ? getUintArray(max) : Array;
        if (!UintArray) {
          throw new Error("invalid max value: " + max);
        }
        this.max = max;
        this.maxSize = maxSize;
        this.maxEntrySize = maxEntrySize || this.maxSize;
        this.sizeCalculation = sizeCalculation || length;
        if (this.sizeCalculation) {
          if (!this.maxSize && !this.maxEntrySize) {
            throw new TypeError(
              "cannot set sizeCalculation without setting maxSize or maxEntrySize"
            );
          }
          if (typeof this.sizeCalculation !== "function") {
            throw new TypeError("sizeCalculation set to non-function");
          }
        }
        this.fetchMethod = fetchMethod || null;
        if (this.fetchMethod && typeof this.fetchMethod !== "function") {
          throw new TypeError(
            "fetchMethod must be a function if specified"
          );
        }
        this.fetchContext = fetchContext;
        if (!this.fetchMethod && fetchContext !== void 0) {
          throw new TypeError(
            "cannot set fetchContext without fetchMethod"
          );
        }
        this.keyMap = /* @__PURE__ */ new Map();
        this.keyList = new Array(max).fill(null);
        this.valList = new Array(max).fill(null);
        this.next = new UintArray(max);
        this.prev = new UintArray(max);
        this.head = 0;
        this.tail = 0;
        this.free = new Stack(max);
        this.initialFill = 1;
        this.size = 0;
        if (typeof dispose === "function") {
          this.dispose = dispose;
        }
        if (typeof disposeAfter === "function") {
          this.disposeAfter = disposeAfter;
          this.disposed = [];
        } else {
          this.disposeAfter = null;
          this.disposed = null;
        }
        this.noDisposeOnSet = !!noDisposeOnSet;
        this.noUpdateTTL = !!noUpdateTTL;
        this.noDeleteOnFetchRejection = !!noDeleteOnFetchRejection;
        this.allowStaleOnFetchRejection = !!allowStaleOnFetchRejection;
        this.allowStaleOnFetchAbort = !!allowStaleOnFetchAbort;
        this.ignoreFetchAbort = !!ignoreFetchAbort;
        if (this.maxEntrySize !== 0) {
          if (this.maxSize !== 0) {
            if (!isPosInt(this.maxSize)) {
              throw new TypeError(
                "maxSize must be a positive integer if specified"
              );
            }
          }
          if (!isPosInt(this.maxEntrySize)) {
            throw new TypeError(
              "maxEntrySize must be a positive integer if specified"
            );
          }
          this.initializeSizeTracking();
        }
        this.allowStale = !!allowStale || !!stale;
        this.noDeleteOnStaleGet = !!noDeleteOnStaleGet;
        this.updateAgeOnGet = !!updateAgeOnGet;
        this.updateAgeOnHas = !!updateAgeOnHas;
        this.ttlResolution = isPosInt(ttlResolution) || ttlResolution === 0 ? ttlResolution : 1;
        this.ttlAutopurge = !!ttlAutopurge;
        this.ttl = ttl || maxAge || 0;
        if (this.ttl) {
          if (!isPosInt(this.ttl)) {
            throw new TypeError(
              "ttl must be a positive integer if specified"
            );
          }
          this.initializeTTLTracking();
        }
        if (this.max === 0 && this.ttl === 0 && this.maxSize === 0) {
          throw new TypeError(
            "At least one of max, maxSize, or ttl is required"
          );
        }
        if (!this.ttlAutopurge && !this.max && !this.maxSize) {
          const code = "LRU_CACHE_UNBOUNDED";
          if (shouldWarn(code)) {
            warned.add(code);
            const msg = "TTL caching without ttlAutopurge, max, or maxSize can result in unbounded memory consumption.";
            emitWarning(msg, "UnboundedCacheWarning", code, _LRUCache);
          }
        }
        if (stale) {
          deprecatedOption("stale", "allowStale");
        }
        if (maxAge) {
          deprecatedOption("maxAge", "ttl");
        }
        if (length) {
          deprecatedOption("length", "sizeCalculation");
        }
      }
      getRemainingTTL(key) {
        return this.has(key, { updateAgeOnHas: false }) ? Infinity : 0;
      }
      initializeTTLTracking() {
        this.ttls = new ZeroArray(this.max);
        this.starts = new ZeroArray(this.max);
        this.setItemTTL = (index, ttl, start = perf.now()) => {
          this.starts[index] = ttl !== 0 ? start : 0;
          this.ttls[index] = ttl;
          if (ttl !== 0 && this.ttlAutopurge) {
            const t = setTimeout(() => {
              if (this.isStale(index)) {
                this.delete(this.keyList[index]);
              }
            }, ttl + 1);
            if (t.unref) {
              t.unref();
            }
          }
        };
        this.updateItemAge = (index) => {
          this.starts[index] = this.ttls[index] !== 0 ? perf.now() : 0;
        };
        this.statusTTL = (status, index) => {
          if (status) {
            status.ttl = this.ttls[index];
            status.start = this.starts[index];
            status.now = cachedNow || getNow();
            status.remainingTTL = status.now + status.ttl - status.start;
          }
        };
        let cachedNow = 0;
        const getNow = /* @__PURE__ */ __name(() => {
          const n10 = perf.now();
          if (this.ttlResolution > 0) {
            cachedNow = n10;
            const t = setTimeout(
              () => cachedNow = 0,
              this.ttlResolution
            );
            if (t.unref) {
              t.unref();
            }
          }
          return n10;
        }, "getNow");
        this.getRemainingTTL = (key) => {
          const index = this.keyMap.get(key);
          if (index === void 0) {
            return 0;
          }
          return this.ttls[index] === 0 || this.starts[index] === 0 ? Infinity : this.starts[index] + this.ttls[index] - (cachedNow || getNow());
        };
        this.isStale = (index) => {
          return this.ttls[index] !== 0 && this.starts[index] !== 0 && (cachedNow || getNow()) - this.starts[index] > this.ttls[index];
        };
      }
      updateItemAge(_index) {
      }
      statusTTL(_status, _index) {
      }
      setItemTTL(_index, _ttl, _start) {
      }
      isStale(_index) {
        return false;
      }
      initializeSizeTracking() {
        this.calculatedSize = 0;
        this.sizes = new ZeroArray(this.max);
        this.removeItemSize = (index) => {
          this.calculatedSize -= this.sizes[index];
          this.sizes[index] = 0;
        };
        this.requireSize = (k32, v, size, sizeCalculation) => {
          if (this.isBackgroundFetch(v)) {
            return 0;
          }
          if (!isPosInt(size)) {
            if (sizeCalculation) {
              if (typeof sizeCalculation !== "function") {
                throw new TypeError("sizeCalculation must be a function");
              }
              size = sizeCalculation(v, k32);
              if (!isPosInt(size)) {
                throw new TypeError(
                  "sizeCalculation return invalid (expect positive integer)"
                );
              }
            } else {
              throw new TypeError(
                "invalid size value (must be positive integer). When maxSize or maxEntrySize is used, sizeCalculation or size must be set."
              );
            }
          }
          return size;
        };
        this.addItemSize = (index, size, status) => {
          this.sizes[index] = size;
          if (this.maxSize) {
            const maxSize = this.maxSize - this.sizes[index];
            while (this.calculatedSize > maxSize) {
              this.evict(true);
            }
          }
          this.calculatedSize += this.sizes[index];
          if (status) {
            status.entrySize = size;
            status.totalCalculatedSize = this.calculatedSize;
          }
        };
      }
      removeItemSize(_index) {
      }
      addItemSize(_index, _size) {
      }
      requireSize(_k, _v, size, sizeCalculation) {
        if (size || sizeCalculation) {
          throw new TypeError(
            "cannot set size without setting maxSize or maxEntrySize on cache"
          );
        }
      }
      *indexes({ allowStale = this.allowStale } = {}) {
        if (this.size) {
          for (let i32 = this.tail; true; ) {
            if (!this.isValidIndex(i32)) {
              break;
            }
            if (allowStale || !this.isStale(i32)) {
              yield i32;
            }
            if (i32 === this.head) {
              break;
            } else {
              i32 = this.prev[i32];
            }
          }
        }
      }
      *rindexes({ allowStale = this.allowStale } = {}) {
        if (this.size) {
          for (let i32 = this.head; true; ) {
            if (!this.isValidIndex(i32)) {
              break;
            }
            if (allowStale || !this.isStale(i32)) {
              yield i32;
            }
            if (i32 === this.tail) {
              break;
            } else {
              i32 = this.next[i32];
            }
          }
        }
      }
      isValidIndex(index) {
        return index !== void 0 && this.keyMap.get(this.keyList[index]) === index;
      }
      *entries() {
        for (const i32 of this.indexes()) {
          if (this.valList[i32] !== void 0 && this.keyList[i32] !== void 0 && !this.isBackgroundFetch(this.valList[i32])) {
            yield [this.keyList[i32], this.valList[i32]];
          }
        }
      }
      *rentries() {
        for (const i32 of this.rindexes()) {
          if (this.valList[i32] !== void 0 && this.keyList[i32] !== void 0 && !this.isBackgroundFetch(this.valList[i32])) {
            yield [this.keyList[i32], this.valList[i32]];
          }
        }
      }
      *keys() {
        for (const i32 of this.indexes()) {
          if (this.keyList[i32] !== void 0 && !this.isBackgroundFetch(this.valList[i32])) {
            yield this.keyList[i32];
          }
        }
      }
      *rkeys() {
        for (const i32 of this.rindexes()) {
          if (this.keyList[i32] !== void 0 && !this.isBackgroundFetch(this.valList[i32])) {
            yield this.keyList[i32];
          }
        }
      }
      *values() {
        for (const i32 of this.indexes()) {
          if (this.valList[i32] !== void 0 && !this.isBackgroundFetch(this.valList[i32])) {
            yield this.valList[i32];
          }
        }
      }
      *rvalues() {
        for (const i32 of this.rindexes()) {
          if (this.valList[i32] !== void 0 && !this.isBackgroundFetch(this.valList[i32])) {
            yield this.valList[i32];
          }
        }
      }
      [Symbol.iterator]() {
        return this.entries();
      }
      find(fn, getOptions) {
        for (const i32 of this.indexes()) {
          const v = this.valList[i32];
          const value = this.isBackgroundFetch(v) ? v.__staleWhileFetching : v;
          if (value === void 0) continue;
          if (fn(value, this.keyList[i32], this)) {
            return this.get(this.keyList[i32], getOptions);
          }
        }
      }
      forEach(fn, thisp = this) {
        for (const i32 of this.indexes()) {
          const v = this.valList[i32];
          const value = this.isBackgroundFetch(v) ? v.__staleWhileFetching : v;
          if (value === void 0) continue;
          fn.call(thisp, value, this.keyList[i32], this);
        }
      }
      rforEach(fn, thisp = this) {
        for (const i32 of this.rindexes()) {
          const v = this.valList[i32];
          const value = this.isBackgroundFetch(v) ? v.__staleWhileFetching : v;
          if (value === void 0) continue;
          fn.call(thisp, value, this.keyList[i32], this);
        }
      }
      get prune() {
        deprecatedMethod("prune", "purgeStale");
        return this.purgeStale;
      }
      purgeStale() {
        let deleted = false;
        for (const i32 of this.rindexes({ allowStale: true })) {
          if (this.isStale(i32)) {
            this.delete(this.keyList[i32]);
            deleted = true;
          }
        }
        return deleted;
      }
      dump() {
        const arr = [];
        for (const i32 of this.indexes({ allowStale: true })) {
          const key = this.keyList[i32];
          const v = this.valList[i32];
          const value = this.isBackgroundFetch(v) ? v.__staleWhileFetching : v;
          if (value === void 0) continue;
          const entry = { value };
          if (this.ttls) {
            entry.ttl = this.ttls[i32];
            const age = perf.now() - this.starts[i32];
            entry.start = Math.floor(Date.now() - age);
          }
          if (this.sizes) {
            entry.size = this.sizes[i32];
          }
          arr.unshift([key, entry]);
        }
        return arr;
      }
      load(arr) {
        this.clear();
        for (const [key, entry] of arr) {
          if (entry.start) {
            const age = Date.now() - entry.start;
            entry.start = perf.now() - age;
          }
          this.set(key, entry.value, entry);
        }
      }
      dispose(_v, _k, _reason) {
      }
      set(k32, v, {
        ttl = this.ttl,
        start,
        noDisposeOnSet = this.noDisposeOnSet,
        size = 0,
        sizeCalculation = this.sizeCalculation,
        noUpdateTTL = this.noUpdateTTL,
        status
      } = {}) {
        size = this.requireSize(k32, v, size, sizeCalculation);
        if (this.maxEntrySize && size > this.maxEntrySize) {
          if (status) {
            status.set = "miss";
            status.maxEntrySizeExceeded = true;
          }
          this.delete(k32);
          return this;
        }
        let index = this.size === 0 ? void 0 : this.keyMap.get(k32);
        if (index === void 0) {
          index = this.newIndex();
          this.keyList[index] = k32;
          this.valList[index] = v;
          this.keyMap.set(k32, index);
          this.next[this.tail] = index;
          this.prev[index] = this.tail;
          this.tail = index;
          this.size++;
          this.addItemSize(index, size, status);
          if (status) {
            status.set = "add";
          }
          noUpdateTTL = false;
        } else {
          this.moveToTail(index);
          const oldVal = this.valList[index];
          if (v !== oldVal) {
            if (this.isBackgroundFetch(oldVal)) {
              oldVal.__abortController.abort(new Error("replaced"));
            } else {
              if (!noDisposeOnSet) {
                this.dispose(oldVal, k32, "set");
                if (this.disposeAfter) {
                  this.disposed.push([oldVal, k32, "set"]);
                }
              }
            }
            this.removeItemSize(index);
            this.valList[index] = v;
            this.addItemSize(index, size, status);
            if (status) {
              status.set = "replace";
              const oldValue = oldVal && this.isBackgroundFetch(oldVal) ? oldVal.__staleWhileFetching : oldVal;
              if (oldValue !== void 0) status.oldValue = oldValue;
            }
          } else if (status) {
            status.set = "update";
          }
        }
        if (ttl !== 0 && this.ttl === 0 && !this.ttls) {
          this.initializeTTLTracking();
        }
        if (!noUpdateTTL) {
          this.setItemTTL(index, ttl, start);
        }
        this.statusTTL(status, index);
        if (this.disposeAfter) {
          while (this.disposed.length) {
            this.disposeAfter(...this.disposed.shift());
          }
        }
        return this;
      }
      newIndex() {
        if (this.size === 0) {
          return this.tail;
        }
        if (this.size === this.max && this.max !== 0) {
          return this.evict(false);
        }
        if (this.free.length !== 0) {
          return this.free.pop();
        }
        return this.initialFill++;
      }
      pop() {
        if (this.size) {
          const val = this.valList[this.head];
          this.evict(true);
          return val;
        }
      }
      evict(free) {
        const head = this.head;
        const k32 = this.keyList[head];
        const v = this.valList[head];
        if (this.isBackgroundFetch(v)) {
          v.__abortController.abort(new Error("evicted"));
        } else {
          this.dispose(v, k32, "evict");
          if (this.disposeAfter) {
            this.disposed.push([v, k32, "evict"]);
          }
        }
        this.removeItemSize(head);
        if (free) {
          this.keyList[head] = null;
          this.valList[head] = null;
          this.free.push(head);
        }
        this.head = this.next[head];
        this.keyMap.delete(k32);
        this.size--;
        return head;
      }
      has(k32, { updateAgeOnHas = this.updateAgeOnHas, status } = {}) {
        const index = this.keyMap.get(k32);
        if (index !== void 0) {
          if (!this.isStale(index)) {
            if (updateAgeOnHas) {
              this.updateItemAge(index);
            }
            if (status) status.has = "hit";
            this.statusTTL(status, index);
            return true;
          } else if (status) {
            status.has = "stale";
            this.statusTTL(status, index);
          }
        } else if (status) {
          status.has = "miss";
        }
        return false;
      }
      // like get(), but without any LRU updating or TTL expiration
      peek(k32, { allowStale = this.allowStale } = {}) {
        const index = this.keyMap.get(k32);
        if (index !== void 0 && (allowStale || !this.isStale(index))) {
          const v = this.valList[index];
          return this.isBackgroundFetch(v) ? v.__staleWhileFetching : v;
        }
      }
      backgroundFetch(k32, index, options, context) {
        const v = index === void 0 ? void 0 : this.valList[index];
        if (this.isBackgroundFetch(v)) {
          return v;
        }
        const ac = new AC();
        if (options.signal) {
          options.signal.addEventListener(
            "abort",
            () => ac.abort(options.signal.reason)
          );
        }
        const fetchOpts = {
          signal: ac.signal,
          options,
          context
        };
        const cb = /* @__PURE__ */ __name((v2, updateCache = false) => {
          const { aborted } = ac.signal;
          const ignoreAbort = options.ignoreFetchAbort && v2 !== void 0;
          if (options.status) {
            if (aborted && !updateCache) {
              options.status.fetchAborted = true;
              options.status.fetchError = ac.signal.reason;
              if (ignoreAbort) options.status.fetchAbortIgnored = true;
            } else {
              options.status.fetchResolved = true;
            }
          }
          if (aborted && !ignoreAbort && !updateCache) {
            return fetchFail(ac.signal.reason);
          }
          if (this.valList[index] === p10) {
            if (v2 === void 0) {
              if (p10.__staleWhileFetching) {
                this.valList[index] = p10.__staleWhileFetching;
              } else {
                this.delete(k32);
              }
            } else {
              if (options.status) options.status.fetchUpdated = true;
              this.set(k32, v2, fetchOpts.options);
            }
          }
          return v2;
        }, "cb");
        const eb = /* @__PURE__ */ __name((er) => {
          if (options.status) {
            options.status.fetchRejected = true;
            options.status.fetchError = er;
          }
          return fetchFail(er);
        }, "eb");
        const fetchFail = /* @__PURE__ */ __name((er) => {
          const { aborted } = ac.signal;
          const allowStaleAborted = aborted && options.allowStaleOnFetchAbort;
          const allowStale = allowStaleAborted || options.allowStaleOnFetchRejection;
          const noDelete = allowStale || options.noDeleteOnFetchRejection;
          if (this.valList[index] === p10) {
            const del = !noDelete || p10.__staleWhileFetching === void 0;
            if (del) {
              this.delete(k32);
            } else if (!allowStaleAborted) {
              this.valList[index] = p10.__staleWhileFetching;
            }
          }
          if (allowStale) {
            if (options.status && p10.__staleWhileFetching !== void 0) {
              options.status.returnedStale = true;
            }
            return p10.__staleWhileFetching;
          } else if (p10.__returned === p10) {
            throw er;
          }
        }, "fetchFail");
        const pcall = /* @__PURE__ */ __name((res, rej) => {
          this.fetchMethod(k32, v, fetchOpts).then((v2) => res(v2), rej);
          ac.signal.addEventListener("abort", () => {
            if (!options.ignoreFetchAbort || options.allowStaleOnFetchAbort) {
              res();
              if (options.allowStaleOnFetchAbort) {
                res = /* @__PURE__ */ __name((v2) => cb(v2, true), "res");
              }
            }
          });
        }, "pcall");
        if (options.status) options.status.fetchDispatched = true;
        const p10 = new Promise(pcall).then(cb, eb);
        p10.__abortController = ac;
        p10.__staleWhileFetching = v;
        p10.__returned = null;
        if (index === void 0) {
          this.set(k32, p10, { ...fetchOpts.options, status: void 0 });
          index = this.keyMap.get(k32);
        } else {
          this.valList[index] = p10;
        }
        return p10;
      }
      isBackgroundFetch(p10) {
        return p10 && typeof p10 === "object" && typeof p10.then === "function" && Object.prototype.hasOwnProperty.call(
          p10,
          "__staleWhileFetching"
        ) && Object.prototype.hasOwnProperty.call(p10, "__returned") && (p10.__returned === p10 || p10.__returned === null);
      }
      // this takes the union of get() and set() opts, because it does both
      async fetch(k32, {
        // get options
        allowStale = this.allowStale,
        updateAgeOnGet = this.updateAgeOnGet,
        noDeleteOnStaleGet = this.noDeleteOnStaleGet,
        // set options
        ttl = this.ttl,
        noDisposeOnSet = this.noDisposeOnSet,
        size = 0,
        sizeCalculation = this.sizeCalculation,
        noUpdateTTL = this.noUpdateTTL,
        // fetch exclusive options
        noDeleteOnFetchRejection = this.noDeleteOnFetchRejection,
        allowStaleOnFetchRejection = this.allowStaleOnFetchRejection,
        ignoreFetchAbort = this.ignoreFetchAbort,
        allowStaleOnFetchAbort = this.allowStaleOnFetchAbort,
        fetchContext = this.fetchContext,
        forceRefresh = false,
        status,
        signal
      } = {}) {
        if (!this.fetchMethod) {
          if (status) status.fetch = "get";
          return this.get(k32, {
            allowStale,
            updateAgeOnGet,
            noDeleteOnStaleGet,
            status
          });
        }
        const options = {
          allowStale,
          updateAgeOnGet,
          noDeleteOnStaleGet,
          ttl,
          noDisposeOnSet,
          size,
          sizeCalculation,
          noUpdateTTL,
          noDeleteOnFetchRejection,
          allowStaleOnFetchRejection,
          allowStaleOnFetchAbort,
          ignoreFetchAbort,
          status,
          signal
        };
        let index = this.keyMap.get(k32);
        if (index === void 0) {
          if (status) status.fetch = "miss";
          const p10 = this.backgroundFetch(k32, index, options, fetchContext);
          return p10.__returned = p10;
        } else {
          const v = this.valList[index];
          if (this.isBackgroundFetch(v)) {
            const stale = allowStale && v.__staleWhileFetching !== void 0;
            if (status) {
              status.fetch = "inflight";
              if (stale) status.returnedStale = true;
            }
            return stale ? v.__staleWhileFetching : v.__returned = v;
          }
          const isStale = this.isStale(index);
          if (!forceRefresh && !isStale) {
            if (status) status.fetch = "hit";
            this.moveToTail(index);
            if (updateAgeOnGet) {
              this.updateItemAge(index);
            }
            this.statusTTL(status, index);
            return v;
          }
          const p10 = this.backgroundFetch(k32, index, options, fetchContext);
          const hasStale = p10.__staleWhileFetching !== void 0;
          const staleVal = hasStale && allowStale;
          if (status) {
            status.fetch = hasStale && isStale ? "stale" : "refresh";
            if (staleVal && isStale) status.returnedStale = true;
          }
          return staleVal ? p10.__staleWhileFetching : p10.__returned = p10;
        }
      }
      get(k32, {
        allowStale = this.allowStale,
        updateAgeOnGet = this.updateAgeOnGet,
        noDeleteOnStaleGet = this.noDeleteOnStaleGet,
        status
      } = {}) {
        const index = this.keyMap.get(k32);
        if (index !== void 0) {
          const value = this.valList[index];
          const fetching = this.isBackgroundFetch(value);
          this.statusTTL(status, index);
          if (this.isStale(index)) {
            if (status) status.get = "stale";
            if (!fetching) {
              if (!noDeleteOnStaleGet) {
                this.delete(k32);
              }
              if (status) status.returnedStale = allowStale;
              return allowStale ? value : void 0;
            } else {
              if (status) {
                status.returnedStale = allowStale && value.__staleWhileFetching !== void 0;
              }
              return allowStale ? value.__staleWhileFetching : void 0;
            }
          } else {
            if (status) status.get = "hit";
            if (fetching) {
              return value.__staleWhileFetching;
            }
            this.moveToTail(index);
            if (updateAgeOnGet) {
              this.updateItemAge(index);
            }
            return value;
          }
        } else if (status) {
          status.get = "miss";
        }
      }
      connect(p10, n10) {
        this.prev[n10] = p10;
        this.next[p10] = n10;
      }
      moveToTail(index) {
        if (index !== this.tail) {
          if (index === this.head) {
            this.head = this.next[index];
          } else {
            this.connect(this.prev[index], this.next[index]);
          }
          this.connect(this.tail, index);
          this.tail = index;
        }
      }
      get del() {
        deprecatedMethod("del", "delete");
        return this.delete;
      }
      delete(k32) {
        let deleted = false;
        if (this.size !== 0) {
          const index = this.keyMap.get(k32);
          if (index !== void 0) {
            deleted = true;
            if (this.size === 1) {
              this.clear();
            } else {
              this.removeItemSize(index);
              const v = this.valList[index];
              if (this.isBackgroundFetch(v)) {
                v.__abortController.abort(new Error("deleted"));
              } else {
                this.dispose(v, k32, "delete");
                if (this.disposeAfter) {
                  this.disposed.push([v, k32, "delete"]);
                }
              }
              this.keyMap.delete(k32);
              this.keyList[index] = null;
              this.valList[index] = null;
              if (index === this.tail) {
                this.tail = this.prev[index];
              } else if (index === this.head) {
                this.head = this.next[index];
              } else {
                this.next[this.prev[index]] = this.next[index];
                this.prev[this.next[index]] = this.prev[index];
              }
              this.size--;
              this.free.push(index);
            }
          }
        }
        if (this.disposed) {
          while (this.disposed.length) {
            this.disposeAfter(...this.disposed.shift());
          }
        }
        return deleted;
      }
      clear() {
        for (const index of this.rindexes({ allowStale: true })) {
          const v = this.valList[index];
          if (this.isBackgroundFetch(v)) {
            v.__abortController.abort(new Error("deleted"));
          } else {
            const k32 = this.keyList[index];
            this.dispose(v, k32, "delete");
            if (this.disposeAfter) {
              this.disposed.push([v, k32, "delete"]);
            }
          }
        }
        this.keyMap.clear();
        this.valList.fill(null);
        this.keyList.fill(null);
        if (this.ttls) {
          this.ttls.fill(0);
          this.starts.fill(0);
        }
        if (this.sizes) {
          this.sizes.fill(0);
        }
        this.head = 0;
        this.tail = 0;
        this.initialFill = 1;
        this.free.length = 0;
        this.calculatedSize = 0;
        this.size = 0;
        if (this.disposed) {
          while (this.disposed.length) {
            this.disposeAfter(...this.disposed.shift());
          }
        }
      }
      get reset() {
        deprecatedMethod("reset", "clear");
        return this.clear;
      }
      get length() {
        deprecatedProperty("length", "size");
        return this.size;
      }
      static get AbortController() {
        return AC;
      }
      static get AbortSignal() {
        return AS;
      }
    };
    module2.exports = LRUCache;
  }
});

// ../../node_modules/agent-base/dist/helpers.js
var require_helpers2 = __commonJS({
  "../../node_modules/agent-base/dist/helpers.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __setModuleDefault2 = exports2 && exports2.__setModuleDefault || (Object.create ? (function(o10, v) {
      Object.defineProperty(o10, "default", { enumerable: true, value: v });
    }) : function(o10, v) {
      o10["default"] = v;
    });
    var __importStar2 = exports2 && exports2.__importStar || function(mod) {
      if (mod && mod.__esModule) return mod;
      var result2 = {};
      if (mod != null) {
        for (var k32 in mod) if (k32 !== "default" && Object.prototype.hasOwnProperty.call(mod, k32)) __createBinding3(result2, mod, k32);
      }
      __setModuleDefault2(result2, mod);
      return result2;
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.req = exports2.json = exports2.toBuffer = void 0;
    var http = __importStar2(require("http"));
    var https3 = __importStar2(require("https"));
    async function toBuffer(stream) {
      let length = 0;
      const chunks2 = [];
      for await (const chunk of stream) {
        length += chunk.length;
        chunks2.push(chunk);
      }
      return Buffer.concat(chunks2, length);
    }
    __name(toBuffer, "toBuffer");
    exports2.toBuffer = toBuffer;
    async function json(stream) {
      const buf = await toBuffer(stream);
      const str = buf.toString("utf8");
      try {
        return JSON.parse(str);
      } catch (_err) {
        const err = _err;
        err.message += ` (input: ${str})`;
        throw err;
      }
    }
    __name(json, "json");
    exports2.json = json;
    function req(url, opts = {}) {
      const href = typeof url === "string" ? url : url.href;
      const req2 = (href.startsWith("https:") ? https3 : http).request(url, opts);
      const promise = new Promise((resolve13, reject) => {
        req2.once("response", resolve13).once("error", reject).end();
      });
      req2.then = promise.then.bind(promise);
      return req2;
    }
    __name(req, "req");
    exports2.req = req;
  }
});

// ../../node_modules/agent-base/dist/index.js
var require_dist4 = __commonJS({
  "../../node_modules/agent-base/dist/index.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __setModuleDefault2 = exports2 && exports2.__setModuleDefault || (Object.create ? (function(o10, v) {
      Object.defineProperty(o10, "default", { enumerable: true, value: v });
    }) : function(o10, v) {
      o10["default"] = v;
    });
    var __importStar2 = exports2 && exports2.__importStar || function(mod) {
      if (mod && mod.__esModule) return mod;
      var result2 = {};
      if (mod != null) {
        for (var k32 in mod) if (k32 !== "default" && Object.prototype.hasOwnProperty.call(mod, k32)) __createBinding3(result2, mod, k32);
      }
      __setModuleDefault2(result2, mod);
      return result2;
    };
    var __exportStar3 = exports2 && exports2.__exportStar || function(m20, exports3) {
      for (var p10 in m20) if (p10 !== "default" && !Object.prototype.hasOwnProperty.call(exports3, p10)) __createBinding3(exports3, m20, p10);
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.Agent = void 0;
    var net = __importStar2(require("net"));
    var http = __importStar2(require("http"));
    var https_1 = require("https");
    __exportStar3(require_helpers2(), exports2);
    var INTERNAL = /* @__PURE__ */ Symbol("AgentBaseInternalState");
    var Agent = class extends http.Agent {
      static {
        __name(this, "Agent");
      }
      constructor(opts) {
        super(opts);
        this[INTERNAL] = {};
      }
      /**
       * Determine whether this is an `http` or `https` request.
       */
      isSecureEndpoint(options) {
        if (options) {
          if (typeof options.secureEndpoint === "boolean") {
            return options.secureEndpoint;
          }
          if (typeof options.protocol === "string") {
            return options.protocol === "https:";
          }
        }
        const { stack } = new Error();
        if (typeof stack !== "string")
          return false;
        return stack.split("\n").some((l20) => l20.indexOf("(https.js:") !== -1 || l20.indexOf("node:https:") !== -1);
      }
      // In order to support async signatures in `connect()` and Node's native
      // connection pooling in `http.Agent`, the array of sockets for each origin
      // has to be updated synchronously. This is so the length of the array is
      // accurate when `addRequest()` is next called. We achieve this by creating a
      // fake socket and adding it to `sockets[origin]` and incrementing
      // `totalSocketCount`.
      incrementSockets(name) {
        if (this.maxSockets === Infinity && this.maxTotalSockets === Infinity) {
          return null;
        }
        if (!this.sockets[name]) {
          this.sockets[name] = [];
        }
        const fakeSocket = new net.Socket({ writable: false });
        this.sockets[name].push(fakeSocket);
        this.totalSocketCount++;
        return fakeSocket;
      }
      decrementSockets(name, socket) {
        if (!this.sockets[name] || socket === null) {
          return;
        }
        const sockets = this.sockets[name];
        const index = sockets.indexOf(socket);
        if (index !== -1) {
          sockets.splice(index, 1);
          this.totalSocketCount--;
          if (sockets.length === 0) {
            delete this.sockets[name];
          }
        }
      }
      // In order to properly update the socket pool, we need to call `getName()` on
      // the core `https.Agent` if it is a secureEndpoint.
      getName(options) {
        const secureEndpoint = this.isSecureEndpoint(options);
        if (secureEndpoint) {
          return https_1.Agent.prototype.getName.call(this, options);
        }
        return super.getName(options);
      }
      createSocket(req, options, cb) {
        const connectOpts = {
          ...options,
          secureEndpoint: this.isSecureEndpoint(options)
        };
        const name = this.getName(connectOpts);
        const fakeSocket = this.incrementSockets(name);
        Promise.resolve().then(() => this.connect(req, connectOpts)).then((socket) => {
          this.decrementSockets(name, fakeSocket);
          if (socket instanceof http.Agent) {
            try {
              return socket.addRequest(req, connectOpts);
            } catch (err) {
              return cb(err);
            }
          }
          this[INTERNAL].currentSocket = socket;
          super.createSocket(req, options, cb);
        }, (err) => {
          this.decrementSockets(name, fakeSocket);
          cb(err);
        });
      }
      createConnection() {
        const socket = this[INTERNAL].currentSocket;
        this[INTERNAL].currentSocket = void 0;
        if (!socket) {
          throw new Error("No socket was returned in the `connect()` function");
        }
        return socket;
      }
      get defaultPort() {
        return this[INTERNAL].defaultPort ?? (this.protocol === "https:" ? 443 : 80);
      }
      set defaultPort(v) {
        if (this[INTERNAL]) {
          this[INTERNAL].defaultPort = v;
        }
      }
      get protocol() {
        return this[INTERNAL].protocol ?? (this.isSecureEndpoint() ? "https:" : "http:");
      }
      set protocol(v) {
        if (this[INTERNAL]) {
          this[INTERNAL].protocol = v;
        }
      }
    };
    exports2.Agent = Agent;
  }
});

// ../../node_modules/ms/index.js
var require_ms = __commonJS({
  "../../node_modules/ms/index.js"(exports2, module2) {
    var s = 1e3;
    var m20 = s * 60;
    var h32 = m20 * 60;
    var d32 = h32 * 24;
    var w = d32 * 7;
    var y = d32 * 365.25;
    module2.exports = function(val, options) {
      options = options || {};
      var type = typeof val;
      if (type === "string" && val.length > 0) {
        return parse2(val);
      } else if (type === "number" && isFinite(val)) {
        return options.long ? fmtLong(val) : fmtShort(val);
      }
      throw new Error(
        "val is not a non-empty string or a valid number. val=" + JSON.stringify(val)
      );
    };
    function parse2(str) {
      str = String(str);
      if (str.length > 100) {
        return;
      }
      var match = /^(-?(?:\d+)?\.?\d+) *(milliseconds?|msecs?|ms|seconds?|secs?|s|minutes?|mins?|m|hours?|hrs?|h|days?|d|weeks?|w|years?|yrs?|y)?$/i.exec(
        str
      );
      if (!match) {
        return;
      }
      var n10 = parseFloat(match[1]);
      var type = (match[2] || "ms").toLowerCase();
      switch (type) {
        case "years":
        case "year":
        case "yrs":
        case "yr":
        case "y":
          return n10 * y;
        case "weeks":
        case "week":
        case "w":
          return n10 * w;
        case "days":
        case "day":
        case "d":
          return n10 * d32;
        case "hours":
        case "hour":
        case "hrs":
        case "hr":
        case "h":
          return n10 * h32;
        case "minutes":
        case "minute":
        case "mins":
        case "min":
        case "m":
          return n10 * m20;
        case "seconds":
        case "second":
        case "secs":
        case "sec":
        case "s":
          return n10 * s;
        case "milliseconds":
        case "millisecond":
        case "msecs":
        case "msec":
        case "ms":
          return n10;
        default:
          return void 0;
      }
    }
    __name(parse2, "parse");
    function fmtShort(ms) {
      var msAbs = Math.abs(ms);
      if (msAbs >= d32) {
        return Math.round(ms / d32) + "d";
      }
      if (msAbs >= h32) {
        return Math.round(ms / h32) + "h";
      }
      if (msAbs >= m20) {
        return Math.round(ms / m20) + "m";
      }
      if (msAbs >= s) {
        return Math.round(ms / s) + "s";
      }
      return ms + "ms";
    }
    __name(fmtShort, "fmtShort");
    function fmtLong(ms) {
      var msAbs = Math.abs(ms);
      if (msAbs >= d32) {
        return plural(ms, msAbs, d32, "day");
      }
      if (msAbs >= h32) {
        return plural(ms, msAbs, h32, "hour");
      }
      if (msAbs >= m20) {
        return plural(ms, msAbs, m20, "minute");
      }
      if (msAbs >= s) {
        return plural(ms, msAbs, s, "second");
      }
      return ms + " ms";
    }
    __name(fmtLong, "fmtLong");
    function plural(ms, msAbs, n10, name) {
      var isPlural = msAbs >= n10 * 1.5;
      return Math.round(ms / n10) + " " + name + (isPlural ? "s" : "");
    }
    __name(plural, "plural");
  }
});

// ../../node_modules/debug/src/common.js
var require_common4 = __commonJS({
  "../../node_modules/debug/src/common.js"(exports2, module2) {
    function setup(env3) {
      createDebug.debug = createDebug;
      createDebug.default = createDebug;
      createDebug.coerce = coerce2;
      createDebug.disable = disable;
      createDebug.enable = enable;
      createDebug.enabled = enabled;
      createDebug.humanize = require_ms();
      createDebug.destroy = destroy;
      Object.keys(env3).forEach((key) => {
        createDebug[key] = env3[key];
      });
      createDebug.names = [];
      createDebug.skips = [];
      createDebug.formatters = {};
      function selectColor(namespace) {
        let hash = 0;
        for (let i32 = 0; i32 < namespace.length; i32++) {
          hash = (hash << 5) - hash + namespace.charCodeAt(i32);
          hash |= 0;
        }
        return createDebug.colors[Math.abs(hash) % createDebug.colors.length];
      }
      __name(selectColor, "selectColor");
      createDebug.selectColor = selectColor;
      function createDebug(namespace) {
        let prevTime;
        let enableOverride = null;
        let namespacesCache;
        let enabledCache;
        function debug2(...args) {
          if (!debug2.enabled) {
            return;
          }
          const self2 = debug2;
          const curr = Number(/* @__PURE__ */ new Date());
          const ms = curr - (prevTime || curr);
          self2.diff = ms;
          self2.prev = prevTime;
          self2.curr = curr;
          prevTime = curr;
          args[0] = createDebug.coerce(args[0]);
          if (typeof args[0] !== "string") {
            args.unshift("%O");
          }
          let index = 0;
          args[0] = args[0].replace(/%([a-zA-Z%])/g, (match, format32) => {
            if (match === "%%") {
              return "%";
            }
            index++;
            const formatter = createDebug.formatters[format32];
            if (typeof formatter === "function") {
              const val = args[index];
              match = formatter.call(self2, val);
              args.splice(index, 1);
              index--;
            }
            return match;
          });
          createDebug.formatArgs.call(self2, args);
          const logFn = self2.log || createDebug.log;
          logFn.apply(self2, args);
        }
        __name(debug2, "debug");
        debug2.namespace = namespace;
        debug2.useColors = createDebug.useColors();
        debug2.color = createDebug.selectColor(namespace);
        debug2.extend = extend;
        debug2.destroy = createDebug.destroy;
        Object.defineProperty(debug2, "enabled", {
          enumerable: true,
          configurable: false,
          get: /* @__PURE__ */ __name(() => {
            if (enableOverride !== null) {
              return enableOverride;
            }
            if (namespacesCache !== createDebug.namespaces) {
              namespacesCache = createDebug.namespaces;
              enabledCache = createDebug.enabled(namespace);
            }
            return enabledCache;
          }, "get"),
          set: /* @__PURE__ */ __name((v) => {
            enableOverride = v;
          }, "set")
        });
        if (typeof createDebug.init === "function") {
          createDebug.init(debug2);
        }
        return debug2;
      }
      __name(createDebug, "createDebug");
      function extend(namespace, delimiter2) {
        const newDebug = createDebug(this.namespace + (typeof delimiter2 === "undefined" ? ":" : delimiter2) + namespace);
        newDebug.log = this.log;
        return newDebug;
      }
      __name(extend, "extend");
      function enable(namespaces) {
        createDebug.save(namespaces);
        createDebug.namespaces = namespaces;
        createDebug.names = [];
        createDebug.skips = [];
        const split4 = (typeof namespaces === "string" ? namespaces : "").trim().replace(/\s+/g, ",").split(",").filter(Boolean);
        for (const ns of split4) {
          if (ns[0] === "-") {
            createDebug.skips.push(ns.slice(1));
          } else {
            createDebug.names.push(ns);
          }
        }
      }
      __name(enable, "enable");
      function matchesTemplate(search, template) {
        let searchIndex = 0;
        let templateIndex = 0;
        let starIndex = -1;
        let matchIndex = 0;
        while (searchIndex < search.length) {
          if (templateIndex < template.length && (template[templateIndex] === search[searchIndex] || template[templateIndex] === "*")) {
            if (template[templateIndex] === "*") {
              starIndex = templateIndex;
              matchIndex = searchIndex;
              templateIndex++;
            } else {
              searchIndex++;
              templateIndex++;
            }
          } else if (starIndex !== -1) {
            templateIndex = starIndex + 1;
            matchIndex++;
            searchIndex = matchIndex;
          } else {
            return false;
          }
        }
        while (templateIndex < template.length && template[templateIndex] === "*") {
          templateIndex++;
        }
        return templateIndex === template.length;
      }
      __name(matchesTemplate, "matchesTemplate");
      function disable() {
        const namespaces = [
          ...createDebug.names,
          ...createDebug.skips.map((namespace) => "-" + namespace)
        ].join(",");
        createDebug.enable("");
        return namespaces;
      }
      __name(disable, "disable");
      function enabled(name) {
        for (const skip of createDebug.skips) {
          if (matchesTemplate(name, skip)) {
            return false;
          }
        }
        for (const ns of createDebug.names) {
          if (matchesTemplate(name, ns)) {
            return true;
          }
        }
        return false;
      }
      __name(enabled, "enabled");
      function coerce2(val) {
        if (val instanceof Error) {
          return val.stack || val.message;
        }
        return val;
      }
      __name(coerce2, "coerce");
      function destroy() {
        console.warn("Instance method `debug.destroy()` is deprecated and no longer does anything. It will be removed in the next major version of `debug`.");
      }
      __name(destroy, "destroy");
      createDebug.enable(createDebug.load());
      return createDebug;
    }
    __name(setup, "setup");
    module2.exports = setup;
  }
});

// ../../node_modules/debug/src/browser.js
var require_browser = __commonJS({
  "../../node_modules/debug/src/browser.js"(exports2, module2) {
    exports2.formatArgs = formatArgs;
    exports2.save = save;
    exports2.load = load;
    exports2.useColors = useColors;
    exports2.storage = localstorage();
    exports2.destroy = /* @__PURE__ */ (() => {
      let warned = false;
      return () => {
        if (!warned) {
          warned = true;
          console.warn("Instance method `debug.destroy()` is deprecated and no longer does anything. It will be removed in the next major version of `debug`.");
        }
      };
    })();
    exports2.colors = [
      "#0000CC",
      "#0000FF",
      "#0033CC",
      "#0033FF",
      "#0066CC",
      "#0066FF",
      "#0099CC",
      "#0099FF",
      "#00CC00",
      "#00CC33",
      "#00CC66",
      "#00CC99",
      "#00CCCC",
      "#00CCFF",
      "#3300CC",
      "#3300FF",
      "#3333CC",
      "#3333FF",
      "#3366CC",
      "#3366FF",
      "#3399CC",
      "#3399FF",
      "#33CC00",
      "#33CC33",
      "#33CC66",
      "#33CC99",
      "#33CCCC",
      "#33CCFF",
      "#6600CC",
      "#6600FF",
      "#6633CC",
      "#6633FF",
      "#66CC00",
      "#66CC33",
      "#9900CC",
      "#9900FF",
      "#9933CC",
      "#9933FF",
      "#99CC00",
      "#99CC33",
      "#CC0000",
      "#CC0033",
      "#CC0066",
      "#CC0099",
      "#CC00CC",
      "#CC00FF",
      "#CC3300",
      "#CC3333",
      "#CC3366",
      "#CC3399",
      "#CC33CC",
      "#CC33FF",
      "#CC6600",
      "#CC6633",
      "#CC9900",
      "#CC9933",
      "#CCCC00",
      "#CCCC33",
      "#FF0000",
      "#FF0033",
      "#FF0066",
      "#FF0099",
      "#FF00CC",
      "#FF00FF",
      "#FF3300",
      "#FF3333",
      "#FF3366",
      "#FF3399",
      "#FF33CC",
      "#FF33FF",
      "#FF6600",
      "#FF6633",
      "#FF9900",
      "#FF9933",
      "#FFCC00",
      "#FFCC33"
    ];
    function useColors() {
      if (typeof window !== "undefined" && window.process && (window.process.type === "renderer" || window.process.__nwjs)) {
        return true;
      }
      if (typeof navigator !== "undefined" && navigator.userAgent && navigator.userAgent.toLowerCase().match(/(edge|trident)\/(\d+)/)) {
        return false;
      }
      let m20;
      return typeof document !== "undefined" && document.documentElement && document.documentElement.style && document.documentElement.style.WebkitAppearance || // Is firebug? http://stackoverflow.com/a/398120/376773
      typeof window !== "undefined" && window.console && (window.console.firebug || window.console.exception && window.console.table) || // Is firefox >= v31?
      // https://developer.mozilla.org/en-US/docs/Tools/Web_Console#Styling_messages
      typeof navigator !== "undefined" && navigator.userAgent && (m20 = navigator.userAgent.toLowerCase().match(/firefox\/(\d+)/)) && parseInt(m20[1], 10) >= 31 || // Double check webkit in userAgent just in case we are in a worker
      typeof navigator !== "undefined" && navigator.userAgent && navigator.userAgent.toLowerCase().match(/applewebkit\/(\d+)/);
    }
    __name(useColors, "useColors");
    function formatArgs(args) {
      args[0] = (this.useColors ? "%c" : "") + this.namespace + (this.useColors ? " %c" : " ") + args[0] + (this.useColors ? "%c " : " ") + "+" + module2.exports.humanize(this.diff);
      if (!this.useColors) {
        return;
      }
      const c32 = "color: " + this.color;
      args.splice(1, 0, c32, "color: inherit");
      let index = 0;
      let lastC = 0;
      args[0].replace(/%[a-zA-Z%]/g, (match) => {
        if (match === "%%") {
          return;
        }
        index++;
        if (match === "%c") {
          lastC = index;
        }
      });
      args.splice(lastC, 0, c32);
    }
    __name(formatArgs, "formatArgs");
    exports2.log = console.debug || console.log || (() => {
    });
    function save(namespaces) {
      try {
        if (namespaces) {
          exports2.storage.setItem("debug", namespaces);
        } else {
          exports2.storage.removeItem("debug");
        }
      } catch (error4) {
      }
    }
    __name(save, "save");
    function load() {
      let r32;
      try {
        r32 = exports2.storage.getItem("debug") || exports2.storage.getItem("DEBUG");
      } catch (error4) {
      }
      if (!r32 && typeof process !== "undefined" && "env" in process) {
        r32 = process.env.DEBUG;
      }
      return r32;
    }
    __name(load, "load");
    function localstorage() {
      try {
        return localStorage;
      } catch (error4) {
      }
    }
    __name(localstorage, "localstorage");
    module2.exports = require_common4()(exports2);
    var { formatters } = module2.exports;
    formatters.j = function(v) {
      try {
        return JSON.stringify(v);
      } catch (error4) {
        return "[UnexpectedJSONParseError]: " + error4.message;
      }
    };
  }
});

// ../../node_modules/debug/src/node.js
var require_node = __commonJS({
  "../../node_modules/debug/src/node.js"(exports2, module2) {
    var tty = require("tty");
    var util11 = require("util");
    exports2.init = init;
    exports2.log = log;
    exports2.formatArgs = formatArgs;
    exports2.save = save;
    exports2.load = load;
    exports2.useColors = useColors;
    exports2.destroy = util11.deprecate(
      () => {
      },
      "Instance method `debug.destroy()` is deprecated and no longer does anything. It will be removed in the next major version of `debug`."
    );
    exports2.colors = [6, 2, 3, 4, 5, 1];
    try {
      const supportsColor = require_supports_color();
      if (supportsColor && (supportsColor.stderr || supportsColor).level >= 2) {
        exports2.colors = [
          20,
          21,
          26,
          27,
          32,
          33,
          38,
          39,
          40,
          41,
          42,
          43,
          44,
          45,
          56,
          57,
          62,
          63,
          68,
          69,
          74,
          75,
          76,
          77,
          78,
          79,
          80,
          81,
          92,
          93,
          98,
          99,
          112,
          113,
          128,
          129,
          134,
          135,
          148,
          149,
          160,
          161,
          162,
          163,
          164,
          165,
          166,
          167,
          168,
          169,
          170,
          171,
          172,
          173,
          178,
          179,
          184,
          185,
          196,
          197,
          198,
          199,
          200,
          201,
          202,
          203,
          204,
          205,
          206,
          207,
          208,
          209,
          214,
          215,
          220,
          221
        ];
      }
    } catch (error4) {
    }
    exports2.inspectOpts = Object.keys(process.env).filter((key) => {
      return /^debug_/i.test(key);
    }).reduce((obj, key) => {
      const prop = key.substring(6).toLowerCase().replace(/_([a-z])/g, (_, k32) => {
        return k32.toUpperCase();
      });
      let val = process.env[key];
      if (/^(yes|on|true|enabled)$/i.test(val)) {
        val = true;
      } else if (/^(no|off|false|disabled)$/i.test(val)) {
        val = false;
      } else if (val === "null") {
        val = null;
      } else {
        val = Number(val);
      }
      obj[prop] = val;
      return obj;
    }, {});
    function useColors() {
      return "colors" in exports2.inspectOpts ? Boolean(exports2.inspectOpts.colors) : tty.isatty(process.stderr.fd);
    }
    __name(useColors, "useColors");
    function formatArgs(args) {
      const { namespace: name, useColors: useColors2 } = this;
      if (useColors2) {
        const c32 = this.color;
        const colorCode = "\x1B[3" + (c32 < 8 ? c32 : "8;5;" + c32);
        const prefix = `  ${colorCode};1m${name} \x1B[0m`;
        args[0] = prefix + args[0].split("\n").join("\n" + prefix);
        args.push(colorCode + "m+" + module2.exports.humanize(this.diff) + "\x1B[0m");
      } else {
        args[0] = getDate() + name + " " + args[0];
      }
    }
    __name(formatArgs, "formatArgs");
    function getDate() {
      if (exports2.inspectOpts.hideDate) {
        return "";
      }
      return (/* @__PURE__ */ new Date()).toISOString() + " ";
    }
    __name(getDate, "getDate");
    function log(...args) {
      return process.stderr.write(util11.formatWithOptions(exports2.inspectOpts, ...args) + "\n");
    }
    __name(log, "log");
    function save(namespaces) {
      if (namespaces) {
        process.env.DEBUG = namespaces;
      } else {
        delete process.env.DEBUG;
      }
    }
    __name(save, "save");
    function load() {
      return process.env.DEBUG;
    }
    __name(load, "load");
    function init(debug2) {
      debug2.inspectOpts = {};
      const keys = Object.keys(exports2.inspectOpts);
      for (let i32 = 0; i32 < keys.length; i32++) {
        debug2.inspectOpts[keys[i32]] = exports2.inspectOpts[keys[i32]];
      }
    }
    __name(init, "init");
    module2.exports = require_common4()(exports2);
    var { formatters } = module2.exports;
    formatters.o = function(v) {
      this.inspectOpts.colors = this.useColors;
      return util11.inspect(v, this.inspectOpts).split("\n").map((str) => str.trim()).join(" ");
    };
    formatters.O = function(v) {
      this.inspectOpts.colors = this.useColors;
      return util11.inspect(v, this.inspectOpts);
    };
  }
});

// ../../node_modules/debug/src/index.js
var require_src2 = __commonJS({
  "../../node_modules/debug/src/index.js"(exports2, module2) {
    if (typeof process === "undefined" || process.type === "renderer" || process.browser === true || process.__nwjs) {
      module2.exports = require_browser();
    } else {
      module2.exports = require_node();
    }
  }
});

// ../../node_modules/proxy-agent/node_modules/proxy-from-env/index.js
var require_proxy_from_env = __commonJS({
  "../../node_modules/proxy-agent/node_modules/proxy-from-env/index.js"(exports2) {
    "use strict";
    var parseUrl34 = require("url").parse;
    var DEFAULT_PORTS3 = {
      ftp: 21,
      gopher: 70,
      http: 80,
      https: 443,
      ws: 80,
      wss: 443
    };
    var stringEndsWith = String.prototype.endsWith || function(s) {
      return s.length <= this.length && this.indexOf(s, this.length - s.length) !== -1;
    };
    function getProxyForUrl(url) {
      var parsedUrl = typeof url === "string" ? parseUrl34(url) : url || {};
      var proto = parsedUrl.protocol;
      var hostname = parsedUrl.host;
      var port = parsedUrl.port;
      if (typeof hostname !== "string" || !hostname || typeof proto !== "string") {
        return "";
      }
      proto = proto.split(":", 1)[0];
      hostname = hostname.replace(/:\d*$/, "");
      port = parseInt(port) || DEFAULT_PORTS3[proto] || 0;
      if (!shouldProxy(hostname, port)) {
        return "";
      }
      var proxy = getEnv("npm_config_" + proto + "_proxy") || getEnv(proto + "_proxy") || getEnv("npm_config_proxy") || getEnv("all_proxy");
      if (proxy && proxy.indexOf("://") === -1) {
        proxy = proto + "://" + proxy;
      }
      return proxy;
    }
    __name(getProxyForUrl, "getProxyForUrl");
    function shouldProxy(hostname, port) {
      var NO_PROXY = (getEnv("npm_config_no_proxy") || getEnv("no_proxy")).toLowerCase();
      if (!NO_PROXY) {
        return true;
      }
      if (NO_PROXY === "*") {
        return false;
      }
      return NO_PROXY.split(/[,\s]/).every(function(proxy) {
        if (!proxy) {
          return true;
        }
        var parsedProxy = proxy.match(/^(.+):(\d+)$/);
        var parsedProxyHostname = parsedProxy ? parsedProxy[1] : proxy;
        var parsedProxyPort = parsedProxy ? parseInt(parsedProxy[2]) : 0;
        if (parsedProxyPort && parsedProxyPort !== port) {
          return true;
        }
        if (!/^[.*]/.test(parsedProxyHostname)) {
          return hostname !== parsedProxyHostname;
        }
        if (parsedProxyHostname.charAt(0) === "*") {
          parsedProxyHostname = parsedProxyHostname.slice(1);
        }
        return !stringEndsWith.call(hostname, parsedProxyHostname);
      });
    }
    __name(shouldProxy, "shouldProxy");
    function getEnv(key) {
      return process.env[key.toLowerCase()] || process.env[key.toUpperCase()] || "";
    }
    __name(getEnv, "getEnv");
    exports2.getProxyForUrl = getProxyForUrl;
  }
});

// ../../node_modules/http-proxy-agent/dist/index.js
var require_dist5 = __commonJS({
  "../../node_modules/http-proxy-agent/dist/index.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __setModuleDefault2 = exports2 && exports2.__setModuleDefault || (Object.create ? (function(o10, v) {
      Object.defineProperty(o10, "default", { enumerable: true, value: v });
    }) : function(o10, v) {
      o10["default"] = v;
    });
    var __importStar2 = exports2 && exports2.__importStar || function(mod) {
      if (mod && mod.__esModule) return mod;
      var result2 = {};
      if (mod != null) {
        for (var k32 in mod) if (k32 !== "default" && Object.prototype.hasOwnProperty.call(mod, k32)) __createBinding3(result2, mod, k32);
      }
      __setModuleDefault2(result2, mod);
      return result2;
    };
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.HttpProxyAgent = void 0;
    var net = __importStar2(require("net"));
    var tls = __importStar2(require("tls"));
    var debug_1 = __importDefault2(require_src2());
    var events_1 = require("events");
    var agent_base_1 = require_dist4();
    var url_1 = require("url");
    var debug2 = (0, debug_1.default)("http-proxy-agent");
    var HttpProxyAgent = class extends agent_base_1.Agent {
      static {
        __name(this, "HttpProxyAgent");
      }
      constructor(proxy, opts) {
        super(opts);
        this.proxy = typeof proxy === "string" ? new url_1.URL(proxy) : proxy;
        this.proxyHeaders = opts?.headers ?? {};
        debug2("Creating new HttpProxyAgent instance: %o", this.proxy.href);
        const host = (this.proxy.hostname || this.proxy.host).replace(/^\[|\]$/g, "");
        const port = this.proxy.port ? parseInt(this.proxy.port, 10) : this.proxy.protocol === "https:" ? 443 : 80;
        this.connectOpts = {
          ...opts ? omit(opts, "headers") : null,
          host,
          port
        };
      }
      addRequest(req, opts) {
        req._header = null;
        this.setRequestProps(req, opts);
        super.addRequest(req, opts);
      }
      setRequestProps(req, opts) {
        const { proxy } = this;
        const protocol = opts.secureEndpoint ? "https:" : "http:";
        const hostname = req.getHeader("host") || "localhost";
        const base = `${protocol}//${hostname}`;
        const url = new url_1.URL(req.path, base);
        if (opts.port !== 80) {
          url.port = String(opts.port);
        }
        req.path = String(url);
        const headers = typeof this.proxyHeaders === "function" ? this.proxyHeaders() : { ...this.proxyHeaders };
        if (proxy.username || proxy.password) {
          const auth = `${decodeURIComponent(proxy.username)}:${decodeURIComponent(proxy.password)}`;
          headers["Proxy-Authorization"] = `Basic ${Buffer.from(auth).toString("base64")}`;
        }
        if (!headers["Proxy-Connection"]) {
          headers["Proxy-Connection"] = this.keepAlive ? "Keep-Alive" : "close";
        }
        for (const name of Object.keys(headers)) {
          const value = headers[name];
          if (value) {
            req.setHeader(name, value);
          }
        }
      }
      async connect(req, opts) {
        req._header = null;
        if (!req.path.includes("://")) {
          this.setRequestProps(req, opts);
        }
        let first;
        let endOfHeaders;
        debug2("Regenerating stored HTTP header string for request");
        req._implicitHeader();
        if (req.outputData && req.outputData.length > 0) {
          debug2("Patching connection write() output buffer with updated header");
          first = req.outputData[0].data;
          endOfHeaders = first.indexOf("\r\n\r\n") + 4;
          req.outputData[0].data = req._header + first.substring(endOfHeaders);
          debug2("Output buffer: %o", req.outputData[0].data);
        }
        let socket;
        if (this.proxy.protocol === "https:") {
          debug2("Creating `tls.Socket`: %o", this.connectOpts);
          socket = tls.connect(this.connectOpts);
        } else {
          debug2("Creating `net.Socket`: %o", this.connectOpts);
          socket = net.connect(this.connectOpts);
        }
        await (0, events_1.once)(socket, "connect");
        return socket;
      }
    };
    HttpProxyAgent.protocols = ["http", "https"];
    exports2.HttpProxyAgent = HttpProxyAgent;
    function omit(obj, ...keys) {
      const ret = {};
      let key;
      for (key in obj) {
        if (!keys.includes(key)) {
          ret[key] = obj[key];
        }
      }
      return ret;
    }
    __name(omit, "omit");
  }
});

// ../../node_modules/https-proxy-agent/dist/parse-proxy-response.js
var require_parse_proxy_response = __commonJS({
  "../../node_modules/https-proxy-agent/dist/parse-proxy-response.js"(exports2) {
    "use strict";
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.parseProxyResponse = void 0;
    var debug_1 = __importDefault2(require_src2());
    var debug2 = (0, debug_1.default)("https-proxy-agent:parse-proxy-response");
    function parseProxyResponse(socket) {
      return new Promise((resolve13, reject) => {
        let buffersLength = 0;
        const buffers = [];
        function read() {
          const b32 = socket.read();
          if (b32)
            ondata(b32);
          else
            socket.once("readable", read);
        }
        __name(read, "read");
        function cleanup() {
          socket.removeListener("end", onend);
          socket.removeListener("error", onerror);
          socket.removeListener("readable", read);
        }
        __name(cleanup, "cleanup");
        function onend() {
          cleanup();
          debug2("onend");
          reject(new Error("Proxy connection ended before receiving CONNECT response"));
        }
        __name(onend, "onend");
        function onerror(err) {
          cleanup();
          debug2("onerror %o", err);
          reject(err);
        }
        __name(onerror, "onerror");
        function ondata(b32) {
          buffers.push(b32);
          buffersLength += b32.length;
          const buffered = Buffer.concat(buffers, buffersLength);
          const endOfHeaders = buffered.indexOf("\r\n\r\n");
          if (endOfHeaders === -1) {
            debug2("have not received end of HTTP headers yet...");
            read();
            return;
          }
          const headerParts = buffered.slice(0, endOfHeaders).toString("ascii").split("\r\n");
          const firstLine = headerParts.shift();
          if (!firstLine) {
            socket.destroy();
            return reject(new Error("No header received from proxy CONNECT response"));
          }
          const firstLineParts = firstLine.split(" ");
          const statusCode = +firstLineParts[1];
          const statusText = firstLineParts.slice(2).join(" ");
          const headers = {};
          for (const header of headerParts) {
            if (!header)
              continue;
            const firstColon = header.indexOf(":");
            if (firstColon === -1) {
              socket.destroy();
              return reject(new Error(`Invalid header from proxy CONNECT response: "${header}"`));
            }
            const key = header.slice(0, firstColon).toLowerCase();
            const value = header.slice(firstColon + 1).trimStart();
            const current = headers[key];
            if (typeof current === "string") {
              headers[key] = [current, value];
            } else if (Array.isArray(current)) {
              current.push(value);
            } else {
              headers[key] = value;
            }
          }
          debug2("got proxy server response: %o %o", firstLine, headers);
          cleanup();
          resolve13({
            connect: {
              statusCode,
              statusText,
              headers
            },
            buffered
          });
        }
        __name(ondata, "ondata");
        socket.on("error", onerror);
        socket.on("end", onend);
        read();
      });
    }
    __name(parseProxyResponse, "parseProxyResponse");
    exports2.parseProxyResponse = parseProxyResponse;
  }
});

// ../../node_modules/https-proxy-agent/dist/index.js
var require_dist6 = __commonJS({
  "../../node_modules/https-proxy-agent/dist/index.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __setModuleDefault2 = exports2 && exports2.__setModuleDefault || (Object.create ? (function(o10, v) {
      Object.defineProperty(o10, "default", { enumerable: true, value: v });
    }) : function(o10, v) {
      o10["default"] = v;
    });
    var __importStar2 = exports2 && exports2.__importStar || function(mod) {
      if (mod && mod.__esModule) return mod;
      var result2 = {};
      if (mod != null) {
        for (var k32 in mod) if (k32 !== "default" && Object.prototype.hasOwnProperty.call(mod, k32)) __createBinding3(result2, mod, k32);
      }
      __setModuleDefault2(result2, mod);
      return result2;
    };
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.HttpsProxyAgent = void 0;
    var net = __importStar2(require("net"));
    var tls = __importStar2(require("tls"));
    var assert_1 = __importDefault2(require("assert"));
    var debug_1 = __importDefault2(require_src2());
    var agent_base_1 = require_dist4();
    var url_1 = require("url");
    var parse_proxy_response_1 = require_parse_proxy_response();
    var debug2 = (0, debug_1.default)("https-proxy-agent");
    var setServernameFromNonIpHost = /* @__PURE__ */ __name((options) => {
      if (options.servername === void 0 && options.host && !net.isIP(options.host)) {
        return {
          ...options,
          servername: options.host
        };
      }
      return options;
    }, "setServernameFromNonIpHost");
    var HttpsProxyAgent = class extends agent_base_1.Agent {
      static {
        __name(this, "HttpsProxyAgent");
      }
      constructor(proxy, opts) {
        super(opts);
        this.options = { path: void 0 };
        this.proxy = typeof proxy === "string" ? new url_1.URL(proxy) : proxy;
        this.proxyHeaders = opts?.headers ?? {};
        debug2("Creating new HttpsProxyAgent instance: %o", this.proxy.href);
        const host = (this.proxy.hostname || this.proxy.host).replace(/^\[|\]$/g, "");
        const port = this.proxy.port ? parseInt(this.proxy.port, 10) : this.proxy.protocol === "https:" ? 443 : 80;
        this.connectOpts = {
          // Attempt to negotiate http/1.1 for proxy servers that support http/2
          ALPNProtocols: ["http/1.1"],
          ...opts ? omit(opts, "headers") : null,
          host,
          port
        };
      }
      /**
       * Called when the node-core HTTP client library is creating a
       * new HTTP request.
       */
      async connect(req, opts) {
        const { proxy } = this;
        if (!opts.host) {
          throw new TypeError('No "host" provided');
        }
        let socket;
        if (proxy.protocol === "https:") {
          debug2("Creating `tls.Socket`: %o", this.connectOpts);
          socket = tls.connect(setServernameFromNonIpHost(this.connectOpts));
        } else {
          debug2("Creating `net.Socket`: %o", this.connectOpts);
          socket = net.connect(this.connectOpts);
        }
        const headers = typeof this.proxyHeaders === "function" ? this.proxyHeaders() : { ...this.proxyHeaders };
        const host = net.isIPv6(opts.host) ? `[${opts.host}]` : opts.host;
        let payload3 = `CONNECT ${host}:${opts.port} HTTP/1.1\r
`;
        if (proxy.username || proxy.password) {
          const auth = `${decodeURIComponent(proxy.username)}:${decodeURIComponent(proxy.password)}`;
          headers["Proxy-Authorization"] = `Basic ${Buffer.from(auth).toString("base64")}`;
        }
        headers.Host = `${host}:${opts.port}`;
        if (!headers["Proxy-Connection"]) {
          headers["Proxy-Connection"] = this.keepAlive ? "Keep-Alive" : "close";
        }
        for (const name of Object.keys(headers)) {
          payload3 += `${name}: ${headers[name]}\r
`;
        }
        const proxyResponsePromise = (0, parse_proxy_response_1.parseProxyResponse)(socket);
        socket.write(`${payload3}\r
`);
        const { connect, buffered } = await proxyResponsePromise;
        req.emit("proxyConnect", connect);
        this.emit("proxyConnect", connect, req);
        if (connect.statusCode === 200) {
          req.once("socket", resume);
          if (opts.secureEndpoint) {
            debug2("Upgrading socket connection to TLS");
            return tls.connect({
              ...omit(setServernameFromNonIpHost(opts), "host", "path", "port"),
              socket
            });
          }
          return socket;
        }
        socket.destroy();
        const fakeSocket = new net.Socket({ writable: false });
        fakeSocket.readable = true;
        req.once("socket", (s) => {
          debug2("Replaying proxy buffer for failed request");
          (0, assert_1.default)(s.listenerCount("data") > 0);
          s.push(buffered);
          s.push(null);
        });
        return fakeSocket;
      }
    };
    HttpsProxyAgent.protocols = ["http", "https"];
    exports2.HttpsProxyAgent = HttpsProxyAgent;
    function resume(socket) {
      socket.resume();
    }
    __name(resume, "resume");
    function omit(obj, ...keys) {
      const ret = {};
      let key;
      for (key in obj) {
        if (!keys.includes(key)) {
          ret[key] = obj[key];
        }
      }
      return ret;
    }
    __name(omit, "omit");
  }
});

// ../../node_modules/smart-buffer/build/utils.js
var require_utils9 = __commonJS({
  "../../node_modules/smart-buffer/build/utils.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var buffer_1 = require("buffer");
    var ERRORS = {
      INVALID_ENCODING: "Invalid encoding provided. Please specify a valid encoding the internal Node.js Buffer supports.",
      INVALID_SMARTBUFFER_SIZE: "Invalid size provided. Size must be a valid integer greater than zero.",
      INVALID_SMARTBUFFER_BUFFER: "Invalid Buffer provided in SmartBufferOptions.",
      INVALID_SMARTBUFFER_OBJECT: "Invalid SmartBufferOptions object supplied to SmartBuffer constructor or factory methods.",
      INVALID_OFFSET: "An invalid offset value was provided.",
      INVALID_OFFSET_NON_NUMBER: "An invalid offset value was provided. A numeric value is required.",
      INVALID_LENGTH: "An invalid length value was provided.",
      INVALID_LENGTH_NON_NUMBER: "An invalid length value was provived. A numeric value is required.",
      INVALID_TARGET_OFFSET: "Target offset is beyond the bounds of the internal SmartBuffer data.",
      INVALID_TARGET_LENGTH: "Specified length value moves cursor beyong the bounds of the internal SmartBuffer data.",
      INVALID_READ_BEYOND_BOUNDS: "Attempted to read beyond the bounds of the managed data.",
      INVALID_WRITE_BEYOND_BOUNDS: "Attempted to write beyond the bounds of the managed data."
    };
    exports2.ERRORS = ERRORS;
    function checkEncoding(encoding) {
      if (!buffer_1.Buffer.isEncoding(encoding)) {
        throw new Error(ERRORS.INVALID_ENCODING);
      }
    }
    __name(checkEncoding, "checkEncoding");
    exports2.checkEncoding = checkEncoding;
    function isFiniteInteger(value) {
      return typeof value === "number" && isFinite(value) && isInteger(value);
    }
    __name(isFiniteInteger, "isFiniteInteger");
    exports2.isFiniteInteger = isFiniteInteger;
    function checkOffsetOrLengthValue(value, offset) {
      if (typeof value === "number") {
        if (!isFiniteInteger(value) || value < 0) {
          throw new Error(offset ? ERRORS.INVALID_OFFSET : ERRORS.INVALID_LENGTH);
        }
      } else {
        throw new Error(offset ? ERRORS.INVALID_OFFSET_NON_NUMBER : ERRORS.INVALID_LENGTH_NON_NUMBER);
      }
    }
    __name(checkOffsetOrLengthValue, "checkOffsetOrLengthValue");
    function checkLengthValue(length) {
      checkOffsetOrLengthValue(length, false);
    }
    __name(checkLengthValue, "checkLengthValue");
    exports2.checkLengthValue = checkLengthValue;
    function checkOffsetValue(offset) {
      checkOffsetOrLengthValue(offset, true);
    }
    __name(checkOffsetValue, "checkOffsetValue");
    exports2.checkOffsetValue = checkOffsetValue;
    function checkTargetOffset(offset, buff) {
      if (offset < 0 || offset > buff.length) {
        throw new Error(ERRORS.INVALID_TARGET_OFFSET);
      }
    }
    __name(checkTargetOffset, "checkTargetOffset");
    exports2.checkTargetOffset = checkTargetOffset;
    function isInteger(value) {
      return typeof value === "number" && isFinite(value) && Math.floor(value) === value;
    }
    __name(isInteger, "isInteger");
    function bigIntAndBufferInt64Check(bufferMethod) {
      if (typeof BigInt === "undefined") {
        throw new Error("Platform does not support JS BigInt type.");
      }
      if (typeof buffer_1.Buffer.prototype[bufferMethod] === "undefined") {
        throw new Error(`Platform does not support Buffer.prototype.${bufferMethod}.`);
      }
    }
    __name(bigIntAndBufferInt64Check, "bigIntAndBufferInt64Check");
    exports2.bigIntAndBufferInt64Check = bigIntAndBufferInt64Check;
  }
});

// ../../node_modules/smart-buffer/build/smartbuffer.js
var require_smartbuffer = __commonJS({
  "../../node_modules/smart-buffer/build/smartbuffer.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var utils_1 = require_utils9();
    var DEFAULT_SMARTBUFFER_SIZE = 4096;
    var DEFAULT_SMARTBUFFER_ENCODING = "utf8";
    var SmartBuffer = class _SmartBuffer {
      static {
        __name(this, "SmartBuffer");
      }
      /**
       * Creates a new SmartBuffer instance.
       *
       * @param options { SmartBufferOptions } The SmartBufferOptions to apply to this instance.
       */
      constructor(options) {
        this.length = 0;
        this._encoding = DEFAULT_SMARTBUFFER_ENCODING;
        this._writeOffset = 0;
        this._readOffset = 0;
        if (_SmartBuffer.isSmartBufferOptions(options)) {
          if (options.encoding) {
            utils_1.checkEncoding(options.encoding);
            this._encoding = options.encoding;
          }
          if (options.size) {
            if (utils_1.isFiniteInteger(options.size) && options.size > 0) {
              this._buff = Buffer.allocUnsafe(options.size);
            } else {
              throw new Error(utils_1.ERRORS.INVALID_SMARTBUFFER_SIZE);
            }
          } else if (options.buff) {
            if (Buffer.isBuffer(options.buff)) {
              this._buff = options.buff;
              this.length = options.buff.length;
            } else {
              throw new Error(utils_1.ERRORS.INVALID_SMARTBUFFER_BUFFER);
            }
          } else {
            this._buff = Buffer.allocUnsafe(DEFAULT_SMARTBUFFER_SIZE);
          }
        } else {
          if (typeof options !== "undefined") {
            throw new Error(utils_1.ERRORS.INVALID_SMARTBUFFER_OBJECT);
          }
          this._buff = Buffer.allocUnsafe(DEFAULT_SMARTBUFFER_SIZE);
        }
      }
      /**
       * Creates a new SmartBuffer instance with the provided internal Buffer size and optional encoding.
       *
       * @param size { Number } The size of the internal Buffer.
       * @param encoding { String } The BufferEncoding to use for strings.
       *
       * @return { SmartBuffer }
       */
      static fromSize(size, encoding) {
        return new this({
          size,
          encoding
        });
      }
      /**
       * Creates a new SmartBuffer instance with the provided Buffer and optional encoding.
       *
       * @param buffer { Buffer } The Buffer to use as the internal Buffer value.
       * @param encoding { String } The BufferEncoding to use for strings.
       *
       * @return { SmartBuffer }
       */
      static fromBuffer(buff, encoding) {
        return new this({
          buff,
          encoding
        });
      }
      /**
       * Creates a new SmartBuffer instance with the provided SmartBufferOptions options.
       *
       * @param options { SmartBufferOptions } The options to use when creating the SmartBuffer instance.
       */
      static fromOptions(options) {
        return new this(options);
      }
      /**
       * Type checking function that determines if an object is a SmartBufferOptions object.
       */
      static isSmartBufferOptions(options) {
        const castOptions = options;
        return castOptions && (castOptions.encoding !== void 0 || castOptions.size !== void 0 || castOptions.buff !== void 0);
      }
      // Signed integers
      /**
       * Reads an Int8 value from the current read position or an optionally provided offset.
       *
       * @param offset { Number } The offset to read data from (optional)
       * @return { Number }
       */
      readInt8(offset) {
        return this._readNumberValue(Buffer.prototype.readInt8, 1, offset);
      }
      /**
       * Reads an Int16BE value from the current read position or an optionally provided offset.
       *
       * @param offset { Number } The offset to read data from (optional)
       * @return { Number }
       */
      readInt16BE(offset) {
        return this._readNumberValue(Buffer.prototype.readInt16BE, 2, offset);
      }
      /**
       * Reads an Int16LE value from the current read position or an optionally provided offset.
       *
       * @param offset { Number } The offset to read data from (optional)
       * @return { Number }
       */
      readInt16LE(offset) {
        return this._readNumberValue(Buffer.prototype.readInt16LE, 2, offset);
      }
      /**
       * Reads an Int32BE value from the current read position or an optionally provided offset.
       *
       * @param offset { Number } The offset to read data from (optional)
       * @return { Number }
       */
      readInt32BE(offset) {
        return this._readNumberValue(Buffer.prototype.readInt32BE, 4, offset);
      }
      /**
       * Reads an Int32LE value from the current read position or an optionally provided offset.
       *
       * @param offset { Number } The offset to read data from (optional)
       * @return { Number }
       */
      readInt32LE(offset) {
        return this._readNumberValue(Buffer.prototype.readInt32LE, 4, offset);
      }
      /**
       * Reads a BigInt64BE value from the current read position or an optionally provided offset.
       *
       * @param offset { Number } The offset to read data from (optional)
       * @return { BigInt }
       */
      readBigInt64BE(offset) {
        utils_1.bigIntAndBufferInt64Check("readBigInt64BE");
        return this._readNumberValue(Buffer.prototype.readBigInt64BE, 8, offset);
      }
      /**
       * Reads a BigInt64LE value from the current read position or an optionally provided offset.
       *
       * @param offset { Number } The offset to read data from (optional)
       * @return { BigInt }
       */
      readBigInt64LE(offset) {
        utils_1.bigIntAndBufferInt64Check("readBigInt64LE");
        return this._readNumberValue(Buffer.prototype.readBigInt64LE, 8, offset);
      }
      /**
       * Writes an Int8 value to the current write position (or at optional offset).
       *
       * @param value { Number } The value to write.
       * @param offset { Number } The offset to write the value at.
       *
       * @return this
       */
      writeInt8(value, offset) {
        this._writeNumberValue(Buffer.prototype.writeInt8, 1, value, offset);
        return this;
      }
      /**
       * Inserts an Int8 value at the given offset value.
       *
       * @param value { Number } The value to insert.
       * @param offset { Number } The offset to insert the value at.
       *
       * @return this
       */
      insertInt8(value, offset) {
        return this._insertNumberValue(Buffer.prototype.writeInt8, 1, value, offset);
      }
      /**
       * Writes an Int16BE value to the current write position (or at optional offset).
       *
       * @param value { Number } The value to write.
       * @param offset { Number } The offset to write the value at.
       *
       * @return this
       */
      writeInt16BE(value, offset) {
        return this._writeNumberValue(Buffer.prototype.writeInt16BE, 2, value, offset);
      }
      /**
       * Inserts an Int16BE value at the given offset value.
       *
       * @param value { Number } The value to insert.
       * @param offset { Number } The offset to insert the value at.
       *
       * @return this
       */
      insertInt16BE(value, offset) {
        return this._insertNumberValue(Buffer.prototype.writeInt16BE, 2, value, offset);
      }
      /**
       * Writes an Int16LE value to the current write position (or at optional offset).
       *
       * @param value { Number } The value to write.
       * @param offset { Number } The offset to write the value at.
       *
       * @return this
       */
      writeInt16LE(value, offset) {
        return this._writeNumberValue(Buffer.prototype.writeInt16LE, 2, value, offset);
      }
      /**
       * Inserts an Int16LE value at the given offset value.
       *
       * @param value { Number } The value to insert.
       * @param offset { Number } The offset to insert the value at.
       *
       * @return this
       */
      insertInt16LE(value, offset) {
        return this._insertNumberValue(Buffer.prototype.writeInt16LE, 2, value, offset);
      }
      /**
       * Writes an Int32BE value to the current write position (or at optional offset).
       *
       * @param value { Number } The value to write.
       * @param offset { Number } The offset to write the value at.
       *
       * @return this
       */
      writeInt32BE(value, offset) {
        return this._writeNumberValue(Buffer.prototype.writeInt32BE, 4, value, offset);
      }
      /**
       * Inserts an Int32BE value at the given offset value.
       *
       * @param value { Number } The value to insert.
       * @param offset { Number } The offset to insert the value at.
       *
       * @return this
       */
      insertInt32BE(value, offset) {
        return this._insertNumberValue(Buffer.prototype.writeInt32BE, 4, value, offset);
      }
      /**
       * Writes an Int32LE value to the current write position (or at optional offset).
       *
       * @param value { Number } The value to write.
       * @param offset { Number } The offset to write the value at.
       *
       * @return this
       */
      writeInt32LE(value, offset) {
        return this._writeNumberValue(Buffer.prototype.writeInt32LE, 4, value, offset);
      }
      /**
       * Inserts an Int32LE value at the given offset value.
       *
       * @param value { Number } The value to insert.
       * @param offset { Number } The offset to insert the value at.
       *
       * @return this
       */
      insertInt32LE(value, offset) {
        return this._insertNumberValue(Buffer.prototype.writeInt32LE, 4, value, offset);
      }
      /**
       * Writes a BigInt64BE value to the current write position (or at optional offset).
       *
       * @param value { BigInt } The value to write.
       * @param offset { Number } The offset to write the value at.
       *
       * @return this
       */
      writeBigInt64BE(value, offset) {
        utils_1.bigIntAndBufferInt64Check("writeBigInt64BE");
        return this._writeNumberValue(Buffer.prototype.writeBigInt64BE, 8, value, offset);
      }
      /**
       * Inserts a BigInt64BE value at the given offset value.
       *
       * @param value { BigInt } The value to insert.
       * @param offset { Number } The offset to insert the value at.
       *
       * @return this
       */
      insertBigInt64BE(value, offset) {
        utils_1.bigIntAndBufferInt64Check("writeBigInt64BE");
        return this._insertNumberValue(Buffer.prototype.writeBigInt64BE, 8, value, offset);
      }
      /**
       * Writes a BigInt64LE value to the current write position (or at optional offset).
       *
       * @param value { BigInt } The value to write.
       * @param offset { Number } The offset to write the value at.
       *
       * @return this
       */
      writeBigInt64LE(value, offset) {
        utils_1.bigIntAndBufferInt64Check("writeBigInt64LE");
        return this._writeNumberValue(Buffer.prototype.writeBigInt64LE, 8, value, offset);
      }
      /**
       * Inserts a Int64LE value at the given offset value.
       *
       * @param value { BigInt } The value to insert.
       * @param offset { Number } The offset to insert the value at.
       *
       * @return this
       */
      insertBigInt64LE(value, offset) {
        utils_1.bigIntAndBufferInt64Check("writeBigInt64LE");
        return this._insertNumberValue(Buffer.prototype.writeBigInt64LE, 8, value, offset);
      }
      // Unsigned Integers
      /**
       * Reads an UInt8 value from the current read position or an optionally provided offset.
       *
       * @param offset { Number } The offset to read data from (optional)
       * @return { Number }
       */
      readUInt8(offset) {
        return this._readNumberValue(Buffer.prototype.readUInt8, 1, offset);
      }
      /**
       * Reads an UInt16BE value from the current read position or an optionally provided offset.
       *
       * @param offset { Number } The offset to read data from (optional)
       * @return { Number }
       */
      readUInt16BE(offset) {
        return this._readNumberValue(Buffer.prototype.readUInt16BE, 2, offset);
      }
      /**
       * Reads an UInt16LE value from the current read position or an optionally provided offset.
       *
       * @param offset { Number } The offset to read data from (optional)
       * @return { Number }
       */
      readUInt16LE(offset) {
        return this._readNumberValue(Buffer.prototype.readUInt16LE, 2, offset);
      }
      /**
       * Reads an UInt32BE value from the current read position or an optionally provided offset.
       *
       * @param offset { Number } The offset to read data from (optional)
       * @return { Number }
       */
      readUInt32BE(offset) {
        return this._readNumberValue(Buffer.prototype.readUInt32BE, 4, offset);
      }
      /**
       * Reads an UInt32LE value from the current read position or an optionally provided offset.
       *
       * @param offset { Number } The offset to read data from (optional)
       * @return { Number }
       */
      readUInt32LE(offset) {
        return this._readNumberValue(Buffer.prototype.readUInt32LE, 4, offset);
      }
      /**
       * Reads a BigUInt64BE value from the current read position or an optionally provided offset.
       *
       * @param offset { Number } The offset to read data from (optional)
       * @return { BigInt }
       */
      readBigUInt64BE(offset) {
        utils_1.bigIntAndBufferInt64Check("readBigUInt64BE");
        return this._readNumberValue(Buffer.prototype.readBigUInt64BE, 8, offset);
      }
      /**
       * Reads a BigUInt64LE value from the current read position or an optionally provided offset.
       *
       * @param offset { Number } The offset to read data from (optional)
       * @return { BigInt }
       */
      readBigUInt64LE(offset) {
        utils_1.bigIntAndBufferInt64Check("readBigUInt64LE");
        return this._readNumberValue(Buffer.prototype.readBigUInt64LE, 8, offset);
      }
      /**
       * Writes an UInt8 value to the current write position (or at optional offset).
       *
       * @param value { Number } The value to write.
       * @param offset { Number } The offset to write the value at.
       *
       * @return this
       */
      writeUInt8(value, offset) {
        return this._writeNumberValue(Buffer.prototype.writeUInt8, 1, value, offset);
      }
      /**
       * Inserts an UInt8 value at the given offset value.
       *
       * @param value { Number } The value to insert.
       * @param offset { Number } The offset to insert the value at.
       *
       * @return this
       */
      insertUInt8(value, offset) {
        return this._insertNumberValue(Buffer.prototype.writeUInt8, 1, value, offset);
      }
      /**
       * Writes an UInt16BE value to the current write position (or at optional offset).
       *
       * @param value { Number } The value to write.
       * @param offset { Number } The offset to write the value at.
       *
       * @return this
       */
      writeUInt16BE(value, offset) {
        return this._writeNumberValue(Buffer.prototype.writeUInt16BE, 2, value, offset);
      }
      /**
       * Inserts an UInt16BE value at the given offset value.
       *
       * @param value { Number } The value to insert.
       * @param offset { Number } The offset to insert the value at.
       *
       * @return this
       */
      insertUInt16BE(value, offset) {
        return this._insertNumberValue(Buffer.prototype.writeUInt16BE, 2, value, offset);
      }
      /**
       * Writes an UInt16LE value to the current write position (or at optional offset).
       *
       * @param value { Number } The value to write.
       * @param offset { Number } The offset to write the value at.
       *
       * @return this
       */
      writeUInt16LE(value, offset) {
        return this._writeNumberValue(Buffer.prototype.writeUInt16LE, 2, value, offset);
      }
      /**
       * Inserts an UInt16LE value at the given offset value.
       *
       * @param value { Number } The value to insert.
       * @param offset { Number } The offset to insert the value at.
       *
       * @return this
       */
      insertUInt16LE(value, offset) {
        return this._insertNumberValue(Buffer.prototype.writeUInt16LE, 2, value, offset);
      }
      /**
       * Writes an UInt32BE value to the current write position (or at optional offset).
       *
       * @param value { Number } The value to write.
       * @param offset { Number } The offset to write the value at.
       *
       * @return this
       */
      writeUInt32BE(value, offset) {
        return this._writeNumberValue(Buffer.prototype.writeUInt32BE, 4, value, offset);
      }
      /**
       * Inserts an UInt32BE value at the given offset value.
       *
       * @param value { Number } The value to insert.
       * @param offset { Number } The offset to insert the value at.
       *
       * @return this
       */
      insertUInt32BE(value, offset) {
        return this._insertNumberValue(Buffer.prototype.writeUInt32BE, 4, value, offset);
      }
      /**
       * Writes an UInt32LE value to the current write position (or at optional offset).
       *
       * @param value { Number } The value to write.
       * @param offset { Number } The offset to write the value at.
       *
       * @return this
       */
      writeUInt32LE(value, offset) {
        return this._writeNumberValue(Buffer.prototype.writeUInt32LE, 4, value, offset);
      }
      /**
       * Inserts an UInt32LE value at the given offset value.
       *
       * @param value { Number } The value to insert.
       * @param offset { Number } The offset to insert the value at.
       *
       * @return this
       */
      insertUInt32LE(value, offset) {
        return this._insertNumberValue(Buffer.prototype.writeUInt32LE, 4, value, offset);
      }
      /**
       * Writes a BigUInt64BE value to the current write position (or at optional offset).
       *
       * @param value { Number } The value to write.
       * @param offset { Number } The offset to write the value at.
       *
       * @return this
       */
      writeBigUInt64BE(value, offset) {
        utils_1.bigIntAndBufferInt64Check("writeBigUInt64BE");
        return this._writeNumberValue(Buffer.prototype.writeBigUInt64BE, 8, value, offset);
      }
      /**
       * Inserts a BigUInt64BE value at the given offset value.
       *
       * @param value { Number } The value to insert.
       * @param offset { Number } The offset to insert the value at.
       *
       * @return this
       */
      insertBigUInt64BE(value, offset) {
        utils_1.bigIntAndBufferInt64Check("writeBigUInt64BE");
        return this._insertNumberValue(Buffer.prototype.writeBigUInt64BE, 8, value, offset);
      }
      /**
       * Writes a BigUInt64LE value to the current write position (or at optional offset).
       *
       * @param value { Number } The value to write.
       * @param offset { Number } The offset to write the value at.
       *
       * @return this
       */
      writeBigUInt64LE(value, offset) {
        utils_1.bigIntAndBufferInt64Check("writeBigUInt64LE");
        return this._writeNumberValue(Buffer.prototype.writeBigUInt64LE, 8, value, offset);
      }
      /**
       * Inserts a BigUInt64LE value at the given offset value.
       *
       * @param value { Number } The value to insert.
       * @param offset { Number } The offset to insert the value at.
       *
       * @return this
       */
      insertBigUInt64LE(value, offset) {
        utils_1.bigIntAndBufferInt64Check("writeBigUInt64LE");
        return this._insertNumberValue(Buffer.prototype.writeBigUInt64LE, 8, value, offset);
      }
      // Floating Point
      /**
       * Reads an FloatBE value from the current read position or an optionally provided offset.
       *
       * @param offset { Number } The offset to read data from (optional)
       * @return { Number }
       */
      readFloatBE(offset) {
        return this._readNumberValue(Buffer.prototype.readFloatBE, 4, offset);
      }
      /**
       * Reads an FloatLE value from the current read position or an optionally provided offset.
       *
       * @param offset { Number } The offset to read data from (optional)
       * @return { Number }
       */
      readFloatLE(offset) {
        return this._readNumberValue(Buffer.prototype.readFloatLE, 4, offset);
      }
      /**
       * Writes a FloatBE value to the current write position (or at optional offset).
       *
       * @param value { Number } The value to write.
       * @param offset { Number } The offset to write the value at.
       *
       * @return this
       */
      writeFloatBE(value, offset) {
        return this._writeNumberValue(Buffer.prototype.writeFloatBE, 4, value, offset);
      }
      /**
       * Inserts a FloatBE value at the given offset value.
       *
       * @param value { Number } The value to insert.
       * @param offset { Number } The offset to insert the value at.
       *
       * @return this
       */
      insertFloatBE(value, offset) {
        return this._insertNumberValue(Buffer.prototype.writeFloatBE, 4, value, offset);
      }
      /**
       * Writes a FloatLE value to the current write position (or at optional offset).
       *
       * @param value { Number } The value to write.
       * @param offset { Number } The offset to write the value at.
       *
       * @return this
       */
      writeFloatLE(value, offset) {
        return this._writeNumberValue(Buffer.prototype.writeFloatLE, 4, value, offset);
      }
      /**
       * Inserts a FloatLE value at the given offset value.
       *
       * @param value { Number } The value to insert.
       * @param offset { Number } The offset to insert the value at.
       *
       * @return this
       */
      insertFloatLE(value, offset) {
        return this._insertNumberValue(Buffer.prototype.writeFloatLE, 4, value, offset);
      }
      // Double Floating Point
      /**
       * Reads an DoublEBE value from the current read position or an optionally provided offset.
       *
       * @param offset { Number } The offset to read data from (optional)
       * @return { Number }
       */
      readDoubleBE(offset) {
        return this._readNumberValue(Buffer.prototype.readDoubleBE, 8, offset);
      }
      /**
       * Reads an DoubleLE value from the current read position or an optionally provided offset.
       *
       * @param offset { Number } The offset to read data from (optional)
       * @return { Number }
       */
      readDoubleLE(offset) {
        return this._readNumberValue(Buffer.prototype.readDoubleLE, 8, offset);
      }
      /**
       * Writes a DoubleBE value to the current write position (or at optional offset).
       *
       * @param value { Number } The value to write.
       * @param offset { Number } The offset to write the value at.
       *
       * @return this
       */
      writeDoubleBE(value, offset) {
        return this._writeNumberValue(Buffer.prototype.writeDoubleBE, 8, value, offset);
      }
      /**
       * Inserts a DoubleBE value at the given offset value.
       *
       * @param value { Number } The value to insert.
       * @param offset { Number } The offset to insert the value at.
       *
       * @return this
       */
      insertDoubleBE(value, offset) {
        return this._insertNumberValue(Buffer.prototype.writeDoubleBE, 8, value, offset);
      }
      /**
       * Writes a DoubleLE value to the current write position (or at optional offset).
       *
       * @param value { Number } The value to write.
       * @param offset { Number } The offset to write the value at.
       *
       * @return this
       */
      writeDoubleLE(value, offset) {
        return this._writeNumberValue(Buffer.prototype.writeDoubleLE, 8, value, offset);
      }
      /**
       * Inserts a DoubleLE value at the given offset value.
       *
       * @param value { Number } The value to insert.
       * @param offset { Number } The offset to insert the value at.
       *
       * @return this
       */
      insertDoubleLE(value, offset) {
        return this._insertNumberValue(Buffer.prototype.writeDoubleLE, 8, value, offset);
      }
      // Strings
      /**
       * Reads a String from the current read position.
       *
       * @param arg1 { Number | String } The number of bytes to read as a String, or the BufferEncoding to use for
       *             the string (Defaults to instance level encoding).
       * @param encoding { String } The BufferEncoding to use for the string (Defaults to instance level encoding).
       *
       * @return { String }
       */
      readString(arg1, encoding) {
        let lengthVal;
        if (typeof arg1 === "number") {
          utils_1.checkLengthValue(arg1);
          lengthVal = Math.min(arg1, this.length - this._readOffset);
        } else {
          encoding = arg1;
          lengthVal = this.length - this._readOffset;
        }
        if (typeof encoding !== "undefined") {
          utils_1.checkEncoding(encoding);
        }
        const value = this._buff.slice(this._readOffset, this._readOffset + lengthVal).toString(encoding || this._encoding);
        this._readOffset += lengthVal;
        return value;
      }
      /**
       * Inserts a String
       *
       * @param value { String } The String value to insert.
       * @param offset { Number } The offset to insert the string at.
       * @param encoding { String } The BufferEncoding to use for writing strings (defaults to instance encoding).
       *
       * @return this
       */
      insertString(value, offset, encoding) {
        utils_1.checkOffsetValue(offset);
        return this._handleString(value, true, offset, encoding);
      }
      /**
       * Writes a String
       *
       * @param value { String } The String value to write.
       * @param arg2 { Number | String } The offset to write the string at, or the BufferEncoding to use.
       * @param encoding { String } The BufferEncoding to use for writing strings (defaults to instance encoding).
       *
       * @return this
       */
      writeString(value, arg2, encoding) {
        return this._handleString(value, false, arg2, encoding);
      }
      /**
       * Reads a null-terminated String from the current read position.
       *
       * @param encoding { String } The BufferEncoding to use for the string (Defaults to instance level encoding).
       *
       * @return { String }
       */
      readStringNT(encoding) {
        if (typeof encoding !== "undefined") {
          utils_1.checkEncoding(encoding);
        }
        let nullPos = this.length;
        for (let i32 = this._readOffset; i32 < this.length; i32++) {
          if (this._buff[i32] === 0) {
            nullPos = i32;
            break;
          }
        }
        const value = this._buff.slice(this._readOffset, nullPos);
        this._readOffset = nullPos + 1;
        return value.toString(encoding || this._encoding);
      }
      /**
       * Inserts a null-terminated String.
       *
       * @param value { String } The String value to write.
       * @param arg2 { Number | String } The offset to write the string to, or the BufferEncoding to use.
       * @param encoding { String } The BufferEncoding to use for writing strings (defaults to instance encoding).
       *
       * @return this
       */
      insertStringNT(value, offset, encoding) {
        utils_1.checkOffsetValue(offset);
        this.insertString(value, offset, encoding);
        this.insertUInt8(0, offset + value.length);
        return this;
      }
      /**
       * Writes a null-terminated String.
       *
       * @param value { String } The String value to write.
       * @param arg2 { Number | String } The offset to write the string to, or the BufferEncoding to use.
       * @param encoding { String } The BufferEncoding to use for writing strings (defaults to instance encoding).
       *
       * @return this
       */
      writeStringNT(value, arg2, encoding) {
        this.writeString(value, arg2, encoding);
        this.writeUInt8(0, typeof arg2 === "number" ? arg2 + value.length : this.writeOffset);
        return this;
      }
      // Buffers
      /**
       * Reads a Buffer from the internal read position.
       *
       * @param length { Number } The length of data to read as a Buffer.
       *
       * @return { Buffer }
       */
      readBuffer(length) {
        if (typeof length !== "undefined") {
          utils_1.checkLengthValue(length);
        }
        const lengthVal = typeof length === "number" ? length : this.length;
        const endPoint = Math.min(this.length, this._readOffset + lengthVal);
        const value = this._buff.slice(this._readOffset, endPoint);
        this._readOffset = endPoint;
        return value;
      }
      /**
       * Writes a Buffer to the current write position.
       *
       * @param value { Buffer } The Buffer to write.
       * @param offset { Number } The offset to write the Buffer to.
       *
       * @return this
       */
      insertBuffer(value, offset) {
        utils_1.checkOffsetValue(offset);
        return this._handleBuffer(value, true, offset);
      }
      /**
       * Writes a Buffer to the current write position.
       *
       * @param value { Buffer } The Buffer to write.
       * @param offset { Number } The offset to write the Buffer to.
       *
       * @return this
       */
      writeBuffer(value, offset) {
        return this._handleBuffer(value, false, offset);
      }
      /**
       * Reads a null-terminated Buffer from the current read poisiton.
       *
       * @return { Buffer }
       */
      readBufferNT() {
        let nullPos = this.length;
        for (let i32 = this._readOffset; i32 < this.length; i32++) {
          if (this._buff[i32] === 0) {
            nullPos = i32;
            break;
          }
        }
        const value = this._buff.slice(this._readOffset, nullPos);
        this._readOffset = nullPos + 1;
        return value;
      }
      /**
       * Inserts a null-terminated Buffer.
       *
       * @param value { Buffer } The Buffer to write.
       * @param offset { Number } The offset to write the Buffer to.
       *
       * @return this
       */
      insertBufferNT(value, offset) {
        utils_1.checkOffsetValue(offset);
        this.insertBuffer(value, offset);
        this.insertUInt8(0, offset + value.length);
        return this;
      }
      /**
       * Writes a null-terminated Buffer.
       *
       * @param value { Buffer } The Buffer to write.
       * @param offset { Number } The offset to write the Buffer to.
       *
       * @return this
       */
      writeBufferNT(value, offset) {
        if (typeof offset !== "undefined") {
          utils_1.checkOffsetValue(offset);
        }
        this.writeBuffer(value, offset);
        this.writeUInt8(0, typeof offset === "number" ? offset + value.length : this._writeOffset);
        return this;
      }
      /**
       * Clears the SmartBuffer instance to its original empty state.
       */
      clear() {
        this._writeOffset = 0;
        this._readOffset = 0;
        this.length = 0;
        return this;
      }
      /**
       * Gets the remaining data left to be read from the SmartBuffer instance.
       *
       * @return { Number }
       */
      remaining() {
        return this.length - this._readOffset;
      }
      /**
       * Gets the current read offset value of the SmartBuffer instance.
       *
       * @return { Number }
       */
      get readOffset() {
        return this._readOffset;
      }
      /**
       * Sets the read offset value of the SmartBuffer instance.
       *
       * @param offset { Number } - The offset value to set.
       */
      set readOffset(offset) {
        utils_1.checkOffsetValue(offset);
        utils_1.checkTargetOffset(offset, this);
        this._readOffset = offset;
      }
      /**
       * Gets the current write offset value of the SmartBuffer instance.
       *
       * @return { Number }
       */
      get writeOffset() {
        return this._writeOffset;
      }
      /**
       * Sets the write offset value of the SmartBuffer instance.
       *
       * @param offset { Number } - The offset value to set.
       */
      set writeOffset(offset) {
        utils_1.checkOffsetValue(offset);
        utils_1.checkTargetOffset(offset, this);
        this._writeOffset = offset;
      }
      /**
       * Gets the currently set string encoding of the SmartBuffer instance.
       *
       * @return { BufferEncoding } The string Buffer encoding currently set.
       */
      get encoding() {
        return this._encoding;
      }
      /**
       * Sets the string encoding of the SmartBuffer instance.
       *
       * @param encoding { BufferEncoding } The string Buffer encoding to set.
       */
      set encoding(encoding) {
        utils_1.checkEncoding(encoding);
        this._encoding = encoding;
      }
      /**
       * Gets the underlying internal Buffer. (This includes unmanaged data in the Buffer)
       *
       * @return { Buffer } The Buffer value.
       */
      get internalBuffer() {
        return this._buff;
      }
      /**
       * Gets the value of the internal managed Buffer (Includes managed data only)
       *
       * @param { Buffer }
       */
      toBuffer() {
        return this._buff.slice(0, this.length);
      }
      /**
       * Gets the String value of the internal managed Buffer
       *
       * @param encoding { String } The BufferEncoding to display the Buffer as (defaults to instance level encoding).
       */
      toString(encoding) {
        const encodingVal = typeof encoding === "string" ? encoding : this._encoding;
        utils_1.checkEncoding(encodingVal);
        return this._buff.toString(encodingVal, 0, this.length);
      }
      /**
       * Destroys the SmartBuffer instance.
       */
      destroy() {
        this.clear();
        return this;
      }
      /**
       * Handles inserting and writing strings.
       *
       * @param value { String } The String value to insert.
       * @param isInsert { Boolean } True if inserting a string, false if writing.
       * @param arg2 { Number | String } The offset to insert the string at, or the BufferEncoding to use.
       * @param encoding { String } The BufferEncoding to use for writing strings (defaults to instance encoding).
       */
      _handleString(value, isInsert, arg3, encoding) {
        let offsetVal = this._writeOffset;
        let encodingVal = this._encoding;
        if (typeof arg3 === "number") {
          offsetVal = arg3;
        } else if (typeof arg3 === "string") {
          utils_1.checkEncoding(arg3);
          encodingVal = arg3;
        }
        if (typeof encoding === "string") {
          utils_1.checkEncoding(encoding);
          encodingVal = encoding;
        }
        const byteLength = Buffer.byteLength(value, encodingVal);
        if (isInsert) {
          this.ensureInsertable(byteLength, offsetVal);
        } else {
          this._ensureWriteable(byteLength, offsetVal);
        }
        this._buff.write(value, offsetVal, byteLength, encodingVal);
        if (isInsert) {
          this._writeOffset += byteLength;
        } else {
          if (typeof arg3 === "number") {
            this._writeOffset = Math.max(this._writeOffset, offsetVal + byteLength);
          } else {
            this._writeOffset += byteLength;
          }
        }
        return this;
      }
      /**
       * Handles writing or insert of a Buffer.
       *
       * @param value { Buffer } The Buffer to write.
       * @param offset { Number } The offset to write the Buffer to.
       */
      _handleBuffer(value, isInsert, offset) {
        const offsetVal = typeof offset === "number" ? offset : this._writeOffset;
        if (isInsert) {
          this.ensureInsertable(value.length, offsetVal);
        } else {
          this._ensureWriteable(value.length, offsetVal);
        }
        value.copy(this._buff, offsetVal);
        if (isInsert) {
          this._writeOffset += value.length;
        } else {
          if (typeof offset === "number") {
            this._writeOffset = Math.max(this._writeOffset, offsetVal + value.length);
          } else {
            this._writeOffset += value.length;
          }
        }
        return this;
      }
      /**
       * Ensures that the internal Buffer is large enough to read data.
       *
       * @param length { Number } The length of the data that needs to be read.
       * @param offset { Number } The offset of the data that needs to be read.
       */
      ensureReadable(length, offset) {
        let offsetVal = this._readOffset;
        if (typeof offset !== "undefined") {
          utils_1.checkOffsetValue(offset);
          offsetVal = offset;
        }
        if (offsetVal < 0 || offsetVal + length > this.length) {
          throw new Error(utils_1.ERRORS.INVALID_READ_BEYOND_BOUNDS);
        }
      }
      /**
       * Ensures that the internal Buffer is large enough to insert data.
       *
       * @param dataLength { Number } The length of the data that needs to be written.
       * @param offset { Number } The offset of the data to be written.
       */
      ensureInsertable(dataLength, offset) {
        utils_1.checkOffsetValue(offset);
        this._ensureCapacity(this.length + dataLength);
        if (offset < this.length) {
          this._buff.copy(this._buff, offset + dataLength, offset, this._buff.length);
        }
        if (offset + dataLength > this.length) {
          this.length = offset + dataLength;
        } else {
          this.length += dataLength;
        }
      }
      /**
       * Ensures that the internal Buffer is large enough to write data.
       *
       * @param dataLength { Number } The length of the data that needs to be written.
       * @param offset { Number } The offset of the data to be written (defaults to writeOffset).
       */
      _ensureWriteable(dataLength, offset) {
        const offsetVal = typeof offset === "number" ? offset : this._writeOffset;
        this._ensureCapacity(offsetVal + dataLength);
        if (offsetVal + dataLength > this.length) {
          this.length = offsetVal + dataLength;
        }
      }
      /**
       * Ensures that the internal Buffer is large enough to write at least the given amount of data.
       *
       * @param minLength { Number } The minimum length of the data needs to be written.
       */
      _ensureCapacity(minLength) {
        const oldLength = this._buff.length;
        if (minLength > oldLength) {
          let data3 = this._buff;
          let newLength = oldLength * 3 / 2 + 1;
          if (newLength < minLength) {
            newLength = minLength;
          }
          this._buff = Buffer.allocUnsafe(newLength);
          data3.copy(this._buff, 0, 0, oldLength);
        }
      }
      /**
       * Reads a numeric number value using the provided function.
       *
       * @typeparam T { number | bigint } The type of the value to be read
       *
       * @param func { Function(offset: number) => number } The function to read data on the internal Buffer with.
       * @param byteSize { Number } The number of bytes read.
       * @param offset { Number } The offset to read from (optional). When this is not provided, the managed readOffset is used instead.
       *
       * @returns { T } the number value
       */
      _readNumberValue(func, byteSize, offset) {
        this.ensureReadable(byteSize, offset);
        const value = func.call(this._buff, typeof offset === "number" ? offset : this._readOffset);
        if (typeof offset === "undefined") {
          this._readOffset += byteSize;
        }
        return value;
      }
      /**
       * Inserts a numeric number value based on the given offset and value.
       *
       * @typeparam T { number | bigint } The type of the value to be written
       *
       * @param func { Function(offset: T, offset?) => number} The function to write data on the internal Buffer with.
       * @param byteSize { Number } The number of bytes written.
       * @param value { T } The number value to write.
       * @param offset { Number } the offset to write the number at (REQUIRED).
       *
       * @returns SmartBuffer this buffer
       */
      _insertNumberValue(func, byteSize, value, offset) {
        utils_1.checkOffsetValue(offset);
        this.ensureInsertable(byteSize, offset);
        func.call(this._buff, value, offset);
        this._writeOffset += byteSize;
        return this;
      }
      /**
       * Writes a numeric number value based on the given offset and value.
       *
       * @typeparam T { number | bigint } The type of the value to be written
       *
       * @param func { Function(offset: T, offset?) => number} The function to write data on the internal Buffer with.
       * @param byteSize { Number } The number of bytes written.
       * @param value { T } The number value to write.
       * @param offset { Number } the offset to write the number at (REQUIRED).
       *
       * @returns SmartBuffer this buffer
       */
      _writeNumberValue(func, byteSize, value, offset) {
        if (typeof offset === "number") {
          if (offset < 0) {
            throw new Error(utils_1.ERRORS.INVALID_WRITE_BEYOND_BOUNDS);
          }
          utils_1.checkOffsetValue(offset);
        }
        const offsetVal = typeof offset === "number" ? offset : this._writeOffset;
        this._ensureWriteable(byteSize, offsetVal);
        func.call(this._buff, value, offsetVal);
        if (typeof offset === "number") {
          this._writeOffset = Math.max(this._writeOffset, offsetVal + byteSize);
        } else {
          this._writeOffset += byteSize;
        }
        return this;
      }
    };
    exports2.SmartBuffer = SmartBuffer;
  }
});

// ../../node_modules/socks/build/common/constants.js
var require_constants7 = __commonJS({
  "../../node_modules/socks/build/common/constants.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.SOCKS5_NO_ACCEPTABLE_AUTH = exports2.SOCKS5_CUSTOM_AUTH_END = exports2.SOCKS5_CUSTOM_AUTH_START = exports2.SOCKS_INCOMING_PACKET_SIZES = exports2.SocksClientState = exports2.Socks5Response = exports2.Socks5HostType = exports2.Socks5Auth = exports2.Socks4Response = exports2.SocksCommand = exports2.ERRORS = exports2.DEFAULT_TIMEOUT = void 0;
    var DEFAULT_TIMEOUT2 = 3e4;
    exports2.DEFAULT_TIMEOUT = DEFAULT_TIMEOUT2;
    var ERRORS = {
      InvalidSocksCommand: "An invalid SOCKS command was provided. Valid options are connect, bind, and associate.",
      InvalidSocksCommandForOperation: "An invalid SOCKS command was provided. Only a subset of commands are supported for this operation.",
      InvalidSocksCommandChain: "An invalid SOCKS command was provided. Chaining currently only supports the connect command.",
      InvalidSocksClientOptionsDestination: "An invalid destination host was provided.",
      InvalidSocksClientOptionsExistingSocket: "An invalid existing socket was provided. This should be an instance of stream.Duplex.",
      InvalidSocksClientOptionsProxy: "Invalid SOCKS proxy details were provided.",
      InvalidSocksClientOptionsTimeout: "An invalid timeout value was provided. Please enter a value above 0 (in ms).",
      InvalidSocksClientOptionsProxiesLength: "At least two socks proxies must be provided for chaining.",
      InvalidSocksClientOptionsCustomAuthRange: "Custom auth must be a value between 0x80 and 0xFE.",
      InvalidSocksClientOptionsCustomAuthOptions: "When a custom_auth_method is provided, custom_auth_request_handler, custom_auth_response_size, and custom_auth_response_handler must also be provided and valid.",
      NegotiationError: "Negotiation error",
      SocketClosed: "Socket closed",
      ProxyConnectionTimedOut: "Proxy connection timed out",
      InternalError: "SocksClient internal error (this should not happen)",
      InvalidSocks4HandshakeResponse: "Received invalid Socks4 handshake response",
      Socks4ProxyRejectedConnection: "Socks4 Proxy rejected connection",
      InvalidSocks4IncomingConnectionResponse: "Socks4 invalid incoming connection response",
      Socks4ProxyRejectedIncomingBoundConnection: "Socks4 Proxy rejected incoming bound connection",
      InvalidSocks5InitialHandshakeResponse: "Received invalid Socks5 initial handshake response",
      InvalidSocks5IntiailHandshakeSocksVersion: "Received invalid Socks5 initial handshake (invalid socks version)",
      InvalidSocks5InitialHandshakeNoAcceptedAuthType: "Received invalid Socks5 initial handshake (no accepted authentication type)",
      InvalidSocks5InitialHandshakeUnknownAuthType: "Received invalid Socks5 initial handshake (unknown authentication type)",
      Socks5AuthenticationFailed: "Socks5 Authentication failed",
      InvalidSocks5FinalHandshake: "Received invalid Socks5 final handshake response",
      InvalidSocks5FinalHandshakeRejected: "Socks5 proxy rejected connection",
      InvalidSocks5IncomingConnectionResponse: "Received invalid Socks5 incoming connection response",
      Socks5ProxyRejectedIncomingBoundConnection: "Socks5 Proxy rejected incoming bound connection"
    };
    exports2.ERRORS = ERRORS;
    var SOCKS_INCOMING_PACKET_SIZES = {
      Socks5InitialHandshakeResponse: 2,
      Socks5UserPassAuthenticationResponse: 2,
      // Command response + incoming connection (bind)
      Socks5ResponseHeader: 5,
      // We need at least 5 to read the hostname length, then we wait for the address+port information.
      Socks5ResponseIPv4: 10,
      // 4 header + 4 ip + 2 port
      Socks5ResponseIPv6: 22,
      // 4 header + 16 ip + 2 port
      Socks5ResponseHostname: /* @__PURE__ */ __name((hostNameLength) => hostNameLength + 7, "Socks5ResponseHostname"),
      // 4 header + 1 host length + host + 2 port
      // Command response + incoming connection (bind)
      Socks4Response: 8
      // 2 header + 2 port + 4 ip
    };
    exports2.SOCKS_INCOMING_PACKET_SIZES = SOCKS_INCOMING_PACKET_SIZES;
    var SocksCommand;
    (function(SocksCommand2) {
      SocksCommand2[SocksCommand2["connect"] = 1] = "connect";
      SocksCommand2[SocksCommand2["bind"] = 2] = "bind";
      SocksCommand2[SocksCommand2["associate"] = 3] = "associate";
    })(SocksCommand || (exports2.SocksCommand = SocksCommand = {}));
    var Socks4Response;
    (function(Socks4Response2) {
      Socks4Response2[Socks4Response2["Granted"] = 90] = "Granted";
      Socks4Response2[Socks4Response2["Failed"] = 91] = "Failed";
      Socks4Response2[Socks4Response2["Rejected"] = 92] = "Rejected";
      Socks4Response2[Socks4Response2["RejectedIdent"] = 93] = "RejectedIdent";
    })(Socks4Response || (exports2.Socks4Response = Socks4Response = {}));
    var Socks5Auth;
    (function(Socks5Auth2) {
      Socks5Auth2[Socks5Auth2["NoAuth"] = 0] = "NoAuth";
      Socks5Auth2[Socks5Auth2["GSSApi"] = 1] = "GSSApi";
      Socks5Auth2[Socks5Auth2["UserPass"] = 2] = "UserPass";
    })(Socks5Auth || (exports2.Socks5Auth = Socks5Auth = {}));
    var SOCKS5_CUSTOM_AUTH_START = 128;
    exports2.SOCKS5_CUSTOM_AUTH_START = SOCKS5_CUSTOM_AUTH_START;
    var SOCKS5_CUSTOM_AUTH_END = 254;
    exports2.SOCKS5_CUSTOM_AUTH_END = SOCKS5_CUSTOM_AUTH_END;
    var SOCKS5_NO_ACCEPTABLE_AUTH = 255;
    exports2.SOCKS5_NO_ACCEPTABLE_AUTH = SOCKS5_NO_ACCEPTABLE_AUTH;
    var Socks5Response;
    (function(Socks5Response2) {
      Socks5Response2[Socks5Response2["Granted"] = 0] = "Granted";
      Socks5Response2[Socks5Response2["Failure"] = 1] = "Failure";
      Socks5Response2[Socks5Response2["NotAllowed"] = 2] = "NotAllowed";
      Socks5Response2[Socks5Response2["NetworkUnreachable"] = 3] = "NetworkUnreachable";
      Socks5Response2[Socks5Response2["HostUnreachable"] = 4] = "HostUnreachable";
      Socks5Response2[Socks5Response2["ConnectionRefused"] = 5] = "ConnectionRefused";
      Socks5Response2[Socks5Response2["TTLExpired"] = 6] = "TTLExpired";
      Socks5Response2[Socks5Response2["CommandNotSupported"] = 7] = "CommandNotSupported";
      Socks5Response2[Socks5Response2["AddressNotSupported"] = 8] = "AddressNotSupported";
    })(Socks5Response || (exports2.Socks5Response = Socks5Response = {}));
    var Socks5HostType;
    (function(Socks5HostType2) {
      Socks5HostType2[Socks5HostType2["IPv4"] = 1] = "IPv4";
      Socks5HostType2[Socks5HostType2["Hostname"] = 3] = "Hostname";
      Socks5HostType2[Socks5HostType2["IPv6"] = 4] = "IPv6";
    })(Socks5HostType || (exports2.Socks5HostType = Socks5HostType = {}));
    var SocksClientState;
    (function(SocksClientState2) {
      SocksClientState2[SocksClientState2["Created"] = 0] = "Created";
      SocksClientState2[SocksClientState2["Connecting"] = 1] = "Connecting";
      SocksClientState2[SocksClientState2["Connected"] = 2] = "Connected";
      SocksClientState2[SocksClientState2["SentInitialHandshake"] = 3] = "SentInitialHandshake";
      SocksClientState2[SocksClientState2["ReceivedInitialHandshakeResponse"] = 4] = "ReceivedInitialHandshakeResponse";
      SocksClientState2[SocksClientState2["SentAuthentication"] = 5] = "SentAuthentication";
      SocksClientState2[SocksClientState2["ReceivedAuthenticationResponse"] = 6] = "ReceivedAuthenticationResponse";
      SocksClientState2[SocksClientState2["SentFinalHandshake"] = 7] = "SentFinalHandshake";
      SocksClientState2[SocksClientState2["ReceivedFinalResponse"] = 8] = "ReceivedFinalResponse";
      SocksClientState2[SocksClientState2["BoundWaitingForConnection"] = 9] = "BoundWaitingForConnection";
      SocksClientState2[SocksClientState2["Established"] = 10] = "Established";
      SocksClientState2[SocksClientState2["Disconnected"] = 11] = "Disconnected";
      SocksClientState2[SocksClientState2["Error"] = 99] = "Error";
    })(SocksClientState || (exports2.SocksClientState = SocksClientState = {}));
  }
});

// ../../node_modules/socks/build/common/util.js
var require_util2 = __commonJS({
  "../../node_modules/socks/build/common/util.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.shuffleArray = exports2.SocksClientError = void 0;
    var SocksClientError = class extends Error {
      static {
        __name(this, "SocksClientError");
      }
      constructor(message2, options) {
        super(message2);
        this.options = options;
      }
    };
    exports2.SocksClientError = SocksClientError;
    function shuffleArray(array) {
      for (let i32 = array.length - 1; i32 > 0; i32--) {
        const j32 = Math.floor(Math.random() * (i32 + 1));
        [array[i32], array[j32]] = [array[j32], array[i32]];
      }
    }
    __name(shuffleArray, "shuffleArray");
    exports2.shuffleArray = shuffleArray;
  }
});

// ../../node_modules/ip-address/dist/address-error.js
var require_address_error = __commonJS({
  "../../node_modules/ip-address/dist/address-error.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.AddressError = void 0;
    var AddressError = class extends Error {
      static {
        __name(this, "AddressError");
      }
      constructor(message2, parseMessage) {
        super(message2);
        this.name = "AddressError";
        this.parseMessage = parseMessage;
      }
    };
    exports2.AddressError = AddressError;
  }
});

// ../../node_modules/ip-address/dist/common.js
var require_common5 = __commonJS({
  "../../node_modules/ip-address/dist/common.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isInSubnet = isInSubnet;
    exports2.isCorrect = isCorrect;
    exports2.prefixLengthFromMask = prefixLengthFromMask;
    exports2.numberToPaddedHex = numberToPaddedHex;
    exports2.stringToPaddedHex = stringToPaddedHex;
    exports2.testBit = testBit;
    var address_error_1 = require_address_error();
    function isInSubnet(address) {
      if (this.subnetMask < address.subnetMask) {
        return false;
      }
      if (this.mask(address.subnetMask) === address.mask()) {
        return true;
      }
      return false;
    }
    __name(isInSubnet, "isInSubnet");
    function isCorrect(defaultBits) {
      return function() {
        if (this.addressMinusSuffix !== this.correctForm()) {
          return false;
        }
        if (this.subnetMask === defaultBits && !this.parsedSubnet) {
          return true;
        }
        return this.parsedSubnet === String(this.subnetMask);
      };
    }
    __name(isCorrect, "isCorrect");
    function prefixLengthFromMask(value, totalBits) {
      const binary = value.toString(2).padStart(totalBits, "0");
      if (binary.length > totalBits) {
        throw new address_error_1.AddressError("Invalid subnet mask.");
      }
      const firstZero = binary.indexOf("0");
      if (firstZero === -1) {
        return totalBits;
      }
      if (binary.slice(firstZero).includes("1")) {
        throw new address_error_1.AddressError("Invalid subnet mask.");
      }
      return firstZero;
    }
    __name(prefixLengthFromMask, "prefixLengthFromMask");
    function numberToPaddedHex(number) {
      return number.toString(16).padStart(2, "0");
    }
    __name(numberToPaddedHex, "numberToPaddedHex");
    function stringToPaddedHex(numberString) {
      return numberToPaddedHex(parseInt(numberString, 10));
    }
    __name(stringToPaddedHex, "stringToPaddedHex");
    function testBit(binaryValue, position) {
      const { length } = binaryValue;
      if (position > length) {
        return false;
      }
      const positionInString = length - position;
      return binaryValue.substring(positionInString, positionInString + 1) === "1";
    }
    __name(testBit, "testBit");
  }
});

// ../../node_modules/ip-address/dist/v4/constants.js
var require_constants8 = __commonJS({
  "../../node_modules/ip-address/dist/v4/constants.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.RE_SUBNET_STRING = exports2.RE_ADDRESS = exports2.GROUPS = exports2.BITS = void 0;
    exports2.BITS = 32;
    exports2.GROUPS = 4;
    exports2.RE_ADDRESS = /^(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$/g;
    exports2.RE_SUBNET_STRING = /\/\d{1,2}$/;
  }
});

// ../../node_modules/ip-address/dist/ipv4.js
var require_ipv4 = __commonJS({
  "../../node_modules/ip-address/dist/ipv4.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __setModuleDefault2 = exports2 && exports2.__setModuleDefault || (Object.create ? (function(o10, v) {
      Object.defineProperty(o10, "default", { enumerable: true, value: v });
    }) : function(o10, v) {
      o10["default"] = v;
    });
    var __importStar2 = exports2 && exports2.__importStar || function(mod) {
      if (mod && mod.__esModule) return mod;
      var result2 = {};
      if (mod != null) {
        for (var k32 in mod) if (k32 !== "default" && Object.prototype.hasOwnProperty.call(mod, k32)) __createBinding3(result2, mod, k32);
      }
      __setModuleDefault2(result2, mod);
      return result2;
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.Address4 = void 0;
    var common = __importStar2(require_common5());
    var constants3 = __importStar2(require_constants8());
    var address_error_1 = require_address_error();
    var isCorrect4 = common.isCorrect(constants3.BITS);
    var Address4 = class _Address4 {
      static {
        __name(this, "Address4");
      }
      constructor(address) {
        this.groups = constants3.GROUPS;
        this.parsedAddress = [];
        this.parsedSubnet = "";
        this.subnet = "/32";
        this.subnetMask = 32;
        this.v4 = true;
        this.isCorrect = isCorrect4;
        this.isInSubnet = common.isInSubnet;
        this.address = address;
        const subnet = constants3.RE_SUBNET_STRING.exec(address);
        if (subnet) {
          this.parsedSubnet = subnet[0].replace("/", "");
          this.subnetMask = parseInt(this.parsedSubnet, 10);
          this.subnet = `/${this.subnetMask}`;
          if (this.subnetMask < 0 || this.subnetMask > constants3.BITS) {
            throw new address_error_1.AddressError("Invalid subnet mask.");
          }
          address = address.replace(constants3.RE_SUBNET_STRING, "");
        }
        this.addressMinusSuffix = address;
        this.parsedAddress = this.parse(address);
      }
      /**
       * Returns true if the given string is a valid IPv4 address (with optional
       * CIDR subnet), false otherwise. Host bits in the subnet portion are
       * allowed (e.g. `192.168.1.5/24` is valid); for strict network-address
       * validation compare `correctForm()` to `startAddress().correctForm()`,
       * or use `networkForm()`.
       */
      static isValid(address) {
        try {
          new _Address4(address);
          return true;
        } catch (e32) {
          return false;
        }
      }
      /**
       * Parses an IPv4 address string into its four octet groups and stores the
       * result on `this.parsedAddress`. Called automatically by the constructor;
       * you typically don't need to call it directly. Throws `AddressError` if
       * the input is not a valid IPv4 address.
       */
      parse(address) {
        const groups = address.split(".");
        if (!address.match(constants3.RE_ADDRESS)) {
          throw new address_error_1.AddressError("Invalid IPv4 address.");
        }
        return groups;
      }
      /**
       * Returns the address in correct form: octets joined with `.` and any
       * leading zeros stripped (e.g. `192.168.1.1`). For IPv4 this matches the
       * canonical dotted-decimal representation.
       */
      correctForm() {
        return this.parsedAddress.map((part) => parseInt(part, 10)).join(".");
      }
      /**
       * Construct an `Address4` from an address and a dotted-decimal subnet
       * mask given as separate strings (e.g. as returned by Node's
       * `os.networkInterfaces()`). Throws `AddressError` if the mask is
       * non-contiguous (e.g. `255.0.255.0`).
       * @example
       * var address = Address4.fromAddressAndMask('192.168.1.1', '255.255.255.0');
       * address.subnetMask; // 24
       */
      static fromAddressAndMask(address, mask) {
        const bits = common.prefixLengthFromMask(new _Address4(mask).bigInt(), constants3.BITS);
        return new _Address4(`${address}/${bits}`);
      }
      /**
       * Construct an `Address4` from an address and a Cisco-style wildcard mask
       * given as separate strings (e.g. `0.0.0.255` for a `/24`). The wildcard
       * mask is the bitwise inverse of the subnet mask. Throws `AddressError`
       * if the mask is non-contiguous (e.g. `0.255.0.255`).
       * @example
       * var address = Address4.fromAddressAndWildcardMask('10.0.0.1', '0.0.0.255');
       * address.subnetMask; // 24
       */
      static fromAddressAndWildcardMask(address, wildcardMask) {
        const wildcard = new _Address4(wildcardMask).bigInt();
        const allOnes = (BigInt(1) << BigInt(constants3.BITS)) - BigInt(1);
        const mask = wildcard ^ allOnes;
        const bits = common.prefixLengthFromMask(mask, constants3.BITS);
        return new _Address4(`${address}/${bits}`);
      }
      /**
       * Construct an `Address4` from a wildcard pattern with trailing `*`
       * octets. The number of trailing wildcards determines the prefix
       * length: each `*` represents 8 bits.
       *
       * Only trailing whole-octet wildcards are supported. Partial-octet
       * wildcards (e.g. `192.168.0.1*`) and interior wildcards (e.g.
       * `192.*.0.1`) throw `AddressError`.
       * @example
       * Address4.fromWildcard('192.168.0.*').subnet;   // '/24'
       * Address4.fromWildcard('192.168.*.*').subnet;   // '/16'
       * Address4.fromWildcard('*.*.*.*').subnet;       // '/0'
       */
      static fromWildcard(input) {
        const groups = input.split(".");
        if (groups.length !== constants3.GROUPS) {
          throw new address_error_1.AddressError("Wildcard pattern must have 4 octets");
        }
        let firstWildcard = -1;
        for (let i32 = 0; i32 < groups.length; i32++) {
          if (groups[i32] === "*") {
            if (firstWildcard === -1) {
              firstWildcard = i32;
            }
          } else if (firstWildcard !== -1) {
            throw new address_error_1.AddressError("Wildcard `*` must only appear in trailing octets (e.g. `192.168.0.*`)");
          }
        }
        const trailing = firstWildcard === -1 ? 0 : groups.length - firstWildcard;
        const replaced = groups.map((g32) => g32 === "*" ? "0" : g32);
        const subnetBits = constants3.BITS - trailing * 8;
        return new _Address4(`${replaced.join(".")}/${subnetBits}`);
      }
      /**
       * Converts a hex string to an IPv4 address object. Accepts 8 hex digits
       * with optional `:` separators (e.g. `'7f000001'` or `'7f:00:00:01'`).
       * Throws `AddressError` for any other length or for non-hex characters.
       * @param {string} hex - a hex string to convert
       * @returns {Address4}
       */
      static fromHex(hex) {
        const stripped = hex.replace(/:/g, "");
        if (!/^[0-9a-fA-F]{8}$/.test(stripped)) {
          throw new address_error_1.AddressError("IPv4 hex must be exactly 8 hex digits");
        }
        const groups = [];
        for (let i32 = 0; i32 < 8; i32 += 2) {
          groups.push(parseInt(stripped.slice(i32, i32 + 2), 16));
        }
        return new _Address4(groups.join("."));
      }
      /**
       * Converts an integer into a IPv4 address object. The integer must be a
       * non-negative safe integer in the range `[0, 2**32 - 1]`; otherwise
       * `AddressError` is thrown.
       * @param {integer} integer - a number to convert
       * @returns {Address4}
       */
      static fromInteger(integer) {
        if (!Number.isInteger(integer) || integer < 0 || integer > 4294967295) {
          throw new address_error_1.AddressError("IPv4 integer must be in the range 0 to 2**32 - 1");
        }
        return _Address4.fromHex(integer.toString(16).padStart(8, "0"));
      }
      /**
       * Return an address from in-addr.arpa form
       * @param {string} arpaFormAddress - an 'in-addr.arpa' form ipv4 address
       * @returns {Adress4}
       * @example
       * var address = Address4.fromArpa(42.2.0.192.in-addr.arpa.)
       * address.correctForm(); // '192.0.2.42'
       */
      static fromArpa(arpaFormAddress) {
        const leader = arpaFormAddress.replace(/(\.in-addr\.arpa)?\.$/, "");
        const address = leader.split(".").reverse().join(".");
        return new _Address4(address);
      }
      /**
       * Converts an IPv4 address object to a hex string
       * @returns {String}
       */
      toHex() {
        return this.parsedAddress.map((part) => common.stringToPaddedHex(part)).join(":");
      }
      /**
       * Converts an IPv4 address object to an array of bytes.
       *
       * To get a Node.js `Buffer`, wrap the result: `Buffer.from(address.toArray())`.
       * @returns {Array}
       */
      toArray() {
        return this.parsedAddress.map((part) => parseInt(part, 10));
      }
      /**
       * Converts an IPv4 address object to an IPv6 address group
       * @returns {String}
       */
      toGroup6() {
        const output = [];
        let i32;
        for (i32 = 0; i32 < constants3.GROUPS; i32 += 2) {
          output.push(`${common.stringToPaddedHex(this.parsedAddress[i32])}${common.stringToPaddedHex(this.parsedAddress[i32 + 1])}`);
        }
        return output.join(":");
      }
      /**
       * Returns the address as a `bigint`
       * @returns {bigint}
       */
      bigInt() {
        return BigInt(`0x${this.parsedAddress.map((n10) => common.stringToPaddedHex(n10)).join("")}`);
      }
      /**
       * Helper function getting start address.
       * @returns {bigint}
       */
      _startAddress() {
        return BigInt(`0b${this.mask() + "0".repeat(constants3.BITS - this.subnetMask)}`);
      }
      /**
       * The first address in the range given by this address' subnet.
       * Often referred to as the Network Address.
       * @returns {Address4}
       */
      startAddress() {
        return _Address4.fromBigInt(this._startAddress());
      }
      /**
       * The first host address in the range given by this address's subnet ie
       * the first address after the Network Address
       * @returns {Address4}
       */
      startAddressExclusive() {
        const adjust = BigInt("1");
        return _Address4.fromBigInt(this._startAddress() + adjust);
      }
      /**
       * Helper function getting end address.
       * @returns {bigint}
       */
      _endAddress() {
        return BigInt(`0b${this.mask() + "1".repeat(constants3.BITS - this.subnetMask)}`);
      }
      /**
       * The last address in the range given by this address' subnet
       * Often referred to as the Broadcast
       * @returns {Address4}
       */
      endAddress() {
        return _Address4.fromBigInt(this._endAddress());
      }
      /**
       * The last host address in the range given by this address's subnet ie
       * the last address prior to the Broadcast Address
       * @returns {Address4}
       */
      endAddressExclusive() {
        const adjust = BigInt("1");
        return _Address4.fromBigInt(this._endAddress() - adjust);
      }
      /**
       * The dotted-decimal form of the subnet mask, e.g. `255.255.240.0` for
       * a `/20`. Returns an `Address4`; call `.correctForm()` for the string.
       * @returns {Address4}
       */
      subnetMaskAddress() {
        return _Address4.fromBigInt(BigInt(`0b${"1".repeat(this.subnetMask)}${"0".repeat(constants3.BITS - this.subnetMask)}`));
      }
      /**
       * The Cisco-style wildcard mask, e.g. `0.0.0.255` for a `/24`. This is
       * the bitwise inverse of `subnetMaskAddress()`. Returns an `Address4`;
       * call `.correctForm()` for the string.
       * @returns {Address4}
       */
      wildcardMask() {
        return _Address4.fromBigInt(BigInt(`0b${"0".repeat(this.subnetMask)}${"1".repeat(constants3.BITS - this.subnetMask)}`));
      }
      /**
       * The network address in CIDR string form, e.g. `192.168.1.0/24` for
       * `192.168.1.5/24`. For an address with no explicit subnet the prefix is
       * `/32`, e.g. `networkForm()` on `192.168.1.5` returns `192.168.1.5/32`.
       * @returns {string}
       */
      networkForm() {
        return `${this.startAddress().correctForm()}/${this.subnetMask}`;
      }
      /**
       * Converts a BigInt to a v4 address object. The value must be in the
       * range `[0, 2**32 - 1]`; otherwise `AddressError` is thrown.
       * @param {bigint} bigInt - a BigInt to convert
       * @returns {Address4}
       */
      static fromBigInt(bigInt) {
        if (bigInt < 0n || bigInt > 0xffffffffn) {
          throw new address_error_1.AddressError("IPv4 BigInt must be in the range 0 to 2**32 - 1");
        }
        return _Address4.fromHex(bigInt.toString(16).padStart(8, "0"));
      }
      /**
       * Convert a byte array to an Address4 object.
       *
       * To convert from a Node.js `Buffer`, spread it: `Address4.fromByteArray([...buf])`.
       * @param {Array<number>} bytes - an array of 4 bytes (0-255)
       * @returns {Address4}
       */
      static fromByteArray(bytes) {
        if (bytes.length !== 4) {
          throw new address_error_1.AddressError("IPv4 addresses require exactly 4 bytes");
        }
        for (let i32 = 0; i32 < bytes.length; i32++) {
          if (!Number.isInteger(bytes[i32]) || bytes[i32] < 0 || bytes[i32] > 255) {
            throw new address_error_1.AddressError("All bytes must be integers between 0 and 255");
          }
        }
        return this.fromUnsignedByteArray(bytes);
      }
      /**
       * Convert an unsigned byte array to an Address4 object
       * @param {Array<number>} bytes - an array of 4 unsigned bytes (0-255)
       * @returns {Address4}
       */
      static fromUnsignedByteArray(bytes) {
        if (bytes.length !== 4) {
          throw new address_error_1.AddressError("IPv4 addresses require exactly 4 bytes");
        }
        const address = bytes.join(".");
        return new _Address4(address);
      }
      /**
       * Returns the first n bits of the address, defaulting to the
       * subnet mask
       * @returns {String}
       */
      mask(mask) {
        if (mask === void 0) {
          mask = this.subnetMask;
        }
        return this.getBitsBase2(0, mask);
      }
      /**
       * Returns the bits in the given range as a base-2 string
       * @returns {string}
       */
      getBitsBase2(start, end) {
        return this.binaryZeroPad().slice(start, end);
      }
      /**
       * Return the reversed ip6.arpa form of the address
       * @param {Object} options
       * @param {boolean} options.omitSuffix - omit the "in-addr.arpa" suffix
       * @returns {String}
       */
      reverseForm(options) {
        if (!options) {
          options = {};
        }
        const reversed = this.correctForm().split(".").reverse().join(".");
        if (options.omitSuffix) {
          return reversed;
        }
        return `${reversed}.in-addr.arpa.`;
      }
      /**
       * Returns true if the given address is a multicast address
       * @returns {boolean}
       */
      isMulticast() {
        return this.isInSubnet(MULTICAST_V4);
      }
      /**
       * Returns true if the address is in one of the [RFC 1918](https://datatracker.ietf.org/doc/html/rfc1918) private address ranges (`10.0.0.0/8`, `172.16.0.0/12`, `192.168.0.0/16`).
       * @returns {boolean}
       */
      isPrivate() {
        return PRIVATE_V4.some((subnet) => this.isInSubnet(subnet));
      }
      /**
       * Returns true if the address is in the loopback range `127.0.0.0/8` ([RFC 1122](https://datatracker.ietf.org/doc/html/rfc1122)).
       * @returns {boolean}
       */
      isLoopback() {
        return this.isInSubnet(LOOPBACK_V4);
      }
      /**
       * Returns true if the address is in the link-local range `169.254.0.0/16` ([RFC 3927](https://datatracker.ietf.org/doc/html/rfc3927)).
       * @returns {boolean}
       */
      isLinkLocal() {
        return this.isInSubnet(LINK_LOCAL_V4);
      }
      /**
       * Returns true if the address is the unspecified address `0.0.0.0`.
       * @returns {boolean}
       */
      isUnspecified() {
        return this.isInSubnet(UNSPECIFIED_V4);
      }
      /**
       * Returns true if the address is the limited broadcast address `255.255.255.255` ([RFC 919](https://datatracker.ietf.org/doc/html/rfc919)).
       * @returns {boolean}
       */
      isBroadcast() {
        return this.isInSubnet(BROADCAST_V4);
      }
      /**
       * Returns true if the address is in the carrier-grade NAT range `100.64.0.0/10` ([RFC 6598](https://datatracker.ietf.org/doc/html/rfc6598)).
       * @returns {boolean}
       */
      isCGNAT() {
        return this.isInSubnet(CGNAT_V4);
      }
      /**
       * Returns a zero-padded base-2 string representation of the address
       * @returns {string}
       */
      binaryZeroPad() {
        if (this._binaryZeroPad === void 0) {
          this._binaryZeroPad = this.bigInt().toString(2).padStart(constants3.BITS, "0");
        }
        return this._binaryZeroPad;
      }
      /**
       * Groups an IPv4 address for inclusion at the end of an IPv6 address
       * @returns {String}
       */
      groupForV6() {
        const segments = this.parsedAddress;
        return this.address.replace(constants3.RE_ADDRESS, `<span class="hover-group group-v4 group-6">${segments.slice(0, 2).join(".")}</span>.<span class="hover-group group-v4 group-7">${segments.slice(2, 4).join(".")}</span>`);
      }
    };
    exports2.Address4 = Address4;
    var MULTICAST_V4 = new Address4("224.0.0.0/4");
    var PRIVATE_V4 = [
      new Address4("10.0.0.0/8"),
      new Address4("172.16.0.0/12"),
      new Address4("192.168.0.0/16")
    ];
    var LOOPBACK_V4 = new Address4("127.0.0.0/8");
    var LINK_LOCAL_V4 = new Address4("169.254.0.0/16");
    var UNSPECIFIED_V4 = new Address4("0.0.0.0/32");
    var BROADCAST_V4 = new Address4("255.255.255.255/32");
    var CGNAT_V4 = new Address4("100.64.0.0/10");
  }
});

// ../../node_modules/ip-address/dist/v6/constants.js
var require_constants9 = __commonJS({
  "../../node_modules/ip-address/dist/v6/constants.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.RE_URL_WITH_PORT = exports2.RE_URL = exports2.RE_ZONE_STRING = exports2.RE_SUBNET_STRING = exports2.RE_BAD_ADDRESS = exports2.RE_BAD_CHARACTERS = exports2.TYPES = exports2.SCOPES = exports2.GROUPS = exports2.BITS = void 0;
    exports2.BITS = 128;
    exports2.GROUPS = 8;
    exports2.SCOPES = {
      0: "Reserved",
      1: "Interface local",
      2: "Link local",
      4: "Admin local",
      5: "Site local",
      8: "Organization local",
      14: "Global",
      15: "Reserved"
    };
    exports2.TYPES = {
      "ff01::1/128": "Multicast (All nodes on this interface)",
      "ff01::2/128": "Multicast (All routers on this interface)",
      "ff02::1/128": "Multicast (All nodes on this link)",
      "ff02::2/128": "Multicast (All routers on this link)",
      "ff05::2/128": "Multicast (All routers in this site)",
      "ff02::5/128": "Multicast (OSPFv3 AllSPF routers)",
      "ff02::6/128": "Multicast (OSPFv3 AllDR routers)",
      "ff02::9/128": "Multicast (RIP routers)",
      "ff02::a/128": "Multicast (EIGRP routers)",
      "ff02::d/128": "Multicast (PIM routers)",
      "ff02::16/128": "Multicast (MLDv2 reports)",
      "ff01::fb/128": "Multicast (mDNSv6)",
      "ff02::fb/128": "Multicast (mDNSv6)",
      "ff05::fb/128": "Multicast (mDNSv6)",
      "ff02::1:2/128": "Multicast (All DHCP servers and relay agents on this link)",
      "ff05::1:2/128": "Multicast (All DHCP servers and relay agents in this site)",
      "ff02::1:3/128": "Multicast (All DHCP servers on this link)",
      "ff05::1:3/128": "Multicast (All DHCP servers in this site)",
      "::/128": "Unspecified",
      "::1/128": "Loopback",
      "ff00::/8": "Multicast",
      "fe80::/10": "Link-local unicast",
      "fc00::/7": "Unique local",
      "2002::/16": "6to4",
      "2001:db8::/32": "Documentation",
      "64:ff9b::/96": "NAT64 (well-known)",
      "64:ff9b:1::/48": "NAT64 (local-use)"
    };
    exports2.RE_BAD_CHARACTERS = /([^0-9a-f:/%])/gi;
    exports2.RE_BAD_ADDRESS = /([0-9a-f]{5,}|:{3,}|[^:]:$|^:[^:]|\/$)/gi;
    exports2.RE_SUBNET_STRING = /\/\d{1,3}(?=%|$)/;
    exports2.RE_ZONE_STRING = /%.*$/;
    exports2.RE_URL = /^\[{0,1}([0-9a-f:]+)\]{0,1}/;
    exports2.RE_URL_WITH_PORT = /\[([0-9a-f:]+)\]:([0-9]{1,5})/;
  }
});

// ../../node_modules/ip-address/dist/v6/helpers.js
var require_helpers3 = __commonJS({
  "../../node_modules/ip-address/dist/v6/helpers.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.escapeHtml = escapeHtml;
    exports2.spanAllZeroes = spanAllZeroes;
    exports2.spanAll = spanAll;
    exports2.spanLeadingZeroes = spanLeadingZeroes;
    exports2.simpleGroup = simpleGroup;
    function escapeHtml(s) {
      return s.replace(/&/g, "&amp;").replace(/</g, "&lt;").replace(/>/g, "&gt;").replace(/"/g, "&quot;").replace(/'/g, "&#39;");
    }
    __name(escapeHtml, "escapeHtml");
    function spanAllZeroes(s) {
      return escapeHtml(s).replace(/(0+)/g, '<span class="zero">$1</span>');
    }
    __name(spanAllZeroes, "spanAllZeroes");
    function spanAll(s, offset = 0) {
      const letters = s.split("");
      return letters.map((n10, i32) => `<span class="digit value-${escapeHtml(n10)} position-${i32 + offset}">${spanAllZeroes(n10)}</span>`).join("");
    }
    __name(spanAll, "spanAll");
    function spanLeadingZeroesSimple(group7) {
      return escapeHtml(group7).replace(/^(0+)/, '<span class="zero">$1</span>');
    }
    __name(spanLeadingZeroesSimple, "spanLeadingZeroesSimple");
    function spanLeadingZeroes(address) {
      const groups = address.split(":");
      return groups.map((g32) => spanLeadingZeroesSimple(g32)).join(":");
    }
    __name(spanLeadingZeroes, "spanLeadingZeroes");
    function simpleGroup(addressString, offset = 0) {
      const groups = addressString.split(":");
      return groups.map((g32, i32) => {
        if (/group-v4/.test(g32)) {
          return g32;
        }
        return `<span class="hover-group group-${i32 + offset}">${spanLeadingZeroesSimple(g32)}</span>`;
      });
    }
    __name(simpleGroup, "simpleGroup");
  }
});

// ../../node_modules/ip-address/dist/v6/regular-expressions.js
var require_regular_expressions = __commonJS({
  "../../node_modules/ip-address/dist/v6/regular-expressions.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __setModuleDefault2 = exports2 && exports2.__setModuleDefault || (Object.create ? (function(o10, v) {
      Object.defineProperty(o10, "default", { enumerable: true, value: v });
    }) : function(o10, v) {
      o10["default"] = v;
    });
    var __importStar2 = exports2 && exports2.__importStar || function(mod) {
      if (mod && mod.__esModule) return mod;
      var result2 = {};
      if (mod != null) {
        for (var k32 in mod) if (k32 !== "default" && Object.prototype.hasOwnProperty.call(mod, k32)) __createBinding3(result2, mod, k32);
      }
      __setModuleDefault2(result2, mod);
      return result2;
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ADDRESS_BOUNDARY = void 0;
    exports2.groupPossibilities = groupPossibilities;
    exports2.padGroup = padGroup;
    exports2.simpleRegularExpression = simpleRegularExpression;
    exports2.possibleElisions = possibleElisions;
    var v6 = __importStar2(require_constants9());
    function groupPossibilities(possibilities) {
      return `(${possibilities.join("|")})`;
    }
    __name(groupPossibilities, "groupPossibilities");
    function padGroup(group7) {
      if (group7.length < 4) {
        return `0{0,${4 - group7.length}}${group7}`;
      }
      return group7;
    }
    __name(padGroup, "padGroup");
    exports2.ADDRESS_BOUNDARY = "[^A-Fa-f0-9:]";
    function simpleRegularExpression(groups) {
      const zeroIndexes = [];
      groups.forEach((group7, i32) => {
        const groupInteger = parseInt(group7, 16);
        if (groupInteger === 0) {
          zeroIndexes.push(i32);
        }
      });
      const possibilities = zeroIndexes.map((zeroIndex) => groups.map((group7, i32) => {
        if (i32 === zeroIndex) {
          const elision = i32 === 0 || i32 === v6.GROUPS - 1 ? ":" : "";
          return groupPossibilities([padGroup(group7), elision]);
        }
        return padGroup(group7);
      }).join(":"));
      possibilities.push(groups.map(padGroup).join(":"));
      return groupPossibilities(possibilities);
    }
    __name(simpleRegularExpression, "simpleRegularExpression");
    function possibleElisions(elidedGroups, moreLeft, moreRight) {
      const left = moreLeft ? "" : ":";
      const right = moreRight ? "" : ":";
      const possibilities = [];
      if (!moreLeft && !moreRight) {
        possibilities.push("::");
      }
      if (moreLeft && moreRight) {
        possibilities.push("");
      }
      if (moreRight && !moreLeft || !moreRight && moreLeft) {
        possibilities.push(":");
      }
      possibilities.push(`${left}(:0{1,4}){1,${elidedGroups - 1}}`);
      possibilities.push(`(0{1,4}:){1,${elidedGroups - 1}}${right}`);
      possibilities.push(`(0{1,4}:){${elidedGroups - 1}}0{1,4}`);
      for (let groups = 1; groups < elidedGroups - 1; groups++) {
        for (let position = 1; position < elidedGroups - groups; position++) {
          possibilities.push(`(0{1,4}:){${position}}:(0{1,4}:){${elidedGroups - position - groups - 1}}0{1,4}`);
        }
      }
      return groupPossibilities(possibilities);
    }
    __name(possibleElisions, "possibleElisions");
  }
});

// ../../node_modules/ip-address/dist/ipv6.js
var require_ipv6 = __commonJS({
  "../../node_modules/ip-address/dist/ipv6.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __setModuleDefault2 = exports2 && exports2.__setModuleDefault || (Object.create ? (function(o10, v) {
      Object.defineProperty(o10, "default", { enumerable: true, value: v });
    }) : function(o10, v) {
      o10["default"] = v;
    });
    var __importStar2 = exports2 && exports2.__importStar || function(mod) {
      if (mod && mod.__esModule) return mod;
      var result2 = {};
      if (mod != null) {
        for (var k32 in mod) if (k32 !== "default" && Object.prototype.hasOwnProperty.call(mod, k32)) __createBinding3(result2, mod, k32);
      }
      __setModuleDefault2(result2, mod);
      return result2;
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.Address6 = void 0;
    var common = __importStar2(require_common5());
    var constants4 = __importStar2(require_constants8());
    var constants6 = __importStar2(require_constants9());
    var helpers = __importStar2(require_helpers3());
    var ipv4_1 = require_ipv4();
    var regular_expressions_1 = require_regular_expressions();
    var address_error_1 = require_address_error();
    var common_1 = require_common5();
    var isCorrect6 = common.isCorrect(constants6.BITS);
    function assert(condition) {
      if (!condition) {
        throw new Error("Assertion failed.");
      }
    }
    __name(assert, "assert");
    function addCommas(number) {
      const r32 = /(\d+)(\d{3})/;
      while (r32.test(number)) {
        number = number.replace(r32, "$1,$2");
      }
      return number;
    }
    __name(addCommas, "addCommas");
    function spanLeadingZeroes4(n10) {
      n10 = n10.replace(/^(0{1,})([1-9]+)$/, '<span class="parse-error">$1</span>$2');
      n10 = n10.replace(/^(0{1,})(0)$/, '<span class="parse-error">$1</span>$2');
      return n10;
    }
    __name(spanLeadingZeroes4, "spanLeadingZeroes4");
    function compact(address, slice) {
      const s1 = [];
      const s2 = [];
      let i32;
      for (i32 = 0; i32 < address.length; i32++) {
        if (i32 < slice[0]) {
          s1.push(address[i32]);
        } else if (i32 > slice[1]) {
          s2.push(address[i32]);
        }
      }
      return s1.concat(["compact"]).concat(s2);
    }
    __name(compact, "compact");
    function paddedHex(octet) {
      return parseInt(octet, 16).toString(16).padStart(4, "0");
    }
    __name(paddedHex, "paddedHex");
    function unsignByte(b32) {
      return b32 & 255;
    }
    __name(unsignByte, "unsignByte");
    var Address6 = class _Address6 {
      static {
        __name(this, "Address6");
      }
      constructor(address, optionalGroups) {
        this.addressMinusSuffix = "";
        this.parsedSubnet = "";
        this.subnet = "/128";
        this.subnetMask = 128;
        this.v4 = false;
        this.zone = "";
        this.isInSubnet = common.isInSubnet;
        this.isCorrect = isCorrect6;
        if (optionalGroups === void 0) {
          this.groups = constants6.GROUPS;
        } else {
          this.groups = optionalGroups;
        }
        this.address = address;
        const subnet = constants6.RE_SUBNET_STRING.exec(address);
        if (subnet) {
          this.parsedSubnet = subnet[0].replace("/", "");
          this.subnetMask = parseInt(this.parsedSubnet, 10);
          this.subnet = `/${this.subnetMask}`;
          if (Number.isNaN(this.subnetMask) || this.subnetMask < 0 || this.subnetMask > constants6.BITS) {
            throw new address_error_1.AddressError("Invalid subnet mask.");
          }
          address = address.replace(constants6.RE_SUBNET_STRING, "");
        } else if (/\//.test(address)) {
          throw new address_error_1.AddressError("Invalid subnet mask.");
        }
        const zone = constants6.RE_ZONE_STRING.exec(address);
        if (zone) {
          this.zone = zone[0];
          address = address.replace(constants6.RE_ZONE_STRING, "");
        }
        this.addressMinusSuffix = address;
        this.parsedAddress = this.parse(this.addressMinusSuffix);
      }
      /**
       * Returns true if the given string is a valid IPv6 address (with optional
       * CIDR subnet and zone identifier), false otherwise. Host bits in the
       * subnet portion are allowed (e.g. `2001:db8::1/32` is valid); for strict
       * network-address validation compare `correctForm()` to
       * `startAddress().correctForm()`, or use `networkForm()`.
       */
      static isValid(address) {
        try {
          new _Address6(address);
          return true;
        } catch (e32) {
          return false;
        }
      }
      /**
       * Convert a BigInt to a v6 address object. The value must be in the
       * range `[0, 2**128 - 1]`; otherwise `AddressError` is thrown.
       * @param {bigint} bigInt - a BigInt to convert
       * @returns {Address6}
       * @example
       * var bigInt = BigInt('1000000000000');
       * var address = Address6.fromBigInt(bigInt);
       * address.correctForm(); // '::e8:d4a5:1000'
       */
      static fromBigInt(bigInt) {
        if (bigInt < 0n || bigInt > (1n << BigInt(constants6.BITS)) - 1n) {
          throw new address_error_1.AddressError("IPv6 BigInt must be in the range 0 to 2**128 - 1");
        }
        const hex = bigInt.toString(16).padStart(32, "0");
        const groups = [];
        for (let i32 = 0; i32 < constants6.GROUPS; i32++) {
          groups.push(hex.slice(i32 * 4, (i32 + 1) * 4));
        }
        return new _Address6(groups.join(":"));
      }
      /**
       * Parse a URL (with optional bracketed host and port) into an address and
       * port. Returns either `{ address, port }` on success or
       * `{ error, address: null, port: null }` if the URL could not be parsed.
       * Ports are returned as numbers (or `null` if absent or out of range).
       * @example
       * var addressAndPort = Address6.fromURL('http://[ffff::]:8080/foo/');
       * addressAndPort.address.correctForm(); // 'ffff::'
       * addressAndPort.port; // 8080
       */
      static fromURL(url) {
        let host;
        let port = null;
        let result2;
        if (url.indexOf("[") !== -1 && url.indexOf("]:") !== -1) {
          result2 = constants6.RE_URL_WITH_PORT.exec(url);
          if (result2 === null) {
            return {
              error: "failed to parse address with port",
              address: null,
              port: null
            };
          }
          host = result2[1];
          port = result2[2];
        } else if (url.indexOf("/") !== -1) {
          url = url.replace(/^[a-z0-9]+:\/\//, "");
          result2 = constants6.RE_URL.exec(url);
          if (result2 === null) {
            return {
              error: "failed to parse address from URL",
              address: null,
              port: null
            };
          }
          host = result2[1];
        } else {
          host = url;
        }
        if (port) {
          port = parseInt(port, 10);
          if (port < 0 || port > 65536) {
            port = null;
          }
        } else {
          port = null;
        }
        return {
          address: new _Address6(host),
          port
        };
      }
      /**
       * Construct an `Address6` from an address and a hex subnet mask given as
       * separate strings (e.g. as returned by Node's `os.networkInterfaces()`).
       * Throws `AddressError` if the mask is non-contiguous (e.g.
       * `ffff::ffff`).
       * @example
       * var address = Address6.fromAddressAndMask('fe80::1', 'ffff:ffff:ffff:ffff::');
       * address.subnetMask; // 64
       */
      static fromAddressAndMask(address, mask) {
        const bits = common.prefixLengthFromMask(new _Address6(mask).bigInt(), constants6.BITS);
        return new _Address6(`${address}/${bits}`);
      }
      /**
       * Construct an `Address6` from an address and a Cisco-style wildcard mask
       * given as separate strings (e.g. `::ffff:ffff:ffff:ffff` for a `/64`).
       * The wildcard mask is the bitwise inverse of the subnet mask. Throws
       * `AddressError` if the mask is non-contiguous.
       * @example
       * var address = Address6.fromAddressAndWildcardMask('fe80::1', '::ffff:ffff:ffff:ffff');
       * address.subnetMask; // 64
       */
      static fromAddressAndWildcardMask(address, wildcardMask) {
        const wildcard = new _Address6(wildcardMask).bigInt();
        const allOnes = (BigInt(1) << BigInt(constants6.BITS)) - BigInt(1);
        const mask = wildcard ^ allOnes;
        const bits = common.prefixLengthFromMask(mask, constants6.BITS);
        return new _Address6(`${address}/${bits}`);
      }
      /**
       * Construct an `Address6` from a wildcard pattern with trailing `*`
       * groups. The number of trailing wildcards determines the prefix
       * length: each `*` represents 16 bits. `::` is expanded to zero groups
       * (not wildcards) before evaluating trailing wildcards.
       *
       * Only trailing whole-group wildcards are supported. Partial-group
       * wildcards (e.g. `2001:db8::0*`) and interior wildcards (e.g.
       * `*::1`) throw `AddressError`.
       * @example
       * Address6.fromWildcard('2001:db8:*:*:*:*:*:*').subnet;  // '/32'
       * Address6.fromWildcard('2001:db8::*').subnet;           // '/112'
       * Address6.fromWildcard('*:*:*:*:*:*:*:*').subnet;       // '/0'
       */
      static fromWildcard(input) {
        if (input.includes("%") || input.includes("/")) {
          throw new address_error_1.AddressError("Wildcard pattern must not include a zone or CIDR suffix");
        }
        const halves = input.split("::");
        if (halves.length > 2) {
          throw new address_error_1.AddressError("Wildcard pattern cannot contain more than one '::'");
        }
        let groups;
        if (halves.length === 2) {
          const left = halves[0] === "" ? [] : halves[0].split(":");
          const right = halves[1] === "" ? [] : halves[1].split(":");
          const remaining = constants6.GROUPS - left.length - right.length;
          if (remaining < 1) {
            throw new address_error_1.AddressError("Wildcard pattern with '::' has too many groups");
          }
          groups = [...left, ...new Array(remaining).fill("0"), ...right];
        } else {
          groups = input.split(":");
        }
        if (groups.length !== constants6.GROUPS) {
          throw new address_error_1.AddressError("Wildcard pattern must have 8 groups");
        }
        let firstWildcard = -1;
        for (let i32 = 0; i32 < groups.length; i32++) {
          if (groups[i32] === "*") {
            if (firstWildcard === -1) {
              firstWildcard = i32;
            }
          } else if (firstWildcard !== -1) {
            throw new address_error_1.AddressError("Wildcard `*` must only appear in trailing groups (e.g. `2001:db8:*:*:*:*:*:*`)");
          }
        }
        const trailing = firstWildcard === -1 ? 0 : groups.length - firstWildcard;
        const replaced = groups.map((g32) => g32 === "*" ? "0" : g32);
        const subnetBits = constants6.BITS - trailing * 16;
        return new _Address6(`${replaced.join(":")}/${subnetBits}`);
      }
      /**
       * Create an IPv6-mapped address given an IPv4 address
       * @param {string} address - An IPv4 address string
       * @returns {Address6}
       * @example
       * var address = Address6.fromAddress4('192.168.0.1');
       * address.correctForm(); // '::ffff:c0a8:1'
       * address.to4in6(); // '::ffff:192.168.0.1'
       */
      static fromAddress4(address) {
        const address4 = new ipv4_1.Address4(address);
        const mask6 = constants6.BITS - (constants4.BITS - address4.subnetMask);
        return new _Address6(`::ffff:${address4.correctForm()}/${mask6}`);
      }
      /**
       * Return an address from ip6.arpa form
       * @param {string} arpaFormAddress - an 'ip6.arpa' form address
       * @returns {Adress6}
       * @example
       * var address = Address6.fromArpa(e.f.f.f.3.c.2.6.f.f.f.e.6.6.8.e.1.0.6.7.9.4.e.c.0.0.0.0.1.0.0.2.ip6.arpa.)
       * address.correctForm(); // '2001:0:ce49:7601:e866:efff:62c3:fffe'
       */
      static fromArpa(arpaFormAddress) {
        let address = arpaFormAddress.replace(/(\.ip6\.arpa)?\.$/, "");
        const semicolonAmount = 7;
        if (address.length !== 63) {
          throw new address_error_1.AddressError("Invalid 'ip6.arpa' form.");
        }
        const parts = address.split(".").reverse();
        for (let i32 = semicolonAmount; i32 > 0; i32--) {
          const insertIndex = i32 * 4;
          parts.splice(insertIndex, 0, ":");
        }
        address = parts.join("");
        return new _Address6(address);
      }
      /**
       * Return the Microsoft UNC transcription of the address
       * @returns {String} the Microsoft UNC transcription of the address
       */
      microsoftTranscription() {
        return `${this.correctForm().replace(/:/g, "-")}.ipv6-literal.net`;
      }
      /**
       * Return the first n bits of the address, defaulting to the subnet mask
       * @param {number} [mask=subnet] - the number of bits to mask
       * @returns {String} the first n bits of the address as a string
       */
      mask(mask = this.subnetMask) {
        return this.getBitsBase2(0, mask);
      }
      /**
       * Return the number of possible subnets of a given size in the address
       * @param {number} [subnetSize=128] - the subnet size
       * @returns {String}
       */
      // TODO: probably useful to have a numeric version of this too
      possibleSubnets(subnetSize = 128) {
        const availableBits = constants6.BITS - this.subnetMask;
        const subnetBits = Math.abs(subnetSize - constants6.BITS);
        const subnetPowers = availableBits - subnetBits;
        if (subnetPowers < 0) {
          return "0";
        }
        return addCommas((BigInt("2") ** BigInt(subnetPowers)).toString(10));
      }
      /**
       * Helper function getting start address.
       * @returns {bigint}
       */
      _startAddress() {
        return BigInt(`0b${this.mask() + "0".repeat(constants6.BITS - this.subnetMask)}`);
      }
      /**
       * The first address in the range given by this address' subnet
       * Often referred to as the Network Address.
       * @returns {Address6}
       */
      startAddress() {
        return _Address6.fromBigInt(this._startAddress());
      }
      /**
       * The first host address in the range given by this address's subnet ie
       * the first address after the Network Address
       * @returns {Address6}
       */
      startAddressExclusive() {
        const adjust = BigInt("1");
        return _Address6.fromBigInt(this._startAddress() + adjust);
      }
      /**
       * Helper function getting end address.
       * @returns {bigint}
       */
      _endAddress() {
        return BigInt(`0b${this.mask() + "1".repeat(constants6.BITS - this.subnetMask)}`);
      }
      /**
       * The last address in the range given by this address' subnet
       * Often referred to as the Broadcast
       * @returns {Address6}
       */
      endAddress() {
        return _Address6.fromBigInt(this._endAddress());
      }
      /**
       * The last host address in the range given by this address's subnet ie
       * the last address prior to the Broadcast Address
       * @returns {Address6}
       */
      endAddressExclusive() {
        const adjust = BigInt("1");
        return _Address6.fromBigInt(this._endAddress() - adjust);
      }
      /**
       * The hex form of the subnet mask, e.g. `ffff:ffff:ffff:ffff::` for a
       * `/64`. Returns an `Address6`; call `.correctForm()` for the string.
       * @returns {Address6}
       */
      subnetMaskAddress() {
        return _Address6.fromBigInt(BigInt(`0b${"1".repeat(this.subnetMask)}${"0".repeat(constants6.BITS - this.subnetMask)}`));
      }
      /**
       * The Cisco-style wildcard mask, e.g. `::ffff:ffff:ffff:ffff` for a
       * `/64`. This is the bitwise inverse of `subnetMaskAddress()`. Returns
       * an `Address6`; call `.correctForm()` for the string.
       * @returns {Address6}
       */
      wildcardMask() {
        return _Address6.fromBigInt(BigInt(`0b${"0".repeat(this.subnetMask)}${"1".repeat(constants6.BITS - this.subnetMask)}`));
      }
      /**
       * The network address in CIDR string form, e.g. `2001:db8::/32` for
       * `2001:db8::1/32`. For an address with no explicit subnet the prefix
       * is `/128`, e.g. `networkForm()` on `2001:db8::1` returns
       * `2001:db8::1/128`.
       * @returns {string}
       */
      networkForm() {
        return `${this.startAddress().correctForm()}/${this.subnetMask}`;
      }
      /**
       * Return the scope of the address. The 4-bit scope field
       * ([RFC 4291 §2.7](https://datatracker.ietf.org/doc/html/rfc4291#section-2.7))
       * is only defined for multicast addresses; for unicast addresses the scope
       * is derived from the address type per
       * [RFC 4007 §6](https://datatracker.ietf.org/doc/html/rfc4007#section-6).
       * @returns {String}
       */
      getScope() {
        const type = this.getType();
        if (type === "Multicast" || type.startsWith("Multicast ")) {
          const scope = constants6.SCOPES[parseInt(this.getBits(12, 16).toString(10), 10)];
          return scope || "Unknown";
        }
        if (type === "Link-local unicast" || type === "Loopback") {
          return "Link local";
        }
        if (type === "Unspecified") {
          return "Unknown";
        }
        return "Global";
      }
      /**
       * Return the type of the address
       * @returns {String}
       */
      getType() {
        for (let i32 = 0; i32 < TYPE_SUBNETS.length; i32++) {
          const entry = TYPE_SUBNETS[i32];
          if (this.isInSubnet(entry[0])) {
            return entry[1];
          }
        }
        return "Global unicast";
      }
      /**
       * Return the bits in the given range as a BigInt
       * @returns {bigint}
       */
      getBits(start, end) {
        return BigInt(`0b${this.getBitsBase2(start, end)}`);
      }
      /**
       * Return the bits in the given range as a base-2 string
       * @returns {String}
       */
      getBitsBase2(start, end) {
        return this.binaryZeroPad().slice(start, end);
      }
      /**
       * Return the bits in the given range as a base-16 string
       * @returns {String}
       */
      getBitsBase16(start, end) {
        const length = end - start;
        if (length % 4 !== 0) {
          throw new Error("Length of bits to retrieve must be divisible by four");
        }
        return this.getBits(start, end).toString(16).padStart(length / 4, "0");
      }
      /**
       * Return the bits that are set past the subnet mask length
       * @returns {String}
       */
      getBitsPastSubnet() {
        return this.getBitsBase2(this.subnetMask, constants6.BITS);
      }
      /**
       * Return the reversed ip6.arpa form of the address
       * @param {Object} options
       * @param {boolean} options.omitSuffix - omit the "ip6.arpa" suffix
       * @returns {String}
       */
      reverseForm(options) {
        if (!options) {
          options = {};
        }
        const characters = Math.floor(this.subnetMask / 4);
        const reversed = this.canonicalForm().replace(/:/g, "").split("").slice(0, characters).reverse().join(".");
        if (characters > 0) {
          if (options.omitSuffix) {
            return reversed;
          }
          return `${reversed}.ip6.arpa.`;
        }
        if (options.omitSuffix) {
          return "";
        }
        return "ip6.arpa.";
      }
      /**
       * Returns the address in correct form, per
       * [RFC 5952](https://datatracker.ietf.org/doc/html/rfc5952): leading zeros
       * stripped, the longest run of zero groups collapsed to `::`, and hex digits
       * lowercased (e.g. `2001:db8::1`). This is the recommended form for display.
       */
      correctForm() {
        let i32;
        let groups = [];
        let zeroCounter = 0;
        const zeroes = [];
        for (i32 = 0; i32 < this.parsedAddress.length; i32++) {
          const value = parseInt(this.parsedAddress[i32], 16);
          if (value === 0) {
            zeroCounter++;
          }
          if (value !== 0 && zeroCounter > 0) {
            if (zeroCounter > 1) {
              zeroes.push([i32 - zeroCounter, i32 - 1]);
            }
            zeroCounter = 0;
          }
        }
        if (zeroCounter > 1) {
          zeroes.push([this.parsedAddress.length - zeroCounter, this.parsedAddress.length - 1]);
        }
        const zeroLengths = zeroes.map((n10) => n10[1] - n10[0] + 1);
        if (zeroes.length > 0) {
          const index = zeroLengths.indexOf(Math.max(...zeroLengths));
          groups = compact(this.parsedAddress, zeroes[index]);
        } else {
          groups = this.parsedAddress;
        }
        for (i32 = 0; i32 < groups.length; i32++) {
          if (groups[i32] !== "compact") {
            groups[i32] = parseInt(groups[i32], 16).toString(16);
          }
        }
        let correct = groups.join(":");
        correct = correct.replace(/^compact$/, "::");
        correct = correct.replace(/(^compact)|(compact$)/, ":");
        correct = correct.replace(/compact/, "");
        return correct;
      }
      /**
       * Return a zero-padded base-2 string representation of the address
       * @returns {String}
       * @example
       * var address = new Address6('2001:4860:4001:803::1011');
       * address.binaryZeroPad();
       * // '0010000000000001010010000110000001000000000000010000100000000011
       * //  0000000000000000000000000000000000000000000000000001000000010001'
       */
      binaryZeroPad() {
        if (this._binaryZeroPad === void 0) {
          this._binaryZeroPad = this.bigInt().toString(2).padStart(constants6.BITS, "0");
        }
        return this._binaryZeroPad;
      }
      /**
       * Parses a v4-in-v6 string (e.g. `::ffff:192.168.0.1`) by extracting the
       * trailing IPv4 address into `this.address4` / `this.parsedAddress4` and
       * returning the address with the v4 portion converted to two v6 groups.
       * Used internally by `parse()`.
       */
      // TODO: Improve the semantics of this helper function
      parse4in6(address) {
        if (address.indexOf(".") === -1) {
          return address;
        }
        const groups = address.split(":");
        const lastGroup = groups.slice(-1)[0];
        const address4 = lastGroup.match(constants4.RE_ADDRESS);
        if (address4) {
          this.parsedAddress4 = address4[0];
          this.address4 = new ipv4_1.Address4(this.parsedAddress4);
          for (let i32 = 0; i32 < this.address4.groups; i32++) {
            if (/^0[0-9]+/.test(this.address4.parsedAddress[i32])) {
              const highlighted = this.address4.parsedAddress.map(spanLeadingZeroes4).join(".");
              const prefix = groups.slice(0, -1).map(helpers.escapeHtml).join(":");
              const separator = groups.length > 1 ? ":" : "";
              throw new address_error_1.AddressError("IPv4 addresses can't have leading zeroes.", `${prefix}${separator}${highlighted}`);
            }
          }
          this.v4 = true;
          groups[groups.length - 1] = this.address4.toGroup6();
          address = groups.join(":");
        }
        return address;
      }
      /**
       * Parses an IPv6 address string into its 8 hexadecimal groups (expanding
       * any `::` elision and any trailing v4-in-v6 portion) and stores the result
       * on `this.parsedAddress`. Called automatically by the constructor; you
       * typically don't need to call it directly. Throws `AddressError` if the
       * input is malformed.
       */
      // TODO: Make private?
      parse(address) {
        address = this.parse4in6(address);
        const badCharacters = address.match(constants6.RE_BAD_CHARACTERS);
        if (badCharacters) {
          throw new address_error_1.AddressError(`Bad character${badCharacters.length > 1 ? "s" : ""} detected in address: ${badCharacters.join("")}`, address.replace(constants6.RE_BAD_CHARACTERS, '<span class="parse-error">$1</span>'));
        }
        const badAddress = address.match(constants6.RE_BAD_ADDRESS);
        if (badAddress) {
          throw new address_error_1.AddressError(`Address failed regex: ${badAddress.join("")}`, address.replace(constants6.RE_BAD_ADDRESS, '<span class="parse-error">$1</span>'));
        }
        let groups = [];
        const halves = address.split("::");
        if (halves.length === 2) {
          let first = halves[0].split(":");
          let last = halves[1].split(":");
          if (first.length === 1 && first[0] === "") {
            first = [];
          }
          if (last.length === 1 && last[0] === "") {
            last = [];
          }
          const remaining = this.groups - (first.length + last.length);
          if (!remaining) {
            throw new address_error_1.AddressError("Error parsing groups");
          }
          this.elidedGroups = remaining;
          this.elisionBegin = first.length;
          this.elisionEnd = first.length + this.elidedGroups;
          groups = groups.concat(first);
          for (let i32 = 0; i32 < remaining; i32++) {
            groups.push("0");
          }
          groups = groups.concat(last);
        } else if (halves.length === 1) {
          groups = address.split(":");
          this.elidedGroups = 0;
        } else {
          throw new address_error_1.AddressError("Too many :: groups found");
        }
        groups = groups.map((group7) => parseInt(group7, 16).toString(16));
        if (groups.length !== this.groups) {
          throw new address_error_1.AddressError("Incorrect number of groups found");
        }
        return groups;
      }
      /**
       * Returns the canonical (fully expanded) form of the address: all 8 groups,
       * each padded to 4 hex digits, with no `::` collapsing
       * (e.g. `2001:0db8:0000:0000:0000:0000:0000:0001`). Useful for sorting and
       * byte-exact comparison.
       */
      canonicalForm() {
        return this.parsedAddress.map(paddedHex).join(":");
      }
      /**
       * Return the decimal form of the address
       * @returns {String}
       */
      decimal() {
        return this.parsedAddress.map((n10) => parseInt(n10, 16).toString(10).padStart(5, "0")).join(":");
      }
      /**
       * Return the address as a BigInt
       * @returns {bigint}
       */
      bigInt() {
        return BigInt(`0x${this.parsedAddress.map(paddedHex).join("")}`);
      }
      /**
       * Return the last two groups of this address as an IPv4 address string
       * @returns {Address4}
       * @example
       * var address = new Address6('2001:4860:4001::1825:bf11');
       * address.to4().correctForm(); // '24.37.191.17'
       */
      to4() {
        const binary = this.binaryZeroPad().split("");
        return ipv4_1.Address4.fromHex(BigInt(`0b${binary.slice(96, 128).join("")}`).toString(16).padStart(8, "0"));
      }
      /**
       * Return the v4-in-v6 form of the address
       * @returns {String}
       */
      to4in6() {
        const address4 = this.to4();
        const address6 = new _Address6(this.parsedAddress.slice(0, 6).join(":"), 6);
        const correct = address6.correctForm();
        let infix = "";
        if (!/:$/.test(correct)) {
          infix = ":";
        }
        return correct + infix + address4.address;
      }
      /**
       * Decodes the Teredo tunneling fields embedded in this address. Returns the
       * Teredo prefix, server IPv4, client IPv4, raw flag bits, cone-NAT flag,
       * UDP port, and Microsoft-format flag breakdown (reserved, universal/local,
       * group/individual, nonce). Only meaningful for addresses in `2001::/32`.
       */
      inspectTeredo() {
        const prefix = this.getBitsBase16(0, 32);
        const bitsForUdpPort = this.getBits(80, 96);
        const udpPort = (bitsForUdpPort ^ BigInt("0xffff")).toString();
        const server4 = ipv4_1.Address4.fromHex(this.getBitsBase16(32, 64));
        const bitsForClient4 = this.getBits(96, 128);
        const client4 = ipv4_1.Address4.fromHex((bitsForClient4 ^ BigInt("0xffffffff")).toString(16).padStart(8, "0"));
        const flagsBase2 = this.getBitsBase2(64, 80);
        const coneNat = (0, common_1.testBit)(flagsBase2, 15);
        const reserved = (0, common_1.testBit)(flagsBase2, 14);
        const groupIndividual = (0, common_1.testBit)(flagsBase2, 8);
        const universalLocal = (0, common_1.testBit)(flagsBase2, 9);
        const nonce = BigInt(`0b${flagsBase2.slice(2, 6) + flagsBase2.slice(8, 16)}`).toString(10);
        return {
          prefix: `${prefix.slice(0, 4)}:${prefix.slice(4, 8)}`,
          server4: server4.address,
          client4: client4.address,
          flags: flagsBase2,
          coneNat,
          microsoft: {
            reserved,
            universalLocal,
            groupIndividual,
            nonce
          },
          udpPort
        };
      }
      /**
       * Decodes the 6to4 tunneling fields embedded in this address. Returns the
       * 6to4 prefix and the embedded IPv4 gateway address. Only meaningful for
       * addresses in `2002::/16`.
       */
      inspect6to4() {
        const prefix = this.getBitsBase16(0, 16);
        const gateway = ipv4_1.Address4.fromHex(this.getBitsBase16(16, 48));
        return {
          prefix: prefix.slice(0, 4),
          gateway: gateway.address
        };
      }
      /**
       * Return a v6 6to4 address from a v6 v4inv6 address
       * @returns {Address6}
       */
      to6to4() {
        if (!this.is4()) {
          return null;
        }
        const addr6to4 = [
          "2002",
          this.getBitsBase16(96, 112),
          this.getBitsBase16(112, 128),
          "",
          "/16"
        ].join(":");
        return new _Address6(addr6to4);
      }
      /**
       * Embed an IPv4 address into a NAT64 IPv6 address using the encoding
       * defined by [RFC 6052](https://datatracker.ietf.org/doc/html/rfc6052).
       * The default prefix is the well-known prefix `64:ff9b::/96`. The prefix
       * length must be one of 32, 40, 48, 56, 64, or 96; for prefixes shorter
       * than /64 the IPv4 octets are split around the reserved bits 64–71.
       * @example
       * Address6.fromAddress4Nat64('192.0.2.33').correctForm(); // '64:ff9b::c000:221'
       * Address6.fromAddress4Nat64('192.0.2.33', '2001:db8::/32').correctForm(); // '2001:db8:c000:221::'
       */
      static fromAddress4Nat64(address, prefix = "64:ff9b::/96") {
        const v47 = new ipv4_1.Address4(address);
        const prefix6 = new _Address6(prefix);
        const pl2 = prefix6.subnetMask;
        if (pl2 !== 32 && pl2 !== 40 && pl2 !== 48 && pl2 !== 56 && pl2 !== 64 && pl2 !== 96) {
          throw new address_error_1.AddressError("NAT64 prefix length must be 32, 40, 48, 56, 64, or 96");
        }
        const prefixBits = prefix6.binaryZeroPad();
        const v4Bits = v47.binaryZeroPad();
        let bits;
        if (pl2 === 96) {
          bits = prefixBits.slice(0, 96) + v4Bits;
        } else {
          const beforeU = 64 - pl2;
          bits = prefixBits.slice(0, pl2) + v4Bits.slice(0, beforeU) + "00000000" + v4Bits.slice(beforeU) + "0".repeat(128 - 72 - (32 - beforeU));
        }
        const hex = BigInt(`0b${bits}`).toString(16).padStart(32, "0");
        const groups = [];
        for (let i32 = 0; i32 < 8; i32++) {
          groups.push(hex.slice(i32 * 4, (i32 + 1) * 4));
        }
        return new _Address6(groups.join(":"));
      }
      /**
       * Extract the embedded IPv4 address from a NAT64 IPv6 address using the
       * encoding defined by [RFC 6052](https://datatracker.ietf.org/doc/html/rfc6052).
       * The default prefix is the well-known prefix `64:ff9b::/96`. Returns
       * `null` if this address is not contained within the given prefix.
       * @example
       * new Address6('64:ff9b::c000:221').toAddress4Nat64()!.correctForm(); // '192.0.2.33'
       */
      toAddress4Nat64(prefix = "64:ff9b::/96") {
        const prefix6 = new _Address6(prefix);
        const pl2 = prefix6.subnetMask;
        if (pl2 !== 32 && pl2 !== 40 && pl2 !== 48 && pl2 !== 56 && pl2 !== 64 && pl2 !== 96) {
          throw new address_error_1.AddressError("NAT64 prefix length must be 32, 40, 48, 56, 64, or 96");
        }
        if (!this.isInSubnet(prefix6)) {
          return null;
        }
        const bits = this.binaryZeroPad();
        let v4Bits;
        if (pl2 === 96) {
          v4Bits = bits.slice(96, 128);
        } else {
          const beforeU = 64 - pl2;
          v4Bits = bits.slice(pl2, pl2 + beforeU) + bits.slice(72, 72 + (32 - beforeU));
        }
        const octets = [];
        for (let i32 = 0; i32 < 4; i32++) {
          octets.push(parseInt(v4Bits.slice(i32 * 8, (i32 + 1) * 8), 2).toString());
        }
        return new ipv4_1.Address4(octets.join("."));
      }
      /**
       * Return a byte array.
       *
       * To get a Node.js `Buffer`, wrap the result: `Buffer.from(address.toByteArray())`.
       * @returns {Array}
       */
      toByteArray() {
        const valueWithoutPadding = this.bigInt().toString(16);
        const leadingPad = "0".repeat(valueWithoutPadding.length % 2);
        const value = `${leadingPad}${valueWithoutPadding}`;
        const bytes = [];
        for (let i32 = 0, length = value.length; i32 < length; i32 += 2) {
          bytes.push(parseInt(value.substring(i32, i32 + 2), 16));
        }
        return bytes;
      }
      /**
       * Return an unsigned byte array.
       *
       * To get a Node.js `Buffer`, wrap the result: `Buffer.from(address.toUnsignedByteArray())`.
       * @returns {Array}
       */
      toUnsignedByteArray() {
        return this.toByteArray().map(unsignByte);
      }
      /**
       * Convert a byte array to an Address6 object.
       *
       * To convert from a Node.js `Buffer`, spread it: `Address6.fromByteArray([...buf])`.
       * @returns {Address6}
       */
      static fromByteArray(bytes) {
        return this.fromUnsignedByteArray(bytes.map(unsignByte));
      }
      /**
       * Convert an unsigned byte array to an Address6 object.
       *
       * To convert from a Node.js `Buffer`, spread it: `Address6.fromUnsignedByteArray([...buf])`.
       * @returns {Address6}
       */
      static fromUnsignedByteArray(bytes) {
        const BYTE_MAX = BigInt("256");
        let result2 = BigInt("0");
        let multiplier = BigInt("1");
        for (let i32 = bytes.length - 1; i32 >= 0; i32--) {
          result2 += multiplier * BigInt(bytes[i32].toString(10));
          multiplier *= BYTE_MAX;
        }
        return _Address6.fromBigInt(result2);
      }
      /**
       * Returns true if the address is in the canonical form, false otherwise
       * @returns {boolean}
       */
      isCanonical() {
        return this.addressMinusSuffix === this.canonicalForm();
      }
      /**
       * Returns true if the address is a link local address, false otherwise
       * @returns {boolean}
       */
      isLinkLocal() {
        if (this.getBitsBase2(0, 64) === "1111111010000000000000000000000000000000000000000000000000000000") {
          return true;
        }
        return false;
      }
      /**
       * Returns true if the address is a multicast address, false otherwise
       * @returns {boolean}
       */
      isMulticast() {
        const type = this.getType();
        return type === "Multicast" || type.startsWith("Multicast ");
      }
      /**
       * Returns true if the address was written in v4-in-v6 dotted-quad notation
       * (e.g. `::ffff:127.0.0.1`), false otherwise. This is a notation-level flag
       * and does not reflect whether the address bits lie in the IPv4-mapped
       * (`::ffff:0:0/96`) subnet — for that, see {@link isMapped4}.
       * @returns {boolean}
       */
      is4() {
        return this.v4;
      }
      /**
       * Returns true if the address is an IPv4-mapped IPv6 address in
       * `::ffff:0:0/96` ([RFC 4291 §2.5.5.2](https://datatracker.ietf.org/doc/html/rfc4291#section-2.5.5.2)),
       * false otherwise. Unlike {@link is4}, this checks the underlying address
       * bits rather than the textual notation, so `::ffff:127.0.0.1` and
       * `::ffff:7f00:1` both return true.
       * @returns {boolean}
       */
      isMapped4() {
        return this.isInSubnet(IPV4_MAPPED_SUBNET);
      }
      /**
       * Returns true if the address is a Teredo address, false otherwise
       * @returns {boolean}
       */
      isTeredo() {
        return this.isInSubnet(TEREDO_SUBNET);
      }
      /**
       * Returns true if the address is a 6to4 address, false otherwise
       * @returns {boolean}
       */
      is6to4() {
        return this.isInSubnet(SIX_TO_FOUR_SUBNET);
      }
      /**
       * Returns true if the address is a loopback address, false otherwise
       * @returns {boolean}
       */
      isLoopback() {
        return this.getType() === "Loopback";
      }
      /**
       * Returns true if the address is a Unique Local Address in `fc00::/7` ([RFC 4193](https://datatracker.ietf.org/doc/html/rfc4193)). ULAs are the IPv6 equivalent of IPv4 [RFC 1918](https://datatracker.ietf.org/doc/html/rfc1918) private addresses.
       * @returns {boolean}
       */
      isULA() {
        return this.isInSubnet(ULA_SUBNET);
      }
      /**
       * Returns true if the address is the unspecified address `::`.
       * @returns {boolean}
       */
      isUnspecified() {
        return this.getType() === "Unspecified";
      }
      /**
       * Returns true if the address is in the documentation prefix `2001:db8::/32` ([RFC 3849](https://datatracker.ietf.org/doc/html/rfc3849)).
       * @returns {boolean}
       */
      isDocumentation() {
        return this.isInSubnet(DOCUMENTATION_SUBNET);
      }
      // #endregion
      // #region HTML
      /**
       * Returns the address as an HTTP URL with the host bracketed, e.g.
       * `http://[2001:db8::1]/`. If `optionalPort` is provided it is appended,
       * e.g. `http://[2001:db8::1]:8080/`.
       */
      href(optionalPort) {
        if (optionalPort === void 0) {
          optionalPort = "";
        } else {
          optionalPort = `:${optionalPort}`;
        }
        return `http://[${this.correctForm()}]${optionalPort}/`;
      }
      /**
       * Returns an HTML `<a>` element whose `href` encodes the address in a URL
       * hash fragment (default prefix `/#address=`). Useful for linking between
       * pages of an address-inspector UI.
       * @param options.className - CSS class for the rendered `<a>` element
       * @param options.prefix - hash prefix prepended to the address (default `/#address=`)
       * @param options.v4 - when true, render the address in v4-in-v6 form
       */
      link(options) {
        if (!options) {
          options = {};
        }
        if (options.className === void 0) {
          options.className = "";
        }
        if (options.prefix === void 0) {
          options.prefix = "/#address=";
        }
        if (options.v4 === void 0) {
          options.v4 = false;
        }
        let formFunction = this.correctForm;
        if (options.v4) {
          formFunction = this.to4in6;
        }
        const form = formFunction.call(this);
        const safeHref = helpers.escapeHtml(`${options.prefix}${form}`);
        const safeForm = helpers.escapeHtml(form);
        if (options.className) {
          const safeClass = helpers.escapeHtml(options.className);
          return `<a href="${safeHref}" class="${safeClass}">${safeForm}</a>`;
        }
        return `<a href="${safeHref}">${safeForm}</a>`;
      }
      /**
       * Groups an address
       * @returns {String}
       */
      group() {
        if (this.elidedGroups === 0) {
          return helpers.simpleGroup(this.addressMinusSuffix).join(":");
        }
        assert(typeof this.elidedGroups === "number");
        assert(typeof this.elisionBegin === "number");
        const output = [];
        const [left, right] = this.addressMinusSuffix.split("::");
        if (left.length) {
          output.push(...helpers.simpleGroup(left));
        } else {
          output.push("");
        }
        const classes = ["hover-group"];
        for (let i32 = this.elisionBegin; i32 < this.elisionBegin + this.elidedGroups; i32++) {
          classes.push(`group-${i32}`);
        }
        output.push(`<span class="${classes.join(" ")}"></span>`);
        if (right.length) {
          output.push(...helpers.simpleGroup(right, this.elisionEnd));
        } else {
          output.push("");
        }
        if (this.is4()) {
          assert(this.address4 instanceof ipv4_1.Address4);
          output.pop();
          output.push(this.address4.groupForV6());
        }
        return output.join(":");
      }
      // #endregion
      // #region Regular expressions
      /**
       * Generate a regular expression string that can be used to find or validate
       * all variations of this address
       * @param {boolean} substringSearch
       * @returns {string}
       */
      regularExpressionString(substringSearch = false) {
        let output = [];
        const address6 = new _Address6(this.correctForm());
        if (address6.elidedGroups === 0) {
          output.push((0, regular_expressions_1.simpleRegularExpression)(address6.parsedAddress));
        } else if (address6.elidedGroups === constants6.GROUPS) {
          output.push((0, regular_expressions_1.possibleElisions)(constants6.GROUPS));
        } else {
          const halves = address6.address.split("::");
          if (halves[0].length) {
            output.push((0, regular_expressions_1.simpleRegularExpression)(halves[0].split(":")));
          }
          assert(typeof address6.elidedGroups === "number");
          output.push((0, regular_expressions_1.possibleElisions)(address6.elidedGroups, halves[0].length !== 0, halves[1].length !== 0));
          if (halves[1].length) {
            output.push((0, regular_expressions_1.simpleRegularExpression)(halves[1].split(":")));
          }
          output = [output.join(":")];
        }
        if (!substringSearch) {
          output = [
            "(?=^|",
            regular_expressions_1.ADDRESS_BOUNDARY,
            "|[^\\w\\:])(",
            ...output,
            ")(?=[^\\w\\:]|",
            regular_expressions_1.ADDRESS_BOUNDARY,
            "|$)"
          ];
        }
        return output.join("");
      }
      /**
       * Generate a regular expression that can be used to find or validate all
       * variations of this address.
       * @param {boolean} substringSearch
       * @returns {RegExp}
       */
      regularExpression(substringSearch = false) {
        return new RegExp(this.regularExpressionString(substringSearch), "i");
      }
    };
    exports2.Address6 = Address6;
    var TYPE_SUBNETS = Object.keys(constants6.TYPES).map((subnet) => [
      new Address6(subnet),
      constants6.TYPES[subnet]
    ]);
    var TEREDO_SUBNET = new Address6("2001::/32");
    var SIX_TO_FOUR_SUBNET = new Address6("2002::/16");
    var ULA_SUBNET = new Address6("fc00::/7");
    var DOCUMENTATION_SUBNET = new Address6("2001:db8::/32");
    var IPV4_MAPPED_SUBNET = new Address6("::ffff:0:0/96");
  }
});

// ../../node_modules/ip-address/dist/ip-address.js
var require_ip_address = __commonJS({
  "../../node_modules/ip-address/dist/ip-address.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __setModuleDefault2 = exports2 && exports2.__setModuleDefault || (Object.create ? (function(o10, v) {
      Object.defineProperty(o10, "default", { enumerable: true, value: v });
    }) : function(o10, v) {
      o10["default"] = v;
    });
    var __importStar2 = exports2 && exports2.__importStar || function(mod) {
      if (mod && mod.__esModule) return mod;
      var result2 = {};
      if (mod != null) {
        for (var k32 in mod) if (k32 !== "default" && Object.prototype.hasOwnProperty.call(mod, k32)) __createBinding3(result2, mod, k32);
      }
      __setModuleDefault2(result2, mod);
      return result2;
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.v6 = exports2.AddressError = exports2.Address6 = exports2.Address4 = void 0;
    var ipv4_1 = require_ipv4();
    Object.defineProperty(exports2, "Address4", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return ipv4_1.Address4;
    }, "get") });
    var ipv6_1 = require_ipv6();
    Object.defineProperty(exports2, "Address6", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return ipv6_1.Address6;
    }, "get") });
    var address_error_1 = require_address_error();
    Object.defineProperty(exports2, "AddressError", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return address_error_1.AddressError;
    }, "get") });
    var helpers = __importStar2(require_helpers3());
    exports2.v6 = { helpers };
  }
});

// ../../node_modules/socks/build/common/helpers.js
var require_helpers4 = __commonJS({
  "../../node_modules/socks/build/common/helpers.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ipToBuffer = exports2.int32ToIpv4 = exports2.ipv4ToInt32 = exports2.validateSocksClientChainOptions = exports2.validateSocksClientOptions = void 0;
    var util_1 = require_util2();
    var constants_1 = require_constants7();
    var stream = require("stream");
    var ip_address_1 = require_ip_address();
    var net = require("net");
    function validateSocksClientOptions(options, acceptedCommands = ["connect", "bind", "associate"]) {
      if (!constants_1.SocksCommand[options.command]) {
        throw new util_1.SocksClientError(constants_1.ERRORS.InvalidSocksCommand, options);
      }
      if (acceptedCommands.indexOf(options.command) === -1) {
        throw new util_1.SocksClientError(constants_1.ERRORS.InvalidSocksCommandForOperation, options);
      }
      if (!isValidSocksRemoteHost(options.destination)) {
        throw new util_1.SocksClientError(constants_1.ERRORS.InvalidSocksClientOptionsDestination, options);
      }
      if (!isValidSocksProxy(options.proxy)) {
        throw new util_1.SocksClientError(constants_1.ERRORS.InvalidSocksClientOptionsProxy, options);
      }
      validateCustomProxyAuth(options.proxy, options);
      if (options.timeout && !isValidTimeoutValue(options.timeout)) {
        throw new util_1.SocksClientError(constants_1.ERRORS.InvalidSocksClientOptionsTimeout, options);
      }
      if (options.existing_socket && !(options.existing_socket instanceof stream.Duplex)) {
        throw new util_1.SocksClientError(constants_1.ERRORS.InvalidSocksClientOptionsExistingSocket, options);
      }
    }
    __name(validateSocksClientOptions, "validateSocksClientOptions");
    exports2.validateSocksClientOptions = validateSocksClientOptions;
    function validateSocksClientChainOptions(options) {
      if (options.command !== "connect") {
        throw new util_1.SocksClientError(constants_1.ERRORS.InvalidSocksCommandChain, options);
      }
      if (!isValidSocksRemoteHost(options.destination)) {
        throw new util_1.SocksClientError(constants_1.ERRORS.InvalidSocksClientOptionsDestination, options);
      }
      if (!(options.proxies && Array.isArray(options.proxies) && options.proxies.length >= 2)) {
        throw new util_1.SocksClientError(constants_1.ERRORS.InvalidSocksClientOptionsProxiesLength, options);
      }
      options.proxies.forEach((proxy) => {
        if (!isValidSocksProxy(proxy)) {
          throw new util_1.SocksClientError(constants_1.ERRORS.InvalidSocksClientOptionsProxy, options);
        }
        validateCustomProxyAuth(proxy, options);
      });
      if (options.timeout && !isValidTimeoutValue(options.timeout)) {
        throw new util_1.SocksClientError(constants_1.ERRORS.InvalidSocksClientOptionsTimeout, options);
      }
    }
    __name(validateSocksClientChainOptions, "validateSocksClientChainOptions");
    exports2.validateSocksClientChainOptions = validateSocksClientChainOptions;
    function validateCustomProxyAuth(proxy, options) {
      if (proxy.custom_auth_method !== void 0) {
        if (proxy.custom_auth_method < constants_1.SOCKS5_CUSTOM_AUTH_START || proxy.custom_auth_method > constants_1.SOCKS5_CUSTOM_AUTH_END) {
          throw new util_1.SocksClientError(constants_1.ERRORS.InvalidSocksClientOptionsCustomAuthRange, options);
        }
        if (proxy.custom_auth_request_handler === void 0 || typeof proxy.custom_auth_request_handler !== "function") {
          throw new util_1.SocksClientError(constants_1.ERRORS.InvalidSocksClientOptionsCustomAuthOptions, options);
        }
        if (proxy.custom_auth_response_size === void 0) {
          throw new util_1.SocksClientError(constants_1.ERRORS.InvalidSocksClientOptionsCustomAuthOptions, options);
        }
        if (proxy.custom_auth_response_handler === void 0 || typeof proxy.custom_auth_response_handler !== "function") {
          throw new util_1.SocksClientError(constants_1.ERRORS.InvalidSocksClientOptionsCustomAuthOptions, options);
        }
      }
    }
    __name(validateCustomProxyAuth, "validateCustomProxyAuth");
    function isValidSocksRemoteHost(remoteHost) {
      return remoteHost && typeof remoteHost.host === "string" && Buffer.byteLength(remoteHost.host) < 256 && typeof remoteHost.port === "number" && remoteHost.port >= 0 && remoteHost.port <= 65535;
    }
    __name(isValidSocksRemoteHost, "isValidSocksRemoteHost");
    function isValidSocksProxy(proxy) {
      return proxy && (typeof proxy.host === "string" || typeof proxy.ipaddress === "string") && typeof proxy.port === "number" && proxy.port >= 0 && proxy.port <= 65535 && (proxy.type === 4 || proxy.type === 5);
    }
    __name(isValidSocksProxy, "isValidSocksProxy");
    function isValidTimeoutValue(value) {
      return typeof value === "number" && value > 0;
    }
    __name(isValidTimeoutValue, "isValidTimeoutValue");
    function ipv4ToInt32(ip) {
      const address = new ip_address_1.Address4(ip);
      return address.toArray().reduce((acc, part) => (acc << 8) + part, 0) >>> 0;
    }
    __name(ipv4ToInt32, "ipv4ToInt32");
    exports2.ipv4ToInt32 = ipv4ToInt32;
    function int32ToIpv4(int32) {
      const octet1 = int32 >>> 24 & 255;
      const octet2 = int32 >>> 16 & 255;
      const octet3 = int32 >>> 8 & 255;
      const octet4 = int32 & 255;
      return [octet1, octet2, octet3, octet4].join(".");
    }
    __name(int32ToIpv4, "int32ToIpv4");
    exports2.int32ToIpv4 = int32ToIpv4;
    function ipToBuffer(ip) {
      if (net.isIPv4(ip)) {
        const address = new ip_address_1.Address4(ip);
        return Buffer.from(address.toArray());
      } else if (net.isIPv6(ip)) {
        const address = new ip_address_1.Address6(ip);
        return Buffer.from(address.canonicalForm().split(":").map((segment) => segment.padStart(4, "0")).join(""), "hex");
      } else {
        throw new Error("Invalid IP address format");
      }
    }
    __name(ipToBuffer, "ipToBuffer");
    exports2.ipToBuffer = ipToBuffer;
  }
});

// ../../node_modules/socks/build/common/receivebuffer.js
var require_receivebuffer = __commonJS({
  "../../node_modules/socks/build/common/receivebuffer.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ReceiveBuffer = void 0;
    var ReceiveBuffer = class {
      static {
        __name(this, "ReceiveBuffer");
      }
      constructor(size = 4096) {
        this.buffer = Buffer.allocUnsafe(size);
        this.offset = 0;
        this.originalSize = size;
      }
      get length() {
        return this.offset;
      }
      append(data3) {
        if (!Buffer.isBuffer(data3)) {
          throw new Error("Attempted to append a non-buffer instance to ReceiveBuffer.");
        }
        if (this.offset + data3.length >= this.buffer.length) {
          const tmp = this.buffer;
          this.buffer = Buffer.allocUnsafe(Math.max(this.buffer.length + this.originalSize, this.buffer.length + data3.length));
          tmp.copy(this.buffer);
        }
        data3.copy(this.buffer, this.offset);
        return this.offset += data3.length;
      }
      peek(length) {
        if (length > this.offset) {
          throw new Error("Attempted to read beyond the bounds of the managed internal data.");
        }
        return this.buffer.slice(0, length);
      }
      get(length) {
        if (length > this.offset) {
          throw new Error("Attempted to read beyond the bounds of the managed internal data.");
        }
        const value = Buffer.allocUnsafe(length);
        this.buffer.slice(0, length).copy(value);
        this.buffer.copyWithin(0, length, length + this.offset - length);
        this.offset -= length;
        return value;
      }
    };
    exports2.ReceiveBuffer = ReceiveBuffer;
  }
});

// ../../node_modules/socks/build/client/socksclient.js
var require_socksclient = __commonJS({
  "../../node_modules/socks/build/client/socksclient.js"(exports2) {
    "use strict";
    var __awaiter2 = exports2 && exports2.__awaiter || function(thisArg, _arguments, P, generator) {
      function adopt(value) {
        return value instanceof P ? value : new P(function(resolve13) {
          resolve13(value);
        });
      }
      __name(adopt, "adopt");
      return new (P || (P = Promise))(function(resolve13, reject) {
        function fulfilled(value) {
          try {
            step(generator.next(value));
          } catch (e32) {
            reject(e32);
          }
        }
        __name(fulfilled, "fulfilled");
        function rejected(value) {
          try {
            step(generator["throw"](value));
          } catch (e32) {
            reject(e32);
          }
        }
        __name(rejected, "rejected");
        function step(result2) {
          result2.done ? resolve13(result2.value) : adopt(result2.value).then(fulfilled, rejected);
        }
        __name(step, "step");
        step((generator = generator.apply(thisArg, _arguments || [])).next());
      });
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.SocksClientError = exports2.SocksClient = void 0;
    var events_1 = require("events");
    var net = require("net");
    var smart_buffer_1 = require_smartbuffer();
    var constants_1 = require_constants7();
    var helpers_1 = require_helpers4();
    var receivebuffer_1 = require_receivebuffer();
    var util_1 = require_util2();
    Object.defineProperty(exports2, "SocksClientError", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return util_1.SocksClientError;
    }, "get") });
    var ip_address_1 = require_ip_address();
    var SocksClient = class _SocksClient extends events_1.EventEmitter {
      static {
        __name(this, "SocksClient");
      }
      constructor(options) {
        super();
        this.options = Object.assign({}, options);
        (0, helpers_1.validateSocksClientOptions)(options);
        this.setState(constants_1.SocksClientState.Created);
      }
      /**
       * Creates a new SOCKS connection.
       *
       * Note: Supports callbacks and promises. Only supports the connect command.
       * @param options { SocksClientOptions } Options.
       * @param callback { Function } An optional callback function.
       * @returns { Promise }
       */
      static createConnection(options, callback) {
        return new Promise((resolve13, reject) => {
          try {
            (0, helpers_1.validateSocksClientOptions)(options, ["connect"]);
          } catch (err) {
            if (typeof callback === "function") {
              callback(err);
              return resolve13(err);
            } else {
              return reject(err);
            }
          }
          const client = new _SocksClient(options);
          client.connect(options.existing_socket);
          client.once("established", (info2) => {
            client.removeAllListeners();
            if (typeof callback === "function") {
              callback(null, info2);
              resolve13(info2);
            } else {
              resolve13(info2);
            }
          });
          client.once("error", (err) => {
            client.removeAllListeners();
            if (typeof callback === "function") {
              callback(err);
              resolve13(err);
            } else {
              reject(err);
            }
          });
        });
      }
      /**
       * Creates a new SOCKS connection chain to a destination host through 2 or more SOCKS proxies.
       *
       * Note: Supports callbacks and promises. Only supports the connect method.
       * Note: Implemented via createConnection() factory function.
       * @param options { SocksClientChainOptions } Options
       * @param callback { Function } An optional callback function.
       * @returns { Promise }
       */
      static createConnectionChain(options, callback) {
        return new Promise((resolve13, reject) => __awaiter2(this, void 0, void 0, function* () {
          try {
            (0, helpers_1.validateSocksClientChainOptions)(options);
          } catch (err) {
            if (typeof callback === "function") {
              callback(err);
              return resolve13(err);
            } else {
              return reject(err);
            }
          }
          if (options.randomizeChain) {
            (0, util_1.shuffleArray)(options.proxies);
          }
          try {
            let sock;
            for (let i32 = 0; i32 < options.proxies.length; i32++) {
              const nextProxy = options.proxies[i32];
              const nextDestination = i32 === options.proxies.length - 1 ? options.destination : {
                host: options.proxies[i32 + 1].host || options.proxies[i32 + 1].ipaddress,
                port: options.proxies[i32 + 1].port
              };
              const result2 = yield _SocksClient.createConnection({
                command: "connect",
                proxy: nextProxy,
                destination: nextDestination,
                existing_socket: sock
              });
              sock = sock || result2.socket;
            }
            if (typeof callback === "function") {
              callback(null, { socket: sock });
              resolve13({ socket: sock });
            } else {
              resolve13({ socket: sock });
            }
          } catch (err) {
            if (typeof callback === "function") {
              callback(err);
              resolve13(err);
            } else {
              reject(err);
            }
          }
        }));
      }
      /**
       * Creates a SOCKS UDP Frame.
       * @param options
       */
      static createUDPFrame(options) {
        const buff = new smart_buffer_1.SmartBuffer();
        buff.writeUInt16BE(0);
        buff.writeUInt8(options.frameNumber || 0);
        if (net.isIPv4(options.remoteHost.host)) {
          buff.writeUInt8(constants_1.Socks5HostType.IPv4);
          buff.writeUInt32BE((0, helpers_1.ipv4ToInt32)(options.remoteHost.host));
        } else if (net.isIPv6(options.remoteHost.host)) {
          buff.writeUInt8(constants_1.Socks5HostType.IPv6);
          buff.writeBuffer((0, helpers_1.ipToBuffer)(options.remoteHost.host));
        } else {
          buff.writeUInt8(constants_1.Socks5HostType.Hostname);
          buff.writeUInt8(Buffer.byteLength(options.remoteHost.host));
          buff.writeString(options.remoteHost.host);
        }
        buff.writeUInt16BE(options.remoteHost.port);
        buff.writeBuffer(options.data);
        return buff.toBuffer();
      }
      /**
       * Parses a SOCKS UDP frame.
       * @param data
       */
      static parseUDPFrame(data3) {
        const buff = smart_buffer_1.SmartBuffer.fromBuffer(data3);
        buff.readOffset = 2;
        const frameNumber = buff.readUInt8();
        const hostType = buff.readUInt8();
        let remoteHost;
        if (hostType === constants_1.Socks5HostType.IPv4) {
          remoteHost = (0, helpers_1.int32ToIpv4)(buff.readUInt32BE());
        } else if (hostType === constants_1.Socks5HostType.IPv6) {
          remoteHost = ip_address_1.Address6.fromByteArray(Array.from(buff.readBuffer(16))).canonicalForm();
        } else {
          remoteHost = buff.readString(buff.readUInt8());
        }
        const remotePort = buff.readUInt16BE();
        return {
          frameNumber,
          remoteHost: {
            host: remoteHost,
            port: remotePort
          },
          data: buff.readBuffer()
        };
      }
      /**
       * Internal state setter. If the SocksClient is in an error state, it cannot be changed to a non error state.
       */
      setState(newState) {
        if (this.state !== constants_1.SocksClientState.Error) {
          this.state = newState;
        }
      }
      /**
       * Starts the connection establishment to the proxy and destination.
       * @param existingSocket Connected socket to use instead of creating a new one (internal use).
       */
      connect(existingSocket) {
        this.onDataReceived = (data3) => this.onDataReceivedHandler(data3);
        this.onClose = () => this.onCloseHandler();
        this.onError = (err) => this.onErrorHandler(err);
        this.onConnect = () => this.onConnectHandler();
        const timer = setTimeout(() => this.onEstablishedTimeout(), this.options.timeout || constants_1.DEFAULT_TIMEOUT);
        if (timer.unref && typeof timer.unref === "function") {
          timer.unref();
        }
        if (existingSocket) {
          this.socket = existingSocket;
        } else {
          this.socket = new net.Socket();
        }
        this.socket.once("close", this.onClose);
        this.socket.once("error", this.onError);
        this.socket.once("connect", this.onConnect);
        this.socket.on("data", this.onDataReceived);
        this.setState(constants_1.SocksClientState.Connecting);
        this.receiveBuffer = new receivebuffer_1.ReceiveBuffer();
        if (existingSocket) {
          this.socket.emit("connect");
        } else {
          this.socket.connect(this.getSocketOptions());
          if (this.options.set_tcp_nodelay !== void 0 && this.options.set_tcp_nodelay !== null) {
            this.socket.setNoDelay(!!this.options.set_tcp_nodelay);
          }
        }
        this.prependOnceListener("established", (info2) => {
          setImmediate(() => {
            if (this.receiveBuffer.length > 0) {
              const excessData = this.receiveBuffer.get(this.receiveBuffer.length);
              info2.socket.emit("data", excessData);
            }
            info2.socket.resume();
          });
        });
      }
      // Socket options (defaults host/port to options.proxy.host/options.proxy.port)
      getSocketOptions() {
        return Object.assign(Object.assign({}, this.options.socket_options), { host: this.options.proxy.host || this.options.proxy.ipaddress, port: this.options.proxy.port });
      }
      /**
       * Handles internal Socks timeout callback.
       * Note: If the Socks client is not BoundWaitingForConnection or Established, the connection will be closed.
       */
      onEstablishedTimeout() {
        if (this.state !== constants_1.SocksClientState.Established && this.state !== constants_1.SocksClientState.BoundWaitingForConnection) {
          this.closeSocket(constants_1.ERRORS.ProxyConnectionTimedOut);
        }
      }
      /**
       * Handles Socket connect event.
       */
      onConnectHandler() {
        this.setState(constants_1.SocksClientState.Connected);
        if (this.options.proxy.type === 4) {
          this.sendSocks4InitialHandshake();
        } else {
          this.sendSocks5InitialHandshake();
        }
        this.setState(constants_1.SocksClientState.SentInitialHandshake);
      }
      /**
       * Handles Socket data event.
       * @param data
       */
      onDataReceivedHandler(data3) {
        this.receiveBuffer.append(data3);
        this.processData();
      }
      /**
       * Handles processing of the data we have received.
       */
      processData() {
        while (this.state !== constants_1.SocksClientState.Established && this.state !== constants_1.SocksClientState.Error && this.receiveBuffer.length >= this.nextRequiredPacketBufferSize) {
          if (this.state === constants_1.SocksClientState.SentInitialHandshake) {
            if (this.options.proxy.type === 4) {
              this.handleSocks4FinalHandshakeResponse();
            } else {
              this.handleInitialSocks5HandshakeResponse();
            }
          } else if (this.state === constants_1.SocksClientState.SentAuthentication) {
            this.handleInitialSocks5AuthenticationHandshakeResponse();
          } else if (this.state === constants_1.SocksClientState.SentFinalHandshake) {
            this.handleSocks5FinalHandshakeResponse();
          } else if (this.state === constants_1.SocksClientState.BoundWaitingForConnection) {
            if (this.options.proxy.type === 4) {
              this.handleSocks4IncomingConnectionResponse();
            } else {
              this.handleSocks5IncomingConnectionResponse();
            }
          } else {
            this.closeSocket(constants_1.ERRORS.InternalError);
            break;
          }
        }
      }
      /**
       * Handles Socket close event.
       * @param had_error
       */
      onCloseHandler() {
        this.closeSocket(constants_1.ERRORS.SocketClosed);
      }
      /**
       * Handles Socket error event.
       * @param err
       */
      onErrorHandler(err) {
        this.closeSocket(err.message);
      }
      /**
       * Removes internal event listeners on the underlying Socket.
       */
      removeInternalSocketHandlers() {
        this.socket.pause();
        this.socket.removeListener("data", this.onDataReceived);
        this.socket.removeListener("close", this.onClose);
        this.socket.removeListener("error", this.onError);
        this.socket.removeListener("connect", this.onConnect);
      }
      /**
       * Closes and destroys the underlying Socket. Emits an error event.
       * @param err { String } An error string to include in error event.
       */
      closeSocket(err) {
        if (this.state !== constants_1.SocksClientState.Error) {
          this.setState(constants_1.SocksClientState.Error);
          this.socket.destroy();
          this.removeInternalSocketHandlers();
          this.emit("error", new util_1.SocksClientError(err, this.options));
        }
      }
      /**
       * Sends initial Socks v4 handshake request.
       */
      sendSocks4InitialHandshake() {
        const userId = this.options.proxy.userId || "";
        const buff = new smart_buffer_1.SmartBuffer();
        buff.writeUInt8(4);
        buff.writeUInt8(constants_1.SocksCommand[this.options.command]);
        buff.writeUInt16BE(this.options.destination.port);
        if (net.isIPv4(this.options.destination.host)) {
          buff.writeBuffer((0, helpers_1.ipToBuffer)(this.options.destination.host));
          buff.writeStringNT(userId);
        } else {
          buff.writeUInt8(0);
          buff.writeUInt8(0);
          buff.writeUInt8(0);
          buff.writeUInt8(1);
          buff.writeStringNT(userId);
          buff.writeStringNT(this.options.destination.host);
        }
        this.nextRequiredPacketBufferSize = constants_1.SOCKS_INCOMING_PACKET_SIZES.Socks4Response;
        this.socket.write(buff.toBuffer());
      }
      /**
       * Handles Socks v4 handshake response.
       * @param data
       */
      handleSocks4FinalHandshakeResponse() {
        const data3 = this.receiveBuffer.get(8);
        if (data3[1] !== constants_1.Socks4Response.Granted) {
          this.closeSocket(`${constants_1.ERRORS.Socks4ProxyRejectedConnection} - (${constants_1.Socks4Response[data3[1]]})`);
        } else {
          if (constants_1.SocksCommand[this.options.command] === constants_1.SocksCommand.bind) {
            const buff = smart_buffer_1.SmartBuffer.fromBuffer(data3);
            buff.readOffset = 2;
            const remoteHost = {
              port: buff.readUInt16BE(),
              host: (0, helpers_1.int32ToIpv4)(buff.readUInt32BE())
            };
            if (remoteHost.host === "0.0.0.0") {
              remoteHost.host = this.options.proxy.ipaddress;
            }
            this.setState(constants_1.SocksClientState.BoundWaitingForConnection);
            this.emit("bound", { remoteHost, socket: this.socket });
          } else {
            this.setState(constants_1.SocksClientState.Established);
            this.removeInternalSocketHandlers();
            this.emit("established", { socket: this.socket });
          }
        }
      }
      /**
       * Handles Socks v4 incoming connection request (BIND)
       * @param data
       */
      handleSocks4IncomingConnectionResponse() {
        const data3 = this.receiveBuffer.get(8);
        if (data3[1] !== constants_1.Socks4Response.Granted) {
          this.closeSocket(`${constants_1.ERRORS.Socks4ProxyRejectedIncomingBoundConnection} - (${constants_1.Socks4Response[data3[1]]})`);
        } else {
          const buff = smart_buffer_1.SmartBuffer.fromBuffer(data3);
          buff.readOffset = 2;
          const remoteHost = {
            port: buff.readUInt16BE(),
            host: (0, helpers_1.int32ToIpv4)(buff.readUInt32BE())
          };
          this.setState(constants_1.SocksClientState.Established);
          this.removeInternalSocketHandlers();
          this.emit("established", { remoteHost, socket: this.socket });
        }
      }
      /**
       * Sends initial Socks v5 handshake request.
       */
      sendSocks5InitialHandshake() {
        const buff = new smart_buffer_1.SmartBuffer();
        const supportedAuthMethods = [constants_1.Socks5Auth.NoAuth];
        if (this.options.proxy.userId || this.options.proxy.password) {
          supportedAuthMethods.push(constants_1.Socks5Auth.UserPass);
        }
        if (this.options.proxy.custom_auth_method !== void 0) {
          supportedAuthMethods.push(this.options.proxy.custom_auth_method);
        }
        buff.writeUInt8(5);
        buff.writeUInt8(supportedAuthMethods.length);
        for (const authMethod of supportedAuthMethods) {
          buff.writeUInt8(authMethod);
        }
        this.nextRequiredPacketBufferSize = constants_1.SOCKS_INCOMING_PACKET_SIZES.Socks5InitialHandshakeResponse;
        this.socket.write(buff.toBuffer());
        this.setState(constants_1.SocksClientState.SentInitialHandshake);
      }
      /**
       * Handles initial Socks v5 handshake response.
       * @param data
       */
      handleInitialSocks5HandshakeResponse() {
        const data3 = this.receiveBuffer.get(2);
        if (data3[0] !== 5) {
          this.closeSocket(constants_1.ERRORS.InvalidSocks5IntiailHandshakeSocksVersion);
        } else if (data3[1] === constants_1.SOCKS5_NO_ACCEPTABLE_AUTH) {
          this.closeSocket(constants_1.ERRORS.InvalidSocks5InitialHandshakeNoAcceptedAuthType);
        } else {
          if (data3[1] === constants_1.Socks5Auth.NoAuth) {
            this.socks5ChosenAuthType = constants_1.Socks5Auth.NoAuth;
            this.sendSocks5CommandRequest();
          } else if (data3[1] === constants_1.Socks5Auth.UserPass) {
            this.socks5ChosenAuthType = constants_1.Socks5Auth.UserPass;
            this.sendSocks5UserPassAuthentication();
          } else if (data3[1] === this.options.proxy.custom_auth_method) {
            this.socks5ChosenAuthType = this.options.proxy.custom_auth_method;
            this.sendSocks5CustomAuthentication();
          } else {
            this.closeSocket(constants_1.ERRORS.InvalidSocks5InitialHandshakeUnknownAuthType);
          }
        }
      }
      /**
       * Sends Socks v5 user & password auth handshake.
       *
       * Note: No auth and user/pass are currently supported.
       */
      sendSocks5UserPassAuthentication() {
        const userId = this.options.proxy.userId || "";
        const password = this.options.proxy.password || "";
        const buff = new smart_buffer_1.SmartBuffer();
        buff.writeUInt8(1);
        buff.writeUInt8(Buffer.byteLength(userId));
        buff.writeString(userId);
        buff.writeUInt8(Buffer.byteLength(password));
        buff.writeString(password);
        this.nextRequiredPacketBufferSize = constants_1.SOCKS_INCOMING_PACKET_SIZES.Socks5UserPassAuthenticationResponse;
        this.socket.write(buff.toBuffer());
        this.setState(constants_1.SocksClientState.SentAuthentication);
      }
      sendSocks5CustomAuthentication() {
        return __awaiter2(this, void 0, void 0, function* () {
          this.nextRequiredPacketBufferSize = this.options.proxy.custom_auth_response_size;
          this.socket.write(yield this.options.proxy.custom_auth_request_handler());
          this.setState(constants_1.SocksClientState.SentAuthentication);
        });
      }
      handleSocks5CustomAuthHandshakeResponse(data3) {
        return __awaiter2(this, void 0, void 0, function* () {
          return yield this.options.proxy.custom_auth_response_handler(data3);
        });
      }
      handleSocks5AuthenticationNoAuthHandshakeResponse(data3) {
        return __awaiter2(this, void 0, void 0, function* () {
          return data3[1] === 0;
        });
      }
      handleSocks5AuthenticationUserPassHandshakeResponse(data3) {
        return __awaiter2(this, void 0, void 0, function* () {
          return data3[1] === 0;
        });
      }
      /**
       * Handles Socks v5 auth handshake response.
       * @param data
       */
      handleInitialSocks5AuthenticationHandshakeResponse() {
        return __awaiter2(this, void 0, void 0, function* () {
          this.setState(constants_1.SocksClientState.ReceivedAuthenticationResponse);
          let authResult = false;
          if (this.socks5ChosenAuthType === constants_1.Socks5Auth.NoAuth) {
            authResult = yield this.handleSocks5AuthenticationNoAuthHandshakeResponse(this.receiveBuffer.get(2));
          } else if (this.socks5ChosenAuthType === constants_1.Socks5Auth.UserPass) {
            authResult = yield this.handleSocks5AuthenticationUserPassHandshakeResponse(this.receiveBuffer.get(2));
          } else if (this.socks5ChosenAuthType === this.options.proxy.custom_auth_method) {
            authResult = yield this.handleSocks5CustomAuthHandshakeResponse(this.receiveBuffer.get(this.options.proxy.custom_auth_response_size));
          }
          if (!authResult) {
            this.closeSocket(constants_1.ERRORS.Socks5AuthenticationFailed);
          } else {
            this.sendSocks5CommandRequest();
          }
        });
      }
      /**
       * Sends Socks v5 final handshake request.
       */
      sendSocks5CommandRequest() {
        const buff = new smart_buffer_1.SmartBuffer();
        buff.writeUInt8(5);
        buff.writeUInt8(constants_1.SocksCommand[this.options.command]);
        buff.writeUInt8(0);
        if (net.isIPv4(this.options.destination.host)) {
          buff.writeUInt8(constants_1.Socks5HostType.IPv4);
          buff.writeBuffer((0, helpers_1.ipToBuffer)(this.options.destination.host));
        } else if (net.isIPv6(this.options.destination.host)) {
          buff.writeUInt8(constants_1.Socks5HostType.IPv6);
          buff.writeBuffer((0, helpers_1.ipToBuffer)(this.options.destination.host));
        } else {
          buff.writeUInt8(constants_1.Socks5HostType.Hostname);
          buff.writeUInt8(this.options.destination.host.length);
          buff.writeString(this.options.destination.host);
        }
        buff.writeUInt16BE(this.options.destination.port);
        this.nextRequiredPacketBufferSize = constants_1.SOCKS_INCOMING_PACKET_SIZES.Socks5ResponseHeader;
        this.socket.write(buff.toBuffer());
        this.setState(constants_1.SocksClientState.SentFinalHandshake);
      }
      /**
       * Handles Socks v5 final handshake response.
       * @param data
       */
      handleSocks5FinalHandshakeResponse() {
        const header = this.receiveBuffer.peek(5);
        if (header[0] !== 5 || header[1] !== constants_1.Socks5Response.Granted) {
          this.closeSocket(`${constants_1.ERRORS.InvalidSocks5FinalHandshakeRejected} - ${constants_1.Socks5Response[header[1]]}`);
        } else {
          const addressType = header[3];
          let remoteHost;
          let buff;
          if (addressType === constants_1.Socks5HostType.IPv4) {
            const dataNeeded = constants_1.SOCKS_INCOMING_PACKET_SIZES.Socks5ResponseIPv4;
            if (this.receiveBuffer.length < dataNeeded) {
              this.nextRequiredPacketBufferSize = dataNeeded;
              return;
            }
            buff = smart_buffer_1.SmartBuffer.fromBuffer(this.receiveBuffer.get(dataNeeded).slice(4));
            remoteHost = {
              host: (0, helpers_1.int32ToIpv4)(buff.readUInt32BE()),
              port: buff.readUInt16BE()
            };
            if (remoteHost.host === "0.0.0.0") {
              remoteHost.host = this.options.proxy.ipaddress;
            }
          } else if (addressType === constants_1.Socks5HostType.Hostname) {
            const hostLength = header[4];
            const dataNeeded = constants_1.SOCKS_INCOMING_PACKET_SIZES.Socks5ResponseHostname(hostLength);
            if (this.receiveBuffer.length < dataNeeded) {
              this.nextRequiredPacketBufferSize = dataNeeded;
              return;
            }
            buff = smart_buffer_1.SmartBuffer.fromBuffer(this.receiveBuffer.get(dataNeeded).slice(5));
            remoteHost = {
              host: buff.readString(hostLength),
              port: buff.readUInt16BE()
            };
          } else if (addressType === constants_1.Socks5HostType.IPv6) {
            const dataNeeded = constants_1.SOCKS_INCOMING_PACKET_SIZES.Socks5ResponseIPv6;
            if (this.receiveBuffer.length < dataNeeded) {
              this.nextRequiredPacketBufferSize = dataNeeded;
              return;
            }
            buff = smart_buffer_1.SmartBuffer.fromBuffer(this.receiveBuffer.get(dataNeeded).slice(4));
            remoteHost = {
              host: ip_address_1.Address6.fromByteArray(Array.from(buff.readBuffer(16))).canonicalForm(),
              port: buff.readUInt16BE()
            };
          }
          this.setState(constants_1.SocksClientState.ReceivedFinalResponse);
          if (constants_1.SocksCommand[this.options.command] === constants_1.SocksCommand.connect) {
            this.setState(constants_1.SocksClientState.Established);
            this.removeInternalSocketHandlers();
            this.emit("established", { remoteHost, socket: this.socket });
          } else if (constants_1.SocksCommand[this.options.command] === constants_1.SocksCommand.bind) {
            this.setState(constants_1.SocksClientState.BoundWaitingForConnection);
            this.nextRequiredPacketBufferSize = constants_1.SOCKS_INCOMING_PACKET_SIZES.Socks5ResponseHeader;
            this.emit("bound", { remoteHost, socket: this.socket });
          } else if (constants_1.SocksCommand[this.options.command] === constants_1.SocksCommand.associate) {
            this.setState(constants_1.SocksClientState.Established);
            this.removeInternalSocketHandlers();
            this.emit("established", {
              remoteHost,
              socket: this.socket
            });
          }
        }
      }
      /**
       * Handles Socks v5 incoming connection request (BIND).
       */
      handleSocks5IncomingConnectionResponse() {
        const header = this.receiveBuffer.peek(5);
        if (header[0] !== 5 || header[1] !== constants_1.Socks5Response.Granted) {
          this.closeSocket(`${constants_1.ERRORS.Socks5ProxyRejectedIncomingBoundConnection} - ${constants_1.Socks5Response[header[1]]}`);
        } else {
          const addressType = header[3];
          let remoteHost;
          let buff;
          if (addressType === constants_1.Socks5HostType.IPv4) {
            const dataNeeded = constants_1.SOCKS_INCOMING_PACKET_SIZES.Socks5ResponseIPv4;
            if (this.receiveBuffer.length < dataNeeded) {
              this.nextRequiredPacketBufferSize = dataNeeded;
              return;
            }
            buff = smart_buffer_1.SmartBuffer.fromBuffer(this.receiveBuffer.get(dataNeeded).slice(4));
            remoteHost = {
              host: (0, helpers_1.int32ToIpv4)(buff.readUInt32BE()),
              port: buff.readUInt16BE()
            };
            if (remoteHost.host === "0.0.0.0") {
              remoteHost.host = this.options.proxy.ipaddress;
            }
          } else if (addressType === constants_1.Socks5HostType.Hostname) {
            const hostLength = header[4];
            const dataNeeded = constants_1.SOCKS_INCOMING_PACKET_SIZES.Socks5ResponseHostname(hostLength);
            if (this.receiveBuffer.length < dataNeeded) {
              this.nextRequiredPacketBufferSize = dataNeeded;
              return;
            }
            buff = smart_buffer_1.SmartBuffer.fromBuffer(this.receiveBuffer.get(dataNeeded).slice(5));
            remoteHost = {
              host: buff.readString(hostLength),
              port: buff.readUInt16BE()
            };
          } else if (addressType === constants_1.Socks5HostType.IPv6) {
            const dataNeeded = constants_1.SOCKS_INCOMING_PACKET_SIZES.Socks5ResponseIPv6;
            if (this.receiveBuffer.length < dataNeeded) {
              this.nextRequiredPacketBufferSize = dataNeeded;
              return;
            }
            buff = smart_buffer_1.SmartBuffer.fromBuffer(this.receiveBuffer.get(dataNeeded).slice(4));
            remoteHost = {
              host: ip_address_1.Address6.fromByteArray(Array.from(buff.readBuffer(16))).canonicalForm(),
              port: buff.readUInt16BE()
            };
          }
          this.setState(constants_1.SocksClientState.Established);
          this.removeInternalSocketHandlers();
          this.emit("established", { remoteHost, socket: this.socket });
        }
      }
      get socksClientOptions() {
        return Object.assign({}, this.options);
      }
    };
    exports2.SocksClient = SocksClient;
  }
});

// ../../node_modules/socks/build/index.js
var require_build = __commonJS({
  "../../node_modules/socks/build/index.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __exportStar3 = exports2 && exports2.__exportStar || function(m20, exports3) {
      for (var p10 in m20) if (p10 !== "default" && !Object.prototype.hasOwnProperty.call(exports3, p10)) __createBinding3(exports3, m20, p10);
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    __exportStar3(require_socksclient(), exports2);
  }
});

// ../../node_modules/socks-proxy-agent/dist/index.js
var require_dist7 = __commonJS({
  "../../node_modules/socks-proxy-agent/dist/index.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __setModuleDefault2 = exports2 && exports2.__setModuleDefault || (Object.create ? (function(o10, v) {
      Object.defineProperty(o10, "default", { enumerable: true, value: v });
    }) : function(o10, v) {
      o10["default"] = v;
    });
    var __importStar2 = exports2 && exports2.__importStar || function(mod) {
      if (mod && mod.__esModule) return mod;
      var result2 = {};
      if (mod != null) {
        for (var k32 in mod) if (k32 !== "default" && Object.prototype.hasOwnProperty.call(mod, k32)) __createBinding3(result2, mod, k32);
      }
      __setModuleDefault2(result2, mod);
      return result2;
    };
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.SocksProxyAgent = void 0;
    var socks_1 = require_build();
    var agent_base_1 = require_dist4();
    var debug_1 = __importDefault2(require_src2());
    var dns = __importStar2(require("dns"));
    var net = __importStar2(require("net"));
    var tls = __importStar2(require("tls"));
    var url_1 = require("url");
    var debug2 = (0, debug_1.default)("socks-proxy-agent");
    var setServernameFromNonIpHost = /* @__PURE__ */ __name((options) => {
      if (options.servername === void 0 && options.host && !net.isIP(options.host)) {
        return {
          ...options,
          servername: options.host
        };
      }
      return options;
    }, "setServernameFromNonIpHost");
    function parseSocksURL(url) {
      let lookup = false;
      let type = 5;
      const host = url.hostname;
      const port = parseInt(url.port, 10) || 1080;
      switch (url.protocol.replace(":", "")) {
        case "socks4":
          lookup = true;
          type = 4;
          break;
        // pass through
        case "socks4a":
          type = 4;
          break;
        case "socks5":
          lookup = true;
          type = 5;
          break;
        // pass through
        case "socks":
          type = 5;
          break;
        case "socks5h":
          type = 5;
          break;
        default:
          throw new TypeError(`A "socks" protocol must be specified! Got: ${String(url.protocol)}`);
      }
      const proxy = {
        host,
        port,
        type
      };
      if (url.username) {
        Object.defineProperty(proxy, "userId", {
          value: decodeURIComponent(url.username),
          enumerable: false
        });
      }
      if (url.password != null) {
        Object.defineProperty(proxy, "password", {
          value: decodeURIComponent(url.password),
          enumerable: false
        });
      }
      return { lookup, proxy };
    }
    __name(parseSocksURL, "parseSocksURL");
    var SocksProxyAgent = class extends agent_base_1.Agent {
      static {
        __name(this, "SocksProxyAgent");
      }
      constructor(uri, opts) {
        super(opts);
        const url = typeof uri === "string" ? new url_1.URL(uri) : uri;
        const { proxy, lookup } = parseSocksURL(url);
        this.shouldLookup = lookup;
        this.proxy = proxy;
        this.timeout = opts?.timeout ?? null;
        this.socketOptions = opts?.socketOptions ?? null;
      }
      /**
       * Initiates a SOCKS connection to the specified SOCKS proxy server,
       * which in turn connects to the specified remote host and port.
       */
      async connect(req, opts) {
        const { shouldLookup, proxy, timeout } = this;
        if (!opts.host) {
          throw new Error("No `host` defined!");
        }
        let { host } = opts;
        const { port, lookup: lookupFn = dns.lookup } = opts;
        if (shouldLookup) {
          host = await new Promise((resolve13, reject) => {
            lookupFn(host, {}, (err, res) => {
              if (err) {
                reject(err);
              } else {
                resolve13(res);
              }
            });
          });
        }
        const socksOpts = {
          proxy,
          destination: {
            host,
            port: typeof port === "number" ? port : parseInt(port, 10)
          },
          command: "connect",
          timeout: timeout ?? void 0,
          // @ts-expect-error the type supplied by socks for socket_options is wider
          // than necessary since socks will always override the host and port
          socket_options: this.socketOptions ?? void 0
        };
        const cleanup = /* @__PURE__ */ __name((tlsSocket) => {
          req.destroy();
          socket.destroy();
          if (tlsSocket)
            tlsSocket.destroy();
        }, "cleanup");
        debug2("Creating socks proxy connection: %o", socksOpts);
        const { socket } = await socks_1.SocksClient.createConnection(socksOpts);
        debug2("Successfully created socks proxy connection");
        if (timeout !== null) {
          socket.setTimeout(timeout);
          socket.on("timeout", () => cleanup());
        }
        if (opts.secureEndpoint) {
          debug2("Upgrading socket connection to TLS");
          const tlsSocket = tls.connect({
            ...omit(setServernameFromNonIpHost(opts), "host", "path", "port"),
            socket
          });
          tlsSocket.once("error", (error4) => {
            debug2("Socket TLS error", error4.message);
            cleanup(tlsSocket);
          });
          return tlsSocket;
        }
        return socket;
      }
    };
    SocksProxyAgent.protocols = [
      "socks",
      "socks4",
      "socks4a",
      "socks5",
      "socks5h"
    ];
    exports2.SocksProxyAgent = SocksProxyAgent;
    function omit(obj, ...keys) {
      const ret = {};
      let key;
      for (key in obj) {
        if (!keys.includes(key)) {
          ret[key] = obj[key];
        }
      }
      return ret;
    }
    __name(omit, "omit");
  }
});

// ../../node_modules/data-uri-to-buffer/dist/common.js
var require_common6 = __commonJS({
  "../../node_modules/data-uri-to-buffer/dist/common.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.makeDataUriToBuffer = void 0;
    var makeDataUriToBuffer = /* @__PURE__ */ __name((convert) => (uri) => {
      uri = String(uri);
      if (!/^data:/i.test(uri)) {
        throw new TypeError('`uri` does not appear to be a Data URI (must begin with "data:")');
      }
      uri = uri.replace(/\r?\n/g, "");
      const firstComma = uri.indexOf(",");
      if (firstComma === -1 || firstComma <= 4) {
        throw new TypeError("malformed data: URI");
      }
      const meta = uri.substring(5, firstComma).split(";");
      let charset = "";
      let base64 = false;
      const type = meta[0] || "text/plain";
      let typeFull = type;
      for (let i32 = 1; i32 < meta.length; i32++) {
        if (meta[i32] === "base64") {
          base64 = true;
        } else if (meta[i32]) {
          typeFull += `;${meta[i32]}`;
          if (meta[i32].indexOf("charset=") === 0) {
            charset = meta[i32].substring(8);
          }
        }
      }
      if (!meta[0] && !charset.length) {
        typeFull += ";charset=US-ASCII";
        charset = "US-ASCII";
      }
      const data3 = unescape(uri.substring(firstComma + 1));
      const buffer = base64 ? convert.base64ToArrayBuffer(data3) : convert.stringToBuffer(data3);
      return {
        type,
        typeFull,
        charset,
        buffer
      };
    }, "makeDataUriToBuffer");
    exports2.makeDataUriToBuffer = makeDataUriToBuffer;
  }
});

// ../../node_modules/data-uri-to-buffer/dist/node.js
var require_node2 = __commonJS({
  "../../node_modules/data-uri-to-buffer/dist/node.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.dataUriToBuffer = void 0;
    var common_1 = require_common6();
    function nodeBuffertoArrayBuffer(nodeBuf) {
      if (nodeBuf.byteLength === nodeBuf.buffer.byteLength) {
        return nodeBuf.buffer;
      }
      const buffer = new ArrayBuffer(nodeBuf.byteLength);
      const view = new Uint8Array(buffer);
      view.set(nodeBuf);
      return buffer;
    }
    __name(nodeBuffertoArrayBuffer, "nodeBuffertoArrayBuffer");
    function base64ToArrayBuffer(base64) {
      return nodeBuffertoArrayBuffer(Buffer.from(base64, "base64"));
    }
    __name(base64ToArrayBuffer, "base64ToArrayBuffer");
    function stringToBuffer(str) {
      return nodeBuffertoArrayBuffer(Buffer.from(str, "ascii"));
    }
    __name(stringToBuffer, "stringToBuffer");
    exports2.dataUriToBuffer = (0, common_1.makeDataUriToBuffer)({ stringToBuffer, base64ToArrayBuffer });
  }
});

// ../../node_modules/get-uri/dist/notmodified.js
var require_notmodified = __commonJS({
  "../../node_modules/get-uri/dist/notmodified.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var NotModifiedError = class extends Error {
      static {
        __name(this, "NotModifiedError");
      }
      constructor(message2) {
        super(message2 || 'Source has not been modified since the provied "cache", re-use previous results');
        this.code = "ENOTMODIFIED";
      }
    };
    exports2.default = NotModifiedError;
  }
});

// ../../node_modules/get-uri/dist/data.js
var require_data = __commonJS({
  "../../node_modules/get-uri/dist/data.js"(exports2) {
    "use strict";
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.data = void 0;
    var debug_1 = __importDefault2(require_src2());
    var stream_1 = require("stream");
    var crypto_1 = require("crypto");
    var data_uri_to_buffer_1 = require_node2();
    var notmodified_1 = __importDefault2(require_notmodified());
    var debug2 = (0, debug_1.default)("get-uri:data");
    var DataReadable = class extends stream_1.Readable {
      static {
        __name(this, "DataReadable");
      }
      constructor(hash, buf) {
        super();
        this.push(buf);
        this.push(null);
        this.hash = hash;
      }
    };
    var data3 = /* @__PURE__ */ __name(async ({ href: uri }, { cache: cache32 } = {}) => {
      const shasum = (0, crypto_1.createHash)("sha1");
      shasum.update(uri);
      const hash = shasum.digest("hex");
      debug2('generated SHA1 hash for "data:" URI: %o', hash);
      if (cache32?.hash === hash) {
        debug2("got matching cache SHA1 hash: %o", hash);
        throw new notmodified_1.default();
      } else {
        debug2('creating Readable stream from "data:" URI buffer');
        const { buffer } = (0, data_uri_to_buffer_1.dataUriToBuffer)(uri);
        return new DataReadable(hash, Buffer.from(buffer));
      }
    }, "data");
    exports2.data = data3;
  }
});

// ../../node_modules/get-uri/dist/notfound.js
var require_notfound = __commonJS({
  "../../node_modules/get-uri/dist/notfound.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var NotFoundError = class extends Error {
      static {
        __name(this, "NotFoundError");
      }
      constructor(message2) {
        super(message2 || "File does not exist at the specified endpoint");
        this.code = "ENOTFOUND";
      }
    };
    exports2.default = NotFoundError;
  }
});

// ../../node_modules/get-uri/dist/file.js
var require_file2 = __commonJS({
  "../../node_modules/get-uri/dist/file.js"(exports2) {
    "use strict";
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.file = void 0;
    var debug_1 = __importDefault2(require_src2());
    var fs_1 = require("fs");
    var notfound_1 = __importDefault2(require_notfound());
    var notmodified_1 = __importDefault2(require_notmodified());
    var url_1 = require("url");
    var debug2 = (0, debug_1.default)("get-uri:file");
    var file = /* @__PURE__ */ __name(async ({ href: uri }, opts = {}) => {
      const {
        cache: cache32,
        flags = "r",
        mode = 438
        // =0666
      } = opts;
      try {
        const filepath = (0, url_1.fileURLToPath)(uri);
        debug2("Normalized pathname: %o", filepath);
        const fdHandle = await fs_1.promises.open(filepath, flags, mode);
        const fd = fdHandle.fd;
        const stat8 = await fdHandle.stat();
        if (cache32 && cache32.stat && stat8 && isNotModified(cache32.stat, stat8)) {
          await fdHandle.close();
          throw new notmodified_1.default();
        }
        const rs = (0, fs_1.createReadStream)(filepath, {
          autoClose: true,
          ...opts,
          fd
        });
        rs.stat = stat8;
        return rs;
      } catch (err) {
        if (err.code === "ENOENT") {
          throw new notfound_1.default();
        }
        throw err;
      }
    }, "file");
    exports2.file = file;
    function isNotModified(prev, curr) {
      return +prev.mtime === +curr.mtime;
    }
    __name(isNotModified, "isNotModified");
  }
});

// ../../node_modules/basic-ftp/dist/parseControlResponse.js
var require_parseControlResponse = __commonJS({
  "../../node_modules/basic-ftp/dist/parseControlResponse.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.parseControlResponse = parseControlResponse;
    exports2.isSingleLine = isSingleLine;
    exports2.isMultiline = isMultiline;
    exports2.positiveCompletion = positiveCompletion;
    exports2.positiveIntermediate = positiveIntermediate;
    var LF = "\n";
    function parseControlResponse(text) {
      const lines = text.split(/\r?\n/).filter(isNotBlank);
      const messages = [];
      let startAt = 0;
      let tokenRegex;
      for (let i32 = 0; i32 < lines.length; i32++) {
        const line = lines[i32];
        if (!tokenRegex) {
          if (isMultiline(line)) {
            const token = line.substr(0, 3);
            tokenRegex = new RegExp(`^${token}(?:$| )`);
            startAt = i32;
          } else if (isSingleLine(line)) {
            messages.push(line);
          }
        } else if (tokenRegex.test(line)) {
          tokenRegex = void 0;
          messages.push(lines.slice(startAt, i32 + 1).join(LF));
        }
      }
      const rest = tokenRegex ? lines.slice(startAt).join(LF) + LF : "";
      return { messages, rest };
    }
    __name(parseControlResponse, "parseControlResponse");
    function isSingleLine(line) {
      return /^\d\d\d(?:$| )/.test(line);
    }
    __name(isSingleLine, "isSingleLine");
    function isMultiline(line) {
      return /^\d\d\d-/.test(line);
    }
    __name(isMultiline, "isMultiline");
    function positiveCompletion(code) {
      return code >= 200 && code < 300;
    }
    __name(positiveCompletion, "positiveCompletion");
    function positiveIntermediate(code) {
      return code >= 300 && code < 400;
    }
    __name(positiveIntermediate, "positiveIntermediate");
    function isNotBlank(str) {
      return str.trim() !== "";
    }
    __name(isNotBlank, "isNotBlank");
  }
});

// ../../node_modules/basic-ftp/dist/FtpContext.js
var require_FtpContext = __commonJS({
  "../../node_modules/basic-ftp/dist/FtpContext.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.FTPContext = exports2.FTPError = void 0;
    var net_1 = require("net");
    var parseControlResponse_1 = require_parseControlResponse();
    var FTPError = class extends Error {
      static {
        __name(this, "FTPError");
      }
      constructor(res) {
        super(res.message);
        this.name = this.constructor.name;
        this.code = res.code;
      }
    };
    exports2.FTPError = FTPError;
    function doNothing() {
    }
    __name(doNothing, "doNothing");
    var maxControlResponseLength = 2 ** 16;
    var FTPContext = class {
      static {
        __name(this, "FTPContext");
      }
      /**
       * Instantiate an FTP context.
       *
       * @param timeout - Timeout in milliseconds to apply to control and data connections. Use 0 for no timeout.
       * @param encoding - Encoding to use for control connection. UTF-8 by default. Use "latin1" for older servers.
       */
      constructor(timeout = 0, encoding = "utf8") {
        this.timeout = timeout;
        this.verbose = false;
        this.ipFamily = void 0;
        this.tlsOptions = {};
        this._partialResponse = "";
        this._encoding = encoding;
        this._socket = this.socket = this._newSocket();
        this._dataSocket = void 0;
      }
      /**
       * Close the context.
       */
      close() {
        const message2 = this._task ? "User closed client during task" : "User closed client";
        const err = new Error(message2);
        this.closeWithError(err);
      }
      /**
       * Close the context with an error.
       */
      closeWithError(err) {
        if (this._closingError) {
          return;
        }
        this._closingError = err;
        this._closeControlSocket();
        this._closeSocket(this._dataSocket);
        this._passToHandler(err);
        this._stopTrackingTask();
      }
      /**
       * Returns true if this context has been closed or hasn't been connected yet. You can reopen it with `access`.
       */
      get closed() {
        return this.socket.remoteAddress === void 0 || this._closingError !== void 0;
      }
      /**
       * Reset this contex and all of its state.
       */
      reset() {
        this.socket = this._newSocket();
      }
      /**
       * Get the FTP control socket.
       */
      get socket() {
        return this._socket;
      }
      /**
       * Set the socket for the control connection. This will only close the current control socket
       * if the new one is not an upgrade to the current one.
       */
      set socket(socket) {
        this.dataSocket = void 0;
        this.tlsOptions = {};
        this._partialResponse = "";
        if (this._socket) {
          const newSocketUpgradesExisting = socket.localPort === this._socket.localPort;
          if (newSocketUpgradesExisting) {
            this._removeSocketListeners(this.socket);
          } else {
            this._closeControlSocket();
          }
        }
        if (socket) {
          this._closingError = void 0;
          socket.setTimeout(0);
          socket.setEncoding(this._encoding);
          socket.setKeepAlive(true);
          socket.on("data", (data3) => this._onControlSocketData(data3));
          socket.on("end", () => this.closeWithError(new Error("Server sent FIN packet unexpectedly, closing connection.")));
          socket.on("close", (hadError) => {
            if (!hadError)
              this.closeWithError(new Error("Server closed connection unexpectedly."));
          });
          this._setupDefaultErrorHandlers(socket, "control socket");
        }
        this._socket = socket;
      }
      /**
       * Get the current FTP data connection if present.
       */
      get dataSocket() {
        return this._dataSocket;
      }
      /**
       * Set the socket for the data connection. This will automatically close the former data socket.
       */
      set dataSocket(socket) {
        this._closeSocket(this._dataSocket);
        if (socket) {
          socket.setTimeout(0);
          this._setupDefaultErrorHandlers(socket, "data socket");
        }
        this._dataSocket = socket;
      }
      /**
       * Get the currently used encoding.
       */
      get encoding() {
        return this._encoding;
      }
      /**
       * Set the encoding used for the control socket.
       *
       * See https://nodejs.org/api/buffer.html#buffer_buffers_and_character_encodings for what encodings
       * are supported by Node.
       */
      set encoding(encoding) {
        this._encoding = encoding;
        if (this.socket) {
          this.socket.setEncoding(encoding);
        }
      }
      /**
       * Send an FTP command without waiting for or handling the result.
       */
      send(command) {
        if (/[\r\n\0]/.test(command)) {
          throw new Error(`Invalid command: Contains control characters. (${command})`);
        }
        const containsPassword = command.startsWith("PASS");
        const message2 = containsPassword ? "> PASS ###" : `> ${command}`;
        this.log(message2);
        this._socket.write(command + "\r\n", this.encoding);
      }
      /**
       * Send an FTP command and handle the first response. Use this if you have a simple
       * request-response situation.
       */
      request(command) {
        return this.handle(command, (res, task) => {
          if (res instanceof Error) {
            task.reject(res);
          } else {
            task.resolve(res);
          }
        });
      }
      /**
       * Send an FTP command and handle any response until you resolve/reject. Use this if you expect multiple responses
       * to a request. This returns a Promise that will hold whatever the response handler passed on when resolving/rejecting its task.
       */
      handle(command, responseHandler) {
        if (this._task) {
          const err = new Error("User launched a task while another one is still running. Forgot to use 'await' or '.then()'?");
          err.stack += `
Running task launched at: ${this._task.stack}`;
          this.closeWithError(err);
        }
        return new Promise((resolveTask, rejectTask) => {
          this._task = {
            stack: new Error().stack || "Unknown call stack",
            responseHandler,
            resolver: {
              resolve: /* @__PURE__ */ __name((arg) => {
                this._stopTrackingTask();
                resolveTask(arg);
              }, "resolve"),
              reject: /* @__PURE__ */ __name((err) => {
                this._stopTrackingTask();
                rejectTask(err);
              }, "reject")
            }
          };
          if (this._closingError) {
            const err = new Error(`Client is closed because ${this._closingError.message}`);
            err.stack += `
Closing reason: ${this._closingError.stack}`;
            err.code = this._closingError.code !== void 0 ? this._closingError.code : "0";
            this._passToHandler(err);
            return;
          }
          this.socket.setTimeout(this.timeout);
          if (command) {
            this.send(command);
          }
        });
      }
      /**
       * Log message if set to be verbose.
       */
      log(message2) {
        if (this.verbose) {
          console.log(message2);
        }
      }
      /**
       * Return true if the control socket is using TLS. This does not mean that a session
       * has already been negotiated.
       */
      get hasTLS() {
        return "encrypted" in this._socket;
      }
      /**
       * Removes reference to current task and handler. This won't resolve or reject the task.
       * @protected
       */
      _stopTrackingTask() {
        this.socket.setTimeout(0);
        this._task = void 0;
      }
      /**
       * Handle incoming data on the control socket. The chunk is going to be of type `string`
       * because we let `socket` handle encoding with `setEncoding`.
       * @protected
       */
      _onControlSocketData(chunk) {
        this.log(`< ${chunk}`);
        if (this._partialResponse.length + chunk.length > maxControlResponseLength) {
          this.closeWithError(new Error("FTP control response exceeded maximum allowed size"));
          return;
        }
        const completeResponse = this._partialResponse + chunk;
        const parsed = (0, parseControlResponse_1.parseControlResponse)(completeResponse);
        this._partialResponse = parsed.rest;
        for (const message2 of parsed.messages) {
          const code = parseInt(message2.substr(0, 3), 10);
          const response = { code, message: message2 };
          const err = code >= 400 ? new FTPError(response) : void 0;
          this._passToHandler(err ? err : response);
        }
      }
      /**
       * Send the current handler a response. This is usually a control socket response
       * or a socket event, like an error or timeout.
       * @protected
       */
      _passToHandler(response) {
        if (this._task) {
          this._task.responseHandler(response, this._task.resolver);
        }
      }
      /**
       * Setup all error handlers for a socket.
       * @protected
       */
      _setupDefaultErrorHandlers(socket, identifier) {
        socket.once("error", (error4) => {
          error4.message += ` (${identifier})`;
          this.closeWithError(error4);
        });
        socket.once("close", (hadError) => {
          if (hadError) {
            this.closeWithError(new Error(`Socket closed due to transmission error (${identifier})`));
          }
        });
        socket.once("timeout", () => {
          socket.destroy();
          this.closeWithError(new Error(`Timeout (${identifier})`));
        });
      }
      /**
       * Close the control socket. Sends QUIT, then FIN, and ignores any response or error.
       */
      _closeControlSocket() {
        this._removeSocketListeners(this._socket);
        this._socket.on("error", doNothing);
        this.send("QUIT");
        this._closeSocket(this._socket);
      }
      /**
       * Close a socket, ignores any error.
       * @protected
       */
      _closeSocket(socket) {
        if (socket) {
          this._removeSocketListeners(socket);
          socket.on("error", doNothing);
          socket.destroy();
        }
      }
      /**
       * Remove all default listeners for socket.
       * @protected
       */
      _removeSocketListeners(socket) {
        socket.removeAllListeners();
        socket.removeAllListeners("timeout");
        socket.removeAllListeners("data");
        socket.removeAllListeners("end");
        socket.removeAllListeners("error");
        socket.removeAllListeners("close");
        socket.removeAllListeners("connect");
      }
      /**
       * Provide a new socket instance.
       *
       * Internal use only, replaced for unit tests.
       */
      _newSocket() {
        return new net_1.Socket();
      }
    };
    exports2.FTPContext = FTPContext;
  }
});

// ../../node_modules/basic-ftp/dist/netUtils.js
var require_netUtils = __commonJS({
  "../../node_modules/basic-ftp/dist/netUtils.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.describeTLS = describeTLS;
    exports2.describeAddress = describeAddress;
    exports2.upgradeSocket = upgradeSocket;
    exports2.ipIsPrivateV4Address = ipIsPrivateV4Address;
    var tls_1 = require("tls");
    function describeTLS(socket) {
      if (socket instanceof tls_1.TLSSocket) {
        const protocol = socket.getProtocol();
        return protocol ? protocol : "Server socket or disconnected client socket";
      }
      return "No encryption";
    }
    __name(describeTLS, "describeTLS");
    function describeAddress(socket) {
      if (socket.remoteFamily === "IPv6") {
        return `[${socket.remoteAddress}]:${socket.remotePort}`;
      }
      return `${socket.remoteAddress}:${socket.remotePort}`;
    }
    __name(describeAddress, "describeAddress");
    function upgradeSocket(socket, options) {
      return new Promise((resolve13, reject) => {
        const tlsOptions = Object.assign({}, options, {
          socket
        });
        const tlsSocket = (0, tls_1.connect)(tlsOptions, () => {
          const expectCertificate = tlsOptions.rejectUnauthorized !== false;
          if (expectCertificate && !tlsSocket.authorized) {
            reject(tlsSocket.authorizationError);
          } else {
            tlsSocket.removeAllListeners("error");
            resolve13(tlsSocket);
          }
        }).once("error", (error4) => {
          reject(error4);
        });
      });
    }
    __name(upgradeSocket, "upgradeSocket");
    function ipIsPrivateV4Address(ip = "") {
      if (ip.startsWith("::ffff:")) {
        ip = ip.substr(7);
      }
      const octets = ip.split(".").map((o10) => parseInt(o10, 10));
      return octets[0] === 10 || octets[0] === 172 && octets[1] >= 16 && octets[1] <= 31 || octets[0] === 192 && octets[1] === 168 || ip === "127.0.0.1";
    }
    __name(ipIsPrivateV4Address, "ipIsPrivateV4Address");
  }
});

// ../../node_modules/basic-ftp/dist/FileInfo.js
var require_FileInfo = __commonJS({
  "../../node_modules/basic-ftp/dist/FileInfo.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.FileInfo = exports2.FileType = void 0;
    var FileType;
    (function(FileType2) {
      FileType2[FileType2["Unknown"] = 0] = "Unknown";
      FileType2[FileType2["File"] = 1] = "File";
      FileType2[FileType2["Directory"] = 2] = "Directory";
      FileType2[FileType2["SymbolicLink"] = 3] = "SymbolicLink";
    })(FileType || (exports2.FileType = FileType = {}));
    var FileInfo = class {
      static {
        __name(this, "FileInfo");
      }
      constructor(name) {
        this.name = name;
        this.type = FileType.Unknown;
        this.size = 0;
        this.rawModifiedAt = "";
        this.modifiedAt = void 0;
        this.permissions = void 0;
        this.hardLinkCount = void 0;
        this.link = void 0;
        this.group = void 0;
        this.user = void 0;
        this.uniqueID = void 0;
        this.name = name;
      }
      get isDirectory() {
        return this.type === FileType.Directory;
      }
      get isSymbolicLink() {
        return this.type === FileType.SymbolicLink;
      }
      get isFile() {
        return this.type === FileType.File;
      }
      /**
       * Deprecated, legacy API. Use `rawModifiedAt` instead.
       * @deprecated
       */
      get date() {
        return this.rawModifiedAt;
      }
      set date(rawModifiedAt) {
        this.rawModifiedAt = rawModifiedAt;
      }
    };
    exports2.FileInfo = FileInfo;
    FileInfo.UnixPermission = {
      Read: 4,
      Write: 2,
      Execute: 1
    };
  }
});

// ../../node_modules/basic-ftp/dist/parseListDOS.js
var require_parseListDOS = __commonJS({
  "../../node_modules/basic-ftp/dist/parseListDOS.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.testLine = testLine;
    exports2.parseLine = parseLine;
    exports2.transformList = transformList;
    var FileInfo_1 = require_FileInfo();
    var RE_LINE = new RegExp(
      "(\\S+)\\s+(\\S+)\\s+(?:(<DIR>)|([0-9]+))\\s+(\\S.*)"
      // First non-space followed by rest of line (name)
    );
    function testLine(line) {
      return /^\d{2}/.test(line) && RE_LINE.test(line);
    }
    __name(testLine, "testLine");
    function parseLine(line) {
      const groups = line.match(RE_LINE);
      if (groups === null) {
        return void 0;
      }
      const name = groups[5];
      if (name === "." || name === "..") {
        return void 0;
      }
      const file = new FileInfo_1.FileInfo(name);
      const fileType = groups[3];
      if (fileType === "<DIR>") {
        file.type = FileInfo_1.FileType.Directory;
        file.size = 0;
      } else {
        file.type = FileInfo_1.FileType.File;
        file.size = parseInt(groups[4], 10);
      }
      file.rawModifiedAt = groups[1] + " " + groups[2];
      return file;
    }
    __name(parseLine, "parseLine");
    function transformList(files) {
      return files;
    }
    __name(transformList, "transformList");
  }
});

// ../../node_modules/basic-ftp/dist/parseListUnix.js
var require_parseListUnix = __commonJS({
  "../../node_modules/basic-ftp/dist/parseListUnix.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.testLine = testLine;
    exports2.parseLine = parseLine;
    exports2.transformList = transformList;
    var FileInfo_1 = require_FileInfo();
    var JA_MONTH = "\u6708";
    var JA_DAY = "\u65E5";
    var JA_YEAR = "\u5E74";
    var RE_LINE = new RegExp("([bcdelfmpSs-])(((r|-)(w|-)([xsStTL-]))((r|-)(w|-)([xsStTL-]))((r|-)(w|-)([xsStTL-]?)))\\+?\\s*(\\d+)\\s+(?:(\\S+(?:\\s\\S+)*?)\\s+)?(?:(\\S+(?:\\s\\S+)*)\\s+)?(\\d+(?:,\\s*\\d+)?)\\s+((?:\\d+[-/]\\d+[-/]\\d+)|(?:\\S{3}\\s+\\d{1,2})|(?:\\d{1,2}\\s+\\S{3})|(?:\\d{1,2}" + JA_MONTH + "\\s+\\d{1,2}" + JA_DAY + "))\\s+((?:\\d+(?::\\d+)?)|(?:\\d{4}" + JA_YEAR + "))\\s(.*)");
    function testLine(line) {
      return RE_LINE.test(line);
    }
    __name(testLine, "testLine");
    function parseLine(line) {
      const groups = line.match(RE_LINE);
      if (groups === null) {
        return void 0;
      }
      const name = groups[21];
      if (name === "." || name === "..") {
        return void 0;
      }
      const file = new FileInfo_1.FileInfo(name);
      file.size = parseInt(groups[18], 10);
      file.user = groups[16];
      file.group = groups[17];
      file.hardLinkCount = parseInt(groups[15], 10);
      file.rawModifiedAt = groups[19] + " " + groups[20];
      file.permissions = {
        user: parseMode(groups[4], groups[5], groups[6]),
        group: parseMode(groups[8], groups[9], groups[10]),
        world: parseMode(groups[12], groups[13], groups[14])
      };
      switch (groups[1].charAt(0)) {
        case "d":
          file.type = FileInfo_1.FileType.Directory;
          break;
        case "e":
          file.type = FileInfo_1.FileType.SymbolicLink;
          break;
        case "l":
          file.type = FileInfo_1.FileType.SymbolicLink;
          break;
        case "b":
        case "c":
          file.type = FileInfo_1.FileType.File;
          break;
        case "f":
        case "-":
          file.type = FileInfo_1.FileType.File;
          break;
        default:
          file.type = FileInfo_1.FileType.Unknown;
      }
      if (file.isSymbolicLink) {
        const end = name.indexOf(" -> ");
        if (end !== -1) {
          file.name = name.substring(0, end);
          file.link = name.substring(end + 4);
        }
      }
      return file;
    }
    __name(parseLine, "parseLine");
    function transformList(files) {
      return files;
    }
    __name(transformList, "transformList");
    function parseMode(r32, w, x) {
      let value = 0;
      if (r32 !== "-") {
        value += FileInfo_1.FileInfo.UnixPermission.Read;
      }
      if (w !== "-") {
        value += FileInfo_1.FileInfo.UnixPermission.Write;
      }
      const execToken = x.charAt(0);
      if (execToken !== "-" && execToken.toUpperCase() !== execToken) {
        value += FileInfo_1.FileInfo.UnixPermission.Execute;
      }
      return value;
    }
    __name(parseMode, "parseMode");
  }
});

// ../../node_modules/basic-ftp/dist/parseListMLSD.js
var require_parseListMLSD = __commonJS({
  "../../node_modules/basic-ftp/dist/parseListMLSD.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.testLine = testLine;
    exports2.parseLine = parseLine;
    exports2.transformList = transformList;
    exports2.parseMLSxDate = parseMLSxDate;
    var FileInfo_1 = require_FileInfo();
    function parseSize(value, info2) {
      info2.size = parseInt(value, 10);
    }
    __name(parseSize, "parseSize");
    var factHandlersByName = {
      "size": parseSize,
      // File size
      "sizd": parseSize,
      // Directory size
      "unique": /* @__PURE__ */ __name((value, info2) => {
        info2.uniqueID = value;
      }, "unique"),
      "modify": /* @__PURE__ */ __name((value, info2) => {
        info2.modifiedAt = parseMLSxDate(value);
        info2.rawModifiedAt = info2.modifiedAt.toISOString();
      }, "modify"),
      "type": /* @__PURE__ */ __name((value, info2) => {
        if (value.startsWith("OS.unix=slink")) {
          info2.type = FileInfo_1.FileType.SymbolicLink;
          info2.link = value.substr(value.indexOf(":") + 1);
          return 1;
        }
        switch (value) {
          case "file":
            info2.type = FileInfo_1.FileType.File;
            break;
          case "dir":
            info2.type = FileInfo_1.FileType.Directory;
            break;
          case "OS.unix=symlink":
            info2.type = FileInfo_1.FileType.SymbolicLink;
            break;
          case "cdir":
          // Current directory being listed
          case "pdir":
            return 2;
          // Don't include these entries in the listing
          default:
            info2.type = FileInfo_1.FileType.Unknown;
        }
        return 1;
      }, "type"),
      "unix.mode": /* @__PURE__ */ __name((value, info2) => {
        const digits = value.substr(-3);
        info2.permissions = {
          user: parseInt(digits[0], 10),
          group: parseInt(digits[1], 10),
          world: parseInt(digits[2], 10)
        };
      }, "unix.mode"),
      "unix.ownername": /* @__PURE__ */ __name((value, info2) => {
        info2.user = value;
      }, "unix.ownername"),
      "unix.owner": /* @__PURE__ */ __name((value, info2) => {
        if (info2.user === void 0)
          info2.user = value;
      }, "unix.owner"),
      get "unix.uid"() {
        return this["unix.owner"];
      },
      "unix.groupname": /* @__PURE__ */ __name((value, info2) => {
        info2.group = value;
      }, "unix.groupname"),
      "unix.group": /* @__PURE__ */ __name((value, info2) => {
        if (info2.group === void 0)
          info2.group = value;
      }, "unix.group"),
      get "unix.gid"() {
        return this["unix.group"];
      }
      // Regarding the fact "perm":
      // We don't handle permission information stored in "perm" because its information is conceptually
      // different from what users of FTP clients usually associate with "permissions". Those that have
      // some expectations (and probably want to edit them with a SITE command) often unknowingly expect
      // the Unix permission system. The information passed by "perm" describes what FTP commands can be
      // executed with a file/directory. But even this can be either incomplete or just meant as a "guide"
      // as the spec mentions. From https://tools.ietf.org/html/rfc3659#section-7.5.5: "The permissions are
      // described here as they apply to FTP commands. They may not map easily into particular permissions
      // available on the server's operating system." The parser by Apache Commons tries to translate these
      // to Unix permissions – this is misleading users and might not even be correct.
    };
    function splitStringOnce(str, delimiter2) {
      const pos = str.indexOf(delimiter2);
      const a32 = str.substr(0, pos);
      const b32 = str.substr(pos + delimiter2.length);
      return [a32, b32];
    }
    __name(splitStringOnce, "splitStringOnce");
    function testLine(line) {
      return /^\S+=\S+;/.test(line) || line.startsWith(" ");
    }
    __name(testLine, "testLine");
    function parseLine(line) {
      const [packedFacts, name] = splitStringOnce(line, " ");
      if (name === "" || name === "." || name === "..") {
        return void 0;
      }
      const info2 = new FileInfo_1.FileInfo(name);
      const facts = packedFacts.split(";");
      for (const fact of facts) {
        const [factName, factValue] = splitStringOnce(fact, "=");
        if (!factValue) {
          continue;
        }
        const factHandler = factHandlersByName[factName.toLowerCase()];
        if (!factHandler) {
          continue;
        }
        const result2 = factHandler(factValue, info2);
        if (result2 === 2) {
          return void 0;
        }
      }
      return info2;
    }
    __name(parseLine, "parseLine");
    function transformList(files) {
      const nonLinksByID = /* @__PURE__ */ new Map();
      for (const file of files) {
        if (!file.isSymbolicLink && file.uniqueID !== void 0) {
          nonLinksByID.set(file.uniqueID, file);
        }
      }
      const resolvedFiles = [];
      for (const file of files) {
        if (file.isSymbolicLink && file.uniqueID !== void 0 && file.link === void 0) {
          const target = nonLinksByID.get(file.uniqueID);
          if (target !== void 0) {
            file.link = target.name;
          }
        }
        const isPartOfDirectory = !file.name.includes("/");
        if (isPartOfDirectory) {
          resolvedFiles.push(file);
        }
      }
      return resolvedFiles;
    }
    __name(transformList, "transformList");
    function parseMLSxDate(fact) {
      return new Date(Date.UTC(
        +fact.slice(0, 4),
        // Year
        +fact.slice(4, 6) - 1,
        // Month
        +fact.slice(6, 8),
        // Date
        +fact.slice(8, 10),
        // Hours
        +fact.slice(10, 12),
        // Minutes
        +fact.slice(12, 14),
        // Seconds
        +fact.slice(15, 18)
        // Milliseconds
      ));
    }
    __name(parseMLSxDate, "parseMLSxDate");
  }
});

// ../../node_modules/basic-ftp/dist/parseList.js
var require_parseList = __commonJS({
  "../../node_modules/basic-ftp/dist/parseList.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __setModuleDefault2 = exports2 && exports2.__setModuleDefault || (Object.create ? (function(o10, v) {
      Object.defineProperty(o10, "default", { enumerable: true, value: v });
    }) : function(o10, v) {
      o10["default"] = v;
    });
    var __importStar2 = exports2 && exports2.__importStar || /* @__PURE__ */ (function() {
      var ownKeys2 = /* @__PURE__ */ __name(function(o10) {
        ownKeys2 = Object.getOwnPropertyNames || function(o11) {
          var ar = [];
          for (var k32 in o11) if (Object.prototype.hasOwnProperty.call(o11, k32)) ar[ar.length] = k32;
          return ar;
        };
        return ownKeys2(o10);
      }, "ownKeys");
      return function(mod) {
        if (mod && mod.__esModule) return mod;
        var result2 = {};
        if (mod != null) {
          for (var k32 = ownKeys2(mod), i32 = 0; i32 < k32.length; i32++) if (k32[i32] !== "default") __createBinding3(result2, mod, k32[i32]);
        }
        __setModuleDefault2(result2, mod);
        return result2;
      };
    })();
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.parseList = parseList;
    var dosParser = __importStar2(require_parseListDOS());
    var unixParser = __importStar2(require_parseListUnix());
    var mlsdParser = __importStar2(require_parseListMLSD());
    var availableParsers = [
      dosParser,
      unixParser,
      mlsdParser
      // Keep MLSD last, may accept filename only
    ];
    function firstCompatibleParser(line, parsers) {
      return parsers.find((parser) => parser.testLine(line) === true);
    }
    __name(firstCompatibleParser, "firstCompatibleParser");
    function isNotBlank(str) {
      return str.trim() !== "";
    }
    __name(isNotBlank, "isNotBlank");
    function isNotMeta(str) {
      return !str.startsWith("total");
    }
    __name(isNotMeta, "isNotMeta");
    var REGEX_NEWLINE = /\r?\n/;
    function parseList(rawList) {
      const lines = rawList.split(REGEX_NEWLINE).filter(isNotBlank).filter(isNotMeta);
      if (lines.length === 0) {
        return [];
      }
      const testLine = lines[lines.length - 1];
      const parser = firstCompatibleParser(testLine, availableParsers);
      if (!parser) {
        throw new Error("This library only supports MLSD, Unix- or DOS-style directory listing. Your FTP server seems to be using another format. You can see the transmitted listing when setting `client.ftp.verbose = true`. You can then provide a custom parser to `client.parseList`, see the documentation for details.");
      }
      const files = lines.map(parser.parseLine).filter((info2) => info2 !== void 0);
      return parser.transformList(files);
    }
    __name(parseList, "parseList");
  }
});

// ../../node_modules/basic-ftp/dist/ProgressTracker.js
var require_ProgressTracker = __commonJS({
  "../../node_modules/basic-ftp/dist/ProgressTracker.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ProgressTracker = void 0;
    var ProgressTracker = class {
      static {
        __name(this, "ProgressTracker");
      }
      constructor() {
        this.bytesOverall = 0;
        this.intervalMs = 500;
        this.onStop = noop;
        this.onHandle = noop;
      }
      /**
       * Register a new handler for progress info. Use `undefined` to disable reporting.
       */
      reportTo(onHandle = noop) {
        this.onHandle = onHandle;
      }
      /**
       * Start tracking transfer progress of a socket.
       *
       * @param socket  The socket to observe.
       * @param name  A name associated with this progress tracking, e.g. a filename.
       * @param type  The type of the transfer, typically "upload" or "download".
       */
      start(socket, name, type) {
        let lastBytes = 0;
        this.onStop = poll(this.intervalMs, () => {
          const bytes = socket.bytesRead + socket.bytesWritten;
          this.bytesOverall += bytes - lastBytes;
          lastBytes = bytes;
          this.onHandle({
            name,
            type,
            bytes,
            bytesOverall: this.bytesOverall
          });
        });
      }
      /**
       * Stop tracking transfer progress.
       */
      stop() {
        this.onStop(false);
      }
      /**
       * Call the progress handler one more time, then stop tracking.
       */
      updateAndStop() {
        this.onStop(true);
      }
    };
    exports2.ProgressTracker = ProgressTracker;
    function poll(intervalMs, updateFunc) {
      const id = setInterval(updateFunc, intervalMs);
      const stopFunc = /* @__PURE__ */ __name((stopWithUpdate) => {
        clearInterval(id);
        if (stopWithUpdate) {
          updateFunc();
        }
        updateFunc = noop;
      }, "stopFunc");
      updateFunc();
      return stopFunc;
    }
    __name(poll, "poll");
    function noop() {
    }
    __name(noop, "noop");
  }
});

// ../../node_modules/basic-ftp/dist/StringWriter.js
var require_StringWriter = __commonJS({
  "../../node_modules/basic-ftp/dist/StringWriter.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.StringWriter = void 0;
    var stream_1 = require("stream");
    var StringWriter = class extends stream_1.Writable {
      static {
        __name(this, "StringWriter");
      }
      constructor(maxByteLength = 1 * 1024 * 1024) {
        super();
        this.maxByteLength = maxByteLength;
        this.byteLength = 0;
        this.bufs = [];
      }
      _write(chunk, _, callback) {
        if (!(chunk instanceof Buffer)) {
          callback(new Error("StringWriter: expects chunks of type 'Buffer'."));
          return;
        }
        if (this.byteLength + chunk.byteLength > this.maxByteLength) {
          callback(new Error(`StringWriter: Maximum bytes exceeded, maxByteLength=${this.maxByteLength}.`));
          return;
        }
        this.byteLength += chunk.byteLength;
        this.bufs.push(chunk);
        callback(null);
      }
      getText(encoding) {
        return Buffer.concat(this.bufs).toString(encoding);
      }
    };
    exports2.StringWriter = StringWriter;
  }
});

// ../../node_modules/basic-ftp/dist/transfer.js
var require_transfer = __commonJS({
  "../../node_modules/basic-ftp/dist/transfer.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.enterPassiveModeIPv6 = enterPassiveModeIPv6;
    exports2.parseEpsvResponse = parseEpsvResponse;
    exports2.enterPassiveModeIPv4 = enterPassiveModeIPv4;
    exports2.enterPassiveModeIPv4_forceControlHostIP = enterPassiveModeIPv4_forceControlHostIP;
    exports2.parsePasvResponse = parsePasvResponse;
    exports2.connectForPassiveTransfer = connectForPassiveTransfer;
    exports2.uploadFrom = uploadFrom;
    exports2.downloadTo = downloadTo;
    var netUtils_1 = require_netUtils();
    var stream_1 = require("stream");
    var tls_1 = require("tls");
    var parseControlResponse_1 = require_parseControlResponse();
    async function enterPassiveModeIPv6(ftp) {
      const res = await ftp.request("EPSV");
      const port = parseEpsvResponse(res.message);
      if (!port) {
        throw new Error("Can't parse EPSV response: " + res.message);
      }
      const controlHost = ftp.socket.remoteAddress;
      if (controlHost === void 0) {
        throw new Error("Control socket is disconnected, can't get remote address.");
      }
      await connectForPassiveTransfer(controlHost, port, ftp);
      return res;
    }
    __name(enterPassiveModeIPv6, "enterPassiveModeIPv6");
    function parseEpsvResponse(message2) {
      const groups = message2.match(/[|!]{3}(.+)[|!]/);
      if (groups === null || groups[1] === void 0) {
        throw new Error(`Can't parse response to 'EPSV': ${message2}`);
      }
      const port = parseInt(groups[1], 10);
      if (Number.isNaN(port)) {
        throw new Error(`Can't parse response to 'EPSV', port is not a number: ${message2}`);
      }
      return port;
    }
    __name(parseEpsvResponse, "parseEpsvResponse");
    async function enterPassiveModeIPv4(ftp) {
      const res = await ftp.request("PASV");
      const target = parsePasvResponse(res.message);
      if (!target) {
        throw new Error("Can't parse PASV response: " + res.message);
      }
      const controlHost = ftp.socket.remoteAddress;
      if ((0, netUtils_1.ipIsPrivateV4Address)(target.host) && controlHost && !(0, netUtils_1.ipIsPrivateV4Address)(controlHost)) {
        target.host = controlHost;
      }
      await connectForPassiveTransfer(target.host, target.port, ftp);
      return res;
    }
    __name(enterPassiveModeIPv4, "enterPassiveModeIPv4");
    async function enterPassiveModeIPv4_forceControlHostIP(ftp) {
      const res = await ftp.request("PASV");
      const target = parsePasvResponse(res.message);
      if (!target) {
        throw new Error("Can't parse PASV response: " + res.message);
      }
      const controlHost = ftp.socket.remoteAddress;
      if (controlHost === void 0) {
        throw new Error("Control socket is disconnected, can't get remote address.");
      }
      await connectForPassiveTransfer(controlHost, target.port, ftp);
      return res;
    }
    __name(enterPassiveModeIPv4_forceControlHostIP, "enterPassiveModeIPv4_forceControlHostIP");
    function parsePasvResponse(message2) {
      const groups = message2.match(/([-\d]+,[-\d]+,[-\d]+,[-\d]+),([-\d]+),([-\d]+)/);
      if (groups === null || groups.length !== 4) {
        throw new Error(`Can't parse response to 'PASV': ${message2}`);
      }
      return {
        host: groups[1].replace(/,/g, "."),
        port: (parseInt(groups[2], 10) & 255) * 256 + (parseInt(groups[3], 10) & 255)
      };
    }
    __name(parsePasvResponse, "parsePasvResponse");
    function connectForPassiveTransfer(host, port, ftp) {
      return new Promise((resolve13, reject) => {
        let socket = ftp._newSocket();
        const handleConnErr = /* @__PURE__ */ __name(function(err) {
          err.message = "Can't open data connection in passive mode: " + err.message;
          reject(err);
        }, "handleConnErr");
        const handleTimeout = /* @__PURE__ */ __name(function() {
          socket.destroy();
          reject(new Error(`Timeout when trying to open data connection to ${host}:${port}`));
        }, "handleTimeout");
        socket.setTimeout(ftp.timeout);
        socket.on("error", handleConnErr);
        socket.on("timeout", handleTimeout);
        socket.connect({ port, host, family: ftp.ipFamily }, () => {
          if (ftp.socket instanceof tls_1.TLSSocket) {
            socket = (0, tls_1.connect)(Object.assign({}, ftp.tlsOptions, {
              socket,
              // Reuse the TLS session negotiated earlier when the control connection
              // was upgraded. Servers expect this because it provides additional
              // security: If a completely new session would be negotiated, a hacker
              // could guess the port and connect to the new data connection before we do
              // by just starting his/her own TLS session.
              session: ftp.socket.getSession()
            }));
          }
          socket.removeListener("error", handleConnErr);
          socket.removeListener("timeout", handleTimeout);
          ftp.dataSocket = socket;
          resolve13();
        });
      });
    }
    __name(connectForPassiveTransfer, "connectForPassiveTransfer");
    var TransferResolver = class {
      static {
        __name(this, "TransferResolver");
      }
      /**
       * Instantiate a TransferResolver
       */
      constructor(ftp, progress) {
        this.ftp = ftp;
        this.progress = progress;
        this.response = void 0;
        this.dataTransferDone = false;
      }
      /**
       * Mark the beginning of a transfer.
       *
       * @param name - Name of the transfer, usually the filename.
       * @param type - Type of transfer, usually "upload" or "download".
       */
      onDataStart(name, type) {
        if (this.ftp.dataSocket === void 0) {
          throw new Error("Data transfer should start but there is no data connection.");
        }
        this.ftp.socket.setTimeout(0);
        this.ftp.dataSocket.setTimeout(this.ftp.timeout);
        this.progress.start(this.ftp.dataSocket, name, type);
      }
      /**
       * The data connection has finished the transfer.
       */
      onDataDone(task) {
        this.progress.updateAndStop();
        this.ftp.socket.setTimeout(this.ftp.timeout);
        if (this.ftp.dataSocket) {
          this.ftp.dataSocket.setTimeout(0);
        }
        this.dataTransferDone = true;
        this.tryResolve(task);
      }
      /**
       * The control connection reports the transfer as finished.
       */
      onControlDone(task, response) {
        this.response = response;
        this.tryResolve(task);
      }
      /**
       * An error has been reported and the task should be rejected.
       */
      onError(task, err) {
        this.progress.updateAndStop();
        this.ftp.socket.setTimeout(this.ftp.timeout);
        this.ftp.dataSocket = void 0;
        task.reject(err);
      }
      /**
       * Control connection sent an unexpected request requiring a response from our part. We
       * can't provide that (because unknown) and have to close the contrext with an error because
       * the FTP server is now caught up in a state we can't resolve.
       */
      onUnexpectedRequest(response) {
        const err = new Error(`Unexpected FTP response is requesting an answer: ${response.message}`);
        this.ftp.closeWithError(err);
      }
      tryResolve(task) {
        const canResolve = this.dataTransferDone && this.response !== void 0;
        if (canResolve) {
          this.ftp.dataSocket = void 0;
          task.resolve(this.response);
        }
      }
    };
    function uploadFrom(source, config2) {
      const resolver = new TransferResolver(config2.ftp, config2.tracker);
      const fullCommand = `${config2.command} ${config2.remotePath}`;
      return config2.ftp.handle(fullCommand, (res, task) => {
        if (res instanceof Error) {
          resolver.onError(task, res);
        } else if (res.code === 150 || res.code === 125) {
          const dataSocket = config2.ftp.dataSocket;
          if (!dataSocket) {
            resolver.onError(task, new Error("Upload should begin but no data connection is available."));
            return;
          }
          const canUpload = "getCipher" in dataSocket ? dataSocket.getCipher() !== void 0 : true;
          onConditionOrEvent(canUpload, dataSocket, "secureConnect", () => {
            config2.ftp.log(`Uploading to ${(0, netUtils_1.describeAddress)(dataSocket)} (${(0, netUtils_1.describeTLS)(dataSocket)})`);
            resolver.onDataStart(config2.remotePath, config2.type);
            (0, stream_1.pipeline)(source, dataSocket, (err) => {
              if (err) {
                resolver.onError(task, err);
              } else {
                resolver.onDataDone(task);
              }
            });
          });
        } else if ((0, parseControlResponse_1.positiveCompletion)(res.code)) {
          resolver.onControlDone(task, res);
        } else if ((0, parseControlResponse_1.positiveIntermediate)(res.code)) {
          resolver.onUnexpectedRequest(res);
        }
      });
    }
    __name(uploadFrom, "uploadFrom");
    function downloadTo(destination, config2) {
      if (!config2.ftp.dataSocket) {
        throw new Error("Download will be initiated but no data connection is available.");
      }
      const resolver = new TransferResolver(config2.ftp, config2.tracker);
      return config2.ftp.handle(config2.command, (res, task) => {
        if (res instanceof Error) {
          resolver.onError(task, res);
        } else if (res.code === 150 || res.code === 125) {
          const dataSocket = config2.ftp.dataSocket;
          if (!dataSocket) {
            resolver.onError(task, new Error("Download should begin but no data connection is available."));
            return;
          }
          config2.ftp.log(`Downloading from ${(0, netUtils_1.describeAddress)(dataSocket)} (${(0, netUtils_1.describeTLS)(dataSocket)})`);
          resolver.onDataStart(config2.remotePath, config2.type);
          (0, stream_1.pipeline)(dataSocket, destination, (err) => {
            if (err) {
              resolver.onError(task, err);
            } else {
              resolver.onDataDone(task);
            }
          });
        } else if (res.code === 350) {
          config2.ftp.send("RETR " + config2.remotePath);
        } else if ((0, parseControlResponse_1.positiveCompletion)(res.code)) {
          resolver.onControlDone(task, res);
        } else if ((0, parseControlResponse_1.positiveIntermediate)(res.code)) {
          resolver.onUnexpectedRequest(res);
        }
      });
    }
    __name(downloadTo, "downloadTo");
    function onConditionOrEvent(condition, emitter, eventName, action) {
      if (condition === true) {
        action();
      } else {
        emitter.once(eventName, () => action());
      }
    }
    __name(onConditionOrEvent, "onConditionOrEvent");
  }
});

// ../../node_modules/basic-ftp/dist/Client.js
var require_Client = __commonJS({
  "../../node_modules/basic-ftp/dist/Client.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.Client = void 0;
    var fs_1 = require("fs");
    var path_1 = require("path");
    var tls_1 = require("tls");
    var util_1 = require("util");
    var FtpContext_1 = require_FtpContext();
    var netUtils_1 = require_netUtils();
    var parseControlResponse_1 = require_parseControlResponse();
    var parseList_1 = require_parseList();
    var parseListMLSD_1 = require_parseListMLSD();
    var ProgressTracker_1 = require_ProgressTracker();
    var StringWriter_1 = require_StringWriter();
    var transfer_1 = require_transfer();
    var fsReadDir = (0, util_1.promisify)(fs_1.readdir);
    var fsMkDir = (0, util_1.promisify)(fs_1.mkdir);
    var fsStat = (0, util_1.promisify)(fs_1.stat);
    var fsOpen = (0, util_1.promisify)(fs_1.open);
    var fsClose = (0, util_1.promisify)(fs_1.close);
    var fsUnlink = (0, util_1.promisify)(fs_1.unlink);
    var defaultClientOptions = {
      allowSeparateTransferHost: true,
      maxListingBytes: 40 * 1024 * 1024
    };
    var LIST_COMMANDS_DEFAULT = /* @__PURE__ */ __name(() => ["LIST -a", "LIST"], "LIST_COMMANDS_DEFAULT");
    var LIST_COMMANDS_MLSD = /* @__PURE__ */ __name(() => ["MLSD", "LIST -a", "LIST"], "LIST_COMMANDS_MLSD");
    var Client3 = class {
      static {
        __name(this, "Client");
      }
      /**
       * Instantiate an FTP client.
       *
       * @param timeout  Timeout in milliseconds, use 0 for no timeout. Optional, default is 30 seconds.
       */
      constructor(timeout = 3e4, userOptions = defaultClientOptions) {
        this.availableListCommands = LIST_COMMANDS_DEFAULT();
        const options = { ...defaultClientOptions, ...userOptions };
        this.ftp = new FtpContext_1.FTPContext(timeout);
        this.prepareTransfer = this._enterFirstCompatibleMode([
          transfer_1.enterPassiveModeIPv6,
          options.allowSeparateTransferHost ? transfer_1.enterPassiveModeIPv4 : transfer_1.enterPassiveModeIPv4_forceControlHostIP
        ]);
        this.options = options;
        this.parseList = parseList_1.parseList;
        this._progressTracker = new ProgressTracker_1.ProgressTracker();
      }
      /**
       * Close the client and all open socket connections.
       *
       * Close the client and all open socket connections. The client can’t be used anymore after calling this method,
       * you have to either reconnect with `access` or `connect` or instantiate a new instance to continue any work.
       * A client is also closed automatically if any timeout or connection error occurs.
       */
      close() {
        this.ftp.close();
        this._progressTracker.stop();
      }
      /**
       * Returns true if the client is closed and can't be used anymore.
       */
      get closed() {
        return this.ftp.closed;
      }
      /**
       * Connect (or reconnect) to an FTP server.
       *
       * This is an instance method and thus can be called multiple times during the lifecycle of a `Client`
       * instance. Whenever you do, the client is reset with a new control connection. This also implies that
       * you can reopen a `Client` instance that has been closed due to an error when reconnecting with this
       * method. In fact, reconnecting is the only way to continue using a closed `Client`.
       *
       * @param host  Host the client should connect to. Optional, default is "localhost".
       * @param port  Port the client should connect to. Optional, default is 21.
       */
      connect(host = "localhost", port = 21) {
        this.ftp.reset();
        this.ftp.socket.connect({
          host,
          port,
          family: this.ftp.ipFamily
        }, () => this.ftp.log(`Connected to ${(0, netUtils_1.describeAddress)(this.ftp.socket)} (${(0, netUtils_1.describeTLS)(this.ftp.socket)})`));
        return this._handleConnectResponse();
      }
      /**
       * As `connect` but using implicit TLS. Implicit TLS is not an FTP standard and has been replaced by
       * explicit TLS. There are still FTP servers that support only implicit TLS, though.
       */
      connectImplicitTLS(host = "localhost", port = 21, tlsOptions = {}) {
        this.ftp.reset();
        this.ftp.socket = (0, tls_1.connect)(port, host, tlsOptions, () => this.ftp.log(`Connected to ${(0, netUtils_1.describeAddress)(this.ftp.socket)} (${(0, netUtils_1.describeTLS)(this.ftp.socket)})`));
        this.ftp.tlsOptions = tlsOptions;
        return this._handleConnectResponse();
      }
      /**
       * Handles the first reponse by an FTP server after the socket connection has been established.
       */
      _handleConnectResponse() {
        return this.ftp.handle(void 0, (res, task) => {
          if (res instanceof Error) {
            task.reject(res);
          } else if ((0, parseControlResponse_1.positiveCompletion)(res.code)) {
            task.resolve(res);
          } else {
            task.reject(new FtpContext_1.FTPError(res));
          }
        });
      }
      /**
       * Send an FTP command and handle the first response.
       */
      send(command, ignoreErrorCodesDEPRECATED = false) {
        if (ignoreErrorCodesDEPRECATED) {
          this.ftp.log("Deprecated call using send(command, flag) with boolean flag to ignore errors. Use sendIgnoringError(command).");
          return this.sendIgnoringError(command);
        }
        return this.ftp.request(command);
      }
      /**
       * Send an FTP command and ignore an FTP error response. Any other kind of error or timeout will still reject the Promise.
       *
       * @param command
       */
      sendIgnoringError(command) {
        return this.ftp.handle(command, (res, task) => {
          if (res instanceof FtpContext_1.FTPError) {
            task.resolve({ code: res.code, message: res.message });
          } else if (res instanceof Error) {
            task.reject(res);
          } else {
            task.resolve(res);
          }
        });
      }
      /**
       * Upgrade the current socket connection to TLS.
       *
       * @param options  TLS options as in `tls.connect(options)`, optional.
       * @param command  Set the authentication command. Optional, default is "AUTH TLS".
       */
      async useTLS(options = {}, command = "AUTH TLS") {
        const ret = await this.send(command);
        this.ftp.socket = await (0, netUtils_1.upgradeSocket)(this.ftp.socket, options);
        this.ftp.tlsOptions = options;
        this.ftp.log(`Control socket is using: ${(0, netUtils_1.describeTLS)(this.ftp.socket)}`);
        return ret;
      }
      /**
       * Login a user with a password.
       *
       * @param user  Username to use for login. Optional, default is "anonymous".
       * @param password  Password to use for login. Optional, default is "guest".
       */
      login(user = "anonymous", password = "guest") {
        this.ftp.log(`Login security: ${(0, netUtils_1.describeTLS)(this.ftp.socket)}`);
        return this.ftp.handle("USER " + user, (res, task) => {
          if (res instanceof Error) {
            task.reject(res);
          } else if ((0, parseControlResponse_1.positiveCompletion)(res.code)) {
            task.resolve(res);
          } else if (res.code === 331) {
            this.ftp.send("PASS " + password);
          } else {
            task.reject(new FtpContext_1.FTPError(res));
          }
        });
      }
      /**
       * Set the usual default settings.
       *
       * Settings used:
       * * Binary mode (TYPE I)
       * * File structure (STRU F)
       * * Additional settings for FTPS (PBSZ 0, PROT P)
       */
      async useDefaultSettings() {
        const features = await this.features();
        const supportsMLSD = features.has("MLST");
        this.availableListCommands = supportsMLSD ? LIST_COMMANDS_MLSD() : LIST_COMMANDS_DEFAULT();
        await this.send("TYPE I");
        await this.sendIgnoringError("STRU F");
        await this.sendIgnoringError("OPTS UTF8 ON");
        if (supportsMLSD) {
          await this.sendIgnoringError("OPTS MLST type;size;modify;unique;unix.mode;unix.owner;unix.group;unix.ownername;unix.groupname;");
        }
        if (this.ftp.hasTLS) {
          await this.sendIgnoringError("PBSZ 0");
          await this.sendIgnoringError("PROT P");
        }
      }
      /**
       * Convenience method that calls `connect`, `useTLS`, `login` and `useDefaultSettings`.
       *
       * This is an instance method and thus can be called multiple times during the lifecycle of a `Client`
       * instance. Whenever you do, the client is reset with a new control connection. This also implies that
       * you can reopen a `Client` instance that has been closed due to an error when reconnecting with this
       * method. In fact, reconnecting is the only way to continue using a closed `Client`.
       */
      async access(options = {}) {
        var _a10, _b;
        const useExplicitTLS = options.secure === true;
        const useImplicitTLS = options.secure === "implicit";
        let welcome;
        if (useImplicitTLS) {
          welcome = await this.connectImplicitTLS(options.host, options.port, options.secureOptions);
        } else {
          welcome = await this.connect(options.host, options.port);
        }
        if (useExplicitTLS) {
          const secureOptions = (_a10 = options.secureOptions) !== null && _a10 !== void 0 ? _a10 : {};
          secureOptions.host = (_b = secureOptions.host) !== null && _b !== void 0 ? _b : options.host;
          await this.useTLS(secureOptions);
        }
        await this.sendIgnoringError("OPTS UTF8 ON");
        await this.login(options.user, options.password);
        await this.useDefaultSettings();
        return welcome;
      }
      /**
       * Get the current working directory.
       */
      async pwd() {
        const res = await this.send("PWD");
        const parsed = res.message.match(/"(.+)"/);
        if (parsed === null || parsed[1] === void 0) {
          throw new Error(`Can't parse response to command 'PWD': ${res.message}`);
        }
        return parsed[1];
      }
      /**
       * Get a description of supported features.
       *
       * This sends the FEAT command and parses the result into a Map where keys correspond to available commands
       * and values hold further information. Be aware that your FTP servers might not support this
       * command in which case this method will not throw an exception but just return an empty Map.
       */
      async features() {
        const res = await this.sendIgnoringError("FEAT");
        const features = /* @__PURE__ */ new Map();
        if (res.code < 400 && (0, parseControlResponse_1.isMultiline)(res.message)) {
          res.message.split("\n").slice(1, -1).forEach((line) => {
            const entry = line.trim().split(" ");
            features.set(entry[0], entry[1] || "");
          });
        }
        return features;
      }
      /**
       * Set the working directory.
       */
      async cd(path47) {
        const validPath = await this.protectWhitespace(path47);
        return this.send("CWD " + validPath);
      }
      /**
       * Switch to the parent directory of the working directory.
       */
      async cdup() {
        return this.send("CDUP");
      }
      /**
       * Get the last modified time of a file. This is not supported by every FTP server, in which case
       * calling this method will throw an exception.
       */
      async lastMod(path47) {
        const validPath = await this.protectWhitespace(path47);
        const res = await this.send(`MDTM ${validPath}`);
        const date7 = res.message.slice(4);
        return (0, parseListMLSD_1.parseMLSxDate)(date7);
      }
      /**
       * Get the size of a file.
       */
      async size(path47) {
        const validPath = await this.protectWhitespace(path47);
        const command = `SIZE ${validPath}`;
        const res = await this.send(command);
        const size = parseInt(res.message.slice(4), 10);
        if (Number.isNaN(size)) {
          throw new Error(`Can't parse response to command '${command}' as a numerical value: ${res.message}`);
        }
        return size;
      }
      /**
       * Rename a file.
       *
       * Depending on the FTP server this might also be used to move a file from one
       * directory to another by providing full paths.
       */
      async rename(srcPath, destPath) {
        const validSrc = await this.protectWhitespace(srcPath);
        const validDest = await this.protectWhitespace(destPath);
        await this.send("RNFR " + validSrc);
        return this.send("RNTO " + validDest);
      }
      /**
       * Remove a file from the current working directory.
       *
       * You can ignore FTP error return codes which won't throw an exception if e.g.
       * the file doesn't exist.
       */
      async remove(path47, ignoreErrorCodes = false) {
        const validPath = await this.protectWhitespace(path47);
        if (ignoreErrorCodes) {
          return this.sendIgnoringError(`DELE ${validPath}`);
        }
        return this.send(`DELE ${validPath}`);
      }
      /**
       * Report transfer progress for any upload or download to a given handler.
       *
       * This will also reset the overall transfer counter that can be used for multiple transfers. You can
       * also call the function without a handler to stop reporting to an earlier one.
       *
       * @param handler  Handler function to call on transfer progress.
       */
      trackProgress(handler) {
        this._progressTracker.bytesOverall = 0;
        this._progressTracker.reportTo(handler);
      }
      /**
       * Upload data from a readable stream or a local file to a remote file.
       *
       * @param source  Readable stream or path to a local file.
       * @param toRemotePath  Path to a remote file to write to.
       */
      async uploadFrom(source, toRemotePath, options = {}) {
        return this._uploadWithCommand(source, toRemotePath, "STOR", options);
      }
      /**
       * Upload data from a readable stream or a local file by appending it to an existing file. If the file doesn't
       * exist the FTP server should create it.
       *
       * @param source  Readable stream or path to a local file.
       * @param toRemotePath  Path to a remote file to write to.
       */
      async appendFrom(source, toRemotePath, options = {}) {
        return this._uploadWithCommand(source, toRemotePath, "APPE", options);
      }
      /**
       * @protected
       */
      async _uploadWithCommand(source, remotePath, command, options) {
        if (typeof source === "string") {
          return this._uploadLocalFile(source, remotePath, command, options);
        }
        return this._uploadFromStream(source, remotePath, command);
      }
      /**
       * @protected
       */
      async _uploadLocalFile(localPath, remotePath, command, options) {
        const fd = await fsOpen(localPath, "r");
        const source = (0, fs_1.createReadStream)("", {
          fd,
          start: options.localStart,
          end: options.localEndInclusive,
          autoClose: false
        });
        try {
          return await this._uploadFromStream(source, remotePath, command);
        } finally {
          await ignoreError(() => fsClose(fd));
        }
      }
      /**
       * @protected
       */
      async _uploadFromStream(source, remotePath, command) {
        const onError = /* @__PURE__ */ __name((err) => this.ftp.closeWithError(err), "onError");
        source.once("error", onError);
        try {
          const validPath = await this.protectWhitespace(remotePath);
          await this.prepareTransfer(this.ftp);
          return await (0, transfer_1.uploadFrom)(source, {
            ftp: this.ftp,
            tracker: this._progressTracker,
            command,
            remotePath: validPath,
            type: "upload"
          });
        } finally {
          source.removeListener("error", onError);
        }
      }
      /**
       * Download a remote file and pipe its data to a writable stream or to a local file.
       *
       * You can optionally define at which position of the remote file you'd like to start
       * downloading. If the destination you provide is a file, the offset will be applied
       * to it as well. For example: To resume a failed download, you'd request the size of
       * the local, partially downloaded file and use that as the offset. Assuming the size
       * is 23, you'd download the rest using `downloadTo("local.txt", "remote.txt", 23)`.
       *
       * @param destination  Stream or path for a local file to write to.
       * @param fromRemotePath  Path of the remote file to read from.
       * @param startAt  Position within the remote file to start downloading at. If the destination is a file, this offset is also applied to it.
       */
      async downloadTo(destination, fromRemotePath, startAt = 0) {
        if (typeof destination === "string") {
          return this._downloadToFile(destination, fromRemotePath, startAt);
        }
        return this._downloadToStream(destination, fromRemotePath, startAt);
      }
      /**
       * @protected
       */
      async _downloadToFile(localPath, remotePath, startAt) {
        const appendingToLocalFile = startAt > 0;
        const fileSystemFlags = appendingToLocalFile ? "r+" : "w";
        const fd = await fsOpen(localPath, fileSystemFlags);
        const destination = (0, fs_1.createWriteStream)("", {
          fd,
          start: startAt,
          autoClose: false
        });
        try {
          return await this._downloadToStream(destination, remotePath, startAt);
        } catch (err) {
          const localFileStats = await ignoreError(() => fsStat(localPath));
          const hasDownloadedData = localFileStats && localFileStats.size > 0;
          const shouldRemoveLocalFile = !appendingToLocalFile && !hasDownloadedData;
          if (shouldRemoveLocalFile) {
            await ignoreError(() => fsUnlink(localPath));
          }
          throw err;
        } finally {
          await ignoreError(() => fsClose(fd));
        }
      }
      /**
       * @protected
       */
      async _downloadToStream(destination, remotePath, startAt) {
        const onError = /* @__PURE__ */ __name((err) => this.ftp.closeWithError(err), "onError");
        destination.once("error", onError);
        try {
          const validPath = await this.protectWhitespace(remotePath);
          await this.prepareTransfer(this.ftp);
          return await (0, transfer_1.downloadTo)(destination, {
            ftp: this.ftp,
            tracker: this._progressTracker,
            command: startAt > 0 ? `REST ${startAt}` : `RETR ${validPath}`,
            remotePath: validPath,
            type: "download"
          });
        } finally {
          destination.removeListener("error", onError);
          destination.end();
        }
      }
      /**
       * List files and directories in the current working directory, or from `path` if specified.
       *
       * @param [path]  Path to remote file or directory.
       */
      async list(path47 = "") {
        const validPath = await this.protectWhitespace(path47);
        let lastError;
        for (const candidate of this.availableListCommands) {
          const command = validPath === "" ? candidate : `${candidate} ${validPath}`;
          await this.prepareTransfer(this.ftp);
          try {
            const parsedList = await this._requestListWithCommand(command);
            this.availableListCommands = [candidate];
            return parsedList;
          } catch (err) {
            const shouldTryNext = err instanceof FtpContext_1.FTPError;
            if (!shouldTryNext) {
              throw err;
            }
            lastError = err;
          }
        }
        throw lastError;
      }
      /**
       * @protected
       */
      async _requestListWithCommand(command) {
        const buffer = new StringWriter_1.StringWriter(this.options.maxListingBytes);
        await (0, transfer_1.downloadTo)(buffer, {
          ftp: this.ftp,
          tracker: this._progressTracker,
          command,
          remotePath: "",
          type: "list"
        });
        const text = buffer.getText(this.ftp.encoding);
        this.ftp.log(text);
        return this.parseList(text);
      }
      /**
       * Remove a directory and all of its content.
       *
       * @param remoteDirPath  The path of the remote directory to delete.
       * @example client.removeDir("foo") // Remove directory 'foo' using a relative path.
       * @example client.removeDir("foo/bar") // Remove directory 'bar' using a relative path.
       * @example client.removeDir("/foo/bar") // Remove directory 'bar' using an absolute path.
       * @example client.removeDir("/") // Remove everything.
       */
      async removeDir(remoteDirPath) {
        return this._exitAtCurrentDirectory(async () => {
          await this.cd(remoteDirPath);
          const absoluteDirPath = await this.pwd();
          await this.clearWorkingDir();
          const dirIsRoot = absoluteDirPath === "/";
          if (!dirIsRoot) {
            await this.cdup();
            await this.removeEmptyDir(absoluteDirPath);
          }
        });
      }
      /**
       * Remove all files and directories in the working directory without removing
       * the working directory itself.
       */
      async clearWorkingDir() {
        for (const file of await this.list()) {
          if (file.isDirectory) {
            await this.cd(file.name);
            await this.clearWorkingDir();
            await this.cdup();
            await this.removeEmptyDir(file.name);
          } else {
            await this.remove(file.name);
          }
        }
      }
      /**
       * Upload the contents of a local directory to the remote working directory.
       *
       * This will overwrite existing files with the same names and reuse existing directories.
       * Unrelated files and directories will remain untouched. You can optionally provide a `remoteDirPath`
       * to put the contents inside a directory which will be created if necessary including all
       * intermediate directories. If you did provide a remoteDirPath the working directory will stay
       * the same as before calling this method.
       *
       * @param localDirPath  Local path, e.g. "foo/bar" or "../test"
       * @param [remoteDirPath]  Remote path of a directory to upload to. Working directory if undefined.
       */
      async uploadFromDir(localDirPath, remoteDirPath) {
        return this._exitAtCurrentDirectory(async () => {
          if (remoteDirPath) {
            await this.ensureDir(remoteDirPath);
          }
          return await this._uploadToWorkingDir(localDirPath);
        });
      }
      /**
       * @protected
       */
      async _uploadToWorkingDir(localDirPath) {
        const files = await fsReadDir(localDirPath);
        for (const file of files) {
          const fullPath = (0, path_1.join)(localDirPath, file);
          const stats = await fsStat(fullPath);
          if (stats.isFile()) {
            await this.uploadFrom(fullPath, file);
          } else if (stats.isDirectory()) {
            await this._openDir(file);
            await this._uploadToWorkingDir(fullPath);
            await this.cdup();
          }
        }
      }
      /**
       * Download all files and directories of the working directory to a local directory.
       *
       * @param localDirPath  The local directory to download to.
       * @param remoteDirPath  Remote directory to download. Current working directory if not specified.
       */
      async downloadToDir(localDirPath, remoteDirPath) {
        return this._exitAtCurrentDirectory(async () => {
          if (remoteDirPath) {
            await this.cd(remoteDirPath);
          }
          return await this._downloadFromWorkingDir(localDirPath);
        });
      }
      /**
       * @protected
       */
      async _downloadFromWorkingDir(localDirPath) {
        await ensureLocalDirectory(localDirPath);
        for (const file of await this.list()) {
          const hasInvalidName = !file.name || (0, path_1.basename)(file.name) !== file.name;
          if (hasInvalidName) {
            const safeName = JSON.stringify(file.name);
            this.ftp.log(`Invalid filename from server listing, will skip file. (${safeName})`);
            continue;
          }
          const localPath = (0, path_1.join)(localDirPath, file.name);
          if (file.isDirectory) {
            await this.cd(file.name);
            await this._downloadFromWorkingDir(localPath);
            await this.cdup();
          } else if (file.isFile) {
            await this.downloadTo(localPath, file.name);
          }
        }
      }
      /**
       * Make sure a given remote path exists, creating all directories as necessary.
       * This function also changes the current working directory to the given path.
       */
      async ensureDir(remoteDirPath) {
        if (remoteDirPath.startsWith("/")) {
          await this.cd("/");
        }
        const names = remoteDirPath.split("/").filter((name) => name !== "");
        for (const name of names) {
          await this._openDir(name);
        }
      }
      /**
       * Try to create a directory and enter it. This will not raise an exception if the directory
       * couldn't be created if for example it already exists.
       * @protected
       */
      async _openDir(dirName) {
        await this.sendIgnoringError("MKD " + dirName);
        await this.cd(dirName);
      }
      /**
       * Remove an empty directory, will fail if not empty.
       */
      async removeEmptyDir(path47) {
        const validPath = await this.protectWhitespace(path47);
        return this.send(`RMD ${validPath}`);
      }
      /**
       * FTP servers can't handle filenames that have leading whitespace. This method transforms
       * a given path to fix that issue for most cases.
       */
      async protectWhitespace(path47) {
        if (!path47.startsWith(" ")) {
          return path47;
        }
        const pwd = await this.pwd();
        const absolutePathPrefix = pwd.endsWith("/") ? pwd : pwd + "/";
        return absolutePathPrefix + path47;
      }
      async _exitAtCurrentDirectory(func) {
        const userDir = await this.pwd();
        try {
          return await func();
        } finally {
          if (!this.closed) {
            await ignoreError(() => this.cd(userDir));
          }
        }
      }
      /**
       * Try all available transfer strategies and pick the first one that works. Update `client` to
       * use the working strategy for all successive transfer requests.
       *
       * @returns a function that will try the provided strategies.
       */
      _enterFirstCompatibleMode(strategies) {
        return async (ftp) => {
          ftp.log("Trying to find optimal transfer strategy...");
          let lastError = void 0;
          for (const strategy of strategies) {
            try {
              const res = await strategy(ftp);
              ftp.log("Optimal transfer strategy found.");
              this.prepareTransfer = strategy;
              return res;
            } catch (err) {
              lastError = err;
            }
          }
          throw new Error(`None of the available transfer strategies work. Last error response was '${lastError}'.`);
        };
      }
      /**
       * DEPRECATED, use `uploadFrom`.
       * @deprecated
       */
      async upload(source, toRemotePath, options = {}) {
        this.ftp.log("Warning: upload() has been deprecated, use uploadFrom().");
        return this.uploadFrom(source, toRemotePath, options);
      }
      /**
       * DEPRECATED, use `appendFrom`.
       * @deprecated
       */
      async append(source, toRemotePath, options = {}) {
        this.ftp.log("Warning: append() has been deprecated, use appendFrom().");
        return this.appendFrom(source, toRemotePath, options);
      }
      /**
       * DEPRECATED, use `downloadTo`.
       * @deprecated
       */
      async download(destination, fromRemotePath, startAt = 0) {
        this.ftp.log("Warning: download() has been deprecated, use downloadTo().");
        return this.downloadTo(destination, fromRemotePath, startAt);
      }
      /**
       * DEPRECATED, use `uploadFromDir`.
       * @deprecated
       */
      async uploadDir(localDirPath, remoteDirPath) {
        this.ftp.log("Warning: uploadDir() has been deprecated, use uploadFromDir().");
        return this.uploadFromDir(localDirPath, remoteDirPath);
      }
      /**
       * DEPRECATED, use `downloadToDir`.
       * @deprecated
       */
      async downloadDir(localDirPath) {
        this.ftp.log("Warning: downloadDir() has been deprecated, use downloadToDir().");
        return this.downloadToDir(localDirPath);
      }
    };
    exports2.Client = Client3;
    async function ensureLocalDirectory(path47) {
      try {
        await fsStat(path47);
      } catch (_a10) {
        await fsMkDir(path47, { recursive: true });
      }
    }
    __name(ensureLocalDirectory, "ensureLocalDirectory");
    async function ignoreError(func) {
      try {
        return await func();
      } catch (_a10) {
        return void 0;
      }
    }
    __name(ignoreError, "ignoreError");
  }
});

// ../../node_modules/basic-ftp/dist/StringEncoding.js
var require_StringEncoding = __commonJS({
  "../../node_modules/basic-ftp/dist/StringEncoding.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
  }
});

// ../../node_modules/basic-ftp/dist/index.js
var require_dist8 = __commonJS({
  "../../node_modules/basic-ftp/dist/index.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __exportStar3 = exports2 && exports2.__exportStar || function(m20, exports3) {
      for (var p10 in m20) if (p10 !== "default" && !Object.prototype.hasOwnProperty.call(exports3, p10)) __createBinding3(exports3, m20, p10);
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.enterPassiveModeIPv6 = exports2.enterPassiveModeIPv4 = void 0;
    __exportStar3(require_Client(), exports2);
    __exportStar3(require_FtpContext(), exports2);
    __exportStar3(require_FileInfo(), exports2);
    __exportStar3(require_parseList(), exports2);
    __exportStar3(require_StringEncoding(), exports2);
    var transfer_1 = require_transfer();
    Object.defineProperty(exports2, "enterPassiveModeIPv4", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return transfer_1.enterPassiveModeIPv4;
    }, "get") });
    Object.defineProperty(exports2, "enterPassiveModeIPv6", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return transfer_1.enterPassiveModeIPv6;
    }, "get") });
  }
});

// ../../node_modules/get-uri/dist/ftp.js
var require_ftp = __commonJS({
  "../../node_modules/get-uri/dist/ftp.js"(exports2) {
    "use strict";
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ftp = void 0;
    var basic_ftp_1 = require_dist8();
    var stream_1 = require("stream");
    var path_1 = require("path");
    var debug_1 = __importDefault2(require_src2());
    var notfound_1 = __importDefault2(require_notfound());
    var notmodified_1 = __importDefault2(require_notmodified());
    var debug2 = (0, debug_1.default)("get-uri:ftp");
    var ftp = /* @__PURE__ */ __name(async (url, opts = {}) => {
      const { cache: cache32 } = opts;
      const filepath = decodeURIComponent(url.pathname);
      let lastModified;
      if (!filepath) {
        throw new TypeError('No "pathname"!');
      }
      const client = new basic_ftp_1.Client();
      try {
        const host = url.hostname || url.host || "localhost";
        const port = parseInt(url.port || "0", 10) || 21;
        const user = url.username ? decodeURIComponent(url.username) : void 0;
        const password = url.password ? decodeURIComponent(url.password) : void 0;
        await client.access({
          host,
          port,
          user,
          password,
          ...opts
        });
        try {
          lastModified = await client.lastMod(filepath);
        } catch (err) {
          if (err.code === 550) {
            throw new notfound_1.default();
          }
        }
        if (!lastModified) {
          const list3 = await client.list((0, path_1.dirname)(filepath));
          const name = (0, path_1.basename)(filepath);
          const entry = list3.find((e32) => e32.name === name);
          if (entry) {
            lastModified = entry.modifiedAt;
          }
        }
        if (lastModified) {
          if (isNotModified()) {
            throw new notmodified_1.default();
          }
        } else {
          throw new notfound_1.default();
        }
        const stream = new stream_1.PassThrough();
        const rs = stream;
        client.downloadTo(stream, filepath).then((result2) => {
          debug2(result2.message);
          client.close();
        });
        rs.lastModified = lastModified;
        return rs;
      } catch (err) {
        client.close();
        throw err;
      }
      function isNotModified() {
        if (cache32?.lastModified && lastModified) {
          return +cache32.lastModified === +lastModified;
        }
        return false;
      }
      __name(isNotModified, "isNotModified");
    }, "ftp");
    exports2.ftp = ftp;
  }
});

// ../../node_modules/get-uri/dist/http-error.js
var require_http_error = __commonJS({
  "../../node_modules/get-uri/dist/http-error.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var http_1 = require("http");
    var HTTPError = class extends Error {
      static {
        __name(this, "HTTPError");
      }
      constructor(statusCode, message2 = http_1.STATUS_CODES[statusCode]) {
        super(message2);
        this.statusCode = statusCode;
        this.code = `E${String(message2).toUpperCase().replace(/\s+/g, "")}`;
      }
    };
    exports2.default = HTTPError;
  }
});

// ../../node_modules/get-uri/dist/http.js
var require_http = __commonJS({
  "../../node_modules/get-uri/dist/http.js"(exports2) {
    "use strict";
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.http = void 0;
    var http_1 = __importDefault2(require("http"));
    var https_1 = __importDefault2(require("https"));
    var events_1 = require("events");
    var debug_1 = __importDefault2(require_src2());
    var http_error_1 = __importDefault2(require_http_error());
    var notfound_1 = __importDefault2(require_notfound());
    var notmodified_1 = __importDefault2(require_notmodified());
    var debug2 = (0, debug_1.default)("get-uri:http");
    var http = /* @__PURE__ */ __name(async (url, opts = {}) => {
      debug2("GET %o", url.href);
      const cache32 = getCache(url, opts.cache);
      if (cache32 && isFresh(cache32) && typeof cache32.statusCode === "number") {
        const type2 = cache32.statusCode / 100 | 0;
        if (type2 === 3 && cache32.headers.location) {
          debug2("cached redirect");
          throw new Error("TODO: implement cached redirects!");
        }
        throw new notmodified_1.default();
      }
      const maxRedirects = typeof opts.maxRedirects === "number" ? opts.maxRedirects : 5;
      debug2("allowing %o max redirects", maxRedirects);
      let mod;
      if (opts.http) {
        mod = opts.http;
        debug2("using secure `https` core module");
      } else {
        mod = http_1.default;
        debug2("using `http` core module");
      }
      const options = { ...opts };
      if (cache32) {
        if (!options.headers) {
          options.headers = {};
        }
        const lastModified = cache32.headers["last-modified"];
        if (lastModified) {
          options.headers["If-Modified-Since"] = lastModified;
          debug2('added "If-Modified-Since" request header: %o', lastModified);
        }
        const etag = cache32.headers.etag;
        if (etag) {
          options.headers["If-None-Match"] = etag;
          debug2('added "If-None-Match" request header: %o', etag);
        }
      }
      const req = mod.get(url, options);
      const [res] = await (0, events_1.once)(req, "response");
      const code = res.statusCode || 0;
      res.date = Date.now();
      res.parsed = url;
      debug2("got %o response status code", code);
      const type = code / 100 | 0;
      const location = res.headers.location;
      if (type === 3 && location) {
        if (!opts.redirects)
          opts.redirects = [];
        const redirects = opts.redirects;
        if (redirects.length < maxRedirects) {
          debug2('got a "redirect" status code with Location: %o', location);
          res.resume();
          redirects.push(res);
          const newUri = new URL(location, url.href);
          debug2("resolved redirect URL: %o", newUri.href);
          const left = maxRedirects - redirects.length;
          debug2("%o more redirects allowed after this one", left);
          if (newUri.protocol !== url.protocol) {
            opts.http = newUri.protocol === "https:" ? https_1.default : void 0;
          }
          return (0, exports2.http)(newUri, opts);
        }
      }
      if (type !== 2) {
        res.resume();
        if (code === 304) {
          throw new notmodified_1.default();
        } else if (code === 404) {
          throw new notfound_1.default();
        }
        throw new http_error_1.default(code);
      }
      if (opts.redirects) {
        res.redirects = opts.redirects;
      }
      return res;
    }, "http");
    exports2.http = http;
    function isFresh(cache32) {
      let fresh = false;
      let expires = parseInt(cache32.headers.expires || "", 10);
      const cacheControl = cache32.headers["cache-control"];
      if (cacheControl) {
        debug2("Cache-Control: %o", cacheControl);
        const parts = cacheControl.split(/,\s*?\b/);
        for (let i32 = 0; i32 < parts.length; i32++) {
          const part = parts[i32];
          const subparts = part.split("=");
          const name = subparts[0];
          switch (name) {
            case "max-age":
              expires = (cache32.date || 0) + parseInt(subparts[1], 10) * 1e3;
              fresh = Date.now() < expires;
              if (fresh) {
                debug2('cache is "fresh" due to previous %o Cache-Control param', part);
              }
              return fresh;
            case "must-revalidate":
              break;
            case "no-cache":
            case "no-store":
              debug2('cache is "stale" due to explicit %o Cache-Control param', name);
              return false;
            default:
              break;
          }
        }
      } else if (expires) {
        debug2("Expires: %o", expires);
        fresh = Date.now() < expires;
        if (fresh) {
          debug2('cache is "fresh" due to previous Expires response header');
        }
        return fresh;
      }
      return false;
    }
    __name(isFresh, "isFresh");
    function getCache(url, cache32) {
      if (cache32) {
        if (cache32.parsed && cache32.parsed.href === url.href) {
          return cache32;
        }
        if (cache32.redirects) {
          for (let i32 = 0; i32 < cache32.redirects.length; i32++) {
            const c32 = getCache(url, cache32.redirects[i32]);
            if (c32) {
              return c32;
            }
          }
        }
      }
      return null;
    }
    __name(getCache, "getCache");
  }
});

// ../../node_modules/get-uri/dist/https.js
var require_https = __commonJS({
  "../../node_modules/get-uri/dist/https.js"(exports2) {
    "use strict";
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.https = void 0;
    var https_1 = __importDefault2(require("https"));
    var http_1 = require_http();
    var https3 = /* @__PURE__ */ __name((url, opts) => {
      return (0, http_1.http)(url, { ...opts, http: https_1.default });
    }, "https");
    exports2.https = https3;
  }
});

// ../../node_modules/get-uri/dist/index.js
var require_dist9 = __commonJS({
  "../../node_modules/get-uri/dist/index.js"(exports2) {
    "use strict";
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.getUri = exports2.isValidProtocol = exports2.protocols = void 0;
    var debug_1 = __importDefault2(require_src2());
    var data_1 = require_data();
    var file_1 = require_file2();
    var ftp_1 = require_ftp();
    var http_1 = require_http();
    var https_1 = require_https();
    var debug2 = (0, debug_1.default)("get-uri");
    exports2.protocols = {
      data: data_1.data,
      file: file_1.file,
      ftp: ftp_1.ftp,
      http: http_1.http,
      https: https_1.https
    };
    var VALID_PROTOCOLS = new Set(Object.keys(exports2.protocols));
    function isValidProtocol(p10) {
      return VALID_PROTOCOLS.has(p10);
    }
    __name(isValidProtocol, "isValidProtocol");
    exports2.isValidProtocol = isValidProtocol;
    async function getUri(uri, opts) {
      debug2("getUri(%o)", uri);
      if (!uri) {
        throw new TypeError('Must pass in a URI to "getUri()"');
      }
      const url = typeof uri === "string" ? new URL(uri) : uri;
      const protocol = url.protocol.replace(/:$/, "");
      if (!isValidProtocol(protocol)) {
        throw new TypeError(`Unsupported protocol "${protocol}" specified in URI: "${uri}"`);
      }
      const getter = exports2.protocols[protocol];
      return getter(url, opts);
    }
    __name(getUri, "getUri");
    exports2.getUri = getUri;
  }
});

// ../../node_modules/estraverse/estraverse.js
var require_estraverse = __commonJS({
  "../../node_modules/estraverse/estraverse.js"(exports2) {
    (/* @__PURE__ */ __name(function clone(exports3) {
      "use strict";
      var Syntax, VisitorOption, VisitorKeys, BREAK, SKIP, REMOVE;
      function deepCopy2(obj) {
        var ret = {}, key, val;
        for (key in obj) {
          if (obj.hasOwnProperty(key)) {
            val = obj[key];
            if (typeof val === "object" && val !== null) {
              ret[key] = deepCopy2(val);
            } else {
              ret[key] = val;
            }
          }
        }
        return ret;
      }
      __name(deepCopy2, "deepCopy");
      function upperBound(array, func) {
        var diff, len, i32, current;
        len = array.length;
        i32 = 0;
        while (len) {
          diff = len >>> 1;
          current = i32 + diff;
          if (func(array[current])) {
            len = diff;
          } else {
            i32 = current + 1;
            len -= diff + 1;
          }
        }
        return i32;
      }
      __name(upperBound, "upperBound");
      Syntax = {
        AssignmentExpression: "AssignmentExpression",
        AssignmentPattern: "AssignmentPattern",
        ArrayExpression: "ArrayExpression",
        ArrayPattern: "ArrayPattern",
        ArrowFunctionExpression: "ArrowFunctionExpression",
        AwaitExpression: "AwaitExpression",
        // CAUTION: It's deferred to ES7.
        BlockStatement: "BlockStatement",
        BinaryExpression: "BinaryExpression",
        BreakStatement: "BreakStatement",
        CallExpression: "CallExpression",
        CatchClause: "CatchClause",
        ChainExpression: "ChainExpression",
        ClassBody: "ClassBody",
        ClassDeclaration: "ClassDeclaration",
        ClassExpression: "ClassExpression",
        ComprehensionBlock: "ComprehensionBlock",
        // CAUTION: It's deferred to ES7.
        ComprehensionExpression: "ComprehensionExpression",
        // CAUTION: It's deferred to ES7.
        ConditionalExpression: "ConditionalExpression",
        ContinueStatement: "ContinueStatement",
        DebuggerStatement: "DebuggerStatement",
        DirectiveStatement: "DirectiveStatement",
        DoWhileStatement: "DoWhileStatement",
        EmptyStatement: "EmptyStatement",
        ExportAllDeclaration: "ExportAllDeclaration",
        ExportDefaultDeclaration: "ExportDefaultDeclaration",
        ExportNamedDeclaration: "ExportNamedDeclaration",
        ExportSpecifier: "ExportSpecifier",
        ExpressionStatement: "ExpressionStatement",
        ForStatement: "ForStatement",
        ForInStatement: "ForInStatement",
        ForOfStatement: "ForOfStatement",
        FunctionDeclaration: "FunctionDeclaration",
        FunctionExpression: "FunctionExpression",
        GeneratorExpression: "GeneratorExpression",
        // CAUTION: It's deferred to ES7.
        Identifier: "Identifier",
        IfStatement: "IfStatement",
        ImportExpression: "ImportExpression",
        ImportDeclaration: "ImportDeclaration",
        ImportDefaultSpecifier: "ImportDefaultSpecifier",
        ImportNamespaceSpecifier: "ImportNamespaceSpecifier",
        ImportSpecifier: "ImportSpecifier",
        Literal: "Literal",
        LabeledStatement: "LabeledStatement",
        LogicalExpression: "LogicalExpression",
        MemberExpression: "MemberExpression",
        MetaProperty: "MetaProperty",
        MethodDefinition: "MethodDefinition",
        ModuleSpecifier: "ModuleSpecifier",
        NewExpression: "NewExpression",
        ObjectExpression: "ObjectExpression",
        ObjectPattern: "ObjectPattern",
        PrivateIdentifier: "PrivateIdentifier",
        Program: "Program",
        Property: "Property",
        PropertyDefinition: "PropertyDefinition",
        RestElement: "RestElement",
        ReturnStatement: "ReturnStatement",
        SequenceExpression: "SequenceExpression",
        SpreadElement: "SpreadElement",
        Super: "Super",
        SwitchStatement: "SwitchStatement",
        SwitchCase: "SwitchCase",
        TaggedTemplateExpression: "TaggedTemplateExpression",
        TemplateElement: "TemplateElement",
        TemplateLiteral: "TemplateLiteral",
        ThisExpression: "ThisExpression",
        ThrowStatement: "ThrowStatement",
        TryStatement: "TryStatement",
        UnaryExpression: "UnaryExpression",
        UpdateExpression: "UpdateExpression",
        VariableDeclaration: "VariableDeclaration",
        VariableDeclarator: "VariableDeclarator",
        WhileStatement: "WhileStatement",
        WithStatement: "WithStatement",
        YieldExpression: "YieldExpression"
      };
      VisitorKeys = {
        AssignmentExpression: ["left", "right"],
        AssignmentPattern: ["left", "right"],
        ArrayExpression: ["elements"],
        ArrayPattern: ["elements"],
        ArrowFunctionExpression: ["params", "body"],
        AwaitExpression: ["argument"],
        // CAUTION: It's deferred to ES7.
        BlockStatement: ["body"],
        BinaryExpression: ["left", "right"],
        BreakStatement: ["label"],
        CallExpression: ["callee", "arguments"],
        CatchClause: ["param", "body"],
        ChainExpression: ["expression"],
        ClassBody: ["body"],
        ClassDeclaration: ["id", "superClass", "body"],
        ClassExpression: ["id", "superClass", "body"],
        ComprehensionBlock: ["left", "right"],
        // CAUTION: It's deferred to ES7.
        ComprehensionExpression: ["blocks", "filter", "body"],
        // CAUTION: It's deferred to ES7.
        ConditionalExpression: ["test", "consequent", "alternate"],
        ContinueStatement: ["label"],
        DebuggerStatement: [],
        DirectiveStatement: [],
        DoWhileStatement: ["body", "test"],
        EmptyStatement: [],
        ExportAllDeclaration: ["source"],
        ExportDefaultDeclaration: ["declaration"],
        ExportNamedDeclaration: ["declaration", "specifiers", "source"],
        ExportSpecifier: ["exported", "local"],
        ExpressionStatement: ["expression"],
        ForStatement: ["init", "test", "update", "body"],
        ForInStatement: ["left", "right", "body"],
        ForOfStatement: ["left", "right", "body"],
        FunctionDeclaration: ["id", "params", "body"],
        FunctionExpression: ["id", "params", "body"],
        GeneratorExpression: ["blocks", "filter", "body"],
        // CAUTION: It's deferred to ES7.
        Identifier: [],
        IfStatement: ["test", "consequent", "alternate"],
        ImportExpression: ["source"],
        ImportDeclaration: ["specifiers", "source"],
        ImportDefaultSpecifier: ["local"],
        ImportNamespaceSpecifier: ["local"],
        ImportSpecifier: ["imported", "local"],
        Literal: [],
        LabeledStatement: ["label", "body"],
        LogicalExpression: ["left", "right"],
        MemberExpression: ["object", "property"],
        MetaProperty: ["meta", "property"],
        MethodDefinition: ["key", "value"],
        ModuleSpecifier: [],
        NewExpression: ["callee", "arguments"],
        ObjectExpression: ["properties"],
        ObjectPattern: ["properties"],
        PrivateIdentifier: [],
        Program: ["body"],
        Property: ["key", "value"],
        PropertyDefinition: ["key", "value"],
        RestElement: ["argument"],
        ReturnStatement: ["argument"],
        SequenceExpression: ["expressions"],
        SpreadElement: ["argument"],
        Super: [],
        SwitchStatement: ["discriminant", "cases"],
        SwitchCase: ["test", "consequent"],
        TaggedTemplateExpression: ["tag", "quasi"],
        TemplateElement: [],
        TemplateLiteral: ["quasis", "expressions"],
        ThisExpression: [],
        ThrowStatement: ["argument"],
        TryStatement: ["block", "handler", "finalizer"],
        UnaryExpression: ["argument"],
        UpdateExpression: ["argument"],
        VariableDeclaration: ["declarations"],
        VariableDeclarator: ["id", "init"],
        WhileStatement: ["test", "body"],
        WithStatement: ["object", "body"],
        YieldExpression: ["argument"]
      };
      BREAK = {};
      SKIP = {};
      REMOVE = {};
      VisitorOption = {
        Break: BREAK,
        Skip: SKIP,
        Remove: REMOVE
      };
      function Reference(parent, key) {
        this.parent = parent;
        this.key = key;
      }
      __name(Reference, "Reference");
      Reference.prototype.replace = /* @__PURE__ */ __name(function replace2(node) {
        this.parent[this.key] = node;
      }, "replace");
      Reference.prototype.remove = /* @__PURE__ */ __name(function remove2() {
        if (Array.isArray(this.parent)) {
          this.parent.splice(this.key, 1);
          return true;
        } else {
          this.replace(null);
          return false;
        }
      }, "remove");
      function Element(node, path47, wrap, ref) {
        this.node = node;
        this.path = path47;
        this.wrap = wrap;
        this.ref = ref;
      }
      __name(Element, "Element");
      function Controller() {
      }
      __name(Controller, "Controller");
      Controller.prototype.path = /* @__PURE__ */ __name(function path47() {
        var i32, iz, j32, jz, result2, element;
        function addToPath(result3, path48) {
          if (Array.isArray(path48)) {
            for (j32 = 0, jz = path48.length; j32 < jz; ++j32) {
              result3.push(path48[j32]);
            }
          } else {
            result3.push(path48);
          }
        }
        __name(addToPath, "addToPath");
        if (!this.__current.path) {
          return null;
        }
        result2 = [];
        for (i32 = 2, iz = this.__leavelist.length; i32 < iz; ++i32) {
          element = this.__leavelist[i32];
          addToPath(result2, element.path);
        }
        addToPath(result2, this.__current.path);
        return result2;
      }, "path");
      Controller.prototype.type = function() {
        var node = this.current();
        return node.type || this.__current.wrap;
      };
      Controller.prototype.parents = /* @__PURE__ */ __name(function parents() {
        var i32, iz, result2;
        result2 = [];
        for (i32 = 1, iz = this.__leavelist.length; i32 < iz; ++i32) {
          result2.push(this.__leavelist[i32].node);
        }
        return result2;
      }, "parents");
      Controller.prototype.current = /* @__PURE__ */ __name(function current() {
        return this.__current.node;
      }, "current");
      Controller.prototype.__execute = /* @__PURE__ */ __name(function __execute(callback, element) {
        var previous, result2;
        result2 = void 0;
        previous = this.__current;
        this.__current = element;
        this.__state = null;
        if (callback) {
          result2 = callback.call(this, element.node, this.__leavelist[this.__leavelist.length - 1].node);
        }
        this.__current = previous;
        return result2;
      }, "__execute");
      Controller.prototype.notify = /* @__PURE__ */ __name(function notify(flag) {
        this.__state = flag;
      }, "notify");
      Controller.prototype.skip = function() {
        this.notify(SKIP);
      };
      Controller.prototype["break"] = function() {
        this.notify(BREAK);
      };
      Controller.prototype.remove = function() {
        this.notify(REMOVE);
      };
      Controller.prototype.__initialize = function(root32, visitor) {
        this.visitor = visitor;
        this.root = root32;
        this.__worklist = [];
        this.__leavelist = [];
        this.__current = null;
        this.__state = null;
        this.__fallback = null;
        if (visitor.fallback === "iteration") {
          this.__fallback = Object.keys;
        } else if (typeof visitor.fallback === "function") {
          this.__fallback = visitor.fallback;
        }
        this.__keys = VisitorKeys;
        if (visitor.keys) {
          this.__keys = Object.assign(Object.create(this.__keys), visitor.keys);
        }
      };
      function isNode(node) {
        if (node == null) {
          return false;
        }
        return typeof node === "object" && typeof node.type === "string";
      }
      __name(isNode, "isNode");
      function isProperty(nodeType, key) {
        return (nodeType === Syntax.ObjectExpression || nodeType === Syntax.ObjectPattern) && "properties" === key;
      }
      __name(isProperty, "isProperty");
      function candidateExistsInLeaveList(leavelist, candidate) {
        for (var i32 = leavelist.length - 1; i32 >= 0; --i32) {
          if (leavelist[i32].node === candidate) {
            return true;
          }
        }
        return false;
      }
      __name(candidateExistsInLeaveList, "candidateExistsInLeaveList");
      Controller.prototype.traverse = /* @__PURE__ */ __name(function traverse2(root32, visitor) {
        var worklist, leavelist, element, node, nodeType, ret, key, current, current2, candidates, candidate, sentinel;
        this.__initialize(root32, visitor);
        sentinel = {};
        worklist = this.__worklist;
        leavelist = this.__leavelist;
        worklist.push(new Element(root32, null, null, null));
        leavelist.push(new Element(null, null, null, null));
        while (worklist.length) {
          element = worklist.pop();
          if (element === sentinel) {
            element = leavelist.pop();
            ret = this.__execute(visitor.leave, element);
            if (this.__state === BREAK || ret === BREAK) {
              return;
            }
            continue;
          }
          if (element.node) {
            ret = this.__execute(visitor.enter, element);
            if (this.__state === BREAK || ret === BREAK) {
              return;
            }
            worklist.push(sentinel);
            leavelist.push(element);
            if (this.__state === SKIP || ret === SKIP) {
              continue;
            }
            node = element.node;
            nodeType = node.type || element.wrap;
            candidates = this.__keys[nodeType];
            if (!candidates) {
              if (this.__fallback) {
                candidates = this.__fallback(node);
              } else {
                throw new Error("Unknown node type " + nodeType + ".");
              }
            }
            current = candidates.length;
            while ((current -= 1) >= 0) {
              key = candidates[current];
              candidate = node[key];
              if (!candidate) {
                continue;
              }
              if (Array.isArray(candidate)) {
                current2 = candidate.length;
                while ((current2 -= 1) >= 0) {
                  if (!candidate[current2]) {
                    continue;
                  }
                  if (candidateExistsInLeaveList(leavelist, candidate[current2])) {
                    continue;
                  }
                  if (isProperty(nodeType, candidates[current])) {
                    element = new Element(candidate[current2], [key, current2], "Property", null);
                  } else if (isNode(candidate[current2])) {
                    element = new Element(candidate[current2], [key, current2], null, null);
                  } else {
                    continue;
                  }
                  worklist.push(element);
                }
              } else if (isNode(candidate)) {
                if (candidateExistsInLeaveList(leavelist, candidate)) {
                  continue;
                }
                worklist.push(new Element(candidate, key, null, null));
              }
            }
          }
        }
      }, "traverse");
      Controller.prototype.replace = /* @__PURE__ */ __name(function replace2(root32, visitor) {
        var worklist, leavelist, node, nodeType, target, element, current, current2, candidates, candidate, sentinel, outer, key;
        function removeElem(element2) {
          var i32, key2, nextElem, parent;
          if (element2.ref.remove()) {
            key2 = element2.ref.key;
            parent = element2.ref.parent;
            i32 = worklist.length;
            while (i32--) {
              nextElem = worklist[i32];
              if (nextElem.ref && nextElem.ref.parent === parent) {
                if (nextElem.ref.key < key2) {
                  break;
                }
                --nextElem.ref.key;
              }
            }
          }
        }
        __name(removeElem, "removeElem");
        this.__initialize(root32, visitor);
        sentinel = {};
        worklist = this.__worklist;
        leavelist = this.__leavelist;
        outer = {
          root: root32
        };
        element = new Element(root32, null, null, new Reference(outer, "root"));
        worklist.push(element);
        leavelist.push(element);
        while (worklist.length) {
          element = worklist.pop();
          if (element === sentinel) {
            element = leavelist.pop();
            target = this.__execute(visitor.leave, element);
            if (target !== void 0 && target !== BREAK && target !== SKIP && target !== REMOVE) {
              element.ref.replace(target);
            }
            if (this.__state === REMOVE || target === REMOVE) {
              removeElem(element);
            }
            if (this.__state === BREAK || target === BREAK) {
              return outer.root;
            }
            continue;
          }
          target = this.__execute(visitor.enter, element);
          if (target !== void 0 && target !== BREAK && target !== SKIP && target !== REMOVE) {
            element.ref.replace(target);
            element.node = target;
          }
          if (this.__state === REMOVE || target === REMOVE) {
            removeElem(element);
            element.node = null;
          }
          if (this.__state === BREAK || target === BREAK) {
            return outer.root;
          }
          node = element.node;
          if (!node) {
            continue;
          }
          worklist.push(sentinel);
          leavelist.push(element);
          if (this.__state === SKIP || target === SKIP) {
            continue;
          }
          nodeType = node.type || element.wrap;
          candidates = this.__keys[nodeType];
          if (!candidates) {
            if (this.__fallback) {
              candidates = this.__fallback(node);
            } else {
              throw new Error("Unknown node type " + nodeType + ".");
            }
          }
          current = candidates.length;
          while ((current -= 1) >= 0) {
            key = candidates[current];
            candidate = node[key];
            if (!candidate) {
              continue;
            }
            if (Array.isArray(candidate)) {
              current2 = candidate.length;
              while ((current2 -= 1) >= 0) {
                if (!candidate[current2]) {
                  continue;
                }
                if (isProperty(nodeType, candidates[current])) {
                  element = new Element(candidate[current2], [key, current2], "Property", new Reference(candidate, current2));
                } else if (isNode(candidate[current2])) {
                  element = new Element(candidate[current2], [key, current2], null, new Reference(candidate, current2));
                } else {
                  continue;
                }
                worklist.push(element);
              }
            } else if (isNode(candidate)) {
              worklist.push(new Element(candidate, key, null, new Reference(node, key)));
            }
          }
        }
        return outer.root;
      }, "replace");
      function traverse(root32, visitor) {
        var controller = new Controller();
        return controller.traverse(root32, visitor);
      }
      __name(traverse, "traverse");
      function replace(root32, visitor) {
        var controller = new Controller();
        return controller.replace(root32, visitor);
      }
      __name(replace, "replace");
      function extendCommentRange(comment, tokens) {
        var target;
        target = upperBound(tokens, /* @__PURE__ */ __name(function search(token) {
          return token.range[0] > comment.range[0];
        }, "search"));
        comment.extendedRange = [comment.range[0], comment.range[1]];
        if (target !== tokens.length) {
          comment.extendedRange[1] = tokens[target].range[0];
        }
        target -= 1;
        if (target >= 0) {
          comment.extendedRange[0] = tokens[target].range[1];
        }
        return comment;
      }
      __name(extendCommentRange, "extendCommentRange");
      function attachComments(tree, providedComments, tokens) {
        var comments = [], comment, len, i32, cursor3;
        if (!tree.range) {
          throw new Error("attachComments needs range information");
        }
        if (!tokens.length) {
          if (providedComments.length) {
            for (i32 = 0, len = providedComments.length; i32 < len; i32 += 1) {
              comment = deepCopy2(providedComments[i32]);
              comment.extendedRange = [0, tree.range[0]];
              comments.push(comment);
            }
            tree.leadingComments = comments;
          }
          return tree;
        }
        for (i32 = 0, len = providedComments.length; i32 < len; i32 += 1) {
          comments.push(extendCommentRange(deepCopy2(providedComments[i32]), tokens));
        }
        cursor3 = 0;
        traverse(tree, {
          enter: /* @__PURE__ */ __name(function(node) {
            var comment2;
            while (cursor3 < comments.length) {
              comment2 = comments[cursor3];
              if (comment2.extendedRange[1] > node.range[0]) {
                break;
              }
              if (comment2.extendedRange[1] === node.range[0]) {
                if (!node.leadingComments) {
                  node.leadingComments = [];
                }
                node.leadingComments.push(comment2);
                comments.splice(cursor3, 1);
              } else {
                cursor3 += 1;
              }
            }
            if (cursor3 === comments.length) {
              return VisitorOption.Break;
            }
            if (comments[cursor3].extendedRange[0] > node.range[1]) {
              return VisitorOption.Skip;
            }
          }, "enter")
        });
        cursor3 = 0;
        traverse(tree, {
          leave: /* @__PURE__ */ __name(function(node) {
            var comment2;
            while (cursor3 < comments.length) {
              comment2 = comments[cursor3];
              if (node.range[1] < comment2.extendedRange[0]) {
                break;
              }
              if (node.range[1] === comment2.extendedRange[0]) {
                if (!node.trailingComments) {
                  node.trailingComments = [];
                }
                node.trailingComments.push(comment2);
                comments.splice(cursor3, 1);
              } else {
                cursor3 += 1;
              }
            }
            if (cursor3 === comments.length) {
              return VisitorOption.Break;
            }
            if (comments[cursor3].extendedRange[0] > node.range[1]) {
              return VisitorOption.Skip;
            }
          }, "leave")
        });
        return tree;
      }
      __name(attachComments, "attachComments");
      exports3.Syntax = Syntax;
      exports3.traverse = traverse;
      exports3.replace = replace;
      exports3.attachComments = attachComments;
      exports3.VisitorKeys = VisitorKeys;
      exports3.VisitorOption = VisitorOption;
      exports3.Controller = Controller;
      exports3.cloneEnvironment = function() {
        return clone({});
      };
      return exports3;
    }, "clone"))(exports2);
  }
});

// ../../node_modules/esutils/lib/ast.js
var require_ast = __commonJS({
  "../../node_modules/esutils/lib/ast.js"(exports2, module2) {
    (function() {
      "use strict";
      function isExpression(node) {
        if (node == null) {
          return false;
        }
        switch (node.type) {
          case "ArrayExpression":
          case "AssignmentExpression":
          case "BinaryExpression":
          case "CallExpression":
          case "ConditionalExpression":
          case "FunctionExpression":
          case "Identifier":
          case "Literal":
          case "LogicalExpression":
          case "MemberExpression":
          case "NewExpression":
          case "ObjectExpression":
          case "SequenceExpression":
          case "ThisExpression":
          case "UnaryExpression":
          case "UpdateExpression":
            return true;
        }
        return false;
      }
      __name(isExpression, "isExpression");
      function isIterationStatement(node) {
        if (node == null) {
          return false;
        }
        switch (node.type) {
          case "DoWhileStatement":
          case "ForInStatement":
          case "ForStatement":
          case "WhileStatement":
            return true;
        }
        return false;
      }
      __name(isIterationStatement, "isIterationStatement");
      function isStatement(node) {
        if (node == null) {
          return false;
        }
        switch (node.type) {
          case "BlockStatement":
          case "BreakStatement":
          case "ContinueStatement":
          case "DebuggerStatement":
          case "DoWhileStatement":
          case "EmptyStatement":
          case "ExpressionStatement":
          case "ForInStatement":
          case "ForStatement":
          case "IfStatement":
          case "LabeledStatement":
          case "ReturnStatement":
          case "SwitchStatement":
          case "ThrowStatement":
          case "TryStatement":
          case "VariableDeclaration":
          case "WhileStatement":
          case "WithStatement":
            return true;
        }
        return false;
      }
      __name(isStatement, "isStatement");
      function isSourceElement(node) {
        return isStatement(node) || node != null && node.type === "FunctionDeclaration";
      }
      __name(isSourceElement, "isSourceElement");
      function trailingStatement(node) {
        switch (node.type) {
          case "IfStatement":
            if (node.alternate != null) {
              return node.alternate;
            }
            return node.consequent;
          case "LabeledStatement":
          case "ForStatement":
          case "ForInStatement":
          case "WhileStatement":
          case "WithStatement":
            return node.body;
        }
        return null;
      }
      __name(trailingStatement, "trailingStatement");
      function isProblematicIfStatement(node) {
        var current;
        if (node.type !== "IfStatement") {
          return false;
        }
        if (node.alternate == null) {
          return false;
        }
        current = node.consequent;
        do {
          if (current.type === "IfStatement") {
            if (current.alternate == null) {
              return true;
            }
          }
          current = trailingStatement(current);
        } while (current);
        return false;
      }
      __name(isProblematicIfStatement, "isProblematicIfStatement");
      module2.exports = {
        isExpression,
        isStatement,
        isIterationStatement,
        isSourceElement,
        isProblematicIfStatement,
        trailingStatement
      };
    })();
  }
});

// ../../node_modules/esutils/lib/code.js
var require_code = __commonJS({
  "../../node_modules/esutils/lib/code.js"(exports2, module2) {
    (function() {
      "use strict";
      var ES6Regex, ES5Regex, NON_ASCII_WHITESPACES, IDENTIFIER_START, IDENTIFIER_PART, ch;
      ES5Regex = {
        // ECMAScript 5.1/Unicode v9.0.0 NonAsciiIdentifierStart:
        NonAsciiIdentifierStart: /[\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u08A0-\u08B4\u08B6-\u08BD\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C60\u0C61\u0C80\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D54-\u0D56\u0D5F-\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u1884\u1887-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1C80-\u1C88\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2E2F\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303C\u3041-\u3096\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FD5\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6EF\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AE\uA7B0-\uA7B7\uA7F7-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA8FD\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]/,
        // ECMAScript 5.1/Unicode v9.0.0 NonAsciiIdentifierPart:
        NonAsciiIdentifierPart: /[\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0300-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u0483-\u0487\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u0591-\u05BD\u05BF\u05C1\u05C2\u05C4\u05C5\u05C7\u05D0-\u05EA\u05F0-\u05F2\u0610-\u061A\u0620-\u0669\u066E-\u06D3\u06D5-\u06DC\u06DF-\u06E8\u06EA-\u06FC\u06FF\u0710-\u074A\u074D-\u07B1\u07C0-\u07F5\u07FA\u0800-\u082D\u0840-\u085B\u08A0-\u08B4\u08B6-\u08BD\u08D4-\u08E1\u08E3-\u0963\u0966-\u096F\u0971-\u0983\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BC-\u09C4\u09C7\u09C8\u09CB-\u09CE\u09D7\u09DC\u09DD\u09DF-\u09E3\u09E6-\u09F1\u0A01-\u0A03\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A3C\u0A3E-\u0A42\u0A47\u0A48\u0A4B-\u0A4D\u0A51\u0A59-\u0A5C\u0A5E\u0A66-\u0A75\u0A81-\u0A83\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABC-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0AD0\u0AE0-\u0AE3\u0AE6-\u0AEF\u0AF9\u0B01-\u0B03\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3C-\u0B44\u0B47\u0B48\u0B4B-\u0B4D\u0B56\u0B57\u0B5C\u0B5D\u0B5F-\u0B63\u0B66-\u0B6F\u0B71\u0B82\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD0\u0BD7\u0BE6-\u0BEF\u0C00-\u0C03\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55\u0C56\u0C58-\u0C5A\u0C60-\u0C63\u0C66-\u0C6F\u0C80-\u0C83\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBC-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5\u0CD6\u0CDE\u0CE0-\u0CE3\u0CE6-\u0CEF\u0CF1\u0CF2\u0D01-\u0D03\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D-\u0D44\u0D46-\u0D48\u0D4A-\u0D4E\u0D54-\u0D57\u0D5F-\u0D63\u0D66-\u0D6F\u0D7A-\u0D7F\u0D82\u0D83\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0DCA\u0DCF-\u0DD4\u0DD6\u0DD8-\u0DDF\u0DE6-\u0DEF\u0DF2\u0DF3\u0E01-\u0E3A\u0E40-\u0E4E\u0E50-\u0E59\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB9\u0EBB-\u0EBD\u0EC0-\u0EC4\u0EC6\u0EC8-\u0ECD\u0ED0-\u0ED9\u0EDC-\u0EDF\u0F00\u0F18\u0F19\u0F20-\u0F29\u0F35\u0F37\u0F39\u0F3E-\u0F47\u0F49-\u0F6C\u0F71-\u0F84\u0F86-\u0F97\u0F99-\u0FBC\u0FC6\u1000-\u1049\u1050-\u109D\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u135D-\u135F\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1714\u1720-\u1734\u1740-\u1753\u1760-\u176C\u176E-\u1770\u1772\u1773\u1780-\u17D3\u17D7\u17DC\u17DD\u17E0-\u17E9\u180B-\u180D\u1810-\u1819\u1820-\u1877\u1880-\u18AA\u18B0-\u18F5\u1900-\u191E\u1920-\u192B\u1930-\u193B\u1946-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u19D0-\u19D9\u1A00-\u1A1B\u1A20-\u1A5E\u1A60-\u1A7C\u1A7F-\u1A89\u1A90-\u1A99\u1AA7\u1AB0-\u1ABD\u1B00-\u1B4B\u1B50-\u1B59\u1B6B-\u1B73\u1B80-\u1BF3\u1C00-\u1C37\u1C40-\u1C49\u1C4D-\u1C7D\u1C80-\u1C88\u1CD0-\u1CD2\u1CD4-\u1CF6\u1CF8\u1CF9\u1D00-\u1DF5\u1DFB-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u200C\u200D\u203F\u2040\u2054\u2071\u207F\u2090-\u209C\u20D0-\u20DC\u20E1\u20E5-\u20F0\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D7F-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2DE0-\u2DFF\u2E2F\u3005-\u3007\u3021-\u302F\u3031-\u3035\u3038-\u303C\u3041-\u3096\u3099\u309A\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FD5\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA62B\uA640-\uA66F\uA674-\uA67D\uA67F-\uA6F1\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AE\uA7B0-\uA7B7\uA7F7-\uA827\uA840-\uA873\uA880-\uA8C5\uA8D0-\uA8D9\uA8E0-\uA8F7\uA8FB\uA8FD\uA900-\uA92D\uA930-\uA953\uA960-\uA97C\uA980-\uA9C0\uA9CF-\uA9D9\uA9E0-\uA9FE\uAA00-\uAA36\uAA40-\uAA4D\uAA50-\uAA59\uAA60-\uAA76\uAA7A-\uAAC2\uAADB-\uAADD\uAAE0-\uAAEF\uAAF2-\uAAF6\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABEA\uABEC\uABED\uABF0-\uABF9\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE00-\uFE0F\uFE20-\uFE2F\uFE33\uFE34\uFE4D-\uFE4F\uFE70-\uFE74\uFE76-\uFEFC\uFF10-\uFF19\uFF21-\uFF3A\uFF3F\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]/
      };
      ES6Regex = {
        // ECMAScript 6/Unicode v9.0.0 NonAsciiIdentifierStart:
        NonAsciiIdentifierStart: /[\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u08A0-\u08B4\u08B6-\u08BD\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C60\u0C61\u0C80\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D54-\u0D56\u0D5F-\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1C80-\u1C88\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2118-\u211D\u2124\u2126\u2128\u212A-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303C\u3041-\u3096\u309B-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FD5\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6EF\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AE\uA7B0-\uA7B7\uA7F7-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA8FD\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD40-\uDD74\uDE80-\uDE9C\uDEA0-\uDED0\uDF00-\uDF1F\uDF30-\uDF4A\uDF50-\uDF75\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDCB0-\uDCD3\uDCD8-\uDCFB\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDCE0-\uDCF2\uDCF4\uDCF5\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00\uDE10-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE4\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48\uDC80-\uDCB2\uDCC0-\uDCF2]|\uD804[\uDC03-\uDC37\uDC83-\uDCAF\uDCD0-\uDCE8\uDD03-\uDD26\uDD50-\uDD72\uDD76\uDD83-\uDDB2\uDDC1-\uDDC4\uDDDA\uDDDC\uDE00-\uDE11\uDE13-\uDE2B\uDE80-\uDE86\uDE88\uDE8A-\uDE8D\uDE8F-\uDE9D\uDE9F-\uDEA8\uDEB0-\uDEDE\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3D\uDF50\uDF5D-\uDF61]|\uD805[\uDC00-\uDC34\uDC47-\uDC4A\uDC80-\uDCAF\uDCC4\uDCC5\uDCC7\uDD80-\uDDAE\uDDD8-\uDDDB\uDE00-\uDE2F\uDE44\uDE80-\uDEAA\uDF00-\uDF19]|\uD806[\uDCA0-\uDCDF\uDCFF\uDEC0-\uDEF8]|\uD807[\uDC00-\uDC08\uDC0A-\uDC2E\uDC40\uDC72-\uDC8F]|\uD808[\uDC00-\uDF99]|\uD809[\uDC00-\uDC6E\uDC80-\uDD43]|[\uD80C\uD81C-\uD820\uD840-\uD868\uD86A-\uD86C\uD86F-\uD872][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD811[\uDC00-\uDE46]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDED0-\uDEED\uDF00-\uDF2F\uDF40-\uDF43\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50\uDF93-\uDF9F\uDFE0]|\uD821[\uDC00-\uDFEC]|\uD822[\uDC00-\uDEF2]|\uD82C[\uDC00\uDC01]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB]|\uD83A[\uDC00-\uDCC4\uDD00-\uDD43]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D\uDC20-\uDFFF]|\uD873[\uDC00-\uDEA1]|\uD87E[\uDC00-\uDE1D]/,
        // ECMAScript 6/Unicode v9.0.0 NonAsciiIdentifierPart:
        NonAsciiIdentifierPart: /[\xAA\xB5\xB7\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0300-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u0483-\u0487\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u0591-\u05BD\u05BF\u05C1\u05C2\u05C4\u05C5\u05C7\u05D0-\u05EA\u05F0-\u05F2\u0610-\u061A\u0620-\u0669\u066E-\u06D3\u06D5-\u06DC\u06DF-\u06E8\u06EA-\u06FC\u06FF\u0710-\u074A\u074D-\u07B1\u07C0-\u07F5\u07FA\u0800-\u082D\u0840-\u085B\u08A0-\u08B4\u08B6-\u08BD\u08D4-\u08E1\u08E3-\u0963\u0966-\u096F\u0971-\u0983\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BC-\u09C4\u09C7\u09C8\u09CB-\u09CE\u09D7\u09DC\u09DD\u09DF-\u09E3\u09E6-\u09F1\u0A01-\u0A03\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A3C\u0A3E-\u0A42\u0A47\u0A48\u0A4B-\u0A4D\u0A51\u0A59-\u0A5C\u0A5E\u0A66-\u0A75\u0A81-\u0A83\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABC-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0AD0\u0AE0-\u0AE3\u0AE6-\u0AEF\u0AF9\u0B01-\u0B03\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3C-\u0B44\u0B47\u0B48\u0B4B-\u0B4D\u0B56\u0B57\u0B5C\u0B5D\u0B5F-\u0B63\u0B66-\u0B6F\u0B71\u0B82\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD0\u0BD7\u0BE6-\u0BEF\u0C00-\u0C03\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55\u0C56\u0C58-\u0C5A\u0C60-\u0C63\u0C66-\u0C6F\u0C80-\u0C83\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBC-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5\u0CD6\u0CDE\u0CE0-\u0CE3\u0CE6-\u0CEF\u0CF1\u0CF2\u0D01-\u0D03\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D-\u0D44\u0D46-\u0D48\u0D4A-\u0D4E\u0D54-\u0D57\u0D5F-\u0D63\u0D66-\u0D6F\u0D7A-\u0D7F\u0D82\u0D83\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0DCA\u0DCF-\u0DD4\u0DD6\u0DD8-\u0DDF\u0DE6-\u0DEF\u0DF2\u0DF3\u0E01-\u0E3A\u0E40-\u0E4E\u0E50-\u0E59\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB9\u0EBB-\u0EBD\u0EC0-\u0EC4\u0EC6\u0EC8-\u0ECD\u0ED0-\u0ED9\u0EDC-\u0EDF\u0F00\u0F18\u0F19\u0F20-\u0F29\u0F35\u0F37\u0F39\u0F3E-\u0F47\u0F49-\u0F6C\u0F71-\u0F84\u0F86-\u0F97\u0F99-\u0FBC\u0FC6\u1000-\u1049\u1050-\u109D\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u135D-\u135F\u1369-\u1371\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1714\u1720-\u1734\u1740-\u1753\u1760-\u176C\u176E-\u1770\u1772\u1773\u1780-\u17D3\u17D7\u17DC\u17DD\u17E0-\u17E9\u180B-\u180D\u1810-\u1819\u1820-\u1877\u1880-\u18AA\u18B0-\u18F5\u1900-\u191E\u1920-\u192B\u1930-\u193B\u1946-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u19D0-\u19DA\u1A00-\u1A1B\u1A20-\u1A5E\u1A60-\u1A7C\u1A7F-\u1A89\u1A90-\u1A99\u1AA7\u1AB0-\u1ABD\u1B00-\u1B4B\u1B50-\u1B59\u1B6B-\u1B73\u1B80-\u1BF3\u1C00-\u1C37\u1C40-\u1C49\u1C4D-\u1C7D\u1C80-\u1C88\u1CD0-\u1CD2\u1CD4-\u1CF6\u1CF8\u1CF9\u1D00-\u1DF5\u1DFB-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u200C\u200D\u203F\u2040\u2054\u2071\u207F\u2090-\u209C\u20D0-\u20DC\u20E1\u20E5-\u20F0\u2102\u2107\u210A-\u2113\u2115\u2118-\u211D\u2124\u2126\u2128\u212A-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D7F-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2DE0-\u2DFF\u3005-\u3007\u3021-\u302F\u3031-\u3035\u3038-\u303C\u3041-\u3096\u3099-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FD5\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA62B\uA640-\uA66F\uA674-\uA67D\uA67F-\uA6F1\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AE\uA7B0-\uA7B7\uA7F7-\uA827\uA840-\uA873\uA880-\uA8C5\uA8D0-\uA8D9\uA8E0-\uA8F7\uA8FB\uA8FD\uA900-\uA92D\uA930-\uA953\uA960-\uA97C\uA980-\uA9C0\uA9CF-\uA9D9\uA9E0-\uA9FE\uAA00-\uAA36\uAA40-\uAA4D\uAA50-\uAA59\uAA60-\uAA76\uAA7A-\uAAC2\uAADB-\uAADD\uAAE0-\uAAEF\uAAF2-\uAAF6\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABEA\uABEC\uABED\uABF0-\uABF9\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE00-\uFE0F\uFE20-\uFE2F\uFE33\uFE34\uFE4D-\uFE4F\uFE70-\uFE74\uFE76-\uFEFC\uFF10-\uFF19\uFF21-\uFF3A\uFF3F\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD40-\uDD74\uDDFD\uDE80-\uDE9C\uDEA0-\uDED0\uDEE0\uDF00-\uDF1F\uDF30-\uDF4A\uDF50-\uDF7A\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDCA0-\uDCA9\uDCB0-\uDCD3\uDCD8-\uDCFB\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDCE0-\uDCF2\uDCF4\uDCF5\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00-\uDE03\uDE05\uDE06\uDE0C-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE38-\uDE3A\uDE3F\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE6\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48\uDC80-\uDCB2\uDCC0-\uDCF2]|\uD804[\uDC00-\uDC46\uDC66-\uDC6F\uDC7F-\uDCBA\uDCD0-\uDCE8\uDCF0-\uDCF9\uDD00-\uDD34\uDD36-\uDD3F\uDD50-\uDD73\uDD76\uDD80-\uDDC4\uDDCA-\uDDCC\uDDD0-\uDDDA\uDDDC\uDE00-\uDE11\uDE13-\uDE37\uDE3E\uDE80-\uDE86\uDE88\uDE8A-\uDE8D\uDE8F-\uDE9D\uDE9F-\uDEA8\uDEB0-\uDEEA\uDEF0-\uDEF9\uDF00-\uDF03\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3C-\uDF44\uDF47\uDF48\uDF4B-\uDF4D\uDF50\uDF57\uDF5D-\uDF63\uDF66-\uDF6C\uDF70-\uDF74]|\uD805[\uDC00-\uDC4A\uDC50-\uDC59\uDC80-\uDCC5\uDCC7\uDCD0-\uDCD9\uDD80-\uDDB5\uDDB8-\uDDC0\uDDD8-\uDDDD\uDE00-\uDE40\uDE44\uDE50-\uDE59\uDE80-\uDEB7\uDEC0-\uDEC9\uDF00-\uDF19\uDF1D-\uDF2B\uDF30-\uDF39]|\uD806[\uDCA0-\uDCE9\uDCFF\uDEC0-\uDEF8]|\uD807[\uDC00-\uDC08\uDC0A-\uDC36\uDC38-\uDC40\uDC50-\uDC59\uDC72-\uDC8F\uDC92-\uDCA7\uDCA9-\uDCB6]|\uD808[\uDC00-\uDF99]|\uD809[\uDC00-\uDC6E\uDC80-\uDD43]|[\uD80C\uD81C-\uD820\uD840-\uD868\uD86A-\uD86C\uD86F-\uD872][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD811[\uDC00-\uDE46]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDE60-\uDE69\uDED0-\uDEED\uDEF0-\uDEF4\uDF00-\uDF36\uDF40-\uDF43\uDF50-\uDF59\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50-\uDF7E\uDF8F-\uDF9F\uDFE0]|\uD821[\uDC00-\uDFEC]|\uD822[\uDC00-\uDEF2]|\uD82C[\uDC00\uDC01]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99\uDC9D\uDC9E]|\uD834[\uDD65-\uDD69\uDD6D-\uDD72\uDD7B-\uDD82\uDD85-\uDD8B\uDDAA-\uDDAD\uDE42-\uDE44]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB\uDFCE-\uDFFF]|\uD836[\uDE00-\uDE36\uDE3B-\uDE6C\uDE75\uDE84\uDE9B-\uDE9F\uDEA1-\uDEAF]|\uD838[\uDC00-\uDC06\uDC08-\uDC18\uDC1B-\uDC21\uDC23\uDC24\uDC26-\uDC2A]|\uD83A[\uDC00-\uDCC4\uDCD0-\uDCD6\uDD00-\uDD4A\uDD50-\uDD59]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D\uDC20-\uDFFF]|\uD873[\uDC00-\uDEA1]|\uD87E[\uDC00-\uDE1D]|\uDB40[\uDD00-\uDDEF]/
      };
      function isDecimalDigit(ch2) {
        return 48 <= ch2 && ch2 <= 57;
      }
      __name(isDecimalDigit, "isDecimalDigit");
      function isHexDigit(ch2) {
        return 48 <= ch2 && ch2 <= 57 || // 0..9
        97 <= ch2 && ch2 <= 102 || // a..f
        65 <= ch2 && ch2 <= 70;
      }
      __name(isHexDigit, "isHexDigit");
      function isOctalDigit(ch2) {
        return ch2 >= 48 && ch2 <= 55;
      }
      __name(isOctalDigit, "isOctalDigit");
      NON_ASCII_WHITESPACES = [
        5760,
        8192,
        8193,
        8194,
        8195,
        8196,
        8197,
        8198,
        8199,
        8200,
        8201,
        8202,
        8239,
        8287,
        12288,
        65279
      ];
      function isWhiteSpace(ch2) {
        return ch2 === 32 || ch2 === 9 || ch2 === 11 || ch2 === 12 || ch2 === 160 || ch2 >= 5760 && NON_ASCII_WHITESPACES.indexOf(ch2) >= 0;
      }
      __name(isWhiteSpace, "isWhiteSpace");
      function isLineTerminator(ch2) {
        return ch2 === 10 || ch2 === 13 || ch2 === 8232 || ch2 === 8233;
      }
      __name(isLineTerminator, "isLineTerminator");
      function fromCodePoint(cp) {
        if (cp <= 65535) {
          return String.fromCharCode(cp);
        }
        var cu1 = String.fromCharCode(Math.floor((cp - 65536) / 1024) + 55296);
        var cu2 = String.fromCharCode((cp - 65536) % 1024 + 56320);
        return cu1 + cu2;
      }
      __name(fromCodePoint, "fromCodePoint");
      IDENTIFIER_START = new Array(128);
      for (ch = 0; ch < 128; ++ch) {
        IDENTIFIER_START[ch] = ch >= 97 && ch <= 122 || // a..z
        ch >= 65 && ch <= 90 || // A..Z
        ch === 36 || ch === 95;
      }
      IDENTIFIER_PART = new Array(128);
      for (ch = 0; ch < 128; ++ch) {
        IDENTIFIER_PART[ch] = ch >= 97 && ch <= 122 || // a..z
        ch >= 65 && ch <= 90 || // A..Z
        ch >= 48 && ch <= 57 || // 0..9
        ch === 36 || ch === 95;
      }
      function isIdentifierStartES5(ch2) {
        return ch2 < 128 ? IDENTIFIER_START[ch2] : ES5Regex.NonAsciiIdentifierStart.test(fromCodePoint(ch2));
      }
      __name(isIdentifierStartES5, "isIdentifierStartES5");
      function isIdentifierPartES5(ch2) {
        return ch2 < 128 ? IDENTIFIER_PART[ch2] : ES5Regex.NonAsciiIdentifierPart.test(fromCodePoint(ch2));
      }
      __name(isIdentifierPartES5, "isIdentifierPartES5");
      function isIdentifierStartES6(ch2) {
        return ch2 < 128 ? IDENTIFIER_START[ch2] : ES6Regex.NonAsciiIdentifierStart.test(fromCodePoint(ch2));
      }
      __name(isIdentifierStartES6, "isIdentifierStartES6");
      function isIdentifierPartES6(ch2) {
        return ch2 < 128 ? IDENTIFIER_PART[ch2] : ES6Regex.NonAsciiIdentifierPart.test(fromCodePoint(ch2));
      }
      __name(isIdentifierPartES6, "isIdentifierPartES6");
      module2.exports = {
        isDecimalDigit,
        isHexDigit,
        isOctalDigit,
        isWhiteSpace,
        isLineTerminator,
        isIdentifierStartES5,
        isIdentifierPartES5,
        isIdentifierStartES6,
        isIdentifierPartES6
      };
    })();
  }
});

// ../../node_modules/esutils/lib/keyword.js
var require_keyword = __commonJS({
  "../../node_modules/esutils/lib/keyword.js"(exports2, module2) {
    (function() {
      "use strict";
      var code = require_code();
      function isStrictModeReservedWordES6(id) {
        switch (id) {
          case "implements":
          case "interface":
          case "package":
          case "private":
          case "protected":
          case "public":
          case "static":
          case "let":
            return true;
          default:
            return false;
        }
      }
      __name(isStrictModeReservedWordES6, "isStrictModeReservedWordES6");
      function isKeywordES5(id, strict) {
        if (!strict && id === "yield") {
          return false;
        }
        return isKeywordES6(id, strict);
      }
      __name(isKeywordES5, "isKeywordES5");
      function isKeywordES6(id, strict) {
        if (strict && isStrictModeReservedWordES6(id)) {
          return true;
        }
        switch (id.length) {
          case 2:
            return id === "if" || id === "in" || id === "do";
          case 3:
            return id === "var" || id === "for" || id === "new" || id === "try";
          case 4:
            return id === "this" || id === "else" || id === "case" || id === "void" || id === "with" || id === "enum";
          case 5:
            return id === "while" || id === "break" || id === "catch" || id === "throw" || id === "const" || id === "yield" || id === "class" || id === "super";
          case 6:
            return id === "return" || id === "typeof" || id === "delete" || id === "switch" || id === "export" || id === "import";
          case 7:
            return id === "default" || id === "finally" || id === "extends";
          case 8:
            return id === "function" || id === "continue" || id === "debugger";
          case 10:
            return id === "instanceof";
          default:
            return false;
        }
      }
      __name(isKeywordES6, "isKeywordES6");
      function isReservedWordES5(id, strict) {
        return id === "null" || id === "true" || id === "false" || isKeywordES5(id, strict);
      }
      __name(isReservedWordES5, "isReservedWordES5");
      function isReservedWordES6(id, strict) {
        return id === "null" || id === "true" || id === "false" || isKeywordES6(id, strict);
      }
      __name(isReservedWordES6, "isReservedWordES6");
      function isRestrictedWord(id) {
        return id === "eval" || id === "arguments";
      }
      __name(isRestrictedWord, "isRestrictedWord");
      function isIdentifierNameES5(id) {
        var i32, iz, ch;
        if (id.length === 0) {
          return false;
        }
        ch = id.charCodeAt(0);
        if (!code.isIdentifierStartES5(ch)) {
          return false;
        }
        for (i32 = 1, iz = id.length; i32 < iz; ++i32) {
          ch = id.charCodeAt(i32);
          if (!code.isIdentifierPartES5(ch)) {
            return false;
          }
        }
        return true;
      }
      __name(isIdentifierNameES5, "isIdentifierNameES5");
      function decodeUtf16(lead, trail) {
        return (lead - 55296) * 1024 + (trail - 56320) + 65536;
      }
      __name(decodeUtf16, "decodeUtf16");
      function isIdentifierNameES6(id) {
        var i32, iz, ch, lowCh, check;
        if (id.length === 0) {
          return false;
        }
        check = code.isIdentifierStartES6;
        for (i32 = 0, iz = id.length; i32 < iz; ++i32) {
          ch = id.charCodeAt(i32);
          if (55296 <= ch && ch <= 56319) {
            ++i32;
            if (i32 >= iz) {
              return false;
            }
            lowCh = id.charCodeAt(i32);
            if (!(56320 <= lowCh && lowCh <= 57343)) {
              return false;
            }
            ch = decodeUtf16(ch, lowCh);
          }
          if (!check(ch)) {
            return false;
          }
          check = code.isIdentifierPartES6;
        }
        return true;
      }
      __name(isIdentifierNameES6, "isIdentifierNameES6");
      function isIdentifierES5(id, strict) {
        return isIdentifierNameES5(id) && !isReservedWordES5(id, strict);
      }
      __name(isIdentifierES5, "isIdentifierES5");
      function isIdentifierES6(id, strict) {
        return isIdentifierNameES6(id) && !isReservedWordES6(id, strict);
      }
      __name(isIdentifierES6, "isIdentifierES6");
      module2.exports = {
        isKeywordES5,
        isKeywordES6,
        isReservedWordES5,
        isReservedWordES6,
        isRestrictedWord,
        isIdentifierNameES5,
        isIdentifierNameES6,
        isIdentifierES5,
        isIdentifierES6
      };
    })();
  }
});

// ../../node_modules/esutils/lib/utils.js
var require_utils10 = __commonJS({
  "../../node_modules/esutils/lib/utils.js"(exports2) {
    (function() {
      "use strict";
      exports2.ast = require_ast();
      exports2.code = require_code();
      exports2.keyword = require_keyword();
    })();
  }
});

// ../../node_modules/source-map/lib/base64.js
var require_base64 = __commonJS({
  "../../node_modules/source-map/lib/base64.js"(exports2) {
    var intToCharMap = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/".split("");
    exports2.encode = function(number) {
      if (0 <= number && number < intToCharMap.length) {
        return intToCharMap[number];
      }
      throw new TypeError("Must be between 0 and 63: " + number);
    };
    exports2.decode = function(charCode) {
      var bigA = 65;
      var bigZ = 90;
      var littleA = 97;
      var littleZ = 122;
      var zero = 48;
      var nine = 57;
      var plus = 43;
      var slash = 47;
      var littleOffset = 26;
      var numberOffset = 52;
      if (bigA <= charCode && charCode <= bigZ) {
        return charCode - bigA;
      }
      if (littleA <= charCode && charCode <= littleZ) {
        return charCode - littleA + littleOffset;
      }
      if (zero <= charCode && charCode <= nine) {
        return charCode - zero + numberOffset;
      }
      if (charCode == plus) {
        return 62;
      }
      if (charCode == slash) {
        return 63;
      }
      return -1;
    };
  }
});

// ../../node_modules/source-map/lib/base64-vlq.js
var require_base64_vlq = __commonJS({
  "../../node_modules/source-map/lib/base64-vlq.js"(exports2) {
    var base64 = require_base64();
    var VLQ_BASE_SHIFT = 5;
    var VLQ_BASE = 1 << VLQ_BASE_SHIFT;
    var VLQ_BASE_MASK = VLQ_BASE - 1;
    var VLQ_CONTINUATION_BIT = VLQ_BASE;
    function toVLQSigned(aValue) {
      return aValue < 0 ? (-aValue << 1) + 1 : (aValue << 1) + 0;
    }
    __name(toVLQSigned, "toVLQSigned");
    function fromVLQSigned(aValue) {
      var isNegative = (aValue & 1) === 1;
      var shifted = aValue >> 1;
      return isNegative ? -shifted : shifted;
    }
    __name(fromVLQSigned, "fromVLQSigned");
    exports2.encode = /* @__PURE__ */ __name(function base64VLQ_encode(aValue) {
      var encoded = "";
      var digit;
      var vlq = toVLQSigned(aValue);
      do {
        digit = vlq & VLQ_BASE_MASK;
        vlq >>>= VLQ_BASE_SHIFT;
        if (vlq > 0) {
          digit |= VLQ_CONTINUATION_BIT;
        }
        encoded += base64.encode(digit);
      } while (vlq > 0);
      return encoded;
    }, "base64VLQ_encode");
    exports2.decode = /* @__PURE__ */ __name(function base64VLQ_decode(aStr, aIndex, aOutParam) {
      var strLen = aStr.length;
      var result2 = 0;
      var shift = 0;
      var continuation, digit;
      do {
        if (aIndex >= strLen) {
          throw new Error("Expected more digits in base 64 VLQ value.");
        }
        digit = base64.decode(aStr.charCodeAt(aIndex++));
        if (digit === -1) {
          throw new Error("Invalid base64 digit: " + aStr.charAt(aIndex - 1));
        }
        continuation = !!(digit & VLQ_CONTINUATION_BIT);
        digit &= VLQ_BASE_MASK;
        result2 = result2 + (digit << shift);
        shift += VLQ_BASE_SHIFT;
      } while (continuation);
      aOutParam.value = fromVLQSigned(result2);
      aOutParam.rest = aIndex;
    }, "base64VLQ_decode");
  }
});

// ../../node_modules/source-map/lib/util.js
var require_util3 = __commonJS({
  "../../node_modules/source-map/lib/util.js"(exports2) {
    function getArg(aArgs, aName, aDefaultValue) {
      if (aName in aArgs) {
        return aArgs[aName];
      } else if (arguments.length === 3) {
        return aDefaultValue;
      } else {
        throw new Error('"' + aName + '" is a required argument.');
      }
    }
    __name(getArg, "getArg");
    exports2.getArg = getArg;
    var urlRegexp = /^(?:([\w+\-.]+):)?\/\/(?:(\w+:\w+)@)?([\w.-]*)(?::(\d+))?(.*)$/;
    var dataUrlRegexp = /^data:.+\,.+$/;
    function urlParse(aUrl) {
      var match = aUrl.match(urlRegexp);
      if (!match) {
        return null;
      }
      return {
        scheme: match[1],
        auth: match[2],
        host: match[3],
        port: match[4],
        path: match[5]
      };
    }
    __name(urlParse, "urlParse");
    exports2.urlParse = urlParse;
    function urlGenerate(aParsedUrl) {
      var url = "";
      if (aParsedUrl.scheme) {
        url += aParsedUrl.scheme + ":";
      }
      url += "//";
      if (aParsedUrl.auth) {
        url += aParsedUrl.auth + "@";
      }
      if (aParsedUrl.host) {
        url += aParsedUrl.host;
      }
      if (aParsedUrl.port) {
        url += ":" + aParsedUrl.port;
      }
      if (aParsedUrl.path) {
        url += aParsedUrl.path;
      }
      return url;
    }
    __name(urlGenerate, "urlGenerate");
    exports2.urlGenerate = urlGenerate;
    function normalize4(aPath) {
      var path47 = aPath;
      var url = urlParse(aPath);
      if (url) {
        if (!url.path) {
          return aPath;
        }
        path47 = url.path;
      }
      var isAbsolute3 = exports2.isAbsolute(path47);
      var parts = path47.split(/\/+/);
      for (var part, up = 0, i32 = parts.length - 1; i32 >= 0; i32--) {
        part = parts[i32];
        if (part === ".") {
          parts.splice(i32, 1);
        } else if (part === "..") {
          up++;
        } else if (up > 0) {
          if (part === "") {
            parts.splice(i32 + 1, up);
            up = 0;
          } else {
            parts.splice(i32, 2);
            up--;
          }
        }
      }
      path47 = parts.join("/");
      if (path47 === "") {
        path47 = isAbsolute3 ? "/" : ".";
      }
      if (url) {
        url.path = path47;
        return urlGenerate(url);
      }
      return path47;
    }
    __name(normalize4, "normalize");
    exports2.normalize = normalize4;
    function join59(aRoot, aPath) {
      if (aRoot === "") {
        aRoot = ".";
      }
      if (aPath === "") {
        aPath = ".";
      }
      var aPathUrl = urlParse(aPath);
      var aRootUrl = urlParse(aRoot);
      if (aRootUrl) {
        aRoot = aRootUrl.path || "/";
      }
      if (aPathUrl && !aPathUrl.scheme) {
        if (aRootUrl) {
          aPathUrl.scheme = aRootUrl.scheme;
        }
        return urlGenerate(aPathUrl);
      }
      if (aPathUrl || aPath.match(dataUrlRegexp)) {
        return aPath;
      }
      if (aRootUrl && !aRootUrl.host && !aRootUrl.path) {
        aRootUrl.host = aPath;
        return urlGenerate(aRootUrl);
      }
      var joined = aPath.charAt(0) === "/" ? aPath : normalize4(aRoot.replace(/\/+$/, "") + "/" + aPath);
      if (aRootUrl) {
        aRootUrl.path = joined;
        return urlGenerate(aRootUrl);
      }
      return joined;
    }
    __name(join59, "join");
    exports2.join = join59;
    exports2.isAbsolute = function(aPath) {
      return aPath.charAt(0) === "/" || urlRegexp.test(aPath);
    };
    function relative5(aRoot, aPath) {
      if (aRoot === "") {
        aRoot = ".";
      }
      aRoot = aRoot.replace(/\/$/, "");
      var level = 0;
      while (aPath.indexOf(aRoot + "/") !== 0) {
        var index = aRoot.lastIndexOf("/");
        if (index < 0) {
          return aPath;
        }
        aRoot = aRoot.slice(0, index);
        if (aRoot.match(/^([^\/]+:\/)?\/*$/)) {
          return aPath;
        }
        ++level;
      }
      return Array(level + 1).join("../") + aPath.substr(aRoot.length + 1);
    }
    __name(relative5, "relative");
    exports2.relative = relative5;
    var supportsNullProto = (function() {
      var obj = /* @__PURE__ */ Object.create(null);
      return !("__proto__" in obj);
    })();
    function identity(s) {
      return s;
    }
    __name(identity, "identity");
    function toSetString(aStr) {
      if (isProtoString(aStr)) {
        return "$" + aStr;
      }
      return aStr;
    }
    __name(toSetString, "toSetString");
    exports2.toSetString = supportsNullProto ? identity : toSetString;
    function fromSetString(aStr) {
      if (isProtoString(aStr)) {
        return aStr.slice(1);
      }
      return aStr;
    }
    __name(fromSetString, "fromSetString");
    exports2.fromSetString = supportsNullProto ? identity : fromSetString;
    function isProtoString(s) {
      if (!s) {
        return false;
      }
      var length = s.length;
      if (length < 9) {
        return false;
      }
      if (s.charCodeAt(length - 1) !== 95 || s.charCodeAt(length - 2) !== 95 || s.charCodeAt(length - 3) !== 111 || s.charCodeAt(length - 4) !== 116 || s.charCodeAt(length - 5) !== 111 || s.charCodeAt(length - 6) !== 114 || s.charCodeAt(length - 7) !== 112 || s.charCodeAt(length - 8) !== 95 || s.charCodeAt(length - 9) !== 95) {
        return false;
      }
      for (var i32 = length - 10; i32 >= 0; i32--) {
        if (s.charCodeAt(i32) !== 36) {
          return false;
        }
      }
      return true;
    }
    __name(isProtoString, "isProtoString");
    function compareByOriginalPositions(mappingA, mappingB, onlyCompareOriginal) {
      var cmp = strcmp(mappingA.source, mappingB.source);
      if (cmp !== 0) {
        return cmp;
      }
      cmp = mappingA.originalLine - mappingB.originalLine;
      if (cmp !== 0) {
        return cmp;
      }
      cmp = mappingA.originalColumn - mappingB.originalColumn;
      if (cmp !== 0 || onlyCompareOriginal) {
        return cmp;
      }
      cmp = mappingA.generatedColumn - mappingB.generatedColumn;
      if (cmp !== 0) {
        return cmp;
      }
      cmp = mappingA.generatedLine - mappingB.generatedLine;
      if (cmp !== 0) {
        return cmp;
      }
      return strcmp(mappingA.name, mappingB.name);
    }
    __name(compareByOriginalPositions, "compareByOriginalPositions");
    exports2.compareByOriginalPositions = compareByOriginalPositions;
    function compareByGeneratedPositionsDeflated(mappingA, mappingB, onlyCompareGenerated) {
      var cmp = mappingA.generatedLine - mappingB.generatedLine;
      if (cmp !== 0) {
        return cmp;
      }
      cmp = mappingA.generatedColumn - mappingB.generatedColumn;
      if (cmp !== 0 || onlyCompareGenerated) {
        return cmp;
      }
      cmp = strcmp(mappingA.source, mappingB.source);
      if (cmp !== 0) {
        return cmp;
      }
      cmp = mappingA.originalLine - mappingB.originalLine;
      if (cmp !== 0) {
        return cmp;
      }
      cmp = mappingA.originalColumn - mappingB.originalColumn;
      if (cmp !== 0) {
        return cmp;
      }
      return strcmp(mappingA.name, mappingB.name);
    }
    __name(compareByGeneratedPositionsDeflated, "compareByGeneratedPositionsDeflated");
    exports2.compareByGeneratedPositionsDeflated = compareByGeneratedPositionsDeflated;
    function strcmp(aStr1, aStr2) {
      if (aStr1 === aStr2) {
        return 0;
      }
      if (aStr1 === null) {
        return 1;
      }
      if (aStr2 === null) {
        return -1;
      }
      if (aStr1 > aStr2) {
        return 1;
      }
      return -1;
    }
    __name(strcmp, "strcmp");
    function compareByGeneratedPositionsInflated(mappingA, mappingB) {
      var cmp = mappingA.generatedLine - mappingB.generatedLine;
      if (cmp !== 0) {
        return cmp;
      }
      cmp = mappingA.generatedColumn - mappingB.generatedColumn;
      if (cmp !== 0) {
        return cmp;
      }
      cmp = strcmp(mappingA.source, mappingB.source);
      if (cmp !== 0) {
        return cmp;
      }
      cmp = mappingA.originalLine - mappingB.originalLine;
      if (cmp !== 0) {
        return cmp;
      }
      cmp = mappingA.originalColumn - mappingB.originalColumn;
      if (cmp !== 0) {
        return cmp;
      }
      return strcmp(mappingA.name, mappingB.name);
    }
    __name(compareByGeneratedPositionsInflated, "compareByGeneratedPositionsInflated");
    exports2.compareByGeneratedPositionsInflated = compareByGeneratedPositionsInflated;
    function parseSourceMapInput(str) {
      return JSON.parse(str.replace(/^\)]}'[^\n]*\n/, ""));
    }
    __name(parseSourceMapInput, "parseSourceMapInput");
    exports2.parseSourceMapInput = parseSourceMapInput;
    function computeSourceURL(sourceRoot, sourceURL, sourceMapURL) {
      sourceURL = sourceURL || "";
      if (sourceRoot) {
        if (sourceRoot[sourceRoot.length - 1] !== "/" && sourceURL[0] !== "/") {
          sourceRoot += "/";
        }
        sourceURL = sourceRoot + sourceURL;
      }
      if (sourceMapURL) {
        var parsed = urlParse(sourceMapURL);
        if (!parsed) {
          throw new Error("sourceMapURL could not be parsed");
        }
        if (parsed.path) {
          var index = parsed.path.lastIndexOf("/");
          if (index >= 0) {
            parsed.path = parsed.path.substring(0, index + 1);
          }
        }
        sourceURL = join59(urlGenerate(parsed), sourceURL);
      }
      return normalize4(sourceURL);
    }
    __name(computeSourceURL, "computeSourceURL");
    exports2.computeSourceURL = computeSourceURL;
  }
});

// ../../node_modules/source-map/lib/array-set.js
var require_array_set = __commonJS({
  "../../node_modules/source-map/lib/array-set.js"(exports2) {
    var util11 = require_util3();
    var has = Object.prototype.hasOwnProperty;
    var hasNativeMap = typeof Map !== "undefined";
    function ArraySet() {
      this._array = [];
      this._set = hasNativeMap ? /* @__PURE__ */ new Map() : /* @__PURE__ */ Object.create(null);
    }
    __name(ArraySet, "ArraySet");
    ArraySet.fromArray = /* @__PURE__ */ __name(function ArraySet_fromArray(aArray, aAllowDuplicates) {
      var set = new ArraySet();
      for (var i32 = 0, len = aArray.length; i32 < len; i32++) {
        set.add(aArray[i32], aAllowDuplicates);
      }
      return set;
    }, "ArraySet_fromArray");
    ArraySet.prototype.size = /* @__PURE__ */ __name(function ArraySet_size() {
      return hasNativeMap ? this._set.size : Object.getOwnPropertyNames(this._set).length;
    }, "ArraySet_size");
    ArraySet.prototype.add = /* @__PURE__ */ __name(function ArraySet_add(aStr, aAllowDuplicates) {
      var sStr = hasNativeMap ? aStr : util11.toSetString(aStr);
      var isDuplicate = hasNativeMap ? this.has(aStr) : has.call(this._set, sStr);
      var idx = this._array.length;
      if (!isDuplicate || aAllowDuplicates) {
        this._array.push(aStr);
      }
      if (!isDuplicate) {
        if (hasNativeMap) {
          this._set.set(aStr, idx);
        } else {
          this._set[sStr] = idx;
        }
      }
    }, "ArraySet_add");
    ArraySet.prototype.has = /* @__PURE__ */ __name(function ArraySet_has(aStr) {
      if (hasNativeMap) {
        return this._set.has(aStr);
      } else {
        var sStr = util11.toSetString(aStr);
        return has.call(this._set, sStr);
      }
    }, "ArraySet_has");
    ArraySet.prototype.indexOf = /* @__PURE__ */ __name(function ArraySet_indexOf(aStr) {
      if (hasNativeMap) {
        var idx = this._set.get(aStr);
        if (idx >= 0) {
          return idx;
        }
      } else {
        var sStr = util11.toSetString(aStr);
        if (has.call(this._set, sStr)) {
          return this._set[sStr];
        }
      }
      throw new Error('"' + aStr + '" is not in the set.');
    }, "ArraySet_indexOf");
    ArraySet.prototype.at = /* @__PURE__ */ __name(function ArraySet_at(aIdx) {
      if (aIdx >= 0 && aIdx < this._array.length) {
        return this._array[aIdx];
      }
      throw new Error("No element indexed by " + aIdx);
    }, "ArraySet_at");
    ArraySet.prototype.toArray = /* @__PURE__ */ __name(function ArraySet_toArray() {
      return this._array.slice();
    }, "ArraySet_toArray");
    exports2.ArraySet = ArraySet;
  }
});

// ../../node_modules/source-map/lib/mapping-list.js
var require_mapping_list = __commonJS({
  "../../node_modules/source-map/lib/mapping-list.js"(exports2) {
    var util11 = require_util3();
    function generatedPositionAfter(mappingA, mappingB) {
      var lineA = mappingA.generatedLine;
      var lineB = mappingB.generatedLine;
      var columnA = mappingA.generatedColumn;
      var columnB = mappingB.generatedColumn;
      return lineB > lineA || lineB == lineA && columnB >= columnA || util11.compareByGeneratedPositionsInflated(mappingA, mappingB) <= 0;
    }
    __name(generatedPositionAfter, "generatedPositionAfter");
    function MappingList() {
      this._array = [];
      this._sorted = true;
      this._last = { generatedLine: -1, generatedColumn: 0 };
    }
    __name(MappingList, "MappingList");
    MappingList.prototype.unsortedForEach = /* @__PURE__ */ __name(function MappingList_forEach(aCallback, aThisArg) {
      this._array.forEach(aCallback, aThisArg);
    }, "MappingList_forEach");
    MappingList.prototype.add = /* @__PURE__ */ __name(function MappingList_add(aMapping) {
      if (generatedPositionAfter(this._last, aMapping)) {
        this._last = aMapping;
        this._array.push(aMapping);
      } else {
        this._sorted = false;
        this._array.push(aMapping);
      }
    }, "MappingList_add");
    MappingList.prototype.toArray = /* @__PURE__ */ __name(function MappingList_toArray() {
      if (!this._sorted) {
        this._array.sort(util11.compareByGeneratedPositionsInflated);
        this._sorted = true;
      }
      return this._array;
    }, "MappingList_toArray");
    exports2.MappingList = MappingList;
  }
});

// ../../node_modules/source-map/lib/source-map-generator.js
var require_source_map_generator = __commonJS({
  "../../node_modules/source-map/lib/source-map-generator.js"(exports2) {
    var base64VLQ = require_base64_vlq();
    var util11 = require_util3();
    var ArraySet = require_array_set().ArraySet;
    var MappingList = require_mapping_list().MappingList;
    function SourceMapGenerator(aArgs) {
      if (!aArgs) {
        aArgs = {};
      }
      this._file = util11.getArg(aArgs, "file", null);
      this._sourceRoot = util11.getArg(aArgs, "sourceRoot", null);
      this._skipValidation = util11.getArg(aArgs, "skipValidation", false);
      this._sources = new ArraySet();
      this._names = new ArraySet();
      this._mappings = new MappingList();
      this._sourcesContents = null;
    }
    __name(SourceMapGenerator, "SourceMapGenerator");
    SourceMapGenerator.prototype._version = 3;
    SourceMapGenerator.fromSourceMap = /* @__PURE__ */ __name(function SourceMapGenerator_fromSourceMap(aSourceMapConsumer) {
      var sourceRoot = aSourceMapConsumer.sourceRoot;
      var generator = new SourceMapGenerator({
        file: aSourceMapConsumer.file,
        sourceRoot
      });
      aSourceMapConsumer.eachMapping(function(mapping) {
        var newMapping = {
          generated: {
            line: mapping.generatedLine,
            column: mapping.generatedColumn
          }
        };
        if (mapping.source != null) {
          newMapping.source = mapping.source;
          if (sourceRoot != null) {
            newMapping.source = util11.relative(sourceRoot, newMapping.source);
          }
          newMapping.original = {
            line: mapping.originalLine,
            column: mapping.originalColumn
          };
          if (mapping.name != null) {
            newMapping.name = mapping.name;
          }
        }
        generator.addMapping(newMapping);
      });
      aSourceMapConsumer.sources.forEach(function(sourceFile) {
        var sourceRelative = sourceFile;
        if (sourceRoot !== null) {
          sourceRelative = util11.relative(sourceRoot, sourceFile);
        }
        if (!generator._sources.has(sourceRelative)) {
          generator._sources.add(sourceRelative);
        }
        var content = aSourceMapConsumer.sourceContentFor(sourceFile);
        if (content != null) {
          generator.setSourceContent(sourceFile, content);
        }
      });
      return generator;
    }, "SourceMapGenerator_fromSourceMap");
    SourceMapGenerator.prototype.addMapping = /* @__PURE__ */ __name(function SourceMapGenerator_addMapping(aArgs) {
      var generated = util11.getArg(aArgs, "generated");
      var original = util11.getArg(aArgs, "original", null);
      var source = util11.getArg(aArgs, "source", null);
      var name = util11.getArg(aArgs, "name", null);
      if (!this._skipValidation) {
        this._validateMapping(generated, original, source, name);
      }
      if (source != null) {
        source = String(source);
        if (!this._sources.has(source)) {
          this._sources.add(source);
        }
      }
      if (name != null) {
        name = String(name);
        if (!this._names.has(name)) {
          this._names.add(name);
        }
      }
      this._mappings.add({
        generatedLine: generated.line,
        generatedColumn: generated.column,
        originalLine: original != null && original.line,
        originalColumn: original != null && original.column,
        source,
        name
      });
    }, "SourceMapGenerator_addMapping");
    SourceMapGenerator.prototype.setSourceContent = /* @__PURE__ */ __name(function SourceMapGenerator_setSourceContent(aSourceFile, aSourceContent) {
      var source = aSourceFile;
      if (this._sourceRoot != null) {
        source = util11.relative(this._sourceRoot, source);
      }
      if (aSourceContent != null) {
        if (!this._sourcesContents) {
          this._sourcesContents = /* @__PURE__ */ Object.create(null);
        }
        this._sourcesContents[util11.toSetString(source)] = aSourceContent;
      } else if (this._sourcesContents) {
        delete this._sourcesContents[util11.toSetString(source)];
        if (Object.keys(this._sourcesContents).length === 0) {
          this._sourcesContents = null;
        }
      }
    }, "SourceMapGenerator_setSourceContent");
    SourceMapGenerator.prototype.applySourceMap = /* @__PURE__ */ __name(function SourceMapGenerator_applySourceMap(aSourceMapConsumer, aSourceFile, aSourceMapPath) {
      var sourceFile = aSourceFile;
      if (aSourceFile == null) {
        if (aSourceMapConsumer.file == null) {
          throw new Error(
            `SourceMapGenerator.prototype.applySourceMap requires either an explicit source file, or the source map's "file" property. Both were omitted.`
          );
        }
        sourceFile = aSourceMapConsumer.file;
      }
      var sourceRoot = this._sourceRoot;
      if (sourceRoot != null) {
        sourceFile = util11.relative(sourceRoot, sourceFile);
      }
      var newSources = new ArraySet();
      var newNames = new ArraySet();
      this._mappings.unsortedForEach(function(mapping) {
        if (mapping.source === sourceFile && mapping.originalLine != null) {
          var original = aSourceMapConsumer.originalPositionFor({
            line: mapping.originalLine,
            column: mapping.originalColumn
          });
          if (original.source != null) {
            mapping.source = original.source;
            if (aSourceMapPath != null) {
              mapping.source = util11.join(aSourceMapPath, mapping.source);
            }
            if (sourceRoot != null) {
              mapping.source = util11.relative(sourceRoot, mapping.source);
            }
            mapping.originalLine = original.line;
            mapping.originalColumn = original.column;
            if (original.name != null) {
              mapping.name = original.name;
            }
          }
        }
        var source = mapping.source;
        if (source != null && !newSources.has(source)) {
          newSources.add(source);
        }
        var name = mapping.name;
        if (name != null && !newNames.has(name)) {
          newNames.add(name);
        }
      }, this);
      this._sources = newSources;
      this._names = newNames;
      aSourceMapConsumer.sources.forEach(function(sourceFile2) {
        var content = aSourceMapConsumer.sourceContentFor(sourceFile2);
        if (content != null) {
          if (aSourceMapPath != null) {
            sourceFile2 = util11.join(aSourceMapPath, sourceFile2);
          }
          if (sourceRoot != null) {
            sourceFile2 = util11.relative(sourceRoot, sourceFile2);
          }
          this.setSourceContent(sourceFile2, content);
        }
      }, this);
    }, "SourceMapGenerator_applySourceMap");
    SourceMapGenerator.prototype._validateMapping = /* @__PURE__ */ __name(function SourceMapGenerator_validateMapping(aGenerated, aOriginal, aSource, aName) {
      if (aOriginal && typeof aOriginal.line !== "number" && typeof aOriginal.column !== "number") {
        throw new Error(
          "original.line and original.column are not numbers -- you probably meant to omit the original mapping entirely and only map the generated position. If so, pass null for the original mapping instead of an object with empty or null values."
        );
      }
      if (aGenerated && "line" in aGenerated && "column" in aGenerated && aGenerated.line > 0 && aGenerated.column >= 0 && !aOriginal && !aSource && !aName) {
        return;
      } else if (aGenerated && "line" in aGenerated && "column" in aGenerated && aOriginal && "line" in aOriginal && "column" in aOriginal && aGenerated.line > 0 && aGenerated.column >= 0 && aOriginal.line > 0 && aOriginal.column >= 0 && aSource) {
        return;
      } else {
        throw new Error("Invalid mapping: " + JSON.stringify({
          generated: aGenerated,
          source: aSource,
          original: aOriginal,
          name: aName
        }));
      }
    }, "SourceMapGenerator_validateMapping");
    SourceMapGenerator.prototype._serializeMappings = /* @__PURE__ */ __name(function SourceMapGenerator_serializeMappings() {
      var previousGeneratedColumn = 0;
      var previousGeneratedLine = 1;
      var previousOriginalColumn = 0;
      var previousOriginalLine = 0;
      var previousName = 0;
      var previousSource = 0;
      var result2 = "";
      var next;
      var mapping;
      var nameIdx;
      var sourceIdx;
      var mappings = this._mappings.toArray();
      for (var i32 = 0, len = mappings.length; i32 < len; i32++) {
        mapping = mappings[i32];
        next = "";
        if (mapping.generatedLine !== previousGeneratedLine) {
          previousGeneratedColumn = 0;
          while (mapping.generatedLine !== previousGeneratedLine) {
            next += ";";
            previousGeneratedLine++;
          }
        } else {
          if (i32 > 0) {
            if (!util11.compareByGeneratedPositionsInflated(mapping, mappings[i32 - 1])) {
              continue;
            }
            next += ",";
          }
        }
        next += base64VLQ.encode(mapping.generatedColumn - previousGeneratedColumn);
        previousGeneratedColumn = mapping.generatedColumn;
        if (mapping.source != null) {
          sourceIdx = this._sources.indexOf(mapping.source);
          next += base64VLQ.encode(sourceIdx - previousSource);
          previousSource = sourceIdx;
          next += base64VLQ.encode(mapping.originalLine - 1 - previousOriginalLine);
          previousOriginalLine = mapping.originalLine - 1;
          next += base64VLQ.encode(mapping.originalColumn - previousOriginalColumn);
          previousOriginalColumn = mapping.originalColumn;
          if (mapping.name != null) {
            nameIdx = this._names.indexOf(mapping.name);
            next += base64VLQ.encode(nameIdx - previousName);
            previousName = nameIdx;
          }
        }
        result2 += next;
      }
      return result2;
    }, "SourceMapGenerator_serializeMappings");
    SourceMapGenerator.prototype._generateSourcesContent = /* @__PURE__ */ __name(function SourceMapGenerator_generateSourcesContent(aSources, aSourceRoot) {
      return aSources.map(function(source) {
        if (!this._sourcesContents) {
          return null;
        }
        if (aSourceRoot != null) {
          source = util11.relative(aSourceRoot, source);
        }
        var key = util11.toSetString(source);
        return Object.prototype.hasOwnProperty.call(this._sourcesContents, key) ? this._sourcesContents[key] : null;
      }, this);
    }, "SourceMapGenerator_generateSourcesContent");
    SourceMapGenerator.prototype.toJSON = /* @__PURE__ */ __name(function SourceMapGenerator_toJSON() {
      var map5 = {
        version: this._version,
        sources: this._sources.toArray(),
        names: this._names.toArray(),
        mappings: this._serializeMappings()
      };
      if (this._file != null) {
        map5.file = this._file;
      }
      if (this._sourceRoot != null) {
        map5.sourceRoot = this._sourceRoot;
      }
      if (this._sourcesContents) {
        map5.sourcesContent = this._generateSourcesContent(map5.sources, map5.sourceRoot);
      }
      return map5;
    }, "SourceMapGenerator_toJSON");
    SourceMapGenerator.prototype.toString = /* @__PURE__ */ __name(function SourceMapGenerator_toString() {
      return JSON.stringify(this.toJSON());
    }, "SourceMapGenerator_toString");
    exports2.SourceMapGenerator = SourceMapGenerator;
  }
});

// ../../node_modules/source-map/lib/binary-search.js
var require_binary_search = __commonJS({
  "../../node_modules/source-map/lib/binary-search.js"(exports2) {
    exports2.GREATEST_LOWER_BOUND = 1;
    exports2.LEAST_UPPER_BOUND = 2;
    function recursiveSearch(aLow, aHigh, aNeedle, aHaystack, aCompare, aBias) {
      var mid = Math.floor((aHigh - aLow) / 2) + aLow;
      var cmp = aCompare(aNeedle, aHaystack[mid], true);
      if (cmp === 0) {
        return mid;
      } else if (cmp > 0) {
        if (aHigh - mid > 1) {
          return recursiveSearch(mid, aHigh, aNeedle, aHaystack, aCompare, aBias);
        }
        if (aBias == exports2.LEAST_UPPER_BOUND) {
          return aHigh < aHaystack.length ? aHigh : -1;
        } else {
          return mid;
        }
      } else {
        if (mid - aLow > 1) {
          return recursiveSearch(aLow, mid, aNeedle, aHaystack, aCompare, aBias);
        }
        if (aBias == exports2.LEAST_UPPER_BOUND) {
          return mid;
        } else {
          return aLow < 0 ? -1 : aLow;
        }
      }
    }
    __name(recursiveSearch, "recursiveSearch");
    exports2.search = /* @__PURE__ */ __name(function search(aNeedle, aHaystack, aCompare, aBias) {
      if (aHaystack.length === 0) {
        return -1;
      }
      var index = recursiveSearch(
        -1,
        aHaystack.length,
        aNeedle,
        aHaystack,
        aCompare,
        aBias || exports2.GREATEST_LOWER_BOUND
      );
      if (index < 0) {
        return -1;
      }
      while (index - 1 >= 0) {
        if (aCompare(aHaystack[index], aHaystack[index - 1], true) !== 0) {
          break;
        }
        --index;
      }
      return index;
    }, "search");
  }
});

// ../../node_modules/source-map/lib/quick-sort.js
var require_quick_sort = __commonJS({
  "../../node_modules/source-map/lib/quick-sort.js"(exports2) {
    function swap(ary, x, y) {
      var temp = ary[x];
      ary[x] = ary[y];
      ary[y] = temp;
    }
    __name(swap, "swap");
    function randomIntInRange(low, high) {
      return Math.round(low + Math.random() * (high - low));
    }
    __name(randomIntInRange, "randomIntInRange");
    function doQuickSort(ary, comparator, p10, r32) {
      if (p10 < r32) {
        var pivotIndex = randomIntInRange(p10, r32);
        var i32 = p10 - 1;
        swap(ary, pivotIndex, r32);
        var pivot = ary[r32];
        for (var j32 = p10; j32 < r32; j32++) {
          if (comparator(ary[j32], pivot) <= 0) {
            i32 += 1;
            swap(ary, i32, j32);
          }
        }
        swap(ary, i32 + 1, j32);
        var q10 = i32 + 1;
        doQuickSort(ary, comparator, p10, q10 - 1);
        doQuickSort(ary, comparator, q10 + 1, r32);
      }
    }
    __name(doQuickSort, "doQuickSort");
    exports2.quickSort = function(ary, comparator) {
      doQuickSort(ary, comparator, 0, ary.length - 1);
    };
  }
});

// ../../node_modules/source-map/lib/source-map-consumer.js
var require_source_map_consumer = __commonJS({
  "../../node_modules/source-map/lib/source-map-consumer.js"(exports2) {
    var util11 = require_util3();
    var binarySearch = require_binary_search();
    var ArraySet = require_array_set().ArraySet;
    var base64VLQ = require_base64_vlq();
    var quickSort = require_quick_sort().quickSort;
    function SourceMapConsumer(aSourceMap, aSourceMapURL) {
      var sourceMap = aSourceMap;
      if (typeof aSourceMap === "string") {
        sourceMap = util11.parseSourceMapInput(aSourceMap);
      }
      return sourceMap.sections != null ? new IndexedSourceMapConsumer(sourceMap, aSourceMapURL) : new BasicSourceMapConsumer(sourceMap, aSourceMapURL);
    }
    __name(SourceMapConsumer, "SourceMapConsumer");
    SourceMapConsumer.fromSourceMap = function(aSourceMap, aSourceMapURL) {
      return BasicSourceMapConsumer.fromSourceMap(aSourceMap, aSourceMapURL);
    };
    SourceMapConsumer.prototype._version = 3;
    SourceMapConsumer.prototype.__generatedMappings = null;
    Object.defineProperty(SourceMapConsumer.prototype, "_generatedMappings", {
      configurable: true,
      enumerable: true,
      get: /* @__PURE__ */ __name(function() {
        if (!this.__generatedMappings) {
          this._parseMappings(this._mappings, this.sourceRoot);
        }
        return this.__generatedMappings;
      }, "get")
    });
    SourceMapConsumer.prototype.__originalMappings = null;
    Object.defineProperty(SourceMapConsumer.prototype, "_originalMappings", {
      configurable: true,
      enumerable: true,
      get: /* @__PURE__ */ __name(function() {
        if (!this.__originalMappings) {
          this._parseMappings(this._mappings, this.sourceRoot);
        }
        return this.__originalMappings;
      }, "get")
    });
    SourceMapConsumer.prototype._charIsMappingSeparator = /* @__PURE__ */ __name(function SourceMapConsumer_charIsMappingSeparator(aStr, index) {
      var c32 = aStr.charAt(index);
      return c32 === ";" || c32 === ",";
    }, "SourceMapConsumer_charIsMappingSeparator");
    SourceMapConsumer.prototype._parseMappings = /* @__PURE__ */ __name(function SourceMapConsumer_parseMappings(aStr, aSourceRoot) {
      throw new Error("Subclasses must implement _parseMappings");
    }, "SourceMapConsumer_parseMappings");
    SourceMapConsumer.GENERATED_ORDER = 1;
    SourceMapConsumer.ORIGINAL_ORDER = 2;
    SourceMapConsumer.GREATEST_LOWER_BOUND = 1;
    SourceMapConsumer.LEAST_UPPER_BOUND = 2;
    SourceMapConsumer.prototype.eachMapping = /* @__PURE__ */ __name(function SourceMapConsumer_eachMapping(aCallback, aContext, aOrder) {
      var context = aContext || null;
      var order = aOrder || SourceMapConsumer.GENERATED_ORDER;
      var mappings;
      switch (order) {
        case SourceMapConsumer.GENERATED_ORDER:
          mappings = this._generatedMappings;
          break;
        case SourceMapConsumer.ORIGINAL_ORDER:
          mappings = this._originalMappings;
          break;
        default:
          throw new Error("Unknown order of iteration.");
      }
      var sourceRoot = this.sourceRoot;
      mappings.map(function(mapping) {
        var source = mapping.source === null ? null : this._sources.at(mapping.source);
        source = util11.computeSourceURL(sourceRoot, source, this._sourceMapURL);
        return {
          source,
          generatedLine: mapping.generatedLine,
          generatedColumn: mapping.generatedColumn,
          originalLine: mapping.originalLine,
          originalColumn: mapping.originalColumn,
          name: mapping.name === null ? null : this._names.at(mapping.name)
        };
      }, this).forEach(aCallback, context);
    }, "SourceMapConsumer_eachMapping");
    SourceMapConsumer.prototype.allGeneratedPositionsFor = /* @__PURE__ */ __name(function SourceMapConsumer_allGeneratedPositionsFor(aArgs) {
      var line = util11.getArg(aArgs, "line");
      var needle = {
        source: util11.getArg(aArgs, "source"),
        originalLine: line,
        originalColumn: util11.getArg(aArgs, "column", 0)
      };
      needle.source = this._findSourceIndex(needle.source);
      if (needle.source < 0) {
        return [];
      }
      var mappings = [];
      var index = this._findMapping(
        needle,
        this._originalMappings,
        "originalLine",
        "originalColumn",
        util11.compareByOriginalPositions,
        binarySearch.LEAST_UPPER_BOUND
      );
      if (index >= 0) {
        var mapping = this._originalMappings[index];
        if (aArgs.column === void 0) {
          var originalLine = mapping.originalLine;
          while (mapping && mapping.originalLine === originalLine) {
            mappings.push({
              line: util11.getArg(mapping, "generatedLine", null),
              column: util11.getArg(mapping, "generatedColumn", null),
              lastColumn: util11.getArg(mapping, "lastGeneratedColumn", null)
            });
            mapping = this._originalMappings[++index];
          }
        } else {
          var originalColumn = mapping.originalColumn;
          while (mapping && mapping.originalLine === line && mapping.originalColumn == originalColumn) {
            mappings.push({
              line: util11.getArg(mapping, "generatedLine", null),
              column: util11.getArg(mapping, "generatedColumn", null),
              lastColumn: util11.getArg(mapping, "lastGeneratedColumn", null)
            });
            mapping = this._originalMappings[++index];
          }
        }
      }
      return mappings;
    }, "SourceMapConsumer_allGeneratedPositionsFor");
    exports2.SourceMapConsumer = SourceMapConsumer;
    function BasicSourceMapConsumer(aSourceMap, aSourceMapURL) {
      var sourceMap = aSourceMap;
      if (typeof aSourceMap === "string") {
        sourceMap = util11.parseSourceMapInput(aSourceMap);
      }
      var version = util11.getArg(sourceMap, "version");
      var sources = util11.getArg(sourceMap, "sources");
      var names = util11.getArg(sourceMap, "names", []);
      var sourceRoot = util11.getArg(sourceMap, "sourceRoot", null);
      var sourcesContent = util11.getArg(sourceMap, "sourcesContent", null);
      var mappings = util11.getArg(sourceMap, "mappings");
      var file = util11.getArg(sourceMap, "file", null);
      if (version != this._version) {
        throw new Error("Unsupported version: " + version);
      }
      if (sourceRoot) {
        sourceRoot = util11.normalize(sourceRoot);
      }
      sources = sources.map(String).map(util11.normalize).map(function(source) {
        return sourceRoot && util11.isAbsolute(sourceRoot) && util11.isAbsolute(source) ? util11.relative(sourceRoot, source) : source;
      });
      this._names = ArraySet.fromArray(names.map(String), true);
      this._sources = ArraySet.fromArray(sources, true);
      this._absoluteSources = this._sources.toArray().map(function(s) {
        return util11.computeSourceURL(sourceRoot, s, aSourceMapURL);
      });
      this.sourceRoot = sourceRoot;
      this.sourcesContent = sourcesContent;
      this._mappings = mappings;
      this._sourceMapURL = aSourceMapURL;
      this.file = file;
    }
    __name(BasicSourceMapConsumer, "BasicSourceMapConsumer");
    BasicSourceMapConsumer.prototype = Object.create(SourceMapConsumer.prototype);
    BasicSourceMapConsumer.prototype.consumer = SourceMapConsumer;
    BasicSourceMapConsumer.prototype._findSourceIndex = function(aSource) {
      var relativeSource = aSource;
      if (this.sourceRoot != null) {
        relativeSource = util11.relative(this.sourceRoot, relativeSource);
      }
      if (this._sources.has(relativeSource)) {
        return this._sources.indexOf(relativeSource);
      }
      var i32;
      for (i32 = 0; i32 < this._absoluteSources.length; ++i32) {
        if (this._absoluteSources[i32] == aSource) {
          return i32;
        }
      }
      return -1;
    };
    BasicSourceMapConsumer.fromSourceMap = /* @__PURE__ */ __name(function SourceMapConsumer_fromSourceMap(aSourceMap, aSourceMapURL) {
      var smc = Object.create(BasicSourceMapConsumer.prototype);
      var names = smc._names = ArraySet.fromArray(aSourceMap._names.toArray(), true);
      var sources = smc._sources = ArraySet.fromArray(aSourceMap._sources.toArray(), true);
      smc.sourceRoot = aSourceMap._sourceRoot;
      smc.sourcesContent = aSourceMap._generateSourcesContent(
        smc._sources.toArray(),
        smc.sourceRoot
      );
      smc.file = aSourceMap._file;
      smc._sourceMapURL = aSourceMapURL;
      smc._absoluteSources = smc._sources.toArray().map(function(s) {
        return util11.computeSourceURL(smc.sourceRoot, s, aSourceMapURL);
      });
      var generatedMappings = aSourceMap._mappings.toArray().slice();
      var destGeneratedMappings = smc.__generatedMappings = [];
      var destOriginalMappings = smc.__originalMappings = [];
      for (var i32 = 0, length = generatedMappings.length; i32 < length; i32++) {
        var srcMapping = generatedMappings[i32];
        var destMapping = new Mapping();
        destMapping.generatedLine = srcMapping.generatedLine;
        destMapping.generatedColumn = srcMapping.generatedColumn;
        if (srcMapping.source) {
          destMapping.source = sources.indexOf(srcMapping.source);
          destMapping.originalLine = srcMapping.originalLine;
          destMapping.originalColumn = srcMapping.originalColumn;
          if (srcMapping.name) {
            destMapping.name = names.indexOf(srcMapping.name);
          }
          destOriginalMappings.push(destMapping);
        }
        destGeneratedMappings.push(destMapping);
      }
      quickSort(smc.__originalMappings, util11.compareByOriginalPositions);
      return smc;
    }, "SourceMapConsumer_fromSourceMap");
    BasicSourceMapConsumer.prototype._version = 3;
    Object.defineProperty(BasicSourceMapConsumer.prototype, "sources", {
      get: /* @__PURE__ */ __name(function() {
        return this._absoluteSources.slice();
      }, "get")
    });
    function Mapping() {
      this.generatedLine = 0;
      this.generatedColumn = 0;
      this.source = null;
      this.originalLine = null;
      this.originalColumn = null;
      this.name = null;
    }
    __name(Mapping, "Mapping");
    BasicSourceMapConsumer.prototype._parseMappings = /* @__PURE__ */ __name(function SourceMapConsumer_parseMappings(aStr, aSourceRoot) {
      var generatedLine = 1;
      var previousGeneratedColumn = 0;
      var previousOriginalLine = 0;
      var previousOriginalColumn = 0;
      var previousSource = 0;
      var previousName = 0;
      var length = aStr.length;
      var index = 0;
      var cachedSegments = {};
      var temp = {};
      var originalMappings = [];
      var generatedMappings = [];
      var mapping, str, segment, end, value;
      while (index < length) {
        if (aStr.charAt(index) === ";") {
          generatedLine++;
          index++;
          previousGeneratedColumn = 0;
        } else if (aStr.charAt(index) === ",") {
          index++;
        } else {
          mapping = new Mapping();
          mapping.generatedLine = generatedLine;
          for (end = index; end < length; end++) {
            if (this._charIsMappingSeparator(aStr, end)) {
              break;
            }
          }
          str = aStr.slice(index, end);
          segment = cachedSegments[str];
          if (segment) {
            index += str.length;
          } else {
            segment = [];
            while (index < end) {
              base64VLQ.decode(aStr, index, temp);
              value = temp.value;
              index = temp.rest;
              segment.push(value);
            }
            if (segment.length === 2) {
              throw new Error("Found a source, but no line and column");
            }
            if (segment.length === 3) {
              throw new Error("Found a source and line, but no column");
            }
            cachedSegments[str] = segment;
          }
          mapping.generatedColumn = previousGeneratedColumn + segment[0];
          previousGeneratedColumn = mapping.generatedColumn;
          if (segment.length > 1) {
            mapping.source = previousSource + segment[1];
            previousSource += segment[1];
            mapping.originalLine = previousOriginalLine + segment[2];
            previousOriginalLine = mapping.originalLine;
            mapping.originalLine += 1;
            mapping.originalColumn = previousOriginalColumn + segment[3];
            previousOriginalColumn = mapping.originalColumn;
            if (segment.length > 4) {
              mapping.name = previousName + segment[4];
              previousName += segment[4];
            }
          }
          generatedMappings.push(mapping);
          if (typeof mapping.originalLine === "number") {
            originalMappings.push(mapping);
          }
        }
      }
      quickSort(generatedMappings, util11.compareByGeneratedPositionsDeflated);
      this.__generatedMappings = generatedMappings;
      quickSort(originalMappings, util11.compareByOriginalPositions);
      this.__originalMappings = originalMappings;
    }, "SourceMapConsumer_parseMappings");
    BasicSourceMapConsumer.prototype._findMapping = /* @__PURE__ */ __name(function SourceMapConsumer_findMapping(aNeedle, aMappings, aLineName, aColumnName, aComparator, aBias) {
      if (aNeedle[aLineName] <= 0) {
        throw new TypeError("Line must be greater than or equal to 1, got " + aNeedle[aLineName]);
      }
      if (aNeedle[aColumnName] < 0) {
        throw new TypeError("Column must be greater than or equal to 0, got " + aNeedle[aColumnName]);
      }
      return binarySearch.search(aNeedle, aMappings, aComparator, aBias);
    }, "SourceMapConsumer_findMapping");
    BasicSourceMapConsumer.prototype.computeColumnSpans = /* @__PURE__ */ __name(function SourceMapConsumer_computeColumnSpans() {
      for (var index = 0; index < this._generatedMappings.length; ++index) {
        var mapping = this._generatedMappings[index];
        if (index + 1 < this._generatedMappings.length) {
          var nextMapping = this._generatedMappings[index + 1];
          if (mapping.generatedLine === nextMapping.generatedLine) {
            mapping.lastGeneratedColumn = nextMapping.generatedColumn - 1;
            continue;
          }
        }
        mapping.lastGeneratedColumn = Infinity;
      }
    }, "SourceMapConsumer_computeColumnSpans");
    BasicSourceMapConsumer.prototype.originalPositionFor = /* @__PURE__ */ __name(function SourceMapConsumer_originalPositionFor(aArgs) {
      var needle = {
        generatedLine: util11.getArg(aArgs, "line"),
        generatedColumn: util11.getArg(aArgs, "column")
      };
      var index = this._findMapping(
        needle,
        this._generatedMappings,
        "generatedLine",
        "generatedColumn",
        util11.compareByGeneratedPositionsDeflated,
        util11.getArg(aArgs, "bias", SourceMapConsumer.GREATEST_LOWER_BOUND)
      );
      if (index >= 0) {
        var mapping = this._generatedMappings[index];
        if (mapping.generatedLine === needle.generatedLine) {
          var source = util11.getArg(mapping, "source", null);
          if (source !== null) {
            source = this._sources.at(source);
            source = util11.computeSourceURL(this.sourceRoot, source, this._sourceMapURL);
          }
          var name = util11.getArg(mapping, "name", null);
          if (name !== null) {
            name = this._names.at(name);
          }
          return {
            source,
            line: util11.getArg(mapping, "originalLine", null),
            column: util11.getArg(mapping, "originalColumn", null),
            name
          };
        }
      }
      return {
        source: null,
        line: null,
        column: null,
        name: null
      };
    }, "SourceMapConsumer_originalPositionFor");
    BasicSourceMapConsumer.prototype.hasContentsOfAllSources = /* @__PURE__ */ __name(function BasicSourceMapConsumer_hasContentsOfAllSources() {
      if (!this.sourcesContent) {
        return false;
      }
      return this.sourcesContent.length >= this._sources.size() && !this.sourcesContent.some(function(sc) {
        return sc == null;
      });
    }, "BasicSourceMapConsumer_hasContentsOfAllSources");
    BasicSourceMapConsumer.prototype.sourceContentFor = /* @__PURE__ */ __name(function SourceMapConsumer_sourceContentFor(aSource, nullOnMissing) {
      if (!this.sourcesContent) {
        return null;
      }
      var index = this._findSourceIndex(aSource);
      if (index >= 0) {
        return this.sourcesContent[index];
      }
      var relativeSource = aSource;
      if (this.sourceRoot != null) {
        relativeSource = util11.relative(this.sourceRoot, relativeSource);
      }
      var url;
      if (this.sourceRoot != null && (url = util11.urlParse(this.sourceRoot))) {
        var fileUriAbsPath = relativeSource.replace(/^file:\/\//, "");
        if (url.scheme == "file" && this._sources.has(fileUriAbsPath)) {
          return this.sourcesContent[this._sources.indexOf(fileUriAbsPath)];
        }
        if ((!url.path || url.path == "/") && this._sources.has("/" + relativeSource)) {
          return this.sourcesContent[this._sources.indexOf("/" + relativeSource)];
        }
      }
      if (nullOnMissing) {
        return null;
      } else {
        throw new Error('"' + relativeSource + '" is not in the SourceMap.');
      }
    }, "SourceMapConsumer_sourceContentFor");
    BasicSourceMapConsumer.prototype.generatedPositionFor = /* @__PURE__ */ __name(function SourceMapConsumer_generatedPositionFor(aArgs) {
      var source = util11.getArg(aArgs, "source");
      source = this._findSourceIndex(source);
      if (source < 0) {
        return {
          line: null,
          column: null,
          lastColumn: null
        };
      }
      var needle = {
        source,
        originalLine: util11.getArg(aArgs, "line"),
        originalColumn: util11.getArg(aArgs, "column")
      };
      var index = this._findMapping(
        needle,
        this._originalMappings,
        "originalLine",
        "originalColumn",
        util11.compareByOriginalPositions,
        util11.getArg(aArgs, "bias", SourceMapConsumer.GREATEST_LOWER_BOUND)
      );
      if (index >= 0) {
        var mapping = this._originalMappings[index];
        if (mapping.source === needle.source) {
          return {
            line: util11.getArg(mapping, "generatedLine", null),
            column: util11.getArg(mapping, "generatedColumn", null),
            lastColumn: util11.getArg(mapping, "lastGeneratedColumn", null)
          };
        }
      }
      return {
        line: null,
        column: null,
        lastColumn: null
      };
    }, "SourceMapConsumer_generatedPositionFor");
    exports2.BasicSourceMapConsumer = BasicSourceMapConsumer;
    function IndexedSourceMapConsumer(aSourceMap, aSourceMapURL) {
      var sourceMap = aSourceMap;
      if (typeof aSourceMap === "string") {
        sourceMap = util11.parseSourceMapInput(aSourceMap);
      }
      var version = util11.getArg(sourceMap, "version");
      var sections = util11.getArg(sourceMap, "sections");
      if (version != this._version) {
        throw new Error("Unsupported version: " + version);
      }
      this._sources = new ArraySet();
      this._names = new ArraySet();
      var lastOffset = {
        line: -1,
        column: 0
      };
      this._sections = sections.map(function(s) {
        if (s.url) {
          throw new Error("Support for url field in sections not implemented.");
        }
        var offset = util11.getArg(s, "offset");
        var offsetLine = util11.getArg(offset, "line");
        var offsetColumn = util11.getArg(offset, "column");
        if (offsetLine < lastOffset.line || offsetLine === lastOffset.line && offsetColumn < lastOffset.column) {
          throw new Error("Section offsets must be ordered and non-overlapping.");
        }
        lastOffset = offset;
        return {
          generatedOffset: {
            // The offset fields are 0-based, but we use 1-based indices when
            // encoding/decoding from VLQ.
            generatedLine: offsetLine + 1,
            generatedColumn: offsetColumn + 1
          },
          consumer: new SourceMapConsumer(util11.getArg(s, "map"), aSourceMapURL)
        };
      });
    }
    __name(IndexedSourceMapConsumer, "IndexedSourceMapConsumer");
    IndexedSourceMapConsumer.prototype = Object.create(SourceMapConsumer.prototype);
    IndexedSourceMapConsumer.prototype.constructor = SourceMapConsumer;
    IndexedSourceMapConsumer.prototype._version = 3;
    Object.defineProperty(IndexedSourceMapConsumer.prototype, "sources", {
      get: /* @__PURE__ */ __name(function() {
        var sources = [];
        for (var i32 = 0; i32 < this._sections.length; i32++) {
          for (var j32 = 0; j32 < this._sections[i32].consumer.sources.length; j32++) {
            sources.push(this._sections[i32].consumer.sources[j32]);
          }
        }
        return sources;
      }, "get")
    });
    IndexedSourceMapConsumer.prototype.originalPositionFor = /* @__PURE__ */ __name(function IndexedSourceMapConsumer_originalPositionFor(aArgs) {
      var needle = {
        generatedLine: util11.getArg(aArgs, "line"),
        generatedColumn: util11.getArg(aArgs, "column")
      };
      var sectionIndex = binarySearch.search(
        needle,
        this._sections,
        function(needle2, section2) {
          var cmp = needle2.generatedLine - section2.generatedOffset.generatedLine;
          if (cmp) {
            return cmp;
          }
          return needle2.generatedColumn - section2.generatedOffset.generatedColumn;
        }
      );
      var section = this._sections[sectionIndex];
      if (!section) {
        return {
          source: null,
          line: null,
          column: null,
          name: null
        };
      }
      return section.consumer.originalPositionFor({
        line: needle.generatedLine - (section.generatedOffset.generatedLine - 1),
        column: needle.generatedColumn - (section.generatedOffset.generatedLine === needle.generatedLine ? section.generatedOffset.generatedColumn - 1 : 0),
        bias: aArgs.bias
      });
    }, "IndexedSourceMapConsumer_originalPositionFor");
    IndexedSourceMapConsumer.prototype.hasContentsOfAllSources = /* @__PURE__ */ __name(function IndexedSourceMapConsumer_hasContentsOfAllSources() {
      return this._sections.every(function(s) {
        return s.consumer.hasContentsOfAllSources();
      });
    }, "IndexedSourceMapConsumer_hasContentsOfAllSources");
    IndexedSourceMapConsumer.prototype.sourceContentFor = /* @__PURE__ */ __name(function IndexedSourceMapConsumer_sourceContentFor(aSource, nullOnMissing) {
      for (var i32 = 0; i32 < this._sections.length; i32++) {
        var section = this._sections[i32];
        var content = section.consumer.sourceContentFor(aSource, true);
        if (content) {
          return content;
        }
      }
      if (nullOnMissing) {
        return null;
      } else {
        throw new Error('"' + aSource + '" is not in the SourceMap.');
      }
    }, "IndexedSourceMapConsumer_sourceContentFor");
    IndexedSourceMapConsumer.prototype.generatedPositionFor = /* @__PURE__ */ __name(function IndexedSourceMapConsumer_generatedPositionFor(aArgs) {
      for (var i32 = 0; i32 < this._sections.length; i32++) {
        var section = this._sections[i32];
        if (section.consumer._findSourceIndex(util11.getArg(aArgs, "source")) === -1) {
          continue;
        }
        var generatedPosition = section.consumer.generatedPositionFor(aArgs);
        if (generatedPosition) {
          var ret = {
            line: generatedPosition.line + (section.generatedOffset.generatedLine - 1),
            column: generatedPosition.column + (section.generatedOffset.generatedLine === generatedPosition.line ? section.generatedOffset.generatedColumn - 1 : 0)
          };
          return ret;
        }
      }
      return {
        line: null,
        column: null
      };
    }, "IndexedSourceMapConsumer_generatedPositionFor");
    IndexedSourceMapConsumer.prototype._parseMappings = /* @__PURE__ */ __name(function IndexedSourceMapConsumer_parseMappings(aStr, aSourceRoot) {
      this.__generatedMappings = [];
      this.__originalMappings = [];
      for (var i32 = 0; i32 < this._sections.length; i32++) {
        var section = this._sections[i32];
        var sectionMappings = section.consumer._generatedMappings;
        for (var j32 = 0; j32 < sectionMappings.length; j32++) {
          var mapping = sectionMappings[j32];
          var source = section.consumer._sources.at(mapping.source);
          source = util11.computeSourceURL(section.consumer.sourceRoot, source, this._sourceMapURL);
          this._sources.add(source);
          source = this._sources.indexOf(source);
          var name = null;
          if (mapping.name) {
            name = section.consumer._names.at(mapping.name);
            this._names.add(name);
            name = this._names.indexOf(name);
          }
          var adjustedMapping = {
            source,
            generatedLine: mapping.generatedLine + (section.generatedOffset.generatedLine - 1),
            generatedColumn: mapping.generatedColumn + (section.generatedOffset.generatedLine === mapping.generatedLine ? section.generatedOffset.generatedColumn - 1 : 0),
            originalLine: mapping.originalLine,
            originalColumn: mapping.originalColumn,
            name
          };
          this.__generatedMappings.push(adjustedMapping);
          if (typeof adjustedMapping.originalLine === "number") {
            this.__originalMappings.push(adjustedMapping);
          }
        }
      }
      quickSort(this.__generatedMappings, util11.compareByGeneratedPositionsDeflated);
      quickSort(this.__originalMappings, util11.compareByOriginalPositions);
    }, "IndexedSourceMapConsumer_parseMappings");
    exports2.IndexedSourceMapConsumer = IndexedSourceMapConsumer;
  }
});

// ../../node_modules/source-map/lib/source-node.js
var require_source_node = __commonJS({
  "../../node_modules/source-map/lib/source-node.js"(exports2) {
    var SourceMapGenerator = require_source_map_generator().SourceMapGenerator;
    var util11 = require_util3();
    var REGEX_NEWLINE = /(\r?\n)/;
    var NEWLINE_CODE = 10;
    var isSourceNode = "$$$isSourceNode$$$";
    function SourceNode(aLine, aColumn, aSource, aChunks, aName) {
      this.children = [];
      this.sourceContents = {};
      this.line = aLine == null ? null : aLine;
      this.column = aColumn == null ? null : aColumn;
      this.source = aSource == null ? null : aSource;
      this.name = aName == null ? null : aName;
      this[isSourceNode] = true;
      if (aChunks != null) this.add(aChunks);
    }
    __name(SourceNode, "SourceNode");
    SourceNode.fromStringWithSourceMap = /* @__PURE__ */ __name(function SourceNode_fromStringWithSourceMap(aGeneratedCode, aSourceMapConsumer, aRelativePath) {
      var node = new SourceNode();
      var remainingLines = aGeneratedCode.split(REGEX_NEWLINE);
      var remainingLinesIndex = 0;
      var shiftNextLine = /* @__PURE__ */ __name(function() {
        var lineContents = getNextLine();
        var newLine = getNextLine() || "";
        return lineContents + newLine;
        function getNextLine() {
          return remainingLinesIndex < remainingLines.length ? remainingLines[remainingLinesIndex++] : void 0;
        }
        __name(getNextLine, "getNextLine");
      }, "shiftNextLine");
      var lastGeneratedLine = 1, lastGeneratedColumn = 0;
      var lastMapping = null;
      aSourceMapConsumer.eachMapping(function(mapping) {
        if (lastMapping !== null) {
          if (lastGeneratedLine < mapping.generatedLine) {
            addMappingWithCode(lastMapping, shiftNextLine());
            lastGeneratedLine++;
            lastGeneratedColumn = 0;
          } else {
            var nextLine = remainingLines[remainingLinesIndex] || "";
            var code = nextLine.substr(0, mapping.generatedColumn - lastGeneratedColumn);
            remainingLines[remainingLinesIndex] = nextLine.substr(mapping.generatedColumn - lastGeneratedColumn);
            lastGeneratedColumn = mapping.generatedColumn;
            addMappingWithCode(lastMapping, code);
            lastMapping = mapping;
            return;
          }
        }
        while (lastGeneratedLine < mapping.generatedLine) {
          node.add(shiftNextLine());
          lastGeneratedLine++;
        }
        if (lastGeneratedColumn < mapping.generatedColumn) {
          var nextLine = remainingLines[remainingLinesIndex] || "";
          node.add(nextLine.substr(0, mapping.generatedColumn));
          remainingLines[remainingLinesIndex] = nextLine.substr(mapping.generatedColumn);
          lastGeneratedColumn = mapping.generatedColumn;
        }
        lastMapping = mapping;
      }, this);
      if (remainingLinesIndex < remainingLines.length) {
        if (lastMapping) {
          addMappingWithCode(lastMapping, shiftNextLine());
        }
        node.add(remainingLines.splice(remainingLinesIndex).join(""));
      }
      aSourceMapConsumer.sources.forEach(function(sourceFile) {
        var content = aSourceMapConsumer.sourceContentFor(sourceFile);
        if (content != null) {
          if (aRelativePath != null) {
            sourceFile = util11.join(aRelativePath, sourceFile);
          }
          node.setSourceContent(sourceFile, content);
        }
      });
      return node;
      function addMappingWithCode(mapping, code) {
        if (mapping === null || mapping.source === void 0) {
          node.add(code);
        } else {
          var source = aRelativePath ? util11.join(aRelativePath, mapping.source) : mapping.source;
          node.add(new SourceNode(
            mapping.originalLine,
            mapping.originalColumn,
            source,
            code,
            mapping.name
          ));
        }
      }
      __name(addMappingWithCode, "addMappingWithCode");
    }, "SourceNode_fromStringWithSourceMap");
    SourceNode.prototype.add = /* @__PURE__ */ __name(function SourceNode_add(aChunk) {
      if (Array.isArray(aChunk)) {
        aChunk.forEach(function(chunk) {
          this.add(chunk);
        }, this);
      } else if (aChunk[isSourceNode] || typeof aChunk === "string") {
        if (aChunk) {
          this.children.push(aChunk);
        }
      } else {
        throw new TypeError(
          "Expected a SourceNode, string, or an array of SourceNodes and strings. Got " + aChunk
        );
      }
      return this;
    }, "SourceNode_add");
    SourceNode.prototype.prepend = /* @__PURE__ */ __name(function SourceNode_prepend(aChunk) {
      if (Array.isArray(aChunk)) {
        for (var i32 = aChunk.length - 1; i32 >= 0; i32--) {
          this.prepend(aChunk[i32]);
        }
      } else if (aChunk[isSourceNode] || typeof aChunk === "string") {
        this.children.unshift(aChunk);
      } else {
        throw new TypeError(
          "Expected a SourceNode, string, or an array of SourceNodes and strings. Got " + aChunk
        );
      }
      return this;
    }, "SourceNode_prepend");
    SourceNode.prototype.walk = /* @__PURE__ */ __name(function SourceNode_walk(aFn) {
      var chunk;
      for (var i32 = 0, len = this.children.length; i32 < len; i32++) {
        chunk = this.children[i32];
        if (chunk[isSourceNode]) {
          chunk.walk(aFn);
        } else {
          if (chunk !== "") {
            aFn(chunk, {
              source: this.source,
              line: this.line,
              column: this.column,
              name: this.name
            });
          }
        }
      }
    }, "SourceNode_walk");
    SourceNode.prototype.join = /* @__PURE__ */ __name(function SourceNode_join(aSep) {
      var newChildren;
      var i32;
      var len = this.children.length;
      if (len > 0) {
        newChildren = [];
        for (i32 = 0; i32 < len - 1; i32++) {
          newChildren.push(this.children[i32]);
          newChildren.push(aSep);
        }
        newChildren.push(this.children[i32]);
        this.children = newChildren;
      }
      return this;
    }, "SourceNode_join");
    SourceNode.prototype.replaceRight = /* @__PURE__ */ __name(function SourceNode_replaceRight(aPattern, aReplacement) {
      var lastChild = this.children[this.children.length - 1];
      if (lastChild[isSourceNode]) {
        lastChild.replaceRight(aPattern, aReplacement);
      } else if (typeof lastChild === "string") {
        this.children[this.children.length - 1] = lastChild.replace(aPattern, aReplacement);
      } else {
        this.children.push("".replace(aPattern, aReplacement));
      }
      return this;
    }, "SourceNode_replaceRight");
    SourceNode.prototype.setSourceContent = /* @__PURE__ */ __name(function SourceNode_setSourceContent(aSourceFile, aSourceContent) {
      this.sourceContents[util11.toSetString(aSourceFile)] = aSourceContent;
    }, "SourceNode_setSourceContent");
    SourceNode.prototype.walkSourceContents = /* @__PURE__ */ __name(function SourceNode_walkSourceContents(aFn) {
      for (var i32 = 0, len = this.children.length; i32 < len; i32++) {
        if (this.children[i32][isSourceNode]) {
          this.children[i32].walkSourceContents(aFn);
        }
      }
      var sources = Object.keys(this.sourceContents);
      for (var i32 = 0, len = sources.length; i32 < len; i32++) {
        aFn(util11.fromSetString(sources[i32]), this.sourceContents[sources[i32]]);
      }
    }, "SourceNode_walkSourceContents");
    SourceNode.prototype.toString = /* @__PURE__ */ __name(function SourceNode_toString() {
      var str = "";
      this.walk(function(chunk) {
        str += chunk;
      });
      return str;
    }, "SourceNode_toString");
    SourceNode.prototype.toStringWithSourceMap = /* @__PURE__ */ __name(function SourceNode_toStringWithSourceMap(aArgs) {
      var generated = {
        code: "",
        line: 1,
        column: 0
      };
      var map5 = new SourceMapGenerator(aArgs);
      var sourceMappingActive = false;
      var lastOriginalSource = null;
      var lastOriginalLine = null;
      var lastOriginalColumn = null;
      var lastOriginalName = null;
      this.walk(function(chunk, original) {
        generated.code += chunk;
        if (original.source !== null && original.line !== null && original.column !== null) {
          if (lastOriginalSource !== original.source || lastOriginalLine !== original.line || lastOriginalColumn !== original.column || lastOriginalName !== original.name) {
            map5.addMapping({
              source: original.source,
              original: {
                line: original.line,
                column: original.column
              },
              generated: {
                line: generated.line,
                column: generated.column
              },
              name: original.name
            });
          }
          lastOriginalSource = original.source;
          lastOriginalLine = original.line;
          lastOriginalColumn = original.column;
          lastOriginalName = original.name;
          sourceMappingActive = true;
        } else if (sourceMappingActive) {
          map5.addMapping({
            generated: {
              line: generated.line,
              column: generated.column
            }
          });
          lastOriginalSource = null;
          sourceMappingActive = false;
        }
        for (var idx = 0, length = chunk.length; idx < length; idx++) {
          if (chunk.charCodeAt(idx) === NEWLINE_CODE) {
            generated.line++;
            generated.column = 0;
            if (idx + 1 === length) {
              lastOriginalSource = null;
              sourceMappingActive = false;
            } else if (sourceMappingActive) {
              map5.addMapping({
                source: original.source,
                original: {
                  line: original.line,
                  column: original.column
                },
                generated: {
                  line: generated.line,
                  column: generated.column
                },
                name: original.name
              });
            }
          } else {
            generated.column++;
          }
        }
      });
      this.walkSourceContents(function(sourceFile, sourceContent) {
        map5.setSourceContent(sourceFile, sourceContent);
      });
      return { code: generated.code, map: map5 };
    }, "SourceNode_toStringWithSourceMap");
    exports2.SourceNode = SourceNode;
  }
});

// ../../node_modules/source-map/source-map.js
var require_source_map = __commonJS({
  "../../node_modules/source-map/source-map.js"(exports2) {
    exports2.SourceMapGenerator = require_source_map_generator().SourceMapGenerator;
    exports2.SourceMapConsumer = require_source_map_consumer().SourceMapConsumer;
    exports2.SourceNode = require_source_node().SourceNode;
  }
});

// ../../node_modules/escodegen/package.json
var require_package20 = __commonJS({
  "../../node_modules/escodegen/package.json"(exports2, module2) {
    module2.exports = {
      name: "escodegen",
      description: "ECMAScript code generator",
      homepage: "http://github.com/estools/escodegen",
      main: "escodegen.js",
      bin: {
        esgenerate: "./bin/esgenerate.js",
        escodegen: "./bin/escodegen.js"
      },
      files: [
        "LICENSE.BSD",
        "README.md",
        "bin",
        "escodegen.js",
        "package.json"
      ],
      version: "2.1.0",
      engines: {
        node: ">=6.0"
      },
      maintainers: [
        {
          name: "Yusuke Suzuki",
          email: "utatane.tea@gmail.com",
          web: "http://github.com/Constellation"
        }
      ],
      repository: {
        type: "git",
        url: "http://github.com/estools/escodegen.git"
      },
      dependencies: {
        estraverse: "^5.2.0",
        esutils: "^2.0.2",
        esprima: "^4.0.1"
      },
      optionalDependencies: {
        "source-map": "~0.6.1"
      },
      devDependencies: {
        acorn: "^8.0.4",
        bluebird: "^3.4.7",
        "bower-registry-client": "^1.0.0",
        chai: "^4.2.0",
        "chai-exclude": "^2.0.2",
        "commonjs-everywhere": "^0.9.7",
        gulp: "^4.0.2",
        "gulp-eslint": "^6.0.0",
        "gulp-mocha": "^7.0.2",
        minimist: "^1.2.5",
        optionator: "^0.9.1",
        semver: "^7.3.4"
      },
      license: "BSD-2-Clause",
      scripts: {
        test: "gulp travis",
        "unit-test": "gulp test",
        lint: "gulp lint",
        release: "node tools/release.js",
        "build-min": "./node_modules/.bin/cjsify -ma path: tools/entry-point.js > escodegen.browser.min.js",
        build: "./node_modules/.bin/cjsify -a path: tools/entry-point.js > escodegen.browser.js"
      }
    };
  }
});

// ../../node_modules/escodegen/escodegen.js
var require_escodegen = __commonJS({
  "../../node_modules/escodegen/escodegen.js"(exports2) {
    (function() {
      "use strict";
      var Syntax, Precedence, BinaryPrecedence, SourceNode, estraverse, esutils, base, indent, json, renumber, hexadecimal, quotes, escapeless, newline, space, parentheses, semicolons, safeConcatenation, directive, extra, parse2, sourceMap, sourceCode, preserveBlankLines, FORMAT_MINIFY, FORMAT_DEFAULTS;
      estraverse = require_estraverse();
      esutils = require_utils10();
      Syntax = estraverse.Syntax;
      function isExpression(node) {
        return CodeGenerator.Expression.hasOwnProperty(node.type);
      }
      __name(isExpression, "isExpression");
      function isStatement(node) {
        return CodeGenerator.Statement.hasOwnProperty(node.type);
      }
      __name(isStatement, "isStatement");
      Precedence = {
        Sequence: 0,
        Yield: 1,
        Assignment: 1,
        Conditional: 2,
        ArrowFunction: 2,
        Coalesce: 3,
        LogicalOR: 4,
        LogicalAND: 5,
        BitwiseOR: 6,
        BitwiseXOR: 7,
        BitwiseAND: 8,
        Equality: 9,
        Relational: 10,
        BitwiseSHIFT: 11,
        Additive: 12,
        Multiplicative: 13,
        Exponentiation: 14,
        Await: 15,
        Unary: 15,
        Postfix: 16,
        OptionalChaining: 17,
        Call: 18,
        New: 19,
        TaggedTemplate: 20,
        Member: 21,
        Primary: 22
      };
      BinaryPrecedence = {
        "??": Precedence.Coalesce,
        "||": Precedence.LogicalOR,
        "&&": Precedence.LogicalAND,
        "|": Precedence.BitwiseOR,
        "^": Precedence.BitwiseXOR,
        "&": Precedence.BitwiseAND,
        "==": Precedence.Equality,
        "!=": Precedence.Equality,
        "===": Precedence.Equality,
        "!==": Precedence.Equality,
        "is": Precedence.Equality,
        "isnt": Precedence.Equality,
        "<": Precedence.Relational,
        ">": Precedence.Relational,
        "<=": Precedence.Relational,
        ">=": Precedence.Relational,
        "in": Precedence.Relational,
        "instanceof": Precedence.Relational,
        "<<": Precedence.BitwiseSHIFT,
        ">>": Precedence.BitwiseSHIFT,
        ">>>": Precedence.BitwiseSHIFT,
        "+": Precedence.Additive,
        "-": Precedence.Additive,
        "*": Precedence.Multiplicative,
        "%": Precedence.Multiplicative,
        "/": Precedence.Multiplicative,
        "**": Precedence.Exponentiation
      };
      var F_ALLOW_IN = 1, F_ALLOW_CALL = 1 << 1, F_ALLOW_UNPARATH_NEW = 1 << 2, F_FUNC_BODY = 1 << 3, F_DIRECTIVE_CTX = 1 << 4, F_SEMICOLON_OPT = 1 << 5, F_FOUND_COALESCE = 1 << 6;
      var E_FTT = F_ALLOW_CALL | F_ALLOW_UNPARATH_NEW, E_TTF = F_ALLOW_IN | F_ALLOW_CALL, E_TTT = F_ALLOW_IN | F_ALLOW_CALL | F_ALLOW_UNPARATH_NEW, E_TFF = F_ALLOW_IN, E_FFT = F_ALLOW_UNPARATH_NEW, E_TFT = F_ALLOW_IN | F_ALLOW_UNPARATH_NEW;
      var S_TFFF = F_ALLOW_IN, S_TFFT = F_ALLOW_IN | F_SEMICOLON_OPT, S_FFFF = 0, S_TFTF = F_ALLOW_IN | F_DIRECTIVE_CTX, S_TTFF = F_ALLOW_IN | F_FUNC_BODY;
      function getDefaultOptions() {
        return {
          indent: null,
          base: null,
          parse: null,
          comment: false,
          format: {
            indent: {
              style: "    ",
              base: 0,
              adjustMultilineComment: false
            },
            newline: "\n",
            space: " ",
            json: false,
            renumber: false,
            hexadecimal: false,
            quotes: "single",
            escapeless: false,
            compact: false,
            parentheses: true,
            semicolons: true,
            safeConcatenation: false,
            preserveBlankLines: false
          },
          moz: {
            comprehensionExpressionStartsWithAssignment: false,
            starlessGenerator: false
          },
          sourceMap: null,
          sourceMapRoot: null,
          sourceMapWithCode: false,
          directive: false,
          raw: true,
          verbatim: null,
          sourceCode: null
        };
      }
      __name(getDefaultOptions, "getDefaultOptions");
      function stringRepeat(str, num) {
        var result2 = "";
        for (num |= 0; num > 0; num >>>= 1, str += str) {
          if (num & 1) {
            result2 += str;
          }
        }
        return result2;
      }
      __name(stringRepeat, "stringRepeat");
      function hasLineTerminator(str) {
        return /[\r\n]/g.test(str);
      }
      __name(hasLineTerminator, "hasLineTerminator");
      function endsWithLineTerminator(str) {
        var len = str.length;
        return len && esutils.code.isLineTerminator(str.charCodeAt(len - 1));
      }
      __name(endsWithLineTerminator, "endsWithLineTerminator");
      function merge3(target, override) {
        var key;
        for (key in override) {
          if (override.hasOwnProperty(key)) {
            target[key] = override[key];
          }
        }
        return target;
      }
      __name(merge3, "merge");
      function updateDeeply(target, override) {
        var key, val;
        function isHashObject(target2) {
          return typeof target2 === "object" && target2 instanceof Object && !(target2 instanceof RegExp);
        }
        __name(isHashObject, "isHashObject");
        for (key in override) {
          if (override.hasOwnProperty(key)) {
            val = override[key];
            if (isHashObject(val)) {
              if (isHashObject(target[key])) {
                updateDeeply(target[key], val);
              } else {
                target[key] = updateDeeply({}, val);
              }
            } else {
              target[key] = val;
            }
          }
        }
        return target;
      }
      __name(updateDeeply, "updateDeeply");
      function generateNumber(value) {
        var result2, point, temp, exponent, pos;
        if (value !== value) {
          throw new Error("Numeric literal whose value is NaN");
        }
        if (value < 0 || value === 0 && 1 / value < 0) {
          throw new Error("Numeric literal whose value is negative");
        }
        if (value === 1 / 0) {
          return json ? "null" : renumber ? "1e400" : "1e+400";
        }
        result2 = "" + value;
        if (!renumber || result2.length < 3) {
          return result2;
        }
        point = result2.indexOf(".");
        if (!json && result2.charCodeAt(0) === 48 && point === 1) {
          point = 0;
          result2 = result2.slice(1);
        }
        temp = result2;
        result2 = result2.replace("e+", "e");
        exponent = 0;
        if ((pos = temp.indexOf("e")) > 0) {
          exponent = +temp.slice(pos + 1);
          temp = temp.slice(0, pos);
        }
        if (point >= 0) {
          exponent -= temp.length - point - 1;
          temp = +(temp.slice(0, point) + temp.slice(point + 1)) + "";
        }
        pos = 0;
        while (temp.charCodeAt(temp.length + pos - 1) === 48) {
          --pos;
        }
        if (pos !== 0) {
          exponent -= pos;
          temp = temp.slice(0, pos);
        }
        if (exponent !== 0) {
          temp += "e" + exponent;
        }
        if ((temp.length < result2.length || hexadecimal && value > 1e12 && Math.floor(value) === value && (temp = "0x" + value.toString(16)).length < result2.length) && +temp === value) {
          result2 = temp;
        }
        return result2;
      }
      __name(generateNumber, "generateNumber");
      function escapeRegExpCharacter(ch, previousIsBackslash) {
        if ((ch & ~1) === 8232) {
          return (previousIsBackslash ? "u" : "\\u") + (ch === 8232 ? "2028" : "2029");
        } else if (ch === 10 || ch === 13) {
          return (previousIsBackslash ? "" : "\\") + (ch === 10 ? "n" : "r");
        }
        return String.fromCharCode(ch);
      }
      __name(escapeRegExpCharacter, "escapeRegExpCharacter");
      function generateRegExp(reg) {
        var match, result2, flags, i32, iz, ch, characterInBrack, previousIsBackslash;
        result2 = reg.toString();
        if (reg.source) {
          match = result2.match(/\/([^/]*)$/);
          if (!match) {
            return result2;
          }
          flags = match[1];
          result2 = "";
          characterInBrack = false;
          previousIsBackslash = false;
          for (i32 = 0, iz = reg.source.length; i32 < iz; ++i32) {
            ch = reg.source.charCodeAt(i32);
            if (!previousIsBackslash) {
              if (characterInBrack) {
                if (ch === 93) {
                  characterInBrack = false;
                }
              } else {
                if (ch === 47) {
                  result2 += "\\";
                } else if (ch === 91) {
                  characterInBrack = true;
                }
              }
              result2 += escapeRegExpCharacter(ch, previousIsBackslash);
              previousIsBackslash = ch === 92;
            } else {
              result2 += escapeRegExpCharacter(ch, previousIsBackslash);
              previousIsBackslash = false;
            }
          }
          return "/" + result2 + "/" + flags;
        }
        return result2;
      }
      __name(generateRegExp, "generateRegExp");
      function escapeAllowedCharacter(code, next) {
        var hex;
        if (code === 8) {
          return "\\b";
        }
        if (code === 12) {
          return "\\f";
        }
        if (code === 9) {
          return "\\t";
        }
        hex = code.toString(16).toUpperCase();
        if (json || code > 255) {
          return "\\u" + "0000".slice(hex.length) + hex;
        } else if (code === 0 && !esutils.code.isDecimalDigit(next)) {
          return "\\0";
        } else if (code === 11) {
          return "\\x0B";
        } else {
          return "\\x" + "00".slice(hex.length) + hex;
        }
      }
      __name(escapeAllowedCharacter, "escapeAllowedCharacter");
      function escapeDisallowedCharacter(code) {
        if (code === 92) {
          return "\\\\";
        }
        if (code === 10) {
          return "\\n";
        }
        if (code === 13) {
          return "\\r";
        }
        if (code === 8232) {
          return "\\u2028";
        }
        if (code === 8233) {
          return "\\u2029";
        }
        throw new Error("Incorrectly classified character");
      }
      __name(escapeDisallowedCharacter, "escapeDisallowedCharacter");
      function escapeDirective(str) {
        var i32, iz, code, quote;
        quote = quotes === "double" ? '"' : "'";
        for (i32 = 0, iz = str.length; i32 < iz; ++i32) {
          code = str.charCodeAt(i32);
          if (code === 39) {
            quote = '"';
            break;
          } else if (code === 34) {
            quote = "'";
            break;
          } else if (code === 92) {
            ++i32;
          }
        }
        return quote + str + quote;
      }
      __name(escapeDirective, "escapeDirective");
      function escapeString(str) {
        var result2 = "", i32, len, code, singleQuotes = 0, doubleQuotes = 0, single, quote;
        for (i32 = 0, len = str.length; i32 < len; ++i32) {
          code = str.charCodeAt(i32);
          if (code === 39) {
            ++singleQuotes;
          } else if (code === 34) {
            ++doubleQuotes;
          } else if (code === 47 && json) {
            result2 += "\\";
          } else if (esutils.code.isLineTerminator(code) || code === 92) {
            result2 += escapeDisallowedCharacter(code);
            continue;
          } else if (!esutils.code.isIdentifierPartES5(code) && (json && code < 32 || !json && !escapeless && (code < 32 || code > 126))) {
            result2 += escapeAllowedCharacter(code, str.charCodeAt(i32 + 1));
            continue;
          }
          result2 += String.fromCharCode(code);
        }
        single = !(quotes === "double" || quotes === "auto" && doubleQuotes < singleQuotes);
        quote = single ? "'" : '"';
        if (!(single ? singleQuotes : doubleQuotes)) {
          return quote + result2 + quote;
        }
        str = result2;
        result2 = quote;
        for (i32 = 0, len = str.length; i32 < len; ++i32) {
          code = str.charCodeAt(i32);
          if (code === 39 && single || code === 34 && !single) {
            result2 += "\\";
          }
          result2 += String.fromCharCode(code);
        }
        return result2 + quote;
      }
      __name(escapeString, "escapeString");
      function flattenToString(arr) {
        var i32, iz, elem, result2 = "";
        for (i32 = 0, iz = arr.length; i32 < iz; ++i32) {
          elem = arr[i32];
          result2 += Array.isArray(elem) ? flattenToString(elem) : elem;
        }
        return result2;
      }
      __name(flattenToString, "flattenToString");
      function toSourceNodeWhenNeeded(generated, node) {
        if (!sourceMap) {
          if (Array.isArray(generated)) {
            return flattenToString(generated);
          } else {
            return generated;
          }
        }
        if (node == null) {
          if (generated instanceof SourceNode) {
            return generated;
          } else {
            node = {};
          }
        }
        if (node.loc == null) {
          return new SourceNode(null, null, sourceMap, generated, node.name || null);
        }
        return new SourceNode(node.loc.start.line, node.loc.start.column, sourceMap === true ? node.loc.source || null : sourceMap, generated, node.name || null);
      }
      __name(toSourceNodeWhenNeeded, "toSourceNodeWhenNeeded");
      function noEmptySpace() {
        return space ? space : " ";
      }
      __name(noEmptySpace, "noEmptySpace");
      function join59(left, right) {
        var leftSource, rightSource, leftCharCode, rightCharCode;
        leftSource = toSourceNodeWhenNeeded(left).toString();
        if (leftSource.length === 0) {
          return [right];
        }
        rightSource = toSourceNodeWhenNeeded(right).toString();
        if (rightSource.length === 0) {
          return [left];
        }
        leftCharCode = leftSource.charCodeAt(leftSource.length - 1);
        rightCharCode = rightSource.charCodeAt(0);
        if ((leftCharCode === 43 || leftCharCode === 45) && leftCharCode === rightCharCode || esutils.code.isIdentifierPartES5(leftCharCode) && esutils.code.isIdentifierPartES5(rightCharCode) || leftCharCode === 47 && rightCharCode === 105) {
          return [left, noEmptySpace(), right];
        } else if (esutils.code.isWhiteSpace(leftCharCode) || esutils.code.isLineTerminator(leftCharCode) || esutils.code.isWhiteSpace(rightCharCode) || esutils.code.isLineTerminator(rightCharCode)) {
          return [left, right];
        }
        return [left, space, right];
      }
      __name(join59, "join");
      function addIndent(stmt) {
        return [base, stmt];
      }
      __name(addIndent, "addIndent");
      function withIndent(fn) {
        var previousBase;
        previousBase = base;
        base += indent;
        fn(base);
        base = previousBase;
      }
      __name(withIndent, "withIndent");
      function calculateSpaces(str) {
        var i32;
        for (i32 = str.length - 1; i32 >= 0; --i32) {
          if (esutils.code.isLineTerminator(str.charCodeAt(i32))) {
            break;
          }
        }
        return str.length - 1 - i32;
      }
      __name(calculateSpaces, "calculateSpaces");
      function adjustMultilineComment(value, specialBase) {
        var array, i32, len, line, j32, spaces, previousBase, sn;
        array = value.split(/\r\n|[\r\n]/);
        spaces = Number.MAX_VALUE;
        for (i32 = 1, len = array.length; i32 < len; ++i32) {
          line = array[i32];
          j32 = 0;
          while (j32 < line.length && esutils.code.isWhiteSpace(line.charCodeAt(j32))) {
            ++j32;
          }
          if (spaces > j32) {
            spaces = j32;
          }
        }
        if (typeof specialBase !== "undefined") {
          previousBase = base;
          if (array[1][spaces] === "*") {
            specialBase += " ";
          }
          base = specialBase;
        } else {
          if (spaces & 1) {
            --spaces;
          }
          previousBase = base;
        }
        for (i32 = 1, len = array.length; i32 < len; ++i32) {
          sn = toSourceNodeWhenNeeded(addIndent(array[i32].slice(spaces)));
          array[i32] = sourceMap ? sn.join("") : sn;
        }
        base = previousBase;
        return array.join("\n");
      }
      __name(adjustMultilineComment, "adjustMultilineComment");
      function generateComment(comment, specialBase) {
        if (comment.type === "Line") {
          if (endsWithLineTerminator(comment.value)) {
            return "//" + comment.value;
          } else {
            var result2 = "//" + comment.value;
            if (!preserveBlankLines) {
              result2 += "\n";
            }
            return result2;
          }
        }
        if (extra.format.indent.adjustMultilineComment && /[\n\r]/.test(comment.value)) {
          return adjustMultilineComment("/*" + comment.value + "*/", specialBase);
        }
        return "/*" + comment.value + "*/";
      }
      __name(generateComment, "generateComment");
      function addComments(stmt, result2) {
        var i32, len, comment, save, tailingToStatement, specialBase, fragment, extRange, range7, prevRange, prefix, infix, suffix, count;
        if (stmt.leadingComments && stmt.leadingComments.length > 0) {
          save = result2;
          if (preserveBlankLines) {
            comment = stmt.leadingComments[0];
            result2 = [];
            extRange = comment.extendedRange;
            range7 = comment.range;
            prefix = sourceCode.substring(extRange[0], range7[0]);
            count = (prefix.match(/\n/g) || []).length;
            if (count > 0) {
              result2.push(stringRepeat("\n", count));
              result2.push(addIndent(generateComment(comment)));
            } else {
              result2.push(prefix);
              result2.push(generateComment(comment));
            }
            prevRange = range7;
            for (i32 = 1, len = stmt.leadingComments.length; i32 < len; i32++) {
              comment = stmt.leadingComments[i32];
              range7 = comment.range;
              infix = sourceCode.substring(prevRange[1], range7[0]);
              count = (infix.match(/\n/g) || []).length;
              result2.push(stringRepeat("\n", count));
              result2.push(addIndent(generateComment(comment)));
              prevRange = range7;
            }
            suffix = sourceCode.substring(range7[1], extRange[1]);
            count = (suffix.match(/\n/g) || []).length;
            result2.push(stringRepeat("\n", count));
          } else {
            comment = stmt.leadingComments[0];
            result2 = [];
            if (safeConcatenation && stmt.type === Syntax.Program && stmt.body.length === 0) {
              result2.push("\n");
            }
            result2.push(generateComment(comment));
            if (!endsWithLineTerminator(toSourceNodeWhenNeeded(result2).toString())) {
              result2.push("\n");
            }
            for (i32 = 1, len = stmt.leadingComments.length; i32 < len; ++i32) {
              comment = stmt.leadingComments[i32];
              fragment = [generateComment(comment)];
              if (!endsWithLineTerminator(toSourceNodeWhenNeeded(fragment).toString())) {
                fragment.push("\n");
              }
              result2.push(addIndent(fragment));
            }
          }
          result2.push(addIndent(save));
        }
        if (stmt.trailingComments) {
          if (preserveBlankLines) {
            comment = stmt.trailingComments[0];
            extRange = comment.extendedRange;
            range7 = comment.range;
            prefix = sourceCode.substring(extRange[0], range7[0]);
            count = (prefix.match(/\n/g) || []).length;
            if (count > 0) {
              result2.push(stringRepeat("\n", count));
              result2.push(addIndent(generateComment(comment)));
            } else {
              result2.push(prefix);
              result2.push(generateComment(comment));
            }
          } else {
            tailingToStatement = !endsWithLineTerminator(toSourceNodeWhenNeeded(result2).toString());
            specialBase = stringRepeat(" ", calculateSpaces(toSourceNodeWhenNeeded([base, result2, indent]).toString()));
            for (i32 = 0, len = stmt.trailingComments.length; i32 < len; ++i32) {
              comment = stmt.trailingComments[i32];
              if (tailingToStatement) {
                if (i32 === 0) {
                  result2 = [result2, indent];
                } else {
                  result2 = [result2, specialBase];
                }
                result2.push(generateComment(comment, specialBase));
              } else {
                result2 = [result2, addIndent(generateComment(comment))];
              }
              if (i32 !== len - 1 && !endsWithLineTerminator(toSourceNodeWhenNeeded(result2).toString())) {
                result2 = [result2, "\n"];
              }
            }
          }
        }
        return result2;
      }
      __name(addComments, "addComments");
      function generateBlankLines(start, end, result2) {
        var j32, newlineCount = 0;
        for (j32 = start; j32 < end; j32++) {
          if (sourceCode[j32] === "\n") {
            newlineCount++;
          }
        }
        for (j32 = 1; j32 < newlineCount; j32++) {
          result2.push(newline);
        }
      }
      __name(generateBlankLines, "generateBlankLines");
      function parenthesize(text, current, should) {
        if (current < should) {
          return ["(", text, ")"];
        }
        return text;
      }
      __name(parenthesize, "parenthesize");
      function generateVerbatimString(string) {
        var i32, iz, result2;
        result2 = string.split(/\r\n|\n/);
        for (i32 = 1, iz = result2.length; i32 < iz; i32++) {
          result2[i32] = newline + base + result2[i32];
        }
        return result2;
      }
      __name(generateVerbatimString, "generateVerbatimString");
      function generateVerbatim(expr, precedence) {
        var verbatim, result2, prec;
        verbatim = expr[extra.verbatim];
        if (typeof verbatim === "string") {
          result2 = parenthesize(generateVerbatimString(verbatim), Precedence.Sequence, precedence);
        } else {
          result2 = generateVerbatimString(verbatim.content);
          prec = verbatim.precedence != null ? verbatim.precedence : Precedence.Sequence;
          result2 = parenthesize(result2, prec, precedence);
        }
        return toSourceNodeWhenNeeded(result2, expr);
      }
      __name(generateVerbatim, "generateVerbatim");
      function CodeGenerator() {
      }
      __name(CodeGenerator, "CodeGenerator");
      CodeGenerator.prototype.maybeBlock = function(stmt, flags) {
        var result2, noLeadingComment, that = this;
        noLeadingComment = !extra.comment || !stmt.leadingComments;
        if (stmt.type === Syntax.BlockStatement && noLeadingComment) {
          return [space, this.generateStatement(stmt, flags)];
        }
        if (stmt.type === Syntax.EmptyStatement && noLeadingComment) {
          return ";";
        }
        withIndent(function() {
          result2 = [
            newline,
            addIndent(that.generateStatement(stmt, flags))
          ];
        });
        return result2;
      };
      CodeGenerator.prototype.maybeBlockSuffix = function(stmt, result2) {
        var ends = endsWithLineTerminator(toSourceNodeWhenNeeded(result2).toString());
        if (stmt.type === Syntax.BlockStatement && (!extra.comment || !stmt.leadingComments) && !ends) {
          return [result2, space];
        }
        if (ends) {
          return [result2, base];
        }
        return [result2, newline, base];
      };
      function generateIdentifier(node) {
        return toSourceNodeWhenNeeded(node.name, node);
      }
      __name(generateIdentifier, "generateIdentifier");
      function generateAsyncPrefix(node, spaceRequired) {
        return node.async ? "async" + (spaceRequired ? noEmptySpace() : space) : "";
      }
      __name(generateAsyncPrefix, "generateAsyncPrefix");
      function generateStarSuffix(node) {
        var isGenerator = node.generator && !extra.moz.starlessGenerator;
        return isGenerator ? "*" + space : "";
      }
      __name(generateStarSuffix, "generateStarSuffix");
      function generateMethodPrefix(prop) {
        var func = prop.value, prefix = "";
        if (func.async) {
          prefix += generateAsyncPrefix(func, !prop.computed);
        }
        if (func.generator) {
          prefix += generateStarSuffix(func) ? "*" : "";
        }
        return prefix;
      }
      __name(generateMethodPrefix, "generateMethodPrefix");
      CodeGenerator.prototype.generatePattern = function(node, precedence, flags) {
        if (node.type === Syntax.Identifier) {
          return generateIdentifier(node);
        }
        return this.generateExpression(node, precedence, flags);
      };
      CodeGenerator.prototype.generateFunctionParams = function(node) {
        var i32, iz, result2, hasDefault;
        hasDefault = false;
        if (node.type === Syntax.ArrowFunctionExpression && !node.rest && (!node.defaults || node.defaults.length === 0) && node.params.length === 1 && node.params[0].type === Syntax.Identifier) {
          result2 = [generateAsyncPrefix(node, true), generateIdentifier(node.params[0])];
        } else {
          result2 = node.type === Syntax.ArrowFunctionExpression ? [generateAsyncPrefix(node, false)] : [];
          result2.push("(");
          if (node.defaults) {
            hasDefault = true;
          }
          for (i32 = 0, iz = node.params.length; i32 < iz; ++i32) {
            if (hasDefault && node.defaults[i32]) {
              result2.push(this.generateAssignment(node.params[i32], node.defaults[i32], "=", Precedence.Assignment, E_TTT));
            } else {
              result2.push(this.generatePattern(node.params[i32], Precedence.Assignment, E_TTT));
            }
            if (i32 + 1 < iz) {
              result2.push("," + space);
            }
          }
          if (node.rest) {
            if (node.params.length) {
              result2.push("," + space);
            }
            result2.push("...");
            result2.push(generateIdentifier(node.rest));
          }
          result2.push(")");
        }
        return result2;
      };
      CodeGenerator.prototype.generateFunctionBody = function(node) {
        var result2, expr;
        result2 = this.generateFunctionParams(node);
        if (node.type === Syntax.ArrowFunctionExpression) {
          result2.push(space);
          result2.push("=>");
        }
        if (node.expression) {
          result2.push(space);
          expr = this.generateExpression(node.body, Precedence.Assignment, E_TTT);
          if (expr.toString().charAt(0) === "{") {
            expr = ["(", expr, ")"];
          }
          result2.push(expr);
        } else {
          result2.push(this.maybeBlock(node.body, S_TTFF));
        }
        return result2;
      };
      CodeGenerator.prototype.generateIterationForStatement = function(operator, stmt, flags) {
        var result2 = ["for" + (stmt.await ? noEmptySpace() + "await" : "") + space + "("], that = this;
        withIndent(function() {
          if (stmt.left.type === Syntax.VariableDeclaration) {
            withIndent(function() {
              result2.push(stmt.left.kind + noEmptySpace());
              result2.push(that.generateStatement(stmt.left.declarations[0], S_FFFF));
            });
          } else {
            result2.push(that.generateExpression(stmt.left, Precedence.Call, E_TTT));
          }
          result2 = join59(result2, operator);
          result2 = [join59(
            result2,
            that.generateExpression(stmt.right, Precedence.Assignment, E_TTT)
          ), ")"];
        });
        result2.push(this.maybeBlock(stmt.body, flags));
        return result2;
      };
      CodeGenerator.prototype.generatePropertyKey = function(expr, computed) {
        var result2 = [];
        if (computed) {
          result2.push("[");
        }
        result2.push(this.generateExpression(expr, Precedence.Assignment, E_TTT));
        if (computed) {
          result2.push("]");
        }
        return result2;
      };
      CodeGenerator.prototype.generateAssignment = function(left, right, operator, precedence, flags) {
        if (Precedence.Assignment < precedence) {
          flags |= F_ALLOW_IN;
        }
        return parenthesize(
          [
            this.generateExpression(left, Precedence.Call, flags),
            space + operator + space,
            this.generateExpression(right, Precedence.Assignment, flags)
          ],
          Precedence.Assignment,
          precedence
        );
      };
      CodeGenerator.prototype.semicolon = function(flags) {
        if (!semicolons && flags & F_SEMICOLON_OPT) {
          return "";
        }
        return ";";
      };
      CodeGenerator.Statement = {
        BlockStatement: /* @__PURE__ */ __name(function(stmt, flags) {
          var range7, content, result2 = ["{", newline], that = this;
          withIndent(function() {
            if (stmt.body.length === 0 && preserveBlankLines) {
              range7 = stmt.range;
              if (range7[1] - range7[0] > 2) {
                content = sourceCode.substring(range7[0] + 1, range7[1] - 1);
                if (content[0] === "\n") {
                  result2 = ["{"];
                }
                result2.push(content);
              }
            }
            var i32, iz, fragment, bodyFlags;
            bodyFlags = S_TFFF;
            if (flags & F_FUNC_BODY) {
              bodyFlags |= F_DIRECTIVE_CTX;
            }
            for (i32 = 0, iz = stmt.body.length; i32 < iz; ++i32) {
              if (preserveBlankLines) {
                if (i32 === 0) {
                  if (stmt.body[0].leadingComments) {
                    range7 = stmt.body[0].leadingComments[0].extendedRange;
                    content = sourceCode.substring(range7[0], range7[1]);
                    if (content[0] === "\n") {
                      result2 = ["{"];
                    }
                  }
                  if (!stmt.body[0].leadingComments) {
                    generateBlankLines(stmt.range[0], stmt.body[0].range[0], result2);
                  }
                }
                if (i32 > 0) {
                  if (!stmt.body[i32 - 1].trailingComments && !stmt.body[i32].leadingComments) {
                    generateBlankLines(stmt.body[i32 - 1].range[1], stmt.body[i32].range[0], result2);
                  }
                }
              }
              if (i32 === iz - 1) {
                bodyFlags |= F_SEMICOLON_OPT;
              }
              if (stmt.body[i32].leadingComments && preserveBlankLines) {
                fragment = that.generateStatement(stmt.body[i32], bodyFlags);
              } else {
                fragment = addIndent(that.generateStatement(stmt.body[i32], bodyFlags));
              }
              result2.push(fragment);
              if (!endsWithLineTerminator(toSourceNodeWhenNeeded(fragment).toString())) {
                if (preserveBlankLines && i32 < iz - 1) {
                  if (!stmt.body[i32 + 1].leadingComments) {
                    result2.push(newline);
                  }
                } else {
                  result2.push(newline);
                }
              }
              if (preserveBlankLines) {
                if (i32 === iz - 1) {
                  if (!stmt.body[i32].trailingComments) {
                    generateBlankLines(stmt.body[i32].range[1], stmt.range[1], result2);
                  }
                }
              }
            }
          });
          result2.push(addIndent("}"));
          return result2;
        }, "BlockStatement"),
        BreakStatement: /* @__PURE__ */ __name(function(stmt, flags) {
          if (stmt.label) {
            return "break " + stmt.label.name + this.semicolon(flags);
          }
          return "break" + this.semicolon(flags);
        }, "BreakStatement"),
        ContinueStatement: /* @__PURE__ */ __name(function(stmt, flags) {
          if (stmt.label) {
            return "continue " + stmt.label.name + this.semicolon(flags);
          }
          return "continue" + this.semicolon(flags);
        }, "ContinueStatement"),
        ClassBody: /* @__PURE__ */ __name(function(stmt, flags) {
          var result2 = ["{", newline], that = this;
          withIndent(function(indent2) {
            var i32, iz;
            for (i32 = 0, iz = stmt.body.length; i32 < iz; ++i32) {
              result2.push(indent2);
              result2.push(that.generateExpression(stmt.body[i32], Precedence.Sequence, E_TTT));
              if (i32 + 1 < iz) {
                result2.push(newline);
              }
            }
          });
          if (!endsWithLineTerminator(toSourceNodeWhenNeeded(result2).toString())) {
            result2.push(newline);
          }
          result2.push(base);
          result2.push("}");
          return result2;
        }, "ClassBody"),
        ClassDeclaration: /* @__PURE__ */ __name(function(stmt, flags) {
          var result2, fragment;
          result2 = ["class"];
          if (stmt.id) {
            result2 = join59(result2, this.generateExpression(stmt.id, Precedence.Sequence, E_TTT));
          }
          if (stmt.superClass) {
            fragment = join59("extends", this.generateExpression(stmt.superClass, Precedence.Unary, E_TTT));
            result2 = join59(result2, fragment);
          }
          result2.push(space);
          result2.push(this.generateStatement(stmt.body, S_TFFT));
          return result2;
        }, "ClassDeclaration"),
        DirectiveStatement: /* @__PURE__ */ __name(function(stmt, flags) {
          if (extra.raw && stmt.raw) {
            return stmt.raw + this.semicolon(flags);
          }
          return escapeDirective(stmt.directive) + this.semicolon(flags);
        }, "DirectiveStatement"),
        DoWhileStatement: /* @__PURE__ */ __name(function(stmt, flags) {
          var result2 = join59("do", this.maybeBlock(stmt.body, S_TFFF));
          result2 = this.maybeBlockSuffix(stmt.body, result2);
          return join59(result2, [
            "while" + space + "(",
            this.generateExpression(stmt.test, Precedence.Sequence, E_TTT),
            ")" + this.semicolon(flags)
          ]);
        }, "DoWhileStatement"),
        CatchClause: /* @__PURE__ */ __name(function(stmt, flags) {
          var result2, that = this;
          withIndent(function() {
            var guard;
            if (stmt.param) {
              result2 = [
                "catch" + space + "(",
                that.generateExpression(stmt.param, Precedence.Sequence, E_TTT),
                ")"
              ];
              if (stmt.guard) {
                guard = that.generateExpression(stmt.guard, Precedence.Sequence, E_TTT);
                result2.splice(2, 0, " if ", guard);
              }
            } else {
              result2 = ["catch"];
            }
          });
          result2.push(this.maybeBlock(stmt.body, S_TFFF));
          return result2;
        }, "CatchClause"),
        DebuggerStatement: /* @__PURE__ */ __name(function(stmt, flags) {
          return "debugger" + this.semicolon(flags);
        }, "DebuggerStatement"),
        EmptyStatement: /* @__PURE__ */ __name(function(stmt, flags) {
          return ";";
        }, "EmptyStatement"),
        ExportDefaultDeclaration: /* @__PURE__ */ __name(function(stmt, flags) {
          var result2 = ["export"], bodyFlags;
          bodyFlags = flags & F_SEMICOLON_OPT ? S_TFFT : S_TFFF;
          result2 = join59(result2, "default");
          if (isStatement(stmt.declaration)) {
            result2 = join59(result2, this.generateStatement(stmt.declaration, bodyFlags));
          } else {
            result2 = join59(result2, this.generateExpression(stmt.declaration, Precedence.Assignment, E_TTT) + this.semicolon(flags));
          }
          return result2;
        }, "ExportDefaultDeclaration"),
        ExportNamedDeclaration: /* @__PURE__ */ __name(function(stmt, flags) {
          var result2 = ["export"], bodyFlags, that = this;
          bodyFlags = flags & F_SEMICOLON_OPT ? S_TFFT : S_TFFF;
          if (stmt.declaration) {
            return join59(result2, this.generateStatement(stmt.declaration, bodyFlags));
          }
          if (stmt.specifiers) {
            if (stmt.specifiers.length === 0) {
              result2 = join59(result2, "{" + space + "}");
            } else if (stmt.specifiers[0].type === Syntax.ExportBatchSpecifier) {
              result2 = join59(result2, this.generateExpression(stmt.specifiers[0], Precedence.Sequence, E_TTT));
            } else {
              result2 = join59(result2, "{");
              withIndent(function(indent2) {
                var i32, iz;
                result2.push(newline);
                for (i32 = 0, iz = stmt.specifiers.length; i32 < iz; ++i32) {
                  result2.push(indent2);
                  result2.push(that.generateExpression(stmt.specifiers[i32], Precedence.Sequence, E_TTT));
                  if (i32 + 1 < iz) {
                    result2.push("," + newline);
                  }
                }
              });
              if (!endsWithLineTerminator(toSourceNodeWhenNeeded(result2).toString())) {
                result2.push(newline);
              }
              result2.push(base + "}");
            }
            if (stmt.source) {
              result2 = join59(result2, [
                "from" + space,
                // ModuleSpecifier
                this.generateExpression(stmt.source, Precedence.Sequence, E_TTT),
                this.semicolon(flags)
              ]);
            } else {
              result2.push(this.semicolon(flags));
            }
          }
          return result2;
        }, "ExportNamedDeclaration"),
        ExportAllDeclaration: /* @__PURE__ */ __name(function(stmt, flags) {
          return [
            "export" + space,
            "*" + space,
            "from" + space,
            // ModuleSpecifier
            this.generateExpression(stmt.source, Precedence.Sequence, E_TTT),
            this.semicolon(flags)
          ];
        }, "ExportAllDeclaration"),
        ExpressionStatement: /* @__PURE__ */ __name(function(stmt, flags) {
          var result2, fragment;
          function isClassPrefixed(fragment2) {
            var code;
            if (fragment2.slice(0, 5) !== "class") {
              return false;
            }
            code = fragment2.charCodeAt(5);
            return code === 123 || esutils.code.isWhiteSpace(code) || esutils.code.isLineTerminator(code);
          }
          __name(isClassPrefixed, "isClassPrefixed");
          function isFunctionPrefixed(fragment2) {
            var code;
            if (fragment2.slice(0, 8) !== "function") {
              return false;
            }
            code = fragment2.charCodeAt(8);
            return code === 40 || esutils.code.isWhiteSpace(code) || code === 42 || esutils.code.isLineTerminator(code);
          }
          __name(isFunctionPrefixed, "isFunctionPrefixed");
          function isAsyncPrefixed(fragment2) {
            var code, i32, iz;
            if (fragment2.slice(0, 5) !== "async") {
              return false;
            }
            if (!esutils.code.isWhiteSpace(fragment2.charCodeAt(5))) {
              return false;
            }
            for (i32 = 6, iz = fragment2.length; i32 < iz; ++i32) {
              if (!esutils.code.isWhiteSpace(fragment2.charCodeAt(i32))) {
                break;
              }
            }
            if (i32 === iz) {
              return false;
            }
            if (fragment2.slice(i32, i32 + 8) !== "function") {
              return false;
            }
            code = fragment2.charCodeAt(i32 + 8);
            return code === 40 || esutils.code.isWhiteSpace(code) || code === 42 || esutils.code.isLineTerminator(code);
          }
          __name(isAsyncPrefixed, "isAsyncPrefixed");
          result2 = [this.generateExpression(stmt.expression, Precedence.Sequence, E_TTT)];
          fragment = toSourceNodeWhenNeeded(result2).toString();
          if (fragment.charCodeAt(0) === 123 || // ObjectExpression
          isClassPrefixed(fragment) || isFunctionPrefixed(fragment) || isAsyncPrefixed(fragment) || directive && flags & F_DIRECTIVE_CTX && stmt.expression.type === Syntax.Literal && typeof stmt.expression.value === "string") {
            result2 = ["(", result2, ")" + this.semicolon(flags)];
          } else {
            result2.push(this.semicolon(flags));
          }
          return result2;
        }, "ExpressionStatement"),
        ImportDeclaration: /* @__PURE__ */ __name(function(stmt, flags) {
          var result2, cursor3, that = this;
          if (stmt.specifiers.length === 0) {
            return [
              "import",
              space,
              // ModuleSpecifier
              this.generateExpression(stmt.source, Precedence.Sequence, E_TTT),
              this.semicolon(flags)
            ];
          }
          result2 = [
            "import"
          ];
          cursor3 = 0;
          if (stmt.specifiers[cursor3].type === Syntax.ImportDefaultSpecifier) {
            result2 = join59(result2, [
              this.generateExpression(stmt.specifiers[cursor3], Precedence.Sequence, E_TTT)
            ]);
            ++cursor3;
          }
          if (stmt.specifiers[cursor3]) {
            if (cursor3 !== 0) {
              result2.push(",");
            }
            if (stmt.specifiers[cursor3].type === Syntax.ImportNamespaceSpecifier) {
              result2 = join59(result2, [
                space,
                this.generateExpression(stmt.specifiers[cursor3], Precedence.Sequence, E_TTT)
              ]);
            } else {
              result2.push(space + "{");
              if (stmt.specifiers.length - cursor3 === 1) {
                result2.push(space);
                result2.push(this.generateExpression(stmt.specifiers[cursor3], Precedence.Sequence, E_TTT));
                result2.push(space + "}" + space);
              } else {
                withIndent(function(indent2) {
                  var i32, iz;
                  result2.push(newline);
                  for (i32 = cursor3, iz = stmt.specifiers.length; i32 < iz; ++i32) {
                    result2.push(indent2);
                    result2.push(that.generateExpression(stmt.specifiers[i32], Precedence.Sequence, E_TTT));
                    if (i32 + 1 < iz) {
                      result2.push("," + newline);
                    }
                  }
                });
                if (!endsWithLineTerminator(toSourceNodeWhenNeeded(result2).toString())) {
                  result2.push(newline);
                }
                result2.push(base + "}" + space);
              }
            }
          }
          result2 = join59(result2, [
            "from" + space,
            // ModuleSpecifier
            this.generateExpression(stmt.source, Precedence.Sequence, E_TTT),
            this.semicolon(flags)
          ]);
          return result2;
        }, "ImportDeclaration"),
        VariableDeclarator: /* @__PURE__ */ __name(function(stmt, flags) {
          var itemFlags = flags & F_ALLOW_IN ? E_TTT : E_FTT;
          if (stmt.init) {
            return [
              this.generateExpression(stmt.id, Precedence.Assignment, itemFlags),
              space,
              "=",
              space,
              this.generateExpression(stmt.init, Precedence.Assignment, itemFlags)
            ];
          }
          return this.generatePattern(stmt.id, Precedence.Assignment, itemFlags);
        }, "VariableDeclarator"),
        VariableDeclaration: /* @__PURE__ */ __name(function(stmt, flags) {
          var result2, i32, iz, node, bodyFlags, that = this;
          result2 = [stmt.kind];
          bodyFlags = flags & F_ALLOW_IN ? S_TFFF : S_FFFF;
          function block() {
            node = stmt.declarations[0];
            if (extra.comment && node.leadingComments) {
              result2.push("\n");
              result2.push(addIndent(that.generateStatement(node, bodyFlags)));
            } else {
              result2.push(noEmptySpace());
              result2.push(that.generateStatement(node, bodyFlags));
            }
            for (i32 = 1, iz = stmt.declarations.length; i32 < iz; ++i32) {
              node = stmt.declarations[i32];
              if (extra.comment && node.leadingComments) {
                result2.push("," + newline);
                result2.push(addIndent(that.generateStatement(node, bodyFlags)));
              } else {
                result2.push("," + space);
                result2.push(that.generateStatement(node, bodyFlags));
              }
            }
          }
          __name(block, "block");
          if (stmt.declarations.length > 1) {
            withIndent(block);
          } else {
            block();
          }
          result2.push(this.semicolon(flags));
          return result2;
        }, "VariableDeclaration"),
        ThrowStatement: /* @__PURE__ */ __name(function(stmt, flags) {
          return [join59(
            "throw",
            this.generateExpression(stmt.argument, Precedence.Sequence, E_TTT)
          ), this.semicolon(flags)];
        }, "ThrowStatement"),
        TryStatement: /* @__PURE__ */ __name(function(stmt, flags) {
          var result2, i32, iz, guardedHandlers;
          result2 = ["try", this.maybeBlock(stmt.block, S_TFFF)];
          result2 = this.maybeBlockSuffix(stmt.block, result2);
          if (stmt.handlers) {
            for (i32 = 0, iz = stmt.handlers.length; i32 < iz; ++i32) {
              result2 = join59(result2, this.generateStatement(stmt.handlers[i32], S_TFFF));
              if (stmt.finalizer || i32 + 1 !== iz) {
                result2 = this.maybeBlockSuffix(stmt.handlers[i32].body, result2);
              }
            }
          } else {
            guardedHandlers = stmt.guardedHandlers || [];
            for (i32 = 0, iz = guardedHandlers.length; i32 < iz; ++i32) {
              result2 = join59(result2, this.generateStatement(guardedHandlers[i32], S_TFFF));
              if (stmt.finalizer || i32 + 1 !== iz) {
                result2 = this.maybeBlockSuffix(guardedHandlers[i32].body, result2);
              }
            }
            if (stmt.handler) {
              if (Array.isArray(stmt.handler)) {
                for (i32 = 0, iz = stmt.handler.length; i32 < iz; ++i32) {
                  result2 = join59(result2, this.generateStatement(stmt.handler[i32], S_TFFF));
                  if (stmt.finalizer || i32 + 1 !== iz) {
                    result2 = this.maybeBlockSuffix(stmt.handler[i32].body, result2);
                  }
                }
              } else {
                result2 = join59(result2, this.generateStatement(stmt.handler, S_TFFF));
                if (stmt.finalizer) {
                  result2 = this.maybeBlockSuffix(stmt.handler.body, result2);
                }
              }
            }
          }
          if (stmt.finalizer) {
            result2 = join59(result2, ["finally", this.maybeBlock(stmt.finalizer, S_TFFF)]);
          }
          return result2;
        }, "TryStatement"),
        SwitchStatement: /* @__PURE__ */ __name(function(stmt, flags) {
          var result2, fragment, i32, iz, bodyFlags, that = this;
          withIndent(function() {
            result2 = [
              "switch" + space + "(",
              that.generateExpression(stmt.discriminant, Precedence.Sequence, E_TTT),
              ")" + space + "{" + newline
            ];
          });
          if (stmt.cases) {
            bodyFlags = S_TFFF;
            for (i32 = 0, iz = stmt.cases.length; i32 < iz; ++i32) {
              if (i32 === iz - 1) {
                bodyFlags |= F_SEMICOLON_OPT;
              }
              fragment = addIndent(this.generateStatement(stmt.cases[i32], bodyFlags));
              result2.push(fragment);
              if (!endsWithLineTerminator(toSourceNodeWhenNeeded(fragment).toString())) {
                result2.push(newline);
              }
            }
          }
          result2.push(addIndent("}"));
          return result2;
        }, "SwitchStatement"),
        SwitchCase: /* @__PURE__ */ __name(function(stmt, flags) {
          var result2, fragment, i32, iz, bodyFlags, that = this;
          withIndent(function() {
            if (stmt.test) {
              result2 = [
                join59("case", that.generateExpression(stmt.test, Precedence.Sequence, E_TTT)),
                ":"
              ];
            } else {
              result2 = ["default:"];
            }
            i32 = 0;
            iz = stmt.consequent.length;
            if (iz && stmt.consequent[0].type === Syntax.BlockStatement) {
              fragment = that.maybeBlock(stmt.consequent[0], S_TFFF);
              result2.push(fragment);
              i32 = 1;
            }
            if (i32 !== iz && !endsWithLineTerminator(toSourceNodeWhenNeeded(result2).toString())) {
              result2.push(newline);
            }
            bodyFlags = S_TFFF;
            for (; i32 < iz; ++i32) {
              if (i32 === iz - 1 && flags & F_SEMICOLON_OPT) {
                bodyFlags |= F_SEMICOLON_OPT;
              }
              fragment = addIndent(that.generateStatement(stmt.consequent[i32], bodyFlags));
              result2.push(fragment);
              if (i32 + 1 !== iz && !endsWithLineTerminator(toSourceNodeWhenNeeded(fragment).toString())) {
                result2.push(newline);
              }
            }
          });
          return result2;
        }, "SwitchCase"),
        IfStatement: /* @__PURE__ */ __name(function(stmt, flags) {
          var result2, bodyFlags, semicolonOptional, that = this;
          withIndent(function() {
            result2 = [
              "if" + space + "(",
              that.generateExpression(stmt.test, Precedence.Sequence, E_TTT),
              ")"
            ];
          });
          semicolonOptional = flags & F_SEMICOLON_OPT;
          bodyFlags = S_TFFF;
          if (semicolonOptional) {
            bodyFlags |= F_SEMICOLON_OPT;
          }
          if (stmt.alternate) {
            result2.push(this.maybeBlock(stmt.consequent, S_TFFF));
            result2 = this.maybeBlockSuffix(stmt.consequent, result2);
            if (stmt.alternate.type === Syntax.IfStatement) {
              result2 = join59(result2, ["else ", this.generateStatement(stmt.alternate, bodyFlags)]);
            } else {
              result2 = join59(result2, join59("else", this.maybeBlock(stmt.alternate, bodyFlags)));
            }
          } else {
            result2.push(this.maybeBlock(stmt.consequent, bodyFlags));
          }
          return result2;
        }, "IfStatement"),
        ForStatement: /* @__PURE__ */ __name(function(stmt, flags) {
          var result2, that = this;
          withIndent(function() {
            result2 = ["for" + space + "("];
            if (stmt.init) {
              if (stmt.init.type === Syntax.VariableDeclaration) {
                result2.push(that.generateStatement(stmt.init, S_FFFF));
              } else {
                result2.push(that.generateExpression(stmt.init, Precedence.Sequence, E_FTT));
                result2.push(";");
              }
            } else {
              result2.push(";");
            }
            if (stmt.test) {
              result2.push(space);
              result2.push(that.generateExpression(stmt.test, Precedence.Sequence, E_TTT));
              result2.push(";");
            } else {
              result2.push(";");
            }
            if (stmt.update) {
              result2.push(space);
              result2.push(that.generateExpression(stmt.update, Precedence.Sequence, E_TTT));
              result2.push(")");
            } else {
              result2.push(")");
            }
          });
          result2.push(this.maybeBlock(stmt.body, flags & F_SEMICOLON_OPT ? S_TFFT : S_TFFF));
          return result2;
        }, "ForStatement"),
        ForInStatement: /* @__PURE__ */ __name(function(stmt, flags) {
          return this.generateIterationForStatement("in", stmt, flags & F_SEMICOLON_OPT ? S_TFFT : S_TFFF);
        }, "ForInStatement"),
        ForOfStatement: /* @__PURE__ */ __name(function(stmt, flags) {
          return this.generateIterationForStatement("of", stmt, flags & F_SEMICOLON_OPT ? S_TFFT : S_TFFF);
        }, "ForOfStatement"),
        LabeledStatement: /* @__PURE__ */ __name(function(stmt, flags) {
          return [stmt.label.name + ":", this.maybeBlock(stmt.body, flags & F_SEMICOLON_OPT ? S_TFFT : S_TFFF)];
        }, "LabeledStatement"),
        Program: /* @__PURE__ */ __name(function(stmt, flags) {
          var result2, fragment, i32, iz, bodyFlags;
          iz = stmt.body.length;
          result2 = [safeConcatenation && iz > 0 ? "\n" : ""];
          bodyFlags = S_TFTF;
          for (i32 = 0; i32 < iz; ++i32) {
            if (!safeConcatenation && i32 === iz - 1) {
              bodyFlags |= F_SEMICOLON_OPT;
            }
            if (preserveBlankLines) {
              if (i32 === 0) {
                if (!stmt.body[0].leadingComments) {
                  generateBlankLines(stmt.range[0], stmt.body[i32].range[0], result2);
                }
              }
              if (i32 > 0) {
                if (!stmt.body[i32 - 1].trailingComments && !stmt.body[i32].leadingComments) {
                  generateBlankLines(stmt.body[i32 - 1].range[1], stmt.body[i32].range[0], result2);
                }
              }
            }
            fragment = addIndent(this.generateStatement(stmt.body[i32], bodyFlags));
            result2.push(fragment);
            if (i32 + 1 < iz && !endsWithLineTerminator(toSourceNodeWhenNeeded(fragment).toString())) {
              if (preserveBlankLines) {
                if (!stmt.body[i32 + 1].leadingComments) {
                  result2.push(newline);
                }
              } else {
                result2.push(newline);
              }
            }
            if (preserveBlankLines) {
              if (i32 === iz - 1) {
                if (!stmt.body[i32].trailingComments) {
                  generateBlankLines(stmt.body[i32].range[1], stmt.range[1], result2);
                }
              }
            }
          }
          return result2;
        }, "Program"),
        FunctionDeclaration: /* @__PURE__ */ __name(function(stmt, flags) {
          return [
            generateAsyncPrefix(stmt, true),
            "function",
            generateStarSuffix(stmt) || noEmptySpace(),
            stmt.id ? generateIdentifier(stmt.id) : "",
            this.generateFunctionBody(stmt)
          ];
        }, "FunctionDeclaration"),
        ReturnStatement: /* @__PURE__ */ __name(function(stmt, flags) {
          if (stmt.argument) {
            return [join59(
              "return",
              this.generateExpression(stmt.argument, Precedence.Sequence, E_TTT)
            ), this.semicolon(flags)];
          }
          return ["return" + this.semicolon(flags)];
        }, "ReturnStatement"),
        WhileStatement: /* @__PURE__ */ __name(function(stmt, flags) {
          var result2, that = this;
          withIndent(function() {
            result2 = [
              "while" + space + "(",
              that.generateExpression(stmt.test, Precedence.Sequence, E_TTT),
              ")"
            ];
          });
          result2.push(this.maybeBlock(stmt.body, flags & F_SEMICOLON_OPT ? S_TFFT : S_TFFF));
          return result2;
        }, "WhileStatement"),
        WithStatement: /* @__PURE__ */ __name(function(stmt, flags) {
          var result2, that = this;
          withIndent(function() {
            result2 = [
              "with" + space + "(",
              that.generateExpression(stmt.object, Precedence.Sequence, E_TTT),
              ")"
            ];
          });
          result2.push(this.maybeBlock(stmt.body, flags & F_SEMICOLON_OPT ? S_TFFT : S_TFFF));
          return result2;
        }, "WithStatement")
      };
      merge3(CodeGenerator.prototype, CodeGenerator.Statement);
      CodeGenerator.Expression = {
        SequenceExpression: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          var result2, i32, iz;
          if (Precedence.Sequence < precedence) {
            flags |= F_ALLOW_IN;
          }
          result2 = [];
          for (i32 = 0, iz = expr.expressions.length; i32 < iz; ++i32) {
            result2.push(this.generateExpression(expr.expressions[i32], Precedence.Assignment, flags));
            if (i32 + 1 < iz) {
              result2.push("," + space);
            }
          }
          return parenthesize(result2, Precedence.Sequence, precedence);
        }, "SequenceExpression"),
        AssignmentExpression: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          return this.generateAssignment(expr.left, expr.right, expr.operator, precedence, flags);
        }, "AssignmentExpression"),
        ArrowFunctionExpression: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          return parenthesize(this.generateFunctionBody(expr), Precedence.ArrowFunction, precedence);
        }, "ArrowFunctionExpression"),
        ConditionalExpression: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          if (Precedence.Conditional < precedence) {
            flags |= F_ALLOW_IN;
          }
          return parenthesize(
            [
              this.generateExpression(expr.test, Precedence.Coalesce, flags),
              space + "?" + space,
              this.generateExpression(expr.consequent, Precedence.Assignment, flags),
              space + ":" + space,
              this.generateExpression(expr.alternate, Precedence.Assignment, flags)
            ],
            Precedence.Conditional,
            precedence
          );
        }, "ConditionalExpression"),
        LogicalExpression: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          if (expr.operator === "??") {
            flags |= F_FOUND_COALESCE;
          }
          return this.BinaryExpression(expr, precedence, flags);
        }, "LogicalExpression"),
        BinaryExpression: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          var result2, leftPrecedence, rightPrecedence, currentPrecedence, fragment, leftSource;
          currentPrecedence = BinaryPrecedence[expr.operator];
          leftPrecedence = expr.operator === "**" ? Precedence.Postfix : currentPrecedence;
          rightPrecedence = expr.operator === "**" ? currentPrecedence : currentPrecedence + 1;
          if (currentPrecedence < precedence) {
            flags |= F_ALLOW_IN;
          }
          fragment = this.generateExpression(expr.left, leftPrecedence, flags);
          leftSource = fragment.toString();
          if (leftSource.charCodeAt(leftSource.length - 1) === 47 && esutils.code.isIdentifierPartES5(expr.operator.charCodeAt(0))) {
            result2 = [fragment, noEmptySpace(), expr.operator];
          } else {
            result2 = join59(fragment, expr.operator);
          }
          fragment = this.generateExpression(expr.right, rightPrecedence, flags);
          if (expr.operator === "/" && fragment.toString().charAt(0) === "/" || expr.operator.slice(-1) === "<" && fragment.toString().slice(0, 3) === "!--") {
            result2.push(noEmptySpace());
            result2.push(fragment);
          } else {
            result2 = join59(result2, fragment);
          }
          if (expr.operator === "in" && !(flags & F_ALLOW_IN)) {
            return ["(", result2, ")"];
          }
          if ((expr.operator === "||" || expr.operator === "&&") && flags & F_FOUND_COALESCE) {
            return ["(", result2, ")"];
          }
          return parenthesize(result2, currentPrecedence, precedence);
        }, "BinaryExpression"),
        CallExpression: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          var result2, i32, iz;
          result2 = [this.generateExpression(expr.callee, Precedence.Call, E_TTF)];
          if (expr.optional) {
            result2.push("?.");
          }
          result2.push("(");
          for (i32 = 0, iz = expr["arguments"].length; i32 < iz; ++i32) {
            result2.push(this.generateExpression(expr["arguments"][i32], Precedence.Assignment, E_TTT));
            if (i32 + 1 < iz) {
              result2.push("," + space);
            }
          }
          result2.push(")");
          if (!(flags & F_ALLOW_CALL)) {
            return ["(", result2, ")"];
          }
          return parenthesize(result2, Precedence.Call, precedence);
        }, "CallExpression"),
        ChainExpression: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          if (Precedence.OptionalChaining < precedence) {
            flags |= F_ALLOW_CALL;
          }
          var result2 = this.generateExpression(expr.expression, Precedence.OptionalChaining, flags);
          return parenthesize(result2, Precedence.OptionalChaining, precedence);
        }, "ChainExpression"),
        NewExpression: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          var result2, length, i32, iz, itemFlags;
          length = expr["arguments"].length;
          itemFlags = flags & F_ALLOW_UNPARATH_NEW && !parentheses && length === 0 ? E_TFT : E_TFF;
          result2 = join59(
            "new",
            this.generateExpression(expr.callee, Precedence.New, itemFlags)
          );
          if (!(flags & F_ALLOW_UNPARATH_NEW) || parentheses || length > 0) {
            result2.push("(");
            for (i32 = 0, iz = length; i32 < iz; ++i32) {
              result2.push(this.generateExpression(expr["arguments"][i32], Precedence.Assignment, E_TTT));
              if (i32 + 1 < iz) {
                result2.push("," + space);
              }
            }
            result2.push(")");
          }
          return parenthesize(result2, Precedence.New, precedence);
        }, "NewExpression"),
        MemberExpression: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          var result2, fragment;
          result2 = [this.generateExpression(expr.object, Precedence.Call, flags & F_ALLOW_CALL ? E_TTF : E_TFF)];
          if (expr.computed) {
            if (expr.optional) {
              result2.push("?.");
            }
            result2.push("[");
            result2.push(this.generateExpression(expr.property, Precedence.Sequence, flags & F_ALLOW_CALL ? E_TTT : E_TFT));
            result2.push("]");
          } else {
            if (!expr.optional && expr.object.type === Syntax.Literal && typeof expr.object.value === "number") {
              fragment = toSourceNodeWhenNeeded(result2).toString();
              if (fragment.indexOf(".") < 0 && !/[eExX]/.test(fragment) && esutils.code.isDecimalDigit(fragment.charCodeAt(fragment.length - 1)) && !(fragment.length >= 2 && fragment.charCodeAt(0) === 48)) {
                result2.push(" ");
              }
            }
            result2.push(expr.optional ? "?." : ".");
            result2.push(generateIdentifier(expr.property));
          }
          return parenthesize(result2, Precedence.Member, precedence);
        }, "MemberExpression"),
        MetaProperty: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          var result2;
          result2 = [];
          result2.push(typeof expr.meta === "string" ? expr.meta : generateIdentifier(expr.meta));
          result2.push(".");
          result2.push(typeof expr.property === "string" ? expr.property : generateIdentifier(expr.property));
          return parenthesize(result2, Precedence.Member, precedence);
        }, "MetaProperty"),
        UnaryExpression: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          var result2, fragment, rightCharCode, leftSource, leftCharCode;
          fragment = this.generateExpression(expr.argument, Precedence.Unary, E_TTT);
          if (space === "") {
            result2 = join59(expr.operator, fragment);
          } else {
            result2 = [expr.operator];
            if (expr.operator.length > 2) {
              result2 = join59(result2, fragment);
            } else {
              leftSource = toSourceNodeWhenNeeded(result2).toString();
              leftCharCode = leftSource.charCodeAt(leftSource.length - 1);
              rightCharCode = fragment.toString().charCodeAt(0);
              if ((leftCharCode === 43 || leftCharCode === 45) && leftCharCode === rightCharCode || esutils.code.isIdentifierPartES5(leftCharCode) && esutils.code.isIdentifierPartES5(rightCharCode)) {
                result2.push(noEmptySpace());
                result2.push(fragment);
              } else {
                result2.push(fragment);
              }
            }
          }
          return parenthesize(result2, Precedence.Unary, precedence);
        }, "UnaryExpression"),
        YieldExpression: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          var result2;
          if (expr.delegate) {
            result2 = "yield*";
          } else {
            result2 = "yield";
          }
          if (expr.argument) {
            result2 = join59(
              result2,
              this.generateExpression(expr.argument, Precedence.Yield, E_TTT)
            );
          }
          return parenthesize(result2, Precedence.Yield, precedence);
        }, "YieldExpression"),
        AwaitExpression: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          var result2 = join59(
            expr.all ? "await*" : "await",
            this.generateExpression(expr.argument, Precedence.Await, E_TTT)
          );
          return parenthesize(result2, Precedence.Await, precedence);
        }, "AwaitExpression"),
        UpdateExpression: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          if (expr.prefix) {
            return parenthesize(
              [
                expr.operator,
                this.generateExpression(expr.argument, Precedence.Unary, E_TTT)
              ],
              Precedence.Unary,
              precedence
            );
          }
          return parenthesize(
            [
              this.generateExpression(expr.argument, Precedence.Postfix, E_TTT),
              expr.operator
            ],
            Precedence.Postfix,
            precedence
          );
        }, "UpdateExpression"),
        FunctionExpression: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          var result2 = [
            generateAsyncPrefix(expr, true),
            "function"
          ];
          if (expr.id) {
            result2.push(generateStarSuffix(expr) || noEmptySpace());
            result2.push(generateIdentifier(expr.id));
          } else {
            result2.push(generateStarSuffix(expr) || space);
          }
          result2.push(this.generateFunctionBody(expr));
          return result2;
        }, "FunctionExpression"),
        ArrayPattern: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          return this.ArrayExpression(expr, precedence, flags, true);
        }, "ArrayPattern"),
        ArrayExpression: /* @__PURE__ */ __name(function(expr, precedence, flags, isPattern) {
          var result2, multiline, that = this;
          if (!expr.elements.length) {
            return "[]";
          }
          multiline = isPattern ? false : expr.elements.length > 1;
          result2 = ["[", multiline ? newline : ""];
          withIndent(function(indent2) {
            var i32, iz;
            for (i32 = 0, iz = expr.elements.length; i32 < iz; ++i32) {
              if (!expr.elements[i32]) {
                if (multiline) {
                  result2.push(indent2);
                }
                if (i32 + 1 === iz) {
                  result2.push(",");
                }
              } else {
                result2.push(multiline ? indent2 : "");
                result2.push(that.generateExpression(expr.elements[i32], Precedence.Assignment, E_TTT));
              }
              if (i32 + 1 < iz) {
                result2.push("," + (multiline ? newline : space));
              }
            }
          });
          if (multiline && !endsWithLineTerminator(toSourceNodeWhenNeeded(result2).toString())) {
            result2.push(newline);
          }
          result2.push(multiline ? base : "");
          result2.push("]");
          return result2;
        }, "ArrayExpression"),
        RestElement: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          return "..." + this.generatePattern(expr.argument);
        }, "RestElement"),
        ClassExpression: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          var result2, fragment;
          result2 = ["class"];
          if (expr.id) {
            result2 = join59(result2, this.generateExpression(expr.id, Precedence.Sequence, E_TTT));
          }
          if (expr.superClass) {
            fragment = join59("extends", this.generateExpression(expr.superClass, Precedence.Unary, E_TTT));
            result2 = join59(result2, fragment);
          }
          result2.push(space);
          result2.push(this.generateStatement(expr.body, S_TFFT));
          return result2;
        }, "ClassExpression"),
        MethodDefinition: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          var result2, fragment;
          if (expr["static"]) {
            result2 = ["static" + space];
          } else {
            result2 = [];
          }
          if (expr.kind === "get" || expr.kind === "set") {
            fragment = [
              join59(expr.kind, this.generatePropertyKey(expr.key, expr.computed)),
              this.generateFunctionBody(expr.value)
            ];
          } else {
            fragment = [
              generateMethodPrefix(expr),
              this.generatePropertyKey(expr.key, expr.computed),
              this.generateFunctionBody(expr.value)
            ];
          }
          return join59(result2, fragment);
        }, "MethodDefinition"),
        Property: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          if (expr.kind === "get" || expr.kind === "set") {
            return [
              expr.kind,
              noEmptySpace(),
              this.generatePropertyKey(expr.key, expr.computed),
              this.generateFunctionBody(expr.value)
            ];
          }
          if (expr.shorthand) {
            if (expr.value.type === "AssignmentPattern") {
              return this.AssignmentPattern(expr.value, Precedence.Sequence, E_TTT);
            }
            return this.generatePropertyKey(expr.key, expr.computed);
          }
          if (expr.method) {
            return [
              generateMethodPrefix(expr),
              this.generatePropertyKey(expr.key, expr.computed),
              this.generateFunctionBody(expr.value)
            ];
          }
          return [
            this.generatePropertyKey(expr.key, expr.computed),
            ":" + space,
            this.generateExpression(expr.value, Precedence.Assignment, E_TTT)
          ];
        }, "Property"),
        ObjectExpression: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          var multiline, result2, fragment, that = this;
          if (!expr.properties.length) {
            return "{}";
          }
          multiline = expr.properties.length > 1;
          withIndent(function() {
            fragment = that.generateExpression(expr.properties[0], Precedence.Sequence, E_TTT);
          });
          if (!multiline) {
            if (!hasLineTerminator(toSourceNodeWhenNeeded(fragment).toString())) {
              return ["{", space, fragment, space, "}"];
            }
          }
          withIndent(function(indent2) {
            var i32, iz;
            result2 = ["{", newline, indent2, fragment];
            if (multiline) {
              result2.push("," + newline);
              for (i32 = 1, iz = expr.properties.length; i32 < iz; ++i32) {
                result2.push(indent2);
                result2.push(that.generateExpression(expr.properties[i32], Precedence.Sequence, E_TTT));
                if (i32 + 1 < iz) {
                  result2.push("," + newline);
                }
              }
            }
          });
          if (!endsWithLineTerminator(toSourceNodeWhenNeeded(result2).toString())) {
            result2.push(newline);
          }
          result2.push(base);
          result2.push("}");
          return result2;
        }, "ObjectExpression"),
        AssignmentPattern: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          return this.generateAssignment(expr.left, expr.right, "=", precedence, flags);
        }, "AssignmentPattern"),
        ObjectPattern: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          var result2, i32, iz, multiline, property, that = this;
          if (!expr.properties.length) {
            return "{}";
          }
          multiline = false;
          if (expr.properties.length === 1) {
            property = expr.properties[0];
            if (property.type === Syntax.Property && property.value.type !== Syntax.Identifier) {
              multiline = true;
            }
          } else {
            for (i32 = 0, iz = expr.properties.length; i32 < iz; ++i32) {
              property = expr.properties[i32];
              if (property.type === Syntax.Property && !property.shorthand) {
                multiline = true;
                break;
              }
            }
          }
          result2 = ["{", multiline ? newline : ""];
          withIndent(function(indent2) {
            var i33, iz2;
            for (i33 = 0, iz2 = expr.properties.length; i33 < iz2; ++i33) {
              result2.push(multiline ? indent2 : "");
              result2.push(that.generateExpression(expr.properties[i33], Precedence.Sequence, E_TTT));
              if (i33 + 1 < iz2) {
                result2.push("," + (multiline ? newline : space));
              }
            }
          });
          if (multiline && !endsWithLineTerminator(toSourceNodeWhenNeeded(result2).toString())) {
            result2.push(newline);
          }
          result2.push(multiline ? base : "");
          result2.push("}");
          return result2;
        }, "ObjectPattern"),
        ThisExpression: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          return "this";
        }, "ThisExpression"),
        Super: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          return "super";
        }, "Super"),
        Identifier: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          return generateIdentifier(expr);
        }, "Identifier"),
        ImportDefaultSpecifier: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          return generateIdentifier(expr.id || expr.local);
        }, "ImportDefaultSpecifier"),
        ImportNamespaceSpecifier: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          var result2 = ["*"];
          var id = expr.id || expr.local;
          if (id) {
            result2.push(space + "as" + noEmptySpace() + generateIdentifier(id));
          }
          return result2;
        }, "ImportNamespaceSpecifier"),
        ImportSpecifier: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          var imported = expr.imported;
          var result2 = [imported.name];
          var local = expr.local;
          if (local && local.name !== imported.name) {
            result2.push(noEmptySpace() + "as" + noEmptySpace() + generateIdentifier(local));
          }
          return result2;
        }, "ImportSpecifier"),
        ExportSpecifier: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          var local = expr.local;
          var result2 = [local.name];
          var exported = expr.exported;
          if (exported && exported.name !== local.name) {
            result2.push(noEmptySpace() + "as" + noEmptySpace() + generateIdentifier(exported));
          }
          return result2;
        }, "ExportSpecifier"),
        Literal: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          var raw;
          if (expr.hasOwnProperty("raw") && parse2 && extra.raw) {
            try {
              raw = parse2(expr.raw).body[0].expression;
              if (raw.type === Syntax.Literal) {
                if (raw.value === expr.value) {
                  return expr.raw;
                }
              }
            } catch (e32) {
            }
          }
          if (expr.regex) {
            return "/" + expr.regex.pattern + "/" + expr.regex.flags;
          }
          if (typeof expr.value === "bigint") {
            return expr.value.toString() + "n";
          }
          if (expr.bigint) {
            return expr.bigint + "n";
          }
          if (expr.value === null) {
            return "null";
          }
          if (typeof expr.value === "string") {
            return escapeString(expr.value);
          }
          if (typeof expr.value === "number") {
            return generateNumber(expr.value);
          }
          if (typeof expr.value === "boolean") {
            return expr.value ? "true" : "false";
          }
          return generateRegExp(expr.value);
        }, "Literal"),
        GeneratorExpression: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          return this.ComprehensionExpression(expr, precedence, flags);
        }, "GeneratorExpression"),
        ComprehensionExpression: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          var result2, i32, iz, fragment, that = this;
          result2 = expr.type === Syntax.GeneratorExpression ? ["("] : ["["];
          if (extra.moz.comprehensionExpressionStartsWithAssignment) {
            fragment = this.generateExpression(expr.body, Precedence.Assignment, E_TTT);
            result2.push(fragment);
          }
          if (expr.blocks) {
            withIndent(function() {
              for (i32 = 0, iz = expr.blocks.length; i32 < iz; ++i32) {
                fragment = that.generateExpression(expr.blocks[i32], Precedence.Sequence, E_TTT);
                if (i32 > 0 || extra.moz.comprehensionExpressionStartsWithAssignment) {
                  result2 = join59(result2, fragment);
                } else {
                  result2.push(fragment);
                }
              }
            });
          }
          if (expr.filter) {
            result2 = join59(result2, "if" + space);
            fragment = this.generateExpression(expr.filter, Precedence.Sequence, E_TTT);
            result2 = join59(result2, ["(", fragment, ")"]);
          }
          if (!extra.moz.comprehensionExpressionStartsWithAssignment) {
            fragment = this.generateExpression(expr.body, Precedence.Assignment, E_TTT);
            result2 = join59(result2, fragment);
          }
          result2.push(expr.type === Syntax.GeneratorExpression ? ")" : "]");
          return result2;
        }, "ComprehensionExpression"),
        ComprehensionBlock: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          var fragment;
          if (expr.left.type === Syntax.VariableDeclaration) {
            fragment = [
              expr.left.kind,
              noEmptySpace(),
              this.generateStatement(expr.left.declarations[0], S_FFFF)
            ];
          } else {
            fragment = this.generateExpression(expr.left, Precedence.Call, E_TTT);
          }
          fragment = join59(fragment, expr.of ? "of" : "in");
          fragment = join59(fragment, this.generateExpression(expr.right, Precedence.Sequence, E_TTT));
          return ["for" + space + "(", fragment, ")"];
        }, "ComprehensionBlock"),
        SpreadElement: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          return [
            "...",
            this.generateExpression(expr.argument, Precedence.Assignment, E_TTT)
          ];
        }, "SpreadElement"),
        TaggedTemplateExpression: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          var itemFlags = E_TTF;
          if (!(flags & F_ALLOW_CALL)) {
            itemFlags = E_TFF;
          }
          var result2 = [
            this.generateExpression(expr.tag, Precedence.Call, itemFlags),
            this.generateExpression(expr.quasi, Precedence.Primary, E_FFT)
          ];
          return parenthesize(result2, Precedence.TaggedTemplate, precedence);
        }, "TaggedTemplateExpression"),
        TemplateElement: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          return expr.value.raw;
        }, "TemplateElement"),
        TemplateLiteral: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          var result2, i32, iz;
          result2 = ["`"];
          for (i32 = 0, iz = expr.quasis.length; i32 < iz; ++i32) {
            result2.push(this.generateExpression(expr.quasis[i32], Precedence.Primary, E_TTT));
            if (i32 + 1 < iz) {
              result2.push("${" + space);
              result2.push(this.generateExpression(expr.expressions[i32], Precedence.Sequence, E_TTT));
              result2.push(space + "}");
            }
          }
          result2.push("`");
          return result2;
        }, "TemplateLiteral"),
        ModuleSpecifier: /* @__PURE__ */ __name(function(expr, precedence, flags) {
          return this.Literal(expr, precedence, flags);
        }, "ModuleSpecifier"),
        ImportExpression: /* @__PURE__ */ __name(function(expr, precedence, flag) {
          return parenthesize([
            "import(",
            this.generateExpression(expr.source, Precedence.Assignment, E_TTT),
            ")"
          ], Precedence.Call, precedence);
        }, "ImportExpression")
      };
      merge3(CodeGenerator.prototype, CodeGenerator.Expression);
      CodeGenerator.prototype.generateExpression = function(expr, precedence, flags) {
        var result2, type;
        type = expr.type || Syntax.Property;
        if (extra.verbatim && expr.hasOwnProperty(extra.verbatim)) {
          return generateVerbatim(expr, precedence);
        }
        result2 = this[type](expr, precedence, flags);
        if (extra.comment) {
          result2 = addComments(expr, result2);
        }
        return toSourceNodeWhenNeeded(result2, expr);
      };
      CodeGenerator.prototype.generateStatement = function(stmt, flags) {
        var result2, fragment;
        result2 = this[stmt.type](stmt, flags);
        if (extra.comment) {
          result2 = addComments(stmt, result2);
        }
        fragment = toSourceNodeWhenNeeded(result2).toString();
        if (stmt.type === Syntax.Program && !safeConcatenation && newline === "" && fragment.charAt(fragment.length - 1) === "\n") {
          result2 = sourceMap ? toSourceNodeWhenNeeded(result2).replaceRight(/\s+$/, "") : fragment.replace(/\s+$/, "");
        }
        return toSourceNodeWhenNeeded(result2, stmt);
      };
      function generateInternal(node) {
        var codegen;
        codegen = new CodeGenerator();
        if (isStatement(node)) {
          return codegen.generateStatement(node, S_TFFF);
        }
        if (isExpression(node)) {
          return codegen.generateExpression(node, Precedence.Sequence, E_TTT);
        }
        throw new Error("Unknown node type: " + node.type);
      }
      __name(generateInternal, "generateInternal");
      function generate(node, options) {
        var defaultOptions2 = getDefaultOptions(), result2, pair;
        if (options != null) {
          if (typeof options.indent === "string") {
            defaultOptions2.format.indent.style = options.indent;
          }
          if (typeof options.base === "number") {
            defaultOptions2.format.indent.base = options.base;
          }
          options = updateDeeply(defaultOptions2, options);
          indent = options.format.indent.style;
          if (typeof options.base === "string") {
            base = options.base;
          } else {
            base = stringRepeat(indent, options.format.indent.base);
          }
        } else {
          options = defaultOptions2;
          indent = options.format.indent.style;
          base = stringRepeat(indent, options.format.indent.base);
        }
        json = options.format.json;
        renumber = options.format.renumber;
        hexadecimal = json ? false : options.format.hexadecimal;
        quotes = json ? "double" : options.format.quotes;
        escapeless = options.format.escapeless;
        newline = options.format.newline;
        space = options.format.space;
        if (options.format.compact) {
          newline = space = indent = base = "";
        }
        parentheses = options.format.parentheses;
        semicolons = options.format.semicolons;
        safeConcatenation = options.format.safeConcatenation;
        directive = options.directive;
        parse2 = json ? null : options.parse;
        sourceMap = options.sourceMap;
        sourceCode = options.sourceCode;
        preserveBlankLines = options.format.preserveBlankLines && sourceCode !== null;
        extra = options;
        if (sourceMap) {
          if (!exports2.browser) {
            SourceNode = require_source_map().SourceNode;
          } else {
            SourceNode = global.sourceMap.SourceNode;
          }
        }
        result2 = generateInternal(node);
        if (!sourceMap) {
          pair = { code: result2.toString(), map: null };
          return options.sourceMapWithCode ? pair : pair.code;
        }
        pair = result2.toStringWithSourceMap({
          file: options.file,
          sourceRoot: options.sourceMapRoot
        });
        if (options.sourceContent) {
          pair.map.setSourceContent(
            options.sourceMap,
            options.sourceContent
          );
        }
        if (options.sourceMapWithCode) {
          return pair;
        }
        return pair.map.toString();
      }
      __name(generate, "generate");
      FORMAT_MINIFY = {
        indent: {
          style: "",
          base: 0
        },
        renumber: true,
        hexadecimal: true,
        quotes: "auto",
        escapeless: true,
        compact: true,
        parentheses: false,
        semicolons: false
      };
      FORMAT_DEFAULTS = getDefaultOptions().format;
      exports2.version = require_package20().version;
      exports2.generate = generate;
      exports2.attachComments = estraverse.attachComments;
      exports2.Precedence = updateDeeply({}, Precedence);
      exports2.browser = false;
      exports2.FORMAT_MINIFY = FORMAT_MINIFY;
      exports2.FORMAT_DEFAULTS = FORMAT_DEFAULTS;
    })();
  }
});

// ../../node_modules/esprima/dist/esprima.js
var require_esprima = __commonJS({
  "../../node_modules/esprima/dist/esprima.js"(exports2, module2) {
    (/* @__PURE__ */ __name((function webpackUniversalModuleDefinition(root32, factory) {
      if (typeof exports2 === "object" && typeof module2 === "object")
        module2.exports = factory();
      else if (typeof define === "function" && define.amd)
        define([], factory);
      else if (typeof exports2 === "object")
        exports2["esprima"] = factory();
      else
        root32["esprima"] = factory();
    }), "webpackUniversalModuleDefinition"))(exports2, function() {
      return (
        /******/
        (function(modules) {
          var installedModules = {};
          function __webpack_require__(moduleId) {
            if (installedModules[moduleId])
              return installedModules[moduleId].exports;
            var module3 = installedModules[moduleId] = {
              /******/
              exports: {},
              /******/
              id: moduleId,
              /******/
              loaded: false
              /******/
            };
            modules[moduleId].call(module3.exports, module3, module3.exports, __webpack_require__);
            module3.loaded = true;
            return module3.exports;
          }
          __name(__webpack_require__, "__webpack_require__");
          __webpack_require__.m = modules;
          __webpack_require__.c = installedModules;
          __webpack_require__.p = "";
          return __webpack_require__(0);
        })([
          /* 0 */
          /***/
          function(module3, exports3, __webpack_require__) {
            "use strict";
            Object.defineProperty(exports3, "__esModule", { value: true });
            var comment_handler_1 = __webpack_require__(1);
            var jsx_parser_1 = __webpack_require__(3);
            var parser_1 = __webpack_require__(8);
            var tokenizer_1 = __webpack_require__(15);
            function parse2(code, options, delegate) {
              var commentHandler = null;
              var proxyDelegate = /* @__PURE__ */ __name(function(node, metadata) {
                if (delegate) {
                  delegate(node, metadata);
                }
                if (commentHandler) {
                  commentHandler.visit(node, metadata);
                }
              }, "proxyDelegate");
              var parserDelegate = typeof delegate === "function" ? proxyDelegate : null;
              var collectComment = false;
              if (options) {
                collectComment = typeof options.comment === "boolean" && options.comment;
                var attachComment = typeof options.attachComment === "boolean" && options.attachComment;
                if (collectComment || attachComment) {
                  commentHandler = new comment_handler_1.CommentHandler();
                  commentHandler.attach = attachComment;
                  options.comment = true;
                  parserDelegate = proxyDelegate;
                }
              }
              var isModule = false;
              if (options && typeof options.sourceType === "string") {
                isModule = options.sourceType === "module";
              }
              var parser;
              if (options && typeof options.jsx === "boolean" && options.jsx) {
                parser = new jsx_parser_1.JSXParser(code, options, parserDelegate);
              } else {
                parser = new parser_1.Parser(code, options, parserDelegate);
              }
              var program = isModule ? parser.parseModule() : parser.parseScript();
              var ast = program;
              if (collectComment && commentHandler) {
                ast.comments = commentHandler.comments;
              }
              if (parser.config.tokens) {
                ast.tokens = parser.tokens;
              }
              if (parser.config.tolerant) {
                ast.errors = parser.errorHandler.errors;
              }
              return ast;
            }
            __name(parse2, "parse");
            exports3.parse = parse2;
            function parseModule(code, options, delegate) {
              var parsingOptions = options || {};
              parsingOptions.sourceType = "module";
              return parse2(code, parsingOptions, delegate);
            }
            __name(parseModule, "parseModule");
            exports3.parseModule = parseModule;
            function parseScript(code, options, delegate) {
              var parsingOptions = options || {};
              parsingOptions.sourceType = "script";
              return parse2(code, parsingOptions, delegate);
            }
            __name(parseScript, "parseScript");
            exports3.parseScript = parseScript;
            function tokenize(code, options, delegate) {
              var tokenizer = new tokenizer_1.Tokenizer(code, options);
              var tokens;
              tokens = [];
              try {
                while (true) {
                  var token = tokenizer.getNextToken();
                  if (!token) {
                    break;
                  }
                  if (delegate) {
                    token = delegate(token);
                  }
                  tokens.push(token);
                }
              } catch (e32) {
                tokenizer.errorHandler.tolerate(e32);
              }
              if (tokenizer.errorHandler.tolerant) {
                tokens.errors = tokenizer.errors();
              }
              return tokens;
            }
            __name(tokenize, "tokenize");
            exports3.tokenize = tokenize;
            var syntax_1 = __webpack_require__(2);
            exports3.Syntax = syntax_1.Syntax;
            exports3.version = "4.0.1";
          },
          /* 1 */
          /***/
          function(module3, exports3, __webpack_require__) {
            "use strict";
            Object.defineProperty(exports3, "__esModule", { value: true });
            var syntax_1 = __webpack_require__(2);
            var CommentHandler = (function() {
              function CommentHandler2() {
                this.attach = false;
                this.comments = [];
                this.stack = [];
                this.leading = [];
                this.trailing = [];
              }
              __name(CommentHandler2, "CommentHandler");
              CommentHandler2.prototype.insertInnerComments = function(node, metadata) {
                if (node.type === syntax_1.Syntax.BlockStatement && node.body.length === 0) {
                  var innerComments = [];
                  for (var i32 = this.leading.length - 1; i32 >= 0; --i32) {
                    var entry = this.leading[i32];
                    if (metadata.end.offset >= entry.start) {
                      innerComments.unshift(entry.comment);
                      this.leading.splice(i32, 1);
                      this.trailing.splice(i32, 1);
                    }
                  }
                  if (innerComments.length) {
                    node.innerComments = innerComments;
                  }
                }
              };
              CommentHandler2.prototype.findTrailingComments = function(metadata) {
                var trailingComments = [];
                if (this.trailing.length > 0) {
                  for (var i32 = this.trailing.length - 1; i32 >= 0; --i32) {
                    var entry_1 = this.trailing[i32];
                    if (entry_1.start >= metadata.end.offset) {
                      trailingComments.unshift(entry_1.comment);
                    }
                  }
                  this.trailing.length = 0;
                  return trailingComments;
                }
                var entry = this.stack[this.stack.length - 1];
                if (entry && entry.node.trailingComments) {
                  var firstComment = entry.node.trailingComments[0];
                  if (firstComment && firstComment.range[0] >= metadata.end.offset) {
                    trailingComments = entry.node.trailingComments;
                    delete entry.node.trailingComments;
                  }
                }
                return trailingComments;
              };
              CommentHandler2.prototype.findLeadingComments = function(metadata) {
                var leadingComments = [];
                var target;
                while (this.stack.length > 0) {
                  var entry = this.stack[this.stack.length - 1];
                  if (entry && entry.start >= metadata.start.offset) {
                    target = entry.node;
                    this.stack.pop();
                  } else {
                    break;
                  }
                }
                if (target) {
                  var count = target.leadingComments ? target.leadingComments.length : 0;
                  for (var i32 = count - 1; i32 >= 0; --i32) {
                    var comment = target.leadingComments[i32];
                    if (comment.range[1] <= metadata.start.offset) {
                      leadingComments.unshift(comment);
                      target.leadingComments.splice(i32, 1);
                    }
                  }
                  if (target.leadingComments && target.leadingComments.length === 0) {
                    delete target.leadingComments;
                  }
                  return leadingComments;
                }
                for (var i32 = this.leading.length - 1; i32 >= 0; --i32) {
                  var entry = this.leading[i32];
                  if (entry.start <= metadata.start.offset) {
                    leadingComments.unshift(entry.comment);
                    this.leading.splice(i32, 1);
                  }
                }
                return leadingComments;
              };
              CommentHandler2.prototype.visitNode = function(node, metadata) {
                if (node.type === syntax_1.Syntax.Program && node.body.length > 0) {
                  return;
                }
                this.insertInnerComments(node, metadata);
                var trailingComments = this.findTrailingComments(metadata);
                var leadingComments = this.findLeadingComments(metadata);
                if (leadingComments.length > 0) {
                  node.leadingComments = leadingComments;
                }
                if (trailingComments.length > 0) {
                  node.trailingComments = trailingComments;
                }
                this.stack.push({
                  node,
                  start: metadata.start.offset
                });
              };
              CommentHandler2.prototype.visitComment = function(node, metadata) {
                var type = node.type[0] === "L" ? "Line" : "Block";
                var comment = {
                  type,
                  value: node.value
                };
                if (node.range) {
                  comment.range = node.range;
                }
                if (node.loc) {
                  comment.loc = node.loc;
                }
                this.comments.push(comment);
                if (this.attach) {
                  var entry = {
                    comment: {
                      type,
                      value: node.value,
                      range: [metadata.start.offset, metadata.end.offset]
                    },
                    start: metadata.start.offset
                  };
                  if (node.loc) {
                    entry.comment.loc = node.loc;
                  }
                  node.type = type;
                  this.leading.push(entry);
                  this.trailing.push(entry);
                }
              };
              CommentHandler2.prototype.visit = function(node, metadata) {
                if (node.type === "LineComment") {
                  this.visitComment(node, metadata);
                } else if (node.type === "BlockComment") {
                  this.visitComment(node, metadata);
                } else if (this.attach) {
                  this.visitNode(node, metadata);
                }
              };
              return CommentHandler2;
            })();
            exports3.CommentHandler = CommentHandler;
          },
          /* 2 */
          /***/
          function(module3, exports3) {
            "use strict";
            Object.defineProperty(exports3, "__esModule", { value: true });
            exports3.Syntax = {
              AssignmentExpression: "AssignmentExpression",
              AssignmentPattern: "AssignmentPattern",
              ArrayExpression: "ArrayExpression",
              ArrayPattern: "ArrayPattern",
              ArrowFunctionExpression: "ArrowFunctionExpression",
              AwaitExpression: "AwaitExpression",
              BlockStatement: "BlockStatement",
              BinaryExpression: "BinaryExpression",
              BreakStatement: "BreakStatement",
              CallExpression: "CallExpression",
              CatchClause: "CatchClause",
              ClassBody: "ClassBody",
              ClassDeclaration: "ClassDeclaration",
              ClassExpression: "ClassExpression",
              ConditionalExpression: "ConditionalExpression",
              ContinueStatement: "ContinueStatement",
              DoWhileStatement: "DoWhileStatement",
              DebuggerStatement: "DebuggerStatement",
              EmptyStatement: "EmptyStatement",
              ExportAllDeclaration: "ExportAllDeclaration",
              ExportDefaultDeclaration: "ExportDefaultDeclaration",
              ExportNamedDeclaration: "ExportNamedDeclaration",
              ExportSpecifier: "ExportSpecifier",
              ExpressionStatement: "ExpressionStatement",
              ForStatement: "ForStatement",
              ForOfStatement: "ForOfStatement",
              ForInStatement: "ForInStatement",
              FunctionDeclaration: "FunctionDeclaration",
              FunctionExpression: "FunctionExpression",
              Identifier: "Identifier",
              IfStatement: "IfStatement",
              ImportDeclaration: "ImportDeclaration",
              ImportDefaultSpecifier: "ImportDefaultSpecifier",
              ImportNamespaceSpecifier: "ImportNamespaceSpecifier",
              ImportSpecifier: "ImportSpecifier",
              Literal: "Literal",
              LabeledStatement: "LabeledStatement",
              LogicalExpression: "LogicalExpression",
              MemberExpression: "MemberExpression",
              MetaProperty: "MetaProperty",
              MethodDefinition: "MethodDefinition",
              NewExpression: "NewExpression",
              ObjectExpression: "ObjectExpression",
              ObjectPattern: "ObjectPattern",
              Program: "Program",
              Property: "Property",
              RestElement: "RestElement",
              ReturnStatement: "ReturnStatement",
              SequenceExpression: "SequenceExpression",
              SpreadElement: "SpreadElement",
              Super: "Super",
              SwitchCase: "SwitchCase",
              SwitchStatement: "SwitchStatement",
              TaggedTemplateExpression: "TaggedTemplateExpression",
              TemplateElement: "TemplateElement",
              TemplateLiteral: "TemplateLiteral",
              ThisExpression: "ThisExpression",
              ThrowStatement: "ThrowStatement",
              TryStatement: "TryStatement",
              UnaryExpression: "UnaryExpression",
              UpdateExpression: "UpdateExpression",
              VariableDeclaration: "VariableDeclaration",
              VariableDeclarator: "VariableDeclarator",
              WhileStatement: "WhileStatement",
              WithStatement: "WithStatement",
              YieldExpression: "YieldExpression"
            };
          },
          /* 3 */
          /***/
          function(module3, exports3, __webpack_require__) {
            "use strict";
            var __extends2 = this && this.__extends || (function() {
              var extendStatics2 = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(d32, b32) {
                d32.__proto__ = b32;
              } || function(d32, b32) {
                for (var p10 in b32) if (b32.hasOwnProperty(p10)) d32[p10] = b32[p10];
              };
              return function(d32, b32) {
                extendStatics2(d32, b32);
                function __() {
                  this.constructor = d32;
                }
                __name(__, "__");
                d32.prototype = b32 === null ? Object.create(b32) : (__.prototype = b32.prototype, new __());
              };
            })();
            Object.defineProperty(exports3, "__esModule", { value: true });
            var character_1 = __webpack_require__(4);
            var JSXNode = __webpack_require__(5);
            var jsx_syntax_1 = __webpack_require__(6);
            var Node2 = __webpack_require__(7);
            var parser_1 = __webpack_require__(8);
            var token_1 = __webpack_require__(13);
            var xhtml_entities_1 = __webpack_require__(14);
            token_1.TokenName[
              100
              /* Identifier */
            ] = "JSXIdentifier";
            token_1.TokenName[
              101
              /* Text */
            ] = "JSXText";
            function getQualifiedElementName(elementName) {
              var qualifiedName;
              switch (elementName.type) {
                case jsx_syntax_1.JSXSyntax.JSXIdentifier:
                  var id = elementName;
                  qualifiedName = id.name;
                  break;
                case jsx_syntax_1.JSXSyntax.JSXNamespacedName:
                  var ns = elementName;
                  qualifiedName = getQualifiedElementName(ns.namespace) + ":" + getQualifiedElementName(ns.name);
                  break;
                case jsx_syntax_1.JSXSyntax.JSXMemberExpression:
                  var expr = elementName;
                  qualifiedName = getQualifiedElementName(expr.object) + "." + getQualifiedElementName(expr.property);
                  break;
                /* istanbul ignore next */
                default:
                  break;
              }
              return qualifiedName;
            }
            __name(getQualifiedElementName, "getQualifiedElementName");
            var JSXParser = (function(_super) {
              __extends2(JSXParser2, _super);
              function JSXParser2(code, options, delegate) {
                return _super.call(this, code, options, delegate) || this;
              }
              __name(JSXParser2, "JSXParser");
              JSXParser2.prototype.parsePrimaryExpression = function() {
                return this.match("<") ? this.parseJSXRoot() : _super.prototype.parsePrimaryExpression.call(this);
              };
              JSXParser2.prototype.startJSX = function() {
                this.scanner.index = this.startMarker.index;
                this.scanner.lineNumber = this.startMarker.line;
                this.scanner.lineStart = this.startMarker.index - this.startMarker.column;
              };
              JSXParser2.prototype.finishJSX = function() {
                this.nextToken();
              };
              JSXParser2.prototype.reenterJSX = function() {
                this.startJSX();
                this.expectJSX("}");
                if (this.config.tokens) {
                  this.tokens.pop();
                }
              };
              JSXParser2.prototype.createJSXNode = function() {
                this.collectComments();
                return {
                  index: this.scanner.index,
                  line: this.scanner.lineNumber,
                  column: this.scanner.index - this.scanner.lineStart
                };
              };
              JSXParser2.prototype.createJSXChildNode = function() {
                return {
                  index: this.scanner.index,
                  line: this.scanner.lineNumber,
                  column: this.scanner.index - this.scanner.lineStart
                };
              };
              JSXParser2.prototype.scanXHTMLEntity = function(quote) {
                var result2 = "&";
                var valid3 = true;
                var terminated = false;
                var numeric = false;
                var hex = false;
                while (!this.scanner.eof() && valid3 && !terminated) {
                  var ch = this.scanner.source[this.scanner.index];
                  if (ch === quote) {
                    break;
                  }
                  terminated = ch === ";";
                  result2 += ch;
                  ++this.scanner.index;
                  if (!terminated) {
                    switch (result2.length) {
                      case 2:
                        numeric = ch === "#";
                        break;
                      case 3:
                        if (numeric) {
                          hex = ch === "x";
                          valid3 = hex || character_1.Character.isDecimalDigit(ch.charCodeAt(0));
                          numeric = numeric && !hex;
                        }
                        break;
                      default:
                        valid3 = valid3 && !(numeric && !character_1.Character.isDecimalDigit(ch.charCodeAt(0)));
                        valid3 = valid3 && !(hex && !character_1.Character.isHexDigit(ch.charCodeAt(0)));
                        break;
                    }
                  }
                }
                if (valid3 && terminated && result2.length > 2) {
                  var str = result2.substr(1, result2.length - 2);
                  if (numeric && str.length > 1) {
                    result2 = String.fromCharCode(parseInt(str.substr(1), 10));
                  } else if (hex && str.length > 2) {
                    result2 = String.fromCharCode(parseInt("0" + str.substr(1), 16));
                  } else if (!numeric && !hex && xhtml_entities_1.XHTMLEntities[str]) {
                    result2 = xhtml_entities_1.XHTMLEntities[str];
                  }
                }
                return result2;
              };
              JSXParser2.prototype.lexJSX = function() {
                var cp = this.scanner.source.charCodeAt(this.scanner.index);
                if (cp === 60 || cp === 62 || cp === 47 || cp === 58 || cp === 61 || cp === 123 || cp === 125) {
                  var value = this.scanner.source[this.scanner.index++];
                  return {
                    type: 7,
                    value,
                    lineNumber: this.scanner.lineNumber,
                    lineStart: this.scanner.lineStart,
                    start: this.scanner.index - 1,
                    end: this.scanner.index
                  };
                }
                if (cp === 34 || cp === 39) {
                  var start = this.scanner.index;
                  var quote = this.scanner.source[this.scanner.index++];
                  var str = "";
                  while (!this.scanner.eof()) {
                    var ch = this.scanner.source[this.scanner.index++];
                    if (ch === quote) {
                      break;
                    } else if (ch === "&") {
                      str += this.scanXHTMLEntity(quote);
                    } else {
                      str += ch;
                    }
                  }
                  return {
                    type: 8,
                    value: str,
                    lineNumber: this.scanner.lineNumber,
                    lineStart: this.scanner.lineStart,
                    start,
                    end: this.scanner.index
                  };
                }
                if (cp === 46) {
                  var n1 = this.scanner.source.charCodeAt(this.scanner.index + 1);
                  var n22 = this.scanner.source.charCodeAt(this.scanner.index + 2);
                  var value = n1 === 46 && n22 === 46 ? "..." : ".";
                  var start = this.scanner.index;
                  this.scanner.index += value.length;
                  return {
                    type: 7,
                    value,
                    lineNumber: this.scanner.lineNumber,
                    lineStart: this.scanner.lineStart,
                    start,
                    end: this.scanner.index
                  };
                }
                if (cp === 96) {
                  return {
                    type: 10,
                    value: "",
                    lineNumber: this.scanner.lineNumber,
                    lineStart: this.scanner.lineStart,
                    start: this.scanner.index,
                    end: this.scanner.index
                  };
                }
                if (character_1.Character.isIdentifierStart(cp) && cp !== 92) {
                  var start = this.scanner.index;
                  ++this.scanner.index;
                  while (!this.scanner.eof()) {
                    var ch = this.scanner.source.charCodeAt(this.scanner.index);
                    if (character_1.Character.isIdentifierPart(ch) && ch !== 92) {
                      ++this.scanner.index;
                    } else if (ch === 45) {
                      ++this.scanner.index;
                    } else {
                      break;
                    }
                  }
                  var id = this.scanner.source.slice(start, this.scanner.index);
                  return {
                    type: 100,
                    value: id,
                    lineNumber: this.scanner.lineNumber,
                    lineStart: this.scanner.lineStart,
                    start,
                    end: this.scanner.index
                  };
                }
                return this.scanner.lex();
              };
              JSXParser2.prototype.nextJSXToken = function() {
                this.collectComments();
                this.startMarker.index = this.scanner.index;
                this.startMarker.line = this.scanner.lineNumber;
                this.startMarker.column = this.scanner.index - this.scanner.lineStart;
                var token = this.lexJSX();
                this.lastMarker.index = this.scanner.index;
                this.lastMarker.line = this.scanner.lineNumber;
                this.lastMarker.column = this.scanner.index - this.scanner.lineStart;
                if (this.config.tokens) {
                  this.tokens.push(this.convertToken(token));
                }
                return token;
              };
              JSXParser2.prototype.nextJSXText = function() {
                this.startMarker.index = this.scanner.index;
                this.startMarker.line = this.scanner.lineNumber;
                this.startMarker.column = this.scanner.index - this.scanner.lineStart;
                var start = this.scanner.index;
                var text = "";
                while (!this.scanner.eof()) {
                  var ch = this.scanner.source[this.scanner.index];
                  if (ch === "{" || ch === "<") {
                    break;
                  }
                  ++this.scanner.index;
                  text += ch;
                  if (character_1.Character.isLineTerminator(ch.charCodeAt(0))) {
                    ++this.scanner.lineNumber;
                    if (ch === "\r" && this.scanner.source[this.scanner.index] === "\n") {
                      ++this.scanner.index;
                    }
                    this.scanner.lineStart = this.scanner.index;
                  }
                }
                this.lastMarker.index = this.scanner.index;
                this.lastMarker.line = this.scanner.lineNumber;
                this.lastMarker.column = this.scanner.index - this.scanner.lineStart;
                var token = {
                  type: 101,
                  value: text,
                  lineNumber: this.scanner.lineNumber,
                  lineStart: this.scanner.lineStart,
                  start,
                  end: this.scanner.index
                };
                if (text.length > 0 && this.config.tokens) {
                  this.tokens.push(this.convertToken(token));
                }
                return token;
              };
              JSXParser2.prototype.peekJSXToken = function() {
                var state13 = this.scanner.saveState();
                this.scanner.scanComments();
                var next = this.lexJSX();
                this.scanner.restoreState(state13);
                return next;
              };
              JSXParser2.prototype.expectJSX = function(value) {
                var token = this.nextJSXToken();
                if (token.type !== 7 || token.value !== value) {
                  this.throwUnexpectedToken(token);
                }
              };
              JSXParser2.prototype.matchJSX = function(value) {
                var next = this.peekJSXToken();
                return next.type === 7 && next.value === value;
              };
              JSXParser2.prototype.parseJSXIdentifier = function() {
                var node = this.createJSXNode();
                var token = this.nextJSXToken();
                if (token.type !== 100) {
                  this.throwUnexpectedToken(token);
                }
                return this.finalize(node, new JSXNode.JSXIdentifier(token.value));
              };
              JSXParser2.prototype.parseJSXElementName = function() {
                var node = this.createJSXNode();
                var elementName = this.parseJSXIdentifier();
                if (this.matchJSX(":")) {
                  var namespace = elementName;
                  this.expectJSX(":");
                  var name_1 = this.parseJSXIdentifier();
                  elementName = this.finalize(node, new JSXNode.JSXNamespacedName(namespace, name_1));
                } else if (this.matchJSX(".")) {
                  while (this.matchJSX(".")) {
                    var object = elementName;
                    this.expectJSX(".");
                    var property = this.parseJSXIdentifier();
                    elementName = this.finalize(node, new JSXNode.JSXMemberExpression(object, property));
                  }
                }
                return elementName;
              };
              JSXParser2.prototype.parseJSXAttributeName = function() {
                var node = this.createJSXNode();
                var attributeName;
                var identifier = this.parseJSXIdentifier();
                if (this.matchJSX(":")) {
                  var namespace = identifier;
                  this.expectJSX(":");
                  var name_2 = this.parseJSXIdentifier();
                  attributeName = this.finalize(node, new JSXNode.JSXNamespacedName(namespace, name_2));
                } else {
                  attributeName = identifier;
                }
                return attributeName;
              };
              JSXParser2.prototype.parseJSXStringLiteralAttribute = function() {
                var node = this.createJSXNode();
                var token = this.nextJSXToken();
                if (token.type !== 8) {
                  this.throwUnexpectedToken(token);
                }
                var raw = this.getTokenRaw(token);
                return this.finalize(node, new Node2.Literal(token.value, raw));
              };
              JSXParser2.prototype.parseJSXExpressionAttribute = function() {
                var node = this.createJSXNode();
                this.expectJSX("{");
                this.finishJSX();
                if (this.match("}")) {
                  this.tolerateError("JSX attributes must only be assigned a non-empty expression");
                }
                var expression = this.parseAssignmentExpression();
                this.reenterJSX();
                return this.finalize(node, new JSXNode.JSXExpressionContainer(expression));
              };
              JSXParser2.prototype.parseJSXAttributeValue = function() {
                return this.matchJSX("{") ? this.parseJSXExpressionAttribute() : this.matchJSX("<") ? this.parseJSXElement() : this.parseJSXStringLiteralAttribute();
              };
              JSXParser2.prototype.parseJSXNameValueAttribute = function() {
                var node = this.createJSXNode();
                var name = this.parseJSXAttributeName();
                var value = null;
                if (this.matchJSX("=")) {
                  this.expectJSX("=");
                  value = this.parseJSXAttributeValue();
                }
                return this.finalize(node, new JSXNode.JSXAttribute(name, value));
              };
              JSXParser2.prototype.parseJSXSpreadAttribute = function() {
                var node = this.createJSXNode();
                this.expectJSX("{");
                this.expectJSX("...");
                this.finishJSX();
                var argument = this.parseAssignmentExpression();
                this.reenterJSX();
                return this.finalize(node, new JSXNode.JSXSpreadAttribute(argument));
              };
              JSXParser2.prototype.parseJSXAttributes = function() {
                var attributes = [];
                while (!this.matchJSX("/") && !this.matchJSX(">")) {
                  var attribute = this.matchJSX("{") ? this.parseJSXSpreadAttribute() : this.parseJSXNameValueAttribute();
                  attributes.push(attribute);
                }
                return attributes;
              };
              JSXParser2.prototype.parseJSXOpeningElement = function() {
                var node = this.createJSXNode();
                this.expectJSX("<");
                var name = this.parseJSXElementName();
                var attributes = this.parseJSXAttributes();
                var selfClosing = this.matchJSX("/");
                if (selfClosing) {
                  this.expectJSX("/");
                }
                this.expectJSX(">");
                return this.finalize(node, new JSXNode.JSXOpeningElement(name, selfClosing, attributes));
              };
              JSXParser2.prototype.parseJSXBoundaryElement = function() {
                var node = this.createJSXNode();
                this.expectJSX("<");
                if (this.matchJSX("/")) {
                  this.expectJSX("/");
                  var name_3 = this.parseJSXElementName();
                  this.expectJSX(">");
                  return this.finalize(node, new JSXNode.JSXClosingElement(name_3));
                }
                var name = this.parseJSXElementName();
                var attributes = this.parseJSXAttributes();
                var selfClosing = this.matchJSX("/");
                if (selfClosing) {
                  this.expectJSX("/");
                }
                this.expectJSX(">");
                return this.finalize(node, new JSXNode.JSXOpeningElement(name, selfClosing, attributes));
              };
              JSXParser2.prototype.parseJSXEmptyExpression = function() {
                var node = this.createJSXChildNode();
                this.collectComments();
                this.lastMarker.index = this.scanner.index;
                this.lastMarker.line = this.scanner.lineNumber;
                this.lastMarker.column = this.scanner.index - this.scanner.lineStart;
                return this.finalize(node, new JSXNode.JSXEmptyExpression());
              };
              JSXParser2.prototype.parseJSXExpressionContainer = function() {
                var node = this.createJSXNode();
                this.expectJSX("{");
                var expression;
                if (this.matchJSX("}")) {
                  expression = this.parseJSXEmptyExpression();
                  this.expectJSX("}");
                } else {
                  this.finishJSX();
                  expression = this.parseAssignmentExpression();
                  this.reenterJSX();
                }
                return this.finalize(node, new JSXNode.JSXExpressionContainer(expression));
              };
              JSXParser2.prototype.parseJSXChildren = function() {
                var children = [];
                while (!this.scanner.eof()) {
                  var node = this.createJSXChildNode();
                  var token = this.nextJSXText();
                  if (token.start < token.end) {
                    var raw = this.getTokenRaw(token);
                    var child = this.finalize(node, new JSXNode.JSXText(token.value, raw));
                    children.push(child);
                  }
                  if (this.scanner.source[this.scanner.index] === "{") {
                    var container = this.parseJSXExpressionContainer();
                    children.push(container);
                  } else {
                    break;
                  }
                }
                return children;
              };
              JSXParser2.prototype.parseComplexJSXElement = function(el) {
                var stack = [];
                while (!this.scanner.eof()) {
                  el.children = el.children.concat(this.parseJSXChildren());
                  var node = this.createJSXChildNode();
                  var element = this.parseJSXBoundaryElement();
                  if (element.type === jsx_syntax_1.JSXSyntax.JSXOpeningElement) {
                    var opening = element;
                    if (opening.selfClosing) {
                      var child = this.finalize(node, new JSXNode.JSXElement(opening, [], null));
                      el.children.push(child);
                    } else {
                      stack.push(el);
                      el = { node, opening, closing: null, children: [] };
                    }
                  }
                  if (element.type === jsx_syntax_1.JSXSyntax.JSXClosingElement) {
                    el.closing = element;
                    var open_1 = getQualifiedElementName(el.opening.name);
                    var close_1 = getQualifiedElementName(el.closing.name);
                    if (open_1 !== close_1) {
                      this.tolerateError("Expected corresponding JSX closing tag for %0", open_1);
                    }
                    if (stack.length > 0) {
                      var child = this.finalize(el.node, new JSXNode.JSXElement(el.opening, el.children, el.closing));
                      el = stack[stack.length - 1];
                      el.children.push(child);
                      stack.pop();
                    } else {
                      break;
                    }
                  }
                }
                return el;
              };
              JSXParser2.prototype.parseJSXElement = function() {
                var node = this.createJSXNode();
                var opening = this.parseJSXOpeningElement();
                var children = [];
                var closing = null;
                if (!opening.selfClosing) {
                  var el = this.parseComplexJSXElement({ node, opening, closing, children });
                  children = el.children;
                  closing = el.closing;
                }
                return this.finalize(node, new JSXNode.JSXElement(opening, children, closing));
              };
              JSXParser2.prototype.parseJSXRoot = function() {
                if (this.config.tokens) {
                  this.tokens.pop();
                }
                this.startJSX();
                var element = this.parseJSXElement();
                this.finishJSX();
                return element;
              };
              JSXParser2.prototype.isStartOfExpression = function() {
                return _super.prototype.isStartOfExpression.call(this) || this.match("<");
              };
              return JSXParser2;
            })(parser_1.Parser);
            exports3.JSXParser = JSXParser;
          },
          /* 4 */
          /***/
          function(module3, exports3) {
            "use strict";
            Object.defineProperty(exports3, "__esModule", { value: true });
            var Regex = {
              // Unicode v8.0.0 NonAsciiIdentifierStart:
              NonAsciiIdentifierStart: /[\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u08A0-\u08B4\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C60\u0C61\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D5F-\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2118-\u211D\u2124\u2126\u2128\u212A-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303C\u3041-\u3096\u309B-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FD5\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6EF\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AD\uA7B0-\uA7B7\uA7F7-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA8FD\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD40-\uDD74\uDE80-\uDE9C\uDEA0-\uDED0\uDF00-\uDF1F\uDF30-\uDF4A\uDF50-\uDF75\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDCE0-\uDCF2\uDCF4\uDCF5\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00\uDE10-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE4\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48\uDC80-\uDCB2\uDCC0-\uDCF2]|\uD804[\uDC03-\uDC37\uDC83-\uDCAF\uDCD0-\uDCE8\uDD03-\uDD26\uDD50-\uDD72\uDD76\uDD83-\uDDB2\uDDC1-\uDDC4\uDDDA\uDDDC\uDE00-\uDE11\uDE13-\uDE2B\uDE80-\uDE86\uDE88\uDE8A-\uDE8D\uDE8F-\uDE9D\uDE9F-\uDEA8\uDEB0-\uDEDE\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3D\uDF50\uDF5D-\uDF61]|\uD805[\uDC80-\uDCAF\uDCC4\uDCC5\uDCC7\uDD80-\uDDAE\uDDD8-\uDDDB\uDE00-\uDE2F\uDE44\uDE80-\uDEAA\uDF00-\uDF19]|\uD806[\uDCA0-\uDCDF\uDCFF\uDEC0-\uDEF8]|\uD808[\uDC00-\uDF99]|\uD809[\uDC00-\uDC6E\uDC80-\uDD43]|[\uD80C\uD840-\uD868\uD86A-\uD86C\uD86F-\uD872][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD811[\uDC00-\uDE46]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDED0-\uDEED\uDF00-\uDF2F\uDF40-\uDF43\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50\uDF93-\uDF9F]|\uD82C[\uDC00\uDC01]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB]|\uD83A[\uDC00-\uDCC4]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D\uDC20-\uDFFF]|\uD873[\uDC00-\uDEA1]|\uD87E[\uDC00-\uDE1D]/,
              // Unicode v8.0.0 NonAsciiIdentifierPart:
              NonAsciiIdentifierPart: /[\xAA\xB5\xB7\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0300-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u0483-\u0487\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u0591-\u05BD\u05BF\u05C1\u05C2\u05C4\u05C5\u05C7\u05D0-\u05EA\u05F0-\u05F2\u0610-\u061A\u0620-\u0669\u066E-\u06D3\u06D5-\u06DC\u06DF-\u06E8\u06EA-\u06FC\u06FF\u0710-\u074A\u074D-\u07B1\u07C0-\u07F5\u07FA\u0800-\u082D\u0840-\u085B\u08A0-\u08B4\u08E3-\u0963\u0966-\u096F\u0971-\u0983\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BC-\u09C4\u09C7\u09C8\u09CB-\u09CE\u09D7\u09DC\u09DD\u09DF-\u09E3\u09E6-\u09F1\u0A01-\u0A03\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A3C\u0A3E-\u0A42\u0A47\u0A48\u0A4B-\u0A4D\u0A51\u0A59-\u0A5C\u0A5E\u0A66-\u0A75\u0A81-\u0A83\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABC-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0AD0\u0AE0-\u0AE3\u0AE6-\u0AEF\u0AF9\u0B01-\u0B03\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3C-\u0B44\u0B47\u0B48\u0B4B-\u0B4D\u0B56\u0B57\u0B5C\u0B5D\u0B5F-\u0B63\u0B66-\u0B6F\u0B71\u0B82\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD0\u0BD7\u0BE6-\u0BEF\u0C00-\u0C03\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55\u0C56\u0C58-\u0C5A\u0C60-\u0C63\u0C66-\u0C6F\u0C81-\u0C83\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBC-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5\u0CD6\u0CDE\u0CE0-\u0CE3\u0CE6-\u0CEF\u0CF1\u0CF2\u0D01-\u0D03\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D-\u0D44\u0D46-\u0D48\u0D4A-\u0D4E\u0D57\u0D5F-\u0D63\u0D66-\u0D6F\u0D7A-\u0D7F\u0D82\u0D83\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0DCA\u0DCF-\u0DD4\u0DD6\u0DD8-\u0DDF\u0DE6-\u0DEF\u0DF2\u0DF3\u0E01-\u0E3A\u0E40-\u0E4E\u0E50-\u0E59\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB9\u0EBB-\u0EBD\u0EC0-\u0EC4\u0EC6\u0EC8-\u0ECD\u0ED0-\u0ED9\u0EDC-\u0EDF\u0F00\u0F18\u0F19\u0F20-\u0F29\u0F35\u0F37\u0F39\u0F3E-\u0F47\u0F49-\u0F6C\u0F71-\u0F84\u0F86-\u0F97\u0F99-\u0FBC\u0FC6\u1000-\u1049\u1050-\u109D\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u135D-\u135F\u1369-\u1371\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1714\u1720-\u1734\u1740-\u1753\u1760-\u176C\u176E-\u1770\u1772\u1773\u1780-\u17D3\u17D7\u17DC\u17DD\u17E0-\u17E9\u180B-\u180D\u1810-\u1819\u1820-\u1877\u1880-\u18AA\u18B0-\u18F5\u1900-\u191E\u1920-\u192B\u1930-\u193B\u1946-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u19D0-\u19DA\u1A00-\u1A1B\u1A20-\u1A5E\u1A60-\u1A7C\u1A7F-\u1A89\u1A90-\u1A99\u1AA7\u1AB0-\u1ABD\u1B00-\u1B4B\u1B50-\u1B59\u1B6B-\u1B73\u1B80-\u1BF3\u1C00-\u1C37\u1C40-\u1C49\u1C4D-\u1C7D\u1CD0-\u1CD2\u1CD4-\u1CF6\u1CF8\u1CF9\u1D00-\u1DF5\u1DFC-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u200C\u200D\u203F\u2040\u2054\u2071\u207F\u2090-\u209C\u20D0-\u20DC\u20E1\u20E5-\u20F0\u2102\u2107\u210A-\u2113\u2115\u2118-\u211D\u2124\u2126\u2128\u212A-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D7F-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2DE0-\u2DFF\u3005-\u3007\u3021-\u302F\u3031-\u3035\u3038-\u303C\u3041-\u3096\u3099-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FD5\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA62B\uA640-\uA66F\uA674-\uA67D\uA67F-\uA6F1\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AD\uA7B0-\uA7B7\uA7F7-\uA827\uA840-\uA873\uA880-\uA8C4\uA8D0-\uA8D9\uA8E0-\uA8F7\uA8FB\uA8FD\uA900-\uA92D\uA930-\uA953\uA960-\uA97C\uA980-\uA9C0\uA9CF-\uA9D9\uA9E0-\uA9FE\uAA00-\uAA36\uAA40-\uAA4D\uAA50-\uAA59\uAA60-\uAA76\uAA7A-\uAAC2\uAADB-\uAADD\uAAE0-\uAAEF\uAAF2-\uAAF6\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABEA\uABEC\uABED\uABF0-\uABF9\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE00-\uFE0F\uFE20-\uFE2F\uFE33\uFE34\uFE4D-\uFE4F\uFE70-\uFE74\uFE76-\uFEFC\uFF10-\uFF19\uFF21-\uFF3A\uFF3F\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD40-\uDD74\uDDFD\uDE80-\uDE9C\uDEA0-\uDED0\uDEE0\uDF00-\uDF1F\uDF30-\uDF4A\uDF50-\uDF7A\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDCA0-\uDCA9\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDCE0-\uDCF2\uDCF4\uDCF5\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00-\uDE03\uDE05\uDE06\uDE0C-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE38-\uDE3A\uDE3F\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE6\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48\uDC80-\uDCB2\uDCC0-\uDCF2]|\uD804[\uDC00-\uDC46\uDC66-\uDC6F\uDC7F-\uDCBA\uDCD0-\uDCE8\uDCF0-\uDCF9\uDD00-\uDD34\uDD36-\uDD3F\uDD50-\uDD73\uDD76\uDD80-\uDDC4\uDDCA-\uDDCC\uDDD0-\uDDDA\uDDDC\uDE00-\uDE11\uDE13-\uDE37\uDE80-\uDE86\uDE88\uDE8A-\uDE8D\uDE8F-\uDE9D\uDE9F-\uDEA8\uDEB0-\uDEEA\uDEF0-\uDEF9\uDF00-\uDF03\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3C-\uDF44\uDF47\uDF48\uDF4B-\uDF4D\uDF50\uDF57\uDF5D-\uDF63\uDF66-\uDF6C\uDF70-\uDF74]|\uD805[\uDC80-\uDCC5\uDCC7\uDCD0-\uDCD9\uDD80-\uDDB5\uDDB8-\uDDC0\uDDD8-\uDDDD\uDE00-\uDE40\uDE44\uDE50-\uDE59\uDE80-\uDEB7\uDEC0-\uDEC9\uDF00-\uDF19\uDF1D-\uDF2B\uDF30-\uDF39]|\uD806[\uDCA0-\uDCE9\uDCFF\uDEC0-\uDEF8]|\uD808[\uDC00-\uDF99]|\uD809[\uDC00-\uDC6E\uDC80-\uDD43]|[\uD80C\uD840-\uD868\uD86A-\uD86C\uD86F-\uD872][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD811[\uDC00-\uDE46]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDE60-\uDE69\uDED0-\uDEED\uDEF0-\uDEF4\uDF00-\uDF36\uDF40-\uDF43\uDF50-\uDF59\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50-\uDF7E\uDF8F-\uDF9F]|\uD82C[\uDC00\uDC01]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99\uDC9D\uDC9E]|\uD834[\uDD65-\uDD69\uDD6D-\uDD72\uDD7B-\uDD82\uDD85-\uDD8B\uDDAA-\uDDAD\uDE42-\uDE44]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB\uDFCE-\uDFFF]|\uD836[\uDE00-\uDE36\uDE3B-\uDE6C\uDE75\uDE84\uDE9B-\uDE9F\uDEA1-\uDEAF]|\uD83A[\uDC00-\uDCC4\uDCD0-\uDCD6]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D\uDC20-\uDFFF]|\uD873[\uDC00-\uDEA1]|\uD87E[\uDC00-\uDE1D]|\uDB40[\uDD00-\uDDEF]/
            };
            exports3.Character = {
              /* tslint:disable:no-bitwise */
              fromCodePoint: /* @__PURE__ */ __name(function(cp) {
                return cp < 65536 ? String.fromCharCode(cp) : String.fromCharCode(55296 + (cp - 65536 >> 10)) + String.fromCharCode(56320 + (cp - 65536 & 1023));
              }, "fromCodePoint"),
              // https://tc39.github.io/ecma262/#sec-white-space
              isWhiteSpace: /* @__PURE__ */ __name(function(cp) {
                return cp === 32 || cp === 9 || cp === 11 || cp === 12 || cp === 160 || cp >= 5760 && [5760, 8192, 8193, 8194, 8195, 8196, 8197, 8198, 8199, 8200, 8201, 8202, 8239, 8287, 12288, 65279].indexOf(cp) >= 0;
              }, "isWhiteSpace"),
              // https://tc39.github.io/ecma262/#sec-line-terminators
              isLineTerminator: /* @__PURE__ */ __name(function(cp) {
                return cp === 10 || cp === 13 || cp === 8232 || cp === 8233;
              }, "isLineTerminator"),
              // https://tc39.github.io/ecma262/#sec-names-and-keywords
              isIdentifierStart: /* @__PURE__ */ __name(function(cp) {
                return cp === 36 || cp === 95 || cp >= 65 && cp <= 90 || cp >= 97 && cp <= 122 || cp === 92 || cp >= 128 && Regex.NonAsciiIdentifierStart.test(exports3.Character.fromCodePoint(cp));
              }, "isIdentifierStart"),
              isIdentifierPart: /* @__PURE__ */ __name(function(cp) {
                return cp === 36 || cp === 95 || cp >= 65 && cp <= 90 || cp >= 97 && cp <= 122 || cp >= 48 && cp <= 57 || cp === 92 || cp >= 128 && Regex.NonAsciiIdentifierPart.test(exports3.Character.fromCodePoint(cp));
              }, "isIdentifierPart"),
              // https://tc39.github.io/ecma262/#sec-literals-numeric-literals
              isDecimalDigit: /* @__PURE__ */ __name(function(cp) {
                return cp >= 48 && cp <= 57;
              }, "isDecimalDigit"),
              isHexDigit: /* @__PURE__ */ __name(function(cp) {
                return cp >= 48 && cp <= 57 || cp >= 65 && cp <= 70 || cp >= 97 && cp <= 102;
              }, "isHexDigit"),
              isOctalDigit: /* @__PURE__ */ __name(function(cp) {
                return cp >= 48 && cp <= 55;
              }, "isOctalDigit")
            };
          },
          /* 5 */
          /***/
          function(module3, exports3, __webpack_require__) {
            "use strict";
            Object.defineProperty(exports3, "__esModule", { value: true });
            var jsx_syntax_1 = __webpack_require__(6);
            var JSXClosingElement = /* @__PURE__ */ (function() {
              function JSXClosingElement2(name) {
                this.type = jsx_syntax_1.JSXSyntax.JSXClosingElement;
                this.name = name;
              }
              __name(JSXClosingElement2, "JSXClosingElement");
              return JSXClosingElement2;
            })();
            exports3.JSXClosingElement = JSXClosingElement;
            var JSXElement = /* @__PURE__ */ (function() {
              function JSXElement2(openingElement, children, closingElement) {
                this.type = jsx_syntax_1.JSXSyntax.JSXElement;
                this.openingElement = openingElement;
                this.children = children;
                this.closingElement = closingElement;
              }
              __name(JSXElement2, "JSXElement");
              return JSXElement2;
            })();
            exports3.JSXElement = JSXElement;
            var JSXEmptyExpression = /* @__PURE__ */ (function() {
              function JSXEmptyExpression2() {
                this.type = jsx_syntax_1.JSXSyntax.JSXEmptyExpression;
              }
              __name(JSXEmptyExpression2, "JSXEmptyExpression");
              return JSXEmptyExpression2;
            })();
            exports3.JSXEmptyExpression = JSXEmptyExpression;
            var JSXExpressionContainer = /* @__PURE__ */ (function() {
              function JSXExpressionContainer2(expression) {
                this.type = jsx_syntax_1.JSXSyntax.JSXExpressionContainer;
                this.expression = expression;
              }
              __name(JSXExpressionContainer2, "JSXExpressionContainer");
              return JSXExpressionContainer2;
            })();
            exports3.JSXExpressionContainer = JSXExpressionContainer;
            var JSXIdentifier = /* @__PURE__ */ (function() {
              function JSXIdentifier2(name) {
                this.type = jsx_syntax_1.JSXSyntax.JSXIdentifier;
                this.name = name;
              }
              __name(JSXIdentifier2, "JSXIdentifier");
              return JSXIdentifier2;
            })();
            exports3.JSXIdentifier = JSXIdentifier;
            var JSXMemberExpression = /* @__PURE__ */ (function() {
              function JSXMemberExpression2(object, property) {
                this.type = jsx_syntax_1.JSXSyntax.JSXMemberExpression;
                this.object = object;
                this.property = property;
              }
              __name(JSXMemberExpression2, "JSXMemberExpression");
              return JSXMemberExpression2;
            })();
            exports3.JSXMemberExpression = JSXMemberExpression;
            var JSXAttribute = /* @__PURE__ */ (function() {
              function JSXAttribute2(name, value) {
                this.type = jsx_syntax_1.JSXSyntax.JSXAttribute;
                this.name = name;
                this.value = value;
              }
              __name(JSXAttribute2, "JSXAttribute");
              return JSXAttribute2;
            })();
            exports3.JSXAttribute = JSXAttribute;
            var JSXNamespacedName = /* @__PURE__ */ (function() {
              function JSXNamespacedName2(namespace, name) {
                this.type = jsx_syntax_1.JSXSyntax.JSXNamespacedName;
                this.namespace = namespace;
                this.name = name;
              }
              __name(JSXNamespacedName2, "JSXNamespacedName");
              return JSXNamespacedName2;
            })();
            exports3.JSXNamespacedName = JSXNamespacedName;
            var JSXOpeningElement = /* @__PURE__ */ (function() {
              function JSXOpeningElement2(name, selfClosing, attributes) {
                this.type = jsx_syntax_1.JSXSyntax.JSXOpeningElement;
                this.name = name;
                this.selfClosing = selfClosing;
                this.attributes = attributes;
              }
              __name(JSXOpeningElement2, "JSXOpeningElement");
              return JSXOpeningElement2;
            })();
            exports3.JSXOpeningElement = JSXOpeningElement;
            var JSXSpreadAttribute = /* @__PURE__ */ (function() {
              function JSXSpreadAttribute2(argument) {
                this.type = jsx_syntax_1.JSXSyntax.JSXSpreadAttribute;
                this.argument = argument;
              }
              __name(JSXSpreadAttribute2, "JSXSpreadAttribute");
              return JSXSpreadAttribute2;
            })();
            exports3.JSXSpreadAttribute = JSXSpreadAttribute;
            var JSXText = /* @__PURE__ */ (function() {
              function JSXText2(value, raw) {
                this.type = jsx_syntax_1.JSXSyntax.JSXText;
                this.value = value;
                this.raw = raw;
              }
              __name(JSXText2, "JSXText");
              return JSXText2;
            })();
            exports3.JSXText = JSXText;
          },
          /* 6 */
          /***/
          function(module3, exports3) {
            "use strict";
            Object.defineProperty(exports3, "__esModule", { value: true });
            exports3.JSXSyntax = {
              JSXAttribute: "JSXAttribute",
              JSXClosingElement: "JSXClosingElement",
              JSXElement: "JSXElement",
              JSXEmptyExpression: "JSXEmptyExpression",
              JSXExpressionContainer: "JSXExpressionContainer",
              JSXIdentifier: "JSXIdentifier",
              JSXMemberExpression: "JSXMemberExpression",
              JSXNamespacedName: "JSXNamespacedName",
              JSXOpeningElement: "JSXOpeningElement",
              JSXSpreadAttribute: "JSXSpreadAttribute",
              JSXText: "JSXText"
            };
          },
          /* 7 */
          /***/
          function(module3, exports3, __webpack_require__) {
            "use strict";
            Object.defineProperty(exports3, "__esModule", { value: true });
            var syntax_1 = __webpack_require__(2);
            var ArrayExpression = /* @__PURE__ */ (function() {
              function ArrayExpression2(elements) {
                this.type = syntax_1.Syntax.ArrayExpression;
                this.elements = elements;
              }
              __name(ArrayExpression2, "ArrayExpression");
              return ArrayExpression2;
            })();
            exports3.ArrayExpression = ArrayExpression;
            var ArrayPattern = /* @__PURE__ */ (function() {
              function ArrayPattern2(elements) {
                this.type = syntax_1.Syntax.ArrayPattern;
                this.elements = elements;
              }
              __name(ArrayPattern2, "ArrayPattern");
              return ArrayPattern2;
            })();
            exports3.ArrayPattern = ArrayPattern;
            var ArrowFunctionExpression = /* @__PURE__ */ (function() {
              function ArrowFunctionExpression2(params, body, expression) {
                this.type = syntax_1.Syntax.ArrowFunctionExpression;
                this.id = null;
                this.params = params;
                this.body = body;
                this.generator = false;
                this.expression = expression;
                this.async = false;
              }
              __name(ArrowFunctionExpression2, "ArrowFunctionExpression");
              return ArrowFunctionExpression2;
            })();
            exports3.ArrowFunctionExpression = ArrowFunctionExpression;
            var AssignmentExpression = /* @__PURE__ */ (function() {
              function AssignmentExpression2(operator, left, right) {
                this.type = syntax_1.Syntax.AssignmentExpression;
                this.operator = operator;
                this.left = left;
                this.right = right;
              }
              __name(AssignmentExpression2, "AssignmentExpression");
              return AssignmentExpression2;
            })();
            exports3.AssignmentExpression = AssignmentExpression;
            var AssignmentPattern = /* @__PURE__ */ (function() {
              function AssignmentPattern2(left, right) {
                this.type = syntax_1.Syntax.AssignmentPattern;
                this.left = left;
                this.right = right;
              }
              __name(AssignmentPattern2, "AssignmentPattern");
              return AssignmentPattern2;
            })();
            exports3.AssignmentPattern = AssignmentPattern;
            var AsyncArrowFunctionExpression = /* @__PURE__ */ (function() {
              function AsyncArrowFunctionExpression2(params, body, expression) {
                this.type = syntax_1.Syntax.ArrowFunctionExpression;
                this.id = null;
                this.params = params;
                this.body = body;
                this.generator = false;
                this.expression = expression;
                this.async = true;
              }
              __name(AsyncArrowFunctionExpression2, "AsyncArrowFunctionExpression");
              return AsyncArrowFunctionExpression2;
            })();
            exports3.AsyncArrowFunctionExpression = AsyncArrowFunctionExpression;
            var AsyncFunctionDeclaration = /* @__PURE__ */ (function() {
              function AsyncFunctionDeclaration2(id, params, body) {
                this.type = syntax_1.Syntax.FunctionDeclaration;
                this.id = id;
                this.params = params;
                this.body = body;
                this.generator = false;
                this.expression = false;
                this.async = true;
              }
              __name(AsyncFunctionDeclaration2, "AsyncFunctionDeclaration");
              return AsyncFunctionDeclaration2;
            })();
            exports3.AsyncFunctionDeclaration = AsyncFunctionDeclaration;
            var AsyncFunctionExpression = /* @__PURE__ */ (function() {
              function AsyncFunctionExpression2(id, params, body) {
                this.type = syntax_1.Syntax.FunctionExpression;
                this.id = id;
                this.params = params;
                this.body = body;
                this.generator = false;
                this.expression = false;
                this.async = true;
              }
              __name(AsyncFunctionExpression2, "AsyncFunctionExpression");
              return AsyncFunctionExpression2;
            })();
            exports3.AsyncFunctionExpression = AsyncFunctionExpression;
            var AwaitExpression = /* @__PURE__ */ (function() {
              function AwaitExpression2(argument) {
                this.type = syntax_1.Syntax.AwaitExpression;
                this.argument = argument;
              }
              __name(AwaitExpression2, "AwaitExpression");
              return AwaitExpression2;
            })();
            exports3.AwaitExpression = AwaitExpression;
            var BinaryExpression = /* @__PURE__ */ (function() {
              function BinaryExpression2(operator, left, right) {
                var logical = operator === "||" || operator === "&&";
                this.type = logical ? syntax_1.Syntax.LogicalExpression : syntax_1.Syntax.BinaryExpression;
                this.operator = operator;
                this.left = left;
                this.right = right;
              }
              __name(BinaryExpression2, "BinaryExpression");
              return BinaryExpression2;
            })();
            exports3.BinaryExpression = BinaryExpression;
            var BlockStatement = /* @__PURE__ */ (function() {
              function BlockStatement2(body) {
                this.type = syntax_1.Syntax.BlockStatement;
                this.body = body;
              }
              __name(BlockStatement2, "BlockStatement");
              return BlockStatement2;
            })();
            exports3.BlockStatement = BlockStatement;
            var BreakStatement = /* @__PURE__ */ (function() {
              function BreakStatement2(label) {
                this.type = syntax_1.Syntax.BreakStatement;
                this.label = label;
              }
              __name(BreakStatement2, "BreakStatement");
              return BreakStatement2;
            })();
            exports3.BreakStatement = BreakStatement;
            var CallExpression = /* @__PURE__ */ (function() {
              function CallExpression2(callee, args) {
                this.type = syntax_1.Syntax.CallExpression;
                this.callee = callee;
                this.arguments = args;
              }
              __name(CallExpression2, "CallExpression");
              return CallExpression2;
            })();
            exports3.CallExpression = CallExpression;
            var CatchClause = /* @__PURE__ */ (function() {
              function CatchClause2(param, body) {
                this.type = syntax_1.Syntax.CatchClause;
                this.param = param;
                this.body = body;
              }
              __name(CatchClause2, "CatchClause");
              return CatchClause2;
            })();
            exports3.CatchClause = CatchClause;
            var ClassBody = /* @__PURE__ */ (function() {
              function ClassBody2(body) {
                this.type = syntax_1.Syntax.ClassBody;
                this.body = body;
              }
              __name(ClassBody2, "ClassBody");
              return ClassBody2;
            })();
            exports3.ClassBody = ClassBody;
            var ClassDeclaration = /* @__PURE__ */ (function() {
              function ClassDeclaration2(id, superClass, body) {
                this.type = syntax_1.Syntax.ClassDeclaration;
                this.id = id;
                this.superClass = superClass;
                this.body = body;
              }
              __name(ClassDeclaration2, "ClassDeclaration");
              return ClassDeclaration2;
            })();
            exports3.ClassDeclaration = ClassDeclaration;
            var ClassExpression = /* @__PURE__ */ (function() {
              function ClassExpression2(id, superClass, body) {
                this.type = syntax_1.Syntax.ClassExpression;
                this.id = id;
                this.superClass = superClass;
                this.body = body;
              }
              __name(ClassExpression2, "ClassExpression");
              return ClassExpression2;
            })();
            exports3.ClassExpression = ClassExpression;
            var ComputedMemberExpression = /* @__PURE__ */ (function() {
              function ComputedMemberExpression2(object, property) {
                this.type = syntax_1.Syntax.MemberExpression;
                this.computed = true;
                this.object = object;
                this.property = property;
              }
              __name(ComputedMemberExpression2, "ComputedMemberExpression");
              return ComputedMemberExpression2;
            })();
            exports3.ComputedMemberExpression = ComputedMemberExpression;
            var ConditionalExpression = /* @__PURE__ */ (function() {
              function ConditionalExpression2(test, consequent, alternate) {
                this.type = syntax_1.Syntax.ConditionalExpression;
                this.test = test;
                this.consequent = consequent;
                this.alternate = alternate;
              }
              __name(ConditionalExpression2, "ConditionalExpression");
              return ConditionalExpression2;
            })();
            exports3.ConditionalExpression = ConditionalExpression;
            var ContinueStatement = /* @__PURE__ */ (function() {
              function ContinueStatement2(label) {
                this.type = syntax_1.Syntax.ContinueStatement;
                this.label = label;
              }
              __name(ContinueStatement2, "ContinueStatement");
              return ContinueStatement2;
            })();
            exports3.ContinueStatement = ContinueStatement;
            var DebuggerStatement = /* @__PURE__ */ (function() {
              function DebuggerStatement2() {
                this.type = syntax_1.Syntax.DebuggerStatement;
              }
              __name(DebuggerStatement2, "DebuggerStatement");
              return DebuggerStatement2;
            })();
            exports3.DebuggerStatement = DebuggerStatement;
            var Directive = /* @__PURE__ */ (function() {
              function Directive2(expression, directive) {
                this.type = syntax_1.Syntax.ExpressionStatement;
                this.expression = expression;
                this.directive = directive;
              }
              __name(Directive2, "Directive");
              return Directive2;
            })();
            exports3.Directive = Directive;
            var DoWhileStatement = /* @__PURE__ */ (function() {
              function DoWhileStatement2(body, test) {
                this.type = syntax_1.Syntax.DoWhileStatement;
                this.body = body;
                this.test = test;
              }
              __name(DoWhileStatement2, "DoWhileStatement");
              return DoWhileStatement2;
            })();
            exports3.DoWhileStatement = DoWhileStatement;
            var EmptyStatement = /* @__PURE__ */ (function() {
              function EmptyStatement2() {
                this.type = syntax_1.Syntax.EmptyStatement;
              }
              __name(EmptyStatement2, "EmptyStatement");
              return EmptyStatement2;
            })();
            exports3.EmptyStatement = EmptyStatement;
            var ExportAllDeclaration = /* @__PURE__ */ (function() {
              function ExportAllDeclaration2(source) {
                this.type = syntax_1.Syntax.ExportAllDeclaration;
                this.source = source;
              }
              __name(ExportAllDeclaration2, "ExportAllDeclaration");
              return ExportAllDeclaration2;
            })();
            exports3.ExportAllDeclaration = ExportAllDeclaration;
            var ExportDefaultDeclaration = /* @__PURE__ */ (function() {
              function ExportDefaultDeclaration2(declaration) {
                this.type = syntax_1.Syntax.ExportDefaultDeclaration;
                this.declaration = declaration;
              }
              __name(ExportDefaultDeclaration2, "ExportDefaultDeclaration");
              return ExportDefaultDeclaration2;
            })();
            exports3.ExportDefaultDeclaration = ExportDefaultDeclaration;
            var ExportNamedDeclaration = /* @__PURE__ */ (function() {
              function ExportNamedDeclaration2(declaration, specifiers, source) {
                this.type = syntax_1.Syntax.ExportNamedDeclaration;
                this.declaration = declaration;
                this.specifiers = specifiers;
                this.source = source;
              }
              __name(ExportNamedDeclaration2, "ExportNamedDeclaration");
              return ExportNamedDeclaration2;
            })();
            exports3.ExportNamedDeclaration = ExportNamedDeclaration;
            var ExportSpecifier = /* @__PURE__ */ (function() {
              function ExportSpecifier2(local, exported) {
                this.type = syntax_1.Syntax.ExportSpecifier;
                this.exported = exported;
                this.local = local;
              }
              __name(ExportSpecifier2, "ExportSpecifier");
              return ExportSpecifier2;
            })();
            exports3.ExportSpecifier = ExportSpecifier;
            var ExpressionStatement = /* @__PURE__ */ (function() {
              function ExpressionStatement2(expression) {
                this.type = syntax_1.Syntax.ExpressionStatement;
                this.expression = expression;
              }
              __name(ExpressionStatement2, "ExpressionStatement");
              return ExpressionStatement2;
            })();
            exports3.ExpressionStatement = ExpressionStatement;
            var ForInStatement = /* @__PURE__ */ (function() {
              function ForInStatement2(left, right, body) {
                this.type = syntax_1.Syntax.ForInStatement;
                this.left = left;
                this.right = right;
                this.body = body;
                this.each = false;
              }
              __name(ForInStatement2, "ForInStatement");
              return ForInStatement2;
            })();
            exports3.ForInStatement = ForInStatement;
            var ForOfStatement = /* @__PURE__ */ (function() {
              function ForOfStatement2(left, right, body) {
                this.type = syntax_1.Syntax.ForOfStatement;
                this.left = left;
                this.right = right;
                this.body = body;
              }
              __name(ForOfStatement2, "ForOfStatement");
              return ForOfStatement2;
            })();
            exports3.ForOfStatement = ForOfStatement;
            var ForStatement = /* @__PURE__ */ (function() {
              function ForStatement2(init, test, update, body) {
                this.type = syntax_1.Syntax.ForStatement;
                this.init = init;
                this.test = test;
                this.update = update;
                this.body = body;
              }
              __name(ForStatement2, "ForStatement");
              return ForStatement2;
            })();
            exports3.ForStatement = ForStatement;
            var FunctionDeclaration = /* @__PURE__ */ (function() {
              function FunctionDeclaration2(id, params, body, generator) {
                this.type = syntax_1.Syntax.FunctionDeclaration;
                this.id = id;
                this.params = params;
                this.body = body;
                this.generator = generator;
                this.expression = false;
                this.async = false;
              }
              __name(FunctionDeclaration2, "FunctionDeclaration");
              return FunctionDeclaration2;
            })();
            exports3.FunctionDeclaration = FunctionDeclaration;
            var FunctionExpression = /* @__PURE__ */ (function() {
              function FunctionExpression2(id, params, body, generator) {
                this.type = syntax_1.Syntax.FunctionExpression;
                this.id = id;
                this.params = params;
                this.body = body;
                this.generator = generator;
                this.expression = false;
                this.async = false;
              }
              __name(FunctionExpression2, "FunctionExpression");
              return FunctionExpression2;
            })();
            exports3.FunctionExpression = FunctionExpression;
            var Identifier = /* @__PURE__ */ (function() {
              function Identifier2(name) {
                this.type = syntax_1.Syntax.Identifier;
                this.name = name;
              }
              __name(Identifier2, "Identifier");
              return Identifier2;
            })();
            exports3.Identifier = Identifier;
            var IfStatement = /* @__PURE__ */ (function() {
              function IfStatement2(test, consequent, alternate) {
                this.type = syntax_1.Syntax.IfStatement;
                this.test = test;
                this.consequent = consequent;
                this.alternate = alternate;
              }
              __name(IfStatement2, "IfStatement");
              return IfStatement2;
            })();
            exports3.IfStatement = IfStatement;
            var ImportDeclaration = /* @__PURE__ */ (function() {
              function ImportDeclaration2(specifiers, source) {
                this.type = syntax_1.Syntax.ImportDeclaration;
                this.specifiers = specifiers;
                this.source = source;
              }
              __name(ImportDeclaration2, "ImportDeclaration");
              return ImportDeclaration2;
            })();
            exports3.ImportDeclaration = ImportDeclaration;
            var ImportDefaultSpecifier = /* @__PURE__ */ (function() {
              function ImportDefaultSpecifier2(local) {
                this.type = syntax_1.Syntax.ImportDefaultSpecifier;
                this.local = local;
              }
              __name(ImportDefaultSpecifier2, "ImportDefaultSpecifier");
              return ImportDefaultSpecifier2;
            })();
            exports3.ImportDefaultSpecifier = ImportDefaultSpecifier;
            var ImportNamespaceSpecifier = /* @__PURE__ */ (function() {
              function ImportNamespaceSpecifier2(local) {
                this.type = syntax_1.Syntax.ImportNamespaceSpecifier;
                this.local = local;
              }
              __name(ImportNamespaceSpecifier2, "ImportNamespaceSpecifier");
              return ImportNamespaceSpecifier2;
            })();
            exports3.ImportNamespaceSpecifier = ImportNamespaceSpecifier;
            var ImportSpecifier = /* @__PURE__ */ (function() {
              function ImportSpecifier2(local, imported) {
                this.type = syntax_1.Syntax.ImportSpecifier;
                this.local = local;
                this.imported = imported;
              }
              __name(ImportSpecifier2, "ImportSpecifier");
              return ImportSpecifier2;
            })();
            exports3.ImportSpecifier = ImportSpecifier;
            var LabeledStatement = /* @__PURE__ */ (function() {
              function LabeledStatement2(label, body) {
                this.type = syntax_1.Syntax.LabeledStatement;
                this.label = label;
                this.body = body;
              }
              __name(LabeledStatement2, "LabeledStatement");
              return LabeledStatement2;
            })();
            exports3.LabeledStatement = LabeledStatement;
            var Literal = /* @__PURE__ */ (function() {
              function Literal2(value, raw) {
                this.type = syntax_1.Syntax.Literal;
                this.value = value;
                this.raw = raw;
              }
              __name(Literal2, "Literal");
              return Literal2;
            })();
            exports3.Literal = Literal;
            var MetaProperty = /* @__PURE__ */ (function() {
              function MetaProperty2(meta, property) {
                this.type = syntax_1.Syntax.MetaProperty;
                this.meta = meta;
                this.property = property;
              }
              __name(MetaProperty2, "MetaProperty");
              return MetaProperty2;
            })();
            exports3.MetaProperty = MetaProperty;
            var MethodDefinition = /* @__PURE__ */ (function() {
              function MethodDefinition2(key, computed, value, kind, isStatic) {
                this.type = syntax_1.Syntax.MethodDefinition;
                this.key = key;
                this.computed = computed;
                this.value = value;
                this.kind = kind;
                this.static = isStatic;
              }
              __name(MethodDefinition2, "MethodDefinition");
              return MethodDefinition2;
            })();
            exports3.MethodDefinition = MethodDefinition;
            var Module = /* @__PURE__ */ (function() {
              function Module2(body) {
                this.type = syntax_1.Syntax.Program;
                this.body = body;
                this.sourceType = "module";
              }
              __name(Module2, "Module");
              return Module2;
            })();
            exports3.Module = Module;
            var NewExpression = /* @__PURE__ */ (function() {
              function NewExpression2(callee, args) {
                this.type = syntax_1.Syntax.NewExpression;
                this.callee = callee;
                this.arguments = args;
              }
              __name(NewExpression2, "NewExpression");
              return NewExpression2;
            })();
            exports3.NewExpression = NewExpression;
            var ObjectExpression = /* @__PURE__ */ (function() {
              function ObjectExpression2(properties) {
                this.type = syntax_1.Syntax.ObjectExpression;
                this.properties = properties;
              }
              __name(ObjectExpression2, "ObjectExpression");
              return ObjectExpression2;
            })();
            exports3.ObjectExpression = ObjectExpression;
            var ObjectPattern = /* @__PURE__ */ (function() {
              function ObjectPattern2(properties) {
                this.type = syntax_1.Syntax.ObjectPattern;
                this.properties = properties;
              }
              __name(ObjectPattern2, "ObjectPattern");
              return ObjectPattern2;
            })();
            exports3.ObjectPattern = ObjectPattern;
            var Property = /* @__PURE__ */ (function() {
              function Property2(kind, key, computed, value, method, shorthand) {
                this.type = syntax_1.Syntax.Property;
                this.key = key;
                this.computed = computed;
                this.value = value;
                this.kind = kind;
                this.method = method;
                this.shorthand = shorthand;
              }
              __name(Property2, "Property");
              return Property2;
            })();
            exports3.Property = Property;
            var RegexLiteral = /* @__PURE__ */ (function() {
              function RegexLiteral2(value, raw, pattern, flags) {
                this.type = syntax_1.Syntax.Literal;
                this.value = value;
                this.raw = raw;
                this.regex = { pattern, flags };
              }
              __name(RegexLiteral2, "RegexLiteral");
              return RegexLiteral2;
            })();
            exports3.RegexLiteral = RegexLiteral;
            var RestElement = /* @__PURE__ */ (function() {
              function RestElement2(argument) {
                this.type = syntax_1.Syntax.RestElement;
                this.argument = argument;
              }
              __name(RestElement2, "RestElement");
              return RestElement2;
            })();
            exports3.RestElement = RestElement;
            var ReturnStatement = /* @__PURE__ */ (function() {
              function ReturnStatement2(argument) {
                this.type = syntax_1.Syntax.ReturnStatement;
                this.argument = argument;
              }
              __name(ReturnStatement2, "ReturnStatement");
              return ReturnStatement2;
            })();
            exports3.ReturnStatement = ReturnStatement;
            var Script = /* @__PURE__ */ (function() {
              function Script2(body) {
                this.type = syntax_1.Syntax.Program;
                this.body = body;
                this.sourceType = "script";
              }
              __name(Script2, "Script");
              return Script2;
            })();
            exports3.Script = Script;
            var SequenceExpression = /* @__PURE__ */ (function() {
              function SequenceExpression2(expressions) {
                this.type = syntax_1.Syntax.SequenceExpression;
                this.expressions = expressions;
              }
              __name(SequenceExpression2, "SequenceExpression");
              return SequenceExpression2;
            })();
            exports3.SequenceExpression = SequenceExpression;
            var SpreadElement = /* @__PURE__ */ (function() {
              function SpreadElement2(argument) {
                this.type = syntax_1.Syntax.SpreadElement;
                this.argument = argument;
              }
              __name(SpreadElement2, "SpreadElement");
              return SpreadElement2;
            })();
            exports3.SpreadElement = SpreadElement;
            var StaticMemberExpression = /* @__PURE__ */ (function() {
              function StaticMemberExpression2(object, property) {
                this.type = syntax_1.Syntax.MemberExpression;
                this.computed = false;
                this.object = object;
                this.property = property;
              }
              __name(StaticMemberExpression2, "StaticMemberExpression");
              return StaticMemberExpression2;
            })();
            exports3.StaticMemberExpression = StaticMemberExpression;
            var Super = /* @__PURE__ */ (function() {
              function Super2() {
                this.type = syntax_1.Syntax.Super;
              }
              __name(Super2, "Super");
              return Super2;
            })();
            exports3.Super = Super;
            var SwitchCase = /* @__PURE__ */ (function() {
              function SwitchCase2(test, consequent) {
                this.type = syntax_1.Syntax.SwitchCase;
                this.test = test;
                this.consequent = consequent;
              }
              __name(SwitchCase2, "SwitchCase");
              return SwitchCase2;
            })();
            exports3.SwitchCase = SwitchCase;
            var SwitchStatement = /* @__PURE__ */ (function() {
              function SwitchStatement2(discriminant, cases) {
                this.type = syntax_1.Syntax.SwitchStatement;
                this.discriminant = discriminant;
                this.cases = cases;
              }
              __name(SwitchStatement2, "SwitchStatement");
              return SwitchStatement2;
            })();
            exports3.SwitchStatement = SwitchStatement;
            var TaggedTemplateExpression = /* @__PURE__ */ (function() {
              function TaggedTemplateExpression2(tag3, quasi) {
                this.type = syntax_1.Syntax.TaggedTemplateExpression;
                this.tag = tag3;
                this.quasi = quasi;
              }
              __name(TaggedTemplateExpression2, "TaggedTemplateExpression");
              return TaggedTemplateExpression2;
            })();
            exports3.TaggedTemplateExpression = TaggedTemplateExpression;
            var TemplateElement = /* @__PURE__ */ (function() {
              function TemplateElement2(value, tail) {
                this.type = syntax_1.Syntax.TemplateElement;
                this.value = value;
                this.tail = tail;
              }
              __name(TemplateElement2, "TemplateElement");
              return TemplateElement2;
            })();
            exports3.TemplateElement = TemplateElement;
            var TemplateLiteral = /* @__PURE__ */ (function() {
              function TemplateLiteral2(quasis, expressions) {
                this.type = syntax_1.Syntax.TemplateLiteral;
                this.quasis = quasis;
                this.expressions = expressions;
              }
              __name(TemplateLiteral2, "TemplateLiteral");
              return TemplateLiteral2;
            })();
            exports3.TemplateLiteral = TemplateLiteral;
            var ThisExpression = /* @__PURE__ */ (function() {
              function ThisExpression2() {
                this.type = syntax_1.Syntax.ThisExpression;
              }
              __name(ThisExpression2, "ThisExpression");
              return ThisExpression2;
            })();
            exports3.ThisExpression = ThisExpression;
            var ThrowStatement = /* @__PURE__ */ (function() {
              function ThrowStatement2(argument) {
                this.type = syntax_1.Syntax.ThrowStatement;
                this.argument = argument;
              }
              __name(ThrowStatement2, "ThrowStatement");
              return ThrowStatement2;
            })();
            exports3.ThrowStatement = ThrowStatement;
            var TryStatement = /* @__PURE__ */ (function() {
              function TryStatement2(block, handler, finalizer) {
                this.type = syntax_1.Syntax.TryStatement;
                this.block = block;
                this.handler = handler;
                this.finalizer = finalizer;
              }
              __name(TryStatement2, "TryStatement");
              return TryStatement2;
            })();
            exports3.TryStatement = TryStatement;
            var UnaryExpression = /* @__PURE__ */ (function() {
              function UnaryExpression2(operator, argument) {
                this.type = syntax_1.Syntax.UnaryExpression;
                this.operator = operator;
                this.argument = argument;
                this.prefix = true;
              }
              __name(UnaryExpression2, "UnaryExpression");
              return UnaryExpression2;
            })();
            exports3.UnaryExpression = UnaryExpression;
            var UpdateExpression = /* @__PURE__ */ (function() {
              function UpdateExpression2(operator, argument, prefix) {
                this.type = syntax_1.Syntax.UpdateExpression;
                this.operator = operator;
                this.argument = argument;
                this.prefix = prefix;
              }
              __name(UpdateExpression2, "UpdateExpression");
              return UpdateExpression2;
            })();
            exports3.UpdateExpression = UpdateExpression;
            var VariableDeclaration = /* @__PURE__ */ (function() {
              function VariableDeclaration2(declarations, kind) {
                this.type = syntax_1.Syntax.VariableDeclaration;
                this.declarations = declarations;
                this.kind = kind;
              }
              __name(VariableDeclaration2, "VariableDeclaration");
              return VariableDeclaration2;
            })();
            exports3.VariableDeclaration = VariableDeclaration;
            var VariableDeclarator = /* @__PURE__ */ (function() {
              function VariableDeclarator2(id, init) {
                this.type = syntax_1.Syntax.VariableDeclarator;
                this.id = id;
                this.init = init;
              }
              __name(VariableDeclarator2, "VariableDeclarator");
              return VariableDeclarator2;
            })();
            exports3.VariableDeclarator = VariableDeclarator;
            var WhileStatement = /* @__PURE__ */ (function() {
              function WhileStatement2(test, body) {
                this.type = syntax_1.Syntax.WhileStatement;
                this.test = test;
                this.body = body;
              }
              __name(WhileStatement2, "WhileStatement");
              return WhileStatement2;
            })();
            exports3.WhileStatement = WhileStatement;
            var WithStatement = /* @__PURE__ */ (function() {
              function WithStatement2(object, body) {
                this.type = syntax_1.Syntax.WithStatement;
                this.object = object;
                this.body = body;
              }
              __name(WithStatement2, "WithStatement");
              return WithStatement2;
            })();
            exports3.WithStatement = WithStatement;
            var YieldExpression = /* @__PURE__ */ (function() {
              function YieldExpression2(argument, delegate) {
                this.type = syntax_1.Syntax.YieldExpression;
                this.argument = argument;
                this.delegate = delegate;
              }
              __name(YieldExpression2, "YieldExpression");
              return YieldExpression2;
            })();
            exports3.YieldExpression = YieldExpression;
          },
          /* 8 */
          /***/
          function(module3, exports3, __webpack_require__) {
            "use strict";
            Object.defineProperty(exports3, "__esModule", { value: true });
            var assert_1 = __webpack_require__(9);
            var error_handler_1 = __webpack_require__(10);
            var messages_1 = __webpack_require__(11);
            var Node2 = __webpack_require__(7);
            var scanner_1 = __webpack_require__(12);
            var syntax_1 = __webpack_require__(2);
            var token_1 = __webpack_require__(13);
            var ArrowParameterPlaceHolder = "ArrowParameterPlaceHolder";
            var Parser = (function() {
              function Parser2(code, options, delegate) {
                if (options === void 0) {
                  options = {};
                }
                this.config = {
                  range: typeof options.range === "boolean" && options.range,
                  loc: typeof options.loc === "boolean" && options.loc,
                  source: null,
                  tokens: typeof options.tokens === "boolean" && options.tokens,
                  comment: typeof options.comment === "boolean" && options.comment,
                  tolerant: typeof options.tolerant === "boolean" && options.tolerant
                };
                if (this.config.loc && options.source && options.source !== null) {
                  this.config.source = String(options.source);
                }
                this.delegate = delegate;
                this.errorHandler = new error_handler_1.ErrorHandler();
                this.errorHandler.tolerant = this.config.tolerant;
                this.scanner = new scanner_1.Scanner(code, this.errorHandler);
                this.scanner.trackComment = this.config.comment;
                this.operatorPrecedence = {
                  ")": 0,
                  ";": 0,
                  ",": 0,
                  "=": 0,
                  "]": 0,
                  "||": 1,
                  "&&": 2,
                  "|": 3,
                  "^": 4,
                  "&": 5,
                  "==": 6,
                  "!=": 6,
                  "===": 6,
                  "!==": 6,
                  "<": 7,
                  ">": 7,
                  "<=": 7,
                  ">=": 7,
                  "<<": 8,
                  ">>": 8,
                  ">>>": 8,
                  "+": 9,
                  "-": 9,
                  "*": 11,
                  "/": 11,
                  "%": 11
                };
                this.lookahead = {
                  type: 2,
                  value: "",
                  lineNumber: this.scanner.lineNumber,
                  lineStart: 0,
                  start: 0,
                  end: 0
                };
                this.hasLineTerminator = false;
                this.context = {
                  isModule: false,
                  await: false,
                  allowIn: true,
                  allowStrictDirective: true,
                  allowYield: true,
                  firstCoverInitializedNameError: null,
                  isAssignmentTarget: false,
                  isBindingElement: false,
                  inFunctionBody: false,
                  inIteration: false,
                  inSwitch: false,
                  labelSet: {},
                  strict: false
                };
                this.tokens = [];
                this.startMarker = {
                  index: 0,
                  line: this.scanner.lineNumber,
                  column: 0
                };
                this.lastMarker = {
                  index: 0,
                  line: this.scanner.lineNumber,
                  column: 0
                };
                this.nextToken();
                this.lastMarker = {
                  index: this.scanner.index,
                  line: this.scanner.lineNumber,
                  column: this.scanner.index - this.scanner.lineStart
                };
              }
              __name(Parser2, "Parser");
              Parser2.prototype.throwError = function(messageFormat) {
                var values = [];
                for (var _i = 1; _i < arguments.length; _i++) {
                  values[_i - 1] = arguments[_i];
                }
                var args = Array.prototype.slice.call(arguments, 1);
                var msg = messageFormat.replace(/%(\d)/g, function(whole, idx) {
                  assert_1.assert(idx < args.length, "Message reference must be in range");
                  return args[idx];
                });
                var index = this.lastMarker.index;
                var line = this.lastMarker.line;
                var column = this.lastMarker.column + 1;
                throw this.errorHandler.createError(index, line, column, msg);
              };
              Parser2.prototype.tolerateError = function(messageFormat) {
                var values = [];
                for (var _i = 1; _i < arguments.length; _i++) {
                  values[_i - 1] = arguments[_i];
                }
                var args = Array.prototype.slice.call(arguments, 1);
                var msg = messageFormat.replace(/%(\d)/g, function(whole, idx) {
                  assert_1.assert(idx < args.length, "Message reference must be in range");
                  return args[idx];
                });
                var index = this.lastMarker.index;
                var line = this.scanner.lineNumber;
                var column = this.lastMarker.column + 1;
                this.errorHandler.tolerateError(index, line, column, msg);
              };
              Parser2.prototype.unexpectedTokenError = function(token, message2) {
                var msg = message2 || messages_1.Messages.UnexpectedToken;
                var value;
                if (token) {
                  if (!message2) {
                    msg = token.type === 2 ? messages_1.Messages.UnexpectedEOS : token.type === 3 ? messages_1.Messages.UnexpectedIdentifier : token.type === 6 ? messages_1.Messages.UnexpectedNumber : token.type === 8 ? messages_1.Messages.UnexpectedString : token.type === 10 ? messages_1.Messages.UnexpectedTemplate : messages_1.Messages.UnexpectedToken;
                    if (token.type === 4) {
                      if (this.scanner.isFutureReservedWord(token.value)) {
                        msg = messages_1.Messages.UnexpectedReserved;
                      } else if (this.context.strict && this.scanner.isStrictModeReservedWord(token.value)) {
                        msg = messages_1.Messages.StrictReservedWord;
                      }
                    }
                  }
                  value = token.value;
                } else {
                  value = "ILLEGAL";
                }
                msg = msg.replace("%0", value);
                if (token && typeof token.lineNumber === "number") {
                  var index = token.start;
                  var line = token.lineNumber;
                  var lastMarkerLineStart = this.lastMarker.index - this.lastMarker.column;
                  var column = token.start - lastMarkerLineStart + 1;
                  return this.errorHandler.createError(index, line, column, msg);
                } else {
                  var index = this.lastMarker.index;
                  var line = this.lastMarker.line;
                  var column = this.lastMarker.column + 1;
                  return this.errorHandler.createError(index, line, column, msg);
                }
              };
              Parser2.prototype.throwUnexpectedToken = function(token, message2) {
                throw this.unexpectedTokenError(token, message2);
              };
              Parser2.prototype.tolerateUnexpectedToken = function(token, message2) {
                this.errorHandler.tolerate(this.unexpectedTokenError(token, message2));
              };
              Parser2.prototype.collectComments = function() {
                if (!this.config.comment) {
                  this.scanner.scanComments();
                } else {
                  var comments = this.scanner.scanComments();
                  if (comments.length > 0 && this.delegate) {
                    for (var i32 = 0; i32 < comments.length; ++i32) {
                      var e32 = comments[i32];
                      var node = void 0;
                      node = {
                        type: e32.multiLine ? "BlockComment" : "LineComment",
                        value: this.scanner.source.slice(e32.slice[0], e32.slice[1])
                      };
                      if (this.config.range) {
                        node.range = e32.range;
                      }
                      if (this.config.loc) {
                        node.loc = e32.loc;
                      }
                      var metadata = {
                        start: {
                          line: e32.loc.start.line,
                          column: e32.loc.start.column,
                          offset: e32.range[0]
                        },
                        end: {
                          line: e32.loc.end.line,
                          column: e32.loc.end.column,
                          offset: e32.range[1]
                        }
                      };
                      this.delegate(node, metadata);
                    }
                  }
                }
              };
              Parser2.prototype.getTokenRaw = function(token) {
                return this.scanner.source.slice(token.start, token.end);
              };
              Parser2.prototype.convertToken = function(token) {
                var t = {
                  type: token_1.TokenName[token.type],
                  value: this.getTokenRaw(token)
                };
                if (this.config.range) {
                  t.range = [token.start, token.end];
                }
                if (this.config.loc) {
                  t.loc = {
                    start: {
                      line: this.startMarker.line,
                      column: this.startMarker.column
                    },
                    end: {
                      line: this.scanner.lineNumber,
                      column: this.scanner.index - this.scanner.lineStart
                    }
                  };
                }
                if (token.type === 9) {
                  var pattern = token.pattern;
                  var flags = token.flags;
                  t.regex = { pattern, flags };
                }
                return t;
              };
              Parser2.prototype.nextToken = function() {
                var token = this.lookahead;
                this.lastMarker.index = this.scanner.index;
                this.lastMarker.line = this.scanner.lineNumber;
                this.lastMarker.column = this.scanner.index - this.scanner.lineStart;
                this.collectComments();
                if (this.scanner.index !== this.startMarker.index) {
                  this.startMarker.index = this.scanner.index;
                  this.startMarker.line = this.scanner.lineNumber;
                  this.startMarker.column = this.scanner.index - this.scanner.lineStart;
                }
                var next = this.scanner.lex();
                this.hasLineTerminator = token.lineNumber !== next.lineNumber;
                if (next && this.context.strict && next.type === 3) {
                  if (this.scanner.isStrictModeReservedWord(next.value)) {
                    next.type = 4;
                  }
                }
                this.lookahead = next;
                if (this.config.tokens && next.type !== 2) {
                  this.tokens.push(this.convertToken(next));
                }
                return token;
              };
              Parser2.prototype.nextRegexToken = function() {
                this.collectComments();
                var token = this.scanner.scanRegExp();
                if (this.config.tokens) {
                  this.tokens.pop();
                  this.tokens.push(this.convertToken(token));
                }
                this.lookahead = token;
                this.nextToken();
                return token;
              };
              Parser2.prototype.createNode = function() {
                return {
                  index: this.startMarker.index,
                  line: this.startMarker.line,
                  column: this.startMarker.column
                };
              };
              Parser2.prototype.startNode = function(token, lastLineStart) {
                if (lastLineStart === void 0) {
                  lastLineStart = 0;
                }
                var column = token.start - token.lineStart;
                var line = token.lineNumber;
                if (column < 0) {
                  column += lastLineStart;
                  line--;
                }
                return {
                  index: token.start,
                  line,
                  column
                };
              };
              Parser2.prototype.finalize = function(marker, node) {
                if (this.config.range) {
                  node.range = [marker.index, this.lastMarker.index];
                }
                if (this.config.loc) {
                  node.loc = {
                    start: {
                      line: marker.line,
                      column: marker.column
                    },
                    end: {
                      line: this.lastMarker.line,
                      column: this.lastMarker.column
                    }
                  };
                  if (this.config.source) {
                    node.loc.source = this.config.source;
                  }
                }
                if (this.delegate) {
                  var metadata = {
                    start: {
                      line: marker.line,
                      column: marker.column,
                      offset: marker.index
                    },
                    end: {
                      line: this.lastMarker.line,
                      column: this.lastMarker.column,
                      offset: this.lastMarker.index
                    }
                  };
                  this.delegate(node, metadata);
                }
                return node;
              };
              Parser2.prototype.expect = function(value) {
                var token = this.nextToken();
                if (token.type !== 7 || token.value !== value) {
                  this.throwUnexpectedToken(token);
                }
              };
              Parser2.prototype.expectCommaSeparator = function() {
                if (this.config.tolerant) {
                  var token = this.lookahead;
                  if (token.type === 7 && token.value === ",") {
                    this.nextToken();
                  } else if (token.type === 7 && token.value === ";") {
                    this.nextToken();
                    this.tolerateUnexpectedToken(token);
                  } else {
                    this.tolerateUnexpectedToken(token, messages_1.Messages.UnexpectedToken);
                  }
                } else {
                  this.expect(",");
                }
              };
              Parser2.prototype.expectKeyword = function(keyword) {
                var token = this.nextToken();
                if (token.type !== 4 || token.value !== keyword) {
                  this.throwUnexpectedToken(token);
                }
              };
              Parser2.prototype.match = function(value) {
                return this.lookahead.type === 7 && this.lookahead.value === value;
              };
              Parser2.prototype.matchKeyword = function(keyword) {
                return this.lookahead.type === 4 && this.lookahead.value === keyword;
              };
              Parser2.prototype.matchContextualKeyword = function(keyword) {
                return this.lookahead.type === 3 && this.lookahead.value === keyword;
              };
              Parser2.prototype.matchAssign = function() {
                if (this.lookahead.type !== 7) {
                  return false;
                }
                var op3 = this.lookahead.value;
                return op3 === "=" || op3 === "*=" || op3 === "**=" || op3 === "/=" || op3 === "%=" || op3 === "+=" || op3 === "-=" || op3 === "<<=" || op3 === ">>=" || op3 === ">>>=" || op3 === "&=" || op3 === "^=" || op3 === "|=";
              };
              Parser2.prototype.isolateCoverGrammar = function(parseFunction) {
                var previousIsBindingElement = this.context.isBindingElement;
                var previousIsAssignmentTarget = this.context.isAssignmentTarget;
                var previousFirstCoverInitializedNameError = this.context.firstCoverInitializedNameError;
                this.context.isBindingElement = true;
                this.context.isAssignmentTarget = true;
                this.context.firstCoverInitializedNameError = null;
                var result2 = parseFunction.call(this);
                if (this.context.firstCoverInitializedNameError !== null) {
                  this.throwUnexpectedToken(this.context.firstCoverInitializedNameError);
                }
                this.context.isBindingElement = previousIsBindingElement;
                this.context.isAssignmentTarget = previousIsAssignmentTarget;
                this.context.firstCoverInitializedNameError = previousFirstCoverInitializedNameError;
                return result2;
              };
              Parser2.prototype.inheritCoverGrammar = function(parseFunction) {
                var previousIsBindingElement = this.context.isBindingElement;
                var previousIsAssignmentTarget = this.context.isAssignmentTarget;
                var previousFirstCoverInitializedNameError = this.context.firstCoverInitializedNameError;
                this.context.isBindingElement = true;
                this.context.isAssignmentTarget = true;
                this.context.firstCoverInitializedNameError = null;
                var result2 = parseFunction.call(this);
                this.context.isBindingElement = this.context.isBindingElement && previousIsBindingElement;
                this.context.isAssignmentTarget = this.context.isAssignmentTarget && previousIsAssignmentTarget;
                this.context.firstCoverInitializedNameError = previousFirstCoverInitializedNameError || this.context.firstCoverInitializedNameError;
                return result2;
              };
              Parser2.prototype.consumeSemicolon = function() {
                if (this.match(";")) {
                  this.nextToken();
                } else if (!this.hasLineTerminator) {
                  if (this.lookahead.type !== 2 && !this.match("}")) {
                    this.throwUnexpectedToken(this.lookahead);
                  }
                  this.lastMarker.index = this.startMarker.index;
                  this.lastMarker.line = this.startMarker.line;
                  this.lastMarker.column = this.startMarker.column;
                }
              };
              Parser2.prototype.parsePrimaryExpression = function() {
                var node = this.createNode();
                var expr;
                var token, raw;
                switch (this.lookahead.type) {
                  case 3:
                    if ((this.context.isModule || this.context.await) && this.lookahead.value === "await") {
                      this.tolerateUnexpectedToken(this.lookahead);
                    }
                    expr = this.matchAsyncFunction() ? this.parseFunctionExpression() : this.finalize(node, new Node2.Identifier(this.nextToken().value));
                    break;
                  case 6:
                  case 8:
                    if (this.context.strict && this.lookahead.octal) {
                      this.tolerateUnexpectedToken(this.lookahead, messages_1.Messages.StrictOctalLiteral);
                    }
                    this.context.isAssignmentTarget = false;
                    this.context.isBindingElement = false;
                    token = this.nextToken();
                    raw = this.getTokenRaw(token);
                    expr = this.finalize(node, new Node2.Literal(token.value, raw));
                    break;
                  case 1:
                    this.context.isAssignmentTarget = false;
                    this.context.isBindingElement = false;
                    token = this.nextToken();
                    raw = this.getTokenRaw(token);
                    expr = this.finalize(node, new Node2.Literal(token.value === "true", raw));
                    break;
                  case 5:
                    this.context.isAssignmentTarget = false;
                    this.context.isBindingElement = false;
                    token = this.nextToken();
                    raw = this.getTokenRaw(token);
                    expr = this.finalize(node, new Node2.Literal(null, raw));
                    break;
                  case 10:
                    expr = this.parseTemplateLiteral();
                    break;
                  case 7:
                    switch (this.lookahead.value) {
                      case "(":
                        this.context.isBindingElement = false;
                        expr = this.inheritCoverGrammar(this.parseGroupExpression);
                        break;
                      case "[":
                        expr = this.inheritCoverGrammar(this.parseArrayInitializer);
                        break;
                      case "{":
                        expr = this.inheritCoverGrammar(this.parseObjectInitializer);
                        break;
                      case "/":
                      case "/=":
                        this.context.isAssignmentTarget = false;
                        this.context.isBindingElement = false;
                        this.scanner.index = this.startMarker.index;
                        token = this.nextRegexToken();
                        raw = this.getTokenRaw(token);
                        expr = this.finalize(node, new Node2.RegexLiteral(token.regex, raw, token.pattern, token.flags));
                        break;
                      default:
                        expr = this.throwUnexpectedToken(this.nextToken());
                    }
                    break;
                  case 4:
                    if (!this.context.strict && this.context.allowYield && this.matchKeyword("yield")) {
                      expr = this.parseIdentifierName();
                    } else if (!this.context.strict && this.matchKeyword("let")) {
                      expr = this.finalize(node, new Node2.Identifier(this.nextToken().value));
                    } else {
                      this.context.isAssignmentTarget = false;
                      this.context.isBindingElement = false;
                      if (this.matchKeyword("function")) {
                        expr = this.parseFunctionExpression();
                      } else if (this.matchKeyword("this")) {
                        this.nextToken();
                        expr = this.finalize(node, new Node2.ThisExpression());
                      } else if (this.matchKeyword("class")) {
                        expr = this.parseClassExpression();
                      } else {
                        expr = this.throwUnexpectedToken(this.nextToken());
                      }
                    }
                    break;
                  default:
                    expr = this.throwUnexpectedToken(this.nextToken());
                }
                return expr;
              };
              Parser2.prototype.parseSpreadElement = function() {
                var node = this.createNode();
                this.expect("...");
                var arg = this.inheritCoverGrammar(this.parseAssignmentExpression);
                return this.finalize(node, new Node2.SpreadElement(arg));
              };
              Parser2.prototype.parseArrayInitializer = function() {
                var node = this.createNode();
                var elements = [];
                this.expect("[");
                while (!this.match("]")) {
                  if (this.match(",")) {
                    this.nextToken();
                    elements.push(null);
                  } else if (this.match("...")) {
                    var element = this.parseSpreadElement();
                    if (!this.match("]")) {
                      this.context.isAssignmentTarget = false;
                      this.context.isBindingElement = false;
                      this.expect(",");
                    }
                    elements.push(element);
                  } else {
                    elements.push(this.inheritCoverGrammar(this.parseAssignmentExpression));
                    if (!this.match("]")) {
                      this.expect(",");
                    }
                  }
                }
                this.expect("]");
                return this.finalize(node, new Node2.ArrayExpression(elements));
              };
              Parser2.prototype.parsePropertyMethod = function(params) {
                this.context.isAssignmentTarget = false;
                this.context.isBindingElement = false;
                var previousStrict = this.context.strict;
                var previousAllowStrictDirective = this.context.allowStrictDirective;
                this.context.allowStrictDirective = params.simple;
                var body = this.isolateCoverGrammar(this.parseFunctionSourceElements);
                if (this.context.strict && params.firstRestricted) {
                  this.tolerateUnexpectedToken(params.firstRestricted, params.message);
                }
                if (this.context.strict && params.stricted) {
                  this.tolerateUnexpectedToken(params.stricted, params.message);
                }
                this.context.strict = previousStrict;
                this.context.allowStrictDirective = previousAllowStrictDirective;
                return body;
              };
              Parser2.prototype.parsePropertyMethodFunction = function() {
                var isGenerator = false;
                var node = this.createNode();
                var previousAllowYield = this.context.allowYield;
                this.context.allowYield = true;
                var params = this.parseFormalParameters();
                var method = this.parsePropertyMethod(params);
                this.context.allowYield = previousAllowYield;
                return this.finalize(node, new Node2.FunctionExpression(null, params.params, method, isGenerator));
              };
              Parser2.prototype.parsePropertyMethodAsyncFunction = function() {
                var node = this.createNode();
                var previousAllowYield = this.context.allowYield;
                var previousAwait = this.context.await;
                this.context.allowYield = false;
                this.context.await = true;
                var params = this.parseFormalParameters();
                var method = this.parsePropertyMethod(params);
                this.context.allowYield = previousAllowYield;
                this.context.await = previousAwait;
                return this.finalize(node, new Node2.AsyncFunctionExpression(null, params.params, method));
              };
              Parser2.prototype.parseObjectPropertyKey = function() {
                var node = this.createNode();
                var token = this.nextToken();
                var key;
                switch (token.type) {
                  case 8:
                  case 6:
                    if (this.context.strict && token.octal) {
                      this.tolerateUnexpectedToken(token, messages_1.Messages.StrictOctalLiteral);
                    }
                    var raw = this.getTokenRaw(token);
                    key = this.finalize(node, new Node2.Literal(token.value, raw));
                    break;
                  case 3:
                  case 1:
                  case 5:
                  case 4:
                    key = this.finalize(node, new Node2.Identifier(token.value));
                    break;
                  case 7:
                    if (token.value === "[") {
                      key = this.isolateCoverGrammar(this.parseAssignmentExpression);
                      this.expect("]");
                    } else {
                      key = this.throwUnexpectedToken(token);
                    }
                    break;
                  default:
                    key = this.throwUnexpectedToken(token);
                }
                return key;
              };
              Parser2.prototype.isPropertyKey = function(key, value) {
                return key.type === syntax_1.Syntax.Identifier && key.name === value || key.type === syntax_1.Syntax.Literal && key.value === value;
              };
              Parser2.prototype.parseObjectProperty = function(hasProto) {
                var node = this.createNode();
                var token = this.lookahead;
                var kind;
                var key = null;
                var value = null;
                var computed = false;
                var method = false;
                var shorthand = false;
                var isAsync = false;
                if (token.type === 3) {
                  var id = token.value;
                  this.nextToken();
                  computed = this.match("[");
                  isAsync = !this.hasLineTerminator && id === "async" && !this.match(":") && !this.match("(") && !this.match("*") && !this.match(",");
                  key = isAsync ? this.parseObjectPropertyKey() : this.finalize(node, new Node2.Identifier(id));
                } else if (this.match("*")) {
                  this.nextToken();
                } else {
                  computed = this.match("[");
                  key = this.parseObjectPropertyKey();
                }
                var lookaheadPropertyKey = this.qualifiedPropertyName(this.lookahead);
                if (token.type === 3 && !isAsync && token.value === "get" && lookaheadPropertyKey) {
                  kind = "get";
                  computed = this.match("[");
                  key = this.parseObjectPropertyKey();
                  this.context.allowYield = false;
                  value = this.parseGetterMethod();
                } else if (token.type === 3 && !isAsync && token.value === "set" && lookaheadPropertyKey) {
                  kind = "set";
                  computed = this.match("[");
                  key = this.parseObjectPropertyKey();
                  value = this.parseSetterMethod();
                } else if (token.type === 7 && token.value === "*" && lookaheadPropertyKey) {
                  kind = "init";
                  computed = this.match("[");
                  key = this.parseObjectPropertyKey();
                  value = this.parseGeneratorMethod();
                  method = true;
                } else {
                  if (!key) {
                    this.throwUnexpectedToken(this.lookahead);
                  }
                  kind = "init";
                  if (this.match(":") && !isAsync) {
                    if (!computed && this.isPropertyKey(key, "__proto__")) {
                      if (hasProto.value) {
                        this.tolerateError(messages_1.Messages.DuplicateProtoProperty);
                      }
                      hasProto.value = true;
                    }
                    this.nextToken();
                    value = this.inheritCoverGrammar(this.parseAssignmentExpression);
                  } else if (this.match("(")) {
                    value = isAsync ? this.parsePropertyMethodAsyncFunction() : this.parsePropertyMethodFunction();
                    method = true;
                  } else if (token.type === 3) {
                    var id = this.finalize(node, new Node2.Identifier(token.value));
                    if (this.match("=")) {
                      this.context.firstCoverInitializedNameError = this.lookahead;
                      this.nextToken();
                      shorthand = true;
                      var init = this.isolateCoverGrammar(this.parseAssignmentExpression);
                      value = this.finalize(node, new Node2.AssignmentPattern(id, init));
                    } else {
                      shorthand = true;
                      value = id;
                    }
                  } else {
                    this.throwUnexpectedToken(this.nextToken());
                  }
                }
                return this.finalize(node, new Node2.Property(kind, key, computed, value, method, shorthand));
              };
              Parser2.prototype.parseObjectInitializer = function() {
                var node = this.createNode();
                this.expect("{");
                var properties = [];
                var hasProto = { value: false };
                while (!this.match("}")) {
                  properties.push(this.parseObjectProperty(hasProto));
                  if (!this.match("}")) {
                    this.expectCommaSeparator();
                  }
                }
                this.expect("}");
                return this.finalize(node, new Node2.ObjectExpression(properties));
              };
              Parser2.prototype.parseTemplateHead = function() {
                assert_1.assert(this.lookahead.head, "Template literal must start with a template head");
                var node = this.createNode();
                var token = this.nextToken();
                var raw = token.value;
                var cooked = token.cooked;
                return this.finalize(node, new Node2.TemplateElement({ raw, cooked }, token.tail));
              };
              Parser2.prototype.parseTemplateElement = function() {
                if (this.lookahead.type !== 10) {
                  this.throwUnexpectedToken();
                }
                var node = this.createNode();
                var token = this.nextToken();
                var raw = token.value;
                var cooked = token.cooked;
                return this.finalize(node, new Node2.TemplateElement({ raw, cooked }, token.tail));
              };
              Parser2.prototype.parseTemplateLiteral = function() {
                var node = this.createNode();
                var expressions = [];
                var quasis = [];
                var quasi = this.parseTemplateHead();
                quasis.push(quasi);
                while (!quasi.tail) {
                  expressions.push(this.parseExpression());
                  quasi = this.parseTemplateElement();
                  quasis.push(quasi);
                }
                return this.finalize(node, new Node2.TemplateLiteral(quasis, expressions));
              };
              Parser2.prototype.reinterpretExpressionAsPattern = function(expr) {
                switch (expr.type) {
                  case syntax_1.Syntax.Identifier:
                  case syntax_1.Syntax.MemberExpression:
                  case syntax_1.Syntax.RestElement:
                  case syntax_1.Syntax.AssignmentPattern:
                    break;
                  case syntax_1.Syntax.SpreadElement:
                    expr.type = syntax_1.Syntax.RestElement;
                    this.reinterpretExpressionAsPattern(expr.argument);
                    break;
                  case syntax_1.Syntax.ArrayExpression:
                    expr.type = syntax_1.Syntax.ArrayPattern;
                    for (var i32 = 0; i32 < expr.elements.length; i32++) {
                      if (expr.elements[i32] !== null) {
                        this.reinterpretExpressionAsPattern(expr.elements[i32]);
                      }
                    }
                    break;
                  case syntax_1.Syntax.ObjectExpression:
                    expr.type = syntax_1.Syntax.ObjectPattern;
                    for (var i32 = 0; i32 < expr.properties.length; i32++) {
                      this.reinterpretExpressionAsPattern(expr.properties[i32].value);
                    }
                    break;
                  case syntax_1.Syntax.AssignmentExpression:
                    expr.type = syntax_1.Syntax.AssignmentPattern;
                    delete expr.operator;
                    this.reinterpretExpressionAsPattern(expr.left);
                    break;
                  default:
                    break;
                }
              };
              Parser2.prototype.parseGroupExpression = function() {
                var expr;
                this.expect("(");
                if (this.match(")")) {
                  this.nextToken();
                  if (!this.match("=>")) {
                    this.expect("=>");
                  }
                  expr = {
                    type: ArrowParameterPlaceHolder,
                    params: [],
                    async: false
                  };
                } else {
                  var startToken = this.lookahead;
                  var params = [];
                  if (this.match("...")) {
                    expr = this.parseRestElement(params);
                    this.expect(")");
                    if (!this.match("=>")) {
                      this.expect("=>");
                    }
                    expr = {
                      type: ArrowParameterPlaceHolder,
                      params: [expr],
                      async: false
                    };
                  } else {
                    var arrow = false;
                    this.context.isBindingElement = true;
                    expr = this.inheritCoverGrammar(this.parseAssignmentExpression);
                    if (this.match(",")) {
                      var expressions = [];
                      this.context.isAssignmentTarget = false;
                      expressions.push(expr);
                      while (this.lookahead.type !== 2) {
                        if (!this.match(",")) {
                          break;
                        }
                        this.nextToken();
                        if (this.match(")")) {
                          this.nextToken();
                          for (var i32 = 0; i32 < expressions.length; i32++) {
                            this.reinterpretExpressionAsPattern(expressions[i32]);
                          }
                          arrow = true;
                          expr = {
                            type: ArrowParameterPlaceHolder,
                            params: expressions,
                            async: false
                          };
                        } else if (this.match("...")) {
                          if (!this.context.isBindingElement) {
                            this.throwUnexpectedToken(this.lookahead);
                          }
                          expressions.push(this.parseRestElement(params));
                          this.expect(")");
                          if (!this.match("=>")) {
                            this.expect("=>");
                          }
                          this.context.isBindingElement = false;
                          for (var i32 = 0; i32 < expressions.length; i32++) {
                            this.reinterpretExpressionAsPattern(expressions[i32]);
                          }
                          arrow = true;
                          expr = {
                            type: ArrowParameterPlaceHolder,
                            params: expressions,
                            async: false
                          };
                        } else {
                          expressions.push(this.inheritCoverGrammar(this.parseAssignmentExpression));
                        }
                        if (arrow) {
                          break;
                        }
                      }
                      if (!arrow) {
                        expr = this.finalize(this.startNode(startToken), new Node2.SequenceExpression(expressions));
                      }
                    }
                    if (!arrow) {
                      this.expect(")");
                      if (this.match("=>")) {
                        if (expr.type === syntax_1.Syntax.Identifier && expr.name === "yield") {
                          arrow = true;
                          expr = {
                            type: ArrowParameterPlaceHolder,
                            params: [expr],
                            async: false
                          };
                        }
                        if (!arrow) {
                          if (!this.context.isBindingElement) {
                            this.throwUnexpectedToken(this.lookahead);
                          }
                          if (expr.type === syntax_1.Syntax.SequenceExpression) {
                            for (var i32 = 0; i32 < expr.expressions.length; i32++) {
                              this.reinterpretExpressionAsPattern(expr.expressions[i32]);
                            }
                          } else {
                            this.reinterpretExpressionAsPattern(expr);
                          }
                          var parameters = expr.type === syntax_1.Syntax.SequenceExpression ? expr.expressions : [expr];
                          expr = {
                            type: ArrowParameterPlaceHolder,
                            params: parameters,
                            async: false
                          };
                        }
                      }
                      this.context.isBindingElement = false;
                    }
                  }
                }
                return expr;
              };
              Parser2.prototype.parseArguments = function() {
                this.expect("(");
                var args = [];
                if (!this.match(")")) {
                  while (true) {
                    var expr = this.match("...") ? this.parseSpreadElement() : this.isolateCoverGrammar(this.parseAssignmentExpression);
                    args.push(expr);
                    if (this.match(")")) {
                      break;
                    }
                    this.expectCommaSeparator();
                    if (this.match(")")) {
                      break;
                    }
                  }
                }
                this.expect(")");
                return args;
              };
              Parser2.prototype.isIdentifierName = function(token) {
                return token.type === 3 || token.type === 4 || token.type === 1 || token.type === 5;
              };
              Parser2.prototype.parseIdentifierName = function() {
                var node = this.createNode();
                var token = this.nextToken();
                if (!this.isIdentifierName(token)) {
                  this.throwUnexpectedToken(token);
                }
                return this.finalize(node, new Node2.Identifier(token.value));
              };
              Parser2.prototype.parseNewExpression = function() {
                var node = this.createNode();
                var id = this.parseIdentifierName();
                assert_1.assert(id.name === "new", "New expression must start with `new`");
                var expr;
                if (this.match(".")) {
                  this.nextToken();
                  if (this.lookahead.type === 3 && this.context.inFunctionBody && this.lookahead.value === "target") {
                    var property = this.parseIdentifierName();
                    expr = new Node2.MetaProperty(id, property);
                  } else {
                    this.throwUnexpectedToken(this.lookahead);
                  }
                } else {
                  var callee = this.isolateCoverGrammar(this.parseLeftHandSideExpression);
                  var args = this.match("(") ? this.parseArguments() : [];
                  expr = new Node2.NewExpression(callee, args);
                  this.context.isAssignmentTarget = false;
                  this.context.isBindingElement = false;
                }
                return this.finalize(node, expr);
              };
              Parser2.prototype.parseAsyncArgument = function() {
                var arg = this.parseAssignmentExpression();
                this.context.firstCoverInitializedNameError = null;
                return arg;
              };
              Parser2.prototype.parseAsyncArguments = function() {
                this.expect("(");
                var args = [];
                if (!this.match(")")) {
                  while (true) {
                    var expr = this.match("...") ? this.parseSpreadElement() : this.isolateCoverGrammar(this.parseAsyncArgument);
                    args.push(expr);
                    if (this.match(")")) {
                      break;
                    }
                    this.expectCommaSeparator();
                    if (this.match(")")) {
                      break;
                    }
                  }
                }
                this.expect(")");
                return args;
              };
              Parser2.prototype.parseLeftHandSideExpressionAllowCall = function() {
                var startToken = this.lookahead;
                var maybeAsync = this.matchContextualKeyword("async");
                var previousAllowIn = this.context.allowIn;
                this.context.allowIn = true;
                var expr;
                if (this.matchKeyword("super") && this.context.inFunctionBody) {
                  expr = this.createNode();
                  this.nextToken();
                  expr = this.finalize(expr, new Node2.Super());
                  if (!this.match("(") && !this.match(".") && !this.match("[")) {
                    this.throwUnexpectedToken(this.lookahead);
                  }
                } else {
                  expr = this.inheritCoverGrammar(this.matchKeyword("new") ? this.parseNewExpression : this.parsePrimaryExpression);
                }
                while (true) {
                  if (this.match(".")) {
                    this.context.isBindingElement = false;
                    this.context.isAssignmentTarget = true;
                    this.expect(".");
                    var property = this.parseIdentifierName();
                    expr = this.finalize(this.startNode(startToken), new Node2.StaticMemberExpression(expr, property));
                  } else if (this.match("(")) {
                    var asyncArrow = maybeAsync && startToken.lineNumber === this.lookahead.lineNumber;
                    this.context.isBindingElement = false;
                    this.context.isAssignmentTarget = false;
                    var args = asyncArrow ? this.parseAsyncArguments() : this.parseArguments();
                    expr = this.finalize(this.startNode(startToken), new Node2.CallExpression(expr, args));
                    if (asyncArrow && this.match("=>")) {
                      for (var i32 = 0; i32 < args.length; ++i32) {
                        this.reinterpretExpressionAsPattern(args[i32]);
                      }
                      expr = {
                        type: ArrowParameterPlaceHolder,
                        params: args,
                        async: true
                      };
                    }
                  } else if (this.match("[")) {
                    this.context.isBindingElement = false;
                    this.context.isAssignmentTarget = true;
                    this.expect("[");
                    var property = this.isolateCoverGrammar(this.parseExpression);
                    this.expect("]");
                    expr = this.finalize(this.startNode(startToken), new Node2.ComputedMemberExpression(expr, property));
                  } else if (this.lookahead.type === 10 && this.lookahead.head) {
                    var quasi = this.parseTemplateLiteral();
                    expr = this.finalize(this.startNode(startToken), new Node2.TaggedTemplateExpression(expr, quasi));
                  } else {
                    break;
                  }
                }
                this.context.allowIn = previousAllowIn;
                return expr;
              };
              Parser2.prototype.parseSuper = function() {
                var node = this.createNode();
                this.expectKeyword("super");
                if (!this.match("[") && !this.match(".")) {
                  this.throwUnexpectedToken(this.lookahead);
                }
                return this.finalize(node, new Node2.Super());
              };
              Parser2.prototype.parseLeftHandSideExpression = function() {
                assert_1.assert(this.context.allowIn, "callee of new expression always allow in keyword.");
                var node = this.startNode(this.lookahead);
                var expr = this.matchKeyword("super") && this.context.inFunctionBody ? this.parseSuper() : this.inheritCoverGrammar(this.matchKeyword("new") ? this.parseNewExpression : this.parsePrimaryExpression);
                while (true) {
                  if (this.match("[")) {
                    this.context.isBindingElement = false;
                    this.context.isAssignmentTarget = true;
                    this.expect("[");
                    var property = this.isolateCoverGrammar(this.parseExpression);
                    this.expect("]");
                    expr = this.finalize(node, new Node2.ComputedMemberExpression(expr, property));
                  } else if (this.match(".")) {
                    this.context.isBindingElement = false;
                    this.context.isAssignmentTarget = true;
                    this.expect(".");
                    var property = this.parseIdentifierName();
                    expr = this.finalize(node, new Node2.StaticMemberExpression(expr, property));
                  } else if (this.lookahead.type === 10 && this.lookahead.head) {
                    var quasi = this.parseTemplateLiteral();
                    expr = this.finalize(node, new Node2.TaggedTemplateExpression(expr, quasi));
                  } else {
                    break;
                  }
                }
                return expr;
              };
              Parser2.prototype.parseUpdateExpression = function() {
                var expr;
                var startToken = this.lookahead;
                if (this.match("++") || this.match("--")) {
                  var node = this.startNode(startToken);
                  var token = this.nextToken();
                  expr = this.inheritCoverGrammar(this.parseUnaryExpression);
                  if (this.context.strict && expr.type === syntax_1.Syntax.Identifier && this.scanner.isRestrictedWord(expr.name)) {
                    this.tolerateError(messages_1.Messages.StrictLHSPrefix);
                  }
                  if (!this.context.isAssignmentTarget) {
                    this.tolerateError(messages_1.Messages.InvalidLHSInAssignment);
                  }
                  var prefix = true;
                  expr = this.finalize(node, new Node2.UpdateExpression(token.value, expr, prefix));
                  this.context.isAssignmentTarget = false;
                  this.context.isBindingElement = false;
                } else {
                  expr = this.inheritCoverGrammar(this.parseLeftHandSideExpressionAllowCall);
                  if (!this.hasLineTerminator && this.lookahead.type === 7) {
                    if (this.match("++") || this.match("--")) {
                      if (this.context.strict && expr.type === syntax_1.Syntax.Identifier && this.scanner.isRestrictedWord(expr.name)) {
                        this.tolerateError(messages_1.Messages.StrictLHSPostfix);
                      }
                      if (!this.context.isAssignmentTarget) {
                        this.tolerateError(messages_1.Messages.InvalidLHSInAssignment);
                      }
                      this.context.isAssignmentTarget = false;
                      this.context.isBindingElement = false;
                      var operator = this.nextToken().value;
                      var prefix = false;
                      expr = this.finalize(this.startNode(startToken), new Node2.UpdateExpression(operator, expr, prefix));
                    }
                  }
                }
                return expr;
              };
              Parser2.prototype.parseAwaitExpression = function() {
                var node = this.createNode();
                this.nextToken();
                var argument = this.parseUnaryExpression();
                return this.finalize(node, new Node2.AwaitExpression(argument));
              };
              Parser2.prototype.parseUnaryExpression = function() {
                var expr;
                if (this.match("+") || this.match("-") || this.match("~") || this.match("!") || this.matchKeyword("delete") || this.matchKeyword("void") || this.matchKeyword("typeof")) {
                  var node = this.startNode(this.lookahead);
                  var token = this.nextToken();
                  expr = this.inheritCoverGrammar(this.parseUnaryExpression);
                  expr = this.finalize(node, new Node2.UnaryExpression(token.value, expr));
                  if (this.context.strict && expr.operator === "delete" && expr.argument.type === syntax_1.Syntax.Identifier) {
                    this.tolerateError(messages_1.Messages.StrictDelete);
                  }
                  this.context.isAssignmentTarget = false;
                  this.context.isBindingElement = false;
                } else if (this.context.await && this.matchContextualKeyword("await")) {
                  expr = this.parseAwaitExpression();
                } else {
                  expr = this.parseUpdateExpression();
                }
                return expr;
              };
              Parser2.prototype.parseExponentiationExpression = function() {
                var startToken = this.lookahead;
                var expr = this.inheritCoverGrammar(this.parseUnaryExpression);
                if (expr.type !== syntax_1.Syntax.UnaryExpression && this.match("**")) {
                  this.nextToken();
                  this.context.isAssignmentTarget = false;
                  this.context.isBindingElement = false;
                  var left = expr;
                  var right = this.isolateCoverGrammar(this.parseExponentiationExpression);
                  expr = this.finalize(this.startNode(startToken), new Node2.BinaryExpression("**", left, right));
                }
                return expr;
              };
              Parser2.prototype.binaryPrecedence = function(token) {
                var op3 = token.value;
                var precedence;
                if (token.type === 7) {
                  precedence = this.operatorPrecedence[op3] || 0;
                } else if (token.type === 4) {
                  precedence = op3 === "instanceof" || this.context.allowIn && op3 === "in" ? 7 : 0;
                } else {
                  precedence = 0;
                }
                return precedence;
              };
              Parser2.prototype.parseBinaryExpression = function() {
                var startToken = this.lookahead;
                var expr = this.inheritCoverGrammar(this.parseExponentiationExpression);
                var token = this.lookahead;
                var prec = this.binaryPrecedence(token);
                if (prec > 0) {
                  this.nextToken();
                  this.context.isAssignmentTarget = false;
                  this.context.isBindingElement = false;
                  var markers = [startToken, this.lookahead];
                  var left = expr;
                  var right = this.isolateCoverGrammar(this.parseExponentiationExpression);
                  var stack = [left, token.value, right];
                  var precedences = [prec];
                  while (true) {
                    prec = this.binaryPrecedence(this.lookahead);
                    if (prec <= 0) {
                      break;
                    }
                    while (stack.length > 2 && prec <= precedences[precedences.length - 1]) {
                      right = stack.pop();
                      var operator = stack.pop();
                      precedences.pop();
                      left = stack.pop();
                      markers.pop();
                      var node = this.startNode(markers[markers.length - 1]);
                      stack.push(this.finalize(node, new Node2.BinaryExpression(operator, left, right)));
                    }
                    stack.push(this.nextToken().value);
                    precedences.push(prec);
                    markers.push(this.lookahead);
                    stack.push(this.isolateCoverGrammar(this.parseExponentiationExpression));
                  }
                  var i32 = stack.length - 1;
                  expr = stack[i32];
                  var lastMarker = markers.pop();
                  while (i32 > 1) {
                    var marker = markers.pop();
                    var lastLineStart = lastMarker && lastMarker.lineStart;
                    var node = this.startNode(marker, lastLineStart);
                    var operator = stack[i32 - 1];
                    expr = this.finalize(node, new Node2.BinaryExpression(operator, stack[i32 - 2], expr));
                    i32 -= 2;
                    lastMarker = marker;
                  }
                }
                return expr;
              };
              Parser2.prototype.parseConditionalExpression = function() {
                var startToken = this.lookahead;
                var expr = this.inheritCoverGrammar(this.parseBinaryExpression);
                if (this.match("?")) {
                  this.nextToken();
                  var previousAllowIn = this.context.allowIn;
                  this.context.allowIn = true;
                  var consequent = this.isolateCoverGrammar(this.parseAssignmentExpression);
                  this.context.allowIn = previousAllowIn;
                  this.expect(":");
                  var alternate = this.isolateCoverGrammar(this.parseAssignmentExpression);
                  expr = this.finalize(this.startNode(startToken), new Node2.ConditionalExpression(expr, consequent, alternate));
                  this.context.isAssignmentTarget = false;
                  this.context.isBindingElement = false;
                }
                return expr;
              };
              Parser2.prototype.checkPatternParam = function(options, param) {
                switch (param.type) {
                  case syntax_1.Syntax.Identifier:
                    this.validateParam(options, param, param.name);
                    break;
                  case syntax_1.Syntax.RestElement:
                    this.checkPatternParam(options, param.argument);
                    break;
                  case syntax_1.Syntax.AssignmentPattern:
                    this.checkPatternParam(options, param.left);
                    break;
                  case syntax_1.Syntax.ArrayPattern:
                    for (var i32 = 0; i32 < param.elements.length; i32++) {
                      if (param.elements[i32] !== null) {
                        this.checkPatternParam(options, param.elements[i32]);
                      }
                    }
                    break;
                  case syntax_1.Syntax.ObjectPattern:
                    for (var i32 = 0; i32 < param.properties.length; i32++) {
                      this.checkPatternParam(options, param.properties[i32].value);
                    }
                    break;
                  default:
                    break;
                }
                options.simple = options.simple && param instanceof Node2.Identifier;
              };
              Parser2.prototype.reinterpretAsCoverFormalsList = function(expr) {
                var params = [expr];
                var options;
                var asyncArrow = false;
                switch (expr.type) {
                  case syntax_1.Syntax.Identifier:
                    break;
                  case ArrowParameterPlaceHolder:
                    params = expr.params;
                    asyncArrow = expr.async;
                    break;
                  default:
                    return null;
                }
                options = {
                  simple: true,
                  paramSet: {}
                };
                for (var i32 = 0; i32 < params.length; ++i32) {
                  var param = params[i32];
                  if (param.type === syntax_1.Syntax.AssignmentPattern) {
                    if (param.right.type === syntax_1.Syntax.YieldExpression) {
                      if (param.right.argument) {
                        this.throwUnexpectedToken(this.lookahead);
                      }
                      param.right.type = syntax_1.Syntax.Identifier;
                      param.right.name = "yield";
                      delete param.right.argument;
                      delete param.right.delegate;
                    }
                  } else if (asyncArrow && param.type === syntax_1.Syntax.Identifier && param.name === "await") {
                    this.throwUnexpectedToken(this.lookahead);
                  }
                  this.checkPatternParam(options, param);
                  params[i32] = param;
                }
                if (this.context.strict || !this.context.allowYield) {
                  for (var i32 = 0; i32 < params.length; ++i32) {
                    var param = params[i32];
                    if (param.type === syntax_1.Syntax.YieldExpression) {
                      this.throwUnexpectedToken(this.lookahead);
                    }
                  }
                }
                if (options.message === messages_1.Messages.StrictParamDupe) {
                  var token = this.context.strict ? options.stricted : options.firstRestricted;
                  this.throwUnexpectedToken(token, options.message);
                }
                return {
                  simple: options.simple,
                  params,
                  stricted: options.stricted,
                  firstRestricted: options.firstRestricted,
                  message: options.message
                };
              };
              Parser2.prototype.parseAssignmentExpression = function() {
                var expr;
                if (!this.context.allowYield && this.matchKeyword("yield")) {
                  expr = this.parseYieldExpression();
                } else {
                  var startToken = this.lookahead;
                  var token = startToken;
                  expr = this.parseConditionalExpression();
                  if (token.type === 3 && token.lineNumber === this.lookahead.lineNumber && token.value === "async") {
                    if (this.lookahead.type === 3 || this.matchKeyword("yield")) {
                      var arg = this.parsePrimaryExpression();
                      this.reinterpretExpressionAsPattern(arg);
                      expr = {
                        type: ArrowParameterPlaceHolder,
                        params: [arg],
                        async: true
                      };
                    }
                  }
                  if (expr.type === ArrowParameterPlaceHolder || this.match("=>")) {
                    this.context.isAssignmentTarget = false;
                    this.context.isBindingElement = false;
                    var isAsync = expr.async;
                    var list3 = this.reinterpretAsCoverFormalsList(expr);
                    if (list3) {
                      if (this.hasLineTerminator) {
                        this.tolerateUnexpectedToken(this.lookahead);
                      }
                      this.context.firstCoverInitializedNameError = null;
                      var previousStrict = this.context.strict;
                      var previousAllowStrictDirective = this.context.allowStrictDirective;
                      this.context.allowStrictDirective = list3.simple;
                      var previousAllowYield = this.context.allowYield;
                      var previousAwait = this.context.await;
                      this.context.allowYield = true;
                      this.context.await = isAsync;
                      var node = this.startNode(startToken);
                      this.expect("=>");
                      var body = void 0;
                      if (this.match("{")) {
                        var previousAllowIn = this.context.allowIn;
                        this.context.allowIn = true;
                        body = this.parseFunctionSourceElements();
                        this.context.allowIn = previousAllowIn;
                      } else {
                        body = this.isolateCoverGrammar(this.parseAssignmentExpression);
                      }
                      var expression = body.type !== syntax_1.Syntax.BlockStatement;
                      if (this.context.strict && list3.firstRestricted) {
                        this.throwUnexpectedToken(list3.firstRestricted, list3.message);
                      }
                      if (this.context.strict && list3.stricted) {
                        this.tolerateUnexpectedToken(list3.stricted, list3.message);
                      }
                      expr = isAsync ? this.finalize(node, new Node2.AsyncArrowFunctionExpression(list3.params, body, expression)) : this.finalize(node, new Node2.ArrowFunctionExpression(list3.params, body, expression));
                      this.context.strict = previousStrict;
                      this.context.allowStrictDirective = previousAllowStrictDirective;
                      this.context.allowYield = previousAllowYield;
                      this.context.await = previousAwait;
                    }
                  } else {
                    if (this.matchAssign()) {
                      if (!this.context.isAssignmentTarget) {
                        this.tolerateError(messages_1.Messages.InvalidLHSInAssignment);
                      }
                      if (this.context.strict && expr.type === syntax_1.Syntax.Identifier) {
                        var id = expr;
                        if (this.scanner.isRestrictedWord(id.name)) {
                          this.tolerateUnexpectedToken(token, messages_1.Messages.StrictLHSAssignment);
                        }
                        if (this.scanner.isStrictModeReservedWord(id.name)) {
                          this.tolerateUnexpectedToken(token, messages_1.Messages.StrictReservedWord);
                        }
                      }
                      if (!this.match("=")) {
                        this.context.isAssignmentTarget = false;
                        this.context.isBindingElement = false;
                      } else {
                        this.reinterpretExpressionAsPattern(expr);
                      }
                      token = this.nextToken();
                      var operator = token.value;
                      var right = this.isolateCoverGrammar(this.parseAssignmentExpression);
                      expr = this.finalize(this.startNode(startToken), new Node2.AssignmentExpression(operator, expr, right));
                      this.context.firstCoverInitializedNameError = null;
                    }
                  }
                }
                return expr;
              };
              Parser2.prototype.parseExpression = function() {
                var startToken = this.lookahead;
                var expr = this.isolateCoverGrammar(this.parseAssignmentExpression);
                if (this.match(",")) {
                  var expressions = [];
                  expressions.push(expr);
                  while (this.lookahead.type !== 2) {
                    if (!this.match(",")) {
                      break;
                    }
                    this.nextToken();
                    expressions.push(this.isolateCoverGrammar(this.parseAssignmentExpression));
                  }
                  expr = this.finalize(this.startNode(startToken), new Node2.SequenceExpression(expressions));
                }
                return expr;
              };
              Parser2.prototype.parseStatementListItem = function() {
                var statement;
                this.context.isAssignmentTarget = true;
                this.context.isBindingElement = true;
                if (this.lookahead.type === 4) {
                  switch (this.lookahead.value) {
                    case "export":
                      if (!this.context.isModule) {
                        this.tolerateUnexpectedToken(this.lookahead, messages_1.Messages.IllegalExportDeclaration);
                      }
                      statement = this.parseExportDeclaration();
                      break;
                    case "import":
                      if (!this.context.isModule) {
                        this.tolerateUnexpectedToken(this.lookahead, messages_1.Messages.IllegalImportDeclaration);
                      }
                      statement = this.parseImportDeclaration();
                      break;
                    case "const":
                      statement = this.parseLexicalDeclaration({ inFor: false });
                      break;
                    case "function":
                      statement = this.parseFunctionDeclaration();
                      break;
                    case "class":
                      statement = this.parseClassDeclaration();
                      break;
                    case "let":
                      statement = this.isLexicalDeclaration() ? this.parseLexicalDeclaration({ inFor: false }) : this.parseStatement();
                      break;
                    default:
                      statement = this.parseStatement();
                      break;
                  }
                } else {
                  statement = this.parseStatement();
                }
                return statement;
              };
              Parser2.prototype.parseBlock = function() {
                var node = this.createNode();
                this.expect("{");
                var block = [];
                while (true) {
                  if (this.match("}")) {
                    break;
                  }
                  block.push(this.parseStatementListItem());
                }
                this.expect("}");
                return this.finalize(node, new Node2.BlockStatement(block));
              };
              Parser2.prototype.parseLexicalBinding = function(kind, options) {
                var node = this.createNode();
                var params = [];
                var id = this.parsePattern(params, kind);
                if (this.context.strict && id.type === syntax_1.Syntax.Identifier) {
                  if (this.scanner.isRestrictedWord(id.name)) {
                    this.tolerateError(messages_1.Messages.StrictVarName);
                  }
                }
                var init = null;
                if (kind === "const") {
                  if (!this.matchKeyword("in") && !this.matchContextualKeyword("of")) {
                    if (this.match("=")) {
                      this.nextToken();
                      init = this.isolateCoverGrammar(this.parseAssignmentExpression);
                    } else {
                      this.throwError(messages_1.Messages.DeclarationMissingInitializer, "const");
                    }
                  }
                } else if (!options.inFor && id.type !== syntax_1.Syntax.Identifier || this.match("=")) {
                  this.expect("=");
                  init = this.isolateCoverGrammar(this.parseAssignmentExpression);
                }
                return this.finalize(node, new Node2.VariableDeclarator(id, init));
              };
              Parser2.prototype.parseBindingList = function(kind, options) {
                var list3 = [this.parseLexicalBinding(kind, options)];
                while (this.match(",")) {
                  this.nextToken();
                  list3.push(this.parseLexicalBinding(kind, options));
                }
                return list3;
              };
              Parser2.prototype.isLexicalDeclaration = function() {
                var state13 = this.scanner.saveState();
                this.scanner.scanComments();
                var next = this.scanner.lex();
                this.scanner.restoreState(state13);
                return next.type === 3 || next.type === 7 && next.value === "[" || next.type === 7 && next.value === "{" || next.type === 4 && next.value === "let" || next.type === 4 && next.value === "yield";
              };
              Parser2.prototype.parseLexicalDeclaration = function(options) {
                var node = this.createNode();
                var kind = this.nextToken().value;
                assert_1.assert(kind === "let" || kind === "const", "Lexical declaration must be either let or const");
                var declarations = this.parseBindingList(kind, options);
                this.consumeSemicolon();
                return this.finalize(node, new Node2.VariableDeclaration(declarations, kind));
              };
              Parser2.prototype.parseBindingRestElement = function(params, kind) {
                var node = this.createNode();
                this.expect("...");
                var arg = this.parsePattern(params, kind);
                return this.finalize(node, new Node2.RestElement(arg));
              };
              Parser2.prototype.parseArrayPattern = function(params, kind) {
                var node = this.createNode();
                this.expect("[");
                var elements = [];
                while (!this.match("]")) {
                  if (this.match(",")) {
                    this.nextToken();
                    elements.push(null);
                  } else {
                    if (this.match("...")) {
                      elements.push(this.parseBindingRestElement(params, kind));
                      break;
                    } else {
                      elements.push(this.parsePatternWithDefault(params, kind));
                    }
                    if (!this.match("]")) {
                      this.expect(",");
                    }
                  }
                }
                this.expect("]");
                return this.finalize(node, new Node2.ArrayPattern(elements));
              };
              Parser2.prototype.parsePropertyPattern = function(params, kind) {
                var node = this.createNode();
                var computed = false;
                var shorthand = false;
                var method = false;
                var key;
                var value;
                if (this.lookahead.type === 3) {
                  var keyToken = this.lookahead;
                  key = this.parseVariableIdentifier();
                  var init = this.finalize(node, new Node2.Identifier(keyToken.value));
                  if (this.match("=")) {
                    params.push(keyToken);
                    shorthand = true;
                    this.nextToken();
                    var expr = this.parseAssignmentExpression();
                    value = this.finalize(this.startNode(keyToken), new Node2.AssignmentPattern(init, expr));
                  } else if (!this.match(":")) {
                    params.push(keyToken);
                    shorthand = true;
                    value = init;
                  } else {
                    this.expect(":");
                    value = this.parsePatternWithDefault(params, kind);
                  }
                } else {
                  computed = this.match("[");
                  key = this.parseObjectPropertyKey();
                  this.expect(":");
                  value = this.parsePatternWithDefault(params, kind);
                }
                return this.finalize(node, new Node2.Property("init", key, computed, value, method, shorthand));
              };
              Parser2.prototype.parseObjectPattern = function(params, kind) {
                var node = this.createNode();
                var properties = [];
                this.expect("{");
                while (!this.match("}")) {
                  properties.push(this.parsePropertyPattern(params, kind));
                  if (!this.match("}")) {
                    this.expect(",");
                  }
                }
                this.expect("}");
                return this.finalize(node, new Node2.ObjectPattern(properties));
              };
              Parser2.prototype.parsePattern = function(params, kind) {
                var pattern;
                if (this.match("[")) {
                  pattern = this.parseArrayPattern(params, kind);
                } else if (this.match("{")) {
                  pattern = this.parseObjectPattern(params, kind);
                } else {
                  if (this.matchKeyword("let") && (kind === "const" || kind === "let")) {
                    this.tolerateUnexpectedToken(this.lookahead, messages_1.Messages.LetInLexicalBinding);
                  }
                  params.push(this.lookahead);
                  pattern = this.parseVariableIdentifier(kind);
                }
                return pattern;
              };
              Parser2.prototype.parsePatternWithDefault = function(params, kind) {
                var startToken = this.lookahead;
                var pattern = this.parsePattern(params, kind);
                if (this.match("=")) {
                  this.nextToken();
                  var previousAllowYield = this.context.allowYield;
                  this.context.allowYield = true;
                  var right = this.isolateCoverGrammar(this.parseAssignmentExpression);
                  this.context.allowYield = previousAllowYield;
                  pattern = this.finalize(this.startNode(startToken), new Node2.AssignmentPattern(pattern, right));
                }
                return pattern;
              };
              Parser2.prototype.parseVariableIdentifier = function(kind) {
                var node = this.createNode();
                var token = this.nextToken();
                if (token.type === 4 && token.value === "yield") {
                  if (this.context.strict) {
                    this.tolerateUnexpectedToken(token, messages_1.Messages.StrictReservedWord);
                  } else if (!this.context.allowYield) {
                    this.throwUnexpectedToken(token);
                  }
                } else if (token.type !== 3) {
                  if (this.context.strict && token.type === 4 && this.scanner.isStrictModeReservedWord(token.value)) {
                    this.tolerateUnexpectedToken(token, messages_1.Messages.StrictReservedWord);
                  } else {
                    if (this.context.strict || token.value !== "let" || kind !== "var") {
                      this.throwUnexpectedToken(token);
                    }
                  }
                } else if ((this.context.isModule || this.context.await) && token.type === 3 && token.value === "await") {
                  this.tolerateUnexpectedToken(token);
                }
                return this.finalize(node, new Node2.Identifier(token.value));
              };
              Parser2.prototype.parseVariableDeclaration = function(options) {
                var node = this.createNode();
                var params = [];
                var id = this.parsePattern(params, "var");
                if (this.context.strict && id.type === syntax_1.Syntax.Identifier) {
                  if (this.scanner.isRestrictedWord(id.name)) {
                    this.tolerateError(messages_1.Messages.StrictVarName);
                  }
                }
                var init = null;
                if (this.match("=")) {
                  this.nextToken();
                  init = this.isolateCoverGrammar(this.parseAssignmentExpression);
                } else if (id.type !== syntax_1.Syntax.Identifier && !options.inFor) {
                  this.expect("=");
                }
                return this.finalize(node, new Node2.VariableDeclarator(id, init));
              };
              Parser2.prototype.parseVariableDeclarationList = function(options) {
                var opt = { inFor: options.inFor };
                var list3 = [];
                list3.push(this.parseVariableDeclaration(opt));
                while (this.match(",")) {
                  this.nextToken();
                  list3.push(this.parseVariableDeclaration(opt));
                }
                return list3;
              };
              Parser2.prototype.parseVariableStatement = function() {
                var node = this.createNode();
                this.expectKeyword("var");
                var declarations = this.parseVariableDeclarationList({ inFor: false });
                this.consumeSemicolon();
                return this.finalize(node, new Node2.VariableDeclaration(declarations, "var"));
              };
              Parser2.prototype.parseEmptyStatement = function() {
                var node = this.createNode();
                this.expect(";");
                return this.finalize(node, new Node2.EmptyStatement());
              };
              Parser2.prototype.parseExpressionStatement = function() {
                var node = this.createNode();
                var expr = this.parseExpression();
                this.consumeSemicolon();
                return this.finalize(node, new Node2.ExpressionStatement(expr));
              };
              Parser2.prototype.parseIfClause = function() {
                if (this.context.strict && this.matchKeyword("function")) {
                  this.tolerateError(messages_1.Messages.StrictFunction);
                }
                return this.parseStatement();
              };
              Parser2.prototype.parseIfStatement = function() {
                var node = this.createNode();
                var consequent;
                var alternate = null;
                this.expectKeyword("if");
                this.expect("(");
                var test = this.parseExpression();
                if (!this.match(")") && this.config.tolerant) {
                  this.tolerateUnexpectedToken(this.nextToken());
                  consequent = this.finalize(this.createNode(), new Node2.EmptyStatement());
                } else {
                  this.expect(")");
                  consequent = this.parseIfClause();
                  if (this.matchKeyword("else")) {
                    this.nextToken();
                    alternate = this.parseIfClause();
                  }
                }
                return this.finalize(node, new Node2.IfStatement(test, consequent, alternate));
              };
              Parser2.prototype.parseDoWhileStatement = function() {
                var node = this.createNode();
                this.expectKeyword("do");
                var previousInIteration = this.context.inIteration;
                this.context.inIteration = true;
                var body = this.parseStatement();
                this.context.inIteration = previousInIteration;
                this.expectKeyword("while");
                this.expect("(");
                var test = this.parseExpression();
                if (!this.match(")") && this.config.tolerant) {
                  this.tolerateUnexpectedToken(this.nextToken());
                } else {
                  this.expect(")");
                  if (this.match(";")) {
                    this.nextToken();
                  }
                }
                return this.finalize(node, new Node2.DoWhileStatement(body, test));
              };
              Parser2.prototype.parseWhileStatement = function() {
                var node = this.createNode();
                var body;
                this.expectKeyword("while");
                this.expect("(");
                var test = this.parseExpression();
                if (!this.match(")") && this.config.tolerant) {
                  this.tolerateUnexpectedToken(this.nextToken());
                  body = this.finalize(this.createNode(), new Node2.EmptyStatement());
                } else {
                  this.expect(")");
                  var previousInIteration = this.context.inIteration;
                  this.context.inIteration = true;
                  body = this.parseStatement();
                  this.context.inIteration = previousInIteration;
                }
                return this.finalize(node, new Node2.WhileStatement(test, body));
              };
              Parser2.prototype.parseForStatement = function() {
                var init = null;
                var test = null;
                var update = null;
                var forIn = true;
                var left, right;
                var node = this.createNode();
                this.expectKeyword("for");
                this.expect("(");
                if (this.match(";")) {
                  this.nextToken();
                } else {
                  if (this.matchKeyword("var")) {
                    init = this.createNode();
                    this.nextToken();
                    var previousAllowIn = this.context.allowIn;
                    this.context.allowIn = false;
                    var declarations = this.parseVariableDeclarationList({ inFor: true });
                    this.context.allowIn = previousAllowIn;
                    if (declarations.length === 1 && this.matchKeyword("in")) {
                      var decl = declarations[0];
                      if (decl.init && (decl.id.type === syntax_1.Syntax.ArrayPattern || decl.id.type === syntax_1.Syntax.ObjectPattern || this.context.strict)) {
                        this.tolerateError(messages_1.Messages.ForInOfLoopInitializer, "for-in");
                      }
                      init = this.finalize(init, new Node2.VariableDeclaration(declarations, "var"));
                      this.nextToken();
                      left = init;
                      right = this.parseExpression();
                      init = null;
                    } else if (declarations.length === 1 && declarations[0].init === null && this.matchContextualKeyword("of")) {
                      init = this.finalize(init, new Node2.VariableDeclaration(declarations, "var"));
                      this.nextToken();
                      left = init;
                      right = this.parseAssignmentExpression();
                      init = null;
                      forIn = false;
                    } else {
                      init = this.finalize(init, new Node2.VariableDeclaration(declarations, "var"));
                      this.expect(";");
                    }
                  } else if (this.matchKeyword("const") || this.matchKeyword("let")) {
                    init = this.createNode();
                    var kind = this.nextToken().value;
                    if (!this.context.strict && this.lookahead.value === "in") {
                      init = this.finalize(init, new Node2.Identifier(kind));
                      this.nextToken();
                      left = init;
                      right = this.parseExpression();
                      init = null;
                    } else {
                      var previousAllowIn = this.context.allowIn;
                      this.context.allowIn = false;
                      var declarations = this.parseBindingList(kind, { inFor: true });
                      this.context.allowIn = previousAllowIn;
                      if (declarations.length === 1 && declarations[0].init === null && this.matchKeyword("in")) {
                        init = this.finalize(init, new Node2.VariableDeclaration(declarations, kind));
                        this.nextToken();
                        left = init;
                        right = this.parseExpression();
                        init = null;
                      } else if (declarations.length === 1 && declarations[0].init === null && this.matchContextualKeyword("of")) {
                        init = this.finalize(init, new Node2.VariableDeclaration(declarations, kind));
                        this.nextToken();
                        left = init;
                        right = this.parseAssignmentExpression();
                        init = null;
                        forIn = false;
                      } else {
                        this.consumeSemicolon();
                        init = this.finalize(init, new Node2.VariableDeclaration(declarations, kind));
                      }
                    }
                  } else {
                    var initStartToken = this.lookahead;
                    var previousAllowIn = this.context.allowIn;
                    this.context.allowIn = false;
                    init = this.inheritCoverGrammar(this.parseAssignmentExpression);
                    this.context.allowIn = previousAllowIn;
                    if (this.matchKeyword("in")) {
                      if (!this.context.isAssignmentTarget || init.type === syntax_1.Syntax.AssignmentExpression) {
                        this.tolerateError(messages_1.Messages.InvalidLHSInForIn);
                      }
                      this.nextToken();
                      this.reinterpretExpressionAsPattern(init);
                      left = init;
                      right = this.parseExpression();
                      init = null;
                    } else if (this.matchContextualKeyword("of")) {
                      if (!this.context.isAssignmentTarget || init.type === syntax_1.Syntax.AssignmentExpression) {
                        this.tolerateError(messages_1.Messages.InvalidLHSInForLoop);
                      }
                      this.nextToken();
                      this.reinterpretExpressionAsPattern(init);
                      left = init;
                      right = this.parseAssignmentExpression();
                      init = null;
                      forIn = false;
                    } else {
                      if (this.match(",")) {
                        var initSeq = [init];
                        while (this.match(",")) {
                          this.nextToken();
                          initSeq.push(this.isolateCoverGrammar(this.parseAssignmentExpression));
                        }
                        init = this.finalize(this.startNode(initStartToken), new Node2.SequenceExpression(initSeq));
                      }
                      this.expect(";");
                    }
                  }
                }
                if (typeof left === "undefined") {
                  if (!this.match(";")) {
                    test = this.parseExpression();
                  }
                  this.expect(";");
                  if (!this.match(")")) {
                    update = this.parseExpression();
                  }
                }
                var body;
                if (!this.match(")") && this.config.tolerant) {
                  this.tolerateUnexpectedToken(this.nextToken());
                  body = this.finalize(this.createNode(), new Node2.EmptyStatement());
                } else {
                  this.expect(")");
                  var previousInIteration = this.context.inIteration;
                  this.context.inIteration = true;
                  body = this.isolateCoverGrammar(this.parseStatement);
                  this.context.inIteration = previousInIteration;
                }
                return typeof left === "undefined" ? this.finalize(node, new Node2.ForStatement(init, test, update, body)) : forIn ? this.finalize(node, new Node2.ForInStatement(left, right, body)) : this.finalize(node, new Node2.ForOfStatement(left, right, body));
              };
              Parser2.prototype.parseContinueStatement = function() {
                var node = this.createNode();
                this.expectKeyword("continue");
                var label = null;
                if (this.lookahead.type === 3 && !this.hasLineTerminator) {
                  var id = this.parseVariableIdentifier();
                  label = id;
                  var key = "$" + id.name;
                  if (!Object.prototype.hasOwnProperty.call(this.context.labelSet, key)) {
                    this.throwError(messages_1.Messages.UnknownLabel, id.name);
                  }
                }
                this.consumeSemicolon();
                if (label === null && !this.context.inIteration) {
                  this.throwError(messages_1.Messages.IllegalContinue);
                }
                return this.finalize(node, new Node2.ContinueStatement(label));
              };
              Parser2.prototype.parseBreakStatement = function() {
                var node = this.createNode();
                this.expectKeyword("break");
                var label = null;
                if (this.lookahead.type === 3 && !this.hasLineTerminator) {
                  var id = this.parseVariableIdentifier();
                  var key = "$" + id.name;
                  if (!Object.prototype.hasOwnProperty.call(this.context.labelSet, key)) {
                    this.throwError(messages_1.Messages.UnknownLabel, id.name);
                  }
                  label = id;
                }
                this.consumeSemicolon();
                if (label === null && !this.context.inIteration && !this.context.inSwitch) {
                  this.throwError(messages_1.Messages.IllegalBreak);
                }
                return this.finalize(node, new Node2.BreakStatement(label));
              };
              Parser2.prototype.parseReturnStatement = function() {
                if (!this.context.inFunctionBody) {
                  this.tolerateError(messages_1.Messages.IllegalReturn);
                }
                var node = this.createNode();
                this.expectKeyword("return");
                var hasArgument = !this.match(";") && !this.match("}") && !this.hasLineTerminator && this.lookahead.type !== 2 || this.lookahead.type === 8 || this.lookahead.type === 10;
                var argument = hasArgument ? this.parseExpression() : null;
                this.consumeSemicolon();
                return this.finalize(node, new Node2.ReturnStatement(argument));
              };
              Parser2.prototype.parseWithStatement = function() {
                if (this.context.strict) {
                  this.tolerateError(messages_1.Messages.StrictModeWith);
                }
                var node = this.createNode();
                var body;
                this.expectKeyword("with");
                this.expect("(");
                var object = this.parseExpression();
                if (!this.match(")") && this.config.tolerant) {
                  this.tolerateUnexpectedToken(this.nextToken());
                  body = this.finalize(this.createNode(), new Node2.EmptyStatement());
                } else {
                  this.expect(")");
                  body = this.parseStatement();
                }
                return this.finalize(node, new Node2.WithStatement(object, body));
              };
              Parser2.prototype.parseSwitchCase = function() {
                var node = this.createNode();
                var test;
                if (this.matchKeyword("default")) {
                  this.nextToken();
                  test = null;
                } else {
                  this.expectKeyword("case");
                  test = this.parseExpression();
                }
                this.expect(":");
                var consequent = [];
                while (true) {
                  if (this.match("}") || this.matchKeyword("default") || this.matchKeyword("case")) {
                    break;
                  }
                  consequent.push(this.parseStatementListItem());
                }
                return this.finalize(node, new Node2.SwitchCase(test, consequent));
              };
              Parser2.prototype.parseSwitchStatement = function() {
                var node = this.createNode();
                this.expectKeyword("switch");
                this.expect("(");
                var discriminant = this.parseExpression();
                this.expect(")");
                var previousInSwitch = this.context.inSwitch;
                this.context.inSwitch = true;
                var cases = [];
                var defaultFound = false;
                this.expect("{");
                while (true) {
                  if (this.match("}")) {
                    break;
                  }
                  var clause = this.parseSwitchCase();
                  if (clause.test === null) {
                    if (defaultFound) {
                      this.throwError(messages_1.Messages.MultipleDefaultsInSwitch);
                    }
                    defaultFound = true;
                  }
                  cases.push(clause);
                }
                this.expect("}");
                this.context.inSwitch = previousInSwitch;
                return this.finalize(node, new Node2.SwitchStatement(discriminant, cases));
              };
              Parser2.prototype.parseLabelledStatement = function() {
                var node = this.createNode();
                var expr = this.parseExpression();
                var statement;
                if (expr.type === syntax_1.Syntax.Identifier && this.match(":")) {
                  this.nextToken();
                  var id = expr;
                  var key = "$" + id.name;
                  if (Object.prototype.hasOwnProperty.call(this.context.labelSet, key)) {
                    this.throwError(messages_1.Messages.Redeclaration, "Label", id.name);
                  }
                  this.context.labelSet[key] = true;
                  var body = void 0;
                  if (this.matchKeyword("class")) {
                    this.tolerateUnexpectedToken(this.lookahead);
                    body = this.parseClassDeclaration();
                  } else if (this.matchKeyword("function")) {
                    var token = this.lookahead;
                    var declaration = this.parseFunctionDeclaration();
                    if (this.context.strict) {
                      this.tolerateUnexpectedToken(token, messages_1.Messages.StrictFunction);
                    } else if (declaration.generator) {
                      this.tolerateUnexpectedToken(token, messages_1.Messages.GeneratorInLegacyContext);
                    }
                    body = declaration;
                  } else {
                    body = this.parseStatement();
                  }
                  delete this.context.labelSet[key];
                  statement = new Node2.LabeledStatement(id, body);
                } else {
                  this.consumeSemicolon();
                  statement = new Node2.ExpressionStatement(expr);
                }
                return this.finalize(node, statement);
              };
              Parser2.prototype.parseThrowStatement = function() {
                var node = this.createNode();
                this.expectKeyword("throw");
                if (this.hasLineTerminator) {
                  this.throwError(messages_1.Messages.NewlineAfterThrow);
                }
                var argument = this.parseExpression();
                this.consumeSemicolon();
                return this.finalize(node, new Node2.ThrowStatement(argument));
              };
              Parser2.prototype.parseCatchClause = function() {
                var node = this.createNode();
                this.expectKeyword("catch");
                this.expect("(");
                if (this.match(")")) {
                  this.throwUnexpectedToken(this.lookahead);
                }
                var params = [];
                var param = this.parsePattern(params);
                var paramMap = {};
                for (var i32 = 0; i32 < params.length; i32++) {
                  var key = "$" + params[i32].value;
                  if (Object.prototype.hasOwnProperty.call(paramMap, key)) {
                    this.tolerateError(messages_1.Messages.DuplicateBinding, params[i32].value);
                  }
                  paramMap[key] = true;
                }
                if (this.context.strict && param.type === syntax_1.Syntax.Identifier) {
                  if (this.scanner.isRestrictedWord(param.name)) {
                    this.tolerateError(messages_1.Messages.StrictCatchVariable);
                  }
                }
                this.expect(")");
                var body = this.parseBlock();
                return this.finalize(node, new Node2.CatchClause(param, body));
              };
              Parser2.prototype.parseFinallyClause = function() {
                this.expectKeyword("finally");
                return this.parseBlock();
              };
              Parser2.prototype.parseTryStatement = function() {
                var node = this.createNode();
                this.expectKeyword("try");
                var block = this.parseBlock();
                var handler = this.matchKeyword("catch") ? this.parseCatchClause() : null;
                var finalizer = this.matchKeyword("finally") ? this.parseFinallyClause() : null;
                if (!handler && !finalizer) {
                  this.throwError(messages_1.Messages.NoCatchOrFinally);
                }
                return this.finalize(node, new Node2.TryStatement(block, handler, finalizer));
              };
              Parser2.prototype.parseDebuggerStatement = function() {
                var node = this.createNode();
                this.expectKeyword("debugger");
                this.consumeSemicolon();
                return this.finalize(node, new Node2.DebuggerStatement());
              };
              Parser2.prototype.parseStatement = function() {
                var statement;
                switch (this.lookahead.type) {
                  case 1:
                  case 5:
                  case 6:
                  case 8:
                  case 10:
                  case 9:
                    statement = this.parseExpressionStatement();
                    break;
                  case 7:
                    var value = this.lookahead.value;
                    if (value === "{") {
                      statement = this.parseBlock();
                    } else if (value === "(") {
                      statement = this.parseExpressionStatement();
                    } else if (value === ";") {
                      statement = this.parseEmptyStatement();
                    } else {
                      statement = this.parseExpressionStatement();
                    }
                    break;
                  case 3:
                    statement = this.matchAsyncFunction() ? this.parseFunctionDeclaration() : this.parseLabelledStatement();
                    break;
                  case 4:
                    switch (this.lookahead.value) {
                      case "break":
                        statement = this.parseBreakStatement();
                        break;
                      case "continue":
                        statement = this.parseContinueStatement();
                        break;
                      case "debugger":
                        statement = this.parseDebuggerStatement();
                        break;
                      case "do":
                        statement = this.parseDoWhileStatement();
                        break;
                      case "for":
                        statement = this.parseForStatement();
                        break;
                      case "function":
                        statement = this.parseFunctionDeclaration();
                        break;
                      case "if":
                        statement = this.parseIfStatement();
                        break;
                      case "return":
                        statement = this.parseReturnStatement();
                        break;
                      case "switch":
                        statement = this.parseSwitchStatement();
                        break;
                      case "throw":
                        statement = this.parseThrowStatement();
                        break;
                      case "try":
                        statement = this.parseTryStatement();
                        break;
                      case "var":
                        statement = this.parseVariableStatement();
                        break;
                      case "while":
                        statement = this.parseWhileStatement();
                        break;
                      case "with":
                        statement = this.parseWithStatement();
                        break;
                      default:
                        statement = this.parseExpressionStatement();
                        break;
                    }
                    break;
                  default:
                    statement = this.throwUnexpectedToken(this.lookahead);
                }
                return statement;
              };
              Parser2.prototype.parseFunctionSourceElements = function() {
                var node = this.createNode();
                this.expect("{");
                var body = this.parseDirectivePrologues();
                var previousLabelSet = this.context.labelSet;
                var previousInIteration = this.context.inIteration;
                var previousInSwitch = this.context.inSwitch;
                var previousInFunctionBody = this.context.inFunctionBody;
                this.context.labelSet = {};
                this.context.inIteration = false;
                this.context.inSwitch = false;
                this.context.inFunctionBody = true;
                while (this.lookahead.type !== 2) {
                  if (this.match("}")) {
                    break;
                  }
                  body.push(this.parseStatementListItem());
                }
                this.expect("}");
                this.context.labelSet = previousLabelSet;
                this.context.inIteration = previousInIteration;
                this.context.inSwitch = previousInSwitch;
                this.context.inFunctionBody = previousInFunctionBody;
                return this.finalize(node, new Node2.BlockStatement(body));
              };
              Parser2.prototype.validateParam = function(options, param, name) {
                var key = "$" + name;
                if (this.context.strict) {
                  if (this.scanner.isRestrictedWord(name)) {
                    options.stricted = param;
                    options.message = messages_1.Messages.StrictParamName;
                  }
                  if (Object.prototype.hasOwnProperty.call(options.paramSet, key)) {
                    options.stricted = param;
                    options.message = messages_1.Messages.StrictParamDupe;
                  }
                } else if (!options.firstRestricted) {
                  if (this.scanner.isRestrictedWord(name)) {
                    options.firstRestricted = param;
                    options.message = messages_1.Messages.StrictParamName;
                  } else if (this.scanner.isStrictModeReservedWord(name)) {
                    options.firstRestricted = param;
                    options.message = messages_1.Messages.StrictReservedWord;
                  } else if (Object.prototype.hasOwnProperty.call(options.paramSet, key)) {
                    options.stricted = param;
                    options.message = messages_1.Messages.StrictParamDupe;
                  }
                }
                if (typeof Object.defineProperty === "function") {
                  Object.defineProperty(options.paramSet, key, { value: true, enumerable: true, writable: true, configurable: true });
                } else {
                  options.paramSet[key] = true;
                }
              };
              Parser2.prototype.parseRestElement = function(params) {
                var node = this.createNode();
                this.expect("...");
                var arg = this.parsePattern(params);
                if (this.match("=")) {
                  this.throwError(messages_1.Messages.DefaultRestParameter);
                }
                if (!this.match(")")) {
                  this.throwError(messages_1.Messages.ParameterAfterRestParameter);
                }
                return this.finalize(node, new Node2.RestElement(arg));
              };
              Parser2.prototype.parseFormalParameter = function(options) {
                var params = [];
                var param = this.match("...") ? this.parseRestElement(params) : this.parsePatternWithDefault(params);
                for (var i32 = 0; i32 < params.length; i32++) {
                  this.validateParam(options, params[i32], params[i32].value);
                }
                options.simple = options.simple && param instanceof Node2.Identifier;
                options.params.push(param);
              };
              Parser2.prototype.parseFormalParameters = function(firstRestricted) {
                var options;
                options = {
                  simple: true,
                  params: [],
                  firstRestricted
                };
                this.expect("(");
                if (!this.match(")")) {
                  options.paramSet = {};
                  while (this.lookahead.type !== 2) {
                    this.parseFormalParameter(options);
                    if (this.match(")")) {
                      break;
                    }
                    this.expect(",");
                    if (this.match(")")) {
                      break;
                    }
                  }
                }
                this.expect(")");
                return {
                  simple: options.simple,
                  params: options.params,
                  stricted: options.stricted,
                  firstRestricted: options.firstRestricted,
                  message: options.message
                };
              };
              Parser2.prototype.matchAsyncFunction = function() {
                var match = this.matchContextualKeyword("async");
                if (match) {
                  var state13 = this.scanner.saveState();
                  this.scanner.scanComments();
                  var next = this.scanner.lex();
                  this.scanner.restoreState(state13);
                  match = state13.lineNumber === next.lineNumber && next.type === 4 && next.value === "function";
                }
                return match;
              };
              Parser2.prototype.parseFunctionDeclaration = function(identifierIsOptional) {
                var node = this.createNode();
                var isAsync = this.matchContextualKeyword("async");
                if (isAsync) {
                  this.nextToken();
                }
                this.expectKeyword("function");
                var isGenerator = isAsync ? false : this.match("*");
                if (isGenerator) {
                  this.nextToken();
                }
                var message2;
                var id = null;
                var firstRestricted = null;
                if (!identifierIsOptional || !this.match("(")) {
                  var token = this.lookahead;
                  id = this.parseVariableIdentifier();
                  if (this.context.strict) {
                    if (this.scanner.isRestrictedWord(token.value)) {
                      this.tolerateUnexpectedToken(token, messages_1.Messages.StrictFunctionName);
                    }
                  } else {
                    if (this.scanner.isRestrictedWord(token.value)) {
                      firstRestricted = token;
                      message2 = messages_1.Messages.StrictFunctionName;
                    } else if (this.scanner.isStrictModeReservedWord(token.value)) {
                      firstRestricted = token;
                      message2 = messages_1.Messages.StrictReservedWord;
                    }
                  }
                }
                var previousAllowAwait = this.context.await;
                var previousAllowYield = this.context.allowYield;
                this.context.await = isAsync;
                this.context.allowYield = !isGenerator;
                var formalParameters = this.parseFormalParameters(firstRestricted);
                var params = formalParameters.params;
                var stricted = formalParameters.stricted;
                firstRestricted = formalParameters.firstRestricted;
                if (formalParameters.message) {
                  message2 = formalParameters.message;
                }
                var previousStrict = this.context.strict;
                var previousAllowStrictDirective = this.context.allowStrictDirective;
                this.context.allowStrictDirective = formalParameters.simple;
                var body = this.parseFunctionSourceElements();
                if (this.context.strict && firstRestricted) {
                  this.throwUnexpectedToken(firstRestricted, message2);
                }
                if (this.context.strict && stricted) {
                  this.tolerateUnexpectedToken(stricted, message2);
                }
                this.context.strict = previousStrict;
                this.context.allowStrictDirective = previousAllowStrictDirective;
                this.context.await = previousAllowAwait;
                this.context.allowYield = previousAllowYield;
                return isAsync ? this.finalize(node, new Node2.AsyncFunctionDeclaration(id, params, body)) : this.finalize(node, new Node2.FunctionDeclaration(id, params, body, isGenerator));
              };
              Parser2.prototype.parseFunctionExpression = function() {
                var node = this.createNode();
                var isAsync = this.matchContextualKeyword("async");
                if (isAsync) {
                  this.nextToken();
                }
                this.expectKeyword("function");
                var isGenerator = isAsync ? false : this.match("*");
                if (isGenerator) {
                  this.nextToken();
                }
                var message2;
                var id = null;
                var firstRestricted;
                var previousAllowAwait = this.context.await;
                var previousAllowYield = this.context.allowYield;
                this.context.await = isAsync;
                this.context.allowYield = !isGenerator;
                if (!this.match("(")) {
                  var token = this.lookahead;
                  id = !this.context.strict && !isGenerator && this.matchKeyword("yield") ? this.parseIdentifierName() : this.parseVariableIdentifier();
                  if (this.context.strict) {
                    if (this.scanner.isRestrictedWord(token.value)) {
                      this.tolerateUnexpectedToken(token, messages_1.Messages.StrictFunctionName);
                    }
                  } else {
                    if (this.scanner.isRestrictedWord(token.value)) {
                      firstRestricted = token;
                      message2 = messages_1.Messages.StrictFunctionName;
                    } else if (this.scanner.isStrictModeReservedWord(token.value)) {
                      firstRestricted = token;
                      message2 = messages_1.Messages.StrictReservedWord;
                    }
                  }
                }
                var formalParameters = this.parseFormalParameters(firstRestricted);
                var params = formalParameters.params;
                var stricted = formalParameters.stricted;
                firstRestricted = formalParameters.firstRestricted;
                if (formalParameters.message) {
                  message2 = formalParameters.message;
                }
                var previousStrict = this.context.strict;
                var previousAllowStrictDirective = this.context.allowStrictDirective;
                this.context.allowStrictDirective = formalParameters.simple;
                var body = this.parseFunctionSourceElements();
                if (this.context.strict && firstRestricted) {
                  this.throwUnexpectedToken(firstRestricted, message2);
                }
                if (this.context.strict && stricted) {
                  this.tolerateUnexpectedToken(stricted, message2);
                }
                this.context.strict = previousStrict;
                this.context.allowStrictDirective = previousAllowStrictDirective;
                this.context.await = previousAllowAwait;
                this.context.allowYield = previousAllowYield;
                return isAsync ? this.finalize(node, new Node2.AsyncFunctionExpression(id, params, body)) : this.finalize(node, new Node2.FunctionExpression(id, params, body, isGenerator));
              };
              Parser2.prototype.parseDirective = function() {
                var token = this.lookahead;
                var node = this.createNode();
                var expr = this.parseExpression();
                var directive = expr.type === syntax_1.Syntax.Literal ? this.getTokenRaw(token).slice(1, -1) : null;
                this.consumeSemicolon();
                return this.finalize(node, directive ? new Node2.Directive(expr, directive) : new Node2.ExpressionStatement(expr));
              };
              Parser2.prototype.parseDirectivePrologues = function() {
                var firstRestricted = null;
                var body = [];
                while (true) {
                  var token = this.lookahead;
                  if (token.type !== 8) {
                    break;
                  }
                  var statement = this.parseDirective();
                  body.push(statement);
                  var directive = statement.directive;
                  if (typeof directive !== "string") {
                    break;
                  }
                  if (directive === "use strict") {
                    this.context.strict = true;
                    if (firstRestricted) {
                      this.tolerateUnexpectedToken(firstRestricted, messages_1.Messages.StrictOctalLiteral);
                    }
                    if (!this.context.allowStrictDirective) {
                      this.tolerateUnexpectedToken(token, messages_1.Messages.IllegalLanguageModeDirective);
                    }
                  } else {
                    if (!firstRestricted && token.octal) {
                      firstRestricted = token;
                    }
                  }
                }
                return body;
              };
              Parser2.prototype.qualifiedPropertyName = function(token) {
                switch (token.type) {
                  case 3:
                  case 8:
                  case 1:
                  case 5:
                  case 6:
                  case 4:
                    return true;
                  case 7:
                    return token.value === "[";
                  default:
                    break;
                }
                return false;
              };
              Parser2.prototype.parseGetterMethod = function() {
                var node = this.createNode();
                var isGenerator = false;
                var previousAllowYield = this.context.allowYield;
                this.context.allowYield = !isGenerator;
                var formalParameters = this.parseFormalParameters();
                if (formalParameters.params.length > 0) {
                  this.tolerateError(messages_1.Messages.BadGetterArity);
                }
                var method = this.parsePropertyMethod(formalParameters);
                this.context.allowYield = previousAllowYield;
                return this.finalize(node, new Node2.FunctionExpression(null, formalParameters.params, method, isGenerator));
              };
              Parser2.prototype.parseSetterMethod = function() {
                var node = this.createNode();
                var isGenerator = false;
                var previousAllowYield = this.context.allowYield;
                this.context.allowYield = !isGenerator;
                var formalParameters = this.parseFormalParameters();
                if (formalParameters.params.length !== 1) {
                  this.tolerateError(messages_1.Messages.BadSetterArity);
                } else if (formalParameters.params[0] instanceof Node2.RestElement) {
                  this.tolerateError(messages_1.Messages.BadSetterRestParameter);
                }
                var method = this.parsePropertyMethod(formalParameters);
                this.context.allowYield = previousAllowYield;
                return this.finalize(node, new Node2.FunctionExpression(null, formalParameters.params, method, isGenerator));
              };
              Parser2.prototype.parseGeneratorMethod = function() {
                var node = this.createNode();
                var isGenerator = true;
                var previousAllowYield = this.context.allowYield;
                this.context.allowYield = true;
                var params = this.parseFormalParameters();
                this.context.allowYield = false;
                var method = this.parsePropertyMethod(params);
                this.context.allowYield = previousAllowYield;
                return this.finalize(node, new Node2.FunctionExpression(null, params.params, method, isGenerator));
              };
              Parser2.prototype.isStartOfExpression = function() {
                var start = true;
                var value = this.lookahead.value;
                switch (this.lookahead.type) {
                  case 7:
                    start = value === "[" || value === "(" || value === "{" || value === "+" || value === "-" || value === "!" || value === "~" || value === "++" || value === "--" || value === "/" || value === "/=";
                    break;
                  case 4:
                    start = value === "class" || value === "delete" || value === "function" || value === "let" || value === "new" || value === "super" || value === "this" || value === "typeof" || value === "void" || value === "yield";
                    break;
                  default:
                    break;
                }
                return start;
              };
              Parser2.prototype.parseYieldExpression = function() {
                var node = this.createNode();
                this.expectKeyword("yield");
                var argument = null;
                var delegate = false;
                if (!this.hasLineTerminator) {
                  var previousAllowYield = this.context.allowYield;
                  this.context.allowYield = false;
                  delegate = this.match("*");
                  if (delegate) {
                    this.nextToken();
                    argument = this.parseAssignmentExpression();
                  } else if (this.isStartOfExpression()) {
                    argument = this.parseAssignmentExpression();
                  }
                  this.context.allowYield = previousAllowYield;
                }
                return this.finalize(node, new Node2.YieldExpression(argument, delegate));
              };
              Parser2.prototype.parseClassElement = function(hasConstructor) {
                var token = this.lookahead;
                var node = this.createNode();
                var kind = "";
                var key = null;
                var value = null;
                var computed = false;
                var method = false;
                var isStatic = false;
                var isAsync = false;
                if (this.match("*")) {
                  this.nextToken();
                } else {
                  computed = this.match("[");
                  key = this.parseObjectPropertyKey();
                  var id = key;
                  if (id.name === "static" && (this.qualifiedPropertyName(this.lookahead) || this.match("*"))) {
                    token = this.lookahead;
                    isStatic = true;
                    computed = this.match("[");
                    if (this.match("*")) {
                      this.nextToken();
                    } else {
                      key = this.parseObjectPropertyKey();
                    }
                  }
                  if (token.type === 3 && !this.hasLineTerminator && token.value === "async") {
                    var punctuator = this.lookahead.value;
                    if (punctuator !== ":" && punctuator !== "(" && punctuator !== "*") {
                      isAsync = true;
                      token = this.lookahead;
                      key = this.parseObjectPropertyKey();
                      if (token.type === 3 && token.value === "constructor") {
                        this.tolerateUnexpectedToken(token, messages_1.Messages.ConstructorIsAsync);
                      }
                    }
                  }
                }
                var lookaheadPropertyKey = this.qualifiedPropertyName(this.lookahead);
                if (token.type === 3) {
                  if (token.value === "get" && lookaheadPropertyKey) {
                    kind = "get";
                    computed = this.match("[");
                    key = this.parseObjectPropertyKey();
                    this.context.allowYield = false;
                    value = this.parseGetterMethod();
                  } else if (token.value === "set" && lookaheadPropertyKey) {
                    kind = "set";
                    computed = this.match("[");
                    key = this.parseObjectPropertyKey();
                    value = this.parseSetterMethod();
                  }
                } else if (token.type === 7 && token.value === "*" && lookaheadPropertyKey) {
                  kind = "init";
                  computed = this.match("[");
                  key = this.parseObjectPropertyKey();
                  value = this.parseGeneratorMethod();
                  method = true;
                }
                if (!kind && key && this.match("(")) {
                  kind = "init";
                  value = isAsync ? this.parsePropertyMethodAsyncFunction() : this.parsePropertyMethodFunction();
                  method = true;
                }
                if (!kind) {
                  this.throwUnexpectedToken(this.lookahead);
                }
                if (kind === "init") {
                  kind = "method";
                }
                if (!computed) {
                  if (isStatic && this.isPropertyKey(key, "prototype")) {
                    this.throwUnexpectedToken(token, messages_1.Messages.StaticPrototype);
                  }
                  if (!isStatic && this.isPropertyKey(key, "constructor")) {
                    if (kind !== "method" || !method || value && value.generator) {
                      this.throwUnexpectedToken(token, messages_1.Messages.ConstructorSpecialMethod);
                    }
                    if (hasConstructor.value) {
                      this.throwUnexpectedToken(token, messages_1.Messages.DuplicateConstructor);
                    } else {
                      hasConstructor.value = true;
                    }
                    kind = "constructor";
                  }
                }
                return this.finalize(node, new Node2.MethodDefinition(key, computed, value, kind, isStatic));
              };
              Parser2.prototype.parseClassElementList = function() {
                var body = [];
                var hasConstructor = { value: false };
                this.expect("{");
                while (!this.match("}")) {
                  if (this.match(";")) {
                    this.nextToken();
                  } else {
                    body.push(this.parseClassElement(hasConstructor));
                  }
                }
                this.expect("}");
                return body;
              };
              Parser2.prototype.parseClassBody = function() {
                var node = this.createNode();
                var elementList = this.parseClassElementList();
                return this.finalize(node, new Node2.ClassBody(elementList));
              };
              Parser2.prototype.parseClassDeclaration = function(identifierIsOptional) {
                var node = this.createNode();
                var previousStrict = this.context.strict;
                this.context.strict = true;
                this.expectKeyword("class");
                var id = identifierIsOptional && this.lookahead.type !== 3 ? null : this.parseVariableIdentifier();
                var superClass = null;
                if (this.matchKeyword("extends")) {
                  this.nextToken();
                  superClass = this.isolateCoverGrammar(this.parseLeftHandSideExpressionAllowCall);
                }
                var classBody = this.parseClassBody();
                this.context.strict = previousStrict;
                return this.finalize(node, new Node2.ClassDeclaration(id, superClass, classBody));
              };
              Parser2.prototype.parseClassExpression = function() {
                var node = this.createNode();
                var previousStrict = this.context.strict;
                this.context.strict = true;
                this.expectKeyword("class");
                var id = this.lookahead.type === 3 ? this.parseVariableIdentifier() : null;
                var superClass = null;
                if (this.matchKeyword("extends")) {
                  this.nextToken();
                  superClass = this.isolateCoverGrammar(this.parseLeftHandSideExpressionAllowCall);
                }
                var classBody = this.parseClassBody();
                this.context.strict = previousStrict;
                return this.finalize(node, new Node2.ClassExpression(id, superClass, classBody));
              };
              Parser2.prototype.parseModule = function() {
                this.context.strict = true;
                this.context.isModule = true;
                this.scanner.isModule = true;
                var node = this.createNode();
                var body = this.parseDirectivePrologues();
                while (this.lookahead.type !== 2) {
                  body.push(this.parseStatementListItem());
                }
                return this.finalize(node, new Node2.Module(body));
              };
              Parser2.prototype.parseScript = function() {
                var node = this.createNode();
                var body = this.parseDirectivePrologues();
                while (this.lookahead.type !== 2) {
                  body.push(this.parseStatementListItem());
                }
                return this.finalize(node, new Node2.Script(body));
              };
              Parser2.prototype.parseModuleSpecifier = function() {
                var node = this.createNode();
                if (this.lookahead.type !== 8) {
                  this.throwError(messages_1.Messages.InvalidModuleSpecifier);
                }
                var token = this.nextToken();
                var raw = this.getTokenRaw(token);
                return this.finalize(node, new Node2.Literal(token.value, raw));
              };
              Parser2.prototype.parseImportSpecifier = function() {
                var node = this.createNode();
                var imported;
                var local;
                if (this.lookahead.type === 3) {
                  imported = this.parseVariableIdentifier();
                  local = imported;
                  if (this.matchContextualKeyword("as")) {
                    this.nextToken();
                    local = this.parseVariableIdentifier();
                  }
                } else {
                  imported = this.parseIdentifierName();
                  local = imported;
                  if (this.matchContextualKeyword("as")) {
                    this.nextToken();
                    local = this.parseVariableIdentifier();
                  } else {
                    this.throwUnexpectedToken(this.nextToken());
                  }
                }
                return this.finalize(node, new Node2.ImportSpecifier(local, imported));
              };
              Parser2.prototype.parseNamedImports = function() {
                this.expect("{");
                var specifiers = [];
                while (!this.match("}")) {
                  specifiers.push(this.parseImportSpecifier());
                  if (!this.match("}")) {
                    this.expect(",");
                  }
                }
                this.expect("}");
                return specifiers;
              };
              Parser2.prototype.parseImportDefaultSpecifier = function() {
                var node = this.createNode();
                var local = this.parseIdentifierName();
                return this.finalize(node, new Node2.ImportDefaultSpecifier(local));
              };
              Parser2.prototype.parseImportNamespaceSpecifier = function() {
                var node = this.createNode();
                this.expect("*");
                if (!this.matchContextualKeyword("as")) {
                  this.throwError(messages_1.Messages.NoAsAfterImportNamespace);
                }
                this.nextToken();
                var local = this.parseIdentifierName();
                return this.finalize(node, new Node2.ImportNamespaceSpecifier(local));
              };
              Parser2.prototype.parseImportDeclaration = function() {
                if (this.context.inFunctionBody) {
                  this.throwError(messages_1.Messages.IllegalImportDeclaration);
                }
                var node = this.createNode();
                this.expectKeyword("import");
                var src;
                var specifiers = [];
                if (this.lookahead.type === 8) {
                  src = this.parseModuleSpecifier();
                } else {
                  if (this.match("{")) {
                    specifiers = specifiers.concat(this.parseNamedImports());
                  } else if (this.match("*")) {
                    specifiers.push(this.parseImportNamespaceSpecifier());
                  } else if (this.isIdentifierName(this.lookahead) && !this.matchKeyword("default")) {
                    specifiers.push(this.parseImportDefaultSpecifier());
                    if (this.match(",")) {
                      this.nextToken();
                      if (this.match("*")) {
                        specifiers.push(this.parseImportNamespaceSpecifier());
                      } else if (this.match("{")) {
                        specifiers = specifiers.concat(this.parseNamedImports());
                      } else {
                        this.throwUnexpectedToken(this.lookahead);
                      }
                    }
                  } else {
                    this.throwUnexpectedToken(this.nextToken());
                  }
                  if (!this.matchContextualKeyword("from")) {
                    var message2 = this.lookahead.value ? messages_1.Messages.UnexpectedToken : messages_1.Messages.MissingFromClause;
                    this.throwError(message2, this.lookahead.value);
                  }
                  this.nextToken();
                  src = this.parseModuleSpecifier();
                }
                this.consumeSemicolon();
                return this.finalize(node, new Node2.ImportDeclaration(specifiers, src));
              };
              Parser2.prototype.parseExportSpecifier = function() {
                var node = this.createNode();
                var local = this.parseIdentifierName();
                var exported = local;
                if (this.matchContextualKeyword("as")) {
                  this.nextToken();
                  exported = this.parseIdentifierName();
                }
                return this.finalize(node, new Node2.ExportSpecifier(local, exported));
              };
              Parser2.prototype.parseExportDeclaration = function() {
                if (this.context.inFunctionBody) {
                  this.throwError(messages_1.Messages.IllegalExportDeclaration);
                }
                var node = this.createNode();
                this.expectKeyword("export");
                var exportDeclaration;
                if (this.matchKeyword("default")) {
                  this.nextToken();
                  if (this.matchKeyword("function")) {
                    var declaration = this.parseFunctionDeclaration(true);
                    exportDeclaration = this.finalize(node, new Node2.ExportDefaultDeclaration(declaration));
                  } else if (this.matchKeyword("class")) {
                    var declaration = this.parseClassDeclaration(true);
                    exportDeclaration = this.finalize(node, new Node2.ExportDefaultDeclaration(declaration));
                  } else if (this.matchContextualKeyword("async")) {
                    var declaration = this.matchAsyncFunction() ? this.parseFunctionDeclaration(true) : this.parseAssignmentExpression();
                    exportDeclaration = this.finalize(node, new Node2.ExportDefaultDeclaration(declaration));
                  } else {
                    if (this.matchContextualKeyword("from")) {
                      this.throwError(messages_1.Messages.UnexpectedToken, this.lookahead.value);
                    }
                    var declaration = this.match("{") ? this.parseObjectInitializer() : this.match("[") ? this.parseArrayInitializer() : this.parseAssignmentExpression();
                    this.consumeSemicolon();
                    exportDeclaration = this.finalize(node, new Node2.ExportDefaultDeclaration(declaration));
                  }
                } else if (this.match("*")) {
                  this.nextToken();
                  if (!this.matchContextualKeyword("from")) {
                    var message2 = this.lookahead.value ? messages_1.Messages.UnexpectedToken : messages_1.Messages.MissingFromClause;
                    this.throwError(message2, this.lookahead.value);
                  }
                  this.nextToken();
                  var src = this.parseModuleSpecifier();
                  this.consumeSemicolon();
                  exportDeclaration = this.finalize(node, new Node2.ExportAllDeclaration(src));
                } else if (this.lookahead.type === 4) {
                  var declaration = void 0;
                  switch (this.lookahead.value) {
                    case "let":
                    case "const":
                      declaration = this.parseLexicalDeclaration({ inFor: false });
                      break;
                    case "var":
                    case "class":
                    case "function":
                      declaration = this.parseStatementListItem();
                      break;
                    default:
                      this.throwUnexpectedToken(this.lookahead);
                  }
                  exportDeclaration = this.finalize(node, new Node2.ExportNamedDeclaration(declaration, [], null));
                } else if (this.matchAsyncFunction()) {
                  var declaration = this.parseFunctionDeclaration();
                  exportDeclaration = this.finalize(node, new Node2.ExportNamedDeclaration(declaration, [], null));
                } else {
                  var specifiers = [];
                  var source = null;
                  var isExportFromIdentifier = false;
                  this.expect("{");
                  while (!this.match("}")) {
                    isExportFromIdentifier = isExportFromIdentifier || this.matchKeyword("default");
                    specifiers.push(this.parseExportSpecifier());
                    if (!this.match("}")) {
                      this.expect(",");
                    }
                  }
                  this.expect("}");
                  if (this.matchContextualKeyword("from")) {
                    this.nextToken();
                    source = this.parseModuleSpecifier();
                    this.consumeSemicolon();
                  } else if (isExportFromIdentifier) {
                    var message2 = this.lookahead.value ? messages_1.Messages.UnexpectedToken : messages_1.Messages.MissingFromClause;
                    this.throwError(message2, this.lookahead.value);
                  } else {
                    this.consumeSemicolon();
                  }
                  exportDeclaration = this.finalize(node, new Node2.ExportNamedDeclaration(null, specifiers, source));
                }
                return exportDeclaration;
              };
              return Parser2;
            })();
            exports3.Parser = Parser;
          },
          /* 9 */
          /***/
          function(module3, exports3) {
            "use strict";
            Object.defineProperty(exports3, "__esModule", { value: true });
            function assert(condition, message2) {
              if (!condition) {
                throw new Error("ASSERT: " + message2);
              }
            }
            __name(assert, "assert");
            exports3.assert = assert;
          },
          /* 10 */
          /***/
          function(module3, exports3) {
            "use strict";
            Object.defineProperty(exports3, "__esModule", { value: true });
            var ErrorHandler = (function() {
              function ErrorHandler2() {
                this.errors = [];
                this.tolerant = false;
              }
              __name(ErrorHandler2, "ErrorHandler");
              ErrorHandler2.prototype.recordError = function(error4) {
                this.errors.push(error4);
              };
              ErrorHandler2.prototype.tolerate = function(error4) {
                if (this.tolerant) {
                  this.recordError(error4);
                } else {
                  throw error4;
                }
              };
              ErrorHandler2.prototype.constructError = function(msg, column) {
                var error4 = new Error(msg);
                try {
                  throw error4;
                } catch (base) {
                  if (Object.create && Object.defineProperty) {
                    error4 = Object.create(base);
                    Object.defineProperty(error4, "column", { value: column });
                  }
                }
                return error4;
              };
              ErrorHandler2.prototype.createError = function(index, line, col, description) {
                var msg = "Line " + line + ": " + description;
                var error4 = this.constructError(msg, col);
                error4.index = index;
                error4.lineNumber = line;
                error4.description = description;
                return error4;
              };
              ErrorHandler2.prototype.throwError = function(index, line, col, description) {
                throw this.createError(index, line, col, description);
              };
              ErrorHandler2.prototype.tolerateError = function(index, line, col, description) {
                var error4 = this.createError(index, line, col, description);
                if (this.tolerant) {
                  this.recordError(error4);
                } else {
                  throw error4;
                }
              };
              return ErrorHandler2;
            })();
            exports3.ErrorHandler = ErrorHandler;
          },
          /* 11 */
          /***/
          function(module3, exports3) {
            "use strict";
            Object.defineProperty(exports3, "__esModule", { value: true });
            exports3.Messages = {
              BadGetterArity: "Getter must not have any formal parameters",
              BadSetterArity: "Setter must have exactly one formal parameter",
              BadSetterRestParameter: "Setter function argument must not be a rest parameter",
              ConstructorIsAsync: "Class constructor may not be an async method",
              ConstructorSpecialMethod: "Class constructor may not be an accessor",
              DeclarationMissingInitializer: "Missing initializer in %0 declaration",
              DefaultRestParameter: "Unexpected token =",
              DuplicateBinding: "Duplicate binding %0",
              DuplicateConstructor: "A class may only have one constructor",
              DuplicateProtoProperty: "Duplicate __proto__ fields are not allowed in object literals",
              ForInOfLoopInitializer: "%0 loop variable declaration may not have an initializer",
              GeneratorInLegacyContext: "Generator declarations are not allowed in legacy contexts",
              IllegalBreak: "Illegal break statement",
              IllegalContinue: "Illegal continue statement",
              IllegalExportDeclaration: "Unexpected token",
              IllegalImportDeclaration: "Unexpected token",
              IllegalLanguageModeDirective: "Illegal 'use strict' directive in function with non-simple parameter list",
              IllegalReturn: "Illegal return statement",
              InvalidEscapedReservedWord: "Keyword must not contain escaped characters",
              InvalidHexEscapeSequence: "Invalid hexadecimal escape sequence",
              InvalidLHSInAssignment: "Invalid left-hand side in assignment",
              InvalidLHSInForIn: "Invalid left-hand side in for-in",
              InvalidLHSInForLoop: "Invalid left-hand side in for-loop",
              InvalidModuleSpecifier: "Unexpected token",
              InvalidRegExp: "Invalid regular expression",
              LetInLexicalBinding: "let is disallowed as a lexically bound name",
              MissingFromClause: "Unexpected token",
              MultipleDefaultsInSwitch: "More than one default clause in switch statement",
              NewlineAfterThrow: "Illegal newline after throw",
              NoAsAfterImportNamespace: "Unexpected token",
              NoCatchOrFinally: "Missing catch or finally after try",
              ParameterAfterRestParameter: "Rest parameter must be last formal parameter",
              Redeclaration: "%0 '%1' has already been declared",
              StaticPrototype: "Classes may not have static property named prototype",
              StrictCatchVariable: "Catch variable may not be eval or arguments in strict mode",
              StrictDelete: "Delete of an unqualified identifier in strict mode.",
              StrictFunction: "In strict mode code, functions can only be declared at top level or inside a block",
              StrictFunctionName: "Function name may not be eval or arguments in strict mode",
              StrictLHSAssignment: "Assignment to eval or arguments is not allowed in strict mode",
              StrictLHSPostfix: "Postfix increment/decrement may not have eval or arguments operand in strict mode",
              StrictLHSPrefix: "Prefix increment/decrement may not have eval or arguments operand in strict mode",
              StrictModeWith: "Strict mode code may not include a with statement",
              StrictOctalLiteral: "Octal literals are not allowed in strict mode.",
              StrictParamDupe: "Strict mode function may not have duplicate parameter names",
              StrictParamName: "Parameter name eval or arguments is not allowed in strict mode",
              StrictReservedWord: "Use of future reserved word in strict mode",
              StrictVarName: "Variable name may not be eval or arguments in strict mode",
              TemplateOctalLiteral: "Octal literals are not allowed in template strings.",
              UnexpectedEOS: "Unexpected end of input",
              UnexpectedIdentifier: "Unexpected identifier",
              UnexpectedNumber: "Unexpected number",
              UnexpectedReserved: "Unexpected reserved word",
              UnexpectedString: "Unexpected string",
              UnexpectedTemplate: "Unexpected quasi %0",
              UnexpectedToken: "Unexpected token %0",
              UnexpectedTokenIllegal: "Unexpected token ILLEGAL",
              UnknownLabel: "Undefined label '%0'",
              UnterminatedRegExp: "Invalid regular expression: missing /"
            };
          },
          /* 12 */
          /***/
          function(module3, exports3, __webpack_require__) {
            "use strict";
            Object.defineProperty(exports3, "__esModule", { value: true });
            var assert_1 = __webpack_require__(9);
            var character_1 = __webpack_require__(4);
            var messages_1 = __webpack_require__(11);
            function hexValue(ch) {
              return "0123456789abcdef".indexOf(ch.toLowerCase());
            }
            __name(hexValue, "hexValue");
            function octalValue(ch) {
              return "01234567".indexOf(ch);
            }
            __name(octalValue, "octalValue");
            var Scanner = (function() {
              function Scanner2(code, handler) {
                this.source = code;
                this.errorHandler = handler;
                this.trackComment = false;
                this.isModule = false;
                this.length = code.length;
                this.index = 0;
                this.lineNumber = code.length > 0 ? 1 : 0;
                this.lineStart = 0;
                this.curlyStack = [];
              }
              __name(Scanner2, "Scanner");
              Scanner2.prototype.saveState = function() {
                return {
                  index: this.index,
                  lineNumber: this.lineNumber,
                  lineStart: this.lineStart
                };
              };
              Scanner2.prototype.restoreState = function(state13) {
                this.index = state13.index;
                this.lineNumber = state13.lineNumber;
                this.lineStart = state13.lineStart;
              };
              Scanner2.prototype.eof = function() {
                return this.index >= this.length;
              };
              Scanner2.prototype.throwUnexpectedToken = function(message2) {
                if (message2 === void 0) {
                  message2 = messages_1.Messages.UnexpectedTokenIllegal;
                }
                return this.errorHandler.throwError(this.index, this.lineNumber, this.index - this.lineStart + 1, message2);
              };
              Scanner2.prototype.tolerateUnexpectedToken = function(message2) {
                if (message2 === void 0) {
                  message2 = messages_1.Messages.UnexpectedTokenIllegal;
                }
                this.errorHandler.tolerateError(this.index, this.lineNumber, this.index - this.lineStart + 1, message2);
              };
              Scanner2.prototype.skipSingleLineComment = function(offset) {
                var comments = [];
                var start, loc;
                if (this.trackComment) {
                  comments = [];
                  start = this.index - offset;
                  loc = {
                    start: {
                      line: this.lineNumber,
                      column: this.index - this.lineStart - offset
                    },
                    end: {}
                  };
                }
                while (!this.eof()) {
                  var ch = this.source.charCodeAt(this.index);
                  ++this.index;
                  if (character_1.Character.isLineTerminator(ch)) {
                    if (this.trackComment) {
                      loc.end = {
                        line: this.lineNumber,
                        column: this.index - this.lineStart - 1
                      };
                      var entry = {
                        multiLine: false,
                        slice: [start + offset, this.index - 1],
                        range: [start, this.index - 1],
                        loc
                      };
                      comments.push(entry);
                    }
                    if (ch === 13 && this.source.charCodeAt(this.index) === 10) {
                      ++this.index;
                    }
                    ++this.lineNumber;
                    this.lineStart = this.index;
                    return comments;
                  }
                }
                if (this.trackComment) {
                  loc.end = {
                    line: this.lineNumber,
                    column: this.index - this.lineStart
                  };
                  var entry = {
                    multiLine: false,
                    slice: [start + offset, this.index],
                    range: [start, this.index],
                    loc
                  };
                  comments.push(entry);
                }
                return comments;
              };
              Scanner2.prototype.skipMultiLineComment = function() {
                var comments = [];
                var start, loc;
                if (this.trackComment) {
                  comments = [];
                  start = this.index - 2;
                  loc = {
                    start: {
                      line: this.lineNumber,
                      column: this.index - this.lineStart - 2
                    },
                    end: {}
                  };
                }
                while (!this.eof()) {
                  var ch = this.source.charCodeAt(this.index);
                  if (character_1.Character.isLineTerminator(ch)) {
                    if (ch === 13 && this.source.charCodeAt(this.index + 1) === 10) {
                      ++this.index;
                    }
                    ++this.lineNumber;
                    ++this.index;
                    this.lineStart = this.index;
                  } else if (ch === 42) {
                    if (this.source.charCodeAt(this.index + 1) === 47) {
                      this.index += 2;
                      if (this.trackComment) {
                        loc.end = {
                          line: this.lineNumber,
                          column: this.index - this.lineStart
                        };
                        var entry = {
                          multiLine: true,
                          slice: [start + 2, this.index - 2],
                          range: [start, this.index],
                          loc
                        };
                        comments.push(entry);
                      }
                      return comments;
                    }
                    ++this.index;
                  } else {
                    ++this.index;
                  }
                }
                if (this.trackComment) {
                  loc.end = {
                    line: this.lineNumber,
                    column: this.index - this.lineStart
                  };
                  var entry = {
                    multiLine: true,
                    slice: [start + 2, this.index],
                    range: [start, this.index],
                    loc
                  };
                  comments.push(entry);
                }
                this.tolerateUnexpectedToken();
                return comments;
              };
              Scanner2.prototype.scanComments = function() {
                var comments;
                if (this.trackComment) {
                  comments = [];
                }
                var start = this.index === 0;
                while (!this.eof()) {
                  var ch = this.source.charCodeAt(this.index);
                  if (character_1.Character.isWhiteSpace(ch)) {
                    ++this.index;
                  } else if (character_1.Character.isLineTerminator(ch)) {
                    ++this.index;
                    if (ch === 13 && this.source.charCodeAt(this.index) === 10) {
                      ++this.index;
                    }
                    ++this.lineNumber;
                    this.lineStart = this.index;
                    start = true;
                  } else if (ch === 47) {
                    ch = this.source.charCodeAt(this.index + 1);
                    if (ch === 47) {
                      this.index += 2;
                      var comment = this.skipSingleLineComment(2);
                      if (this.trackComment) {
                        comments = comments.concat(comment);
                      }
                      start = true;
                    } else if (ch === 42) {
                      this.index += 2;
                      var comment = this.skipMultiLineComment();
                      if (this.trackComment) {
                        comments = comments.concat(comment);
                      }
                    } else {
                      break;
                    }
                  } else if (start && ch === 45) {
                    if (this.source.charCodeAt(this.index + 1) === 45 && this.source.charCodeAt(this.index + 2) === 62) {
                      this.index += 3;
                      var comment = this.skipSingleLineComment(3);
                      if (this.trackComment) {
                        comments = comments.concat(comment);
                      }
                    } else {
                      break;
                    }
                  } else if (ch === 60 && !this.isModule) {
                    if (this.source.slice(this.index + 1, this.index + 4) === "!--") {
                      this.index += 4;
                      var comment = this.skipSingleLineComment(4);
                      if (this.trackComment) {
                        comments = comments.concat(comment);
                      }
                    } else {
                      break;
                    }
                  } else {
                    break;
                  }
                }
                return comments;
              };
              Scanner2.prototype.isFutureReservedWord = function(id) {
                switch (id) {
                  case "enum":
                  case "export":
                  case "import":
                  case "super":
                    return true;
                  default:
                    return false;
                }
              };
              Scanner2.prototype.isStrictModeReservedWord = function(id) {
                switch (id) {
                  case "implements":
                  case "interface":
                  case "package":
                  case "private":
                  case "protected":
                  case "public":
                  case "static":
                  case "yield":
                  case "let":
                    return true;
                  default:
                    return false;
                }
              };
              Scanner2.prototype.isRestrictedWord = function(id) {
                return id === "eval" || id === "arguments";
              };
              Scanner2.prototype.isKeyword = function(id) {
                switch (id.length) {
                  case 2:
                    return id === "if" || id === "in" || id === "do";
                  case 3:
                    return id === "var" || id === "for" || id === "new" || id === "try" || id === "let";
                  case 4:
                    return id === "this" || id === "else" || id === "case" || id === "void" || id === "with" || id === "enum";
                  case 5:
                    return id === "while" || id === "break" || id === "catch" || id === "throw" || id === "const" || id === "yield" || id === "class" || id === "super";
                  case 6:
                    return id === "return" || id === "typeof" || id === "delete" || id === "switch" || id === "export" || id === "import";
                  case 7:
                    return id === "default" || id === "finally" || id === "extends";
                  case 8:
                    return id === "function" || id === "continue" || id === "debugger";
                  case 10:
                    return id === "instanceof";
                  default:
                    return false;
                }
              };
              Scanner2.prototype.codePointAt = function(i32) {
                var cp = this.source.charCodeAt(i32);
                if (cp >= 55296 && cp <= 56319) {
                  var second = this.source.charCodeAt(i32 + 1);
                  if (second >= 56320 && second <= 57343) {
                    var first = cp;
                    cp = (first - 55296) * 1024 + second - 56320 + 65536;
                  }
                }
                return cp;
              };
              Scanner2.prototype.scanHexEscape = function(prefix) {
                var len = prefix === "u" ? 4 : 2;
                var code = 0;
                for (var i32 = 0; i32 < len; ++i32) {
                  if (!this.eof() && character_1.Character.isHexDigit(this.source.charCodeAt(this.index))) {
                    code = code * 16 + hexValue(this.source[this.index++]);
                  } else {
                    return null;
                  }
                }
                return String.fromCharCode(code);
              };
              Scanner2.prototype.scanUnicodeCodePointEscape = function() {
                var ch = this.source[this.index];
                var code = 0;
                if (ch === "}") {
                  this.throwUnexpectedToken();
                }
                while (!this.eof()) {
                  ch = this.source[this.index++];
                  if (!character_1.Character.isHexDigit(ch.charCodeAt(0))) {
                    break;
                  }
                  code = code * 16 + hexValue(ch);
                }
                if (code > 1114111 || ch !== "}") {
                  this.throwUnexpectedToken();
                }
                return character_1.Character.fromCodePoint(code);
              };
              Scanner2.prototype.getIdentifier = function() {
                var start = this.index++;
                while (!this.eof()) {
                  var ch = this.source.charCodeAt(this.index);
                  if (ch === 92) {
                    this.index = start;
                    return this.getComplexIdentifier();
                  } else if (ch >= 55296 && ch < 57343) {
                    this.index = start;
                    return this.getComplexIdentifier();
                  }
                  if (character_1.Character.isIdentifierPart(ch)) {
                    ++this.index;
                  } else {
                    break;
                  }
                }
                return this.source.slice(start, this.index);
              };
              Scanner2.prototype.getComplexIdentifier = function() {
                var cp = this.codePointAt(this.index);
                var id = character_1.Character.fromCodePoint(cp);
                this.index += id.length;
                var ch;
                if (cp === 92) {
                  if (this.source.charCodeAt(this.index) !== 117) {
                    this.throwUnexpectedToken();
                  }
                  ++this.index;
                  if (this.source[this.index] === "{") {
                    ++this.index;
                    ch = this.scanUnicodeCodePointEscape();
                  } else {
                    ch = this.scanHexEscape("u");
                    if (ch === null || ch === "\\" || !character_1.Character.isIdentifierStart(ch.charCodeAt(0))) {
                      this.throwUnexpectedToken();
                    }
                  }
                  id = ch;
                }
                while (!this.eof()) {
                  cp = this.codePointAt(this.index);
                  if (!character_1.Character.isIdentifierPart(cp)) {
                    break;
                  }
                  ch = character_1.Character.fromCodePoint(cp);
                  id += ch;
                  this.index += ch.length;
                  if (cp === 92) {
                    id = id.substr(0, id.length - 1);
                    if (this.source.charCodeAt(this.index) !== 117) {
                      this.throwUnexpectedToken();
                    }
                    ++this.index;
                    if (this.source[this.index] === "{") {
                      ++this.index;
                      ch = this.scanUnicodeCodePointEscape();
                    } else {
                      ch = this.scanHexEscape("u");
                      if (ch === null || ch === "\\" || !character_1.Character.isIdentifierPart(ch.charCodeAt(0))) {
                        this.throwUnexpectedToken();
                      }
                    }
                    id += ch;
                  }
                }
                return id;
              };
              Scanner2.prototype.octalToDecimal = function(ch) {
                var octal = ch !== "0";
                var code = octalValue(ch);
                if (!this.eof() && character_1.Character.isOctalDigit(this.source.charCodeAt(this.index))) {
                  octal = true;
                  code = code * 8 + octalValue(this.source[this.index++]);
                  if ("0123".indexOf(ch) >= 0 && !this.eof() && character_1.Character.isOctalDigit(this.source.charCodeAt(this.index))) {
                    code = code * 8 + octalValue(this.source[this.index++]);
                  }
                }
                return {
                  code,
                  octal
                };
              };
              Scanner2.prototype.scanIdentifier = function() {
                var type;
                var start = this.index;
                var id = this.source.charCodeAt(start) === 92 ? this.getComplexIdentifier() : this.getIdentifier();
                if (id.length === 1) {
                  type = 3;
                } else if (this.isKeyword(id)) {
                  type = 4;
                } else if (id === "null") {
                  type = 5;
                } else if (id === "true" || id === "false") {
                  type = 1;
                } else {
                  type = 3;
                }
                if (type !== 3 && start + id.length !== this.index) {
                  var restore = this.index;
                  this.index = start;
                  this.tolerateUnexpectedToken(messages_1.Messages.InvalidEscapedReservedWord);
                  this.index = restore;
                }
                return {
                  type,
                  value: id,
                  lineNumber: this.lineNumber,
                  lineStart: this.lineStart,
                  start,
                  end: this.index
                };
              };
              Scanner2.prototype.scanPunctuator = function() {
                var start = this.index;
                var str = this.source[this.index];
                switch (str) {
                  case "(":
                  case "{":
                    if (str === "{") {
                      this.curlyStack.push("{");
                    }
                    ++this.index;
                    break;
                  case ".":
                    ++this.index;
                    if (this.source[this.index] === "." && this.source[this.index + 1] === ".") {
                      this.index += 2;
                      str = "...";
                    }
                    break;
                  case "}":
                    ++this.index;
                    this.curlyStack.pop();
                    break;
                  case ")":
                  case ";":
                  case ",":
                  case "[":
                  case "]":
                  case ":":
                  case "?":
                  case "~":
                    ++this.index;
                    break;
                  default:
                    str = this.source.substr(this.index, 4);
                    if (str === ">>>=") {
                      this.index += 4;
                    } else {
                      str = str.substr(0, 3);
                      if (str === "===" || str === "!==" || str === ">>>" || str === "<<=" || str === ">>=" || str === "**=") {
                        this.index += 3;
                      } else {
                        str = str.substr(0, 2);
                        if (str === "&&" || str === "||" || str === "==" || str === "!=" || str === "+=" || str === "-=" || str === "*=" || str === "/=" || str === "++" || str === "--" || str === "<<" || str === ">>" || str === "&=" || str === "|=" || str === "^=" || str === "%=" || str === "<=" || str === ">=" || str === "=>" || str === "**") {
                          this.index += 2;
                        } else {
                          str = this.source[this.index];
                          if ("<>=!+-*%&|^/".indexOf(str) >= 0) {
                            ++this.index;
                          }
                        }
                      }
                    }
                }
                if (this.index === start) {
                  this.throwUnexpectedToken();
                }
                return {
                  type: 7,
                  value: str,
                  lineNumber: this.lineNumber,
                  lineStart: this.lineStart,
                  start,
                  end: this.index
                };
              };
              Scanner2.prototype.scanHexLiteral = function(start) {
                var num = "";
                while (!this.eof()) {
                  if (!character_1.Character.isHexDigit(this.source.charCodeAt(this.index))) {
                    break;
                  }
                  num += this.source[this.index++];
                }
                if (num.length === 0) {
                  this.throwUnexpectedToken();
                }
                if (character_1.Character.isIdentifierStart(this.source.charCodeAt(this.index))) {
                  this.throwUnexpectedToken();
                }
                return {
                  type: 6,
                  value: parseInt("0x" + num, 16),
                  lineNumber: this.lineNumber,
                  lineStart: this.lineStart,
                  start,
                  end: this.index
                };
              };
              Scanner2.prototype.scanBinaryLiteral = function(start) {
                var num = "";
                var ch;
                while (!this.eof()) {
                  ch = this.source[this.index];
                  if (ch !== "0" && ch !== "1") {
                    break;
                  }
                  num += this.source[this.index++];
                }
                if (num.length === 0) {
                  this.throwUnexpectedToken();
                }
                if (!this.eof()) {
                  ch = this.source.charCodeAt(this.index);
                  if (character_1.Character.isIdentifierStart(ch) || character_1.Character.isDecimalDigit(ch)) {
                    this.throwUnexpectedToken();
                  }
                }
                return {
                  type: 6,
                  value: parseInt(num, 2),
                  lineNumber: this.lineNumber,
                  lineStart: this.lineStart,
                  start,
                  end: this.index
                };
              };
              Scanner2.prototype.scanOctalLiteral = function(prefix, start) {
                var num = "";
                var octal = false;
                if (character_1.Character.isOctalDigit(prefix.charCodeAt(0))) {
                  octal = true;
                  num = "0" + this.source[this.index++];
                } else {
                  ++this.index;
                }
                while (!this.eof()) {
                  if (!character_1.Character.isOctalDigit(this.source.charCodeAt(this.index))) {
                    break;
                  }
                  num += this.source[this.index++];
                }
                if (!octal && num.length === 0) {
                  this.throwUnexpectedToken();
                }
                if (character_1.Character.isIdentifierStart(this.source.charCodeAt(this.index)) || character_1.Character.isDecimalDigit(this.source.charCodeAt(this.index))) {
                  this.throwUnexpectedToken();
                }
                return {
                  type: 6,
                  value: parseInt(num, 8),
                  octal,
                  lineNumber: this.lineNumber,
                  lineStart: this.lineStart,
                  start,
                  end: this.index
                };
              };
              Scanner2.prototype.isImplicitOctalLiteral = function() {
                for (var i32 = this.index + 1; i32 < this.length; ++i32) {
                  var ch = this.source[i32];
                  if (ch === "8" || ch === "9") {
                    return false;
                  }
                  if (!character_1.Character.isOctalDigit(ch.charCodeAt(0))) {
                    return true;
                  }
                }
                return true;
              };
              Scanner2.prototype.scanNumericLiteral = function() {
                var start = this.index;
                var ch = this.source[start];
                assert_1.assert(character_1.Character.isDecimalDigit(ch.charCodeAt(0)) || ch === ".", "Numeric literal must start with a decimal digit or a decimal point");
                var num = "";
                if (ch !== ".") {
                  num = this.source[this.index++];
                  ch = this.source[this.index];
                  if (num === "0") {
                    if (ch === "x" || ch === "X") {
                      ++this.index;
                      return this.scanHexLiteral(start);
                    }
                    if (ch === "b" || ch === "B") {
                      ++this.index;
                      return this.scanBinaryLiteral(start);
                    }
                    if (ch === "o" || ch === "O") {
                      return this.scanOctalLiteral(ch, start);
                    }
                    if (ch && character_1.Character.isOctalDigit(ch.charCodeAt(0))) {
                      if (this.isImplicitOctalLiteral()) {
                        return this.scanOctalLiteral(ch, start);
                      }
                    }
                  }
                  while (character_1.Character.isDecimalDigit(this.source.charCodeAt(this.index))) {
                    num += this.source[this.index++];
                  }
                  ch = this.source[this.index];
                }
                if (ch === ".") {
                  num += this.source[this.index++];
                  while (character_1.Character.isDecimalDigit(this.source.charCodeAt(this.index))) {
                    num += this.source[this.index++];
                  }
                  ch = this.source[this.index];
                }
                if (ch === "e" || ch === "E") {
                  num += this.source[this.index++];
                  ch = this.source[this.index];
                  if (ch === "+" || ch === "-") {
                    num += this.source[this.index++];
                  }
                  if (character_1.Character.isDecimalDigit(this.source.charCodeAt(this.index))) {
                    while (character_1.Character.isDecimalDigit(this.source.charCodeAt(this.index))) {
                      num += this.source[this.index++];
                    }
                  } else {
                    this.throwUnexpectedToken();
                  }
                }
                if (character_1.Character.isIdentifierStart(this.source.charCodeAt(this.index))) {
                  this.throwUnexpectedToken();
                }
                return {
                  type: 6,
                  value: parseFloat(num),
                  lineNumber: this.lineNumber,
                  lineStart: this.lineStart,
                  start,
                  end: this.index
                };
              };
              Scanner2.prototype.scanStringLiteral = function() {
                var start = this.index;
                var quote = this.source[start];
                assert_1.assert(quote === "'" || quote === '"', "String literal must starts with a quote");
                ++this.index;
                var octal = false;
                var str = "";
                while (!this.eof()) {
                  var ch = this.source[this.index++];
                  if (ch === quote) {
                    quote = "";
                    break;
                  } else if (ch === "\\") {
                    ch = this.source[this.index++];
                    if (!ch || !character_1.Character.isLineTerminator(ch.charCodeAt(0))) {
                      switch (ch) {
                        case "u":
                          if (this.source[this.index] === "{") {
                            ++this.index;
                            str += this.scanUnicodeCodePointEscape();
                          } else {
                            var unescaped_1 = this.scanHexEscape(ch);
                            if (unescaped_1 === null) {
                              this.throwUnexpectedToken();
                            }
                            str += unescaped_1;
                          }
                          break;
                        case "x":
                          var unescaped = this.scanHexEscape(ch);
                          if (unescaped === null) {
                            this.throwUnexpectedToken(messages_1.Messages.InvalidHexEscapeSequence);
                          }
                          str += unescaped;
                          break;
                        case "n":
                          str += "\n";
                          break;
                        case "r":
                          str += "\r";
                          break;
                        case "t":
                          str += "	";
                          break;
                        case "b":
                          str += "\b";
                          break;
                        case "f":
                          str += "\f";
                          break;
                        case "v":
                          str += "\v";
                          break;
                        case "8":
                        case "9":
                          str += ch;
                          this.tolerateUnexpectedToken();
                          break;
                        default:
                          if (ch && character_1.Character.isOctalDigit(ch.charCodeAt(0))) {
                            var octToDec = this.octalToDecimal(ch);
                            octal = octToDec.octal || octal;
                            str += String.fromCharCode(octToDec.code);
                          } else {
                            str += ch;
                          }
                          break;
                      }
                    } else {
                      ++this.lineNumber;
                      if (ch === "\r" && this.source[this.index] === "\n") {
                        ++this.index;
                      }
                      this.lineStart = this.index;
                    }
                  } else if (character_1.Character.isLineTerminator(ch.charCodeAt(0))) {
                    break;
                  } else {
                    str += ch;
                  }
                }
                if (quote !== "") {
                  this.index = start;
                  this.throwUnexpectedToken();
                }
                return {
                  type: 8,
                  value: str,
                  octal,
                  lineNumber: this.lineNumber,
                  lineStart: this.lineStart,
                  start,
                  end: this.index
                };
              };
              Scanner2.prototype.scanTemplate = function() {
                var cooked = "";
                var terminated = false;
                var start = this.index;
                var head = this.source[start] === "`";
                var tail = false;
                var rawOffset = 2;
                ++this.index;
                while (!this.eof()) {
                  var ch = this.source[this.index++];
                  if (ch === "`") {
                    rawOffset = 1;
                    tail = true;
                    terminated = true;
                    break;
                  } else if (ch === "$") {
                    if (this.source[this.index] === "{") {
                      this.curlyStack.push("${");
                      ++this.index;
                      terminated = true;
                      break;
                    }
                    cooked += ch;
                  } else if (ch === "\\") {
                    ch = this.source[this.index++];
                    if (!character_1.Character.isLineTerminator(ch.charCodeAt(0))) {
                      switch (ch) {
                        case "n":
                          cooked += "\n";
                          break;
                        case "r":
                          cooked += "\r";
                          break;
                        case "t":
                          cooked += "	";
                          break;
                        case "u":
                          if (this.source[this.index] === "{") {
                            ++this.index;
                            cooked += this.scanUnicodeCodePointEscape();
                          } else {
                            var restore = this.index;
                            var unescaped_2 = this.scanHexEscape(ch);
                            if (unescaped_2 !== null) {
                              cooked += unescaped_2;
                            } else {
                              this.index = restore;
                              cooked += ch;
                            }
                          }
                          break;
                        case "x":
                          var unescaped = this.scanHexEscape(ch);
                          if (unescaped === null) {
                            this.throwUnexpectedToken(messages_1.Messages.InvalidHexEscapeSequence);
                          }
                          cooked += unescaped;
                          break;
                        case "b":
                          cooked += "\b";
                          break;
                        case "f":
                          cooked += "\f";
                          break;
                        case "v":
                          cooked += "\v";
                          break;
                        default:
                          if (ch === "0") {
                            if (character_1.Character.isDecimalDigit(this.source.charCodeAt(this.index))) {
                              this.throwUnexpectedToken(messages_1.Messages.TemplateOctalLiteral);
                            }
                            cooked += "\0";
                          } else if (character_1.Character.isOctalDigit(ch.charCodeAt(0))) {
                            this.throwUnexpectedToken(messages_1.Messages.TemplateOctalLiteral);
                          } else {
                            cooked += ch;
                          }
                          break;
                      }
                    } else {
                      ++this.lineNumber;
                      if (ch === "\r" && this.source[this.index] === "\n") {
                        ++this.index;
                      }
                      this.lineStart = this.index;
                    }
                  } else if (character_1.Character.isLineTerminator(ch.charCodeAt(0))) {
                    ++this.lineNumber;
                    if (ch === "\r" && this.source[this.index] === "\n") {
                      ++this.index;
                    }
                    this.lineStart = this.index;
                    cooked += "\n";
                  } else {
                    cooked += ch;
                  }
                }
                if (!terminated) {
                  this.throwUnexpectedToken();
                }
                if (!head) {
                  this.curlyStack.pop();
                }
                return {
                  type: 10,
                  value: this.source.slice(start + 1, this.index - rawOffset),
                  cooked,
                  head,
                  tail,
                  lineNumber: this.lineNumber,
                  lineStart: this.lineStart,
                  start,
                  end: this.index
                };
              };
              Scanner2.prototype.testRegExp = function(pattern, flags) {
                var astralSubstitute = "\uFFFF";
                var tmp = pattern;
                var self2 = this;
                if (flags.indexOf("u") >= 0) {
                  tmp = tmp.replace(/\\u\{([0-9a-fA-F]+)\}|\\u([a-fA-F0-9]{4})/g, function($0, $1, $2) {
                    var codePoint = parseInt($1 || $2, 16);
                    if (codePoint > 1114111) {
                      self2.throwUnexpectedToken(messages_1.Messages.InvalidRegExp);
                    }
                    if (codePoint <= 65535) {
                      return String.fromCharCode(codePoint);
                    }
                    return astralSubstitute;
                  }).replace(/[\uD800-\uDBFF][\uDC00-\uDFFF]/g, astralSubstitute);
                }
                try {
                  RegExp(tmp);
                } catch (e32) {
                  this.throwUnexpectedToken(messages_1.Messages.InvalidRegExp);
                }
                try {
                  return new RegExp(pattern, flags);
                } catch (exception) {
                  return null;
                }
              };
              Scanner2.prototype.scanRegExpBody = function() {
                var ch = this.source[this.index];
                assert_1.assert(ch === "/", "Regular expression literal must start with a slash");
                var str = this.source[this.index++];
                var classMarker = false;
                var terminated = false;
                while (!this.eof()) {
                  ch = this.source[this.index++];
                  str += ch;
                  if (ch === "\\") {
                    ch = this.source[this.index++];
                    if (character_1.Character.isLineTerminator(ch.charCodeAt(0))) {
                      this.throwUnexpectedToken(messages_1.Messages.UnterminatedRegExp);
                    }
                    str += ch;
                  } else if (character_1.Character.isLineTerminator(ch.charCodeAt(0))) {
                    this.throwUnexpectedToken(messages_1.Messages.UnterminatedRegExp);
                  } else if (classMarker) {
                    if (ch === "]") {
                      classMarker = false;
                    }
                  } else {
                    if (ch === "/") {
                      terminated = true;
                      break;
                    } else if (ch === "[") {
                      classMarker = true;
                    }
                  }
                }
                if (!terminated) {
                  this.throwUnexpectedToken(messages_1.Messages.UnterminatedRegExp);
                }
                return str.substr(1, str.length - 2);
              };
              Scanner2.prototype.scanRegExpFlags = function() {
                var str = "";
                var flags = "";
                while (!this.eof()) {
                  var ch = this.source[this.index];
                  if (!character_1.Character.isIdentifierPart(ch.charCodeAt(0))) {
                    break;
                  }
                  ++this.index;
                  if (ch === "\\" && !this.eof()) {
                    ch = this.source[this.index];
                    if (ch === "u") {
                      ++this.index;
                      var restore = this.index;
                      var char = this.scanHexEscape("u");
                      if (char !== null) {
                        flags += char;
                        for (str += "\\u"; restore < this.index; ++restore) {
                          str += this.source[restore];
                        }
                      } else {
                        this.index = restore;
                        flags += "u";
                        str += "\\u";
                      }
                      this.tolerateUnexpectedToken();
                    } else {
                      str += "\\";
                      this.tolerateUnexpectedToken();
                    }
                  } else {
                    flags += ch;
                    str += ch;
                  }
                }
                return flags;
              };
              Scanner2.prototype.scanRegExp = function() {
                var start = this.index;
                var pattern = this.scanRegExpBody();
                var flags = this.scanRegExpFlags();
                var value = this.testRegExp(pattern, flags);
                return {
                  type: 9,
                  value: "",
                  pattern,
                  flags,
                  regex: value,
                  lineNumber: this.lineNumber,
                  lineStart: this.lineStart,
                  start,
                  end: this.index
                };
              };
              Scanner2.prototype.lex = function() {
                if (this.eof()) {
                  return {
                    type: 2,
                    value: "",
                    lineNumber: this.lineNumber,
                    lineStart: this.lineStart,
                    start: this.index,
                    end: this.index
                  };
                }
                var cp = this.source.charCodeAt(this.index);
                if (character_1.Character.isIdentifierStart(cp)) {
                  return this.scanIdentifier();
                }
                if (cp === 40 || cp === 41 || cp === 59) {
                  return this.scanPunctuator();
                }
                if (cp === 39 || cp === 34) {
                  return this.scanStringLiteral();
                }
                if (cp === 46) {
                  if (character_1.Character.isDecimalDigit(this.source.charCodeAt(this.index + 1))) {
                    return this.scanNumericLiteral();
                  }
                  return this.scanPunctuator();
                }
                if (character_1.Character.isDecimalDigit(cp)) {
                  return this.scanNumericLiteral();
                }
                if (cp === 96 || cp === 125 && this.curlyStack[this.curlyStack.length - 1] === "${") {
                  return this.scanTemplate();
                }
                if (cp >= 55296 && cp < 57343) {
                  if (character_1.Character.isIdentifierStart(this.codePointAt(this.index))) {
                    return this.scanIdentifier();
                  }
                }
                return this.scanPunctuator();
              };
              return Scanner2;
            })();
            exports3.Scanner = Scanner;
          },
          /* 13 */
          /***/
          function(module3, exports3) {
            "use strict";
            Object.defineProperty(exports3, "__esModule", { value: true });
            exports3.TokenName = {};
            exports3.TokenName[
              1
              /* BooleanLiteral */
            ] = "Boolean";
            exports3.TokenName[
              2
              /* EOF */
            ] = "<end>";
            exports3.TokenName[
              3
              /* Identifier */
            ] = "Identifier";
            exports3.TokenName[
              4
              /* Keyword */
            ] = "Keyword";
            exports3.TokenName[
              5
              /* NullLiteral */
            ] = "Null";
            exports3.TokenName[
              6
              /* NumericLiteral */
            ] = "Numeric";
            exports3.TokenName[
              7
              /* Punctuator */
            ] = "Punctuator";
            exports3.TokenName[
              8
              /* StringLiteral */
            ] = "String";
            exports3.TokenName[
              9
              /* RegularExpression */
            ] = "RegularExpression";
            exports3.TokenName[
              10
              /* Template */
            ] = "Template";
          },
          /* 14 */
          /***/
          function(module3, exports3) {
            "use strict";
            Object.defineProperty(exports3, "__esModule", { value: true });
            exports3.XHTMLEntities = {
              quot: '"',
              amp: "&",
              apos: "'",
              gt: ">",
              nbsp: "\xA0",
              iexcl: "\xA1",
              cent: "\xA2",
              pound: "\xA3",
              curren: "\xA4",
              yen: "\xA5",
              brvbar: "\xA6",
              sect: "\xA7",
              uml: "\xA8",
              copy: "\xA9",
              ordf: "\xAA",
              laquo: "\xAB",
              not: "\xAC",
              shy: "\xAD",
              reg: "\xAE",
              macr: "\xAF",
              deg: "\xB0",
              plusmn: "\xB1",
              sup2: "\xB2",
              sup3: "\xB3",
              acute: "\xB4",
              micro: "\xB5",
              para: "\xB6",
              middot: "\xB7",
              cedil: "\xB8",
              sup1: "\xB9",
              ordm: "\xBA",
              raquo: "\xBB",
              frac14: "\xBC",
              frac12: "\xBD",
              frac34: "\xBE",
              iquest: "\xBF",
              Agrave: "\xC0",
              Aacute: "\xC1",
              Acirc: "\xC2",
              Atilde: "\xC3",
              Auml: "\xC4",
              Aring: "\xC5",
              AElig: "\xC6",
              Ccedil: "\xC7",
              Egrave: "\xC8",
              Eacute: "\xC9",
              Ecirc: "\xCA",
              Euml: "\xCB",
              Igrave: "\xCC",
              Iacute: "\xCD",
              Icirc: "\xCE",
              Iuml: "\xCF",
              ETH: "\xD0",
              Ntilde: "\xD1",
              Ograve: "\xD2",
              Oacute: "\xD3",
              Ocirc: "\xD4",
              Otilde: "\xD5",
              Ouml: "\xD6",
              times: "\xD7",
              Oslash: "\xD8",
              Ugrave: "\xD9",
              Uacute: "\xDA",
              Ucirc: "\xDB",
              Uuml: "\xDC",
              Yacute: "\xDD",
              THORN: "\xDE",
              szlig: "\xDF",
              agrave: "\xE0",
              aacute: "\xE1",
              acirc: "\xE2",
              atilde: "\xE3",
              auml: "\xE4",
              aring: "\xE5",
              aelig: "\xE6",
              ccedil: "\xE7",
              egrave: "\xE8",
              eacute: "\xE9",
              ecirc: "\xEA",
              euml: "\xEB",
              igrave: "\xEC",
              iacute: "\xED",
              icirc: "\xEE",
              iuml: "\xEF",
              eth: "\xF0",
              ntilde: "\xF1",
              ograve: "\xF2",
              oacute: "\xF3",
              ocirc: "\xF4",
              otilde: "\xF5",
              ouml: "\xF6",
              divide: "\xF7",
              oslash: "\xF8",
              ugrave: "\xF9",
              uacute: "\xFA",
              ucirc: "\xFB",
              uuml: "\xFC",
              yacute: "\xFD",
              thorn: "\xFE",
              yuml: "\xFF",
              OElig: "\u0152",
              oelig: "\u0153",
              Scaron: "\u0160",
              scaron: "\u0161",
              Yuml: "\u0178",
              fnof: "\u0192",
              circ: "\u02C6",
              tilde: "\u02DC",
              Alpha: "\u0391",
              Beta: "\u0392",
              Gamma: "\u0393",
              Delta: "\u0394",
              Epsilon: "\u0395",
              Zeta: "\u0396",
              Eta: "\u0397",
              Theta: "\u0398",
              Iota: "\u0399",
              Kappa: "\u039A",
              Lambda: "\u039B",
              Mu: "\u039C",
              Nu: "\u039D",
              Xi: "\u039E",
              Omicron: "\u039F",
              Pi: "\u03A0",
              Rho: "\u03A1",
              Sigma: "\u03A3",
              Tau: "\u03A4",
              Upsilon: "\u03A5",
              Phi: "\u03A6",
              Chi: "\u03A7",
              Psi: "\u03A8",
              Omega: "\u03A9",
              alpha: "\u03B1",
              beta: "\u03B2",
              gamma: "\u03B3",
              delta: "\u03B4",
              epsilon: "\u03B5",
              zeta: "\u03B6",
              eta: "\u03B7",
              theta: "\u03B8",
              iota: "\u03B9",
              kappa: "\u03BA",
              lambda: "\u03BB",
              mu: "\u03BC",
              nu: "\u03BD",
              xi: "\u03BE",
              omicron: "\u03BF",
              pi: "\u03C0",
              rho: "\u03C1",
              sigmaf: "\u03C2",
              sigma: "\u03C3",
              tau: "\u03C4",
              upsilon: "\u03C5",
              phi: "\u03C6",
              chi: "\u03C7",
              psi: "\u03C8",
              omega: "\u03C9",
              thetasym: "\u03D1",
              upsih: "\u03D2",
              piv: "\u03D6",
              ensp: "\u2002",
              emsp: "\u2003",
              thinsp: "\u2009",
              zwnj: "\u200C",
              zwj: "\u200D",
              lrm: "\u200E",
              rlm: "\u200F",
              ndash: "\u2013",
              mdash: "\u2014",
              lsquo: "\u2018",
              rsquo: "\u2019",
              sbquo: "\u201A",
              ldquo: "\u201C",
              rdquo: "\u201D",
              bdquo: "\u201E",
              dagger: "\u2020",
              Dagger: "\u2021",
              bull: "\u2022",
              hellip: "\u2026",
              permil: "\u2030",
              prime: "\u2032",
              Prime: "\u2033",
              lsaquo: "\u2039",
              rsaquo: "\u203A",
              oline: "\u203E",
              frasl: "\u2044",
              euro: "\u20AC",
              image: "\u2111",
              weierp: "\u2118",
              real: "\u211C",
              trade: "\u2122",
              alefsym: "\u2135",
              larr: "\u2190",
              uarr: "\u2191",
              rarr: "\u2192",
              darr: "\u2193",
              harr: "\u2194",
              crarr: "\u21B5",
              lArr: "\u21D0",
              uArr: "\u21D1",
              rArr: "\u21D2",
              dArr: "\u21D3",
              hArr: "\u21D4",
              forall: "\u2200",
              part: "\u2202",
              exist: "\u2203",
              empty: "\u2205",
              nabla: "\u2207",
              isin: "\u2208",
              notin: "\u2209",
              ni: "\u220B",
              prod: "\u220F",
              sum: "\u2211",
              minus: "\u2212",
              lowast: "\u2217",
              radic: "\u221A",
              prop: "\u221D",
              infin: "\u221E",
              ang: "\u2220",
              and: "\u2227",
              or: "\u2228",
              cap: "\u2229",
              cup: "\u222A",
              int: "\u222B",
              there4: "\u2234",
              sim: "\u223C",
              cong: "\u2245",
              asymp: "\u2248",
              ne: "\u2260",
              equiv: "\u2261",
              le: "\u2264",
              ge: "\u2265",
              sub: "\u2282",
              sup: "\u2283",
              nsub: "\u2284",
              sube: "\u2286",
              supe: "\u2287",
              oplus: "\u2295",
              otimes: "\u2297",
              perp: "\u22A5",
              sdot: "\u22C5",
              lceil: "\u2308",
              rceil: "\u2309",
              lfloor: "\u230A",
              rfloor: "\u230B",
              loz: "\u25CA",
              spades: "\u2660",
              clubs: "\u2663",
              hearts: "\u2665",
              diams: "\u2666",
              lang: "\u27E8",
              rang: "\u27E9"
            };
          },
          /* 15 */
          /***/
          function(module3, exports3, __webpack_require__) {
            "use strict";
            Object.defineProperty(exports3, "__esModule", { value: true });
            var error_handler_1 = __webpack_require__(10);
            var scanner_1 = __webpack_require__(12);
            var token_1 = __webpack_require__(13);
            var Reader = (function() {
              function Reader2() {
                this.values = [];
                this.curly = this.paren = -1;
              }
              __name(Reader2, "Reader");
              Reader2.prototype.beforeFunctionExpression = function(t) {
                return [
                  "(",
                  "{",
                  "[",
                  "in",
                  "typeof",
                  "instanceof",
                  "new",
                  "return",
                  "case",
                  "delete",
                  "throw",
                  "void",
                  // assignment operators
                  "=",
                  "+=",
                  "-=",
                  "*=",
                  "**=",
                  "/=",
                  "%=",
                  "<<=",
                  ">>=",
                  ">>>=",
                  "&=",
                  "|=",
                  "^=",
                  ",",
                  // binary/unary operators
                  "+",
                  "-",
                  "*",
                  "**",
                  "/",
                  "%",
                  "++",
                  "--",
                  "<<",
                  ">>",
                  ">>>",
                  "&",
                  "|",
                  "^",
                  "!",
                  "~",
                  "&&",
                  "||",
                  "?",
                  ":",
                  "===",
                  "==",
                  ">=",
                  "<=",
                  "<",
                  ">",
                  "!=",
                  "!=="
                ].indexOf(t) >= 0;
              };
              Reader2.prototype.isRegexStart = function() {
                var previous = this.values[this.values.length - 1];
                var regex = previous !== null;
                switch (previous) {
                  case "this":
                  case "]":
                    regex = false;
                    break;
                  case ")":
                    var keyword = this.values[this.paren - 1];
                    regex = keyword === "if" || keyword === "while" || keyword === "for" || keyword === "with";
                    break;
                  case "}":
                    regex = false;
                    if (this.values[this.curly - 3] === "function") {
                      var check = this.values[this.curly - 4];
                      regex = check ? !this.beforeFunctionExpression(check) : false;
                    } else if (this.values[this.curly - 4] === "function") {
                      var check = this.values[this.curly - 5];
                      regex = check ? !this.beforeFunctionExpression(check) : true;
                    }
                    break;
                  default:
                    break;
                }
                return regex;
              };
              Reader2.prototype.push = function(token) {
                if (token.type === 7 || token.type === 4) {
                  if (token.value === "{") {
                    this.curly = this.values.length;
                  } else if (token.value === "(") {
                    this.paren = this.values.length;
                  }
                  this.values.push(token.value);
                } else {
                  this.values.push(null);
                }
              };
              return Reader2;
            })();
            var Tokenizer = (function() {
              function Tokenizer2(code, config2) {
                this.errorHandler = new error_handler_1.ErrorHandler();
                this.errorHandler.tolerant = config2 ? typeof config2.tolerant === "boolean" && config2.tolerant : false;
                this.scanner = new scanner_1.Scanner(code, this.errorHandler);
                this.scanner.trackComment = config2 ? typeof config2.comment === "boolean" && config2.comment : false;
                this.trackRange = config2 ? typeof config2.range === "boolean" && config2.range : false;
                this.trackLoc = config2 ? typeof config2.loc === "boolean" && config2.loc : false;
                this.buffer = [];
                this.reader = new Reader();
              }
              __name(Tokenizer2, "Tokenizer");
              Tokenizer2.prototype.errors = function() {
                return this.errorHandler.errors;
              };
              Tokenizer2.prototype.getNextToken = function() {
                if (this.buffer.length === 0) {
                  var comments = this.scanner.scanComments();
                  if (this.scanner.trackComment) {
                    for (var i32 = 0; i32 < comments.length; ++i32) {
                      var e32 = comments[i32];
                      var value = this.scanner.source.slice(e32.slice[0], e32.slice[1]);
                      var comment = {
                        type: e32.multiLine ? "BlockComment" : "LineComment",
                        value
                      };
                      if (this.trackRange) {
                        comment.range = e32.range;
                      }
                      if (this.trackLoc) {
                        comment.loc = e32.loc;
                      }
                      this.buffer.push(comment);
                    }
                  }
                  if (!this.scanner.eof()) {
                    var loc = void 0;
                    if (this.trackLoc) {
                      loc = {
                        start: {
                          line: this.scanner.lineNumber,
                          column: this.scanner.index - this.scanner.lineStart
                        },
                        end: {}
                      };
                    }
                    var startRegex = this.scanner.source[this.scanner.index] === "/" && this.reader.isRegexStart();
                    var token = startRegex ? this.scanner.scanRegExp() : this.scanner.lex();
                    this.reader.push(token);
                    var entry = {
                      type: token_1.TokenName[token.type],
                      value: this.scanner.source.slice(token.start, token.end)
                    };
                    if (this.trackRange) {
                      entry.range = [token.start, token.end];
                    }
                    if (this.trackLoc) {
                      loc.end = {
                        line: this.scanner.lineNumber,
                        column: this.scanner.index - this.scanner.lineStart
                      };
                      entry.loc = loc;
                    }
                    if (token.type === 9) {
                      var pattern = token.pattern;
                      var flags = token.flags;
                      entry.regex = { pattern, flags };
                    }
                    this.buffer.push(entry);
                  }
                }
                return this.buffer.shift();
              };
              return Tokenizer2;
            })();
            exports3.Tokenizer = Tokenizer;
          }
          /******/
        ])
      );
    });
  }
});

// ../../node_modules/ast-types/lib/types.js
var require_types2 = __commonJS({
  "../../node_modules/ast-types/lib/types.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.Def = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var Op = Object.prototype;
    var objToStr = Op.toString;
    var hasOwn = Op.hasOwnProperty;
    var BaseType = (
      /** @class */
      (function() {
        function BaseType2() {
        }
        __name(BaseType2, "BaseType");
        BaseType2.prototype.assert = function(value, deep) {
          if (!this.check(value, deep)) {
            var str = shallowStringify(value);
            throw new Error(str + " does not match type " + this);
          }
          return true;
        };
        BaseType2.prototype.arrayOf = function() {
          var elemType = this;
          return new ArrayType(elemType);
        };
        return BaseType2;
      })()
    );
    var ArrayType = (
      /** @class */
      (function(_super) {
        tslib_1.__extends(ArrayType2, _super);
        function ArrayType2(elemType) {
          var _this = _super.call(this) || this;
          _this.elemType = elemType;
          _this.kind = "ArrayType";
          return _this;
        }
        __name(ArrayType2, "ArrayType");
        ArrayType2.prototype.toString = function() {
          return "[" + this.elemType + "]";
        };
        ArrayType2.prototype.check = function(value, deep) {
          var _this = this;
          return Array.isArray(value) && value.every(function(elem) {
            return _this.elemType.check(elem, deep);
          });
        };
        return ArrayType2;
      })(BaseType)
    );
    var IdentityType = (
      /** @class */
      (function(_super) {
        tslib_1.__extends(IdentityType2, _super);
        function IdentityType2(value) {
          var _this = _super.call(this) || this;
          _this.value = value;
          _this.kind = "IdentityType";
          return _this;
        }
        __name(IdentityType2, "IdentityType");
        IdentityType2.prototype.toString = function() {
          return String(this.value);
        };
        IdentityType2.prototype.check = function(value, deep) {
          var result2 = value === this.value;
          if (!result2 && typeof deep === "function") {
            deep(this, value);
          }
          return result2;
        };
        return IdentityType2;
      })(BaseType)
    );
    var ObjectType = (
      /** @class */
      (function(_super) {
        tslib_1.__extends(ObjectType2, _super);
        function ObjectType2(fields) {
          var _this = _super.call(this) || this;
          _this.fields = fields;
          _this.kind = "ObjectType";
          return _this;
        }
        __name(ObjectType2, "ObjectType");
        ObjectType2.prototype.toString = function() {
          return "{ " + this.fields.join(", ") + " }";
        };
        ObjectType2.prototype.check = function(value, deep) {
          return objToStr.call(value) === objToStr.call({}) && this.fields.every(function(field) {
            return field.type.check(value[field.name], deep);
          });
        };
        return ObjectType2;
      })(BaseType)
    );
    var OrType = (
      /** @class */
      (function(_super) {
        tslib_1.__extends(OrType2, _super);
        function OrType2(types2) {
          var _this = _super.call(this) || this;
          _this.types = types2;
          _this.kind = "OrType";
          return _this;
        }
        __name(OrType2, "OrType");
        OrType2.prototype.toString = function() {
          return this.types.join(" | ");
        };
        OrType2.prototype.check = function(value, deep) {
          return this.types.some(function(type) {
            return type.check(value, deep);
          });
        };
        return OrType2;
      })(BaseType)
    );
    var PredicateType = (
      /** @class */
      (function(_super) {
        tslib_1.__extends(PredicateType2, _super);
        function PredicateType2(name, predicate) {
          var _this = _super.call(this) || this;
          _this.name = name;
          _this.predicate = predicate;
          _this.kind = "PredicateType";
          return _this;
        }
        __name(PredicateType2, "PredicateType");
        PredicateType2.prototype.toString = function() {
          return this.name;
        };
        PredicateType2.prototype.check = function(value, deep) {
          var result2 = this.predicate(value, deep);
          if (!result2 && typeof deep === "function") {
            deep(this, value);
          }
          return result2;
        };
        return PredicateType2;
      })(BaseType)
    );
    var Def = (
      /** @class */
      (function() {
        function Def2(type, typeName) {
          this.type = type;
          this.typeName = typeName;
          this.baseNames = [];
          this.ownFields = /* @__PURE__ */ Object.create(null);
          this.allSupertypes = /* @__PURE__ */ Object.create(null);
          this.supertypeList = [];
          this.allFields = /* @__PURE__ */ Object.create(null);
          this.fieldNames = [];
          this.finalized = false;
          this.buildable = false;
          this.buildParams = [];
        }
        __name(Def2, "Def");
        Def2.prototype.isSupertypeOf = function(that) {
          if (that instanceof Def2) {
            if (this.finalized !== true || that.finalized !== true) {
              throw new Error("");
            }
            return hasOwn.call(that.allSupertypes, this.typeName);
          } else {
            throw new Error(that + " is not a Def");
          }
        };
        Def2.prototype.checkAllFields = function(value, deep) {
          var allFields = this.allFields;
          if (this.finalized !== true) {
            throw new Error("" + this.typeName);
          }
          function checkFieldByName(name) {
            var field = allFields[name];
            var type = field.type;
            var child = field.getValue(value);
            return type.check(child, deep);
          }
          __name(checkFieldByName, "checkFieldByName");
          return value !== null && typeof value === "object" && Object.keys(allFields).every(checkFieldByName);
        };
        Def2.prototype.bases = function() {
          var supertypeNames = [];
          for (var _i = 0; _i < arguments.length; _i++) {
            supertypeNames[_i] = arguments[_i];
          }
          var bases = this.baseNames;
          if (this.finalized) {
            if (supertypeNames.length !== bases.length) {
              throw new Error("");
            }
            for (var i32 = 0; i32 < supertypeNames.length; i32++) {
              if (supertypeNames[i32] !== bases[i32]) {
                throw new Error("");
              }
            }
            return this;
          }
          supertypeNames.forEach(function(baseName) {
            if (bases.indexOf(baseName) < 0) {
              bases.push(baseName);
            }
          });
          return this;
        };
        return Def2;
      })()
    );
    exports2.Def = Def;
    var Field6 = (
      /** @class */
      (function() {
        function Field7(name, type, defaultFn, hidden) {
          this.name = name;
          this.type = type;
          this.defaultFn = defaultFn;
          this.hidden = !!hidden;
        }
        __name(Field7, "Field");
        Field7.prototype.toString = function() {
          return JSON.stringify(this.name) + ": " + this.type;
        };
        Field7.prototype.getValue = function(obj) {
          var value = obj[this.name];
          if (typeof value !== "undefined") {
            return value;
          }
          if (typeof this.defaultFn === "function") {
            value = this.defaultFn.call(obj);
          }
          return value;
        };
        return Field7;
      })()
    );
    function shallowStringify(value) {
      if (Array.isArray(value)) {
        return "[" + value.map(shallowStringify).join(", ") + "]";
      }
      if (value && typeof value === "object") {
        return "{ " + Object.keys(value).map(function(key) {
          return key + ": " + value[key];
        }).join(", ") + " }";
      }
      return JSON.stringify(value);
    }
    __name(shallowStringify, "shallowStringify");
    function typesPlugin(_fork) {
      var Type = {
        or: /* @__PURE__ */ __name(function() {
          var types2 = [];
          for (var _i = 0; _i < arguments.length; _i++) {
            types2[_i] = arguments[_i];
          }
          return new OrType(types2.map(function(type) {
            return Type.from(type);
          }));
        }, "or"),
        from: /* @__PURE__ */ __name(function(value, name) {
          if (value instanceof ArrayType || value instanceof IdentityType || value instanceof ObjectType || value instanceof OrType || value instanceof PredicateType) {
            return value;
          }
          if (value instanceof Def) {
            return value.type;
          }
          if (isArray2.check(value)) {
            if (value.length !== 1) {
              throw new Error("only one element type is permitted for typed arrays");
            }
            return new ArrayType(Type.from(value[0]));
          }
          if (isObject3.check(value)) {
            return new ObjectType(Object.keys(value).map(function(name2) {
              return new Field6(name2, Type.from(value[name2], name2));
            }));
          }
          if (typeof value === "function") {
            var bicfIndex = builtInCtorFns.indexOf(value);
            if (bicfIndex >= 0) {
              return builtInCtorTypes[bicfIndex];
            }
            if (typeof name !== "string") {
              throw new Error("missing name");
            }
            return new PredicateType(name, value);
          }
          return new IdentityType(value);
        }, "from"),
        // Define a type whose name is registered in a namespace (the defCache) so
        // that future definitions will return the same type given the same name.
        // In particular, this system allows for circular and forward definitions.
        // The Def object d returned from Type.def may be used to configure the
        // type d.type by calling methods such as d.bases, d.build, and d.field.
        def: /* @__PURE__ */ __name(function(typeName) {
          return hasOwn.call(defCache, typeName) ? defCache[typeName] : defCache[typeName] = new DefImpl(typeName);
        }, "def"),
        hasDef: /* @__PURE__ */ __name(function(typeName) {
          return hasOwn.call(defCache, typeName);
        }, "hasDef")
      };
      var builtInCtorFns = [];
      var builtInCtorTypes = [];
      function defBuiltInType(name, example) {
        var objStr = objToStr.call(example);
        var type = new PredicateType(name, function(value) {
          return objToStr.call(value) === objStr;
        });
        if (example && typeof example.constructor === "function") {
          builtInCtorFns.push(example.constructor);
          builtInCtorTypes.push(type);
        }
        return type;
      }
      __name(defBuiltInType, "defBuiltInType");
      var isString = defBuiltInType("string", "truthy");
      var isFunction5 = defBuiltInType("function", function() {
      });
      var isArray2 = defBuiltInType("array", []);
      var isObject3 = defBuiltInType("object", {});
      var isRegExp = defBuiltInType("RegExp", /./);
      var isDate = defBuiltInType("Date", /* @__PURE__ */ new Date());
      var isNumber = defBuiltInType("number", 3);
      var isBoolean2 = defBuiltInType("boolean", true);
      var isNull = defBuiltInType("null", null);
      var isUndefined = defBuiltInType("undefined", void 0);
      var builtInTypes = {
        string: isString,
        function: isFunction5,
        array: isArray2,
        object: isObject3,
        RegExp: isRegExp,
        Date: isDate,
        number: isNumber,
        boolean: isBoolean2,
        null: isNull,
        undefined: isUndefined
      };
      var defCache = /* @__PURE__ */ Object.create(null);
      function defFromValue(value) {
        if (value && typeof value === "object") {
          var type = value.type;
          if (typeof type === "string" && hasOwn.call(defCache, type)) {
            var d32 = defCache[type];
            if (d32.finalized) {
              return d32;
            }
          }
        }
        return null;
      }
      __name(defFromValue, "defFromValue");
      var DefImpl = (
        /** @class */
        (function(_super) {
          tslib_1.__extends(DefImpl2, _super);
          function DefImpl2(typeName) {
            var _this = _super.call(this, new PredicateType(typeName, function(value, deep) {
              return _this.check(value, deep);
            }), typeName) || this;
            return _this;
          }
          __name(DefImpl2, "DefImpl");
          DefImpl2.prototype.check = function(value, deep) {
            if (this.finalized !== true) {
              throw new Error("prematurely checking unfinalized type " + this.typeName);
            }
            if (value === null || typeof value !== "object") {
              return false;
            }
            var vDef = defFromValue(value);
            if (!vDef) {
              if (this.typeName === "SourceLocation" || this.typeName === "Position") {
                return this.checkAllFields(value, deep);
              }
              return false;
            }
            if (deep && vDef === this) {
              return this.checkAllFields(value, deep);
            }
            if (!this.isSupertypeOf(vDef)) {
              return false;
            }
            if (!deep) {
              return true;
            }
            return vDef.checkAllFields(value, deep) && this.checkAllFields(value, false);
          };
          DefImpl2.prototype.build = function() {
            var _this = this;
            var buildParams = [];
            for (var _i = 0; _i < arguments.length; _i++) {
              buildParams[_i] = arguments[_i];
            }
            this.buildParams = buildParams;
            if (this.buildable) {
              return this;
            }
            this.field("type", String, function() {
              return _this.typeName;
            });
            this.buildable = true;
            var addParam = /* @__PURE__ */ __name(function(built, param, arg, isArgAvailable) {
              if (hasOwn.call(built, param))
                return;
              var all = _this.allFields;
              if (!hasOwn.call(all, param)) {
                throw new Error("" + param);
              }
              var field = all[param];
              var type = field.type;
              var value;
              if (isArgAvailable) {
                value = arg;
              } else if (field.defaultFn) {
                value = field.defaultFn.call(built);
              } else {
                var message2 = "no value or default function given for field " + JSON.stringify(param) + " of " + _this.typeName + "(" + _this.buildParams.map(function(name) {
                  return all[name];
                }).join(", ") + ")";
                throw new Error(message2);
              }
              if (!type.check(value)) {
                throw new Error(shallowStringify(value) + " does not match field " + field + " of type " + _this.typeName);
              }
              built[param] = value;
            }, "addParam");
            var builder = /* @__PURE__ */ __name(function() {
              var args = [];
              for (var _i2 = 0; _i2 < arguments.length; _i2++) {
                args[_i2] = arguments[_i2];
              }
              var argc = args.length;
              if (!_this.finalized) {
                throw new Error("attempting to instantiate unfinalized type " + _this.typeName);
              }
              var built = Object.create(nodePrototype);
              _this.buildParams.forEach(function(param, i32) {
                if (i32 < argc) {
                  addParam(built, param, args[i32], true);
                } else {
                  addParam(built, param, null, false);
                }
              });
              Object.keys(_this.allFields).forEach(function(param) {
                addParam(built, param, null, false);
              });
              if (built.type !== _this.typeName) {
                throw new Error("");
              }
              return built;
            }, "builder");
            builder.from = function(obj) {
              if (!_this.finalized) {
                throw new Error("attempting to instantiate unfinalized type " + _this.typeName);
              }
              var built = Object.create(nodePrototype);
              Object.keys(_this.allFields).forEach(function(param) {
                if (hasOwn.call(obj, param)) {
                  addParam(built, param, obj[param], true);
                } else {
                  addParam(built, param, null, false);
                }
              });
              if (built.type !== _this.typeName) {
                throw new Error("");
              }
              return built;
            };
            Object.defineProperty(builders, getBuilderName(this.typeName), {
              enumerable: true,
              value: builder
            });
            return this;
          };
          DefImpl2.prototype.field = function(name, type, defaultFn, hidden) {
            if (this.finalized) {
              console.error("Ignoring attempt to redefine field " + JSON.stringify(name) + " of finalized type " + JSON.stringify(this.typeName));
              return this;
            }
            this.ownFields[name] = new Field6(name, Type.from(type), defaultFn, hidden);
            return this;
          };
          DefImpl2.prototype.finalize = function() {
            var _this = this;
            if (!this.finalized) {
              var allFields = this.allFields;
              var allSupertypes = this.allSupertypes;
              this.baseNames.forEach(function(name) {
                var def = defCache[name];
                if (def instanceof Def) {
                  def.finalize();
                  extend(allFields, def.allFields);
                  extend(allSupertypes, def.allSupertypes);
                } else {
                  var message2 = "unknown supertype name " + JSON.stringify(name) + " for subtype " + JSON.stringify(_this.typeName);
                  throw new Error(message2);
                }
              });
              extend(allFields, this.ownFields);
              allSupertypes[this.typeName] = this;
              this.fieldNames.length = 0;
              for (var fieldName in allFields) {
                if (hasOwn.call(allFields, fieldName) && !allFields[fieldName].hidden) {
                  this.fieldNames.push(fieldName);
                }
              }
              Object.defineProperty(namedTypes, this.typeName, {
                enumerable: true,
                value: this.type
              });
              this.finalized = true;
              populateSupertypeList(this.typeName, this.supertypeList);
              if (this.buildable && this.supertypeList.lastIndexOf("Expression") >= 0) {
                wrapExpressionBuilderWithStatement(this.typeName);
              }
            }
          };
          return DefImpl2;
        })(Def)
      );
      function getSupertypeNames(typeName) {
        if (!hasOwn.call(defCache, typeName)) {
          throw new Error("");
        }
        var d32 = defCache[typeName];
        if (d32.finalized !== true) {
          throw new Error("");
        }
        return d32.supertypeList.slice(1);
      }
      __name(getSupertypeNames, "getSupertypeNames");
      function computeSupertypeLookupTable(candidates) {
        var table3 = {};
        var typeNames = Object.keys(defCache);
        var typeNameCount = typeNames.length;
        for (var i32 = 0; i32 < typeNameCount; ++i32) {
          var typeName = typeNames[i32];
          var d32 = defCache[typeName];
          if (d32.finalized !== true) {
            throw new Error("" + typeName);
          }
          for (var j32 = 0; j32 < d32.supertypeList.length; ++j32) {
            var superTypeName = d32.supertypeList[j32];
            if (hasOwn.call(candidates, superTypeName)) {
              table3[typeName] = superTypeName;
              break;
            }
          }
        }
        return table3;
      }
      __name(computeSupertypeLookupTable, "computeSupertypeLookupTable");
      var builders = /* @__PURE__ */ Object.create(null);
      var nodePrototype = {};
      function defineMethod(name, func) {
        var old = nodePrototype[name];
        if (isUndefined.check(func)) {
          delete nodePrototype[name];
        } else {
          isFunction5.assert(func);
          Object.defineProperty(nodePrototype, name, {
            enumerable: true,
            configurable: true,
            value: func
          });
        }
        return old;
      }
      __name(defineMethod, "defineMethod");
      function getBuilderName(typeName) {
        return typeName.replace(/^[A-Z]+/, function(upperCasePrefix) {
          var len = upperCasePrefix.length;
          switch (len) {
            case 0:
              return "";
            // If there's only one initial capital letter, just lower-case it.
            case 1:
              return upperCasePrefix.toLowerCase();
            default:
              return upperCasePrefix.slice(0, len - 1).toLowerCase() + upperCasePrefix.charAt(len - 1);
          }
        });
      }
      __name(getBuilderName, "getBuilderName");
      function getStatementBuilderName(typeName) {
        typeName = getBuilderName(typeName);
        return typeName.replace(/(Expression)?$/, "Statement");
      }
      __name(getStatementBuilderName, "getStatementBuilderName");
      var namedTypes = {};
      function getFieldNames(object) {
        var d32 = defFromValue(object);
        if (d32) {
          return d32.fieldNames.slice(0);
        }
        if ("type" in object) {
          throw new Error("did not recognize object of type " + JSON.stringify(object.type));
        }
        return Object.keys(object);
      }
      __name(getFieldNames, "getFieldNames");
      function getFieldValue(object, fieldName) {
        var d32 = defFromValue(object);
        if (d32) {
          var field = d32.allFields[fieldName];
          if (field) {
            return field.getValue(object);
          }
        }
        return object && object[fieldName];
      }
      __name(getFieldValue, "getFieldValue");
      function eachField(object, callback, context) {
        getFieldNames(object).forEach(function(name) {
          callback.call(this, name, getFieldValue(object, name));
        }, context);
      }
      __name(eachField, "eachField");
      function someField(object, callback, context) {
        return getFieldNames(object).some(function(name) {
          return callback.call(this, name, getFieldValue(object, name));
        }, context);
      }
      __name(someField, "someField");
      function wrapExpressionBuilderWithStatement(typeName) {
        var wrapperName = getStatementBuilderName(typeName);
        if (builders[wrapperName])
          return;
        var wrapped = builders[getBuilderName(typeName)];
        if (!wrapped)
          return;
        var builder = /* @__PURE__ */ __name(function() {
          var args = [];
          for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
          }
          return builders.expressionStatement(wrapped.apply(builders, args));
        }, "builder");
        builder.from = function() {
          var args = [];
          for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
          }
          return builders.expressionStatement(wrapped.from.apply(builders, args));
        };
        builders[wrapperName] = builder;
      }
      __name(wrapExpressionBuilderWithStatement, "wrapExpressionBuilderWithStatement");
      function populateSupertypeList(typeName, list3) {
        list3.length = 0;
        list3.push(typeName);
        var lastSeen = /* @__PURE__ */ Object.create(null);
        for (var pos = 0; pos < list3.length; ++pos) {
          typeName = list3[pos];
          var d32 = defCache[typeName];
          if (d32.finalized !== true) {
            throw new Error("");
          }
          if (hasOwn.call(lastSeen, typeName)) {
            delete list3[lastSeen[typeName]];
          }
          lastSeen[typeName] = pos;
          list3.push.apply(list3, d32.baseNames);
        }
        for (var to = 0, from = to, len = list3.length; from < len; ++from) {
          if (hasOwn.call(list3, from)) {
            list3[to++] = list3[from];
          }
        }
        list3.length = to;
      }
      __name(populateSupertypeList, "populateSupertypeList");
      function extend(into, from) {
        Object.keys(from).forEach(function(name) {
          into[name] = from[name];
        });
        return into;
      }
      __name(extend, "extend");
      function finalize() {
        Object.keys(defCache).forEach(function(name) {
          defCache[name].finalize();
        });
      }
      __name(finalize, "finalize");
      return {
        Type,
        builtInTypes,
        getSupertypeNames,
        computeSupertypeLookupTable,
        builders,
        defineMethod,
        getBuilderName,
        getStatementBuilderName,
        namedTypes,
        getFieldNames,
        getFieldValue,
        eachField,
        someField,
        finalize
      };
    }
    __name(typesPlugin, "typesPlugin");
    exports2.default = typesPlugin;
  }
});

// ../../node_modules/ast-types/lib/path.js
var require_path2 = __commonJS({
  "../../node_modules/ast-types/lib/path.js"(exports2, module2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var types_1 = tslib_1.__importDefault(require_types2());
    var Op = Object.prototype;
    var hasOwn = Op.hasOwnProperty;
    function pathPlugin(fork) {
      var types2 = fork.use(types_1.default);
      var isArray2 = types2.builtInTypes.array;
      var isNumber = types2.builtInTypes.number;
      var Path = /* @__PURE__ */ __name(function Path2(value, parentPath, name) {
        if (!(this instanceof Path2)) {
          throw new Error("Path constructor cannot be invoked without 'new'");
        }
        if (parentPath) {
          if (!(parentPath instanceof Path2)) {
            throw new Error("");
          }
        } else {
          parentPath = null;
          name = null;
        }
        this.value = value;
        this.parentPath = parentPath;
        this.name = name;
        this.__childCache = null;
      }, "Path");
      var Pp = Path.prototype;
      function getChildCache(path47) {
        return path47.__childCache || (path47.__childCache = /* @__PURE__ */ Object.create(null));
      }
      __name(getChildCache, "getChildCache");
      function getChildPath(path47, name) {
        var cache32 = getChildCache(path47);
        var actualChildValue = path47.getValueProperty(name);
        var childPath = cache32[name];
        if (!hasOwn.call(cache32, name) || // Ensure consistency between cache and reality.
        childPath.value !== actualChildValue) {
          childPath = cache32[name] = new path47.constructor(actualChildValue, path47, name);
        }
        return childPath;
      }
      __name(getChildPath, "getChildPath");
      Pp.getValueProperty = /* @__PURE__ */ __name(function getValueProperty(name) {
        return this.value[name];
      }, "getValueProperty");
      Pp.get = /* @__PURE__ */ __name(function get4() {
        var names = [];
        for (var _i = 0; _i < arguments.length; _i++) {
          names[_i] = arguments[_i];
        }
        var path47 = this;
        var count = names.length;
        for (var i32 = 0; i32 < count; ++i32) {
          path47 = getChildPath(path47, names[i32]);
        }
        return path47;
      }, "get");
      Pp.each = /* @__PURE__ */ __name(function each(callback, context) {
        var childPaths = [];
        var len = this.value.length;
        var i32 = 0;
        for (var i32 = 0; i32 < len; ++i32) {
          if (hasOwn.call(this.value, i32)) {
            childPaths[i32] = this.get(i32);
          }
        }
        context = context || this;
        for (i32 = 0; i32 < len; ++i32) {
          if (hasOwn.call(childPaths, i32)) {
            callback.call(context, childPaths[i32]);
          }
        }
      }, "each");
      Pp.map = /* @__PURE__ */ __name(function map5(callback, context) {
        var result2 = [];
        this.each(function(childPath) {
          result2.push(callback.call(this, childPath));
        }, context);
        return result2;
      }, "map");
      Pp.filter = /* @__PURE__ */ __name(function filter(callback, context) {
        var result2 = [];
        this.each(function(childPath) {
          if (callback.call(this, childPath)) {
            result2.push(childPath);
          }
        }, context);
        return result2;
      }, "filter");
      function emptyMoves() {
      }
      __name(emptyMoves, "emptyMoves");
      function getMoves(path47, offset, start, end) {
        isArray2.assert(path47.value);
        if (offset === 0) {
          return emptyMoves;
        }
        var length = path47.value.length;
        if (length < 1) {
          return emptyMoves;
        }
        var argc = arguments.length;
        if (argc === 2) {
          start = 0;
          end = length;
        } else if (argc === 3) {
          start = Math.max(start, 0);
          end = length;
        } else {
          start = Math.max(start, 0);
          end = Math.min(end, length);
        }
        isNumber.assert(start);
        isNumber.assert(end);
        var moves = /* @__PURE__ */ Object.create(null);
        var cache32 = getChildCache(path47);
        for (var i32 = start; i32 < end; ++i32) {
          if (hasOwn.call(path47.value, i32)) {
            var childPath = path47.get(i32);
            if (childPath.name !== i32) {
              throw new Error("");
            }
            var newIndex = i32 + offset;
            childPath.name = newIndex;
            moves[newIndex] = childPath;
            delete cache32[i32];
          }
        }
        delete cache32.length;
        return function() {
          for (var newIndex2 in moves) {
            var childPath2 = moves[newIndex2];
            if (childPath2.name !== +newIndex2) {
              throw new Error("");
            }
            cache32[newIndex2] = childPath2;
            path47.value[newIndex2] = childPath2.value;
          }
        };
      }
      __name(getMoves, "getMoves");
      Pp.shift = /* @__PURE__ */ __name(function shift() {
        var move = getMoves(this, -1);
        var result2 = this.value.shift();
        move();
        return result2;
      }, "shift");
      Pp.unshift = /* @__PURE__ */ __name(function unshift() {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
          args[_i] = arguments[_i];
        }
        var move = getMoves(this, args.length);
        var result2 = this.value.unshift.apply(this.value, args);
        move();
        return result2;
      }, "unshift");
      Pp.push = /* @__PURE__ */ __name(function push() {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
          args[_i] = arguments[_i];
        }
        isArray2.assert(this.value);
        delete getChildCache(this).length;
        return this.value.push.apply(this.value, args);
      }, "push");
      Pp.pop = /* @__PURE__ */ __name(function pop() {
        isArray2.assert(this.value);
        var cache32 = getChildCache(this);
        delete cache32[this.value.length - 1];
        delete cache32.length;
        return this.value.pop();
      }, "pop");
      Pp.insertAt = /* @__PURE__ */ __name(function insertAt(index) {
        var argc = arguments.length;
        var move = getMoves(this, argc - 1, index);
        if (move === emptyMoves && argc <= 1) {
          return this;
        }
        index = Math.max(index, 0);
        for (var i32 = 1; i32 < argc; ++i32) {
          this.value[index + i32 - 1] = arguments[i32];
        }
        move();
        return this;
      }, "insertAt");
      Pp.insertBefore = /* @__PURE__ */ __name(function insertBefore() {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
          args[_i] = arguments[_i];
        }
        var pp = this.parentPath;
        var argc = args.length;
        var insertAtArgs = [this.name];
        for (var i32 = 0; i32 < argc; ++i32) {
          insertAtArgs.push(args[i32]);
        }
        return pp.insertAt.apply(pp, insertAtArgs);
      }, "insertBefore");
      Pp.insertAfter = /* @__PURE__ */ __name(function insertAfter() {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
          args[_i] = arguments[_i];
        }
        var pp = this.parentPath;
        var argc = args.length;
        var insertAtArgs = [this.name + 1];
        for (var i32 = 0; i32 < argc; ++i32) {
          insertAtArgs.push(args[i32]);
        }
        return pp.insertAt.apply(pp, insertAtArgs);
      }, "insertAfter");
      function repairRelationshipWithParent(path47) {
        if (!(path47 instanceof Path)) {
          throw new Error("");
        }
        var pp = path47.parentPath;
        if (!pp) {
          return path47;
        }
        var parentValue = pp.value;
        var parentCache = getChildCache(pp);
        if (parentValue[path47.name] === path47.value) {
          parentCache[path47.name] = path47;
        } else if (isArray2.check(parentValue)) {
          var i32 = parentValue.indexOf(path47.value);
          if (i32 >= 0) {
            parentCache[path47.name = i32] = path47;
          }
        } else {
          parentValue[path47.name] = path47.value;
          parentCache[path47.name] = path47;
        }
        if (parentValue[path47.name] !== path47.value) {
          throw new Error("");
        }
        if (path47.parentPath.get(path47.name) !== path47) {
          throw new Error("");
        }
        return path47;
      }
      __name(repairRelationshipWithParent, "repairRelationshipWithParent");
      Pp.replace = /* @__PURE__ */ __name(function replace(replacement) {
        var results = [];
        var parentValue = this.parentPath.value;
        var parentCache = getChildCache(this.parentPath);
        var count = arguments.length;
        repairRelationshipWithParent(this);
        if (isArray2.check(parentValue)) {
          var originalLength = parentValue.length;
          var move = getMoves(this.parentPath, count - 1, this.name + 1);
          var spliceArgs = [this.name, 1];
          for (var i32 = 0; i32 < count; ++i32) {
            spliceArgs.push(arguments[i32]);
          }
          var splicedOut = parentValue.splice.apply(parentValue, spliceArgs);
          if (splicedOut[0] !== this.value) {
            throw new Error("");
          }
          if (parentValue.length !== originalLength - 1 + count) {
            throw new Error("");
          }
          move();
          if (count === 0) {
            delete this.value;
            delete parentCache[this.name];
            this.__childCache = null;
          } else {
            if (parentValue[this.name] !== replacement) {
              throw new Error("");
            }
            if (this.value !== replacement) {
              this.value = replacement;
              this.__childCache = null;
            }
            for (i32 = 0; i32 < count; ++i32) {
              results.push(this.parentPath.get(this.name + i32));
            }
            if (results[0] !== this) {
              throw new Error("");
            }
          }
        } else if (count === 1) {
          if (this.value !== replacement) {
            this.__childCache = null;
          }
          this.value = parentValue[this.name] = replacement;
          results.push(this);
        } else if (count === 0) {
          delete parentValue[this.name];
          delete this.value;
          this.__childCache = null;
        } else {
          throw new Error("Could not replace path");
        }
        return results;
      }, "replace");
      return Path;
    }
    __name(pathPlugin, "pathPlugin");
    exports2.default = pathPlugin;
    module2.exports = exports2["default"];
  }
});

// ../../node_modules/ast-types/lib/scope.js
var require_scope = __commonJS({
  "../../node_modules/ast-types/lib/scope.js"(exports2, module2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var types_1 = tslib_1.__importDefault(require_types2());
    var hasOwn = Object.prototype.hasOwnProperty;
    function scopePlugin(fork) {
      var types2 = fork.use(types_1.default);
      var Type = types2.Type;
      var namedTypes = types2.namedTypes;
      var Node2 = namedTypes.Node;
      var Expression = namedTypes.Expression;
      var isArray2 = types2.builtInTypes.array;
      var b32 = types2.builders;
      var Scope = /* @__PURE__ */ __name(function Scope2(path47, parentScope) {
        if (!(this instanceof Scope2)) {
          throw new Error("Scope constructor cannot be invoked without 'new'");
        }
        ScopeType.assert(path47.value);
        var depth;
        if (parentScope) {
          if (!(parentScope instanceof Scope2)) {
            throw new Error("");
          }
          depth = parentScope.depth + 1;
        } else {
          parentScope = null;
          depth = 0;
        }
        Object.defineProperties(this, {
          path: { value: path47 },
          node: { value: path47.value },
          isGlobal: { value: !parentScope, enumerable: true },
          depth: { value: depth },
          parent: { value: parentScope },
          bindings: { value: {} },
          types: { value: {} }
        });
      }, "Scope");
      var scopeTypes = [
        // Program nodes introduce global scopes.
        namedTypes.Program,
        // Function is the supertype of FunctionExpression,
        // FunctionDeclaration, ArrowExpression, etc.
        namedTypes.Function,
        // In case you didn't know, the caught parameter shadows any variable
        // of the same name in an outer scope.
        namedTypes.CatchClause
      ];
      var ScopeType = Type.or.apply(Type, scopeTypes);
      Scope.isEstablishedBy = function(node) {
        return ScopeType.check(node);
      };
      var Sp = Scope.prototype;
      Sp.didScan = false;
      Sp.declares = function(name) {
        this.scan();
        return hasOwn.call(this.bindings, name);
      };
      Sp.declaresType = function(name) {
        this.scan();
        return hasOwn.call(this.types, name);
      };
      Sp.declareTemporary = function(prefix) {
        if (prefix) {
          if (!/^[a-z$_]/i.test(prefix)) {
            throw new Error("");
          }
        } else {
          prefix = "t$";
        }
        prefix += this.depth.toString(36) + "$";
        this.scan();
        var index = 0;
        while (this.declares(prefix + index)) {
          ++index;
        }
        var name = prefix + index;
        return this.bindings[name] = types2.builders.identifier(name);
      };
      Sp.injectTemporary = function(identifier, init) {
        identifier || (identifier = this.declareTemporary());
        var bodyPath = this.path.get("body");
        if (namedTypes.BlockStatement.check(bodyPath.value)) {
          bodyPath = bodyPath.get("body");
        }
        bodyPath.unshift(b32.variableDeclaration("var", [b32.variableDeclarator(identifier, init || null)]));
        return identifier;
      };
      Sp.scan = function(force) {
        if (force || !this.didScan) {
          for (var name in this.bindings) {
            delete this.bindings[name];
          }
          scanScope(this.path, this.bindings, this.types);
          this.didScan = true;
        }
      };
      Sp.getBindings = function() {
        this.scan();
        return this.bindings;
      };
      Sp.getTypes = function() {
        this.scan();
        return this.types;
      };
      function scanScope(path47, bindings, scopeTypes2) {
        var node = path47.value;
        ScopeType.assert(node);
        if (namedTypes.CatchClause.check(node)) {
          var param = path47.get("param");
          if (param.value) {
            addPattern(param, bindings);
          }
        } else {
          recursiveScanScope(path47, bindings, scopeTypes2);
        }
      }
      __name(scanScope, "scanScope");
      function recursiveScanScope(path47, bindings, scopeTypes2) {
        var node = path47.value;
        if (path47.parent && namedTypes.FunctionExpression.check(path47.parent.node) && path47.parent.node.id) {
          addPattern(path47.parent.get("id"), bindings);
        }
        if (!node) {
        } else if (isArray2.check(node)) {
          path47.each(function(childPath) {
            recursiveScanChild(childPath, bindings, scopeTypes2);
          });
        } else if (namedTypes.Function.check(node)) {
          path47.get("params").each(function(paramPath) {
            addPattern(paramPath, bindings);
          });
          recursiveScanChild(path47.get("body"), bindings, scopeTypes2);
        } else if (namedTypes.TypeAlias && namedTypes.TypeAlias.check(node) || namedTypes.InterfaceDeclaration && namedTypes.InterfaceDeclaration.check(node) || namedTypes.TSTypeAliasDeclaration && namedTypes.TSTypeAliasDeclaration.check(node) || namedTypes.TSInterfaceDeclaration && namedTypes.TSInterfaceDeclaration.check(node)) {
          addTypePattern(path47.get("id"), scopeTypes2);
        } else if (namedTypes.VariableDeclarator.check(node)) {
          addPattern(path47.get("id"), bindings);
          recursiveScanChild(path47.get("init"), bindings, scopeTypes2);
        } else if (node.type === "ImportSpecifier" || node.type === "ImportNamespaceSpecifier" || node.type === "ImportDefaultSpecifier") {
          addPattern(
            // Esprima used to use the .name field to refer to the local
            // binding identifier for ImportSpecifier nodes, but .id for
            // ImportNamespaceSpecifier and ImportDefaultSpecifier nodes.
            // ESTree/Acorn/ESpree use .local for all three node types.
            path47.get(node.local ? "local" : node.name ? "name" : "id"),
            bindings
          );
        } else if (Node2.check(node) && !Expression.check(node)) {
          types2.eachField(node, function(name, child) {
            var childPath = path47.get(name);
            if (!pathHasValue(childPath, child)) {
              throw new Error("");
            }
            recursiveScanChild(childPath, bindings, scopeTypes2);
          });
        }
      }
      __name(recursiveScanScope, "recursiveScanScope");
      function pathHasValue(path47, value) {
        if (path47.value === value) {
          return true;
        }
        if (Array.isArray(path47.value) && path47.value.length === 0 && Array.isArray(value) && value.length === 0) {
          return true;
        }
        return false;
      }
      __name(pathHasValue, "pathHasValue");
      function recursiveScanChild(path47, bindings, scopeTypes2) {
        var node = path47.value;
        if (!node || Expression.check(node)) {
        } else if (namedTypes.FunctionDeclaration.check(node) && node.id !== null) {
          addPattern(path47.get("id"), bindings);
        } else if (namedTypes.ClassDeclaration && namedTypes.ClassDeclaration.check(node)) {
          addPattern(path47.get("id"), bindings);
        } else if (ScopeType.check(node)) {
          if (namedTypes.CatchClause.check(node) && // TODO Broaden this to accept any pattern.
          namedTypes.Identifier.check(node.param)) {
            var catchParamName = node.param.name;
            var hadBinding = hasOwn.call(bindings, catchParamName);
            recursiveScanScope(path47.get("body"), bindings, scopeTypes2);
            if (!hadBinding) {
              delete bindings[catchParamName];
            }
          }
        } else {
          recursiveScanScope(path47, bindings, scopeTypes2);
        }
      }
      __name(recursiveScanChild, "recursiveScanChild");
      function addPattern(patternPath, bindings) {
        var pattern = patternPath.value;
        namedTypes.Pattern.assert(pattern);
        if (namedTypes.Identifier.check(pattern)) {
          if (hasOwn.call(bindings, pattern.name)) {
            bindings[pattern.name].push(patternPath);
          } else {
            bindings[pattern.name] = [patternPath];
          }
        } else if (namedTypes.AssignmentPattern && namedTypes.AssignmentPattern.check(pattern)) {
          addPattern(patternPath.get("left"), bindings);
        } else if (namedTypes.ObjectPattern && namedTypes.ObjectPattern.check(pattern)) {
          patternPath.get("properties").each(function(propertyPath) {
            var property = propertyPath.value;
            if (namedTypes.Pattern.check(property)) {
              addPattern(propertyPath, bindings);
            } else if (namedTypes.Property.check(property)) {
              addPattern(propertyPath.get("value"), bindings);
            } else if (namedTypes.SpreadProperty && namedTypes.SpreadProperty.check(property)) {
              addPattern(propertyPath.get("argument"), bindings);
            }
          });
        } else if (namedTypes.ArrayPattern && namedTypes.ArrayPattern.check(pattern)) {
          patternPath.get("elements").each(function(elementPath) {
            var element = elementPath.value;
            if (namedTypes.Pattern.check(element)) {
              addPattern(elementPath, bindings);
            } else if (namedTypes.SpreadElement && namedTypes.SpreadElement.check(element)) {
              addPattern(elementPath.get("argument"), bindings);
            }
          });
        } else if (namedTypes.PropertyPattern && namedTypes.PropertyPattern.check(pattern)) {
          addPattern(patternPath.get("pattern"), bindings);
        } else if (namedTypes.SpreadElementPattern && namedTypes.SpreadElementPattern.check(pattern) || namedTypes.SpreadPropertyPattern && namedTypes.SpreadPropertyPattern.check(pattern)) {
          addPattern(patternPath.get("argument"), bindings);
        }
      }
      __name(addPattern, "addPattern");
      function addTypePattern(patternPath, types3) {
        var pattern = patternPath.value;
        namedTypes.Pattern.assert(pattern);
        if (namedTypes.Identifier.check(pattern)) {
          if (hasOwn.call(types3, pattern.name)) {
            types3[pattern.name].push(patternPath);
          } else {
            types3[pattern.name] = [patternPath];
          }
        }
      }
      __name(addTypePattern, "addTypePattern");
      Sp.lookup = function(name) {
        for (var scope = this; scope; scope = scope.parent)
          if (scope.declares(name))
            break;
        return scope;
      };
      Sp.lookupType = function(name) {
        for (var scope = this; scope; scope = scope.parent)
          if (scope.declaresType(name))
            break;
        return scope;
      };
      Sp.getGlobalScope = function() {
        var scope = this;
        while (!scope.isGlobal)
          scope = scope.parent;
        return scope;
      };
      return Scope;
    }
    __name(scopePlugin, "scopePlugin");
    exports2.default = scopePlugin;
    module2.exports = exports2["default"];
  }
});

// ../../node_modules/ast-types/lib/node-path.js
var require_node_path = __commonJS({
  "../../node_modules/ast-types/lib/node-path.js"(exports2, module2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var types_1 = tslib_1.__importDefault(require_types2());
    var path_1 = tslib_1.__importDefault(require_path2());
    var scope_1 = tslib_1.__importDefault(require_scope());
    function nodePathPlugin(fork) {
      var types2 = fork.use(types_1.default);
      var n10 = types2.namedTypes;
      var b32 = types2.builders;
      var isNumber = types2.builtInTypes.number;
      var isArray2 = types2.builtInTypes.array;
      var Path = fork.use(path_1.default);
      var Scope = fork.use(scope_1.default);
      var NodePath = /* @__PURE__ */ __name(function NodePath2(value, parentPath, name) {
        if (!(this instanceof NodePath2)) {
          throw new Error("NodePath constructor cannot be invoked without 'new'");
        }
        Path.call(this, value, parentPath, name);
      }, "NodePath");
      var NPp = NodePath.prototype = Object.create(Path.prototype, {
        constructor: {
          value: NodePath,
          enumerable: false,
          writable: true,
          configurable: true
        }
      });
      Object.defineProperties(NPp, {
        node: {
          get: /* @__PURE__ */ __name(function() {
            Object.defineProperty(this, "node", {
              configurable: true,
              value: this._computeNode()
            });
            return this.node;
          }, "get")
        },
        parent: {
          get: /* @__PURE__ */ __name(function() {
            Object.defineProperty(this, "parent", {
              configurable: true,
              value: this._computeParent()
            });
            return this.parent;
          }, "get")
        },
        scope: {
          get: /* @__PURE__ */ __name(function() {
            Object.defineProperty(this, "scope", {
              configurable: true,
              value: this._computeScope()
            });
            return this.scope;
          }, "get")
        }
      });
      NPp.replace = function() {
        delete this.node;
        delete this.parent;
        delete this.scope;
        return Path.prototype.replace.apply(this, arguments);
      };
      NPp.prune = function() {
        var remainingNodePath = this.parent;
        this.replace();
        return cleanUpNodesAfterPrune(remainingNodePath);
      };
      NPp._computeNode = function() {
        var value = this.value;
        if (n10.Node.check(value)) {
          return value;
        }
        var pp = this.parentPath;
        return pp && pp.node || null;
      };
      NPp._computeParent = function() {
        var value = this.value;
        var pp = this.parentPath;
        if (!n10.Node.check(value)) {
          while (pp && !n10.Node.check(pp.value)) {
            pp = pp.parentPath;
          }
          if (pp) {
            pp = pp.parentPath;
          }
        }
        while (pp && !n10.Node.check(pp.value)) {
          pp = pp.parentPath;
        }
        return pp || null;
      };
      NPp._computeScope = function() {
        var value = this.value;
        var pp = this.parentPath;
        var scope = pp && pp.scope;
        if (n10.Node.check(value) && Scope.isEstablishedBy(value)) {
          scope = new Scope(this, scope);
        }
        return scope || null;
      };
      NPp.getValueProperty = function(name) {
        return types2.getFieldValue(this.value, name);
      };
      NPp.needsParens = function(assumeExpressionContext) {
        var pp = this.parentPath;
        if (!pp) {
          return false;
        }
        var node = this.value;
        if (!n10.Expression.check(node)) {
          return false;
        }
        if (node.type === "Identifier") {
          return false;
        }
        while (!n10.Node.check(pp.value)) {
          pp = pp.parentPath;
          if (!pp) {
            return false;
          }
        }
        var parent = pp.value;
        switch (node.type) {
          case "UnaryExpression":
          case "SpreadElement":
          case "SpreadProperty":
            return parent.type === "MemberExpression" && this.name === "object" && parent.object === node;
          case "BinaryExpression":
          case "LogicalExpression":
            switch (parent.type) {
              case "CallExpression":
                return this.name === "callee" && parent.callee === node;
              case "UnaryExpression":
              case "SpreadElement":
              case "SpreadProperty":
                return true;
              case "MemberExpression":
                return this.name === "object" && parent.object === node;
              case "BinaryExpression":
              case "LogicalExpression": {
                var n_1 = node;
                var po = parent.operator;
                var pp_1 = PRECEDENCE[po];
                var no = n_1.operator;
                var np = PRECEDENCE[no];
                if (pp_1 > np) {
                  return true;
                }
                if (pp_1 === np && this.name === "right") {
                  if (parent.right !== n_1) {
                    throw new Error("Nodes must be equal");
                  }
                  return true;
                }
              }
              default:
                return false;
            }
          case "SequenceExpression":
            switch (parent.type) {
              case "ForStatement":
                return false;
              case "ExpressionStatement":
                return this.name !== "expression";
              default:
                return true;
            }
          case "YieldExpression":
            switch (parent.type) {
              case "BinaryExpression":
              case "LogicalExpression":
              case "UnaryExpression":
              case "SpreadElement":
              case "SpreadProperty":
              case "CallExpression":
              case "MemberExpression":
              case "NewExpression":
              case "ConditionalExpression":
              case "YieldExpression":
                return true;
              default:
                return false;
            }
          case "Literal":
            return parent.type === "MemberExpression" && isNumber.check(node.value) && this.name === "object" && parent.object === node;
          case "AssignmentExpression":
          case "ConditionalExpression":
            switch (parent.type) {
              case "UnaryExpression":
              case "SpreadElement":
              case "SpreadProperty":
              case "BinaryExpression":
              case "LogicalExpression":
                return true;
              case "CallExpression":
                return this.name === "callee" && parent.callee === node;
              case "ConditionalExpression":
                return this.name === "test" && parent.test === node;
              case "MemberExpression":
                return this.name === "object" && parent.object === node;
              default:
                return false;
            }
          default:
            if (parent.type === "NewExpression" && this.name === "callee" && parent.callee === node) {
              return containsCallExpression(node);
            }
        }
        if (assumeExpressionContext !== true && !this.canBeFirstInStatement() && this.firstInStatement())
          return true;
        return false;
      };
      function isBinary(node) {
        return n10.BinaryExpression.check(node) || n10.LogicalExpression.check(node);
      }
      __name(isBinary, "isBinary");
      function isUnaryLike(node) {
        return n10.UnaryExpression.check(node) || n10.SpreadElement && n10.SpreadElement.check(node) || n10.SpreadProperty && n10.SpreadProperty.check(node);
      }
      __name(isUnaryLike, "isUnaryLike");
      var PRECEDENCE = {};
      [
        ["||"],
        ["&&"],
        ["|"],
        ["^"],
        ["&"],
        ["==", "===", "!=", "!=="],
        ["<", ">", "<=", ">=", "in", "instanceof"],
        [">>", "<<", ">>>"],
        ["+", "-"],
        ["*", "/", "%"]
      ].forEach(function(tier, i32) {
        tier.forEach(function(op3) {
          PRECEDENCE[op3] = i32;
        });
      });
      function containsCallExpression(node) {
        if (n10.CallExpression.check(node)) {
          return true;
        }
        if (isArray2.check(node)) {
          return node.some(containsCallExpression);
        }
        if (n10.Node.check(node)) {
          return types2.someField(node, function(_name, child) {
            return containsCallExpression(child);
          });
        }
        return false;
      }
      __name(containsCallExpression, "containsCallExpression");
      NPp.canBeFirstInStatement = function() {
        var node = this.node;
        return !n10.FunctionExpression.check(node) && !n10.ObjectExpression.check(node);
      };
      NPp.firstInStatement = function() {
        return firstInStatement(this);
      };
      function firstInStatement(path47) {
        for (var node, parent; path47.parent; path47 = path47.parent) {
          node = path47.node;
          parent = path47.parent.node;
          if (n10.BlockStatement.check(parent) && path47.parent.name === "body" && path47.name === 0) {
            if (parent.body[0] !== node) {
              throw new Error("Nodes must be equal");
            }
            return true;
          }
          if (n10.ExpressionStatement.check(parent) && path47.name === "expression") {
            if (parent.expression !== node) {
              throw new Error("Nodes must be equal");
            }
            return true;
          }
          if (n10.SequenceExpression.check(parent) && path47.parent.name === "expressions" && path47.name === 0) {
            if (parent.expressions[0] !== node) {
              throw new Error("Nodes must be equal");
            }
            continue;
          }
          if (n10.CallExpression.check(parent) && path47.name === "callee") {
            if (parent.callee !== node) {
              throw new Error("Nodes must be equal");
            }
            continue;
          }
          if (n10.MemberExpression.check(parent) && path47.name === "object") {
            if (parent.object !== node) {
              throw new Error("Nodes must be equal");
            }
            continue;
          }
          if (n10.ConditionalExpression.check(parent) && path47.name === "test") {
            if (parent.test !== node) {
              throw new Error("Nodes must be equal");
            }
            continue;
          }
          if (isBinary(parent) && path47.name === "left") {
            if (parent.left !== node) {
              throw new Error("Nodes must be equal");
            }
            continue;
          }
          if (n10.UnaryExpression.check(parent) && !parent.prefix && path47.name === "argument") {
            if (parent.argument !== node) {
              throw new Error("Nodes must be equal");
            }
            continue;
          }
          return false;
        }
        return true;
      }
      __name(firstInStatement, "firstInStatement");
      function cleanUpNodesAfterPrune(remainingNodePath) {
        if (n10.VariableDeclaration.check(remainingNodePath.node)) {
          var declarations = remainingNodePath.get("declarations").value;
          if (!declarations || declarations.length === 0) {
            return remainingNodePath.prune();
          }
        } else if (n10.ExpressionStatement.check(remainingNodePath.node)) {
          if (!remainingNodePath.get("expression").value) {
            return remainingNodePath.prune();
          }
        } else if (n10.IfStatement.check(remainingNodePath.node)) {
          cleanUpIfStatementAfterPrune(remainingNodePath);
        }
        return remainingNodePath;
      }
      __name(cleanUpNodesAfterPrune, "cleanUpNodesAfterPrune");
      function cleanUpIfStatementAfterPrune(ifStatement) {
        var testExpression = ifStatement.get("test").value;
        var alternate = ifStatement.get("alternate").value;
        var consequent = ifStatement.get("consequent").value;
        if (!consequent && !alternate) {
          var testExpressionStatement = b32.expressionStatement(testExpression);
          ifStatement.replace(testExpressionStatement);
        } else if (!consequent && alternate) {
          var negatedTestExpression = b32.unaryExpression("!", testExpression, true);
          if (n10.UnaryExpression.check(testExpression) && testExpression.operator === "!") {
            negatedTestExpression = testExpression.argument;
          }
          ifStatement.get("test").replace(negatedTestExpression);
          ifStatement.get("consequent").replace(alternate);
          ifStatement.get("alternate").replace();
        }
      }
      __name(cleanUpIfStatementAfterPrune, "cleanUpIfStatementAfterPrune");
      return NodePath;
    }
    __name(nodePathPlugin, "nodePathPlugin");
    exports2.default = nodePathPlugin;
    module2.exports = exports2["default"];
  }
});

// ../../node_modules/ast-types/lib/path-visitor.js
var require_path_visitor = __commonJS({
  "../../node_modules/ast-types/lib/path-visitor.js"(exports2, module2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var types_1 = tslib_1.__importDefault(require_types2());
    var node_path_1 = tslib_1.__importDefault(require_node_path());
    var hasOwn = Object.prototype.hasOwnProperty;
    function pathVisitorPlugin(fork) {
      var types2 = fork.use(types_1.default);
      var NodePath = fork.use(node_path_1.default);
      var isArray2 = types2.builtInTypes.array;
      var isObject3 = types2.builtInTypes.object;
      var isFunction5 = types2.builtInTypes.function;
      var undefined2;
      var PathVisitor = /* @__PURE__ */ __name(function PathVisitor2() {
        if (!(this instanceof PathVisitor2)) {
          throw new Error("PathVisitor constructor cannot be invoked without 'new'");
        }
        this._reusableContextStack = [];
        this._methodNameTable = computeMethodNameTable(this);
        this._shouldVisitComments = hasOwn.call(this._methodNameTable, "Block") || hasOwn.call(this._methodNameTable, "Line");
        this.Context = makeContextConstructor(this);
        this._visiting = false;
        this._changeReported = false;
      }, "PathVisitor");
      function computeMethodNameTable(visitor) {
        var typeNames = /* @__PURE__ */ Object.create(null);
        for (var methodName in visitor) {
          if (/^visit[A-Z]/.test(methodName)) {
            typeNames[methodName.slice("visit".length)] = true;
          }
        }
        var supertypeTable = types2.computeSupertypeLookupTable(typeNames);
        var methodNameTable = /* @__PURE__ */ Object.create(null);
        var typeNameKeys = Object.keys(supertypeTable);
        var typeNameCount = typeNameKeys.length;
        for (var i32 = 0; i32 < typeNameCount; ++i32) {
          var typeName = typeNameKeys[i32];
          methodName = "visit" + supertypeTable[typeName];
          if (isFunction5.check(visitor[methodName])) {
            methodNameTable[typeName] = methodName;
          }
        }
        return methodNameTable;
      }
      __name(computeMethodNameTable, "computeMethodNameTable");
      PathVisitor.fromMethodsObject = /* @__PURE__ */ __name(function fromMethodsObject(methods) {
        if (methods instanceof PathVisitor) {
          return methods;
        }
        if (!isObject3.check(methods)) {
          return new PathVisitor();
        }
        var Visitor = /* @__PURE__ */ __name(function Visitor2() {
          if (!(this instanceof Visitor2)) {
            throw new Error("Visitor constructor cannot be invoked without 'new'");
          }
          PathVisitor.call(this);
        }, "Visitor");
        var Vp = Visitor.prototype = Object.create(PVp);
        Vp.constructor = Visitor;
        extend(Vp, methods);
        extend(Visitor, PathVisitor);
        isFunction5.assert(Visitor.fromMethodsObject);
        isFunction5.assert(Visitor.visit);
        return new Visitor();
      }, "fromMethodsObject");
      function extend(target, source) {
        for (var property in source) {
          if (hasOwn.call(source, property)) {
            target[property] = source[property];
          }
        }
        return target;
      }
      __name(extend, "extend");
      PathVisitor.visit = /* @__PURE__ */ __name(function visit(node, methods) {
        return PathVisitor.fromMethodsObject(methods).visit(node);
      }, "visit");
      var PVp = PathVisitor.prototype;
      PVp.visit = function() {
        if (this._visiting) {
          throw new Error("Recursively calling visitor.visit(path) resets visitor state. Try this.visit(path) or this.traverse(path) instead.");
        }
        this._visiting = true;
        this._changeReported = false;
        this._abortRequested = false;
        var argc = arguments.length;
        var args = new Array(argc);
        for (var i32 = 0; i32 < argc; ++i32) {
          args[i32] = arguments[i32];
        }
        if (!(args[0] instanceof NodePath)) {
          args[0] = new NodePath({ root: args[0] }).get("root");
        }
        this.reset.apply(this, args);
        var didNotThrow;
        try {
          var root32 = this.visitWithoutReset(args[0]);
          didNotThrow = true;
        } finally {
          this._visiting = false;
          if (!didNotThrow && this._abortRequested) {
            return args[0].value;
          }
        }
        return root32;
      };
      PVp.AbortRequest = /* @__PURE__ */ __name(function AbortRequest() {
      }, "AbortRequest");
      PVp.abort = function() {
        var visitor = this;
        visitor._abortRequested = true;
        var request4 = new visitor.AbortRequest();
        request4.cancel = function() {
          visitor._abortRequested = false;
        };
        throw request4;
      };
      PVp.reset = function(_path) {
      };
      PVp.visitWithoutReset = function(path47) {
        if (this instanceof this.Context) {
          return this.visitor.visitWithoutReset(path47);
        }
        if (!(path47 instanceof NodePath)) {
          throw new Error("");
        }
        var value = path47.value;
        var methodName = value && typeof value === "object" && typeof value.type === "string" && this._methodNameTable[value.type];
        if (methodName) {
          var context = this.acquireContext(path47);
          try {
            return context.invokeVisitorMethod(methodName);
          } finally {
            this.releaseContext(context);
          }
        } else {
          return visitChildren(path47, this);
        }
      };
      function visitChildren(path47, visitor) {
        if (!(path47 instanceof NodePath)) {
          throw new Error("");
        }
        if (!(visitor instanceof PathVisitor)) {
          throw new Error("");
        }
        var value = path47.value;
        if (isArray2.check(value)) {
          path47.each(visitor.visitWithoutReset, visitor);
        } else if (!isObject3.check(value)) {
        } else {
          var childNames = types2.getFieldNames(value);
          if (visitor._shouldVisitComments && value.comments && childNames.indexOf("comments") < 0) {
            childNames.push("comments");
          }
          var childCount = childNames.length;
          var childPaths = [];
          for (var i32 = 0; i32 < childCount; ++i32) {
            var childName = childNames[i32];
            if (!hasOwn.call(value, childName)) {
              value[childName] = types2.getFieldValue(value, childName);
            }
            childPaths.push(path47.get(childName));
          }
          for (var i32 = 0; i32 < childCount; ++i32) {
            visitor.visitWithoutReset(childPaths[i32]);
          }
        }
        return path47.value;
      }
      __name(visitChildren, "visitChildren");
      PVp.acquireContext = function(path47) {
        if (this._reusableContextStack.length === 0) {
          return new this.Context(path47);
        }
        return this._reusableContextStack.pop().reset(path47);
      };
      PVp.releaseContext = function(context) {
        if (!(context instanceof this.Context)) {
          throw new Error("");
        }
        this._reusableContextStack.push(context);
        context.currentPath = null;
      };
      PVp.reportChanged = function() {
        this._changeReported = true;
      };
      PVp.wasChangeReported = function() {
        return this._changeReported;
      };
      function makeContextConstructor(visitor) {
        function Context2(path47) {
          if (!(this instanceof Context2)) {
            throw new Error("");
          }
          if (!(this instanceof PathVisitor)) {
            throw new Error("");
          }
          if (!(path47 instanceof NodePath)) {
            throw new Error("");
          }
          Object.defineProperty(this, "visitor", {
            value: visitor,
            writable: false,
            enumerable: true,
            configurable: false
          });
          this.currentPath = path47;
          this.needToCallTraverse = true;
          Object.seal(this);
        }
        __name(Context2, "Context");
        if (!(visitor instanceof PathVisitor)) {
          throw new Error("");
        }
        var Cp = Context2.prototype = Object.create(visitor);
        Cp.constructor = Context2;
        extend(Cp, sharedContextProtoMethods);
        return Context2;
      }
      __name(makeContextConstructor, "makeContextConstructor");
      var sharedContextProtoMethods = /* @__PURE__ */ Object.create(null);
      sharedContextProtoMethods.reset = /* @__PURE__ */ __name(function reset6(path47) {
        if (!(this instanceof this.Context)) {
          throw new Error("");
        }
        if (!(path47 instanceof NodePath)) {
          throw new Error("");
        }
        this.currentPath = path47;
        this.needToCallTraverse = true;
        return this;
      }, "reset");
      sharedContextProtoMethods.invokeVisitorMethod = /* @__PURE__ */ __name(function invokeVisitorMethod(methodName) {
        if (!(this instanceof this.Context)) {
          throw new Error("");
        }
        if (!(this.currentPath instanceof NodePath)) {
          throw new Error("");
        }
        var result2 = this.visitor[methodName].call(this, this.currentPath);
        if (result2 === false) {
          this.needToCallTraverse = false;
        } else if (result2 !== undefined2) {
          this.currentPath = this.currentPath.replace(result2)[0];
          if (this.needToCallTraverse) {
            this.traverse(this.currentPath);
          }
        }
        if (this.needToCallTraverse !== false) {
          throw new Error("Must either call this.traverse or return false in " + methodName);
        }
        var path47 = this.currentPath;
        return path47 && path47.value;
      }, "invokeVisitorMethod");
      sharedContextProtoMethods.traverse = /* @__PURE__ */ __name(function traverse(path47, newVisitor) {
        if (!(this instanceof this.Context)) {
          throw new Error("");
        }
        if (!(path47 instanceof NodePath)) {
          throw new Error("");
        }
        if (!(this.currentPath instanceof NodePath)) {
          throw new Error("");
        }
        this.needToCallTraverse = false;
        return visitChildren(path47, PathVisitor.fromMethodsObject(newVisitor || this.visitor));
      }, "traverse");
      sharedContextProtoMethods.visit = /* @__PURE__ */ __name(function visit(path47, newVisitor) {
        if (!(this instanceof this.Context)) {
          throw new Error("");
        }
        if (!(path47 instanceof NodePath)) {
          throw new Error("");
        }
        if (!(this.currentPath instanceof NodePath)) {
          throw new Error("");
        }
        this.needToCallTraverse = false;
        return PathVisitor.fromMethodsObject(newVisitor || this.visitor).visitWithoutReset(path47);
      }, "visit");
      sharedContextProtoMethods.reportChanged = /* @__PURE__ */ __name(function reportChanged() {
        this.visitor.reportChanged();
      }, "reportChanged");
      sharedContextProtoMethods.abort = /* @__PURE__ */ __name(function abort() {
        this.needToCallTraverse = false;
        this.visitor.abort();
      }, "abort");
      return PathVisitor;
    }
    __name(pathVisitorPlugin, "pathVisitorPlugin");
    exports2.default = pathVisitorPlugin;
    module2.exports = exports2["default"];
  }
});

// ../../node_modules/ast-types/lib/equiv.js
var require_equiv = __commonJS({
  "../../node_modules/ast-types/lib/equiv.js"(exports2, module2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var types_1 = tslib_1.__importDefault(require_types2());
    function default_1(fork) {
      var types2 = fork.use(types_1.default);
      var getFieldNames = types2.getFieldNames;
      var getFieldValue = types2.getFieldValue;
      var isArray2 = types2.builtInTypes.array;
      var isObject3 = types2.builtInTypes.object;
      var isDate = types2.builtInTypes.Date;
      var isRegExp = types2.builtInTypes.RegExp;
      var hasOwn = Object.prototype.hasOwnProperty;
      function astNodesAreEquivalent(a32, b32, problemPath) {
        if (isArray2.check(problemPath)) {
          problemPath.length = 0;
        } else {
          problemPath = null;
        }
        return areEquivalent(a32, b32, problemPath);
      }
      __name(astNodesAreEquivalent, "astNodesAreEquivalent");
      astNodesAreEquivalent.assert = function(a32, b32) {
        var problemPath = [];
        if (!astNodesAreEquivalent(a32, b32, problemPath)) {
          if (problemPath.length === 0) {
            if (a32 !== b32) {
              throw new Error("Nodes must be equal");
            }
          } else {
            throw new Error("Nodes differ in the following path: " + problemPath.map(subscriptForProperty).join(""));
          }
        }
      };
      function subscriptForProperty(property) {
        if (/[_$a-z][_$a-z0-9]*/i.test(property)) {
          return "." + property;
        }
        return "[" + JSON.stringify(property) + "]";
      }
      __name(subscriptForProperty, "subscriptForProperty");
      function areEquivalent(a32, b32, problemPath) {
        if (a32 === b32) {
          return true;
        }
        if (isArray2.check(a32)) {
          return arraysAreEquivalent(a32, b32, problemPath);
        }
        if (isObject3.check(a32)) {
          return objectsAreEquivalent(a32, b32, problemPath);
        }
        if (isDate.check(a32)) {
          return isDate.check(b32) && +a32 === +b32;
        }
        if (isRegExp.check(a32)) {
          return isRegExp.check(b32) && (a32.source === b32.source && a32.global === b32.global && a32.multiline === b32.multiline && a32.ignoreCase === b32.ignoreCase);
        }
        return a32 == b32;
      }
      __name(areEquivalent, "areEquivalent");
      function arraysAreEquivalent(a32, b32, problemPath) {
        isArray2.assert(a32);
        var aLength = a32.length;
        if (!isArray2.check(b32) || b32.length !== aLength) {
          if (problemPath) {
            problemPath.push("length");
          }
          return false;
        }
        for (var i32 = 0; i32 < aLength; ++i32) {
          if (problemPath) {
            problemPath.push(i32);
          }
          if (i32 in a32 !== i32 in b32) {
            return false;
          }
          if (!areEquivalent(a32[i32], b32[i32], problemPath)) {
            return false;
          }
          if (problemPath) {
            var problemPathTail = problemPath.pop();
            if (problemPathTail !== i32) {
              throw new Error("" + problemPathTail);
            }
          }
        }
        return true;
      }
      __name(arraysAreEquivalent, "arraysAreEquivalent");
      function objectsAreEquivalent(a32, b32, problemPath) {
        isObject3.assert(a32);
        if (!isObject3.check(b32)) {
          return false;
        }
        if (a32.type !== b32.type) {
          if (problemPath) {
            problemPath.push("type");
          }
          return false;
        }
        var aNames = getFieldNames(a32);
        var aNameCount = aNames.length;
        var bNames = getFieldNames(b32);
        var bNameCount = bNames.length;
        if (aNameCount === bNameCount) {
          for (var i32 = 0; i32 < aNameCount; ++i32) {
            var name = aNames[i32];
            var aChild = getFieldValue(a32, name);
            var bChild = getFieldValue(b32, name);
            if (problemPath) {
              problemPath.push(name);
            }
            if (!areEquivalent(aChild, bChild, problemPath)) {
              return false;
            }
            if (problemPath) {
              var problemPathTail = problemPath.pop();
              if (problemPathTail !== name) {
                throw new Error("" + problemPathTail);
              }
            }
          }
          return true;
        }
        if (!problemPath) {
          return false;
        }
        var seenNames = /* @__PURE__ */ Object.create(null);
        for (i32 = 0; i32 < aNameCount; ++i32) {
          seenNames[aNames[i32]] = true;
        }
        for (i32 = 0; i32 < bNameCount; ++i32) {
          name = bNames[i32];
          if (!hasOwn.call(seenNames, name)) {
            problemPath.push(name);
            return false;
          }
          delete seenNames[name];
        }
        for (name in seenNames) {
          problemPath.push(name);
          break;
        }
        return false;
      }
      __name(objectsAreEquivalent, "objectsAreEquivalent");
      return astNodesAreEquivalent;
    }
    __name(default_1, "default_1");
    exports2.default = default_1;
    module2.exports = exports2["default"];
  }
});

// ../../node_modules/ast-types/fork.js
var require_fork = __commonJS({
  "../../node_modules/ast-types/fork.js"(exports2, module2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var types_1 = tslib_1.__importDefault(require_types2());
    var path_visitor_1 = tslib_1.__importDefault(require_path_visitor());
    var equiv_1 = tslib_1.__importDefault(require_equiv());
    var path_1 = tslib_1.__importDefault(require_path2());
    var node_path_1 = tslib_1.__importDefault(require_node_path());
    function default_1(defs) {
      var fork = createFork();
      var types2 = fork.use(types_1.default);
      defs.forEach(fork.use);
      types2.finalize();
      var PathVisitor = fork.use(path_visitor_1.default);
      return {
        Type: types2.Type,
        builtInTypes: types2.builtInTypes,
        namedTypes: types2.namedTypes,
        builders: types2.builders,
        defineMethod: types2.defineMethod,
        getFieldNames: types2.getFieldNames,
        getFieldValue: types2.getFieldValue,
        eachField: types2.eachField,
        someField: types2.someField,
        getSupertypeNames: types2.getSupertypeNames,
        getBuilderName: types2.getBuilderName,
        astNodesAreEquivalent: fork.use(equiv_1.default),
        finalize: types2.finalize,
        Path: fork.use(path_1.default),
        NodePath: fork.use(node_path_1.default),
        PathVisitor,
        use: fork.use,
        visit: PathVisitor.visit
      };
    }
    __name(default_1, "default_1");
    exports2.default = default_1;
    function createFork() {
      var used = [];
      var usedResult = [];
      function use(plugin) {
        var idx = used.indexOf(plugin);
        if (idx === -1) {
          idx = used.length;
          used.push(plugin);
          usedResult[idx] = plugin(fork);
        }
        return usedResult[idx];
      }
      __name(use, "use");
      var fork = { use };
      return fork;
    }
    __name(createFork, "createFork");
    module2.exports = exports2["default"];
  }
});

// ../../node_modules/ast-types/lib/shared.js
var require_shared = __commonJS({
  "../../node_modules/ast-types/lib/shared.js"(exports2, module2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var types_1 = tslib_1.__importDefault(require_types2());
    function default_1(fork) {
      var types2 = fork.use(types_1.default);
      var Type = types2.Type;
      var builtin = types2.builtInTypes;
      var isNumber = builtin.number;
      function geq(than) {
        return Type.from(function(value) {
          return isNumber.check(value) && value >= than;
        }, isNumber + " >= " + than);
      }
      __name(geq, "geq");
      ;
      var defaults = {
        // Functions were used because (among other reasons) that's the most
        // elegant way to allow for the emptyArray one always to give a new
        // array instance.
        "null": /* @__PURE__ */ __name(function() {
          return null;
        }, "null"),
        "emptyArray": /* @__PURE__ */ __name(function() {
          return [];
        }, "emptyArray"),
        "false": /* @__PURE__ */ __name(function() {
          return false;
        }, "false"),
        "true": /* @__PURE__ */ __name(function() {
          return true;
        }, "true"),
        "undefined": /* @__PURE__ */ __name(function() {
        }, "undefined"),
        "use strict": /* @__PURE__ */ __name(function() {
          return "use strict";
        }, "use strict")
      };
      var naiveIsPrimitive = Type.or(builtin.string, builtin.number, builtin.boolean, builtin.null, builtin.undefined);
      var isPrimitive = Type.from(function(value) {
        if (value === null)
          return true;
        var type = typeof value;
        if (type === "object" || type === "function") {
          return false;
        }
        return true;
      }, naiveIsPrimitive.toString());
      return {
        geq,
        defaults,
        isPrimitive
      };
    }
    __name(default_1, "default_1");
    exports2.default = default_1;
    module2.exports = exports2["default"];
  }
});

// ../../node_modules/ast-types/def/core.js
var require_core = __commonJS({
  "../../node_modules/ast-types/def/core.js"(exports2, module2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var types_1 = tslib_1.__importDefault(require_types2());
    var shared_1 = tslib_1.__importDefault(require_shared());
    function default_1(fork) {
      var types2 = fork.use(types_1.default);
      var Type = types2.Type;
      var def = Type.def;
      var or = Type.or;
      var shared = fork.use(shared_1.default);
      var defaults = shared.defaults;
      var geq = shared.geq;
      def("Printable").field("loc", or(def("SourceLocation"), null), defaults["null"], true);
      def("Node").bases("Printable").field("type", String).field("comments", or([def("Comment")], null), defaults["null"], true);
      def("SourceLocation").field("start", def("Position")).field("end", def("Position")).field("source", or(String, null), defaults["null"]);
      def("Position").field("line", geq(1)).field("column", geq(0));
      def("File").bases("Node").build("program", "name").field("program", def("Program")).field("name", or(String, null), defaults["null"]);
      def("Program").bases("Node").build("body").field("body", [def("Statement")]);
      def("Function").bases("Node").field("id", or(def("Identifier"), null), defaults["null"]).field("params", [def("Pattern")]).field("body", def("BlockStatement")).field("generator", Boolean, defaults["false"]).field("async", Boolean, defaults["false"]);
      def("Statement").bases("Node");
      def("EmptyStatement").bases("Statement").build();
      def("BlockStatement").bases("Statement").build("body").field("body", [def("Statement")]);
      def("ExpressionStatement").bases("Statement").build("expression").field("expression", def("Expression"));
      def("IfStatement").bases("Statement").build("test", "consequent", "alternate").field("test", def("Expression")).field("consequent", def("Statement")).field("alternate", or(def("Statement"), null), defaults["null"]);
      def("LabeledStatement").bases("Statement").build("label", "body").field("label", def("Identifier")).field("body", def("Statement"));
      def("BreakStatement").bases("Statement").build("label").field("label", or(def("Identifier"), null), defaults["null"]);
      def("ContinueStatement").bases("Statement").build("label").field("label", or(def("Identifier"), null), defaults["null"]);
      def("WithStatement").bases("Statement").build("object", "body").field("object", def("Expression")).field("body", def("Statement"));
      def("SwitchStatement").bases("Statement").build("discriminant", "cases", "lexical").field("discriminant", def("Expression")).field("cases", [def("SwitchCase")]).field("lexical", Boolean, defaults["false"]);
      def("ReturnStatement").bases("Statement").build("argument").field("argument", or(def("Expression"), null));
      def("ThrowStatement").bases("Statement").build("argument").field("argument", def("Expression"));
      def("TryStatement").bases("Statement").build("block", "handler", "finalizer").field("block", def("BlockStatement")).field("handler", or(def("CatchClause"), null), function() {
        return this.handlers && this.handlers[0] || null;
      }).field("handlers", [def("CatchClause")], function() {
        return this.handler ? [this.handler] : [];
      }, true).field("guardedHandlers", [def("CatchClause")], defaults.emptyArray).field("finalizer", or(def("BlockStatement"), null), defaults["null"]);
      def("CatchClause").bases("Node").build("param", "guard", "body").field("param", or(def("Pattern"), null), defaults["null"]).field("guard", or(def("Expression"), null), defaults["null"]).field("body", def("BlockStatement"));
      def("WhileStatement").bases("Statement").build("test", "body").field("test", def("Expression")).field("body", def("Statement"));
      def("DoWhileStatement").bases("Statement").build("body", "test").field("body", def("Statement")).field("test", def("Expression"));
      def("ForStatement").bases("Statement").build("init", "test", "update", "body").field("init", or(def("VariableDeclaration"), def("Expression"), null)).field("test", or(def("Expression"), null)).field("update", or(def("Expression"), null)).field("body", def("Statement"));
      def("ForInStatement").bases("Statement").build("left", "right", "body").field("left", or(def("VariableDeclaration"), def("Expression"))).field("right", def("Expression")).field("body", def("Statement"));
      def("DebuggerStatement").bases("Statement").build();
      def("Declaration").bases("Statement");
      def("FunctionDeclaration").bases("Function", "Declaration").build("id", "params", "body").field("id", def("Identifier"));
      def("FunctionExpression").bases("Function", "Expression").build("id", "params", "body");
      def("VariableDeclaration").bases("Declaration").build("kind", "declarations").field("kind", or("var", "let", "const")).field("declarations", [def("VariableDeclarator")]);
      def("VariableDeclarator").bases("Node").build("id", "init").field("id", def("Pattern")).field("init", or(def("Expression"), null), defaults["null"]);
      def("Expression").bases("Node");
      def("ThisExpression").bases("Expression").build();
      def("ArrayExpression").bases("Expression").build("elements").field("elements", [or(def("Expression"), null)]);
      def("ObjectExpression").bases("Expression").build("properties").field("properties", [def("Property")]);
      def("Property").bases("Node").build("kind", "key", "value").field("kind", or("init", "get", "set")).field("key", or(def("Literal"), def("Identifier"))).field("value", def("Expression"));
      def("SequenceExpression").bases("Expression").build("expressions").field("expressions", [def("Expression")]);
      var UnaryOperator = or("-", "+", "!", "~", "typeof", "void", "delete");
      def("UnaryExpression").bases("Expression").build("operator", "argument", "prefix").field("operator", UnaryOperator).field("argument", def("Expression")).field("prefix", Boolean, defaults["true"]);
      var BinaryOperator = or(
        "==",
        "!=",
        "===",
        "!==",
        "<",
        "<=",
        ">",
        ">=",
        "<<",
        ">>",
        ">>>",
        "+",
        "-",
        "*",
        "/",
        "%",
        "**",
        "&",
        // TODO Missing from the Parser API.
        "|",
        "^",
        "in",
        "instanceof"
      );
      def("BinaryExpression").bases("Expression").build("operator", "left", "right").field("operator", BinaryOperator).field("left", def("Expression")).field("right", def("Expression"));
      var AssignmentOperator = or("=", "+=", "-=", "*=", "/=", "%=", "<<=", ">>=", ">>>=", "|=", "^=", "&=");
      def("AssignmentExpression").bases("Expression").build("operator", "left", "right").field("operator", AssignmentOperator).field("left", or(def("Pattern"), def("MemberExpression"))).field("right", def("Expression"));
      var UpdateOperator = or("++", "--");
      def("UpdateExpression").bases("Expression").build("operator", "argument", "prefix").field("operator", UpdateOperator).field("argument", def("Expression")).field("prefix", Boolean);
      var LogicalOperator = or("||", "&&");
      def("LogicalExpression").bases("Expression").build("operator", "left", "right").field("operator", LogicalOperator).field("left", def("Expression")).field("right", def("Expression"));
      def("ConditionalExpression").bases("Expression").build("test", "consequent", "alternate").field("test", def("Expression")).field("consequent", def("Expression")).field("alternate", def("Expression"));
      def("NewExpression").bases("Expression").build("callee", "arguments").field("callee", def("Expression")).field("arguments", [def("Expression")]);
      def("CallExpression").bases("Expression").build("callee", "arguments").field("callee", def("Expression")).field("arguments", [def("Expression")]);
      def("MemberExpression").bases("Expression").build("object", "property", "computed").field("object", def("Expression")).field("property", or(def("Identifier"), def("Expression"))).field("computed", Boolean, function() {
        var type = this.property.type;
        if (type === "Literal" || type === "MemberExpression" || type === "BinaryExpression") {
          return true;
        }
        return false;
      });
      def("Pattern").bases("Node");
      def("SwitchCase").bases("Node").build("test", "consequent").field("test", or(def("Expression"), null)).field("consequent", [def("Statement")]);
      def("Identifier").bases("Expression", "Pattern").build("name").field("name", String).field("optional", Boolean, defaults["false"]);
      def("Literal").bases("Expression").build("value").field("value", or(String, Boolean, null, Number, RegExp)).field("regex", or({
        pattern: String,
        flags: String
      }, null), function() {
        if (this.value instanceof RegExp) {
          var flags = "";
          if (this.value.ignoreCase)
            flags += "i";
          if (this.value.multiline)
            flags += "m";
          if (this.value.global)
            flags += "g";
          return {
            pattern: this.value.source,
            flags
          };
        }
        return null;
      });
      def("Comment").bases("Printable").field("value", String).field("leading", Boolean, defaults["true"]).field("trailing", Boolean, defaults["false"]);
    }
    __name(default_1, "default_1");
    exports2.default = default_1;
    module2.exports = exports2["default"];
  }
});

// ../../node_modules/ast-types/def/es6.js
var require_es6 = __commonJS({
  "../../node_modules/ast-types/def/es6.js"(exports2, module2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var core_1 = tslib_1.__importDefault(require_core());
    var types_1 = tslib_1.__importDefault(require_types2());
    var shared_1 = tslib_1.__importDefault(require_shared());
    function default_1(fork) {
      fork.use(core_1.default);
      var types2 = fork.use(types_1.default);
      var def = types2.Type.def;
      var or = types2.Type.or;
      var defaults = fork.use(shared_1.default).defaults;
      def("Function").field("generator", Boolean, defaults["false"]).field("expression", Boolean, defaults["false"]).field("defaults", [or(def("Expression"), null)], defaults.emptyArray).field("rest", or(def("Identifier"), null), defaults["null"]);
      def("RestElement").bases("Pattern").build("argument").field("argument", def("Pattern")).field(
        "typeAnnotation",
        // for Babylon. Flow parser puts it on the identifier
        or(def("TypeAnnotation"), def("TSTypeAnnotation"), null),
        defaults["null"]
      );
      def("SpreadElementPattern").bases("Pattern").build("argument").field("argument", def("Pattern"));
      def("FunctionDeclaration").build("id", "params", "body", "generator", "expression");
      def("FunctionExpression").build("id", "params", "body", "generator", "expression");
      def("ArrowFunctionExpression").bases("Function", "Expression").build("params", "body", "expression").field("id", null, defaults["null"]).field("body", or(def("BlockStatement"), def("Expression"))).field("generator", false, defaults["false"]);
      def("ForOfStatement").bases("Statement").build("left", "right", "body").field("left", or(def("VariableDeclaration"), def("Pattern"))).field("right", def("Expression")).field("body", def("Statement"));
      def("YieldExpression").bases("Expression").build("argument", "delegate").field("argument", or(def("Expression"), null)).field("delegate", Boolean, defaults["false"]);
      def("GeneratorExpression").bases("Expression").build("body", "blocks", "filter").field("body", def("Expression")).field("blocks", [def("ComprehensionBlock")]).field("filter", or(def("Expression"), null));
      def("ComprehensionExpression").bases("Expression").build("body", "blocks", "filter").field("body", def("Expression")).field("blocks", [def("ComprehensionBlock")]).field("filter", or(def("Expression"), null));
      def("ComprehensionBlock").bases("Node").build("left", "right", "each").field("left", def("Pattern")).field("right", def("Expression")).field("each", Boolean);
      def("Property").field("key", or(def("Literal"), def("Identifier"), def("Expression"))).field("value", or(def("Expression"), def("Pattern"))).field("method", Boolean, defaults["false"]).field("shorthand", Boolean, defaults["false"]).field("computed", Boolean, defaults["false"]);
      def("ObjectProperty").field("shorthand", Boolean, defaults["false"]);
      def("PropertyPattern").bases("Pattern").build("key", "pattern").field("key", or(def("Literal"), def("Identifier"), def("Expression"))).field("pattern", def("Pattern")).field("computed", Boolean, defaults["false"]);
      def("ObjectPattern").bases("Pattern").build("properties").field("properties", [or(def("PropertyPattern"), def("Property"))]);
      def("ArrayPattern").bases("Pattern").build("elements").field("elements", [or(def("Pattern"), null)]);
      def("MethodDefinition").bases("Declaration").build("kind", "key", "value", "static").field("kind", or("constructor", "method", "get", "set")).field("key", def("Expression")).field("value", def("Function")).field("computed", Boolean, defaults["false"]).field("static", Boolean, defaults["false"]);
      def("SpreadElement").bases("Node").build("argument").field("argument", def("Expression"));
      def("ArrayExpression").field("elements", [or(def("Expression"), def("SpreadElement"), def("RestElement"), null)]);
      def("NewExpression").field("arguments", [or(def("Expression"), def("SpreadElement"))]);
      def("CallExpression").field("arguments", [or(def("Expression"), def("SpreadElement"))]);
      def("AssignmentPattern").bases("Pattern").build("left", "right").field("left", def("Pattern")).field("right", def("Expression"));
      var ClassBodyElement = or(def("MethodDefinition"), def("VariableDeclarator"), def("ClassPropertyDefinition"), def("ClassProperty"));
      def("ClassProperty").bases("Declaration").build("key").field("key", or(def("Literal"), def("Identifier"), def("Expression"))).field("computed", Boolean, defaults["false"]);
      def("ClassPropertyDefinition").bases("Declaration").build("definition").field("definition", ClassBodyElement);
      def("ClassBody").bases("Declaration").build("body").field("body", [ClassBodyElement]);
      def("ClassDeclaration").bases("Declaration").build("id", "body", "superClass").field("id", or(def("Identifier"), null)).field("body", def("ClassBody")).field("superClass", or(def("Expression"), null), defaults["null"]);
      def("ClassExpression").bases("Expression").build("id", "body", "superClass").field("id", or(def("Identifier"), null), defaults["null"]).field("body", def("ClassBody")).field("superClass", or(def("Expression"), null), defaults["null"]);
      def("Specifier").bases("Node");
      def("ModuleSpecifier").bases("Specifier").field("local", or(def("Identifier"), null), defaults["null"]).field("id", or(def("Identifier"), null), defaults["null"]).field("name", or(def("Identifier"), null), defaults["null"]);
      def("ImportSpecifier").bases("ModuleSpecifier").build("id", "name");
      def("ImportNamespaceSpecifier").bases("ModuleSpecifier").build("id");
      def("ImportDefaultSpecifier").bases("ModuleSpecifier").build("id");
      def("ImportDeclaration").bases("Declaration").build("specifiers", "source", "importKind").field("specifiers", [or(def("ImportSpecifier"), def("ImportNamespaceSpecifier"), def("ImportDefaultSpecifier"))], defaults.emptyArray).field("source", def("Literal")).field("importKind", or("value", "type"), function() {
        return "value";
      });
      def("TaggedTemplateExpression").bases("Expression").build("tag", "quasi").field("tag", def("Expression")).field("quasi", def("TemplateLiteral"));
      def("TemplateLiteral").bases("Expression").build("quasis", "expressions").field("quasis", [def("TemplateElement")]).field("expressions", [def("Expression")]);
      def("TemplateElement").bases("Node").build("value", "tail").field("value", { "cooked": String, "raw": String }).field("tail", Boolean);
    }
    __name(default_1, "default_1");
    exports2.default = default_1;
    module2.exports = exports2["default"];
  }
});

// ../../node_modules/ast-types/def/es7.js
var require_es7 = __commonJS({
  "../../node_modules/ast-types/def/es7.js"(exports2, module2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var es6_1 = tslib_1.__importDefault(require_es6());
    var types_1 = tslib_1.__importDefault(require_types2());
    var shared_1 = tslib_1.__importDefault(require_shared());
    function default_1(fork) {
      fork.use(es6_1.default);
      var types2 = fork.use(types_1.default);
      var def = types2.Type.def;
      var or = types2.Type.or;
      var defaults = fork.use(shared_1.default).defaults;
      def("Function").field("async", Boolean, defaults["false"]);
      def("SpreadProperty").bases("Node").build("argument").field("argument", def("Expression"));
      def("ObjectExpression").field("properties", [or(def("Property"), def("SpreadProperty"), def("SpreadElement"))]);
      def("SpreadPropertyPattern").bases("Pattern").build("argument").field("argument", def("Pattern"));
      def("ObjectPattern").field("properties", [or(def("Property"), def("PropertyPattern"), def("SpreadPropertyPattern"))]);
      def("AwaitExpression").bases("Expression").build("argument", "all").field("argument", or(def("Expression"), null)).field("all", Boolean, defaults["false"]);
    }
    __name(default_1, "default_1");
    exports2.default = default_1;
    module2.exports = exports2["default"];
  }
});

// ../../node_modules/ast-types/def/es2020.js
var require_es2020 = __commonJS({
  "../../node_modules/ast-types/def/es2020.js"(exports2, module2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var es7_1 = tslib_1.__importDefault(require_es7());
    var types_1 = tslib_1.__importDefault(require_types2());
    function default_1(fork) {
      fork.use(es7_1.default);
      var types2 = fork.use(types_1.default);
      var def = types2.Type.def;
      def("ImportExpression").bases("Expression").build("source").field("source", def("Expression"));
    }
    __name(default_1, "default_1");
    exports2.default = default_1;
    module2.exports = exports2["default"];
  }
});

// ../../node_modules/ast-types/def/jsx.js
var require_jsx = __commonJS({
  "../../node_modules/ast-types/def/jsx.js"(exports2, module2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var es7_1 = tslib_1.__importDefault(require_es7());
    var types_1 = tslib_1.__importDefault(require_types2());
    var shared_1 = tslib_1.__importDefault(require_shared());
    function default_1(fork) {
      fork.use(es7_1.default);
      var types2 = fork.use(types_1.default);
      var def = types2.Type.def;
      var or = types2.Type.or;
      var defaults = fork.use(shared_1.default).defaults;
      def("JSXAttribute").bases("Node").build("name", "value").field("name", or(def("JSXIdentifier"), def("JSXNamespacedName"))).field("value", or(
        def("Literal"),
        // attr="value"
        def("JSXExpressionContainer"),
        // attr={value}
        null
        // attr= or just attr
      ), defaults["null"]);
      def("JSXIdentifier").bases("Identifier").build("name").field("name", String);
      def("JSXNamespacedName").bases("Node").build("namespace", "name").field("namespace", def("JSXIdentifier")).field("name", def("JSXIdentifier"));
      def("JSXMemberExpression").bases("MemberExpression").build("object", "property").field("object", or(def("JSXIdentifier"), def("JSXMemberExpression"))).field("property", def("JSXIdentifier")).field("computed", Boolean, defaults.false);
      var JSXElementName = or(def("JSXIdentifier"), def("JSXNamespacedName"), def("JSXMemberExpression"));
      def("JSXSpreadAttribute").bases("Node").build("argument").field("argument", def("Expression"));
      var JSXAttributes = [or(def("JSXAttribute"), def("JSXSpreadAttribute"))];
      def("JSXExpressionContainer").bases("Expression").build("expression").field("expression", def("Expression"));
      def("JSXElement").bases("Expression").build("openingElement", "closingElement", "children").field("openingElement", def("JSXOpeningElement")).field("closingElement", or(def("JSXClosingElement"), null), defaults["null"]).field("children", [or(
        def("JSXElement"),
        def("JSXExpressionContainer"),
        def("JSXFragment"),
        def("JSXText"),
        def("Literal")
        // TODO Esprima should return JSXText instead.
      )], defaults.emptyArray).field("name", JSXElementName, function() {
        return this.openingElement.name;
      }, true).field("selfClosing", Boolean, function() {
        return this.openingElement.selfClosing;
      }, true).field("attributes", JSXAttributes, function() {
        return this.openingElement.attributes;
      }, true);
      def("JSXOpeningElement").bases("Node").build("name", "attributes", "selfClosing").field("name", JSXElementName).field("attributes", JSXAttributes, defaults.emptyArray).field("selfClosing", Boolean, defaults["false"]);
      def("JSXClosingElement").bases("Node").build("name").field("name", JSXElementName);
      def("JSXFragment").bases("Expression").build("openingElement", "closingElement", "children").field("openingElement", def("JSXOpeningFragment")).field("closingElement", def("JSXClosingFragment")).field("children", [or(
        def("JSXElement"),
        def("JSXExpressionContainer"),
        def("JSXFragment"),
        def("JSXText"),
        def("Literal")
        // TODO Esprima should return JSXText instead.
      )], defaults.emptyArray);
      def("JSXOpeningFragment").bases("Node").build();
      def("JSXClosingFragment").bases("Node").build();
      def("JSXText").bases("Literal").build("value").field("value", String);
      def("JSXEmptyExpression").bases("Expression").build();
      def("JSXSpreadChild").bases("Expression").build("expression").field("expression", def("Expression"));
    }
    __name(default_1, "default_1");
    exports2.default = default_1;
    module2.exports = exports2["default"];
  }
});

// ../../node_modules/ast-types/def/type-annotations.js
var require_type_annotations = __commonJS({
  "../../node_modules/ast-types/def/type-annotations.js"(exports2, module2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var types_1 = tslib_1.__importDefault(require_types2());
    var shared_1 = tslib_1.__importDefault(require_shared());
    function default_1(fork) {
      var types2 = fork.use(types_1.default);
      var def = types2.Type.def;
      var or = types2.Type.or;
      var defaults = fork.use(shared_1.default).defaults;
      var TypeAnnotation = or(def("TypeAnnotation"), def("TSTypeAnnotation"), null);
      var TypeParamDecl = or(def("TypeParameterDeclaration"), def("TSTypeParameterDeclaration"), null);
      def("Identifier").field("typeAnnotation", TypeAnnotation, defaults["null"]);
      def("ObjectPattern").field("typeAnnotation", TypeAnnotation, defaults["null"]);
      def("Function").field("returnType", TypeAnnotation, defaults["null"]).field("typeParameters", TypeParamDecl, defaults["null"]);
      def("ClassProperty").build("key", "value", "typeAnnotation", "static").field("value", or(def("Expression"), null)).field("static", Boolean, defaults["false"]).field("typeAnnotation", TypeAnnotation, defaults["null"]);
      [
        "ClassDeclaration",
        "ClassExpression"
      ].forEach(function(typeName) {
        def(typeName).field("typeParameters", TypeParamDecl, defaults["null"]).field("superTypeParameters", or(def("TypeParameterInstantiation"), def("TSTypeParameterInstantiation"), null), defaults["null"]).field("implements", or([def("ClassImplements")], [def("TSExpressionWithTypeArguments")]), defaults.emptyArray);
      });
    }
    __name(default_1, "default_1");
    exports2.default = default_1;
    module2.exports = exports2["default"];
  }
});

// ../../node_modules/ast-types/def/flow.js
var require_flow = __commonJS({
  "../../node_modules/ast-types/def/flow.js"(exports2, module2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var es7_1 = tslib_1.__importDefault(require_es7());
    var type_annotations_1 = tslib_1.__importDefault(require_type_annotations());
    var types_1 = tslib_1.__importDefault(require_types2());
    var shared_1 = tslib_1.__importDefault(require_shared());
    function default_1(fork) {
      fork.use(es7_1.default);
      fork.use(type_annotations_1.default);
      var types2 = fork.use(types_1.default);
      var def = types2.Type.def;
      var or = types2.Type.or;
      var defaults = fork.use(shared_1.default).defaults;
      def("Flow").bases("Node");
      def("FlowType").bases("Flow");
      def("AnyTypeAnnotation").bases("FlowType").build();
      def("EmptyTypeAnnotation").bases("FlowType").build();
      def("MixedTypeAnnotation").bases("FlowType").build();
      def("VoidTypeAnnotation").bases("FlowType").build();
      def("NumberTypeAnnotation").bases("FlowType").build();
      def("NumberLiteralTypeAnnotation").bases("FlowType").build("value", "raw").field("value", Number).field("raw", String);
      def("NumericLiteralTypeAnnotation").bases("FlowType").build("value", "raw").field("value", Number).field("raw", String);
      def("StringTypeAnnotation").bases("FlowType").build();
      def("StringLiteralTypeAnnotation").bases("FlowType").build("value", "raw").field("value", String).field("raw", String);
      def("BooleanTypeAnnotation").bases("FlowType").build();
      def("BooleanLiteralTypeAnnotation").bases("FlowType").build("value", "raw").field("value", Boolean).field("raw", String);
      def("TypeAnnotation").bases("Node").build("typeAnnotation").field("typeAnnotation", def("FlowType"));
      def("NullableTypeAnnotation").bases("FlowType").build("typeAnnotation").field("typeAnnotation", def("FlowType"));
      def("NullLiteralTypeAnnotation").bases("FlowType").build();
      def("NullTypeAnnotation").bases("FlowType").build();
      def("ThisTypeAnnotation").bases("FlowType").build();
      def("ExistsTypeAnnotation").bases("FlowType").build();
      def("ExistentialTypeParam").bases("FlowType").build();
      def("FunctionTypeAnnotation").bases("FlowType").build("params", "returnType", "rest", "typeParameters").field("params", [def("FunctionTypeParam")]).field("returnType", def("FlowType")).field("rest", or(def("FunctionTypeParam"), null)).field("typeParameters", or(def("TypeParameterDeclaration"), null));
      def("FunctionTypeParam").bases("Node").build("name", "typeAnnotation", "optional").field("name", def("Identifier")).field("typeAnnotation", def("FlowType")).field("optional", Boolean);
      def("ArrayTypeAnnotation").bases("FlowType").build("elementType").field("elementType", def("FlowType"));
      def("ObjectTypeAnnotation").bases("FlowType").build("properties", "indexers", "callProperties").field("properties", [
        or(def("ObjectTypeProperty"), def("ObjectTypeSpreadProperty"))
      ]).field("indexers", [def("ObjectTypeIndexer")], defaults.emptyArray).field("callProperties", [def("ObjectTypeCallProperty")], defaults.emptyArray).field("inexact", or(Boolean, void 0), defaults["undefined"]).field("exact", Boolean, defaults["false"]).field("internalSlots", [def("ObjectTypeInternalSlot")], defaults.emptyArray);
      def("Variance").bases("Node").build("kind").field("kind", or("plus", "minus"));
      var LegacyVariance = or(def("Variance"), "plus", "minus", null);
      def("ObjectTypeProperty").bases("Node").build("key", "value", "optional").field("key", or(def("Literal"), def("Identifier"))).field("value", def("FlowType")).field("optional", Boolean).field("variance", LegacyVariance, defaults["null"]);
      def("ObjectTypeIndexer").bases("Node").build("id", "key", "value").field("id", def("Identifier")).field("key", def("FlowType")).field("value", def("FlowType")).field("variance", LegacyVariance, defaults["null"]);
      def("ObjectTypeCallProperty").bases("Node").build("value").field("value", def("FunctionTypeAnnotation")).field("static", Boolean, defaults["false"]);
      def("QualifiedTypeIdentifier").bases("Node").build("qualification", "id").field("qualification", or(def("Identifier"), def("QualifiedTypeIdentifier"))).field("id", def("Identifier"));
      def("GenericTypeAnnotation").bases("FlowType").build("id", "typeParameters").field("id", or(def("Identifier"), def("QualifiedTypeIdentifier"))).field("typeParameters", or(def("TypeParameterInstantiation"), null));
      def("MemberTypeAnnotation").bases("FlowType").build("object", "property").field("object", def("Identifier")).field("property", or(def("MemberTypeAnnotation"), def("GenericTypeAnnotation")));
      def("UnionTypeAnnotation").bases("FlowType").build("types").field("types", [def("FlowType")]);
      def("IntersectionTypeAnnotation").bases("FlowType").build("types").field("types", [def("FlowType")]);
      def("TypeofTypeAnnotation").bases("FlowType").build("argument").field("argument", def("FlowType"));
      def("ObjectTypeSpreadProperty").bases("Node").build("argument").field("argument", def("FlowType"));
      def("ObjectTypeInternalSlot").bases("Node").build("id", "value", "optional", "static", "method").field("id", def("Identifier")).field("value", def("FlowType")).field("optional", Boolean).field("static", Boolean).field("method", Boolean);
      def("TypeParameterDeclaration").bases("Node").build("params").field("params", [def("TypeParameter")]);
      def("TypeParameterInstantiation").bases("Node").build("params").field("params", [def("FlowType")]);
      def("TypeParameter").bases("FlowType").build("name", "variance", "bound").field("name", String).field("variance", LegacyVariance, defaults["null"]).field("bound", or(def("TypeAnnotation"), null), defaults["null"]);
      def("ClassProperty").field("variance", LegacyVariance, defaults["null"]);
      def("ClassImplements").bases("Node").build("id").field("id", def("Identifier")).field("superClass", or(def("Expression"), null), defaults["null"]).field("typeParameters", or(def("TypeParameterInstantiation"), null), defaults["null"]);
      def("InterfaceTypeAnnotation").bases("FlowType").build("body", "extends").field("body", def("ObjectTypeAnnotation")).field("extends", or([def("InterfaceExtends")], null), defaults["null"]);
      def("InterfaceDeclaration").bases("Declaration").build("id", "body", "extends").field("id", def("Identifier")).field("typeParameters", or(def("TypeParameterDeclaration"), null), defaults["null"]).field("body", def("ObjectTypeAnnotation")).field("extends", [def("InterfaceExtends")]);
      def("DeclareInterface").bases("InterfaceDeclaration").build("id", "body", "extends");
      def("InterfaceExtends").bases("Node").build("id").field("id", def("Identifier")).field("typeParameters", or(def("TypeParameterInstantiation"), null), defaults["null"]);
      def("TypeAlias").bases("Declaration").build("id", "typeParameters", "right").field("id", def("Identifier")).field("typeParameters", or(def("TypeParameterDeclaration"), null)).field("right", def("FlowType"));
      def("OpaqueType").bases("Declaration").build("id", "typeParameters", "impltype", "supertype").field("id", def("Identifier")).field("typeParameters", or(def("TypeParameterDeclaration"), null)).field("impltype", def("FlowType")).field("supertype", def("FlowType"));
      def("DeclareTypeAlias").bases("TypeAlias").build("id", "typeParameters", "right");
      def("DeclareOpaqueType").bases("TypeAlias").build("id", "typeParameters", "supertype");
      def("TypeCastExpression").bases("Expression").build("expression", "typeAnnotation").field("expression", def("Expression")).field("typeAnnotation", def("TypeAnnotation"));
      def("TupleTypeAnnotation").bases("FlowType").build("types").field("types", [def("FlowType")]);
      def("DeclareVariable").bases("Statement").build("id").field("id", def("Identifier"));
      def("DeclareFunction").bases("Statement").build("id").field("id", def("Identifier"));
      def("DeclareClass").bases("InterfaceDeclaration").build("id");
      def("DeclareModule").bases("Statement").build("id", "body").field("id", or(def("Identifier"), def("Literal"))).field("body", def("BlockStatement"));
      def("DeclareModuleExports").bases("Statement").build("typeAnnotation").field("typeAnnotation", def("TypeAnnotation"));
      def("DeclareExportDeclaration").bases("Declaration").build("default", "declaration", "specifiers", "source").field("default", Boolean).field("declaration", or(
        def("DeclareVariable"),
        def("DeclareFunction"),
        def("DeclareClass"),
        def("FlowType"),
        // Implies default.
        null
      )).field("specifiers", [or(def("ExportSpecifier"), def("ExportBatchSpecifier"))], defaults.emptyArray).field("source", or(def("Literal"), null), defaults["null"]);
      def("DeclareExportAllDeclaration").bases("Declaration").build("source").field("source", or(def("Literal"), null), defaults["null"]);
      def("FlowPredicate").bases("Flow");
      def("InferredPredicate").bases("FlowPredicate").build();
      def("DeclaredPredicate").bases("FlowPredicate").build("value").field("value", def("Expression"));
      def("CallExpression").field("typeArguments", or(null, def("TypeParameterInstantiation")), defaults["null"]);
      def("NewExpression").field("typeArguments", or(null, def("TypeParameterInstantiation")), defaults["null"]);
    }
    __name(default_1, "default_1");
    exports2.default = default_1;
    module2.exports = exports2["default"];
  }
});

// ../../node_modules/ast-types/def/esprima.js
var require_esprima2 = __commonJS({
  "../../node_modules/ast-types/def/esprima.js"(exports2, module2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var es7_1 = tslib_1.__importDefault(require_es7());
    var types_1 = tslib_1.__importDefault(require_types2());
    var shared_1 = tslib_1.__importDefault(require_shared());
    function default_1(fork) {
      fork.use(es7_1.default);
      var types2 = fork.use(types_1.default);
      var defaults = fork.use(shared_1.default).defaults;
      var def = types2.Type.def;
      var or = types2.Type.or;
      def("VariableDeclaration").field("declarations", [or(
        def("VariableDeclarator"),
        def("Identifier")
        // Esprima deviation.
      )]);
      def("Property").field("value", or(
        def("Expression"),
        def("Pattern")
        // Esprima deviation.
      ));
      def("ArrayPattern").field("elements", [or(def("Pattern"), def("SpreadElement"), null)]);
      def("ObjectPattern").field("properties", [or(
        def("Property"),
        def("PropertyPattern"),
        def("SpreadPropertyPattern"),
        def("SpreadProperty")
        // Used by Esprima.
      )]);
      def("ExportSpecifier").bases("ModuleSpecifier").build("id", "name");
      def("ExportBatchSpecifier").bases("Specifier").build();
      def("ExportDeclaration").bases("Declaration").build("default", "declaration", "specifiers", "source").field("default", Boolean).field("declaration", or(
        def("Declaration"),
        def("Expression"),
        // Implies default.
        null
      )).field("specifiers", [or(def("ExportSpecifier"), def("ExportBatchSpecifier"))], defaults.emptyArray).field("source", or(def("Literal"), null), defaults["null"]);
      def("Block").bases("Comment").build(
        "value",
        /*optional:*/
        "leading",
        "trailing"
      );
      def("Line").bases("Comment").build(
        "value",
        /*optional:*/
        "leading",
        "trailing"
      );
    }
    __name(default_1, "default_1");
    exports2.default = default_1;
    module2.exports = exports2["default"];
  }
});

// ../../node_modules/ast-types/def/babel-core.js
var require_babel_core = __commonJS({
  "../../node_modules/ast-types/def/babel-core.js"(exports2, module2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var types_1 = tslib_1.__importDefault(require_types2());
    var shared_1 = tslib_1.__importDefault(require_shared());
    var es7_1 = tslib_1.__importDefault(require_es7());
    function default_1(fork) {
      fork.use(es7_1.default);
      var types2 = fork.use(types_1.default);
      var defaults = fork.use(shared_1.default).defaults;
      var def = types2.Type.def;
      var or = types2.Type.or;
      def("Noop").bases("Statement").build();
      def("DoExpression").bases("Expression").build("body").field("body", [def("Statement")]);
      def("Super").bases("Expression").build();
      def("BindExpression").bases("Expression").build("object", "callee").field("object", or(def("Expression"), null)).field("callee", def("Expression"));
      def("Decorator").bases("Node").build("expression").field("expression", def("Expression"));
      def("Property").field("decorators", or([def("Decorator")], null), defaults["null"]);
      def("MethodDefinition").field("decorators", or([def("Decorator")], null), defaults["null"]);
      def("MetaProperty").bases("Expression").build("meta", "property").field("meta", def("Identifier")).field("property", def("Identifier"));
      def("ParenthesizedExpression").bases("Expression").build("expression").field("expression", def("Expression"));
      def("ImportSpecifier").bases("ModuleSpecifier").build("imported", "local").field("imported", def("Identifier"));
      def("ImportDefaultSpecifier").bases("ModuleSpecifier").build("local");
      def("ImportNamespaceSpecifier").bases("ModuleSpecifier").build("local");
      def("ExportDefaultDeclaration").bases("Declaration").build("declaration").field("declaration", or(def("Declaration"), def("Expression")));
      def("ExportNamedDeclaration").bases("Declaration").build("declaration", "specifiers", "source").field("declaration", or(def("Declaration"), null)).field("specifiers", [def("ExportSpecifier")], defaults.emptyArray).field("source", or(def("Literal"), null), defaults["null"]);
      def("ExportSpecifier").bases("ModuleSpecifier").build("local", "exported").field("exported", def("Identifier"));
      def("ExportNamespaceSpecifier").bases("Specifier").build("exported").field("exported", def("Identifier"));
      def("ExportDefaultSpecifier").bases("Specifier").build("exported").field("exported", def("Identifier"));
      def("ExportAllDeclaration").bases("Declaration").build("exported", "source").field("exported", or(def("Identifier"), null)).field("source", def("Literal"));
      def("CommentBlock").bases("Comment").build(
        "value",
        /*optional:*/
        "leading",
        "trailing"
      );
      def("CommentLine").bases("Comment").build(
        "value",
        /*optional:*/
        "leading",
        "trailing"
      );
      def("Directive").bases("Node").build("value").field("value", def("DirectiveLiteral"));
      def("DirectiveLiteral").bases("Node", "Expression").build("value").field("value", String, defaults["use strict"]);
      def("InterpreterDirective").bases("Node").build("value").field("value", String);
      def("BlockStatement").bases("Statement").build("body").field("body", [def("Statement")]).field("directives", [def("Directive")], defaults.emptyArray);
      def("Program").bases("Node").build("body").field("body", [def("Statement")]).field("directives", [def("Directive")], defaults.emptyArray).field("interpreter", or(def("InterpreterDirective"), null), defaults["null"]);
      def("StringLiteral").bases("Literal").build("value").field("value", String);
      def("NumericLiteral").bases("Literal").build("value").field("value", Number).field("raw", or(String, null), defaults["null"]).field("extra", {
        rawValue: Number,
        raw: String
      }, /* @__PURE__ */ __name(function getDefault() {
        return {
          rawValue: this.value,
          raw: this.value + ""
        };
      }, "getDefault"));
      def("BigIntLiteral").bases("Literal").build("value").field("value", or(String, Number)).field("extra", {
        rawValue: String,
        raw: String
      }, /* @__PURE__ */ __name(function getDefault() {
        return {
          rawValue: String(this.value),
          raw: this.value + "n"
        };
      }, "getDefault"));
      def("NullLiteral").bases("Literal").build().field("value", null, defaults["null"]);
      def("BooleanLiteral").bases("Literal").build("value").field("value", Boolean);
      def("RegExpLiteral").bases("Literal").build("pattern", "flags").field("pattern", String).field("flags", String).field("value", RegExp, function() {
        return new RegExp(this.pattern, this.flags);
      });
      var ObjectExpressionProperty = or(def("Property"), def("ObjectMethod"), def("ObjectProperty"), def("SpreadProperty"), def("SpreadElement"));
      def("ObjectExpression").bases("Expression").build("properties").field("properties", [ObjectExpressionProperty]);
      def("ObjectMethod").bases("Node", "Function").build("kind", "key", "params", "body", "computed").field("kind", or("method", "get", "set")).field("key", or(def("Literal"), def("Identifier"), def("Expression"))).field("params", [def("Pattern")]).field("body", def("BlockStatement")).field("computed", Boolean, defaults["false"]).field("generator", Boolean, defaults["false"]).field("async", Boolean, defaults["false"]).field(
        "accessibility",
        // TypeScript
        or(def("Literal"), null),
        defaults["null"]
      ).field("decorators", or([def("Decorator")], null), defaults["null"]);
      def("ObjectProperty").bases("Node").build("key", "value").field("key", or(def("Literal"), def("Identifier"), def("Expression"))).field("value", or(def("Expression"), def("Pattern"))).field(
        "accessibility",
        // TypeScript
        or(def("Literal"), null),
        defaults["null"]
      ).field("computed", Boolean, defaults["false"]);
      var ClassBodyElement = or(def("MethodDefinition"), def("VariableDeclarator"), def("ClassPropertyDefinition"), def("ClassProperty"), def("ClassPrivateProperty"), def("ClassMethod"), def("ClassPrivateMethod"));
      def("ClassBody").bases("Declaration").build("body").field("body", [ClassBodyElement]);
      def("ClassMethod").bases("Declaration", "Function").build("kind", "key", "params", "body", "computed", "static").field("key", or(def("Literal"), def("Identifier"), def("Expression")));
      def("ClassPrivateMethod").bases("Declaration", "Function").build("key", "params", "body", "kind", "computed", "static").field("key", def("PrivateName"));
      [
        "ClassMethod",
        "ClassPrivateMethod"
      ].forEach(function(typeName) {
        def(typeName).field("kind", or("get", "set", "method", "constructor"), function() {
          return "method";
        }).field("body", def("BlockStatement")).field("computed", Boolean, defaults["false"]).field("static", or(Boolean, null), defaults["null"]).field("abstract", or(Boolean, null), defaults["null"]).field("access", or("public", "private", "protected", null), defaults["null"]).field("accessibility", or("public", "private", "protected", null), defaults["null"]).field("decorators", or([def("Decorator")], null), defaults["null"]).field("optional", or(Boolean, null), defaults["null"]);
      });
      def("ClassPrivateProperty").bases("ClassProperty").build("key", "value").field("key", def("PrivateName")).field("value", or(def("Expression"), null), defaults["null"]);
      def("PrivateName").bases("Expression", "Pattern").build("id").field("id", def("Identifier"));
      var ObjectPatternProperty = or(
        def("Property"),
        def("PropertyPattern"),
        def("SpreadPropertyPattern"),
        def("SpreadProperty"),
        // Used by Esprima
        def("ObjectProperty"),
        // Babel 6
        def("RestProperty")
        // Babel 6
      );
      def("ObjectPattern").bases("Pattern").build("properties").field("properties", [ObjectPatternProperty]).field("decorators", or([def("Decorator")], null), defaults["null"]);
      def("SpreadProperty").bases("Node").build("argument").field("argument", def("Expression"));
      def("RestProperty").bases("Node").build("argument").field("argument", def("Expression"));
      def("ForAwaitStatement").bases("Statement").build("left", "right", "body").field("left", or(def("VariableDeclaration"), def("Expression"))).field("right", def("Expression")).field("body", def("Statement"));
      def("Import").bases("Expression").build();
    }
    __name(default_1, "default_1");
    exports2.default = default_1;
    module2.exports = exports2["default"];
  }
});

// ../../node_modules/ast-types/def/babel.js
var require_babel = __commonJS({
  "../../node_modules/ast-types/def/babel.js"(exports2, module2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var babel_core_1 = tslib_1.__importDefault(require_babel_core());
    var flow_1 = tslib_1.__importDefault(require_flow());
    function default_1(fork) {
      fork.use(babel_core_1.default);
      fork.use(flow_1.default);
    }
    __name(default_1, "default_1");
    exports2.default = default_1;
    module2.exports = exports2["default"];
  }
});

// ../../node_modules/ast-types/def/typescript.js
var require_typescript = __commonJS({
  "../../node_modules/ast-types/def/typescript.js"(exports2, module2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var babel_core_1 = tslib_1.__importDefault(require_babel_core());
    var type_annotations_1 = tslib_1.__importDefault(require_type_annotations());
    var types_1 = tslib_1.__importDefault(require_types2());
    var shared_1 = tslib_1.__importDefault(require_shared());
    function default_1(fork) {
      fork.use(babel_core_1.default);
      fork.use(type_annotations_1.default);
      var types2 = fork.use(types_1.default);
      var n10 = types2.namedTypes;
      var def = types2.Type.def;
      var or = types2.Type.or;
      var defaults = fork.use(shared_1.default).defaults;
      var StringLiteral = types2.Type.from(function(value, deep) {
        if (n10.StringLiteral && n10.StringLiteral.check(value, deep)) {
          return true;
        }
        if (n10.Literal && n10.Literal.check(value, deep) && typeof value.value === "string") {
          return true;
        }
        return false;
      }, "StringLiteral");
      def("TSType").bases("Node");
      var TSEntityName = or(def("Identifier"), def("TSQualifiedName"));
      def("TSTypeReference").bases("TSType", "TSHasOptionalTypeParameterInstantiation").build("typeName", "typeParameters").field("typeName", TSEntityName);
      def("TSHasOptionalTypeParameterInstantiation").field("typeParameters", or(def("TSTypeParameterInstantiation"), null), defaults["null"]);
      def("TSHasOptionalTypeParameters").field("typeParameters", or(def("TSTypeParameterDeclaration"), null, void 0), defaults["null"]);
      def("TSHasOptionalTypeAnnotation").field("typeAnnotation", or(def("TSTypeAnnotation"), null), defaults["null"]);
      def("TSQualifiedName").bases("Node").build("left", "right").field("left", TSEntityName).field("right", TSEntityName);
      def("TSAsExpression").bases("Expression", "Pattern").build("expression", "typeAnnotation").field("expression", def("Expression")).field("typeAnnotation", def("TSType")).field("extra", or({ parenthesized: Boolean }, null), defaults["null"]);
      def("TSNonNullExpression").bases("Expression", "Pattern").build("expression").field("expression", def("Expression"));
      [
        "TSAnyKeyword",
        "TSBigIntKeyword",
        "TSBooleanKeyword",
        "TSNeverKeyword",
        "TSNullKeyword",
        "TSNumberKeyword",
        "TSObjectKeyword",
        "TSStringKeyword",
        "TSSymbolKeyword",
        "TSUndefinedKeyword",
        "TSUnknownKeyword",
        "TSVoidKeyword",
        "TSThisType"
      ].forEach(function(keywordType) {
        def(keywordType).bases("TSType").build();
      });
      def("TSArrayType").bases("TSType").build("elementType").field("elementType", def("TSType"));
      def("TSLiteralType").bases("TSType").build("literal").field("literal", or(def("NumericLiteral"), def("StringLiteral"), def("BooleanLiteral"), def("TemplateLiteral"), def("UnaryExpression")));
      [
        "TSUnionType",
        "TSIntersectionType"
      ].forEach(function(typeName) {
        def(typeName).bases("TSType").build("types").field("types", [def("TSType")]);
      });
      def("TSConditionalType").bases("TSType").build("checkType", "extendsType", "trueType", "falseType").field("checkType", def("TSType")).field("extendsType", def("TSType")).field("trueType", def("TSType")).field("falseType", def("TSType"));
      def("TSInferType").bases("TSType").build("typeParameter").field("typeParameter", def("TSTypeParameter"));
      def("TSParenthesizedType").bases("TSType").build("typeAnnotation").field("typeAnnotation", def("TSType"));
      var ParametersType = [or(def("Identifier"), def("RestElement"), def("ArrayPattern"), def("ObjectPattern"))];
      [
        "TSFunctionType",
        "TSConstructorType"
      ].forEach(function(typeName) {
        def(typeName).bases("TSType", "TSHasOptionalTypeParameters", "TSHasOptionalTypeAnnotation").build("parameters").field("parameters", ParametersType);
      });
      def("TSDeclareFunction").bases("Declaration", "TSHasOptionalTypeParameters").build("id", "params", "returnType").field("declare", Boolean, defaults["false"]).field("async", Boolean, defaults["false"]).field("generator", Boolean, defaults["false"]).field("id", or(def("Identifier"), null), defaults["null"]).field("params", [def("Pattern")]).field("returnType", or(
        def("TSTypeAnnotation"),
        def("Noop"),
        // Still used?
        null
      ), defaults["null"]);
      def("TSDeclareMethod").bases("Declaration", "TSHasOptionalTypeParameters").build("key", "params", "returnType").field("async", Boolean, defaults["false"]).field("generator", Boolean, defaults["false"]).field("params", [def("Pattern")]).field("abstract", Boolean, defaults["false"]).field("accessibility", or("public", "private", "protected", void 0), defaults["undefined"]).field("static", Boolean, defaults["false"]).field("computed", Boolean, defaults["false"]).field("optional", Boolean, defaults["false"]).field("key", or(
        def("Identifier"),
        def("StringLiteral"),
        def("NumericLiteral"),
        // Only allowed if .computed is true.
        def("Expression")
      )).field("kind", or("get", "set", "method", "constructor"), /* @__PURE__ */ __name(function getDefault() {
        return "method";
      }, "getDefault")).field(
        "access",
        // Not "accessibility"?
        or("public", "private", "protected", void 0),
        defaults["undefined"]
      ).field("decorators", or([def("Decorator")], null), defaults["null"]).field("returnType", or(
        def("TSTypeAnnotation"),
        def("Noop"),
        // Still used?
        null
      ), defaults["null"]);
      def("TSMappedType").bases("TSType").build("typeParameter", "typeAnnotation").field("readonly", or(Boolean, "+", "-"), defaults["false"]).field("typeParameter", def("TSTypeParameter")).field("optional", or(Boolean, "+", "-"), defaults["false"]).field("typeAnnotation", or(def("TSType"), null), defaults["null"]);
      def("TSTupleType").bases("TSType").build("elementTypes").field("elementTypes", [or(def("TSType"), def("TSNamedTupleMember"))]);
      def("TSNamedTupleMember").bases("TSType").build("label", "elementType", "optional").field("label", def("Identifier")).field("optional", Boolean, defaults["false"]).field("elementType", def("TSType"));
      def("TSRestType").bases("TSType").build("typeAnnotation").field("typeAnnotation", def("TSType"));
      def("TSOptionalType").bases("TSType").build("typeAnnotation").field("typeAnnotation", def("TSType"));
      def("TSIndexedAccessType").bases("TSType").build("objectType", "indexType").field("objectType", def("TSType")).field("indexType", def("TSType"));
      def("TSTypeOperator").bases("TSType").build("operator").field("operator", String).field("typeAnnotation", def("TSType"));
      def("TSTypeAnnotation").bases("Node").build("typeAnnotation").field("typeAnnotation", or(def("TSType"), def("TSTypeAnnotation")));
      def("TSIndexSignature").bases("Declaration", "TSHasOptionalTypeAnnotation").build("parameters", "typeAnnotation").field("parameters", [def("Identifier")]).field("readonly", Boolean, defaults["false"]);
      def("TSPropertySignature").bases("Declaration", "TSHasOptionalTypeAnnotation").build("key", "typeAnnotation", "optional").field("key", def("Expression")).field("computed", Boolean, defaults["false"]).field("readonly", Boolean, defaults["false"]).field("optional", Boolean, defaults["false"]).field("initializer", or(def("Expression"), null), defaults["null"]);
      def("TSMethodSignature").bases("Declaration", "TSHasOptionalTypeParameters", "TSHasOptionalTypeAnnotation").build("key", "parameters", "typeAnnotation").field("key", def("Expression")).field("computed", Boolean, defaults["false"]).field("optional", Boolean, defaults["false"]).field("parameters", ParametersType);
      def("TSTypePredicate").bases("TSTypeAnnotation", "TSType").build("parameterName", "typeAnnotation", "asserts").field("parameterName", or(def("Identifier"), def("TSThisType"))).field("typeAnnotation", or(def("TSTypeAnnotation"), null), defaults["null"]).field("asserts", Boolean, defaults["false"]);
      [
        "TSCallSignatureDeclaration",
        "TSConstructSignatureDeclaration"
      ].forEach(function(typeName) {
        def(typeName).bases("Declaration", "TSHasOptionalTypeParameters", "TSHasOptionalTypeAnnotation").build("parameters", "typeAnnotation").field("parameters", ParametersType);
      });
      def("TSEnumMember").bases("Node").build("id", "initializer").field("id", or(def("Identifier"), StringLiteral)).field("initializer", or(def("Expression"), null), defaults["null"]);
      def("TSTypeQuery").bases("TSType").build("exprName").field("exprName", or(TSEntityName, def("TSImportType")));
      var TSTypeMember = or(def("TSCallSignatureDeclaration"), def("TSConstructSignatureDeclaration"), def("TSIndexSignature"), def("TSMethodSignature"), def("TSPropertySignature"));
      def("TSTypeLiteral").bases("TSType").build("members").field("members", [TSTypeMember]);
      def("TSTypeParameter").bases("Identifier").build("name", "constraint", "default").field("name", String).field("constraint", or(def("TSType"), void 0), defaults["undefined"]).field("default", or(def("TSType"), void 0), defaults["undefined"]);
      def("TSTypeAssertion").bases("Expression", "Pattern").build("typeAnnotation", "expression").field("typeAnnotation", def("TSType")).field("expression", def("Expression")).field("extra", or({ parenthesized: Boolean }, null), defaults["null"]);
      def("TSTypeParameterDeclaration").bases("Declaration").build("params").field("params", [def("TSTypeParameter")]);
      def("TSTypeParameterInstantiation").bases("Node").build("params").field("params", [def("TSType")]);
      def("TSEnumDeclaration").bases("Declaration").build("id", "members").field("id", def("Identifier")).field("const", Boolean, defaults["false"]).field("declare", Boolean, defaults["false"]).field("members", [def("TSEnumMember")]).field("initializer", or(def("Expression"), null), defaults["null"]);
      def("TSTypeAliasDeclaration").bases("Declaration", "TSHasOptionalTypeParameters").build("id", "typeAnnotation").field("id", def("Identifier")).field("declare", Boolean, defaults["false"]).field("typeAnnotation", def("TSType"));
      def("TSModuleBlock").bases("Node").build("body").field("body", [def("Statement")]);
      def("TSModuleDeclaration").bases("Declaration").build("id", "body").field("id", or(StringLiteral, TSEntityName)).field("declare", Boolean, defaults["false"]).field("global", Boolean, defaults["false"]).field("body", or(def("TSModuleBlock"), def("TSModuleDeclaration"), null), defaults["null"]);
      def("TSImportType").bases("TSType", "TSHasOptionalTypeParameterInstantiation").build("argument", "qualifier", "typeParameters").field("argument", StringLiteral).field("qualifier", or(TSEntityName, void 0), defaults["undefined"]);
      def("TSImportEqualsDeclaration").bases("Declaration").build("id", "moduleReference").field("id", def("Identifier")).field("isExport", Boolean, defaults["false"]).field("moduleReference", or(TSEntityName, def("TSExternalModuleReference")));
      def("TSExternalModuleReference").bases("Declaration").build("expression").field("expression", StringLiteral);
      def("TSExportAssignment").bases("Statement").build("expression").field("expression", def("Expression"));
      def("TSNamespaceExportDeclaration").bases("Declaration").build("id").field("id", def("Identifier"));
      def("TSInterfaceBody").bases("Node").build("body").field("body", [TSTypeMember]);
      def("TSExpressionWithTypeArguments").bases("TSType", "TSHasOptionalTypeParameterInstantiation").build("expression", "typeParameters").field("expression", TSEntityName);
      def("TSInterfaceDeclaration").bases("Declaration", "TSHasOptionalTypeParameters").build("id", "body").field("id", TSEntityName).field("declare", Boolean, defaults["false"]).field("extends", or([def("TSExpressionWithTypeArguments")], null), defaults["null"]).field("body", def("TSInterfaceBody"));
      def("TSParameterProperty").bases("Pattern").build("parameter").field("accessibility", or("public", "private", "protected", void 0), defaults["undefined"]).field("readonly", Boolean, defaults["false"]).field("parameter", or(def("Identifier"), def("AssignmentPattern")));
      def("ClassProperty").field(
        "access",
        // Not "accessibility"?
        or("public", "private", "protected", void 0),
        defaults["undefined"]
      );
      def("ClassBody").field("body", [or(
        def("MethodDefinition"),
        def("VariableDeclarator"),
        def("ClassPropertyDefinition"),
        def("ClassProperty"),
        def("ClassPrivateProperty"),
        def("ClassMethod"),
        def("ClassPrivateMethod"),
        // Just need to add these types:
        def("TSDeclareMethod"),
        TSTypeMember
      )]);
    }
    __name(default_1, "default_1");
    exports2.default = default_1;
    module2.exports = exports2["default"];
  }
});

// ../../node_modules/ast-types/def/es-proposals.js
var require_es_proposals = __commonJS({
  "../../node_modules/ast-types/def/es-proposals.js"(exports2, module2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var types_1 = tslib_1.__importDefault(require_types2());
    var shared_1 = tslib_1.__importDefault(require_shared());
    var core_1 = tslib_1.__importDefault(require_core());
    function default_1(fork) {
      fork.use(core_1.default);
      var types2 = fork.use(types_1.default);
      var Type = types2.Type;
      var def = types2.Type.def;
      var or = Type.or;
      var shared = fork.use(shared_1.default);
      var defaults = shared.defaults;
      def("OptionalMemberExpression").bases("MemberExpression").build("object", "property", "computed", "optional").field("optional", Boolean, defaults["true"]);
      def("OptionalCallExpression").bases("CallExpression").build("callee", "arguments", "optional").field("optional", Boolean, defaults["true"]);
      var LogicalOperator = or("||", "&&", "??");
      def("LogicalExpression").field("operator", LogicalOperator);
    }
    __name(default_1, "default_1");
    exports2.default = default_1;
    module2.exports = exports2["default"];
  }
});

// ../../node_modules/ast-types/gen/namedTypes.js
var require_namedTypes = __commonJS({
  "../../node_modules/ast-types/gen/namedTypes.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.namedTypes = void 0;
    var namedTypes;
    /* @__PURE__ */ (function(namedTypes2) {
    })(namedTypes = exports2.namedTypes || (exports2.namedTypes = {}));
  }
});

// ../../node_modules/ast-types/main.js
var require_main4 = __commonJS({
  "../../node_modules/ast-types/main.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.visit = exports2.use = exports2.Type = exports2.someField = exports2.PathVisitor = exports2.Path = exports2.NodePath = exports2.namedTypes = exports2.getSupertypeNames = exports2.getFieldValue = exports2.getFieldNames = exports2.getBuilderName = exports2.finalize = exports2.eachField = exports2.defineMethod = exports2.builtInTypes = exports2.builders = exports2.astNodesAreEquivalent = void 0;
    var tslib_1 = (init_tslib_es6(), __toCommonJS(tslib_es6_exports));
    var fork_1 = tslib_1.__importDefault(require_fork());
    var core_1 = tslib_1.__importDefault(require_core());
    var es6_1 = tslib_1.__importDefault(require_es6());
    var es7_1 = tslib_1.__importDefault(require_es7());
    var es2020_1 = tslib_1.__importDefault(require_es2020());
    var jsx_1 = tslib_1.__importDefault(require_jsx());
    var flow_1 = tslib_1.__importDefault(require_flow());
    var esprima_1 = tslib_1.__importDefault(require_esprima2());
    var babel_1 = tslib_1.__importDefault(require_babel());
    var typescript_1 = tslib_1.__importDefault(require_typescript());
    var es_proposals_1 = tslib_1.__importDefault(require_es_proposals());
    var namedTypes_1 = require_namedTypes();
    Object.defineProperty(exports2, "namedTypes", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return namedTypes_1.namedTypes;
    }, "get") });
    var _a10 = fork_1.default([
      // This core module of AST types captures ES5 as it is parsed today by
      // git://github.com/ariya/esprima.git#master.
      core_1.default,
      // Feel free to add to or remove from this list of extension modules to
      // configure the precise type hierarchy that you need.
      es6_1.default,
      es7_1.default,
      es2020_1.default,
      jsx_1.default,
      flow_1.default,
      esprima_1.default,
      babel_1.default,
      typescript_1.default,
      es_proposals_1.default
    ]);
    var astNodesAreEquivalent = _a10.astNodesAreEquivalent;
    var builders = _a10.builders;
    var builtInTypes = _a10.builtInTypes;
    var defineMethod = _a10.defineMethod;
    var eachField = _a10.eachField;
    var finalize = _a10.finalize;
    var getBuilderName = _a10.getBuilderName;
    var getFieldNames = _a10.getFieldNames;
    var getFieldValue = _a10.getFieldValue;
    var getSupertypeNames = _a10.getSupertypeNames;
    var n10 = _a10.namedTypes;
    var NodePath = _a10.NodePath;
    var Path = _a10.Path;
    var PathVisitor = _a10.PathVisitor;
    var someField = _a10.someField;
    var Type = _a10.Type;
    var use = _a10.use;
    var visit = _a10.visit;
    exports2.astNodesAreEquivalent = astNodesAreEquivalent;
    exports2.builders = builders;
    exports2.builtInTypes = builtInTypes;
    exports2.defineMethod = defineMethod;
    exports2.eachField = eachField;
    exports2.finalize = finalize;
    exports2.getBuilderName = getBuilderName;
    exports2.getFieldNames = getFieldNames;
    exports2.getFieldValue = getFieldValue;
    exports2.getSupertypeNames = getSupertypeNames;
    exports2.NodePath = NodePath;
    exports2.Path = Path;
    exports2.PathVisitor = PathVisitor;
    exports2.someField = someField;
    exports2.Type = Type;
    exports2.use = use;
    exports2.visit = visit;
    Object.assign(namedTypes_1.namedTypes, n10);
  }
});

// ../../node_modules/degenerator/dist/degenerator.js
var require_degenerator = __commonJS({
  "../../node_modules/degenerator/dist/degenerator.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.degenerator = void 0;
    var util_1 = require("util");
    var escodegen_1 = require_escodegen();
    var esprima_1 = require_esprima();
    var ast_types_1 = require_main4();
    function degenerator(code, _names) {
      if (!Array.isArray(_names)) {
        throw new TypeError('an array of async function "names" is required');
      }
      const names = _names.slice(0);
      const ast = (0, esprima_1.parseScript)(code);
      let lastNamesLength = 0;
      do {
        lastNamesLength = names.length;
        (0, ast_types_1.visit)(ast, {
          visitVariableDeclaration(path47) {
            if (path47.node.declarations) {
              for (let i32 = 0; i32 < path47.node.declarations.length; i32++) {
                const declaration = path47.node.declarations[i32];
                if (ast_types_1.namedTypes.VariableDeclarator.check(declaration) && ast_types_1.namedTypes.Identifier.check(declaration.init) && ast_types_1.namedTypes.Identifier.check(declaration.id) && checkName(declaration.init.name, names) && !checkName(declaration.id.name, names)) {
                  names.push(declaration.id.name);
                }
              }
            }
            return false;
          },
          visitAssignmentExpression(path47) {
            if (ast_types_1.namedTypes.Identifier.check(path47.node.left) && ast_types_1.namedTypes.Identifier.check(path47.node.right) && checkName(path47.node.right.name, names) && !checkName(path47.node.left.name, names)) {
              names.push(path47.node.left.name);
            }
            return false;
          },
          visitFunction(path47) {
            if (path47.node.id) {
              let shouldDegenerate = false;
              (0, ast_types_1.visit)(path47.node, {
                visitCallExpression(path48) {
                  if (checkNames(path48.node, names)) {
                    shouldDegenerate = true;
                  }
                  return false;
                }
              });
              if (!shouldDegenerate) {
                return false;
              }
              path47.node.async = true;
              if (!checkName(path47.node.id.name, names)) {
                names.push(path47.node.id.name);
              }
            }
            this.traverse(path47);
          }
        });
      } while (lastNamesLength !== names.length);
      (0, ast_types_1.visit)(ast, {
        visitCallExpression(path47) {
          if (checkNames(path47.node, names)) {
            const delegate = false;
            const { name, parent: { node: pNode } } = path47;
            const expr = ast_types_1.builders.awaitExpression(path47.node, delegate);
            if (ast_types_1.namedTypes.CallExpression.check(pNode)) {
              pNode.arguments[name] = expr;
            } else {
              pNode[name] = expr;
            }
          }
          this.traverse(path47);
        }
      });
      return (0, escodegen_1.generate)(ast);
    }
    __name(degenerator, "degenerator");
    exports2.degenerator = degenerator;
    function checkNames({ callee }, names) {
      let name;
      if (ast_types_1.namedTypes.Identifier.check(callee)) {
        name = callee.name;
      } else if (ast_types_1.namedTypes.MemberExpression.check(callee)) {
        if (ast_types_1.namedTypes.Identifier.check(callee.object) && ast_types_1.namedTypes.Identifier.check(callee.property)) {
          name = `${callee.object.name}.${callee.property.name}`;
        } else {
          return false;
        }
      } else if (ast_types_1.namedTypes.FunctionExpression.check(callee)) {
        if (callee.id) {
          name = callee.id.name;
        } else {
          return false;
        }
      } else {
        throw new Error(`Don't know how to get name for: ${callee.type}`);
      }
      return checkName(name, names);
    }
    __name(checkNames, "checkNames");
    function checkName(name, names) {
      for (let i32 = 0; i32 < names.length; i32++) {
        const n10 = names[i32];
        if (util_1.types.isRegExp(n10)) {
          if (n10.test(name)) {
            return true;
          }
        } else if (name === n10) {
          return true;
        }
      }
      return false;
    }
    __name(checkName, "checkName");
  }
});

// ../../node_modules/degenerator/dist/compile.js
var require_compile2 = __commonJS({
  "../../node_modules/degenerator/dist/compile.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.compile = void 0;
    var util_1 = require("util");
    var degenerator_1 = require_degenerator();
    function compile(qjs, code, returnName, options = {}) {
      const compiled = (0, degenerator_1.degenerator)(code, options.names ?? []);
      const vm = qjs.newContext();
      if (options.sandbox) {
        for (const [name, value] of Object.entries(options.sandbox)) {
          if (typeof value !== "function") {
            throw new Error(`Expected a "function" for sandbox property \`${name}\`, but got "${typeof value}"`);
          }
          const fnHandle = vm.newFunction(name, (...args) => {
            const result2 = value(...args.map((arg) => quickJSHandleToHost(vm, arg)));
            vm.runtime.executePendingJobs();
            return hostToQuickJSHandle(vm, result2);
          });
          fnHandle.consume((handle) => vm.setProp(vm.global, name, handle));
        }
      }
      const fnResult = vm.evalCode(`${compiled};${returnName}`, options.filename);
      const fn = vm.unwrapResult(fnResult);
      const t = vm.typeof(fn);
      if (t !== "function") {
        throw new Error(`Expected a "function" named \`${returnName}\` to be defined, but got "${t}"`);
      }
      const r32 = /* @__PURE__ */ __name(async function(...args) {
        let promiseHandle;
        let resolvedHandle;
        try {
          const result2 = vm.callFunction(fn, vm.undefined, ...args.map((arg) => hostToQuickJSHandle(vm, arg)));
          promiseHandle = vm.unwrapResult(result2);
          const resolvedResultP = vm.resolvePromise(promiseHandle);
          vm.runtime.executePendingJobs();
          const resolvedResult = await resolvedResultP;
          resolvedHandle = vm.unwrapResult(resolvedResult);
          return quickJSHandleToHost(vm, resolvedHandle);
        } catch (err) {
          if (err && typeof err === "object" && "cause" in err && err.cause) {
            if (typeof err.cause === "object" && "stack" in err.cause && "name" in err.cause && "message" in err.cause && typeof err.cause.stack === "string" && typeof err.cause.name === "string" && typeof err.cause.message === "string") {
              err.cause.stack = `${err.cause.name}: ${err.cause.message}
${err.cause.stack}`;
            }
            throw err.cause;
          }
          throw err;
        } finally {
          promiseHandle?.dispose();
          resolvedHandle?.dispose();
        }
      }, "r");
      Object.defineProperty(r32, "toString", {
        value: /* @__PURE__ */ __name(() => compiled, "value"),
        enumerable: false
      });
      return r32;
    }
    __name(compile, "compile");
    exports2.compile = compile;
    function quickJSHandleToHost(vm, val) {
      return vm.dump(val);
    }
    __name(quickJSHandleToHost, "quickJSHandleToHost");
    function hostToQuickJSHandle(vm, val) {
      if (typeof val === "undefined") {
        return vm.undefined;
      } else if (val === null) {
        return vm.null;
      } else if (typeof val === "string") {
        return vm.newString(val);
      } else if (typeof val === "number") {
        return vm.newNumber(val);
      } else if (typeof val === "bigint") {
        return vm.newBigInt(val);
      } else if (typeof val === "boolean") {
        return val ? vm.true : vm.false;
      } else if (util_1.types.isPromise(val)) {
        const promise = vm.newPromise();
        promise.settled.then(vm.runtime.executePendingJobs);
        val.then((r32) => {
          promise.resolve(hostToQuickJSHandle(vm, r32));
        }, (err) => {
          promise.reject(hostToQuickJSHandle(vm, err));
        });
        return promise.handle;
      } else if (util_1.types.isNativeError(val)) {
        return vm.newError(val);
      }
      throw new Error(`Unsupported value: ${val}`);
    }
    __name(hostToQuickJSHandle, "hostToQuickJSHandle");
  }
});

// ../../node_modules/degenerator/dist/index.js
var require_dist10 = __commonJS({
  "../../node_modules/degenerator/dist/index.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __exportStar3 = exports2 && exports2.__exportStar || function(m20, exports3) {
      for (var p10 in m20) if (p10 !== "default" && !Object.prototype.hasOwnProperty.call(exports3, p10)) __createBinding3(exports3, m20, p10);
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    __exportStar3(require_degenerator(), exports2);
    __exportStar3(require_compile2(), exports2);
  }
});

// ../../node_modules/pac-resolver/dist/dateRange.js
var require_dateRange = __commonJS({
  "../../node_modules/pac-resolver/dist/dateRange.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    function dateRange() {
      return false;
    }
    __name(dateRange, "dateRange");
    exports2.default = dateRange;
  }
});

// ../../node_modules/pac-resolver/dist/dnsDomainIs.js
var require_dnsDomainIs = __commonJS({
  "../../node_modules/pac-resolver/dist/dnsDomainIs.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    function dnsDomainIs(host, domain) {
      host = String(host);
      domain = String(domain);
      return host.substr(domain.length * -1) === domain;
    }
    __name(dnsDomainIs, "dnsDomainIs");
    exports2.default = dnsDomainIs;
  }
});

// ../../node_modules/pac-resolver/dist/dnsDomainLevels.js
var require_dnsDomainLevels = __commonJS({
  "../../node_modules/pac-resolver/dist/dnsDomainLevels.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    function dnsDomainLevels(host) {
      const match = String(host).match(/\./g);
      let levels2 = 0;
      if (match) {
        levels2 = match.length;
      }
      return levels2;
    }
    __name(dnsDomainLevels, "dnsDomainLevels");
    exports2.default = dnsDomainLevels;
  }
});

// ../../node_modules/pac-resolver/dist/util.js
var require_util4 = __commonJS({
  "../../node_modules/pac-resolver/dist/util.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isGMT = exports2.dnsLookup = void 0;
    var dns_1 = require("dns");
    function dnsLookup(host, opts) {
      return new Promise((resolve13, reject) => {
        (0, dns_1.lookup)(host, opts, (err, res) => {
          if (err) {
            reject(err);
          } else {
            resolve13(res);
          }
        });
      });
    }
    __name(dnsLookup, "dnsLookup");
    exports2.dnsLookup = dnsLookup;
    function isGMT(v) {
      return v === "GMT";
    }
    __name(isGMT, "isGMT");
    exports2.isGMT = isGMT;
  }
});

// ../../node_modules/pac-resolver/dist/dnsResolve.js
var require_dnsResolve = __commonJS({
  "../../node_modules/pac-resolver/dist/dnsResolve.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var util_1 = require_util4();
    async function dnsResolve(host) {
      const family = 4;
      try {
        const r32 = await (0, util_1.dnsLookup)(host, { family });
        if (typeof r32 === "string") {
          return r32;
        }
      } catch (err) {
      }
      return null;
    }
    __name(dnsResolve, "dnsResolve");
    exports2.default = dnsResolve;
  }
});

// ../../node_modules/netmask/dist/netmask4.js
var require_netmask4 = __commonJS({
  "../../node_modules/netmask/dist/netmask4.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.Netmask4Impl = void 0;
    exports2.ip2long = ip2long;
    exports2.long2ip = long2ip;
    function long2ip(long) {
      const a32 = (long & 255 << 24) >>> 24;
      const b32 = (long & 255 << 16) >>> 16;
      const c32 = (long & 255 << 8) >>> 8;
      const d32 = long & 255;
      return [a32, b32, c32, d32].join(".");
    }
    __name(long2ip, "long2ip");
    var chr0 = "0".charCodeAt(0);
    var chra = "a".charCodeAt(0);
    var chrA = "A".charCodeAt(0);
    function parseNum(s) {
      let n10 = 0;
      let base = 10;
      let dmax = "9";
      let i32 = 0;
      if (s.length > 1 && s[i32] === "0") {
        if (s[i32 + 1] === "x" || s[i32 + 1] === "X") {
          i32 += 2;
          base = 16;
        } else if ("0" <= s[i32 + 1] && s[i32 + 1] <= "9") {
          i32++;
          base = 8;
          dmax = "7";
        }
      }
      const start = i32;
      while (i32 < s.length) {
        if ("0" <= s[i32] && s[i32] <= dmax) {
          n10 = n10 * base + (s.charCodeAt(i32) - chr0) >>> 0;
        } else if (base === 16) {
          if ("a" <= s[i32] && s[i32] <= "f") {
            n10 = n10 * base + (10 + s.charCodeAt(i32) - chra) >>> 0;
          } else if ("A" <= s[i32] && s[i32] <= "F") {
            n10 = n10 * base + (10 + s.charCodeAt(i32) - chrA) >>> 0;
          } else {
            break;
          }
        } else {
          break;
        }
        if (n10 > 4294967295) {
          throw new Error("too large");
        }
        i32++;
      }
      if (i32 === start) {
        throw new Error("empty octet");
      }
      return [n10, i32];
    }
    __name(parseNum, "parseNum");
    function ip2long(ip) {
      const b32 = [];
      for (let i32 = 0; i32 <= 3; i32++) {
        if (ip.length === 0) {
          break;
        }
        if (i32 > 0) {
          if (ip[0] !== ".") {
            throw new Error("Invalid IP");
          }
          ip = ip.substring(1);
        }
        const [n10, c32] = parseNum(ip);
        ip = ip.substring(c32);
        b32.push(n10);
      }
      if (ip.length !== 0) {
        throw new Error("Invalid IP");
      }
      switch (b32.length) {
        case 1:
          if (b32[0] > 4294967295) {
            throw new Error("Invalid IP");
          }
          return b32[0] >>> 0;
        case 2:
          if (b32[0] > 255 || b32[1] > 16777215) {
            throw new Error("Invalid IP");
          }
          return (b32[0] << 24 | b32[1]) >>> 0;
        case 3:
          if (b32[0] > 255 || b32[1] > 255 || b32[2] > 65535) {
            throw new Error("Invalid IP");
          }
          return (b32[0] << 24 | b32[1] << 16 | b32[2]) >>> 0;
        case 4:
          if (b32[0] > 255 || b32[1] > 255 || b32[2] > 255 || b32[3] > 255) {
            throw new Error("Invalid IP");
          }
          return (b32[0] << 24 | b32[1] << 16 | b32[2] << 8 | b32[3]) >>> 0;
        default:
          throw new Error("Invalid IP");
      }
    }
    __name(ip2long, "ip2long");
    var Netmask4Impl = class _Netmask4Impl {
      static {
        __name(this, "Netmask4Impl");
      }
      constructor(net, mask) {
        if (typeof net !== "string") {
          throw new Error("Missing `net' parameter");
        }
        let maskStr = mask;
        if (!maskStr) {
          const parts = net.split("/", 2);
          net = parts[0];
          maskStr = parts[1];
        }
        if (!maskStr) {
          maskStr = 32;
        }
        if (typeof maskStr === "string" && maskStr.indexOf(".") > -1) {
          try {
            this.maskLong = ip2long(maskStr);
          } catch (error4) {
            throw new Error("Invalid mask: " + maskStr);
          }
          this.bitmask = NaN;
          for (let i32 = 32; i32 >= 0; i32--) {
            if (this.maskLong === 4294967295 << 32 - i32 >>> 0) {
              this.bitmask = i32;
              break;
            }
          }
        } else if (maskStr || maskStr === 0) {
          this.bitmask = parseInt(maskStr, 10);
          this.maskLong = 0;
          if (this.bitmask > 0) {
            this.maskLong = 4294967295 << 32 - this.bitmask >>> 0;
          }
        } else {
          throw new Error("Invalid mask: empty");
        }
        try {
          this.netLong = (ip2long(net) & this.maskLong) >>> 0;
        } catch (error4) {
          throw new Error("Invalid net address: " + net);
        }
        if (!(this.bitmask <= 32)) {
          throw new Error("Invalid mask for ip4: " + maskStr);
        }
        this.size = Math.pow(2, 32 - this.bitmask);
        this.base = long2ip(this.netLong);
        this.mask = long2ip(this.maskLong);
        this.hostmask = long2ip(~this.maskLong);
        this.first = this.bitmask <= 30 ? long2ip(this.netLong + 1) : this.base;
        this.last = this.bitmask <= 30 ? long2ip(this.netLong + this.size - 2) : long2ip(this.netLong + this.size - 1);
        this.broadcast = this.bitmask <= 30 ? long2ip(this.netLong + this.size - 1) : void 0;
      }
      contains(ip) {
        if (typeof ip === "string" && (ip.indexOf("/") > 0 || ip.split(".").length !== 4)) {
          ip = new _Netmask4Impl(ip);
        }
        if (ip instanceof _Netmask4Impl) {
          return this.contains(ip.base) && this.contains(ip.broadcast || ip.last);
        } else {
          return (ip2long(ip) & this.maskLong) >>> 0 === (this.netLong & this.maskLong) >>> 0;
        }
      }
      next(count = 1) {
        return new _Netmask4Impl(long2ip(this.netLong + this.size * count), this.mask);
      }
      forEach(fn) {
        let long = ip2long(this.first);
        const lastLong = ip2long(this.last);
        let index = 0;
        while (long <= lastLong) {
          fn(long2ip(long), long, index);
          index++;
          long++;
        }
      }
      toString() {
        return this.base + "/" + this.bitmask;
      }
    };
    exports2.Netmask4Impl = Netmask4Impl;
  }
});

// ../../node_modules/netmask/dist/netmask6.js
var require_netmask6 = __commonJS({
  "../../node_modules/netmask/dist/netmask6.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.Netmask6Impl = void 0;
    exports2.ip6bigint = ip6bigint;
    exports2.bigint2ip6 = bigint2ip6;
    var netmask4_1 = require_netmask4();
    var MAX_IPV6 = (1n << 128n) - 1n;
    function ip6bigint(ip) {
      const zoneIdx = ip.indexOf("%");
      if (zoneIdx !== -1) {
        ip = ip.substring(0, zoneIdx);
      }
      const lastColon = ip.lastIndexOf(":");
      if (lastColon !== -1 && ip.indexOf(".", lastColon) !== -1) {
        const ipv4Part = ip.substring(lastColon + 1);
        const ipv4Long = (0, netmask4_1.ip2long)(ipv4Part);
        const ipv6Prefix = ip.substring(0, lastColon + 1) + "0:0";
        const prefixVal = parseIPv6Pure(ipv6Prefix);
        return prefixVal & ~0xffffffffn | BigInt(ipv4Long);
      }
      return parseIPv6Pure(ip);
    }
    __name(ip6bigint, "ip6bigint");
    function parseIPv6Pure(ip) {
      const doubleColonIdx = ip.indexOf("::");
      let groups;
      if (doubleColonIdx !== -1) {
        const left = ip.substring(0, doubleColonIdx);
        const right = ip.substring(doubleColonIdx + 2);
        const leftGroups = left === "" ? [] : left.split(":");
        const rightGroups = right === "" ? [] : right.split(":");
        const missing = 8 - leftGroups.length - rightGroups.length;
        if (missing < 0) {
          throw new Error("Invalid IPv6: too many groups");
        }
        groups = [...leftGroups, ...Array(missing).fill("0"), ...rightGroups];
      } else {
        groups = ip.split(":");
      }
      if (groups.length !== 8) {
        throw new Error("Invalid IPv6: expected 8 groups, got " + groups.length);
      }
      let result2 = 0n;
      for (let i32 = 0; i32 < 8; i32++) {
        const g32 = groups[i32];
        if (g32.length === 0 || g32.length > 4) {
          throw new Error('Invalid IPv6: bad group "' + g32 + '"');
        }
        const val = parseInt(g32, 16);
        if (isNaN(val) || val < 0 || val > 65535) {
          throw new Error('Invalid IPv6: bad group "' + g32 + '"');
        }
        result2 = result2 << 16n | BigInt(val);
      }
      return result2;
    }
    __name(parseIPv6Pure, "parseIPv6Pure");
    function bigint2ip6(n10) {
      if (n10 < 0n || n10 > MAX_IPV6) {
        throw new Error("Invalid IPv6 address value");
      }
      const groups = [];
      for (let i32 = 0; i32 < 8; i32++) {
        groups.unshift(Number(n10 & 0xffffn));
        n10 >>= 16n;
      }
      let bestStart = -1;
      let bestLen = 0;
      let curStart = -1;
      let curLen = 0;
      for (let i32 = 0; i32 < 8; i32++) {
        if (groups[i32] === 0) {
          if (curStart === -1) {
            curStart = i32;
            curLen = 1;
          } else {
            curLen++;
          }
        } else {
          if (curLen > bestLen && curLen >= 2) {
            bestStart = curStart;
            bestLen = curLen;
          }
          curStart = -1;
          curLen = 0;
        }
      }
      if (curLen > bestLen && curLen >= 2) {
        bestStart = curStart;
        bestLen = curLen;
      }
      if (bestStart !== -1 && bestStart + bestLen === 8 && bestStart > 0) {
        const before = groups.slice(0, bestStart).map((g32) => g32.toString(16));
        return before.join(":") + "::";
      } else if (bestStart === 0) {
        const after = groups.slice(bestLen).map((g32) => g32.toString(16));
        return "::" + after.join(":");
      } else if (bestStart > 0) {
        const before = groups.slice(0, bestStart).map((g32) => g32.toString(16));
        const after = groups.slice(bestStart + bestLen).map((g32) => g32.toString(16));
        return before.join(":") + "::" + after.join(":");
      } else {
        return groups.map((g32) => g32.toString(16)).join(":");
      }
    }
    __name(bigint2ip6, "bigint2ip6");
    var Netmask6Impl = class _Netmask6Impl {
      static {
        __name(this, "Netmask6Impl");
      }
      constructor(net, mask) {
        if (typeof net !== "string") {
          throw new Error("Missing `net' parameter");
        }
        let prefixLen = mask;
        if (prefixLen === void 0 || prefixLen === null) {
          const slashIdx = net.indexOf("/");
          if (slashIdx !== -1) {
            prefixLen = parseInt(net.substring(slashIdx + 1), 10);
            net = net.substring(0, slashIdx);
          } else {
            prefixLen = 128;
          }
        }
        if (isNaN(prefixLen) || prefixLen < 0 || prefixLen > 128) {
          throw new Error("Invalid mask for IPv6: " + prefixLen);
        }
        this.bitmask = prefixLen;
        if (this.bitmask === 0) {
          this.maskBigint = 0n;
        } else {
          this.maskBigint = MAX_IPV6 >> BigInt(128 - this.bitmask) << BigInt(128 - this.bitmask);
        }
        try {
          this.netBigint = ip6bigint(net) & this.maskBigint;
        } catch (error4) {
          throw new Error("Invalid IPv6 net address: " + net);
        }
        this.size = Number(1n << BigInt(128 - this.bitmask));
        this.base = bigint2ip6(this.netBigint);
        this.mask = bigint2ip6(this.maskBigint);
        this.hostmask = bigint2ip6(~this.maskBigint & MAX_IPV6);
        this.first = this.base;
        this.last = bigint2ip6(this.netBigint + (1n << BigInt(128 - this.bitmask)) - 1n);
        this.broadcast = void 0;
      }
      contains(ip) {
        if (typeof ip === "string") {
          if (ip.indexOf("/") > 0) {
            ip = new _Netmask6Impl(ip);
          }
        }
        if (ip instanceof _Netmask6Impl) {
          return this.contains(ip.base) && this.contains(ip.last);
        } else {
          const addr = ip6bigint(ip);
          return (addr & this.maskBigint) === this.netBigint;
        }
      }
      next(count = 1) {
        const sizeBig = 1n << BigInt(128 - this.bitmask);
        return new _Netmask6Impl(bigint2ip6(this.netBigint + sizeBig * BigInt(count)), this.bitmask);
      }
      forEach(fn) {
        let addr = this.netBigint;
        const sizeBig = 1n << BigInt(128 - this.bitmask);
        const lastAddr = this.netBigint + sizeBig - 1n;
        let index = 0;
        while (addr <= lastAddr) {
          fn(bigint2ip6(addr), Number(addr), index);
          index++;
          addr++;
        }
      }
      toString() {
        return this.base + "/" + this.bitmask;
      }
    };
    exports2.Netmask6Impl = Netmask6Impl;
  }
});

// ../../node_modules/netmask/dist/netmask.js
var require_netmask = __commonJS({
  "../../node_modules/netmask/dist/netmask.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.long2ip = exports2.ip2long = exports2.Netmask = void 0;
    var netmask4_1 = require_netmask4();
    Object.defineProperty(exports2, "ip2long", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return netmask4_1.ip2long;
    }, "get") });
    Object.defineProperty(exports2, "long2ip", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return netmask4_1.long2ip;
    }, "get") });
    var netmask6_1 = require_netmask6();
    var Netmask = class _Netmask {
      static {
        __name(this, "Netmask");
      }
      constructor(net, mask) {
        if (typeof net !== "string") {
          throw new Error("Missing `net' parameter");
        }
        const addrPart = net.indexOf("/") !== -1 ? net.substring(0, net.indexOf("/")) : net;
        if (addrPart.indexOf(":") !== -1) {
          this._impl = new netmask6_1.Netmask6Impl(net, mask);
        } else {
          this._impl = new netmask4_1.Netmask4Impl(net, mask);
        }
        this.base = this._impl.base;
        this.mask = this._impl.mask;
        this.hostmask = this._impl.hostmask;
        this.bitmask = this._impl.bitmask;
        this.size = this._impl.size;
        this.first = this._impl.first;
        this.last = this._impl.last;
        this.broadcast = this._impl.broadcast;
        if (this._impl instanceof netmask4_1.Netmask4Impl) {
          this.maskLong = this._impl.maskLong;
          this.netLong = this._impl.netLong;
        } else {
          this.maskLong = 0;
          this.netLong = 0;
        }
      }
      contains(ip) {
        if (typeof ip === "string") {
          if (ip.indexOf("/") > 0) {
            ip = new _Netmask(ip);
          } else if (ip.indexOf(":") === -1 && ip.split(".").length !== 4) {
            ip = new _Netmask(ip);
          }
        }
        if (ip instanceof _Netmask) {
          return this.contains(ip.base) && this.contains(ip.broadcast || ip.last);
        }
        return this._impl.contains(ip);
      }
      next(count = 1) {
        const nextImpl = this._impl.next(count);
        const result2 = new _Netmask(nextImpl.base, nextImpl.bitmask);
        return result2;
      }
      /** @deprecated */
      forEach(fn) {
        this._impl.forEach(fn);
      }
      toString() {
        return this._impl.toString();
      }
    };
    exports2.Netmask = Netmask;
  }
});

// ../../node_modules/pac-resolver/dist/isInNet.js
var require_isInNet = __commonJS({
  "../../node_modules/pac-resolver/dist/isInNet.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var netmask_1 = require_netmask();
    var util_1 = require_util4();
    async function isInNet(host, pattern, mask) {
      const family = 4;
      try {
        const ip = await (0, util_1.dnsLookup)(host, { family });
        if (typeof ip === "string") {
          const netmask = new netmask_1.Netmask(pattern, mask);
          return netmask.contains(ip);
        }
      } catch (err) {
      }
      return false;
    }
    __name(isInNet, "isInNet");
    exports2.default = isInNet;
  }
});

// ../../node_modules/pac-resolver/dist/isPlainHostName.js
var require_isPlainHostName = __commonJS({
  "../../node_modules/pac-resolver/dist/isPlainHostName.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    function isPlainHostName(host) {
      return !/\./.test(host);
    }
    __name(isPlainHostName, "isPlainHostName");
    exports2.default = isPlainHostName;
  }
});

// ../../node_modules/pac-resolver/dist/isResolvable.js
var require_isResolvable = __commonJS({
  "../../node_modules/pac-resolver/dist/isResolvable.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var util_1 = require_util4();
    async function isResolvable(host) {
      const family = 4;
      try {
        if (await (0, util_1.dnsLookup)(host, { family })) {
          return true;
        }
      } catch (err) {
      }
      return false;
    }
    __name(isResolvable, "isResolvable");
    exports2.default = isResolvable;
  }
});

// ../../node_modules/pac-resolver/dist/localHostOrDomainIs.js
var require_localHostOrDomainIs = __commonJS({
  "../../node_modules/pac-resolver/dist/localHostOrDomainIs.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    function localHostOrDomainIs(host, hostdom) {
      const parts = host.split(".");
      const domparts = hostdom.split(".");
      let matches = true;
      for (let i32 = 0; i32 < parts.length; i32++) {
        if (parts[i32] !== domparts[i32]) {
          matches = false;
          break;
        }
      }
      return matches;
    }
    __name(localHostOrDomainIs, "localHostOrDomainIs");
    exports2.default = localHostOrDomainIs;
  }
});

// ../../node_modules/pac-resolver/dist/ip.js
var require_ip = __commonJS({
  "../../node_modules/pac-resolver/dist/ip.js"(exports2) {
    "use strict";
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ip = void 0;
    var os_1 = __importDefault2(require("os"));
    exports2.ip = {
      address() {
        const interfaces = os_1.default.networkInterfaces();
        const family = normalizeFamily();
        const all = Object.values(interfaces).map((addrs = []) => {
          const addresses = addrs.filter((details) => {
            const detailsFamily = normalizeFamily(details.family);
            if (detailsFamily !== family || exports2.ip.isLoopback(details.address)) {
              return false;
            }
            return true;
          });
          return addresses.length ? addresses[0].address : void 0;
        }).filter(Boolean);
        return !all.length ? exports2.ip.loopback(family) : all[0];
      },
      isLoopback(addr) {
        return /^(::f{4}:)?127\.([0-9]{1,3})\.([0-9]{1,3})\.([0-9]{1,3})/.test(addr) || /^fe80::1$/.test(addr) || /^::1$/.test(addr) || /^::$/.test(addr);
      },
      loopback(family) {
        family = normalizeFamily(family);
        if (family !== "ipv4" && family !== "ipv6") {
          throw new Error("family must be ipv4 or ipv6");
        }
        return family === "ipv4" ? "127.0.0.1" : "fe80::1";
      }
    };
    function normalizeFamily(family) {
      if (family === 4) {
        return "ipv4";
      }
      if (family === 6) {
        return "ipv6";
      }
      return family ? family.toLowerCase() : "ipv4";
    }
    __name(normalizeFamily, "normalizeFamily");
  }
});

// ../../node_modules/pac-resolver/dist/myIpAddress.js
var require_myIpAddress = __commonJS({
  "../../node_modules/pac-resolver/dist/myIpAddress.js"(exports2) {
    "use strict";
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    var ip_1 = require_ip();
    var net_1 = __importDefault2(require("net"));
    async function myIpAddress() {
      return new Promise((resolve13, reject) => {
        const socket = net_1.default.connect({ host: "8.8.8.8", port: 53 });
        const onError = /* @__PURE__ */ __name(() => {
          resolve13(ip_1.ip.address());
        }, "onError");
        socket.once("error", onError);
        socket.once("connect", () => {
          socket.removeListener("error", onError);
          const addr = socket.address();
          socket.destroy();
          if (typeof addr === "string") {
            resolve13(addr);
          } else if (addr.address) {
            resolve13(addr.address);
          } else {
            reject(new Error("Expected a `string`"));
          }
        });
      });
    }
    __name(myIpAddress, "myIpAddress");
    exports2.default = myIpAddress;
  }
});

// ../../node_modules/pac-resolver/dist/shExpMatch.js
var require_shExpMatch = __commonJS({
  "../../node_modules/pac-resolver/dist/shExpMatch.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    function shExpMatch(str, shexp) {
      const re = toRegExp(shexp);
      return re.test(str);
    }
    __name(shExpMatch, "shExpMatch");
    exports2.default = shExpMatch;
    function toRegExp(str) {
      str = String(str).replace(/\./g, "\\.").replace(/\?/g, ".").replace(/\*/g, ".*");
      return new RegExp(`^${str}$`);
    }
    __name(toRegExp, "toRegExp");
  }
});

// ../../node_modules/pac-resolver/dist/timeRange.js
var require_timeRange = __commonJS({
  "../../node_modules/pac-resolver/dist/timeRange.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    function timeRange() {
      const args = Array.prototype.slice.call(arguments);
      const lastArg = args.pop();
      const useGMTzone = lastArg === "GMT";
      const currentDate = /* @__PURE__ */ new Date();
      if (!useGMTzone) {
        args.push(lastArg);
      }
      let result2 = false;
      const noOfArgs = args.length;
      const numericArgs = args.map((n10) => parseInt(n10, 10));
      if (noOfArgs === 1) {
        result2 = getCurrentHour(useGMTzone, currentDate) === numericArgs[0];
      } else if (noOfArgs === 2) {
        const currentHour = getCurrentHour(useGMTzone, currentDate);
        result2 = numericArgs[0] <= currentHour && currentHour < numericArgs[1];
      } else if (noOfArgs === 4) {
        result2 = valueInRange(secondsElapsedToday(numericArgs[0], numericArgs[1], 0), secondsElapsedToday(getCurrentHour(useGMTzone, currentDate), getCurrentMinute(useGMTzone, currentDate), 0), secondsElapsedToday(numericArgs[2], numericArgs[3], 59));
      } else if (noOfArgs === 6) {
        result2 = valueInRange(secondsElapsedToday(numericArgs[0], numericArgs[1], numericArgs[2]), secondsElapsedToday(getCurrentHour(useGMTzone, currentDate), getCurrentMinute(useGMTzone, currentDate), getCurrentSecond(useGMTzone, currentDate)), secondsElapsedToday(numericArgs[3], numericArgs[4], numericArgs[5]));
      }
      return result2;
    }
    __name(timeRange, "timeRange");
    exports2.default = timeRange;
    function secondsElapsedToday(hh, mm, ss) {
      return hh * 3600 + mm * 60 + ss;
    }
    __name(secondsElapsedToday, "secondsElapsedToday");
    function getCurrentHour(gmt, currentDate) {
      return gmt ? currentDate.getUTCHours() : currentDate.getHours();
    }
    __name(getCurrentHour, "getCurrentHour");
    function getCurrentMinute(gmt, currentDate) {
      return gmt ? currentDate.getUTCMinutes() : currentDate.getMinutes();
    }
    __name(getCurrentMinute, "getCurrentMinute");
    function getCurrentSecond(gmt, currentDate) {
      return gmt ? currentDate.getUTCSeconds() : currentDate.getSeconds();
    }
    __name(getCurrentSecond, "getCurrentSecond");
    function valueInRange(start, value, finish) {
      return start <= value && value <= finish;
    }
    __name(valueInRange, "valueInRange");
  }
});

// ../../node_modules/pac-resolver/dist/weekdayRange.js
var require_weekdayRange = __commonJS({
  "../../node_modules/pac-resolver/dist/weekdayRange.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    var util_1 = require_util4();
    var weekdays = ["SUN", "MON", "TUE", "WED", "THU", "FRI", "SAT"];
    function weekdayRange(wd1, wd2, gmt) {
      let useGMTzone = false;
      let wd1Index = -1;
      let wd2Index = -1;
      let wd2IsGmt = false;
      if ((0, util_1.isGMT)(gmt)) {
        useGMTzone = true;
      } else if ((0, util_1.isGMT)(wd2)) {
        useGMTzone = true;
        wd2IsGmt = true;
      }
      wd1Index = weekdays.indexOf(wd1);
      if (!wd2IsGmt && isWeekday(wd2)) {
        wd2Index = weekdays.indexOf(wd2);
      }
      const todaysDay = getTodaysDay(useGMTzone);
      let result2;
      if (wd2Index < 0) {
        result2 = todaysDay === wd1Index;
      } else if (wd1Index <= wd2Index) {
        result2 = valueInRange(wd1Index, todaysDay, wd2Index);
      } else {
        result2 = valueInRange(wd1Index, todaysDay, 6) || valueInRange(0, todaysDay, wd2Index);
      }
      return result2;
    }
    __name(weekdayRange, "weekdayRange");
    exports2.default = weekdayRange;
    function getTodaysDay(gmt) {
      return gmt ? (/* @__PURE__ */ new Date()).getUTCDay() : (/* @__PURE__ */ new Date()).getDay();
    }
    __name(getTodaysDay, "getTodaysDay");
    function valueInRange(start, value, finish) {
      return start <= value && value <= finish;
    }
    __name(valueInRange, "valueInRange");
    function isWeekday(v) {
      if (!v)
        return false;
      return weekdays.includes(v);
    }
    __name(isWeekday, "isWeekday");
  }
});

// ../../node_modules/pac-resolver/dist/index.js
var require_dist11 = __commonJS({
  "../../node_modules/pac-resolver/dist/index.js"(exports2) {
    "use strict";
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.sandbox = exports2.createPacResolver = void 0;
    var degenerator_1 = require_dist10();
    var dateRange_1 = __importDefault2(require_dateRange());
    var dnsDomainIs_1 = __importDefault2(require_dnsDomainIs());
    var dnsDomainLevels_1 = __importDefault2(require_dnsDomainLevels());
    var dnsResolve_1 = __importDefault2(require_dnsResolve());
    var isInNet_1 = __importDefault2(require_isInNet());
    var isPlainHostName_1 = __importDefault2(require_isPlainHostName());
    var isResolvable_1 = __importDefault2(require_isResolvable());
    var localHostOrDomainIs_1 = __importDefault2(require_localHostOrDomainIs());
    var myIpAddress_1 = __importDefault2(require_myIpAddress());
    var shExpMatch_1 = __importDefault2(require_shExpMatch());
    var timeRange_1 = __importDefault2(require_timeRange());
    var weekdayRange_1 = __importDefault2(require_weekdayRange());
    function createPacResolver(qjs, _str, _opts = {}) {
      const str = Buffer.isBuffer(_str) ? _str.toString("utf8") : _str;
      const context = {
        ...exports2.sandbox,
        ..._opts.sandbox
      };
      const names = Object.keys(context).filter((k32) => isAsyncFunction(context[k32]));
      const opts = {
        filename: "proxy.pac",
        names,
        ..._opts,
        sandbox: context
      };
      const resolver = (0, degenerator_1.compile)(qjs, str, "FindProxyForURL", opts);
      function FindProxyForURL(url, _host) {
        const urlObj = typeof url === "string" ? new URL(url) : url;
        const host = _host || urlObj.hostname;
        if (!host) {
          throw new TypeError("Could not determine `host`");
        }
        return resolver(urlObj.href, host);
      }
      __name(FindProxyForURL, "FindProxyForURL");
      Object.defineProperty(FindProxyForURL, "toString", {
        value: /* @__PURE__ */ __name(() => resolver.toString(), "value"),
        enumerable: false
      });
      return FindProxyForURL;
    }
    __name(createPacResolver, "createPacResolver");
    exports2.createPacResolver = createPacResolver;
    exports2.sandbox = Object.freeze({
      alert: /* @__PURE__ */ __name((message2 = "") => console.log("%s", message2), "alert"),
      dateRange: dateRange_1.default,
      dnsDomainIs: dnsDomainIs_1.default,
      dnsDomainLevels: dnsDomainLevels_1.default,
      dnsResolve: dnsResolve_1.default,
      isInNet: isInNet_1.default,
      isPlainHostName: isPlainHostName_1.default,
      isResolvable: isResolvable_1.default,
      localHostOrDomainIs: localHostOrDomainIs_1.default,
      myIpAddress: myIpAddress_1.default,
      shExpMatch: shExpMatch_1.default,
      timeRange: timeRange_1.default,
      weekdayRange: weekdayRange_1.default
    });
    function isAsyncFunction(v) {
      if (typeof v !== "function")
        return false;
      if (v.constructor.name === "AsyncFunction")
        return true;
      if (String(v).indexOf("__awaiter(") !== -1)
        return true;
      return Boolean(v.async);
    }
    __name(isAsyncFunction, "isAsyncFunction");
  }
});

// ../../node_modules/@tootallnate/quickjs-emscripten/dist/esmHelpers.js
var require_esmHelpers = __commonJS({
  "../../node_modules/@tootallnate/quickjs-emscripten/dist/esmHelpers.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.unwrapJavascript = exports2.unwrapTypescript = void 0;
    function fakeUnwrapDefault(mod) {
      return mod.default;
    }
    __name(fakeUnwrapDefault, "fakeUnwrapDefault");
    function actualUnwrapDefault(mod) {
      const maybeUnwrap = mod.default;
      return maybeUnwrap ?? mod;
    }
    __name(actualUnwrapDefault, "actualUnwrapDefault");
    exports2.unwrapTypescript = actualUnwrapDefault;
    exports2.unwrapJavascript = fakeUnwrapDefault;
  }
});

// ../../node_modules/@tootallnate/quickjs-emscripten/dist/debug.js
var require_debug3 = __commonJS({
  "../../node_modules/@tootallnate/quickjs-emscripten/dist/debug.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.debugLog = exports2.QTS_DEBUG = void 0;
    exports2.QTS_DEBUG = Boolean(typeof process === "object" && process.env.QTS_DEBUG);
    exports2.debugLog = exports2.QTS_DEBUG ? console.log.bind(console) : () => {
    };
  }
});

// ../../node_modules/@tootallnate/quickjs-emscripten/dist/errors.js
var require_errors19 = __commonJS({
  "../../node_modules/@tootallnate/quickjs-emscripten/dist/errors.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.QuickJSMemoryLeakDetected = exports2.QuickJSAsyncifySuspended = exports2.QuickJSAsyncifyError = exports2.QuickJSNotImplemented = exports2.QuickJSUseAfterFree = exports2.QuickJSWrongOwner = exports2.QuickJSUnwrapError = void 0;
    var QuickJSUnwrapError = class extends Error {
      static {
        __name(this, "QuickJSUnwrapError");
      }
      constructor(cause, context) {
        super(String(cause));
        this.cause = cause;
        this.context = context;
        this.name = "QuickJSUnwrapError";
      }
    };
    exports2.QuickJSUnwrapError = QuickJSUnwrapError;
    var QuickJSWrongOwner = class extends Error {
      static {
        __name(this, "QuickJSWrongOwner");
      }
      constructor() {
        super(...arguments);
        this.name = "QuickJSWrongOwner";
      }
    };
    exports2.QuickJSWrongOwner = QuickJSWrongOwner;
    var QuickJSUseAfterFree = class extends Error {
      static {
        __name(this, "QuickJSUseAfterFree");
      }
      constructor() {
        super(...arguments);
        this.name = "QuickJSUseAfterFree";
      }
    };
    exports2.QuickJSUseAfterFree = QuickJSUseAfterFree;
    var QuickJSNotImplemented = class extends Error {
      static {
        __name(this, "QuickJSNotImplemented");
      }
      constructor() {
        super(...arguments);
        this.name = "QuickJSNotImplemented";
      }
    };
    exports2.QuickJSNotImplemented = QuickJSNotImplemented;
    var QuickJSAsyncifyError = class extends Error {
      static {
        __name(this, "QuickJSAsyncifyError");
      }
      constructor() {
        super(...arguments);
        this.name = "QuickJSAsyncifyError";
      }
    };
    exports2.QuickJSAsyncifyError = QuickJSAsyncifyError;
    var QuickJSAsyncifySuspended = class extends Error {
      static {
        __name(this, "QuickJSAsyncifySuspended");
      }
      constructor() {
        super(...arguments);
        this.name = "QuickJSAsyncifySuspended";
      }
    };
    exports2.QuickJSAsyncifySuspended = QuickJSAsyncifySuspended;
    var QuickJSMemoryLeakDetected = class extends Error {
      static {
        __name(this, "QuickJSMemoryLeakDetected");
      }
      constructor() {
        super(...arguments);
        this.name = "QuickJSMemoryLeakDetected";
      }
    };
    exports2.QuickJSMemoryLeakDetected = QuickJSMemoryLeakDetected;
  }
});

// ../../node_modules/@tootallnate/quickjs-emscripten/dist/asyncify-helpers.js
var require_asyncify_helpers = __commonJS({
  "../../node_modules/@tootallnate/quickjs-emscripten/dist/asyncify-helpers.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.awaitEachYieldedPromise = exports2.maybeAsync = exports2.maybeAsyncFn = void 0;
    function* awaitYield(value) {
      return yield value;
    }
    __name(awaitYield, "awaitYield");
    function awaitYieldOf(generator) {
      return awaitYield(awaitEachYieldedPromise(generator));
    }
    __name(awaitYieldOf, "awaitYieldOf");
    var AwaitYield = awaitYield;
    AwaitYield.of = awaitYieldOf;
    function maybeAsyncFn(that, fn) {
      return (...args) => {
        const generator = fn.call(that, AwaitYield, ...args);
        return awaitEachYieldedPromise(generator);
      };
    }
    __name(maybeAsyncFn, "maybeAsyncFn");
    exports2.maybeAsyncFn = maybeAsyncFn;
    function maybeAsync(that, startGenerator) {
      const generator = startGenerator.call(that, AwaitYield);
      return awaitEachYieldedPromise(generator);
    }
    __name(maybeAsync, "maybeAsync");
    exports2.maybeAsync = maybeAsync;
    function awaitEachYieldedPromise(gen) {
      function handleNextStep(step) {
        if (step.done) {
          return step.value;
        }
        if (step.value instanceof Promise) {
          return step.value.then((value) => handleNextStep(gen.next(value)), (error4) => handleNextStep(gen.throw(error4)));
        }
        return handleNextStep(gen.next(step.value));
      }
      __name(handleNextStep, "handleNextStep");
      return handleNextStep(gen.next());
    }
    __name(awaitEachYieldedPromise, "awaitEachYieldedPromise");
    exports2.awaitEachYieldedPromise = awaitEachYieldedPromise;
  }
});

// ../../node_modules/@tootallnate/quickjs-emscripten/dist/lifetime.js
var require_lifetime = __commonJS({
  "../../node_modules/@tootallnate/quickjs-emscripten/dist/lifetime.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.Scope = exports2.WeakLifetime = exports2.StaticLifetime = exports2.Lifetime = void 0;
    var asyncify_helpers_1 = require_asyncify_helpers();
    var debug_1 = require_debug3();
    var errors_1 = require_errors19();
    var Lifetime = class _Lifetime {
      static {
        __name(this, "Lifetime");
      }
      /**
       * When the Lifetime is disposed, it will call `disposer(_value)`. Use the
       * disposer function to implement whatever cleanup needs to happen at the end
       * of `value`'s lifetime.
       *
       * `_owner` is not used or controlled by the lifetime. It's just metadata for
       * the creator.
       */
      constructor(_value, copier, disposer, _owner) {
        this._value = _value;
        this.copier = copier;
        this.disposer = disposer;
        this._owner = _owner;
        this._alive = true;
        this._constructorStack = debug_1.QTS_DEBUG ? new Error("Lifetime constructed").stack : void 0;
      }
      get alive() {
        return this._alive;
      }
      /**
       * The value this Lifetime protects. You must never retain the value - it
       * may become invalid, leading to memory errors.
       *
       * @throws If the lifetime has been [[dispose]]d already.
       */
      get value() {
        this.assertAlive();
        return this._value;
      }
      get owner() {
        return this._owner;
      }
      get dupable() {
        return !!this.copier;
      }
      /**
       * Create a new handle pointing to the same [[value]].
       */
      dup() {
        this.assertAlive();
        if (!this.copier) {
          throw new Error("Non-dupable lifetime");
        }
        return new _Lifetime(this.copier(this._value), this.copier, this.disposer, this._owner);
      }
      consume(map5) {
        this.assertAlive();
        const result2 = map5(this);
        this.dispose();
        return result2;
      }
      /**
       * Dispose of [[value]] and perform cleanup.
       */
      dispose() {
        this.assertAlive();
        if (this.disposer) {
          this.disposer(this._value);
        }
        this._alive = false;
      }
      assertAlive() {
        if (!this.alive) {
          if (this._constructorStack) {
            throw new errors_1.QuickJSUseAfterFree(`Lifetime not alive
${this._constructorStack}
Lifetime used`);
          }
          throw new errors_1.QuickJSUseAfterFree("Lifetime not alive");
        }
      }
    };
    exports2.Lifetime = Lifetime;
    var StaticLifetime = class extends Lifetime {
      static {
        __name(this, "StaticLifetime");
      }
      constructor(value, owner) {
        super(value, void 0, void 0, owner);
      }
      // Static lifetime doesn't need a copier to be copiable
      get dupable() {
        return true;
      }
      // Copy returns the same instance.
      dup() {
        return this;
      }
      // Dispose does nothing.
      dispose() {
      }
    };
    exports2.StaticLifetime = StaticLifetime;
    var WeakLifetime = class extends Lifetime {
      static {
        __name(this, "WeakLifetime");
      }
      constructor(value, copier, disposer, owner) {
        super(value, copier, disposer, owner);
      }
      dispose() {
        this._alive = false;
      }
    };
    exports2.WeakLifetime = WeakLifetime;
    function scopeFinally(scope, blockError) {
      let disposeError;
      try {
        scope.dispose();
      } catch (error4) {
        disposeError = error4;
      }
      if (blockError && disposeError) {
        Object.assign(blockError, {
          message: `${blockError.message}
 Then, failed to dispose scope: ${disposeError.message}`,
          disposeError
        });
        throw blockError;
      }
      if (blockError || disposeError) {
        throw blockError || disposeError;
      }
    }
    __name(scopeFinally, "scopeFinally");
    var Scope = class _Scope {
      static {
        __name(this, "Scope");
      }
      constructor() {
        this._disposables = new Lifetime(/* @__PURE__ */ new Set());
      }
      /**
       * Run `block` with a new Scope instance that will be disposed after the block returns.
       * Inside `block`, call `scope.manage` on each lifetime you create to have the lifetime
       * automatically disposed after the block returns.
       *
       * @warning Do not use with async functions. Instead, use [[withScopeAsync]].
       */
      static withScope(block) {
        const scope = new _Scope();
        let blockError;
        try {
          return block(scope);
        } catch (error4) {
          blockError = error4;
          throw error4;
        } finally {
          scopeFinally(scope, blockError);
        }
      }
      static withScopeMaybeAsync(_this, block) {
        return (0, asyncify_helpers_1.maybeAsync)(void 0, function* (awaited) {
          const scope = new _Scope();
          let blockError;
          try {
            return yield* awaited.of(block.call(_this, awaited, scope));
          } catch (error4) {
            blockError = error4;
            throw error4;
          } finally {
            scopeFinally(scope, blockError);
          }
        });
      }
      /**
       * Run `block` with a new Scope instance that will be disposed after the
       * block's returned promise settles. Inside `block`, call `scope.manage` on each
       * lifetime you create to have the lifetime automatically disposed after the
       * block returns.
       */
      static async withScopeAsync(block) {
        const scope = new _Scope();
        let blockError;
        try {
          return await block(scope);
        } catch (error4) {
          blockError = error4;
          throw error4;
        } finally {
          scopeFinally(scope, blockError);
        }
      }
      /**
       * Track `lifetime` so that it is disposed when this scope is disposed.
       */
      manage(lifetime) {
        this._disposables.value.add(lifetime);
        return lifetime;
      }
      get alive() {
        return this._disposables.alive;
      }
      dispose() {
        const lifetimes = Array.from(this._disposables.value.values()).reverse();
        for (const lifetime of lifetimes) {
          if (lifetime.alive) {
            lifetime.dispose();
          }
        }
        this._disposables.dispose();
      }
    };
    exports2.Scope = Scope;
  }
});

// ../../node_modules/@tootallnate/quickjs-emscripten/dist/deferred-promise.js
var require_deferred_promise = __commonJS({
  "../../node_modules/@tootallnate/quickjs-emscripten/dist/deferred-promise.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.QuickJSDeferredPromise = void 0;
    var QuickJSDeferredPromise = class {
      static {
        __name(this, "QuickJSDeferredPromise");
      }
      /**
       * Use [[QuickJSContext.newPromise]] to create a new promise instead of calling
       * this constructor directly.
       * @unstable
       */
      constructor(args) {
        this.resolve = (value) => {
          if (!this.resolveHandle.alive) {
            return;
          }
          this.context.unwrapResult(this.context.callFunction(this.resolveHandle, this.context.undefined, value || this.context.undefined)).dispose();
          this.disposeResolvers();
          this.onSettled();
        };
        this.reject = (value) => {
          if (!this.rejectHandle.alive) {
            return;
          }
          this.context.unwrapResult(this.context.callFunction(this.rejectHandle, this.context.undefined, value || this.context.undefined)).dispose();
          this.disposeResolvers();
          this.onSettled();
        };
        this.dispose = () => {
          if (this.handle.alive) {
            this.handle.dispose();
          }
          this.disposeResolvers();
        };
        this.context = args.context;
        this.owner = args.context.runtime;
        this.handle = args.promiseHandle;
        this.settled = new Promise((resolve13) => {
          this.onSettled = resolve13;
        });
        this.resolveHandle = args.resolveHandle;
        this.rejectHandle = args.rejectHandle;
      }
      get alive() {
        return this.handle.alive || this.resolveHandle.alive || this.rejectHandle.alive;
      }
      disposeResolvers() {
        if (this.resolveHandle.alive) {
          this.resolveHandle.dispose();
        }
        if (this.rejectHandle.alive) {
          this.rejectHandle.dispose();
        }
      }
    };
    exports2.QuickJSDeferredPromise = QuickJSDeferredPromise;
  }
});

// ../../node_modules/@tootallnate/quickjs-emscripten/dist/memory.js
var require_memory = __commonJS({
  "../../node_modules/@tootallnate/quickjs-emscripten/dist/memory.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ModuleMemory = void 0;
    var lifetime_1 = require_lifetime();
    var ModuleMemory = class {
      static {
        __name(this, "ModuleMemory");
      }
      constructor(module3) {
        this.module = module3;
      }
      toPointerArray(handleArray) {
        const typedArray = new Int32Array(handleArray.map((handle) => handle.value));
        const numBytes = typedArray.length * typedArray.BYTES_PER_ELEMENT;
        const ptr = this.module._malloc(numBytes);
        var heapBytes = new Uint8Array(this.module.HEAPU8.buffer, ptr, numBytes);
        heapBytes.set(new Uint8Array(typedArray.buffer));
        return new lifetime_1.Lifetime(ptr, void 0, (ptr2) => this.module._free(ptr2));
      }
      newMutablePointerArray(length) {
        const zeros = new Int32Array(new Array(length).fill(0));
        const numBytes = zeros.length * zeros.BYTES_PER_ELEMENT;
        const ptr = this.module._malloc(numBytes);
        const typedArray = new Int32Array(this.module.HEAPU8.buffer, ptr, length);
        typedArray.set(zeros);
        return new lifetime_1.Lifetime({ typedArray, ptr }, void 0, (value) => this.module._free(value.ptr));
      }
      newHeapCharPointer(string) {
        const numBytes = this.module.lengthBytesUTF8(string) + 1;
        const ptr = this.module._malloc(numBytes);
        this.module.stringToUTF8(string, ptr, numBytes);
        return new lifetime_1.Lifetime(ptr, void 0, (value) => this.module._free(value));
      }
      consumeHeapCharPointer(ptr) {
        const str = this.module.UTF8ToString(ptr);
        this.module._free(ptr);
        return str;
      }
    };
    exports2.ModuleMemory = ModuleMemory;
  }
});

// ../../node_modules/@tootallnate/quickjs-emscripten/dist/types-ffi.js
var require_types_ffi = __commonJS({
  "../../node_modules/@tootallnate/quickjs-emscripten/dist/types-ffi.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.EvalFlags = exports2.assertSync = void 0;
    function assertSync(fn) {
      return /* @__PURE__ */ __name(function mustBeSync(...args) {
        const result2 = fn(...args);
        if (result2 && typeof result2 === "object" && result2 instanceof Promise) {
          throw new Error("Function unexpectedly returned a Promise");
        }
        return result2;
      }, "mustBeSync");
    }
    __name(assertSync, "assertSync");
    exports2.assertSync = assertSync;
    exports2.EvalFlags = {
      /** global code (default) */
      JS_EVAL_TYPE_GLOBAL: 0 << 0,
      /** module code */
      JS_EVAL_TYPE_MODULE: 1 << 0,
      /** direct call (internal use) */
      JS_EVAL_TYPE_DIRECT: 2 << 0,
      /** indirect call (internal use) */
      JS_EVAL_TYPE_INDIRECT: 3 << 0,
      JS_EVAL_TYPE_MASK: 3 << 0,
      /** force 'strict' mode */
      JS_EVAL_FLAG_STRICT: 1 << 3,
      /** force 'strip' mode */
      JS_EVAL_FLAG_STRIP: 1 << 4,
      /**
       * compile but do not run. The result is an object with a
       * JS_TAG_FUNCTION_BYTECODE or JS_TAG_MODULE tag. It can be executed
       * with JS_EvalFunction().
       */
      JS_EVAL_FLAG_COMPILE_ONLY: 1 << 5,
      /** don't include the stack frames before this eval in the Error() backtraces */
      JS_EVAL_FLAG_BACKTRACE_BARRIER: 1 << 6
    };
  }
});

// ../../node_modules/@tootallnate/quickjs-emscripten/dist/types.js
var require_types3 = __commonJS({
  "../../node_modules/@tootallnate/quickjs-emscripten/dist/types.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.concat = exports2.evalOptionsToFlags = exports2.DefaultIntrinsics = void 0;
    var types_ffi_1 = require_types_ffi();
    exports2.DefaultIntrinsics = /* @__PURE__ */ Symbol("DefaultIntrinsics");
    function evalOptionsToFlags(evalOptions) {
      if (typeof evalOptions === "number") {
        return evalOptions;
      }
      if (evalOptions === void 0) {
        return 0;
      }
      const { type, strict, strip, compileOnly, backtraceBarrier } = evalOptions;
      let flags = 0;
      if (type === "global")
        flags |= types_ffi_1.EvalFlags.JS_EVAL_TYPE_GLOBAL;
      if (type === "module")
        flags |= types_ffi_1.EvalFlags.JS_EVAL_TYPE_MODULE;
      if (strict)
        flags |= types_ffi_1.EvalFlags.JS_EVAL_FLAG_STRICT;
      if (strip)
        flags |= types_ffi_1.EvalFlags.JS_EVAL_FLAG_STRIP;
      if (compileOnly)
        flags |= types_ffi_1.EvalFlags.JS_EVAL_FLAG_COMPILE_ONLY;
      if (backtraceBarrier)
        flags |= types_ffi_1.EvalFlags.JS_EVAL_FLAG_BACKTRACE_BARRIER;
      return flags;
    }
    __name(evalOptionsToFlags, "evalOptionsToFlags");
    exports2.evalOptionsToFlags = evalOptionsToFlags;
    function concat(...values) {
      let result2 = [];
      for (const value of values) {
        if (value !== void 0) {
          result2 = result2.concat(value);
        }
      }
      return result2;
    }
    __name(concat, "concat");
    exports2.concat = concat;
  }
});

// ../../node_modules/@tootallnate/quickjs-emscripten/dist/context.js
var require_context = __commonJS({
  "../../node_modules/@tootallnate/quickjs-emscripten/dist/context.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.QuickJSContext = void 0;
    var debug_1 = require_debug3();
    var deferred_promise_1 = require_deferred_promise();
    var errors_1 = require_errors19();
    var lifetime_1 = require_lifetime();
    var memory_1 = require_memory();
    var types_1 = require_types3();
    var ContextMemory = class extends memory_1.ModuleMemory {
      static {
        __name(this, "ContextMemory");
      }
      /** @private */
      constructor(args) {
        super(args.module);
        this.scope = new lifetime_1.Scope();
        this.copyJSValue = (ptr) => {
          return this.ffi.QTS_DupValuePointer(this.ctx.value, ptr);
        };
        this.freeJSValue = (ptr) => {
          this.ffi.QTS_FreeValuePointer(this.ctx.value, ptr);
        };
        args.ownedLifetimes?.forEach((lifetime) => this.scope.manage(lifetime));
        this.owner = args.owner;
        this.module = args.module;
        this.ffi = args.ffi;
        this.rt = args.rt;
        this.ctx = this.scope.manage(args.ctx);
      }
      get alive() {
        return this.scope.alive;
      }
      dispose() {
        return this.scope.dispose();
      }
      /**
       * Track `lifetime` so that it is disposed when this scope is disposed.
       */
      manage(lifetime) {
        return this.scope.manage(lifetime);
      }
      consumeJSCharPointer(ptr) {
        const str = this.module.UTF8ToString(ptr);
        this.ffi.QTS_FreeCString(this.ctx.value, ptr);
        return str;
      }
      heapValueHandle(ptr) {
        return new lifetime_1.Lifetime(ptr, this.copyJSValue, this.freeJSValue, this.owner);
      }
    };
    var QuickJSContext = class {
      static {
        __name(this, "QuickJSContext");
      }
      /**
       * Use {@link QuickJS.createVm} to create a QuickJSContext instance.
       */
      constructor(args) {
        this._undefined = void 0;
        this._null = void 0;
        this._false = void 0;
        this._true = void 0;
        this._global = void 0;
        this._BigInt = void 0;
        this.fnNextId = -32768;
        this.fnMaps = /* @__PURE__ */ new Map();
        this.cToHostCallbacks = {
          callFunction: /* @__PURE__ */ __name((ctx, this_ptr, argc, argv, fn_id) => {
            if (ctx !== this.ctx.value) {
              throw new Error("QuickJSContext instance received C -> JS call with mismatched ctx");
            }
            const fn = this.getFunction(fn_id);
            if (!fn) {
              throw new Error(`QuickJSContext had no callback with id ${fn_id}`);
            }
            return lifetime_1.Scope.withScopeMaybeAsync(this, function* (awaited, scope) {
              const thisHandle = scope.manage(new lifetime_1.WeakLifetime(this_ptr, this.memory.copyJSValue, this.memory.freeJSValue, this.runtime));
              const argHandles = new Array(argc);
              for (let i32 = 0; i32 < argc; i32++) {
                const ptr = this.ffi.QTS_ArgvGetJSValueConstPointer(argv, i32);
                argHandles[i32] = scope.manage(new lifetime_1.WeakLifetime(ptr, this.memory.copyJSValue, this.memory.freeJSValue, this.runtime));
              }
              try {
                const result2 = yield* awaited(fn.apply(thisHandle, argHandles));
                if (result2) {
                  if ("error" in result2 && result2.error) {
                    (0, debug_1.debugLog)("throw error", result2.error);
                    throw result2.error;
                  }
                  const handle = scope.manage(result2 instanceof lifetime_1.Lifetime ? result2 : result2.value);
                  return this.ffi.QTS_DupValuePointer(this.ctx.value, handle.value);
                }
                return 0;
              } catch (error4) {
                return this.errorToHandle(error4).consume((errorHandle) => this.ffi.QTS_Throw(this.ctx.value, errorHandle.value));
              }
            });
          }, "callFunction")
        };
        this.runtime = args.runtime;
        this.module = args.module;
        this.ffi = args.ffi;
        this.rt = args.rt;
        this.ctx = args.ctx;
        this.memory = new ContextMemory({
          ...args,
          owner: this.runtime
        });
        args.callbacks.setContextCallbacks(this.ctx.value, this.cToHostCallbacks);
        this.dump = this.dump.bind(this);
        this.getString = this.getString.bind(this);
        this.getNumber = this.getNumber.bind(this);
        this.resolvePromise = this.resolvePromise.bind(this);
      }
      // @implement Disposable ----------------------------------------------------
      get alive() {
        return this.memory.alive;
      }
      /**
       * Dispose of this VM's underlying resources.
       *
       * @throws Calling this method without disposing of all created handles
       * will result in an error.
       */
      dispose() {
        this.memory.dispose();
      }
      // Globals ------------------------------------------------------------------
      /**
       * [`undefined`](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/undefined).
       */
      get undefined() {
        if (this._undefined) {
          return this._undefined;
        }
        const ptr = this.ffi.QTS_GetUndefined();
        return this._undefined = new lifetime_1.StaticLifetime(ptr);
      }
      /**
       * [`null`](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/null).
       */
      get null() {
        if (this._null) {
          return this._null;
        }
        const ptr = this.ffi.QTS_GetNull();
        return this._null = new lifetime_1.StaticLifetime(ptr);
      }
      /**
       * [`true`](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/true).
       */
      get true() {
        if (this._true) {
          return this._true;
        }
        const ptr = this.ffi.QTS_GetTrue();
        return this._true = new lifetime_1.StaticLifetime(ptr);
      }
      /**
       * [`false`](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/false).
       */
      get false() {
        if (this._false) {
          return this._false;
        }
        const ptr = this.ffi.QTS_GetFalse();
        return this._false = new lifetime_1.StaticLifetime(ptr);
      }
      /**
       * [`global`](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects).
       * A handle to the global object inside the interpreter.
       * You can set properties to create global variables.
       */
      get global() {
        if (this._global) {
          return this._global;
        }
        const ptr = this.ffi.QTS_GetGlobalObject(this.ctx.value);
        this.memory.manage(this.memory.heapValueHandle(ptr));
        this._global = new lifetime_1.StaticLifetime(ptr, this.runtime);
        return this._global;
      }
      // New values ---------------------------------------------------------------
      /**
       * Converts a Javascript number into a QuickJS value.
       */
      newNumber(num) {
        return this.memory.heapValueHandle(this.ffi.QTS_NewFloat64(this.ctx.value, num));
      }
      /**
       * Create a QuickJS [string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String) value.
       */
      newString(str) {
        const ptr = this.memory.newHeapCharPointer(str).consume((charHandle) => this.ffi.QTS_NewString(this.ctx.value, charHandle.value));
        return this.memory.heapValueHandle(ptr);
      }
      /**
       * Create a QuickJS [symbol](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Symbol) value.
       * No two symbols created with this function will be the same value.
       */
      newUniqueSymbol(description) {
        const key = (typeof description === "symbol" ? description.description : description) ?? "";
        const ptr = this.memory.newHeapCharPointer(key).consume((charHandle) => this.ffi.QTS_NewSymbol(this.ctx.value, charHandle.value, 0));
        return this.memory.heapValueHandle(ptr);
      }
      /**
       * Get a symbol from the [global registry](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Symbol#shared_symbols_in_the_global_symbol_registry) for the given key.
       * All symbols created with the same key will be the same value.
       */
      newSymbolFor(key) {
        const description = (typeof key === "symbol" ? key.description : key) ?? "";
        const ptr = this.memory.newHeapCharPointer(description).consume((charHandle) => this.ffi.QTS_NewSymbol(this.ctx.value, charHandle.value, 1));
        return this.memory.heapValueHandle(ptr);
      }
      /**
       * Create a QuickJS [bigint](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/BigInt) value.
       */
      newBigInt(num) {
        if (!this._BigInt) {
          const bigIntHandle2 = this.getProp(this.global, "BigInt");
          this.memory.manage(bigIntHandle2);
          this._BigInt = new lifetime_1.StaticLifetime(bigIntHandle2.value, this.runtime);
        }
        const bigIntHandle = this._BigInt;
        const asString = String(num);
        return this.newString(asString).consume((handle) => this.unwrapResult(this.callFunction(bigIntHandle, this.undefined, handle)));
      }
      /**
       * `{}`.
       * Create a new QuickJS [object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Operators/Object_initializer).
       *
       * @param prototype - Like [`Object.create`](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object/create).
       */
      newObject(prototype) {
        if (prototype) {
          this.runtime.assertOwned(prototype);
        }
        const ptr = prototype ? this.ffi.QTS_NewObjectProto(this.ctx.value, prototype.value) : this.ffi.QTS_NewObject(this.ctx.value);
        return this.memory.heapValueHandle(ptr);
      }
      /**
       * `[]`.
       * Create a new QuickJS [array](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array).
       */
      newArray() {
        const ptr = this.ffi.QTS_NewArray(this.ctx.value);
        return this.memory.heapValueHandle(ptr);
      }
      newPromise(value) {
        const deferredPromise = lifetime_1.Scope.withScope((scope) => {
          const mutablePointerArray = scope.manage(this.memory.newMutablePointerArray(2));
          const promisePtr = this.ffi.QTS_NewPromiseCapability(this.ctx.value, mutablePointerArray.value.ptr);
          const promiseHandle = this.memory.heapValueHandle(promisePtr);
          const [resolveHandle, rejectHandle] = Array.from(mutablePointerArray.value.typedArray).map((jsvaluePtr) => this.memory.heapValueHandle(jsvaluePtr));
          return new deferred_promise_1.QuickJSDeferredPromise({
            context: this,
            promiseHandle,
            resolveHandle,
            rejectHandle
          });
        });
        if (value && typeof value === "function") {
          value = new Promise(value);
        }
        if (value) {
          Promise.resolve(value).then(deferredPromise.resolve, (error4) => error4 instanceof lifetime_1.Lifetime ? deferredPromise.reject(error4) : this.newError(error4).consume(deferredPromise.reject));
        }
        return deferredPromise;
      }
      /**
       * Convert a Javascript function into a QuickJS function value.
       * See [[VmFunctionImplementation]] for more details.
       *
       * A [[VmFunctionImplementation]] should not free its arguments or its return
       * value. A VmFunctionImplementation should also not retain any references to
       * its return value.
       *
       * To implement an async function, create a promise with [[newPromise]], then
       * return the deferred promise handle from `deferred.handle` from your
       * function implementation:
       *
       * ```
       * const deferred = vm.newPromise()
       * someNativeAsyncFunction().then(deferred.resolve)
       * return deferred.handle
       * ```
       */
      newFunction(name, fn) {
        const fnId = ++this.fnNextId;
        this.setFunction(fnId, fn);
        return this.memory.heapValueHandle(this.ffi.QTS_NewFunction(this.ctx.value, fnId, name));
      }
      newError(error4) {
        const errorHandle = this.memory.heapValueHandle(this.ffi.QTS_NewError(this.ctx.value));
        if (error4 && typeof error4 === "object") {
          if (error4.name !== void 0) {
            this.newString(error4.name).consume((handle) => this.setProp(errorHandle, "name", handle));
          }
          if (error4.message !== void 0) {
            this.newString(error4.message).consume((handle) => this.setProp(errorHandle, "message", handle));
          }
        } else if (typeof error4 === "string") {
          this.newString(error4).consume((handle) => this.setProp(errorHandle, "message", handle));
        } else if (error4 !== void 0) {
          this.newString(String(error4)).consume((handle) => this.setProp(errorHandle, "message", handle));
        }
        return errorHandle;
      }
      // Read values --------------------------------------------------------------
      /**
       * `typeof` operator. **Not** [standards compliant](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Operators/typeof).
       *
       * @remarks
       * Does not support BigInt values correctly.
       */
      typeof(handle) {
        this.runtime.assertOwned(handle);
        return this.memory.consumeHeapCharPointer(this.ffi.QTS_Typeof(this.ctx.value, handle.value));
      }
      /**
       * Converts `handle` into a Javascript number.
       * @returns `NaN` on error, otherwise a `number`.
       */
      getNumber(handle) {
        this.runtime.assertOwned(handle);
        return this.ffi.QTS_GetFloat64(this.ctx.value, handle.value);
      }
      /**
       * Converts `handle` to a Javascript string.
       */
      getString(handle) {
        this.runtime.assertOwned(handle);
        return this.memory.consumeJSCharPointer(this.ffi.QTS_GetString(this.ctx.value, handle.value));
      }
      /**
       * Converts `handle` into a Javascript symbol. If the symbol is in the global
       * registry in the guest, it will be created with Symbol.for on the host.
       */
      getSymbol(handle) {
        this.runtime.assertOwned(handle);
        const key = this.memory.consumeJSCharPointer(this.ffi.QTS_GetSymbolDescriptionOrKey(this.ctx.value, handle.value));
        const isGlobal = this.ffi.QTS_IsGlobalSymbol(this.ctx.value, handle.value);
        return isGlobal ? Symbol.for(key) : Symbol(key);
      }
      /**
       * Converts `handle` to a Javascript bigint.
       */
      getBigInt(handle) {
        this.runtime.assertOwned(handle);
        const asString = this.getString(handle);
        return BigInt(asString);
      }
      /**
       * `Promise.resolve(value)`.
       * Convert a handle containing a Promise-like value inside the VM into an
       * actual promise on the host.
       *
       * @remarks
       * You may need to call [[executePendingJobs]] to ensure that the promise is resolved.
       *
       * @param promiseLikeHandle - A handle to a Promise-like value with a `.then(onSuccess, onError)` method.
       */
      resolvePromise(promiseLikeHandle) {
        this.runtime.assertOwned(promiseLikeHandle);
        const vmResolveResult = lifetime_1.Scope.withScope((scope) => {
          const vmPromise = scope.manage(this.getProp(this.global, "Promise"));
          const vmPromiseResolve = scope.manage(this.getProp(vmPromise, "resolve"));
          return this.callFunction(vmPromiseResolve, vmPromise, promiseLikeHandle);
        });
        if (vmResolveResult.error) {
          return Promise.resolve(vmResolveResult);
        }
        return new Promise((resolve13) => {
          lifetime_1.Scope.withScope((scope) => {
            const resolveHandle = scope.manage(this.newFunction("resolve", (value) => {
              resolve13({ value: value && value.dup() });
            }));
            const rejectHandle = scope.manage(this.newFunction("reject", (error4) => {
              resolve13({ error: error4 && error4.dup() });
            }));
            const promiseHandle = scope.manage(vmResolveResult.value);
            const promiseThenHandle = scope.manage(this.getProp(promiseHandle, "then"));
            this.unwrapResult(this.callFunction(promiseThenHandle, promiseHandle, resolveHandle, rejectHandle)).dispose();
          });
        });
      }
      // Properties ---------------------------------------------------------------
      /**
       * `handle[key]`.
       * Get a property from a JSValue.
       *
       * @param key - The property may be specified as a JSValue handle, or as a
       * Javascript string (which will be converted automatically).
       */
      getProp(handle, key) {
        this.runtime.assertOwned(handle);
        const ptr = this.borrowPropertyKey(key).consume((quickJSKey) => this.ffi.QTS_GetProp(this.ctx.value, handle.value, quickJSKey.value));
        const result2 = this.memory.heapValueHandle(ptr);
        return result2;
      }
      /**
       * `handle[key] = value`.
       * Set a property on a JSValue.
       *
       * @remarks
       * Note that the QuickJS authors recommend using [[defineProp]] to define new
       * properties.
       *
       * @param key - The property may be specified as a JSValue handle, or as a
       * Javascript string or number (which will be converted automatically to a JSValue).
       */
      setProp(handle, key, value) {
        this.runtime.assertOwned(handle);
        this.borrowPropertyKey(key).consume((quickJSKey) => this.ffi.QTS_SetProp(this.ctx.value, handle.value, quickJSKey.value, value.value));
      }
      /**
       * [`Object.defineProperty(handle, key, descriptor)`](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object/defineProperty).
       *
       * @param key - The property may be specified as a JSValue handle, or as a
       * Javascript string or number (which will be converted automatically to a JSValue).
       */
      defineProp(handle, key, descriptor) {
        this.runtime.assertOwned(handle);
        lifetime_1.Scope.withScope((scope) => {
          const quickJSKey = scope.manage(this.borrowPropertyKey(key));
          const value = descriptor.value || this.undefined;
          const configurable = Boolean(descriptor.configurable);
          const enumerable = Boolean(descriptor.enumerable);
          const hasValue = Boolean(descriptor.value);
          const get4 = descriptor.get ? scope.manage(this.newFunction(descriptor.get.name, descriptor.get)) : this.undefined;
          const set = descriptor.set ? scope.manage(this.newFunction(descriptor.set.name, descriptor.set)) : this.undefined;
          this.ffi.QTS_DefineProp(this.ctx.value, handle.value, quickJSKey.value, value.value, get4.value, set.value, configurable, enumerable, hasValue);
        });
      }
      // Evaluation ---------------------------------------------------------------
      /**
       * [`func.call(thisVal, ...args)`](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Function/call).
       * Call a JSValue as a function.
       *
       * See [[unwrapResult]], which will throw if the function returned an error, or
       * return the result handle directly. If evaluation returned a handle containing
       * a promise, use [[resolvePromise]] to convert it to a native promise and
       * [[executePendingJobs]] to finish evaluating the promise.
       *
       * @returns A result. If the function threw synchronously, `result.error` be a
       * handle to the exception. Otherwise `result.value` will be a handle to the
       * value.
       */
      callFunction(func, thisVal, ...args) {
        this.runtime.assertOwned(func);
        const resultPtr = this.memory.toPointerArray(args).consume((argsArrayPtr) => this.ffi.QTS_Call(this.ctx.value, func.value, thisVal.value, args.length, argsArrayPtr.value));
        const errorPtr = this.ffi.QTS_ResolveException(this.ctx.value, resultPtr);
        if (errorPtr) {
          this.ffi.QTS_FreeValuePointer(this.ctx.value, resultPtr);
          return { error: this.memory.heapValueHandle(errorPtr) };
        }
        return { value: this.memory.heapValueHandle(resultPtr) };
      }
      /**
       * Like [`eval(code)`](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/eval#Description).
       * Evaluates the Javascript source `code` in the global scope of this VM.
       * When working with async code, you many need to call [[executePendingJobs]]
       * to execute callbacks pending after synchronous evaluation returns.
       *
       * See [[unwrapResult]], which will throw if the function returned an error, or
       * return the result handle directly. If evaluation returned a handle containing
       * a promise, use [[resolvePromise]] to convert it to a native promise and
       * [[executePendingJobs]] to finish evaluating the promise.
       *
       * *Note*: to protect against infinite loops, provide an interrupt handler to
       * [[setInterruptHandler]]. You can use [[shouldInterruptAfterDeadline]] to
       * create a time-based deadline.
       *
       * @returns The last statement's value. If the code threw synchronously,
       * `result.error` will be a handle to the exception. If execution was
       * interrupted, the error will have name `InternalError` and message
       * `interrupted`.
       */
      evalCode(code, filename = "eval.js", options) {
        const detectModule = options === void 0 ? 1 : 0;
        const flags = (0, types_1.evalOptionsToFlags)(options);
        const resultPtr = this.memory.newHeapCharPointer(code).consume((charHandle) => this.ffi.QTS_Eval(this.ctx.value, charHandle.value, filename, detectModule, flags));
        const errorPtr = this.ffi.QTS_ResolveException(this.ctx.value, resultPtr);
        if (errorPtr) {
          this.ffi.QTS_FreeValuePointer(this.ctx.value, resultPtr);
          return { error: this.memory.heapValueHandle(errorPtr) };
        }
        return { value: this.memory.heapValueHandle(resultPtr) };
      }
      /**
       * Throw an error in the VM, interrupted whatever current execution is in progress when execution resumes.
       * @experimental
       */
      throw(error4) {
        return this.errorToHandle(error4).consume((handle) => this.ffi.QTS_Throw(this.ctx.value, handle.value));
      }
      /**
       * @private
       */
      borrowPropertyKey(key) {
        if (typeof key === "number") {
          return this.newNumber(key);
        }
        if (typeof key === "string") {
          return this.newString(key);
        }
        return new lifetime_1.StaticLifetime(key.value, this.runtime);
      }
      /**
       * @private
       */
      getMemory(rt) {
        if (rt === this.rt.value) {
          return this.memory;
        } else {
          throw new Error("Private API. Cannot get memory from a different runtime");
        }
      }
      // Utilities ----------------------------------------------------------------
      /**
       * Dump a JSValue to Javascript in a best-effort fashion.
       * Returns `handle.toString()` if it cannot be serialized to JSON.
       */
      dump(handle) {
        this.runtime.assertOwned(handle);
        const type = this.typeof(handle);
        if (type === "string") {
          return this.getString(handle);
        } else if (type === "number") {
          return this.getNumber(handle);
        } else if (type === "bigint") {
          return this.getBigInt(handle);
        } else if (type === "undefined") {
          return void 0;
        } else if (type === "symbol") {
          return this.getSymbol(handle);
        }
        const str = this.memory.consumeJSCharPointer(this.ffi.QTS_Dump(this.ctx.value, handle.value));
        try {
          return JSON.parse(str);
        } catch (err) {
          return str;
        }
      }
      /**
       * Unwrap a SuccessOrFail result such as a [[VmCallResult]] or a
       * [[ExecutePendingJobsResult]], where the fail branch contains a handle to a QuickJS error value.
       * If the result is a success, returns the value.
       * If the result is an error, converts the error to a native object and throws the error.
       */
      unwrapResult(result2) {
        if (result2.error) {
          const context = "context" in result2.error ? result2.error.context : this;
          const cause = result2.error.consume((error4) => this.dump(error4));
          if (cause && typeof cause === "object" && typeof cause.message === "string") {
            const { message: message2, name, stack } = cause;
            const exception = new errors_1.QuickJSUnwrapError("");
            const hostStack = exception.stack;
            if (typeof name === "string") {
              exception.name = cause.name;
            }
            if (typeof stack === "string") {
              exception.stack = `${name}: ${message2}
${cause.stack}Host: ${hostStack}`;
            }
            Object.assign(exception, { cause, context, message: message2 });
            throw exception;
          }
          throw new errors_1.QuickJSUnwrapError(cause, context);
        }
        return result2.value;
      }
      /** @private */
      getFunction(fn_id) {
        const map_id = fn_id >> 8;
        const fnMap = this.fnMaps.get(map_id);
        if (!fnMap) {
          return void 0;
        }
        return fnMap.get(fn_id);
      }
      /** @private */
      setFunction(fn_id, handle) {
        const map_id = fn_id >> 8;
        let fnMap = this.fnMaps.get(map_id);
        if (!fnMap) {
          fnMap = /* @__PURE__ */ new Map();
          this.fnMaps.set(map_id, fnMap);
        }
        return fnMap.set(fn_id, handle);
      }
      errorToHandle(error4) {
        if (error4 instanceof lifetime_1.Lifetime) {
          return error4;
        }
        return this.newError(error4);
      }
    };
    exports2.QuickJSContext = QuickJSContext;
  }
});

// ../../node_modules/@tootallnate/quickjs-emscripten/dist/runtime.js
var require_runtime = __commonJS({
  "../../node_modules/@tootallnate/quickjs-emscripten/dist/runtime.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.QuickJSRuntime = void 0;
    var asyncify_helpers_1 = require_asyncify_helpers();
    var context_1 = require_context();
    var debug_1 = require_debug3();
    var errors_1 = require_errors19();
    var lifetime_1 = require_lifetime();
    var memory_1 = require_memory();
    var types_1 = require_types3();
    var QuickJSRuntime = class {
      static {
        __name(this, "QuickJSRuntime");
      }
      /** @private */
      constructor(args) {
        this.scope = new lifetime_1.Scope();
        this.contextMap = /* @__PURE__ */ new Map();
        this.cToHostCallbacks = {
          shouldInterrupt: /* @__PURE__ */ __name((rt) => {
            if (rt !== this.rt.value) {
              throw new Error("QuickJSContext instance received C -> JS interrupt with mismatched rt");
            }
            const fn = this.interruptHandler;
            if (!fn) {
              throw new Error("QuickJSContext had no interrupt handler");
            }
            return fn(this) ? 1 : 0;
          }, "shouldInterrupt"),
          loadModuleSource: (0, asyncify_helpers_1.maybeAsyncFn)(this, function* (awaited, rt, ctx, moduleName) {
            const moduleLoader = this.moduleLoader;
            if (!moduleLoader) {
              throw new Error("Runtime has no module loader");
            }
            if (rt !== this.rt.value) {
              throw new Error("Runtime pointer mismatch");
            }
            const context = this.contextMap.get(ctx) ?? this.newContext({
              contextPointer: ctx
            });
            try {
              const result2 = yield* awaited(moduleLoader(moduleName, context));
              if (typeof result2 === "object" && "error" in result2 && result2.error) {
                (0, debug_1.debugLog)("cToHostLoadModule: loader returned error", result2.error);
                throw result2.error;
              }
              const moduleSource = typeof result2 === "string" ? result2 : "value" in result2 ? result2.value : result2;
              return this.memory.newHeapCharPointer(moduleSource).value;
            } catch (error4) {
              (0, debug_1.debugLog)("cToHostLoadModule: caught error", error4);
              context.throw(error4);
              return 0;
            }
          }),
          normalizeModule: (0, asyncify_helpers_1.maybeAsyncFn)(this, function* (awaited, rt, ctx, baseModuleName, moduleNameRequest) {
            const moduleNormalizer = this.moduleNormalizer;
            if (!moduleNormalizer) {
              throw new Error("Runtime has no module normalizer");
            }
            if (rt !== this.rt.value) {
              throw new Error("Runtime pointer mismatch");
            }
            const context = this.contextMap.get(ctx) ?? this.newContext({
              /* TODO: Does this happen? Are we responsible for disposing? I don't think so */
              contextPointer: ctx
            });
            try {
              const result2 = yield* awaited(moduleNormalizer(baseModuleName, moduleNameRequest, context));
              if (typeof result2 === "object" && "error" in result2 && result2.error) {
                (0, debug_1.debugLog)("cToHostNormalizeModule: normalizer returned error", result2.error);
                throw result2.error;
              }
              const name = typeof result2 === "string" ? result2 : result2.value;
              return context.getMemory(this.rt.value).newHeapCharPointer(name).value;
            } catch (error4) {
              (0, debug_1.debugLog)("normalizeModule: caught error", error4);
              context.throw(error4);
              return 0;
            }
          })
        };
        args.ownedLifetimes?.forEach((lifetime) => this.scope.manage(lifetime));
        this.module = args.module;
        this.memory = new memory_1.ModuleMemory(this.module);
        this.ffi = args.ffi;
        this.rt = args.rt;
        this.callbacks = args.callbacks;
        this.scope.manage(this.rt);
        this.callbacks.setRuntimeCallbacks(this.rt.value, this.cToHostCallbacks);
        this.executePendingJobs = this.executePendingJobs.bind(this);
      }
      get alive() {
        return this.scope.alive;
      }
      dispose() {
        return this.scope.dispose();
      }
      newContext(options = {}) {
        if (options.intrinsics && options.intrinsics !== types_1.DefaultIntrinsics) {
          throw new Error("TODO: Custom intrinsics are not supported yet");
        }
        const ctx = new lifetime_1.Lifetime(options.contextPointer || this.ffi.QTS_NewContext(this.rt.value), void 0, (ctx_ptr) => {
          this.contextMap.delete(ctx_ptr);
          this.callbacks.deleteContext(ctx_ptr);
          this.ffi.QTS_FreeContext(ctx_ptr);
        });
        const context = new context_1.QuickJSContext({
          module: this.module,
          ctx,
          ffi: this.ffi,
          rt: this.rt,
          ownedLifetimes: options.ownedLifetimes,
          runtime: this,
          callbacks: this.callbacks
        });
        this.contextMap.set(ctx.value, context);
        return context;
      }
      /**
       * Set the loader for EcmaScript modules requested by any context in this
       * runtime.
       *
       * The loader can be removed with [[removeModuleLoader]].
       */
      setModuleLoader(moduleLoader, moduleNormalizer) {
        this.moduleLoader = moduleLoader;
        this.moduleNormalizer = moduleNormalizer;
        this.ffi.QTS_RuntimeEnableModuleLoader(this.rt.value, this.moduleNormalizer ? 1 : 0);
      }
      /**
       * Remove the the loader set by [[setModuleLoader]]. This disables module loading.
       */
      removeModuleLoader() {
        this.moduleLoader = void 0;
        this.ffi.QTS_RuntimeDisableModuleLoader(this.rt.value);
      }
      // Runtime management -------------------------------------------------------
      /**
       * In QuickJS, promises and async functions create pendingJobs. These do not execute
       * immediately and need to be run by calling [[executePendingJobs]].
       *
       * @return true if there is at least one pendingJob queued up.
       */
      hasPendingJob() {
        return Boolean(this.ffi.QTS_IsJobPending(this.rt.value));
      }
      /**
       * Set a callback which is regularly called by the QuickJS engine when it is
       * executing code. This callback can be used to implement an execution
       * timeout.
       *
       * The interrupt handler can be removed with [[removeInterruptHandler]].
       */
      setInterruptHandler(cb) {
        const prevInterruptHandler = this.interruptHandler;
        this.interruptHandler = cb;
        if (!prevInterruptHandler) {
          this.ffi.QTS_RuntimeEnableInterruptHandler(this.rt.value);
        }
      }
      /**
       * Remove the interrupt handler, if any.
       * See [[setInterruptHandler]].
       */
      removeInterruptHandler() {
        if (this.interruptHandler) {
          this.ffi.QTS_RuntimeDisableInterruptHandler(this.rt.value);
          this.interruptHandler = void 0;
        }
      }
      /**
       * Execute pendingJobs on the runtime until `maxJobsToExecute` jobs are
       * executed (default all pendingJobs), the queue is exhausted, or the runtime
       * encounters an exception.
       *
       * In QuickJS, promises and async functions *inside the runtime* create
       * pendingJobs. These do not execute immediately and need to triggered to run.
       *
       * @param maxJobsToExecute - When negative, run all pending jobs. Otherwise execute
       * at most `maxJobsToExecute` before returning.
       *
       * @return On success, the number of executed jobs. On error, the exception
       * that stopped execution, and the context it occurred in. Note that
       * executePendingJobs will not normally return errors thrown inside async
       * functions or rejected promises. Those errors are available by calling
       * [[resolvePromise]] on the promise handle returned by the async function.
       */
      executePendingJobs(maxJobsToExecute = -1) {
        const ctxPtrOut = this.memory.newMutablePointerArray(1);
        const valuePtr = this.ffi.QTS_ExecutePendingJob(this.rt.value, maxJobsToExecute ?? -1, ctxPtrOut.value.ptr);
        const ctxPtr = ctxPtrOut.value.typedArray[0];
        ctxPtrOut.dispose();
        if (ctxPtr === 0) {
          this.ffi.QTS_FreeValuePointerRuntime(this.rt.value, valuePtr);
          return { value: 0 };
        }
        const context = this.contextMap.get(ctxPtr) ?? this.newContext({
          contextPointer: ctxPtr
        });
        const resultValue = context.getMemory(this.rt.value).heapValueHandle(valuePtr);
        const typeOfRet = context.typeof(resultValue);
        if (typeOfRet === "number") {
          const executedJobs = context.getNumber(resultValue);
          resultValue.dispose();
          return { value: executedJobs };
        } else {
          const error4 = Object.assign(resultValue, { context });
          return {
            error: error4
          };
        }
      }
      /**
       * Set the max memory this runtime can allocate.
       * To remove the limit, set to `-1`.
       */
      setMemoryLimit(limitBytes) {
        if (limitBytes < 0 && limitBytes !== -1) {
          throw new Error("Cannot set memory limit to negative number. To unset, pass -1");
        }
        this.ffi.QTS_RuntimeSetMemoryLimit(this.rt.value, limitBytes);
      }
      /**
       * Compute memory usage for this runtime. Returns the result as a handle to a
       * JSValue object. Use [[QuickJSContext.dump]] to convert to a native object.
       * Calling this method will allocate more memory inside the runtime. The information
       * is accurate as of just before the call to `computeMemoryUsage`.
       * For a human-digestible representation, see [[dumpMemoryUsage]].
       */
      computeMemoryUsage() {
        const serviceContextMemory = this.getSystemContext().getMemory(this.rt.value);
        return serviceContextMemory.heapValueHandle(this.ffi.QTS_RuntimeComputeMemoryUsage(this.rt.value, serviceContextMemory.ctx.value));
      }
      /**
       * @returns a human-readable description of memory usage in this runtime.
       * For programmatic access to this information, see [[computeMemoryUsage]].
       */
      dumpMemoryUsage() {
        return this.memory.consumeHeapCharPointer(this.ffi.QTS_RuntimeDumpMemoryUsage(this.rt.value));
      }
      /**
       * Set the max stack size for this runtime, in bytes.
       * To remove the limit, set to `0`.
       */
      setMaxStackSize(stackSize) {
        if (stackSize < 0) {
          throw new Error("Cannot set memory limit to negative number. To unset, pass 0.");
        }
        this.ffi.QTS_RuntimeSetMaxStackSize(this.rt.value, stackSize);
      }
      /**
       * Assert that `handle` is owned by this runtime.
       * @throws QuickJSWrongOwner if owned by a different runtime.
       */
      assertOwned(handle) {
        if (handle.owner && handle.owner.rt !== this.rt) {
          throw new errors_1.QuickJSWrongOwner(`Handle is not owned by this runtime: ${handle.owner.rt.value} != ${this.rt.value}`);
        }
      }
      getSystemContext() {
        if (!this.context) {
          this.context = this.scope.manage(this.newContext());
        }
        return this.context;
      }
    };
    exports2.QuickJSRuntime = QuickJSRuntime;
  }
});

// ../../node_modules/@tootallnate/quickjs-emscripten/dist/module.js
var require_module = __commonJS({
  "../../node_modules/@tootallnate/quickjs-emscripten/dist/module.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.QuickJSWASMModule = exports2.applyModuleEvalRuntimeOptions = exports2.applyBaseRuntimeOptions = exports2.QuickJSModuleCallbacks = void 0;
    var debug_1 = require_debug3();
    var errors_1 = require_errors19();
    var lifetime_1 = require_lifetime();
    var runtime_1 = require_runtime();
    var types_1 = require_types3();
    var QuickJSEmscriptenModuleCallbacks = class {
      static {
        __name(this, "QuickJSEmscriptenModuleCallbacks");
      }
      constructor(args) {
        this.callFunction = args.callFunction;
        this.shouldInterrupt = args.shouldInterrupt;
        this.loadModuleSource = args.loadModuleSource;
        this.normalizeModule = args.normalizeModule;
      }
    };
    var QuickJSModuleCallbacks = class {
      static {
        __name(this, "QuickJSModuleCallbacks");
      }
      constructor(module3) {
        this.contextCallbacks = /* @__PURE__ */ new Map();
        this.runtimeCallbacks = /* @__PURE__ */ new Map();
        this.suspendedCount = 0;
        this.cToHostCallbacks = new QuickJSEmscriptenModuleCallbacks({
          callFunction: /* @__PURE__ */ __name((asyncify, ctx, this_ptr, argc, argv, fn_id) => this.handleAsyncify(asyncify, () => {
            try {
              const vm = this.contextCallbacks.get(ctx);
              if (!vm) {
                throw new Error(`QuickJSContext(ctx = ${ctx}) not found for C function call "${fn_id}"`);
              }
              return vm.callFunction(ctx, this_ptr, argc, argv, fn_id);
            } catch (error4) {
              console.error("[C to host error: returning null]", error4);
              return 0;
            }
          }), "callFunction"),
          shouldInterrupt: /* @__PURE__ */ __name((asyncify, rt) => this.handleAsyncify(asyncify, () => {
            try {
              const vm = this.runtimeCallbacks.get(rt);
              if (!vm) {
                throw new Error(`QuickJSRuntime(rt = ${rt}) not found for C interrupt`);
              }
              return vm.shouldInterrupt(rt);
            } catch (error4) {
              console.error("[C to host interrupt: returning error]", error4);
              return 1;
            }
          }), "shouldInterrupt"),
          loadModuleSource: /* @__PURE__ */ __name((asyncify, rt, ctx, moduleName) => this.handleAsyncify(asyncify, () => {
            try {
              const runtimeCallbacks = this.runtimeCallbacks.get(rt);
              if (!runtimeCallbacks) {
                throw new Error(`QuickJSRuntime(rt = ${rt}) not found for C module loader`);
              }
              const loadModule = runtimeCallbacks.loadModuleSource;
              if (!loadModule) {
                throw new Error(`QuickJSRuntime(rt = ${rt}) does not support module loading`);
              }
              return loadModule(rt, ctx, moduleName);
            } catch (error4) {
              console.error("[C to host module loader error: returning null]", error4);
              return 0;
            }
          }), "loadModuleSource"),
          normalizeModule: /* @__PURE__ */ __name((asyncify, rt, ctx, moduleBaseName, moduleName) => this.handleAsyncify(asyncify, () => {
            try {
              const runtimeCallbacks = this.runtimeCallbacks.get(rt);
              if (!runtimeCallbacks) {
                throw new Error(`QuickJSRuntime(rt = ${rt}) not found for C module loader`);
              }
              const normalizeModule = runtimeCallbacks.normalizeModule;
              if (!normalizeModule) {
                throw new Error(`QuickJSRuntime(rt = ${rt}) does not support module loading`);
              }
              return normalizeModule(rt, ctx, moduleBaseName, moduleName);
            } catch (error4) {
              console.error("[C to host module loader error: returning null]", error4);
              return 0;
            }
          }), "normalizeModule")
        });
        this.module = module3;
        this.module.callbacks = this.cToHostCallbacks;
      }
      setRuntimeCallbacks(rt, callbacks) {
        this.runtimeCallbacks.set(rt, callbacks);
      }
      deleteRuntime(rt) {
        this.runtimeCallbacks.delete(rt);
      }
      setContextCallbacks(ctx, callbacks) {
        this.contextCallbacks.set(ctx, callbacks);
      }
      deleteContext(ctx) {
        this.contextCallbacks.delete(ctx);
      }
      handleAsyncify(asyncify, fn) {
        if (asyncify) {
          return asyncify.handleSleep((done) => {
            try {
              const result2 = fn();
              if (!(result2 instanceof Promise)) {
                (0, debug_1.debugLog)("asyncify.handleSleep: not suspending:", result2);
                done(result2);
                return;
              }
              if (this.suspended) {
                throw new errors_1.QuickJSAsyncifyError(`Already suspended at: ${this.suspended.stack}
Attempted to suspend at:`);
              } else {
                this.suspended = new errors_1.QuickJSAsyncifySuspended(`(${this.suspendedCount++})`);
                (0, debug_1.debugLog)("asyncify.handleSleep: suspending:", this.suspended);
              }
              result2.then((resolvedResult) => {
                this.suspended = void 0;
                (0, debug_1.debugLog)("asyncify.handleSleep: resolved:", resolvedResult);
                done(resolvedResult);
              }, (error4) => {
                (0, debug_1.debugLog)("asyncify.handleSleep: rejected:", error4);
                console.error("QuickJS: cannot handle error in suspended function", error4);
                this.suspended = void 0;
              });
            } catch (error4) {
              (0, debug_1.debugLog)("asyncify.handleSleep: error:", error4);
              this.suspended = void 0;
              throw error4;
            }
          });
        }
        const value = fn();
        if (value instanceof Promise) {
          throw new Error("Promise return value not supported in non-asyncify context.");
        }
        return value;
      }
    };
    exports2.QuickJSModuleCallbacks = QuickJSModuleCallbacks;
    function applyBaseRuntimeOptions(runtime, options) {
      if (options.interruptHandler) {
        runtime.setInterruptHandler(options.interruptHandler);
      }
      if (options.maxStackSizeBytes !== void 0) {
        runtime.setMaxStackSize(options.maxStackSizeBytes);
      }
      if (options.memoryLimitBytes !== void 0) {
        runtime.setMemoryLimit(options.memoryLimitBytes);
      }
    }
    __name(applyBaseRuntimeOptions, "applyBaseRuntimeOptions");
    exports2.applyBaseRuntimeOptions = applyBaseRuntimeOptions;
    function applyModuleEvalRuntimeOptions(runtime, options) {
      if (options.moduleLoader) {
        runtime.setModuleLoader(options.moduleLoader);
      }
      if (options.shouldInterrupt) {
        runtime.setInterruptHandler(options.shouldInterrupt);
      }
      if (options.memoryLimitBytes !== void 0) {
        runtime.setMemoryLimit(options.memoryLimitBytes);
      }
      if (options.maxStackSizeBytes !== void 0) {
        runtime.setMaxStackSize(options.maxStackSizeBytes);
      }
    }
    __name(applyModuleEvalRuntimeOptions, "applyModuleEvalRuntimeOptions");
    exports2.applyModuleEvalRuntimeOptions = applyModuleEvalRuntimeOptions;
    var QuickJSWASMModule = class {
      static {
        __name(this, "QuickJSWASMModule");
      }
      /** @private */
      constructor(module3, ffi) {
        this.module = module3;
        this.ffi = ffi;
        this.callbacks = new QuickJSModuleCallbacks(module3);
      }
      /**
       * Create a runtime.
       * Use the runtime to set limits on CPU and memory usage and configure module
       * loading for one or more [[QuickJSContext]]s inside the runtime.
       */
      newRuntime(options = {}) {
        const rt = new lifetime_1.Lifetime(this.ffi.QTS_NewRuntime(), void 0, (rt_ptr) => {
          this.callbacks.deleteRuntime(rt_ptr);
          this.ffi.QTS_FreeRuntime(rt_ptr);
        });
        const runtime = new runtime_1.QuickJSRuntime({
          module: this.module,
          callbacks: this.callbacks,
          ffi: this.ffi,
          rt
        });
        applyBaseRuntimeOptions(runtime, options);
        if (options.moduleLoader) {
          runtime.setModuleLoader(options.moduleLoader);
        }
        return runtime;
      }
      /**
       * A simplified API to create a new [[QuickJSRuntime]] and a
       * [[QuickJSContext]] inside that runtime at the same time. The runtime will
       * be disposed when the context is disposed.
       */
      newContext(options = {}) {
        const runtime = this.newRuntime();
        const context = runtime.newContext({
          ...options,
          ownedLifetimes: (0, types_1.concat)(runtime, options.ownedLifetimes)
        });
        runtime.context = context;
        return context;
      }
      /**
       * One-off evaluate code without needing to create a [[QuickJSRuntime]] or
       * [[QuickJSContext]] explicitly.
       *
       * To protect against infinite loops, use the `shouldInterrupt` option. The
       * [[shouldInterruptAfterDeadline]] function will create a time-based deadline.
       *
       * If you need more control over how the code executes, create a
       * [[QuickJSRuntime]] (with [[newRuntime]]) or a [[QuickJSContext]] (with
       * [[newContext]] or [[QuickJSRuntime.newContext]]), and use its
       * [[QuickJSContext.evalCode]] method.
       *
       * Asynchronous callbacks may not run during the first call to `evalCode`. If
       * you need to work with async code inside QuickJS, create a runtime and use
       * [[QuickJSRuntime.executePendingJobs]].
       *
       * @returns The result is coerced to a native Javascript value using JSON
       * serialization, so properties and values unsupported by JSON will be dropped.
       *
       * @throws If `code` throws during evaluation, the exception will be
       * converted into a native Javascript value and thrown.
       *
       * @throws if `options.shouldInterrupt` interrupted execution, will throw a Error
       * with name `"InternalError"` and  message `"interrupted"`.
       */
      evalCode(code, options = {}) {
        return lifetime_1.Scope.withScope((scope) => {
          const vm = scope.manage(this.newContext());
          applyModuleEvalRuntimeOptions(vm.runtime, options);
          const result2 = vm.evalCode(code, "eval.js");
          if (options.memoryLimitBytes !== void 0) {
            vm.runtime.setMemoryLimit(-1);
          }
          if (result2.error) {
            const error4 = vm.dump(scope.manage(result2.error));
            throw error4;
          }
          const value = vm.dump(scope.manage(result2.value));
          return value;
        });
      }
      /**
       * Get a low-level interface to the QuickJS functions in this WebAssembly
       * module.
       * @experimental
       * @unstable No warranty is provided with this API. It could change at any time.
       * @private
       */
      getFFI() {
        return this.ffi;
      }
    };
    exports2.QuickJSWASMModule = QuickJSWASMModule;
  }
});

// ../../node_modules/@tootallnate/quickjs-emscripten/dist/context-asyncify.js
var require_context_asyncify = __commonJS({
  "../../node_modules/@tootallnate/quickjs-emscripten/dist/context-asyncify.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.QuickJSAsyncContext = void 0;
    var context_1 = require_context();
    var debug_1 = require_debug3();
    var types_1 = require_types3();
    var QuickJSAsyncContext = class extends context_1.QuickJSContext {
      static {
        __name(this, "QuickJSAsyncContext");
      }
      /**
       * Asyncified version of [[evalCode]].
       */
      async evalCodeAsync(code, filename = "eval.js", options) {
        const detectModule = options === void 0 ? 1 : 0;
        const flags = (0, types_1.evalOptionsToFlags)(options);
        let resultPtr = 0;
        try {
          resultPtr = await this.memory.newHeapCharPointer(code).consume((charHandle) => this.ffi.QTS_Eval_MaybeAsync(this.ctx.value, charHandle.value, filename, detectModule, flags));
        } catch (error4) {
          (0, debug_1.debugLog)("QTS_Eval_MaybeAsync threw", error4);
          throw error4;
        }
        const errorPtr = this.ffi.QTS_ResolveException(this.ctx.value, resultPtr);
        if (errorPtr) {
          this.ffi.QTS_FreeValuePointer(this.ctx.value, resultPtr);
          return { error: this.memory.heapValueHandle(errorPtr) };
        }
        return { value: this.memory.heapValueHandle(resultPtr) };
      }
      /**
       * Similar to [[newFunction]].
       * Convert an async host Javascript function into a synchronous QuickJS function value.
       *
       * Whenever QuickJS calls this function, the VM's stack will be unwound while
       * waiting the async function to complete, and then restored when the returned
       * promise resolves.
       *
       * Asyncified functions must never call other asyncified functions or
       * `import`, even indirectly, because the stack cannot be unwound twice.
       *
       * See [Emscripten's docs on Asyncify](https://emscripten.org/docs/porting/asyncify.html).
       */
      newAsyncifiedFunction(name, fn) {
        return this.newFunction(name, fn);
      }
    };
    exports2.QuickJSAsyncContext = QuickJSAsyncContext;
  }
});

// ../../node_modules/@tootallnate/quickjs-emscripten/dist/runtime-asyncify.js
var require_runtime_asyncify = __commonJS({
  "../../node_modules/@tootallnate/quickjs-emscripten/dist/runtime-asyncify.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.QuickJSAsyncRuntime = void 0;
    var _1 = require_dist12();
    var context_asyncify_1 = require_context_asyncify();
    var runtime_1 = require_runtime();
    var types_1 = require_types3();
    var QuickJSAsyncRuntime = class extends runtime_1.QuickJSRuntime {
      static {
        __name(this, "QuickJSAsyncRuntime");
      }
      /** @private */
      constructor(args) {
        super(args);
      }
      newContext(options = {}) {
        if (options.intrinsics && options.intrinsics !== types_1.DefaultIntrinsics) {
          throw new Error("TODO: Custom intrinsics are not supported yet");
        }
        const ctx = new _1.Lifetime(this.ffi.QTS_NewContext(this.rt.value), void 0, (ctx_ptr) => {
          this.contextMap.delete(ctx_ptr);
          this.callbacks.deleteContext(ctx_ptr);
          this.ffi.QTS_FreeContext(ctx_ptr);
        });
        const context = new context_asyncify_1.QuickJSAsyncContext({
          module: this.module,
          ctx,
          ffi: this.ffi,
          rt: this.rt,
          ownedLifetimes: [],
          runtime: this,
          callbacks: this.callbacks
        });
        this.contextMap.set(ctx.value, context);
        return context;
      }
      setModuleLoader(moduleLoader, moduleNormalizer) {
        super.setModuleLoader(moduleLoader, moduleNormalizer);
      }
      /**
       * Set the max stack size for this runtime in bytes.
       * To remove the limit, set to `0`.
       *
       * Setting this limit also adjusts the global `ASYNCIFY_STACK_SIZE` for the entire {@link QuickJSAsyncWASMModule}.
       * See the [pull request](https://github.com/justjake/quickjs-emscripten/pull/114) for more details.
       */
      setMaxStackSize(stackSize) {
        return super.setMaxStackSize(stackSize);
      }
    };
    exports2.QuickJSAsyncRuntime = QuickJSAsyncRuntime;
  }
});

// ../../node_modules/@tootallnate/quickjs-emscripten/dist/module-asyncify.js
var require_module_asyncify = __commonJS({
  "../../node_modules/@tootallnate/quickjs-emscripten/dist/module-asyncify.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.QuickJSAsyncWASMModule = void 0;
    var errors_1 = require_errors19();
    var lifetime_1 = require_lifetime();
    var module_1 = require_module();
    var runtime_asyncify_1 = require_runtime_asyncify();
    var QuickJSAsyncWASMModule = class extends module_1.QuickJSWASMModule {
      static {
        __name(this, "QuickJSAsyncWASMModule");
      }
      /** @private */
      constructor(module3, ffi) {
        super(module3, ffi);
        this.ffi = ffi;
        this.module = module3;
      }
      /**
       * Create a new async runtime inside this WebAssembly module. All runtimes inside a
       * module are limited to a single async call at a time. For multiple
       * concurrent async actions, create multiple WebAssembly modules.
       */
      newRuntime(options = {}) {
        const rt = new lifetime_1.Lifetime(this.ffi.QTS_NewRuntime(), void 0, (rt_ptr) => {
          this.callbacks.deleteRuntime(rt_ptr);
          this.ffi.QTS_FreeRuntime(rt_ptr);
        });
        const runtime = new runtime_asyncify_1.QuickJSAsyncRuntime({
          module: this.module,
          ffi: this.ffi,
          rt,
          callbacks: this.callbacks
        });
        (0, module_1.applyBaseRuntimeOptions)(runtime, options);
        if (options.moduleLoader) {
          runtime.setModuleLoader(options.moduleLoader);
        }
        return runtime;
      }
      /**
       * A simplified API to create a new [[QuickJSRuntime]] and a
       * [[QuickJSContext]] inside that runtime at the same time. The runtime will
       * be disposed when the context is disposed.
       */
      newContext(options = {}) {
        const runtime = this.newRuntime();
        const lifetimes = options.ownedLifetimes ? options.ownedLifetimes.concat([runtime]) : [runtime];
        const context = runtime.newContext({ ...options, ownedLifetimes: lifetimes });
        runtime.context = context;
        return context;
      }
      /** Synchronous evalCode is not supported. */
      evalCode() {
        throw new errors_1.QuickJSNotImplemented("QuickJSWASMModuleAsyncify.evalCode: use evalCodeAsync instead");
      }
      /**
       * One-off evaluate code without needing to create a [[QuickJSRuntimeAsync]] or
       * [[QuickJSContextSync]] explicitly.
       *
       * This version allows for asynchronous Ecmascript module loading.
       *
       * Note that only a single async action can occur at a time inside the entire WebAssembly module.
       * **Multiple concurrent async actions is an error.**
       *
       * See the documentation for [[QuickJSWASMModule.evalCode]] for more details.
       */
      evalCodeAsync(code, options) {
        return lifetime_1.Scope.withScopeAsync(async (scope) => {
          const vm = scope.manage(this.newContext());
          (0, module_1.applyModuleEvalRuntimeOptions)(vm.runtime, options);
          const result2 = await vm.evalCodeAsync(code, "eval.js");
          if (options.memoryLimitBytes !== void 0) {
            vm.runtime.setMemoryLimit(-1);
          }
          if (result2.error) {
            const error4 = vm.dump(scope.manage(result2.error));
            throw error4;
          }
          const value = vm.dump(scope.manage(result2.value));
          return value;
        });
      }
    };
    exports2.QuickJSAsyncWASMModule = QuickJSAsyncWASMModule;
  }
});

// ../../node_modules/@tootallnate/quickjs-emscripten/dist/generated/ffi.WASM_RELEASE_SYNC.js
var require_ffi_WASM_RELEASE_SYNC = __commonJS({
  "../../node_modules/@tootallnate/quickjs-emscripten/dist/generated/ffi.WASM_RELEASE_SYNC.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.QuickJSFFI = void 0;
    var QuickJSFFI = class {
      static {
        __name(this, "QuickJSFFI");
      }
      constructor(module3) {
        this.module = module3;
        this.DEBUG = false;
        this.QTS_Throw = this.module.cwrap("QTS_Throw", "number", ["number", "number"]);
        this.QTS_NewError = this.module.cwrap("QTS_NewError", "number", ["number"]);
        this.QTS_RuntimeSetMemoryLimit = this.module.cwrap("QTS_RuntimeSetMemoryLimit", null, ["number", "number"]);
        this.QTS_RuntimeComputeMemoryUsage = this.module.cwrap("QTS_RuntimeComputeMemoryUsage", "number", ["number", "number"]);
        this.QTS_RuntimeDumpMemoryUsage = this.module.cwrap("QTS_RuntimeDumpMemoryUsage", "number", ["number"]);
        this.QTS_RecoverableLeakCheck = this.module.cwrap("QTS_RecoverableLeakCheck", "number", []);
        this.QTS_BuildIsSanitizeLeak = this.module.cwrap("QTS_BuildIsSanitizeLeak", "number", []);
        this.QTS_RuntimeSetMaxStackSize = this.module.cwrap("QTS_RuntimeSetMaxStackSize", null, ["number", "number"]);
        this.QTS_GetUndefined = this.module.cwrap("QTS_GetUndefined", "number", []);
        this.QTS_GetNull = this.module.cwrap("QTS_GetNull", "number", []);
        this.QTS_GetFalse = this.module.cwrap("QTS_GetFalse", "number", []);
        this.QTS_GetTrue = this.module.cwrap("QTS_GetTrue", "number", []);
        this.QTS_NewRuntime = this.module.cwrap("QTS_NewRuntime", "number", []);
        this.QTS_FreeRuntime = this.module.cwrap("QTS_FreeRuntime", null, ["number"]);
        this.QTS_NewContext = this.module.cwrap("QTS_NewContext", "number", ["number"]);
        this.QTS_FreeContext = this.module.cwrap("QTS_FreeContext", null, ["number"]);
        this.QTS_FreeValuePointer = this.module.cwrap("QTS_FreeValuePointer", null, ["number", "number"]);
        this.QTS_FreeValuePointerRuntime = this.module.cwrap("QTS_FreeValuePointerRuntime", null, ["number", "number"]);
        this.QTS_FreeVoidPointer = this.module.cwrap("QTS_FreeVoidPointer", null, ["number", "number"]);
        this.QTS_FreeCString = this.module.cwrap("QTS_FreeCString", null, ["number", "number"]);
        this.QTS_DupValuePointer = this.module.cwrap("QTS_DupValuePointer", "number", ["number", "number"]);
        this.QTS_NewObject = this.module.cwrap("QTS_NewObject", "number", ["number"]);
        this.QTS_NewObjectProto = this.module.cwrap("QTS_NewObjectProto", "number", ["number", "number"]);
        this.QTS_NewArray = this.module.cwrap("QTS_NewArray", "number", ["number"]);
        this.QTS_NewFloat64 = this.module.cwrap("QTS_NewFloat64", "number", ["number", "number"]);
        this.QTS_GetFloat64 = this.module.cwrap("QTS_GetFloat64", "number", ["number", "number"]);
        this.QTS_NewString = this.module.cwrap("QTS_NewString", "number", ["number", "number"]);
        this.QTS_GetString = this.module.cwrap("QTS_GetString", "number", ["number", "number"]);
        this.QTS_NewSymbol = this.module.cwrap("QTS_NewSymbol", "number", ["number", "number", "number"]);
        this.QTS_GetSymbolDescriptionOrKey = this.module.cwrap("QTS_GetSymbolDescriptionOrKey", "number", ["number", "number"]);
        this.QTS_IsGlobalSymbol = this.module.cwrap("QTS_IsGlobalSymbol", "number", ["number", "number"]);
        this.QTS_IsJobPending = this.module.cwrap("QTS_IsJobPending", "number", ["number"]);
        this.QTS_ExecutePendingJob = this.module.cwrap("QTS_ExecutePendingJob", "number", ["number", "number", "number"]);
        this.QTS_GetProp = this.module.cwrap("QTS_GetProp", "number", ["number", "number", "number"]);
        this.QTS_SetProp = this.module.cwrap("QTS_SetProp", null, ["number", "number", "number", "number"]);
        this.QTS_DefineProp = this.module.cwrap("QTS_DefineProp", null, ["number", "number", "number", "number", "number", "number", "boolean", "boolean", "boolean"]);
        this.QTS_Call = this.module.cwrap("QTS_Call", "number", ["number", "number", "number", "number", "number"]);
        this.QTS_ResolveException = this.module.cwrap("QTS_ResolveException", "number", ["number", "number"]);
        this.QTS_Dump = this.module.cwrap("QTS_Dump", "number", ["number", "number"]);
        this.QTS_Eval = this.module.cwrap("QTS_Eval", "number", ["number", "number", "string", "number", "number"]);
        this.QTS_Typeof = this.module.cwrap("QTS_Typeof", "number", ["number", "number"]);
        this.QTS_GetGlobalObject = this.module.cwrap("QTS_GetGlobalObject", "number", ["number"]);
        this.QTS_NewPromiseCapability = this.module.cwrap("QTS_NewPromiseCapability", "number", ["number", "number"]);
        this.QTS_TestStringArg = this.module.cwrap("QTS_TestStringArg", null, ["string"]);
        this.QTS_BuildIsDebug = this.module.cwrap("QTS_BuildIsDebug", "number", []);
        this.QTS_BuildIsAsyncify = this.module.cwrap("QTS_BuildIsAsyncify", "number", []);
        this.QTS_NewFunction = this.module.cwrap("QTS_NewFunction", "number", ["number", "number", "string"]);
        this.QTS_ArgvGetJSValueConstPointer = this.module.cwrap("QTS_ArgvGetJSValueConstPointer", "number", ["number", "number"]);
        this.QTS_RuntimeEnableInterruptHandler = this.module.cwrap("QTS_RuntimeEnableInterruptHandler", null, ["number"]);
        this.QTS_RuntimeDisableInterruptHandler = this.module.cwrap("QTS_RuntimeDisableInterruptHandler", null, ["number"]);
        this.QTS_RuntimeEnableModuleLoader = this.module.cwrap("QTS_RuntimeEnableModuleLoader", null, ["number", "number"]);
        this.QTS_RuntimeDisableModuleLoader = this.module.cwrap("QTS_RuntimeDisableModuleLoader", null, ["number"]);
      }
    };
    exports2.QuickJSFFI = QuickJSFFI;
  }
});

// ../../node_modules/@tootallnate/quickjs-emscripten/dist/generated/emscripten-module.WASM_RELEASE_SYNC.js
var require_emscripten_module_WASM_RELEASE_SYNC = __commonJS({
  "../../node_modules/@tootallnate/quickjs-emscripten/dist/generated/emscripten-module.WASM_RELEASE_SYNC.js"(exports2, module2) {
    "use strict";
    var QuickJSRaw = (() => {
      var _scriptDir = typeof document !== "undefined" && document.currentScript ? document.currentScript.src : void 0;
      if (typeof __filename !== "undefined")
        _scriptDir = _scriptDir || __filename;
      return (function(QuickJSRaw2 = {}) {
        var a32;
        a32 || (a32 = typeof QuickJSRaw2 !== "undefined" ? QuickJSRaw2 : {});
        var m20, n10;
        a32.ready = new Promise(function(b32, c32) {
          m20 = b32;
          n10 = c32;
        });
        var p10 = Object.assign({}, a32), t = "./this.program", u = "object" == typeof window, v = "function" == typeof importScripts, w = "object" == typeof process && "object" == typeof process.versions && "string" == typeof process.versions.node, x = "", y, z, A;
        if (w) {
          var fs51 = require("fs"), B = require("path");
          x = v ? B.dirname(x) + "/" : __dirname + "/";
          y = /* @__PURE__ */ __name((b32, c32) => {
            var d32 = C(b32);
            if (d32)
              return c32 ? d32 : d32.toString();
            b32 = b32.startsWith("file://") ? new URL(b32) : B.normalize(b32);
            return fs51.readFileSync(b32, c32 ? void 0 : "utf8");
          }, "y");
          A = /* @__PURE__ */ __name((b32) => {
            b32 = y(b32, true);
            b32.buffer || (b32 = new Uint8Array(b32));
            return b32;
          }, "A");
          z = /* @__PURE__ */ __name((b32, c32, d32) => {
            var e32 = C(b32);
            e32 && c32(e32);
            b32 = b32.startsWith("file://") ? new URL(b32) : B.normalize(b32);
            fs51.readFile(b32, function(f32, g32) {
              f32 ? d32(f32) : c32(g32.buffer);
            });
          }, "z");
          !a32.thisProgram && 1 < process.argv.length && (t = process.argv[1].replace(/\\/g, "/"));
          process.argv.slice(2);
          a32.inspect = function() {
            return "[Emscripten Module object]";
          };
        } else if (u || v)
          v ? x = self.location.href : "undefined" != typeof document && document.currentScript && (x = document.currentScript.src), _scriptDir && (x = _scriptDir), 0 !== x.indexOf("blob:") ? x = x.substr(0, x.replace(/[?#].*/, "").lastIndexOf("/") + 1) : x = "", y = /* @__PURE__ */ __name((b32) => {
            try {
              var c32 = new XMLHttpRequest();
              c32.open("GET", b32, false);
              c32.send(null);
              return c32.responseText;
            } catch (f32) {
              if (b32 = C(b32)) {
                c32 = [];
                for (var d32 = 0; d32 < b32.length; d32++) {
                  var e32 = b32[d32];
                  255 < e32 && (e32 &= 255);
                  c32.push(String.fromCharCode(e32));
                }
                return c32.join("");
              }
              throw f32;
            }
          }, "y"), v && (A = /* @__PURE__ */ __name((b32) => {
            try {
              var c32 = new XMLHttpRequest();
              c32.open("GET", b32, false);
              c32.responseType = "arraybuffer";
              c32.send(null);
              return new Uint8Array(c32.response);
            } catch (d32) {
              if (b32 = C(b32))
                return b32;
              throw d32;
            }
          }, "A")), z = /* @__PURE__ */ __name((b32, c32, d32) => {
            var e32 = new XMLHttpRequest();
            e32.open("GET", b32, true);
            e32.responseType = "arraybuffer";
            e32.onload = () => {
              if (200 == e32.status || 0 == e32.status && e32.response)
                c32(e32.response);
              else {
                var f32 = C(b32);
                f32 ? c32(f32.buffer) : d32();
              }
            };
            e32.onerror = d32;
            e32.send(null);
          }, "z");
        var aa = a32.print || console.log.bind(console), D = a32.printErr || console.warn.bind(console);
        Object.assign(a32, p10);
        p10 = null;
        a32.thisProgram && (t = a32.thisProgram);
        var E;
        a32.wasmBinary && (E = a32.wasmBinary);
        var noExitRuntime = a32.noExitRuntime || true;
        "object" != typeof WebAssembly && F("no native wasm support detected");
        var G, H = false, I, J, K, L;
        function M() {
          var b32 = G.buffer;
          a32.HEAP8 = I = new Int8Array(b32);
          a32.HEAP16 = new Int16Array(b32);
          a32.HEAP32 = K = new Int32Array(b32);
          a32.HEAPU8 = J = new Uint8Array(b32);
          a32.HEAPU16 = new Uint16Array(b32);
          a32.HEAPU32 = L = new Uint32Array(b32);
          a32.HEAPF32 = new Float32Array(b32);
          a32.HEAPF64 = new Float64Array(b32);
        }
        __name(M, "M");
        var ba = [], ca = [], da = [];
        function ea() {
          var b32 = a32.preRun.shift();
          ba.unshift(b32);
        }
        __name(ea, "ea");
        var N = 0, O = null, P = null;
        function F(b32) {
          if (a32.onAbort)
            a32.onAbort(b32);
          b32 = "Aborted(" + b32 + ")";
          D(b32);
          H = true;
          b32 = new WebAssembly.RuntimeError(b32 + ". Build with -sASSERTIONS for more info.");
          n10(b32);
          throw b32;
        }
        __name(F, "F");
        var Q = "data:application/octet-stream;base64,", R;
        R = "data:application/octet-stream;base64, ";
        if (!R.startsWith(Q)) {
          var fa = R;
          R = a32.locateFile ? a32.locateFile(fa, x) : x + fa;
        }
        function ha(b32) {
          try {
            if (b32 == R && E)
              return new Uint8Array(E);
            var c32 = C(b32);
            if (c32)
              return c32;
            if (A)
              return A(b32);
            throw "both async and sync fetching of the wasm failed";
          } catch (d32) {
            F(d32);
          }
        }
        __name(ha, "ha");
        function ia(b32) {
          if (!E && (u || v)) {
            if ("function" == typeof fetch && !b32.startsWith("file://"))
              return fetch(b32, { credentials: "same-origin" }).then(function(c32) {
                if (!c32.ok)
                  throw "failed to load wasm binary file at '" + b32 + "'";
                return c32.arrayBuffer();
              }).catch(function() {
                return ha(b32);
              });
            if (z)
              return new Promise(function(c32, d32) {
                z(b32, function(e32) {
                  c32(new Uint8Array(e32));
                }, d32);
              });
          }
          return Promise.resolve().then(function() {
            return ha(b32);
          });
        }
        __name(ia, "ia");
        function ja(b32, c32, d32) {
          return ia(b32).then(function(e32) {
            return WebAssembly.instantiate(e32, c32);
          }).then(function(e32) {
            return e32;
          }).then(d32, function(e32) {
            D("failed to asynchronously prepare wasm: " + e32);
            F(e32);
          });
        }
        __name(ja, "ja");
        function ka(b32, c32) {
          var d32 = R;
          return E || "function" != typeof WebAssembly.instantiateStreaming || d32.startsWith(Q) || d32.startsWith("file://") || w || "function" != typeof fetch ? ja(d32, b32, c32) : fetch(d32, { credentials: "same-origin" }).then(function(e32) {
            return WebAssembly.instantiateStreaming(e32, b32).then(c32, function(f32) {
              D("wasm streaming compile failed: " + f32);
              D("falling back to ArrayBuffer instantiation");
              return ja(d32, b32, c32);
            });
          });
        }
        __name(ka, "ka");
        function S(b32) {
          for (; 0 < b32.length; )
            b32.shift()(a32);
        }
        __name(S, "S");
        var la = "undefined" != typeof TextDecoder ? new TextDecoder("utf8") : void 0;
        function na(b32, c32, d32) {
          var e32 = c32 + d32;
          for (d32 = c32; b32[d32] && !(d32 >= e32); )
            ++d32;
          if (16 < d32 - c32 && b32.buffer && la)
            return la.decode(b32.subarray(c32, d32));
          for (e32 = ""; c32 < d32; ) {
            var f32 = b32[c32++];
            if (f32 & 128) {
              var g32 = b32[c32++] & 63;
              if (192 == (f32 & 224))
                e32 += String.fromCharCode((f32 & 31) << 6 | g32);
              else {
                var h32 = b32[c32++] & 63;
                f32 = 224 == (f32 & 240) ? (f32 & 15) << 12 | g32 << 6 | h32 : (f32 & 7) << 18 | g32 << 12 | h32 << 6 | b32[c32++] & 63;
                65536 > f32 ? e32 += String.fromCharCode(f32) : (f32 -= 65536, e32 += String.fromCharCode(55296 | f32 >> 10, 56320 | f32 & 1023));
              }
            } else
              e32 += String.fromCharCode(f32);
          }
          return e32;
        }
        __name(na, "na");
        function T(b32, c32) {
          return b32 ? na(J, b32, c32) : "";
        }
        __name(T, "T");
        var oa = [0, 31, 60, 91, 121, 152, 182, 213, 244, 274, 305, 335], pa = [0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334];
        function U(b32) {
          for (var c32 = 0, d32 = 0; d32 < b32.length; ++d32) {
            var e32 = b32.charCodeAt(d32);
            127 >= e32 ? c32++ : 2047 >= e32 ? c32 += 2 : 55296 <= e32 && 57343 >= e32 ? (c32 += 4, ++d32) : c32 += 3;
          }
          return c32;
        }
        __name(U, "U");
        function V(b32, c32, d32) {
          var e32 = J;
          if (!(0 < d32))
            return 0;
          var f32 = c32;
          d32 = c32 + d32 - 1;
          for (var g32 = 0; g32 < b32.length; ++g32) {
            var h32 = b32.charCodeAt(g32);
            if (55296 <= h32 && 57343 >= h32) {
              var k32 = b32.charCodeAt(++g32);
              h32 = 65536 + ((h32 & 1023) << 10) | k32 & 1023;
            }
            if (127 >= h32) {
              if (c32 >= d32)
                break;
              e32[c32++] = h32;
            } else {
              if (2047 >= h32) {
                if (c32 + 1 >= d32)
                  break;
                e32[c32++] = 192 | h32 >> 6;
              } else {
                if (65535 >= h32) {
                  if (c32 + 2 >= d32)
                    break;
                  e32[c32++] = 224 | h32 >> 12;
                } else {
                  if (c32 + 3 >= d32)
                    break;
                  e32[c32++] = 240 | h32 >> 18;
                  e32[c32++] = 128 | h32 >> 12 & 63;
                }
                e32[c32++] = 128 | h32 >> 6 & 63;
              }
              e32[c32++] = 128 | h32 & 63;
            }
          }
          e32[c32] = 0;
          return c32 - f32;
        }
        __name(V, "V");
        function qa(b32) {
          var c32 = U(b32) + 1, d32 = ra(c32);
          d32 && V(b32, d32, c32);
          return d32;
        }
        __name(qa, "qa");
        var W = {};
        function sa() {
          if (!X) {
            var b32 = { USER: "web_user", LOGNAME: "web_user", PATH: "/", PWD: "/", HOME: "/home/web_user", LANG: ("object" == typeof navigator && navigator.languages && navigator.languages[0] || "C").replace("-", "_") + ".UTF-8", _: t || "./this.program" }, c32;
            for (c32 in W)
              void 0 === W[c32] ? delete b32[c32] : b32[c32] = W[c32];
            var d32 = [];
            for (c32 in b32)
              d32.push(c32 + "=" + b32[c32]);
            X = d32;
          }
          return X;
        }
        __name(sa, "sa");
        var X, ta = [null, [], []];
        function ua(b32, c32, d32, e32) {
          var f32 = { string: /* @__PURE__ */ __name((l20) => {
            var q10 = 0;
            if (null !== l20 && void 0 !== l20 && 0 !== l20) {
              q10 = U(l20) + 1;
              var ma = Y(q10);
              V(l20, ma, q10);
              q10 = ma;
            }
            return q10;
          }, "string"), array: /* @__PURE__ */ __name((l20) => {
            var q10 = Y(l20.length);
            I.set(l20, q10);
            return q10;
          }, "array") };
          b32 = a32["_" + b32];
          var g32 = [], h32 = 0;
          if (e32)
            for (var k32 = 0; k32 < e32.length; k32++) {
              var r32 = f32[d32[k32]];
              r32 ? (0 === h32 && (h32 = va()), g32[k32] = r32(e32[k32])) : g32[k32] = e32[k32];
            }
          d32 = b32.apply(null, g32);
          return d32 = (function(l20) {
            0 !== h32 && wa(h32);
            return "string" === c32 ? T(l20) : "boolean" === c32 ? !!l20 : l20;
          })(d32);
        }
        __name(ua, "ua");
        var xa = "function" == typeof atob ? atob : function(b32) {
          var c32 = "", d32 = 0;
          b32 = b32.replace(/[^A-Za-z0-9\+\/=]/g, "");
          do {
            var e32 = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=".indexOf(b32.charAt(d32++));
            var f32 = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=".indexOf(b32.charAt(d32++));
            var g32 = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=".indexOf(b32.charAt(d32++));
            var h32 = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=".indexOf(b32.charAt(d32++));
            e32 = e32 << 2 | f32 >> 4;
            f32 = (f32 & 15) << 4 | g32 >> 2;
            var k32 = (g32 & 3) << 6 | h32;
            c32 += String.fromCharCode(e32);
            64 !== g32 && (c32 += String.fromCharCode(f32));
            64 !== h32 && (c32 += String.fromCharCode(k32));
          } while (d32 < b32.length);
          return c32;
        };
        function C(b32) {
          if (b32.startsWith(Q)) {
            b32 = b32.slice(Q.length);
            if ("boolean" == typeof w && w) {
              var c32 = Buffer.from(b32, "base64");
              c32 = new Uint8Array(c32.buffer, c32.byteOffset, c32.byteLength);
            } else
              try {
                var d32 = xa(b32), e32 = new Uint8Array(d32.length);
                for (b32 = 0; b32 < d32.length; ++b32)
                  e32[b32] = d32.charCodeAt(b32);
                c32 = e32;
              } catch (f32) {
                throw Error("Converting base64 string to bytes failed.");
              }
            return c32;
          }
        }
        __name(C, "C");
        var ya = {
          a: /* @__PURE__ */ __name(function(b32, c32, d32, e32) {
            F("Assertion failed: " + T(b32) + ", at: " + [c32 ? T(c32) : "unknown filename", d32, e32 ? T(e32) : "unknown function"]);
          }, "a"),
          l: /* @__PURE__ */ __name(function(b32, c32) {
            b32 = new Date(1e3 * (L[b32 >> 2] + 4294967296 * K[b32 + 4 >> 2]));
            K[c32 >> 2] = b32.getSeconds();
            K[c32 + 4 >> 2] = b32.getMinutes();
            K[c32 + 8 >> 2] = b32.getHours();
            K[c32 + 12 >> 2] = b32.getDate();
            K[c32 + 16 >> 2] = b32.getMonth();
            K[c32 + 20 >> 2] = b32.getFullYear() - 1900;
            K[c32 + 24 >> 2] = b32.getDay();
            var d32 = b32.getFullYear();
            K[c32 + 28 >> 2] = (0 !== d32 % 4 || 0 === d32 % 100 && 0 !== d32 % 400 ? pa : oa)[b32.getMonth()] + b32.getDate() - 1 | 0;
            K[c32 + 36 >> 2] = -(60 * b32.getTimezoneOffset());
            d32 = new Date(b32.getFullYear(), 6, 1).getTimezoneOffset();
            var e32 = new Date(b32.getFullYear(), 0, 1).getTimezoneOffset();
            K[c32 + 32 >> 2] = (d32 != e32 && b32.getTimezoneOffset() == Math.min(e32, d32)) | 0;
          }, "l"),
          k: /* @__PURE__ */ __name(function(b32, c32, d32) {
            function e32(r32) {
              return (r32 = r32.toTimeString().match(/\(([A-Za-z ]+)\)$/)) ? r32[1] : "GMT";
            }
            __name(e32, "e");
            var f32 = (/* @__PURE__ */ new Date()).getFullYear(), g32 = new Date(f32, 0, 1), h32 = new Date(f32, 6, 1);
            f32 = g32.getTimezoneOffset();
            var k32 = h32.getTimezoneOffset();
            L[b32 >> 2] = 60 * Math.max(f32, k32);
            K[c32 >> 2] = Number(f32 != k32);
            b32 = e32(g32);
            c32 = e32(h32);
            b32 = qa(b32);
            c32 = qa(c32);
            k32 < f32 ? (L[d32 >> 2] = b32, L[d32 + 4 >> 2] = c32) : (L[d32 >> 2] = c32, L[d32 + 4 >> 2] = b32);
          }, "k"),
          b: /* @__PURE__ */ __name(function() {
            F("");
          }, "b"),
          m: /* @__PURE__ */ __name(function() {
            return Date.now();
          }, "m"),
          j: /* @__PURE__ */ __name(function(b32) {
            var c32 = J.length;
            b32 >>>= 0;
            if (2147483648 < b32)
              return false;
            for (var d32 = 1; 4 >= d32; d32 *= 2) {
              var e32 = c32 * (1 + 0.2 / d32);
              e32 = Math.min(e32, b32 + 100663296);
              var f32 = Math, g32 = f32.min;
              e32 = Math.max(b32, e32);
              e32 += (65536 - e32 % 65536) % 65536;
              a: {
                var h32 = G.buffer;
                try {
                  G.grow(g32.call(f32, 2147483648, e32) - h32.byteLength + 65535 >>> 16);
                  M();
                  var k32 = 1;
                  break a;
                } catch (r32) {
                }
                k32 = void 0;
              }
              if (k32)
                return true;
            }
            return false;
          }, "j"),
          e: /* @__PURE__ */ __name(function(b32, c32) {
            var d32 = 0;
            sa().forEach(function(e32, f32) {
              var g32 = c32 + d32;
              f32 = L[b32 + 4 * f32 >> 2] = g32;
              for (g32 = 0; g32 < e32.length; ++g32)
                I[f32++ >> 0] = e32.charCodeAt(g32);
              I[f32 >> 0] = 0;
              d32 += e32.length + 1;
            });
            return 0;
          }, "e"),
          f: /* @__PURE__ */ __name(function(b32, c32) {
            var d32 = sa();
            L[b32 >> 2] = d32.length;
            var e32 = 0;
            d32.forEach(function(f32) {
              e32 += f32.length + 1;
            });
            L[c32 >> 2] = e32;
            return 0;
          }, "f"),
          d: /* @__PURE__ */ __name(function() {
            return 52;
          }, "d"),
          i: /* @__PURE__ */ __name(function() {
            return 70;
          }, "i"),
          c: /* @__PURE__ */ __name(function(b32, c32, d32, e32) {
            for (var f32 = 0, g32 = 0; g32 < d32; g32++) {
              var h32 = L[c32 >> 2], k32 = L[c32 + 4 >> 2];
              c32 += 8;
              for (var r32 = 0; r32 < k32; r32++) {
                var l20 = J[h32 + r32], q10 = ta[b32];
                0 === l20 || 10 === l20 ? ((1 === b32 ? aa : D)(na(q10, 0)), q10.length = 0) : q10.push(l20);
              }
              f32 += k32;
            }
            L[e32 >> 2] = f32;
            return 0;
          }, "c"),
          o: /* @__PURE__ */ __name(function(b32, c32, d32, e32, f32) {
            return a32.callbacks.callFunction(void 0, b32, c32, d32, e32, f32);
          }, "o"),
          n: /* @__PURE__ */ __name(function(b32) {
            return a32.callbacks.shouldInterrupt(void 0, b32);
          }, "n"),
          h: /* @__PURE__ */ __name(function(b32, c32, d32) {
            d32 = T(d32);
            return a32.callbacks.loadModuleSource(void 0, b32, c32, d32);
          }, "h"),
          g: /* @__PURE__ */ __name(function(b32, c32, d32, e32) {
            d32 = T(d32);
            e32 = T(e32);
            return a32.callbacks.normalizeModule(void 0, b32, c32, d32, e32);
          }, "g")
        };
        (function() {
          function b32(d32) {
            d32 = d32.exports;
            a32.asm = d32;
            G = a32.asm.p;
            M();
            ca.unshift(a32.asm.q);
            N--;
            a32.monitorRunDependencies && a32.monitorRunDependencies(N);
            if (0 == N && (null !== O && (clearInterval(O), O = null), P)) {
              var e32 = P;
              P = null;
              e32();
            }
            return d32;
          }
          __name(b32, "b");
          var c32 = { a: ya };
          N++;
          a32.monitorRunDependencies && a32.monitorRunDependencies(N);
          if (a32.instantiateWasm)
            try {
              return a32.instantiateWasm(c32, b32);
            } catch (d32) {
              D("Module.instantiateWasm callback failed with error: " + d32), n10(d32);
            }
          ka(c32, function(d32) {
            b32(d32.instance);
          }).catch(n10);
          return {};
        })();
        var ra = a32._malloc = function() {
          return (ra = a32._malloc = a32.asm.r).apply(null, arguments);
        };
        a32._QTS_Throw = function() {
          return (a32._QTS_Throw = a32.asm.s).apply(null, arguments);
        };
        a32._QTS_NewError = function() {
          return (a32._QTS_NewError = a32.asm.t).apply(null, arguments);
        };
        a32._QTS_RuntimeSetMemoryLimit = function() {
          return (a32._QTS_RuntimeSetMemoryLimit = a32.asm.u).apply(null, arguments);
        };
        a32._QTS_RuntimeComputeMemoryUsage = function() {
          return (a32._QTS_RuntimeComputeMemoryUsage = a32.asm.v).apply(null, arguments);
        };
        a32._QTS_RuntimeDumpMemoryUsage = function() {
          return (a32._QTS_RuntimeDumpMemoryUsage = a32.asm.w).apply(null, arguments);
        };
        a32._QTS_RecoverableLeakCheck = function() {
          return (a32._QTS_RecoverableLeakCheck = a32.asm.x).apply(null, arguments);
        };
        a32._QTS_BuildIsSanitizeLeak = function() {
          return (a32._QTS_BuildIsSanitizeLeak = a32.asm.y).apply(null, arguments);
        };
        a32._QTS_RuntimeSetMaxStackSize = function() {
          return (a32._QTS_RuntimeSetMaxStackSize = a32.asm.z).apply(null, arguments);
        };
        a32._QTS_GetUndefined = function() {
          return (a32._QTS_GetUndefined = a32.asm.A).apply(null, arguments);
        };
        a32._QTS_GetNull = function() {
          return (a32._QTS_GetNull = a32.asm.B).apply(null, arguments);
        };
        a32._QTS_GetFalse = function() {
          return (a32._QTS_GetFalse = a32.asm.C).apply(null, arguments);
        };
        a32._QTS_GetTrue = function() {
          return (a32._QTS_GetTrue = a32.asm.D).apply(null, arguments);
        };
        a32._QTS_NewRuntime = function() {
          return (a32._QTS_NewRuntime = a32.asm.E).apply(null, arguments);
        };
        a32._QTS_FreeRuntime = function() {
          return (a32._QTS_FreeRuntime = a32.asm.F).apply(null, arguments);
        };
        a32._QTS_NewContext = function() {
          return (a32._QTS_NewContext = a32.asm.G).apply(null, arguments);
        };
        a32._QTS_FreeContext = function() {
          return (a32._QTS_FreeContext = a32.asm.H).apply(null, arguments);
        };
        a32._QTS_FreeValuePointer = function() {
          return (a32._QTS_FreeValuePointer = a32.asm.I).apply(null, arguments);
        };
        a32._free = function() {
          return (a32._free = a32.asm.J).apply(null, arguments);
        };
        a32._QTS_FreeValuePointerRuntime = function() {
          return (a32._QTS_FreeValuePointerRuntime = a32.asm.K).apply(null, arguments);
        };
        a32._QTS_FreeVoidPointer = function() {
          return (a32._QTS_FreeVoidPointer = a32.asm.L).apply(null, arguments);
        };
        a32._QTS_FreeCString = function() {
          return (a32._QTS_FreeCString = a32.asm.M).apply(null, arguments);
        };
        a32._QTS_DupValuePointer = function() {
          return (a32._QTS_DupValuePointer = a32.asm.N).apply(null, arguments);
        };
        a32._QTS_NewObject = function() {
          return (a32._QTS_NewObject = a32.asm.O).apply(null, arguments);
        };
        a32._QTS_NewObjectProto = function() {
          return (a32._QTS_NewObjectProto = a32.asm.P).apply(null, arguments);
        };
        a32._QTS_NewArray = function() {
          return (a32._QTS_NewArray = a32.asm.Q).apply(null, arguments);
        };
        a32._QTS_NewFloat64 = function() {
          return (a32._QTS_NewFloat64 = a32.asm.R).apply(null, arguments);
        };
        a32._QTS_GetFloat64 = function() {
          return (a32._QTS_GetFloat64 = a32.asm.S).apply(null, arguments);
        };
        a32._QTS_NewString = function() {
          return (a32._QTS_NewString = a32.asm.T).apply(null, arguments);
        };
        a32._QTS_GetString = function() {
          return (a32._QTS_GetString = a32.asm.U).apply(null, arguments);
        };
        a32._QTS_NewSymbol = function() {
          return (a32._QTS_NewSymbol = a32.asm.V).apply(null, arguments);
        };
        a32._QTS_GetSymbolDescriptionOrKey = function() {
          return (a32._QTS_GetSymbolDescriptionOrKey = a32.asm.W).apply(null, arguments);
        };
        a32._QTS_IsGlobalSymbol = function() {
          return (a32._QTS_IsGlobalSymbol = a32.asm.X).apply(null, arguments);
        };
        a32._QTS_IsJobPending = function() {
          return (a32._QTS_IsJobPending = a32.asm.Y).apply(null, arguments);
        };
        a32._QTS_ExecutePendingJob = function() {
          return (a32._QTS_ExecutePendingJob = a32.asm.Z).apply(null, arguments);
        };
        a32._QTS_GetProp = function() {
          return (a32._QTS_GetProp = a32.asm._).apply(null, arguments);
        };
        a32._QTS_SetProp = function() {
          return (a32._QTS_SetProp = a32.asm.$).apply(null, arguments);
        };
        a32._QTS_DefineProp = function() {
          return (a32._QTS_DefineProp = a32.asm.aa).apply(null, arguments);
        };
        a32._QTS_Call = function() {
          return (a32._QTS_Call = a32.asm.ba).apply(null, arguments);
        };
        a32._QTS_ResolveException = function() {
          return (a32._QTS_ResolveException = a32.asm.ca).apply(null, arguments);
        };
        a32._QTS_Dump = function() {
          return (a32._QTS_Dump = a32.asm.da).apply(null, arguments);
        };
        a32._QTS_Eval = function() {
          return (a32._QTS_Eval = a32.asm.ea).apply(null, arguments);
        };
        a32._QTS_Typeof = function() {
          return (a32._QTS_Typeof = a32.asm.fa).apply(null, arguments);
        };
        a32._QTS_GetGlobalObject = function() {
          return (a32._QTS_GetGlobalObject = a32.asm.ga).apply(null, arguments);
        };
        a32._QTS_NewPromiseCapability = function() {
          return (a32._QTS_NewPromiseCapability = a32.asm.ha).apply(null, arguments);
        };
        a32._QTS_TestStringArg = function() {
          return (a32._QTS_TestStringArg = a32.asm.ia).apply(null, arguments);
        };
        a32._QTS_BuildIsDebug = function() {
          return (a32._QTS_BuildIsDebug = a32.asm.ja).apply(null, arguments);
        };
        a32._QTS_BuildIsAsyncify = function() {
          return (a32._QTS_BuildIsAsyncify = a32.asm.ka).apply(null, arguments);
        };
        a32._QTS_NewFunction = function() {
          return (a32._QTS_NewFunction = a32.asm.la).apply(null, arguments);
        };
        a32._QTS_ArgvGetJSValueConstPointer = function() {
          return (a32._QTS_ArgvGetJSValueConstPointer = a32.asm.ma).apply(null, arguments);
        };
        a32._QTS_RuntimeEnableInterruptHandler = function() {
          return (a32._QTS_RuntimeEnableInterruptHandler = a32.asm.na).apply(null, arguments);
        };
        a32._QTS_RuntimeDisableInterruptHandler = function() {
          return (a32._QTS_RuntimeDisableInterruptHandler = a32.asm.oa).apply(null, arguments);
        };
        a32._QTS_RuntimeEnableModuleLoader = function() {
          return (a32._QTS_RuntimeEnableModuleLoader = a32.asm.pa).apply(null, arguments);
        };
        a32._QTS_RuntimeDisableModuleLoader = function() {
          return (a32._QTS_RuntimeDisableModuleLoader = a32.asm.qa).apply(null, arguments);
        };
        function va() {
          return (va = a32.asm.sa).apply(null, arguments);
        }
        __name(va, "va");
        function wa() {
          return (wa = a32.asm.ta).apply(null, arguments);
        }
        __name(wa, "wa");
        function Y() {
          return (Y = a32.asm.ua).apply(null, arguments);
        }
        __name(Y, "Y");
        a32.___start_em_js = 74916;
        a32.___stop_em_js = 75818;
        a32.cwrap = function(b32, c32, d32, e32) {
          var f32 = !d32 || d32.every((g32) => "number" === g32 || "boolean" === g32);
          return "string" !== c32 && f32 && !e32 ? a32["_" + b32] : function() {
            return ua(b32, c32, d32, arguments);
          };
        };
        a32.UTF8ToString = T;
        a32.stringToUTF8 = function(b32, c32, d32) {
          return V(b32, c32, d32);
        };
        a32.lengthBytesUTF8 = U;
        var Z;
        P = /* @__PURE__ */ __name(function za() {
          Z || Aa();
          Z || (P = za);
        }, "za");
        function Aa() {
          function b32() {
            if (!Z && (Z = true, a32.calledRun = true, !H)) {
              S(ca);
              m20(a32);
              if (a32.onRuntimeInitialized)
                a32.onRuntimeInitialized();
              if (a32.postRun)
                for ("function" == typeof a32.postRun && (a32.postRun = [a32.postRun]); a32.postRun.length; ) {
                  var c32 = a32.postRun.shift();
                  da.unshift(c32);
                }
              S(da);
            }
          }
          __name(b32, "b");
          if (!(0 < N)) {
            if (a32.preRun)
              for ("function" == typeof a32.preRun && (a32.preRun = [a32.preRun]); a32.preRun.length; )
                ea();
            S(ba);
            0 < N || (a32.setStatus ? (a32.setStatus("Running..."), setTimeout(function() {
              setTimeout(function() {
                a32.setStatus("");
              }, 1);
              b32();
            }, 1)) : b32());
          }
        }
        __name(Aa, "Aa");
        if (a32.preInit)
          for ("function" == typeof a32.preInit && (a32.preInit = [a32.preInit]); 0 < a32.preInit.length; )
            a32.preInit.pop()();
        Aa();
        return QuickJSRaw2.ready;
      });
    })();
    if (typeof exports2 === "object" && typeof module2 === "object")
      module2.exports = QuickJSRaw;
    else if (typeof define === "function" && define["amd"])
      define([], function() {
        return QuickJSRaw;
      });
    else if (typeof exports2 === "object")
      exports2["QuickJSRaw"] = QuickJSRaw;
  }
});

// ../../node_modules/@tootallnate/quickjs-emscripten/dist/variants.js
var require_variants = __commonJS({
  "../../node_modules/@tootallnate/quickjs-emscripten/dist/variants.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __setModuleDefault2 = exports2 && exports2.__setModuleDefault || (Object.create ? (function(o10, v) {
      Object.defineProperty(o10, "default", { enumerable: true, value: v });
    }) : function(o10, v) {
      o10["default"] = v;
    });
    var __importStar2 = exports2 && exports2.__importStar || function(mod) {
      if (mod && mod.__esModule) return mod;
      var result2 = {};
      if (mod != null) {
        for (var k32 in mod) if (k32 !== "default" && Object.prototype.hasOwnProperty.call(mod, k32)) __createBinding3(result2, mod, k32);
      }
      __setModuleDefault2(result2, mod);
      return result2;
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.RELEASE_ASYNC = exports2.DEBUG_ASYNC = exports2.RELEASE_SYNC = exports2.DEBUG_SYNC = exports2.memoizePromiseFactory = exports2.newQuickJSAsyncWASMModule = exports2.newQuickJSWASMModule = void 0;
    var esmHelpers_1 = require_esmHelpers();
    async function newQuickJSWASMModule(variant = exports2.RELEASE_SYNC) {
      const [wasmModuleLoader, QuickJSFFI, { QuickJSWASMModule }] = await Promise.all([
        variant.importModuleLoader(),
        variant.importFFI(),
        Promise.resolve().then(() => __importStar2(require_module())).then(esmHelpers_1.unwrapTypescript)
      ]);
      const wasmModule = await wasmModuleLoader();
      wasmModule.type = "sync";
      const ffi = new QuickJSFFI(wasmModule);
      return new QuickJSWASMModule(wasmModule, ffi);
    }
    __name(newQuickJSWASMModule, "newQuickJSWASMModule");
    exports2.newQuickJSWASMModule = newQuickJSWASMModule;
    async function newQuickJSAsyncWASMModule(variant = exports2.RELEASE_ASYNC) {
      const [wasmModuleLoader, QuickJSAsyncFFI, { QuickJSAsyncWASMModule }] = await Promise.all([
        variant.importModuleLoader(),
        variant.importFFI(),
        Promise.resolve().then(() => __importStar2(require_module_asyncify())).then(esmHelpers_1.unwrapTypescript)
      ]);
      const wasmModule = await wasmModuleLoader();
      wasmModule.type = "async";
      const ffi = new QuickJSAsyncFFI(wasmModule);
      return new QuickJSAsyncWASMModule(wasmModule, ffi);
    }
    __name(newQuickJSAsyncWASMModule, "newQuickJSAsyncWASMModule");
    exports2.newQuickJSAsyncWASMModule = newQuickJSAsyncWASMModule;
    function memoizePromiseFactory(fn) {
      let promise;
      return () => {
        return promise ?? (promise = fn());
      };
    }
    __name(memoizePromiseFactory, "memoizePromiseFactory");
    exports2.memoizePromiseFactory = memoizePromiseFactory;
    exports2.DEBUG_SYNC = {
      type: "sync",
      async importFFI() {
        throw new Error("not implemented");
      },
      async importModuleLoader() {
        throw new Error("not implemented");
      }
    };
    exports2.RELEASE_SYNC = {
      type: "sync",
      async importFFI() {
        const mod = await Promise.resolve().then(() => __importStar2(require_ffi_WASM_RELEASE_SYNC()));
        return (0, esmHelpers_1.unwrapTypescript)(mod).QuickJSFFI;
      },
      async importModuleLoader() {
        const mod = await Promise.resolve().then(() => __importStar2(require_emscripten_module_WASM_RELEASE_SYNC()));
        return (0, esmHelpers_1.unwrapJavascript)(mod);
      }
    };
    exports2.DEBUG_ASYNC = {
      type: "async",
      async importFFI() {
        throw new Error("not implemented");
      },
      async importModuleLoader() {
        throw new Error("not implemented");
      }
    };
    exports2.RELEASE_ASYNC = {
      type: "async",
      async importFFI() {
        throw new Error("not implemented");
      },
      async importModuleLoader() {
        throw new Error("not implemented");
      }
    };
  }
});

// ../../node_modules/@tootallnate/quickjs-emscripten/dist/vm-interface.js
var require_vm_interface = __commonJS({
  "../../node_modules/@tootallnate/quickjs-emscripten/dist/vm-interface.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.isFail = exports2.isSuccess = void 0;
    function isSuccess(successOrFail) {
      return "error" in successOrFail === false;
    }
    __name(isSuccess, "isSuccess");
    exports2.isSuccess = isSuccess;
    function isFail(successOrFail) {
      return "error" in successOrFail === true;
    }
    __name(isFail, "isFail");
    exports2.isFail = isFail;
  }
});

// ../../node_modules/@tootallnate/quickjs-emscripten/dist/module-test.js
var require_module_test = __commonJS({
  "../../node_modules/@tootallnate/quickjs-emscripten/dist/module-test.js"(exports2) {
    "use strict";
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.TestQuickJSWASMModule = void 0;
    var errors_1 = require_errors19();
    var lifetime_1 = require_lifetime();
    var TestQuickJSWASMModule = class {
      static {
        __name(this, "TestQuickJSWASMModule");
      }
      constructor(parent) {
        this.parent = parent;
        this.contexts = /* @__PURE__ */ new Set();
        this.runtimes = /* @__PURE__ */ new Set();
      }
      newRuntime(options) {
        const runtime = this.parent.newRuntime({
          ...options,
          ownedLifetimes: [
            new lifetime_1.Lifetime(void 0, void 0, () => this.runtimes.delete(runtime)),
            ...options?.ownedLifetimes ?? []
          ]
        });
        this.runtimes.add(runtime);
        return runtime;
      }
      newContext(options) {
        const context = this.parent.newContext({
          ...options,
          ownedLifetimes: [
            new lifetime_1.Lifetime(void 0, void 0, () => this.contexts.delete(context)),
            ...options?.ownedLifetimes ?? []
          ]
        });
        this.contexts.add(context);
        return context;
      }
      evalCode(code, options) {
        return this.parent.evalCode(code, options);
      }
      disposeAll() {
        const allDisposables = [...this.contexts, ...this.runtimes];
        this.runtimes.clear();
        this.contexts.clear();
        allDisposables.forEach((d32) => {
          if (d32.alive) {
            d32.dispose();
          }
        });
      }
      assertNoMemoryAllocated() {
        const leaksDetected = this.getFFI().QTS_RecoverableLeakCheck();
        if (leaksDetected) {
          throw new errors_1.QuickJSMemoryLeakDetected("Leak sanitizer detected un-freed memory");
        }
        if (this.contexts.size > 0) {
          throw new errors_1.QuickJSMemoryLeakDetected(`${this.contexts.size} contexts leaked`);
        }
        if (this.runtimes.size > 0) {
          throw new errors_1.QuickJSMemoryLeakDetected(`${this.runtimes.size} runtimes leaked`);
        }
      }
      /** @private */
      getFFI() {
        return this.parent.getFFI();
      }
    };
    exports2.TestQuickJSWASMModule = TestQuickJSWASMModule;
  }
});

// ../../node_modules/@tootallnate/quickjs-emscripten/dist/index.js
var require_dist12 = __commonJS({
  "../../node_modules/@tootallnate/quickjs-emscripten/dist/index.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __setModuleDefault2 = exports2 && exports2.__setModuleDefault || (Object.create ? (function(o10, v) {
      Object.defineProperty(o10, "default", { enumerable: true, value: v });
    }) : function(o10, v) {
      o10["default"] = v;
    });
    var __exportStar3 = exports2 && exports2.__exportStar || function(m20, exports3) {
      for (var p10 in m20) if (p10 !== "default" && !Object.prototype.hasOwnProperty.call(exports3, p10)) __createBinding3(exports3, m20, p10);
    };
    var __importStar2 = exports2 && exports2.__importStar || function(mod) {
      if (mod && mod.__esModule) return mod;
      var result2 = {};
      if (mod != null) {
        for (var k32 in mod) if (k32 !== "default" && Object.prototype.hasOwnProperty.call(mod, k32)) __createBinding3(result2, mod, k32);
      }
      __setModuleDefault2(result2, mod);
      return result2;
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.shouldInterruptAfterDeadline = exports2.newAsyncContext = exports2.newAsyncRuntime = exports2.getQuickJSSync = exports2.getQuickJS = exports2.errors = exports2.RELEASE_SYNC = exports2.RELEASE_ASYNC = exports2.DEBUG_SYNC = exports2.DEBUG_ASYNC = exports2.newQuickJSAsyncWASMModule = exports2.newQuickJSWASMModule = void 0;
    var variants_1 = require_variants();
    Object.defineProperty(exports2, "newQuickJSWASMModule", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return variants_1.newQuickJSWASMModule;
    }, "get") });
    Object.defineProperty(exports2, "newQuickJSAsyncWASMModule", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return variants_1.newQuickJSAsyncWASMModule;
    }, "get") });
    Object.defineProperty(exports2, "DEBUG_ASYNC", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return variants_1.DEBUG_ASYNC;
    }, "get") });
    Object.defineProperty(exports2, "DEBUG_SYNC", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return variants_1.DEBUG_SYNC;
    }, "get") });
    Object.defineProperty(exports2, "RELEASE_ASYNC", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return variants_1.RELEASE_ASYNC;
    }, "get") });
    Object.defineProperty(exports2, "RELEASE_SYNC", { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return variants_1.RELEASE_SYNC;
    }, "get") });
    __exportStar3(require_vm_interface(), exports2);
    __exportStar3(require_lifetime(), exports2);
    exports2.errors = __importStar2(require_errors19());
    __exportStar3(require_deferred_promise(), exports2);
    __exportStar3(require_module_test(), exports2);
    var singleton = void 0;
    var singletonPromise = void 0;
    async function getQuickJS() {
      singletonPromise ?? (singletonPromise = (0, variants_1.newQuickJSWASMModule)().then((instance) => {
        singleton = instance;
        return instance;
      }));
      return await singletonPromise;
    }
    __name(getQuickJS, "getQuickJS");
    exports2.getQuickJS = getQuickJS;
    function getQuickJSSync() {
      if (!singleton) {
        throw new Error("QuickJS not initialized. Await getQuickJS() at least once.");
      }
      return singleton;
    }
    __name(getQuickJSSync, "getQuickJSSync");
    exports2.getQuickJSSync = getQuickJSSync;
    async function newAsyncRuntime(options) {
      const module3 = await (0, variants_1.newQuickJSAsyncWASMModule)();
      return module3.newRuntime(options);
    }
    __name(newAsyncRuntime, "newAsyncRuntime");
    exports2.newAsyncRuntime = newAsyncRuntime;
    async function newAsyncContext(options) {
      const module3 = await (0, variants_1.newQuickJSAsyncWASMModule)();
      return module3.newContext(options);
    }
    __name(newAsyncContext, "newAsyncContext");
    exports2.newAsyncContext = newAsyncContext;
    function shouldInterruptAfterDeadline(deadline) {
      const deadlineAsNumber = typeof deadline === "number" ? deadline : deadline.getTime();
      return function() {
        return Date.now() > deadlineAsNumber;
      };
    }
    __name(shouldInterruptAfterDeadline, "shouldInterruptAfterDeadline");
    exports2.shouldInterruptAfterDeadline = shouldInterruptAfterDeadline;
  }
});

// ../../node_modules/pac-proxy-agent/dist/index.js
var require_dist13 = __commonJS({
  "../../node_modules/pac-proxy-agent/dist/index.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __setModuleDefault2 = exports2 && exports2.__setModuleDefault || (Object.create ? (function(o10, v) {
      Object.defineProperty(o10, "default", { enumerable: true, value: v });
    }) : function(o10, v) {
      o10["default"] = v;
    });
    var __importStar2 = exports2 && exports2.__importStar || function(mod) {
      if (mod && mod.__esModule) return mod;
      var result2 = {};
      if (mod != null) {
        for (var k32 in mod) if (k32 !== "default" && Object.prototype.hasOwnProperty.call(mod, k32)) __createBinding3(result2, mod, k32);
      }
      __setModuleDefault2(result2, mod);
      return result2;
    };
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.PacProxyAgent = void 0;
    var net = __importStar2(require("net"));
    var tls = __importStar2(require("tls"));
    var crypto4 = __importStar2(require("crypto"));
    var events_1 = require("events");
    var debug_1 = __importDefault2(require_src2());
    var url_1 = require("url");
    var agent_base_1 = require_dist4();
    var get_uri_1 = require_dist9();
    var pac_resolver_1 = require_dist11();
    var quickjs_emscripten_1 = require_dist12();
    var debug2 = (0, debug_1.default)("pac-proxy-agent");
    var setServernameFromNonIpHost = /* @__PURE__ */ __name((options) => {
      if (options.servername === void 0 && options.host && !net.isIP(options.host)) {
        return {
          ...options,
          servername: options.host
        };
      }
      return options;
    }, "setServernameFromNonIpHost");
    var PacProxyAgent = class extends agent_base_1.Agent {
      static {
        __name(this, "PacProxyAgent");
      }
      constructor(uri, opts) {
        super(opts);
        this.clearResolverPromise = () => {
          this.resolverPromise = void 0;
        };
        const uriStr = typeof uri === "string" ? uri : uri.href;
        this.uri = new url_1.URL(uriStr.replace(/^pac\+/i, ""));
        debug2("Creating PacProxyAgent with URI %o", this.uri.href);
        this.opts = { ...opts };
        this.cache = void 0;
        this.resolver = void 0;
        this.resolverHash = "";
        this.resolverPromise = void 0;
        if (!this.opts.filename) {
          this.opts.filename = this.uri.href;
        }
      }
      /**
       * Loads the PAC proxy file from the source if necessary, and returns
       * a generated `FindProxyForURL()` resolver function to use.
       */
      getResolver() {
        if (!this.resolverPromise) {
          this.resolverPromise = this.loadResolver();
          this.resolverPromise.then(this.clearResolverPromise, this.clearResolverPromise);
        }
        return this.resolverPromise;
      }
      async loadResolver() {
        try {
          const [qjs, code] = await Promise.all([
            (0, quickjs_emscripten_1.getQuickJS)(),
            this.loadPacFile()
          ]);
          const hash = crypto4.createHash("sha1").update(code).digest("hex");
          if (this.resolver && this.resolverHash === hash) {
            debug2("Same sha1 hash for code - contents have not changed, reusing previous proxy resolver");
            return this.resolver;
          }
          debug2("Creating new proxy resolver instance");
          this.resolver = (0, pac_resolver_1.createPacResolver)(qjs, code, this.opts);
          this.resolverHash = hash;
          return this.resolver;
        } catch (err) {
          if (this.resolver && err.code === "ENOTMODIFIED") {
            debug2("Got ENOTMODIFIED response, reusing previous proxy resolver");
            return this.resolver;
          }
          throw err;
        }
      }
      /**
       * Loads the contents of the PAC proxy file.
       *
       * @api private
       */
      async loadPacFile() {
        debug2("Loading PAC file: %o", this.uri);
        const rs = await (0, get_uri_1.getUri)(this.uri, { ...this.opts, cache: this.cache });
        debug2("Got `Readable` instance for URI");
        this.cache = rs;
        const buf = await (0, agent_base_1.toBuffer)(rs);
        debug2("Read %o byte PAC file from URI", buf.length);
        return buf.toString("utf8");
      }
      /**
       * Called when the node-core HTTP client library is creating a new HTTP request.
       */
      async connect(req, opts) {
        const { secureEndpoint } = opts;
        const isWebSocket = req.getHeader("upgrade") === "websocket";
        const resolver = await this.getResolver();
        const protocol = secureEndpoint ? "https:" : "http:";
        const host = opts.host && net.isIPv6(opts.host) ? `[${opts.host}]` : opts.host;
        const defaultPort = secureEndpoint ? 443 : 80;
        const url = Object.assign(new url_1.URL(req.path, `${protocol}//${host}`), defaultPort ? void 0 : { port: opts.port });
        debug2("url: %s", url);
        let result2 = await resolver(url);
        if (!result2) {
          result2 = "DIRECT";
        }
        const proxies = String(result2).trim().split(/\s*;\s*/g).filter(Boolean);
        if (this.opts.fallbackToDirect && !proxies.includes("DIRECT")) {
          proxies.push("DIRECT");
        }
        for (const proxy of proxies) {
          let agent = null;
          let socket = null;
          const [type, target] = proxy.split(/\s+/);
          debug2("Attempting to use proxy: %o", proxy);
          if (type === "DIRECT") {
            if (secureEndpoint) {
              socket = tls.connect(setServernameFromNonIpHost(opts));
            } else {
              socket = net.connect(opts);
            }
          } else if (type === "SOCKS" || type === "SOCKS5") {
            const { SocksProxyAgent } = await Promise.resolve().then(() => __importStar2(require_dist7()));
            agent = new SocksProxyAgent(`socks://${target}`, this.opts);
          } else if (type === "SOCKS4") {
            const { SocksProxyAgent } = await Promise.resolve().then(() => __importStar2(require_dist7()));
            agent = new SocksProxyAgent(`socks4a://${target}`, this.opts);
          } else if (type === "PROXY" || type === "HTTP" || type === "HTTPS") {
            const proxyURL = `${type === "HTTPS" ? "https" : "http"}://${target}`;
            if (secureEndpoint || isWebSocket) {
              const { HttpsProxyAgent } = await Promise.resolve().then(() => __importStar2(require_dist6()));
              agent = new HttpsProxyAgent(proxyURL, this.opts);
            } else {
              const { HttpProxyAgent } = await Promise.resolve().then(() => __importStar2(require_dist5()));
              agent = new HttpProxyAgent(proxyURL, this.opts);
            }
          }
          try {
            if (socket) {
              await (0, events_1.once)(socket, "connect");
              req.emit("proxy", { proxy, socket });
              return socket;
            }
            if (agent) {
              const s = await agent.connect(req, opts);
              if (!(s instanceof net.Socket)) {
                throw new Error("Expected a `net.Socket` to be returned from agent");
              }
              req.emit("proxy", { proxy, socket: s });
              return s;
            }
            throw new Error(`Could not determine proxy type for: ${proxy}`);
          } catch (err) {
            debug2("Got error for proxy %o: %o", proxy, err);
            req.emit("proxy", { proxy, error: err });
          }
        }
        throw new Error(`Failed to establish a socket connection to proxies: ${JSON.stringify(proxies)}`);
      }
    };
    PacProxyAgent.protocols = [
      "pac+data",
      "pac+file",
      "pac+ftp",
      "pac+http",
      "pac+https"
    ];
    exports2.PacProxyAgent = PacProxyAgent;
  }
});

// ../../node_modules/proxy-agent/dist/index.js
var require_dist14 = __commonJS({
  "../../node_modules/proxy-agent/dist/index.js"(exports2) {
    "use strict";
    var __createBinding3 = exports2 && exports2.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      var desc = Object.getOwnPropertyDescriptor(m20, k32);
      if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
          return m20[k32];
        }, "get") };
      }
      Object.defineProperty(o10, k210, desc);
    }) : (function(o10, m20, k32, k210) {
      if (k210 === void 0) k210 = k32;
      o10[k210] = m20[k32];
    }));
    var __setModuleDefault2 = exports2 && exports2.__setModuleDefault || (Object.create ? (function(o10, v) {
      Object.defineProperty(o10, "default", { enumerable: true, value: v });
    }) : function(o10, v) {
      o10["default"] = v;
    });
    var __importStar2 = exports2 && exports2.__importStar || function(mod) {
      if (mod && mod.__esModule) return mod;
      var result2 = {};
      if (mod != null) {
        for (var k32 in mod) if (k32 !== "default" && Object.prototype.hasOwnProperty.call(mod, k32)) __createBinding3(result2, mod, k32);
      }
      __setModuleDefault2(result2, mod);
      return result2;
    };
    var __importDefault2 = exports2 && exports2.__importDefault || function(mod) {
      return mod && mod.__esModule ? mod : { "default": mod };
    };
    Object.defineProperty(exports2, "__esModule", { value: true });
    exports2.ProxyAgent = exports2.proxies = void 0;
    var http = __importStar2(require("http"));
    var https3 = __importStar2(require("https"));
    var url_1 = require("url");
    var lru_cache_1 = __importDefault2(require_lru_cache());
    var agent_base_1 = require_dist4();
    var debug_1 = __importDefault2(require_src2());
    var proxy_from_env_1 = require_proxy_from_env();
    var debug2 = (0, debug_1.default)("proxy-agent");
    var wellKnownAgents = {
      http: /* @__PURE__ */ __name(async () => (await Promise.resolve().then(() => __importStar2(require_dist5()))).HttpProxyAgent, "http"),
      https: /* @__PURE__ */ __name(async () => (await Promise.resolve().then(() => __importStar2(require_dist6()))).HttpsProxyAgent, "https"),
      socks: /* @__PURE__ */ __name(async () => (await Promise.resolve().then(() => __importStar2(require_dist7()))).SocksProxyAgent, "socks"),
      pac: /* @__PURE__ */ __name(async () => (await Promise.resolve().then(() => __importStar2(require_dist13()))).PacProxyAgent, "pac")
    };
    exports2.proxies = {
      http: [wellKnownAgents.http, wellKnownAgents.https],
      https: [wellKnownAgents.http, wellKnownAgents.https],
      socks: [wellKnownAgents.socks, wellKnownAgents.socks],
      socks4: [wellKnownAgents.socks, wellKnownAgents.socks],
      socks4a: [wellKnownAgents.socks, wellKnownAgents.socks],
      socks5: [wellKnownAgents.socks, wellKnownAgents.socks],
      socks5h: [wellKnownAgents.socks, wellKnownAgents.socks],
      "pac+data": [wellKnownAgents.pac, wellKnownAgents.pac],
      "pac+file": [wellKnownAgents.pac, wellKnownAgents.pac],
      "pac+ftp": [wellKnownAgents.pac, wellKnownAgents.pac],
      "pac+http": [wellKnownAgents.pac, wellKnownAgents.pac],
      "pac+https": [wellKnownAgents.pac, wellKnownAgents.pac]
    };
    function isValidProtocol(v) {
      return Object.keys(exports2.proxies).includes(v);
    }
    __name(isValidProtocol, "isValidProtocol");
    var ProxyAgent2 = class extends agent_base_1.Agent {
      static {
        __name(this, "ProxyAgent");
      }
      constructor(opts) {
        super(opts);
        this.cache = new lru_cache_1.default({
          max: 20,
          dispose: /* @__PURE__ */ __name((agent) => agent.destroy(), "dispose")
        });
        debug2("Creating new ProxyAgent instance: %o", opts);
        this.connectOpts = opts;
        this.httpAgent = opts?.httpAgent || new http.Agent(opts);
        this.httpsAgent = opts?.httpsAgent || new https3.Agent(opts);
        this.getProxyForUrl = opts?.getProxyForUrl || proxy_from_env_1.getProxyForUrl;
      }
      async connect(req, opts) {
        const { secureEndpoint } = opts;
        const isWebSocket = req.getHeader("upgrade") === "websocket";
        const protocol = secureEndpoint ? isWebSocket ? "wss:" : "https:" : isWebSocket ? "ws:" : "http:";
        const host = req.getHeader("host");
        const url = new url_1.URL(req.path, `${protocol}//${host}`).href;
        const proxy = await this.getProxyForUrl(url, req);
        if (!proxy) {
          debug2("Proxy not enabled for URL: %o", url);
          return secureEndpoint ? this.httpsAgent : this.httpAgent;
        }
        debug2("Request URL: %o", url);
        debug2("Proxy URL: %o", proxy);
        const cacheKey = `${protocol}+${proxy}`;
        let agent = this.cache.get(cacheKey);
        if (!agent) {
          const proxyUrl = new url_1.URL(proxy);
          const proxyProto = proxyUrl.protocol.replace(":", "");
          if (!isValidProtocol(proxyProto)) {
            throw new Error(`Unsupported protocol for proxy URL: ${proxy}`);
          }
          const ctor = await exports2.proxies[proxyProto][secureEndpoint || isWebSocket ? 1 : 0]();
          agent = new ctor(proxy, this.connectOpts);
          this.cache.set(cacheKey, agent);
        } else {
          debug2("Cache hit for proxy URL: %o", proxy);
        }
        return agent;
      }
      destroy() {
        for (const agent of this.cache.values()) {
          agent.destroy();
        }
        super.destroy();
      }
    };
    exports2.ProxyAgent = ProxyAgent2;
  }
});

// lib/cli/proxy-agent.ts
var fs50, import_proxy_agent, ProxyAgentProvider;
var init_proxy_agent = __esm({
  "lib/cli/proxy-agent.ts"() {
    "use strict";
    fs50 = __toESM(require_lib4());
    import_proxy_agent = __toESM(require_dist14());
    ProxyAgentProvider = class {
      static {
        __name(this, "ProxyAgentProvider");
      }
      constructor(ioHelper) {
        this.ioHelper = ioHelper;
      }
      async create(options) {
        const getProxyForUrl = options.proxyAddress != null ? () => Promise.resolve(options.proxyAddress) : void 0;
        return new import_proxy_agent.ProxyAgent({
          ca: await this.tryGetCACert(options.caBundlePath),
          getProxyForUrl
        });
      }
      async tryGetCACert(bundlePath) {
        const path47 = bundlePath || this.caBundlePathFromEnvironment();
        if (path47) {
          await this.ioHelper.defaults.debug(`Using CA bundle path: ${path47}`);
          try {
            if (!fs50.pathExistsSync(path47)) {
              return void 0;
            }
            return fs50.readFileSync(path47, { encoding: "utf-8" });
          } catch (e32) {
            await this.ioHelper.defaults.debug(String(e32));
            return void 0;
          }
        }
        return void 0;
      }
      /**
       * Find and return a CA certificate bundle path to be passed into the SDK.
       */
      caBundlePathFromEnvironment() {
        if (process.env.aws_ca_bundle) {
          return process.env.aws_ca_bundle;
        }
        if (process.env.AWS_CA_BUNDLE) {
          return process.env.AWS_CA_BUNDLE;
        }
        return void 0;
      }
    };
  }
});

// lib/cli/util/trap-errors.ts
async function trapErrors(ioHelper, message2, cb) {
  try {
    return await cb();
  } catch (e32) {
    await ioHelper.defaults.debug(`${message2}: ${e32}`);
    return void 0;
  }
}
var init_trap_errors = __esm({
  "lib/cli/util/trap-errors.ts"() {
    "use strict";
    __name(trapErrors, "trapErrors");
  }
});

// lib/api/hotswap.ts
var init_hotswap3 = __esm({
  "lib/api/hotswap.ts"() {
    "use strict";
    init_hotswap2();
  }
});

// lib/cli/tables.ts
function renderTable(cells, columns) {
  return cfnDiff3.formatTable(cells, columns);
}
var cfnDiff3;
var init_tables = __esm({
  "lib/cli/tables.ts"() {
    "use strict";
    cfnDiff3 = __toESM(require_lib9());
    __name(renderTable, "renderTable");
  }
});

// lib/commands/context.ts
async function contextHandler(options) {
  const ioHelper = options.ioHelper;
  if (options.clear) {
    options.context.clear();
    await options.context.save(PROJECT_CONTEXT);
    await ioHelper.defaults.info("All context values cleared.");
  } else if (options.reset) {
    await invalidateContext(ioHelper, options.context, options.reset, options.force ?? false);
    await options.context.save(PROJECT_CONTEXT);
  } else {
    if (options.json) {
      const contextValues = options.context.all;
      await ioHelper.defaults.result(JSON.stringify(contextValues, void 0, 2));
    } else {
      await listContext(ioHelper, options.context);
    }
  }
  return 0;
}
async function listContext(ioHelper, context) {
  const keys = contextKeys(context);
  if (keys.length === 0) {
    await ioHelper.defaults.info("This CDK application does not have any saved context values yet.");
    await ioHelper.defaults.info("");
    await ioHelper.defaults.info("Context will automatically be saved when you synthesize CDK apps");
    await ioHelper.defaults.info("that use environment context information like AZ information, VPCs,");
    await ioHelper.defaults.info("SSM parameters, and so on.");
    return;
  }
  const data_out = [[chalk35.green("#"), chalk35.green("Key"), chalk35.green("Value")]];
  for (const [i32, key] of keys) {
    const jsonWithoutNewlines = JSON.stringify(context.all[key], void 0, 2).replace(/\s+/g, " ");
    data_out.push([i32, key, jsonWithoutNewlines]);
  }
  await ioHelper.defaults.info("Context found in %s:", chalk35.blue(PROJECT_CONFIG));
  await ioHelper.defaults.info("");
  await ioHelper.defaults.info(renderTable(data_out, process.stdout.columns));
  await ioHelper.defaults.info(`Run ${chalk35.blue("cdk context --reset KEY_OR_NUMBER")} to remove a context key. It will be refreshed on the next CDK synthesis run.`);
}
async function invalidateContext(ioHelper, context, key, force) {
  const i32 = parseInt(key, 10);
  if (`${i32}` === key) {
    key = keyByNumber(context, i32);
  }
  if (context.has(key)) {
    context.unset(key);
    if (!context.has(key)) {
      await ioHelper.defaults.info("Context value %s reset. It will be refreshed on next synthesis", chalk35.blue(key));
      return;
    }
    await ioHelper.defaults.error("Only context values specified in %s can be reset through the CLI", chalk35.blue(PROJECT_CONTEXT));
    if (!force) {
      throw new import_toolkit_lib21.ToolkitError("ReadonlyContextKey", `Cannot reset readonly context value with key: ${key}`);
    }
  }
  const matches = keysByExpression(context, key);
  if (matches.length > 0) {
    matches.forEach((match) => {
      context.unset(match);
    });
    const { unset, readonly } = getUnsetAndReadonly(context, matches);
    await printUnset(ioHelper, unset);
    await printReadonly(ioHelper, readonly);
    if (!force && unset.length === 0) {
      throw new import_toolkit_lib21.ToolkitError("NoResettableContextValues", "None of the matched context values could be reset");
    }
    return;
  }
  if (!force) {
    throw new import_toolkit_lib21.ToolkitError("ContextKeyNotFound", `No context value matching key: ${key}`);
  }
}
async function printUnset(ioHelper, unset) {
  if (unset.length === 0) return;
  await ioHelper.defaults.info("The following matched context values reset. They will be refreshed on next synthesis");
  for (const match of unset) {
    await ioHelper.defaults.info("  %s", match);
  }
}
async function printReadonly(ioHelper, readonly) {
  if (readonly.length === 0) return;
  await ioHelper.defaults.warn("The following matched context values could not be reset through the CLI");
  for (const match of readonly) {
    await ioHelper.defaults.info("  %s", match);
  }
  await ioHelper.defaults.info("");
  await ioHelper.defaults.info("This usually means they are configured in %s or %s", chalk35.blue(PROJECT_CONFIG), chalk35.blue(USER_DEFAULTS));
}
function keysByExpression(context, expression) {
  const matchesExpression = picomatch5(expression);
  return context.keys.filter((key) => matchesExpression(key));
}
function getUnsetAndReadonly(context, matches) {
  return matches.reduce((acc, match) => {
    if (context.has(match)) {
      acc.readonly.push(match);
    } else {
      acc.unset.push(match);
    }
    return acc;
  }, { unset: [], readonly: [] });
}
function keyByNumber(context, n10) {
  for (const [i32, key] of contextKeys(context)) {
    if (n10 === i32) {
      return key;
    }
  }
  throw new import_toolkit_lib21.ToolkitError("ContextKeyNumberNotFound", `No context key with number: ${n10}`);
}
function contextKeys(context) {
  const keys = context.keys;
  keys.sort();
  return enumerate1(keys);
}
function enumerate1(xs) {
  const ret = new Array();
  let i32 = 1;
  for (const x of xs) {
    ret.push([i32, x]);
    i32 += 1;
  }
  return ret;
}
var import_toolkit_lib21, chalk35, picomatch5;
var init_context5 = __esm({
  "lib/commands/context.ts"() {
    "use strict";
    import_toolkit_lib21 = __toESM(require_lib12());
    chalk35 = __toESM(require_source());
    init_tables();
    init_user_configuration();
    picomatch5 = require_picomatch4();
    __name(contextHandler, "contextHandler");
    __name(listContext, "listContext");
    __name(invalidateContext, "invalidateContext");
    __name(printUnset, "printUnset");
    __name(printReadonly, "printReadonly");
    __name(keysByExpression, "keysByExpression");
    __name(getUnsetAndReadonly, "getUnsetAndReadonly");
    __name(keyByNumber, "keyByNumber");
    __name(contextKeys, "contextKeys");
    __name(enumerate1, "enumerate1");
  }
});

// lib/commands/docs.ts
async function docs(options) {
  const ioHelper = options.ioHelper;
  const url = "https://docs.aws.amazon.com/cdk/api/v2/";
  await ioHelper.defaults.info(chalk36.green(url));
  const browserCommand = options.browser.replace(/%u/g, url);
  await ioHelper.defaults.debug(`Opening documentation ${chalk36.green(browserCommand)}`);
  const exec5 = (0, import_node_util9.promisify)(childProcess2.exec);
  try {
    const { stdout, stderr } = await exec5(browserCommand);
    if (stdout) {
      await ioHelper.defaults.debug(stdout);
    }
    if (stderr) {
      await ioHelper.defaults.warn(stderr);
    }
  } catch (err) {
    const e32 = err;
    await ioHelper.defaults.debug(`An error occurred when trying to open a browser: ${e32.stack || e32.message}`);
  }
  return 0;
}
var childProcess2, import_node_util9, chalk36;
var init_docs = __esm({
  "lib/commands/docs.ts"() {
    "use strict";
    childProcess2 = __toESM(require("child_process"));
    import_node_util9 = require("node:util");
    chalk36 = __toESM(require_source());
    __name(docs, "docs");
  }
});

// lib/commands/doctor.ts
async function doctor({ ioHelper, settings }) {
  let exitStatus = 0;
  for (const verification of verifications) {
    if (!await verification(ioHelper, settings)) {
      exitStatus = -1;
    }
  }
  await displayVersionMessage(ioHelper);
  return exitStatus;
}
async function displayCliConfiguration(ioHelper, settings) {
  const verbosity = Number(settings?.get(["verbose"]) ?? 0);
  const verbose = verbosity ? `extra verbosity (-${"v".repeat(verbosity)})` : "normal verbosity";
  const debug2 = [];
  if (Boolean(settings?.get(["debugApp"]))) {
    debug2.push("CDK app");
  }
  if (Boolean(settings?.get(["debugCli"]))) {
    debug2.push("CLI");
  }
  const debugging = debug2.length ? `debugging ${debug2.join(" & ")}` : "no debugging";
  await ioHelper.defaults.info(chalk37.gray.italic(
    `${verbose}, ${debugging}`
  ));
  return true;
}
async function displayVersionInformation(ioHelper) {
  await ioHelper.defaults.info(`\u2139\uFE0F CDK CLI Version: ${chalk37.green(versionWithBuild())}`);
  return true;
}
async function displayAwsEnvironmentVariables(ioHelper) {
  const keys = Object.keys(process2.env).filter((s) => s.startsWith("AWS_"));
  if (keys.length === 0) {
    await ioHelper.defaults.info("\u2139\uFE0F No AWS environment variables");
    return true;
  }
  await ioHelper.defaults.info("\u2139\uFE0F AWS environment variables:");
  for (const key of keys) {
    await ioHelper.defaults.info(`  - ${chalk37.blue(key)} = ${chalk37.green(anonymizeAwsVariable(key, process2.env[key]))}`);
  }
  return true;
}
async function displayCdkEnvironmentVariables(ioHelper) {
  const keys = Object.keys(process2.env).filter((s) => s.startsWith("CDK_"));
  if (keys.length === 0) {
    await ioHelper.defaults.info("\u2139\uFE0F No CDK environment variables");
    return true;
  }
  await ioHelper.defaults.info("\u2139\uFE0F CDK environment variables:");
  let healthy = true;
  for (const key of keys.sort()) {
    if (key === cxapi13.CONTEXT_ENV || key === cxapi13.CONTEXT_OVERFLOW_LOCATION_ENV || key === cxapi13.OUTDIR_ENV) {
      await ioHelper.defaults.info(`  - ${chalk37.red(key)} = ${chalk37.green(process2.env[key])} (\u26A0\uFE0F reserved for use by the CDK toolkit)`);
      healthy = false;
    } else {
      await ioHelper.defaults.info(`  - ${chalk37.blue(key)} = ${chalk37.green(process2.env[key])}`);
    }
  }
  return healthy;
}
function anonymizeAwsVariable(name, value) {
  if (name === "AWS_ACCESS_KEY_ID") {
    return value.slice(0, 4) + "<redacted>";
  }
  if (name === "AWS_SECRET_ACCESS_KEY" || name === "AWS_SESSION_TOKEN" || name === "AWS_SECURITY_TOKEN") {
    return "<redacted>";
  }
  return value;
}
var process2, cxapi13, chalk37, verifications;
var init_doctor = __esm({
  "lib/commands/doctor.ts"() {
    "use strict";
    process2 = __toESM(require("process"));
    cxapi13 = __toESM(require_lib11());
    chalk37 = __toESM(require_source());
    init_display_version();
    init_version();
    __name(doctor, "doctor");
    verifications = [
      displayVersionInformation,
      displayCliConfiguration,
      displayAwsEnvironmentVariables,
      displayCdkEnvironmentVariables
    ];
    __name(displayCliConfiguration, "displayCliConfiguration");
    __name(displayVersionInformation, "displayVersionInformation");
    __name(displayAwsEnvironmentVariables, "displayAwsEnvironmentVariables");
    __name(displayCdkEnvironmentVariables, "displayCdkEnvironmentVariables");
    __name(anonymizeAwsVariable, "anonymizeAwsVariable");
  }
});

// ../../node_modules/ansi-colors/symbols.js
var require_symbols = __commonJS({
  "../../node_modules/ansi-colors/symbols.js"(exports2, module2) {
    "use strict";
    var isHyper = typeof process !== "undefined" && process.env.TERM_PROGRAM === "Hyper";
    var isWindows2 = typeof process !== "undefined" && process.platform === "win32";
    var isLinux2 = typeof process !== "undefined" && process.platform === "linux";
    var common = {
      ballotDisabled: "\u2612",
      ballotOff: "\u2610",
      ballotOn: "\u2611",
      bullet: "\u2022",
      bulletWhite: "\u25E6",
      fullBlock: "\u2588",
      heart: "\u2764",
      identicalTo: "\u2261",
      line: "\u2500",
      mark: "\u203B",
      middot: "\xB7",
      minus: "\uFF0D",
      multiplication: "\xD7",
      obelus: "\xF7",
      pencilDownRight: "\u270E",
      pencilRight: "\u270F",
      pencilUpRight: "\u2710",
      percent: "%",
      pilcrow2: "\u2761",
      pilcrow: "\xB6",
      plusMinus: "\xB1",
      question: "?",
      section: "\xA7",
      starsOff: "\u2606",
      starsOn: "\u2605",
      upDownArrow: "\u2195"
    };
    var windows = Object.assign({}, common, {
      check: "\u221A",
      cross: "\xD7",
      ellipsisLarge: "...",
      ellipsis: "...",
      info: "i",
      questionSmall: "?",
      pointer: ">",
      pointerSmall: "\xBB",
      radioOff: "( )",
      radioOn: "(*)",
      warning: "\u203C"
    });
    var other = Object.assign({}, common, {
      ballotCross: "\u2718",
      check: "\u2714",
      cross: "\u2716",
      ellipsisLarge: "\u22EF",
      ellipsis: "\u2026",
      info: "\u2139",
      questionFull: "\uFF1F",
      questionSmall: "\uFE56",
      pointer: isLinux2 ? "\u25B8" : "\u276F",
      pointerSmall: isLinux2 ? "\u2023" : "\u203A",
      radioOff: "\u25EF",
      radioOn: "\u25C9",
      warning: "\u26A0"
    });
    module2.exports = isWindows2 && !isHyper ? windows : other;
    Reflect.defineProperty(module2.exports, "common", { enumerable: false, value: common });
    Reflect.defineProperty(module2.exports, "windows", { enumerable: false, value: windows });
    Reflect.defineProperty(module2.exports, "other", { enumerable: false, value: other });
  }
});

// ../../node_modules/ansi-colors/index.js
var require_ansi_colors = __commonJS({
  "../../node_modules/ansi-colors/index.js"(exports2, module2) {
    "use strict";
    var isObject3 = /* @__PURE__ */ __name((val) => val !== null && typeof val === "object" && !Array.isArray(val), "isObject");
    var ANSI_REGEX = /[\u001b\u009b][[\]#;?()]*(?:(?:(?:[^\W_]*;?[^\W_]*)\u0007)|(?:(?:[0-9]{1,4}(;[0-9]{0,4})*)?[~0-9=<>cf-nqrtyA-PRZ]))/g;
    var hasColor = /* @__PURE__ */ __name(() => {
      if (typeof process !== "undefined") {
        return process.env.FORCE_COLOR !== "0";
      }
      return false;
    }, "hasColor");
    var create = /* @__PURE__ */ __name(() => {
      const colors = {
        enabled: hasColor(),
        visible: true,
        styles: {},
        keys: {}
      };
      const ansi = /* @__PURE__ */ __name((style2) => {
        let open2 = style2.open = `\x1B[${style2.codes[0]}m`;
        let close = style2.close = `\x1B[${style2.codes[1]}m`;
        let regex = style2.regex = new RegExp(`\\u001b\\[${style2.codes[1]}m`, "g");
        style2.wrap = (input, newline) => {
          if (input.includes(close)) input = input.replace(regex, close + open2);
          let output = open2 + input + close;
          return newline ? output.replace(/\r*\n/g, `${close}$&${open2}`) : output;
        };
        return style2;
      }, "ansi");
      const wrap = /* @__PURE__ */ __name((style2, input, newline) => {
        return typeof style2 === "function" ? style2(input) : style2.wrap(input, newline);
      }, "wrap");
      const style = /* @__PURE__ */ __name((input, stack) => {
        if (input === "" || input == null) return "";
        if (colors.enabled === false) return input;
        if (colors.visible === false) return "";
        let str = "" + input;
        let nl = str.includes("\n");
        let n10 = stack.length;
        if (n10 > 0 && stack.includes("unstyle")) {
          stack = [.../* @__PURE__ */ new Set(["unstyle", ...stack])].reverse();
        }
        while (n10-- > 0) str = wrap(colors.styles[stack[n10]], str, nl);
        return str;
      }, "style");
      const define2 = /* @__PURE__ */ __name((name, codes, type) => {
        colors.styles[name] = ansi({ name, codes });
        let keys = colors.keys[type] || (colors.keys[type] = []);
        keys.push(name);
        Reflect.defineProperty(colors, name, {
          configurable: true,
          enumerable: true,
          set(value) {
            colors.alias(name, value);
          },
          get() {
            let color = /* @__PURE__ */ __name((input) => style(input, color.stack), "color");
            Reflect.setPrototypeOf(color, colors);
            color.stack = this.stack ? this.stack.concat(name) : [name];
            return color;
          }
        });
      }, "define");
      define2("reset", [0, 0], "modifier");
      define2("bold", [1, 22], "modifier");
      define2("dim", [2, 22], "modifier");
      define2("italic", [3, 23], "modifier");
      define2("underline", [4, 24], "modifier");
      define2("inverse", [7, 27], "modifier");
      define2("hidden", [8, 28], "modifier");
      define2("strikethrough", [9, 29], "modifier");
      define2("black", [30, 39], "color");
      define2("red", [31, 39], "color");
      define2("green", [32, 39], "color");
      define2("yellow", [33, 39], "color");
      define2("blue", [34, 39], "color");
      define2("magenta", [35, 39], "color");
      define2("cyan", [36, 39], "color");
      define2("white", [37, 39], "color");
      define2("gray", [90, 39], "color");
      define2("grey", [90, 39], "color");
      define2("bgBlack", [40, 49], "bg");
      define2("bgRed", [41, 49], "bg");
      define2("bgGreen", [42, 49], "bg");
      define2("bgYellow", [43, 49], "bg");
      define2("bgBlue", [44, 49], "bg");
      define2("bgMagenta", [45, 49], "bg");
      define2("bgCyan", [46, 49], "bg");
      define2("bgWhite", [47, 49], "bg");
      define2("blackBright", [90, 39], "bright");
      define2("redBright", [91, 39], "bright");
      define2("greenBright", [92, 39], "bright");
      define2("yellowBright", [93, 39], "bright");
      define2("blueBright", [94, 39], "bright");
      define2("magentaBright", [95, 39], "bright");
      define2("cyanBright", [96, 39], "bright");
      define2("whiteBright", [97, 39], "bright");
      define2("bgBlackBright", [100, 49], "bgBright");
      define2("bgRedBright", [101, 49], "bgBright");
      define2("bgGreenBright", [102, 49], "bgBright");
      define2("bgYellowBright", [103, 49], "bgBright");
      define2("bgBlueBright", [104, 49], "bgBright");
      define2("bgMagentaBright", [105, 49], "bgBright");
      define2("bgCyanBright", [106, 49], "bgBright");
      define2("bgWhiteBright", [107, 49], "bgBright");
      colors.ansiRegex = ANSI_REGEX;
      colors.hasColor = colors.hasAnsi = (str) => {
        colors.ansiRegex.lastIndex = 0;
        return typeof str === "string" && str !== "" && colors.ansiRegex.test(str);
      };
      colors.alias = (name, color) => {
        let fn = typeof color === "string" ? colors[color] : color;
        if (typeof fn !== "function") {
          throw new TypeError("Expected alias to be the name of an existing color (string) or a function");
        }
        if (!fn.stack) {
          Reflect.defineProperty(fn, "name", { value: name });
          colors.styles[name] = fn;
          fn.stack = [name];
        }
        Reflect.defineProperty(colors, name, {
          configurable: true,
          enumerable: true,
          set(value) {
            colors.alias(name, value);
          },
          get() {
            let color2 = /* @__PURE__ */ __name((input) => style(input, color2.stack), "color");
            Reflect.setPrototypeOf(color2, colors);
            color2.stack = this.stack ? this.stack.concat(fn.stack) : fn.stack;
            return color2;
          }
        });
      };
      colors.theme = (custom) => {
        if (!isObject3(custom)) throw new TypeError("Expected theme to be an object");
        for (let name of Object.keys(custom)) {
          colors.alias(name, custom[name]);
        }
        return colors;
      };
      colors.alias("unstyle", (str) => {
        if (typeof str === "string" && str !== "") {
          colors.ansiRegex.lastIndex = 0;
          return str.replace(colors.ansiRegex, "");
        }
        return "";
      });
      colors.alias("noop", (str) => str);
      colors.none = colors.clear = colors.noop;
      colors.stripColor = colors.unstyle;
      colors.symbols = require_symbols();
      colors.define = define2;
      return colors;
    }, "create");
    module2.exports = create();
    module2.exports.create = create;
  }
});

// ../../node_modules/enquirer/lib/utils.js
var require_utils11 = __commonJS({
  "../../node_modules/enquirer/lib/utils.js"(exports2) {
    "use strict";
    var toString = Object.prototype.toString;
    var colors = require_ansi_colors();
    var onExitCalled = false;
    var onExitCallbacks = /* @__PURE__ */ new Set();
    var complements = {
      "yellow": "blue",
      "cyan": "red",
      "green": "magenta",
      "black": "white",
      "blue": "yellow",
      "red": "cyan",
      "magenta": "green",
      "white": "black"
    };
    exports2.longest = (arr, prop) => {
      return arr.reduce((a32, v) => Math.max(a32, prop ? v[prop].length : v.length), 0);
    };
    exports2.hasColor = (str) => !!str && colors.hasColor(str);
    var isObject3 = exports2.isObject = (val) => {
      return val !== null && typeof val === "object" && !Array.isArray(val);
    };
    exports2.nativeType = (val) => {
      return toString.call(val).slice(8, -1).toLowerCase().replace(/\s/g, "");
    };
    exports2.isAsyncFn = (val) => {
      return exports2.nativeType(val) === "asyncfunction";
    };
    exports2.isPrimitive = (val) => {
      return val != null && typeof val !== "object" && typeof val !== "function";
    };
    exports2.resolve = (context, value, ...rest) => {
      if (typeof value === "function") {
        return value.call(context, ...rest);
      }
      return value;
    };
    exports2.scrollDown = (choices = []) => [...choices.slice(1), choices[0]];
    exports2.scrollUp = (choices = []) => [choices.pop(), ...choices];
    exports2.reorder = (arr = []) => {
      let res = arr.slice();
      res.sort((a32, b32) => {
        if (a32.index > b32.index) return 1;
        if (a32.index < b32.index) return -1;
        return 0;
      });
      return res;
    };
    exports2.swap = (arr, index, pos) => {
      let len = arr.length;
      let idx = pos === len ? 0 : pos < 0 ? len - 1 : pos;
      let choice = arr[index];
      arr[index] = arr[idx];
      arr[idx] = choice;
    };
    exports2.width = (stream, fallback2 = 80) => {
      let columns = stream && stream.columns ? stream.columns : fallback2;
      if (stream && typeof stream.getWindowSize === "function") {
        columns = stream.getWindowSize()[0];
      }
      if (process.platform === "win32") {
        return columns - 1;
      }
      return columns;
    };
    exports2.height = (stream, fallback2 = 20) => {
      let rows = stream && stream.rows ? stream.rows : fallback2;
      if (stream && typeof stream.getWindowSize === "function") {
        rows = stream.getWindowSize()[1];
      }
      return rows;
    };
    exports2.wordWrap = (str, options = {}) => {
      if (!str) return str;
      if (typeof options === "number") {
        options = { width: options };
      }
      let { indent = "", newline = "\n" + indent, width = 80 } = options;
      let spaces = (newline + indent).match(/[^\S\n]/g) || [];
      width -= spaces.length;
      let source = `.{1,${width}}([\\s\\u200B]+|$)|[^\\s\\u200B]+?([\\s\\u200B]+|$)`;
      let output = str.trim();
      let regex = new RegExp(source, "g");
      let lines = output.match(regex) || [];
      lines = lines.map((line) => line.replace(/\n$/, ""));
      if (options.padEnd) lines = lines.map((line) => line.padEnd(width, " "));
      if (options.padStart) lines = lines.map((line) => line.padStart(width, " "));
      return indent + lines.join(newline);
    };
    exports2.unmute = (color) => {
      let name = color.stack.find((n10) => colors.keys.color.includes(n10));
      if (name) {
        return colors[name];
      }
      let bg = color.stack.find((n10) => n10.slice(2) === "bg");
      if (bg) {
        return colors[name.slice(2)];
      }
      return (str) => str;
    };
    exports2.pascal = (str) => str ? str[0].toUpperCase() + str.slice(1) : "";
    exports2.inverse = (color) => {
      if (!color || !color.stack) return color;
      let name = color.stack.find((n10) => colors.keys.color.includes(n10));
      if (name) {
        let col = colors["bg" + exports2.pascal(name)];
        return col ? col.black : color;
      }
      let bg = color.stack.find((n10) => n10.slice(0, 2) === "bg");
      if (bg) {
        return colors[bg.slice(2).toLowerCase()] || color;
      }
      return colors.none;
    };
    exports2.complement = (color) => {
      if (!color || !color.stack) return color;
      let name = color.stack.find((n10) => colors.keys.color.includes(n10));
      let bg = color.stack.find((n10) => n10.slice(0, 2) === "bg");
      if (name && !bg) {
        return colors[complements[name] || name];
      }
      if (bg) {
        let lower = bg.slice(2).toLowerCase();
        let comp = complements[lower];
        if (!comp) return color;
        return colors["bg" + exports2.pascal(comp)] || color;
      }
      return colors.none;
    };
    exports2.meridiem = (date7) => {
      let hours = date7.getHours();
      let minutes = date7.getMinutes();
      let ampm = hours >= 12 ? "pm" : "am";
      hours = hours % 12;
      let hrs = hours === 0 ? 12 : hours;
      let min = minutes < 10 ? "0" + minutes : minutes;
      return hrs + ":" + min + " " + ampm;
    };
    exports2.set = (obj = {}, prop = "", val) => {
      return prop.split(".").reduce((acc, k32, i32, arr) => {
        let value = arr.length - 1 > i32 ? acc[k32] || {} : val;
        if (!exports2.isObject(value) && i32 < arr.length - 1) value = {};
        return acc[k32] = value;
      }, obj);
    };
    exports2.get = (obj = {}, prop = "", fallback2) => {
      let value = obj[prop] == null ? prop.split(".").reduce((acc, k32) => acc && acc[k32], obj) : obj[prop];
      return value == null ? fallback2 : value;
    };
    exports2.mixin = (target, b32) => {
      if (!isObject3(target)) return b32;
      if (!isObject3(b32)) return target;
      for (let key of Object.keys(b32)) {
        let desc = Object.getOwnPropertyDescriptor(b32, key);
        if (hasOwnProperty.call(desc, "value")) {
          if (hasOwnProperty.call(target, key) && isObject3(desc.value)) {
            let existing = Object.getOwnPropertyDescriptor(target, key);
            if (isObject3(existing.value) && existing.value !== desc.value) {
              target[key] = exports2.merge({}, target[key], b32[key]);
            } else {
              Reflect.defineProperty(target, key, desc);
            }
          } else {
            Reflect.defineProperty(target, key, desc);
          }
        } else {
          Reflect.defineProperty(target, key, desc);
        }
      }
      return target;
    };
    exports2.merge = (...args) => {
      let target = {};
      for (let ele of args) exports2.mixin(target, ele);
      return target;
    };
    exports2.mixinEmitter = (obj, emitter) => {
      let proto = emitter.constructor.prototype;
      for (let key of Object.keys(proto)) {
        let val = proto[key];
        if (typeof val === "function") {
          exports2.define(obj, key, val.bind(emitter));
        } else {
          exports2.define(obj, key, val);
        }
      }
    };
    var onExit = /* @__PURE__ */ __name((quit, code) => {
      if (onExitCalled) return;
      onExitCalled = true;
      onExitCallbacks.forEach((fn) => fn());
      if (quit === true) {
        process.exit(128 + code);
      }
    }, "onExit");
    var onSigTerm = onExit.bind(null, true, 15);
    var onSigInt = onExit.bind(null, true, 2);
    exports2.onExit = (callback) => {
      if (onExitCallbacks.size === 0) {
        process.once("SIGTERM", onSigTerm);
        process.once("SIGINT", onSigInt);
        process.once("exit", onExit);
      }
      onExitCallbacks.add(callback);
      return () => {
        onExitCallbacks.delete(callback);
        if (onExitCallbacks.size === 0) {
          process.off("SIGTERM", onSigTerm);
          process.off("SIGINT", onSigInt);
          process.off("exit", onExit);
        }
      };
    };
    exports2.define = (obj, key, value) => {
      Reflect.defineProperty(obj, key, { value });
    };
    exports2.defineExport = (obj, key, fn) => {
      let custom;
      Reflect.defineProperty(obj, key, {
        enumerable: true,
        configurable: true,
        set(val) {
          custom = val;
        },
        get() {
          return custom ? custom() : fn();
        }
      });
    };
  }
});

// ../../node_modules/enquirer/lib/combos.js
var require_combos = __commonJS({
  "../../node_modules/enquirer/lib/combos.js"(exports2) {
    "use strict";
    exports2.ctrl = {
      a: "first",
      b: "backward",
      c: "cancel",
      d: "deleteForward",
      e: "last",
      f: "forward",
      g: "reset",
      i: "tab",
      k: "cutForward",
      l: "reset",
      n: "newItem",
      m: "cancel",
      j: "submit",
      p: "search",
      r: "remove",
      s: "save",
      u: "undo",
      w: "cutLeft",
      x: "toggleCursor",
      v: "paste"
    };
    exports2.shift = {
      up: "shiftUp",
      down: "shiftDown",
      left: "shiftLeft",
      right: "shiftRight",
      tab: "prev"
    };
    exports2.fn = {
      up: "pageUp",
      down: "pageDown",
      left: "pageLeft",
      right: "pageRight",
      delete: "deleteForward"
    };
    exports2.option = {
      b: "backward",
      f: "forward",
      d: "cutRight",
      left: "cutLeft",
      up: "altUp",
      down: "altDown"
    };
    exports2.keys = {
      pageup: "pageUp",
      // <fn>+<up> (mac), <Page Up> (windows)
      pagedown: "pageDown",
      // <fn>+<down> (mac), <Page Down> (windows)
      home: "home",
      // <fn>+<left> (mac), <home> (windows)
      end: "end",
      // <fn>+<right> (mac), <end> (windows)
      cancel: "cancel",
      delete: "deleteForward",
      backspace: "delete",
      down: "down",
      enter: "submit",
      escape: "cancel",
      left: "left",
      space: "space",
      number: "number",
      return: "submit",
      right: "right",
      tab: "next",
      up: "up"
    };
  }
});

// ../../node_modules/enquirer/lib/queue.js
var require_queue2 = __commonJS({
  "../../node_modules/enquirer/lib/queue.js"(exports2, module2) {
    "use strict";
    module2.exports = class Queue {
      static {
        __name(this, "Queue");
      }
      _queue = [];
      _executing = false;
      _jobRunner = null;
      constructor(jobRunner) {
        this._jobRunner = jobRunner;
      }
      enqueue = /* @__PURE__ */ __name((...args) => {
        this._queue.push(args);
        this._dequeue();
      }, "enqueue");
      destroy() {
        this._queue.length = 0;
        this._jobRunner = null;
      }
      _dequeue() {
        if (this._executing || !this._queue.length) return;
        this._executing = true;
        this._jobRunner(...this._queue.shift());
        setTimeout(() => {
          this._executing = false;
          this._dequeue();
        });
      }
    };
  }
});

// ../../node_modules/enquirer/lib/keypress.js
var require_keypress = __commonJS({
  "../../node_modules/enquirer/lib/keypress.js"(exports2, module2) {
    "use strict";
    var readline = require("readline");
    var combos = require_combos();
    var Queue = require_queue2();
    var metaKeyCodeRe = /^(?:\x1b)([a-zA-Z0-9])$/;
    var fnKeyRe = /^(?:\x1b+)(O|N|\[|\[\[)(?:(\d+)(?:;(\d+))?([~^$])|(?:1;)?(\d+)?([a-zA-Z]))/;
    var keyName = {
      /* xterm/gnome ESC O letter */
      "OP": "f1",
      "OQ": "f2",
      "OR": "f3",
      "OS": "f4",
      /* xterm/rxvt ESC [ number ~ */
      "[11~": "f1",
      "[12~": "f2",
      "[13~": "f3",
      "[14~": "f4",
      /* from Cygwin and used in libuv */
      "[[A": "f1",
      "[[B": "f2",
      "[[C": "f3",
      "[[D": "f4",
      "[[E": "f5",
      /* common */
      "[15~": "f5",
      "[17~": "f6",
      "[18~": "f7",
      "[19~": "f8",
      "[20~": "f9",
      "[21~": "f10",
      "[23~": "f11",
      "[24~": "f12",
      /* xterm ESC [ letter */
      "[A": "up",
      "[B": "down",
      "[C": "right",
      "[D": "left",
      "[E": "clear",
      "[F": "end",
      "[H": "home",
      /* xterm/gnome ESC O letter */
      "OA": "up",
      "OB": "down",
      "OC": "right",
      "OD": "left",
      "OE": "clear",
      "OF": "end",
      "OH": "home",
      /* xterm/rxvt ESC [ number ~ */
      "[1~": "home",
      "[2~": "insert",
      "[3~": "delete",
      "[4~": "end",
      "[5~": "pageup",
      "[6~": "pagedown",
      /* putty */
      "[[5~": "pageup",
      "[[6~": "pagedown",
      /* rxvt */
      "[7~": "home",
      "[8~": "end",
      /* rxvt keys with modifiers */
      "[a": "up",
      "[b": "down",
      "[c": "right",
      "[d": "left",
      "[e": "clear",
      "[2$": "insert",
      "[3$": "delete",
      "[5$": "pageup",
      "[6$": "pagedown",
      "[7$": "home",
      "[8$": "end",
      "Oa": "up",
      "Ob": "down",
      "Oc": "right",
      "Od": "left",
      "Oe": "clear",
      "[2^": "insert",
      "[3^": "delete",
      "[5^": "pageup",
      "[6^": "pagedown",
      "[7^": "home",
      "[8^": "end",
      /* misc. */
      "[Z": "tab"
    };
    function isShiftKey(code) {
      return ["[a", "[b", "[c", "[d", "[e", "[2$", "[3$", "[5$", "[6$", "[7$", "[8$", "[Z"].includes(code);
    }
    __name(isShiftKey, "isShiftKey");
    function isCtrlKey(code) {
      return ["Oa", "Ob", "Oc", "Od", "Oe", "[2^", "[3^", "[5^", "[6^", "[7^", "[8^"].includes(code);
    }
    __name(isCtrlKey, "isCtrlKey");
    var keypress = /* @__PURE__ */ __name((s = "", event = {}) => {
      let parts;
      let key = {
        name: event.name,
        ctrl: false,
        meta: false,
        shift: false,
        option: false,
        sequence: s,
        raw: s,
        ...event
      };
      if (Buffer.isBuffer(s)) {
        if (s[0] > 127 && s[1] === void 0) {
          s[0] -= 128;
          s = "\x1B" + String(s);
        } else {
          s = String(s);
        }
      } else if (s !== void 0 && typeof s !== "string") {
        s = String(s);
      } else if (!s) {
        s = key.sequence || "";
      }
      key.sequence = key.sequence || s || key.name;
      if (s === "\r") {
        key.raw = void 0;
        key.name = "return";
      } else if (s === "\n") {
        key.name = "enter";
      } else if (s === "	") {
        key.name = "tab";
      } else if (s === "\b" || s === "\x7F" || s === "\x1B\x7F" || s === "\x1B\b") {
        key.name = "backspace";
        key.meta = s.charAt(0) === "\x1B";
      } else if (s === "\x1B" || s === "\x1B\x1B") {
        key.name = "escape";
        key.meta = s.length === 2;
      } else if (s === " " || s === "\x1B ") {
        key.name = "space";
        key.meta = s.length === 2;
      } else if (s <= "") {
        key.name = String.fromCharCode(s.charCodeAt(0) + "a".charCodeAt(0) - 1);
        key.ctrl = true;
      } else if (s.length === 1 && s >= "0" && s <= "9") {
        key.name = "number";
      } else if (s.length === 1 && s >= "a" && s <= "z") {
        key.name = s;
      } else if (s.length === 1 && s >= "A" && s <= "Z") {
        key.name = s.toLowerCase();
        key.shift = true;
      } else if (parts = metaKeyCodeRe.exec(s)) {
        key.meta = true;
        key.shift = /^[A-Z]$/.test(parts[1]);
      } else if (parts = fnKeyRe.exec(s)) {
        let segs = [...s];
        if (segs[0] === "\x1B" && segs[1] === "\x1B") {
          key.option = true;
        }
        let code = [parts[1], parts[2], parts[4], parts[6]].filter(Boolean).join("");
        let modifier = (parts[3] || parts[5] || 1) - 1;
        key.ctrl = !!(modifier & 4);
        key.meta = !!(modifier & 10);
        key.shift = !!(modifier & 1);
        key.code = code;
        key.name = keyName[code];
        key.shift = isShiftKey(code) || key.shift;
        key.ctrl = isCtrlKey(code) || key.ctrl;
      }
      return key;
    }, "keypress");
    keypress.listen = (options = {}, onKeypress) => {
      let { stdin } = options;
      if (!stdin || stdin !== process.stdin && !stdin.isTTY) {
        throw new Error("Invalid stream passed");
      }
      let rl = readline.createInterface({ terminal: true, input: stdin });
      readline.emitKeypressEvents(stdin, rl);
      const queue = new Queue((buf, key) => onKeypress(buf, keypress(buf, key), rl));
      let isRaw = stdin.isRaw;
      if (stdin.isTTY) stdin.setRawMode(true);
      stdin.on("keypress", queue.enqueue);
      rl.resume();
      let off = /* @__PURE__ */ __name(() => {
        if (stdin.isTTY) stdin.setRawMode(isRaw);
        stdin.removeListener("keypress", queue.enqueue);
        queue.destroy();
        rl.pause();
        rl.close();
      }, "off");
      return off;
    };
    keypress.action = (buf, key, customActions) => {
      let obj = { ...combos, ...customActions };
      if (key.ctrl) {
        key.action = obj.ctrl[key.name];
        return key;
      }
      if (key.option && obj.option) {
        key.action = obj.option[key.name];
        return key;
      }
      if (key.shift) {
        key.action = obj.shift[key.name];
        return key;
      }
      key.action = obj.keys[key.name];
      return key;
    };
    module2.exports = keypress;
  }
});

// ../../node_modules/enquirer/lib/timer.js
var require_timer = __commonJS({
  "../../node_modules/enquirer/lib/timer.js"(exports2, module2) {
    "use strict";
    module2.exports = (prompt2) => {
      prompt2.timers = prompt2.timers || {};
      let timers = prompt2.options.timers;
      if (!timers) return;
      for (let key of Object.keys(timers)) {
        let opts = timers[key];
        if (typeof opts === "number") {
          opts = { interval: opts };
        }
        create(prompt2, key, opts);
      }
    };
    function create(prompt2, name, options = {}) {
      let timer = prompt2.timers[name] = { name, start: Date.now(), ms: 0, tick: 0 };
      let ms = options.interval || 120;
      timer.frames = options.frames || [];
      timer.loading = true;
      let interval = setInterval(() => {
        timer.ms = Date.now() - timer.start;
        timer.tick++;
        prompt2.render();
      }, ms);
      timer.stop = () => {
        timer.loading = false;
        clearInterval(interval);
      };
      Reflect.defineProperty(timer, "interval", { value: interval });
      prompt2.once("close", () => timer.stop());
      return timer.stop;
    }
    __name(create, "create");
  }
});

// ../../node_modules/enquirer/lib/state.js
var require_state = __commonJS({
  "../../node_modules/enquirer/lib/state.js"(exports2, module2) {
    "use strict";
    var { define: define2, width } = require_utils11();
    var State = class {
      static {
        __name(this, "State");
      }
      constructor(prompt2) {
        let options = prompt2.options;
        define2(this, "_prompt", prompt2);
        this.type = prompt2.type;
        this.name = prompt2.name;
        this.message = "";
        this.header = "";
        this.footer = "";
        this.error = "";
        this.hint = "";
        this.input = "";
        this.cursor = 0;
        this.index = 0;
        this.lines = 0;
        this.tick = 0;
        this.prompt = "";
        this.buffer = "";
        this.width = width(options.stdout || process.stdout);
        Object.assign(this, options);
        this.name = this.name || this.message;
        this.message = this.message || this.name;
        this.symbols = prompt2.symbols;
        this.styles = prompt2.styles;
        this.required = /* @__PURE__ */ new Set();
        this.cancelled = false;
        this.submitted = false;
      }
      clone() {
        let state13 = { ...this };
        state13.status = this.status;
        state13.buffer = Buffer.from(state13.buffer);
        delete state13.clone;
        return state13;
      }
      set color(val) {
        this._color = val;
      }
      get color() {
        let styles = this.prompt.styles;
        if (this.cancelled) return styles.cancelled;
        if (this.submitted) return styles.submitted;
        let color = this._color || styles[this.status];
        return typeof color === "function" ? color : styles.pending;
      }
      set loading(value) {
        this._loading = value;
      }
      get loading() {
        if (typeof this._loading === "boolean") return this._loading;
        if (this.loadingChoices) return "choices";
        return false;
      }
      get status() {
        if (this.cancelled) return "cancelled";
        if (this.submitted) return "submitted";
        return "pending";
      }
    };
    module2.exports = State;
  }
});

// ../../node_modules/enquirer/lib/styles.js
var require_styles = __commonJS({
  "../../node_modules/enquirer/lib/styles.js"(exports2, module2) {
    "use strict";
    var utils = require_utils11();
    var colors = require_ansi_colors();
    var styles = {
      default: colors.noop,
      noop: colors.noop,
      /**
       * Modifiers
       */
      set inverse(custom) {
        this._inverse = custom;
      },
      get inverse() {
        return this._inverse || utils.inverse(this.primary);
      },
      set complement(custom) {
        this._complement = custom;
      },
      get complement() {
        return this._complement || utils.complement(this.primary);
      },
      /**
       * Main color
       */
      primary: colors.cyan,
      /**
       * Main palette
       */
      success: colors.green,
      danger: colors.magenta,
      strong: colors.bold,
      warning: colors.yellow,
      muted: colors.dim,
      disabled: colors.gray,
      dark: colors.dim.gray,
      underline: colors.underline,
      set info(custom) {
        this._info = custom;
      },
      get info() {
        return this._info || this.primary;
      },
      set em(custom) {
        this._em = custom;
      },
      get em() {
        return this._em || this.primary.underline;
      },
      set heading(custom) {
        this._heading = custom;
      },
      get heading() {
        return this._heading || this.muted.underline;
      },
      /**
       * Statuses
       */
      set pending(custom) {
        this._pending = custom;
      },
      get pending() {
        return this._pending || this.primary;
      },
      set submitted(custom) {
        this._submitted = custom;
      },
      get submitted() {
        return this._submitted || this.success;
      },
      set cancelled(custom) {
        this._cancelled = custom;
      },
      get cancelled() {
        return this._cancelled || this.danger;
      },
      /**
       * Special styling
       */
      set typing(custom) {
        this._typing = custom;
      },
      get typing() {
        return this._typing || this.dim;
      },
      set placeholder(custom) {
        this._placeholder = custom;
      },
      get placeholder() {
        return this._placeholder || this.primary.dim;
      },
      set highlight(custom) {
        this._highlight = custom;
      },
      get highlight() {
        return this._highlight || this.inverse;
      }
    };
    styles.merge = (options = {}) => {
      if (options.styles && typeof options.styles.enabled === "boolean") {
        colors.enabled = options.styles.enabled;
      }
      if (options.styles && typeof options.styles.visible === "boolean") {
        colors.visible = options.styles.visible;
      }
      let result2 = utils.merge({}, styles, options.styles);
      delete result2.merge;
      for (let key of Object.keys(colors)) {
        if (!hasOwnProperty.call(result2, key)) {
          Reflect.defineProperty(result2, key, { get: /* @__PURE__ */ __name(() => colors[key], "get") });
        }
      }
      for (let key of Object.keys(colors.styles)) {
        if (!hasOwnProperty.call(result2, key)) {
          Reflect.defineProperty(result2, key, { get: /* @__PURE__ */ __name(() => colors[key], "get") });
        }
      }
      return result2;
    };
    module2.exports = styles;
  }
});

// ../../node_modules/enquirer/lib/symbols.js
var require_symbols2 = __commonJS({
  "../../node_modules/enquirer/lib/symbols.js"(exports2, module2) {
    "use strict";
    var isWindows2 = process.platform === "win32";
    var colors = require_ansi_colors();
    var utils = require_utils11();
    var symbols = {
      ...colors.symbols,
      upDownDoubleArrow: "\u21D5",
      upDownDoubleArrow2: "\u2B0D",
      upDownArrow: "\u2195",
      asterisk: "*",
      asterism: "\u2042",
      bulletWhite: "\u25E6",
      electricArrow: "\u2301",
      ellipsisLarge: "\u22EF",
      ellipsisSmall: "\u2026",
      fullBlock: "\u2588",
      identicalTo: "\u2261",
      indicator: colors.symbols.check,
      leftAngle: "\u2039",
      mark: "\u203B",
      minus: "\u2212",
      multiplication: "\xD7",
      obelus: "\xF7",
      percent: "%",
      pilcrow: "\xB6",
      pilcrow2: "\u2761",
      pencilUpRight: "\u2710",
      pencilDownRight: "\u270E",
      pencilRight: "\u270F",
      plus: "+",
      plusMinus: "\xB1",
      pointRight: "\u261E",
      rightAngle: "\u203A",
      section: "\xA7",
      hexagon: { off: "\u2B21", on: "\u2B22", disabled: "\u2B22" },
      ballot: { on: "\u2611", off: "\u2610", disabled: "\u2612" },
      stars: { on: "\u2605", off: "\u2606", disabled: "\u2606" },
      folder: { on: "\u25BC", off: "\u25B6", disabled: "\u25B6" },
      prefix: {
        pending: colors.symbols.question,
        submitted: colors.symbols.check,
        cancelled: colors.symbols.cross
      },
      separator: {
        pending: colors.symbols.pointerSmall,
        submitted: colors.symbols.middot,
        cancelled: colors.symbols.middot
      },
      radio: {
        off: isWindows2 ? "( )" : "\u25EF",
        on: isWindows2 ? "(*)" : "\u25C9",
        disabled: isWindows2 ? "(|)" : "\u24BE"
      },
      numbers: ["\u24EA", "\u2460", "\u2461", "\u2462", "\u2463", "\u2464", "\u2465", "\u2466", "\u2467", "\u2468", "\u2469", "\u246A", "\u246B", "\u246C", "\u246D", "\u246E", "\u246F", "\u2470", "\u2471", "\u2472", "\u2473", "\u3251", "\u3252", "\u3253", "\u3254", "\u3255", "\u3256", "\u3257", "\u3258", "\u3259", "\u325A", "\u325B", "\u325C", "\u325D", "\u325E", "\u325F", "\u32B1", "\u32B2", "\u32B3", "\u32B4", "\u32B5", "\u32B6", "\u32B7", "\u32B8", "\u32B9", "\u32BA", "\u32BB", "\u32BC", "\u32BD", "\u32BE", "\u32BF"]
    };
    symbols.merge = (options) => {
      let result2 = utils.merge({}, colors.symbols, symbols, options.symbols);
      delete result2.merge;
      return result2;
    };
    module2.exports = symbols;
  }
});

// ../../node_modules/enquirer/lib/theme.js
var require_theme = __commonJS({
  "../../node_modules/enquirer/lib/theme.js"(exports2, module2) {
    "use strict";
    var styles = require_styles();
    var symbols = require_symbols2();
    var utils = require_utils11();
    module2.exports = (prompt2) => {
      prompt2.options = utils.merge({}, prompt2.options.theme, prompt2.options);
      prompt2.symbols = symbols.merge(prompt2.options);
      prompt2.styles = styles.merge(prompt2.options);
    };
  }
});

// ../../node_modules/enquirer/lib/ansi.js
var require_ansi = __commonJS({
  "../../node_modules/enquirer/lib/ansi.js"(exports2, module2) {
    "use strict";
    var isTerm = process.env.TERM_PROGRAM === "Apple_Terminal";
    var stripAnsi2 = require_strip_ansi();
    var utils = require_utils11();
    var ansi = module2.exports = exports2;
    var ESC2 = "\x1B[";
    var BEL = "\x07";
    var hidden = false;
    var code = ansi.code = {
      bell: BEL,
      beep: BEL,
      beginning: `${ESC2}G`,
      down: `${ESC2}J`,
      esc: ESC2,
      getPosition: `${ESC2}6n`,
      hide: `${ESC2}?25l`,
      line: `${ESC2}2K`,
      lineEnd: `${ESC2}K`,
      lineStart: `${ESC2}1K`,
      restorePosition: ESC2 + (isTerm ? "8" : "u"),
      savePosition: ESC2 + (isTerm ? "7" : "s"),
      screen: `${ESC2}2J`,
      show: `${ESC2}?25h`,
      up: `${ESC2}1J`
    };
    var cursor3 = ansi.cursor = {
      get hidden() {
        return hidden;
      },
      hide() {
        hidden = true;
        return code.hide;
      },
      show() {
        hidden = false;
        return code.show;
      },
      forward: /* @__PURE__ */ __name((count = 1) => `${ESC2}${count}C`, "forward"),
      backward: /* @__PURE__ */ __name((count = 1) => `${ESC2}${count}D`, "backward"),
      nextLine: /* @__PURE__ */ __name((count = 1) => `${ESC2}E`.repeat(count), "nextLine"),
      prevLine: /* @__PURE__ */ __name((count = 1) => `${ESC2}F`.repeat(count), "prevLine"),
      up: /* @__PURE__ */ __name((count = 1) => count ? `${ESC2}${count}A` : "", "up"),
      down: /* @__PURE__ */ __name((count = 1) => count ? `${ESC2}${count}B` : "", "down"),
      right: /* @__PURE__ */ __name((count = 1) => count ? `${ESC2}${count}C` : "", "right"),
      left: /* @__PURE__ */ __name((count = 1) => count ? `${ESC2}${count}D` : "", "left"),
      to(x, y) {
        return y ? `${ESC2}${y + 1};${x + 1}H` : `${ESC2}${x + 1}G`;
      },
      move(x = 0, y = 0) {
        let res = "";
        res += x < 0 ? cursor3.left(-x) : x > 0 ? cursor3.right(x) : "";
        res += y < 0 ? cursor3.up(-y) : y > 0 ? cursor3.down(y) : "";
        return res;
      },
      strLen(str) {
        var realLength = 0, len = str.length, charCode = -1;
        for (var i32 = 0; i32 < len; i32++) {
          charCode = str.charCodeAt(i32);
          if (charCode >= 0 && charCode <= 128) realLength += 1;
          else realLength += 2;
        }
        return realLength;
      },
      restore(state13 = {}) {
        let { after, cursor: cursor4, initial, input, prompt: prompt2, size, value } = state13;
        initial = utils.isPrimitive(initial) ? String(initial) : "";
        input = utils.isPrimitive(input) ? String(input) : "";
        value = utils.isPrimitive(value) ? String(value) : "";
        if (size) {
          let codes = ansi.cursor.up(size) + ansi.cursor.to(this.strLen(prompt2));
          let diff = input.length - cursor4;
          if (diff > 0) {
            codes += ansi.cursor.left(diff);
          }
          return codes;
        }
        if (value || after) {
          let pos = !input && !!initial ? -this.strLen(initial) : -this.strLen(input) + cursor4;
          if (after) pos -= this.strLen(after);
          if (input === "" && initial && !prompt2.includes(initial)) {
            pos += this.strLen(initial);
          }
          return ansi.cursor.move(pos);
        }
      }
    };
    var erase = ansi.erase = {
      screen: code.screen,
      up: code.up,
      down: code.down,
      line: code.line,
      lineEnd: code.lineEnd,
      lineStart: code.lineStart,
      lines(n10) {
        let str = "";
        for (let i32 = 0; i32 < n10; i32++) {
          str += ansi.erase.line + (i32 < n10 - 1 ? ansi.cursor.up(1) : "");
        }
        if (n10) str += ansi.code.beginning;
        return str;
      }
    };
    ansi.clear = (input = "", columns = process.stdout.columns) => {
      if (!columns) return erase.line + cursor3.to(0);
      let width = /* @__PURE__ */ __name((str) => [...stripAnsi2(str)].length, "width");
      let lines = input.split(/\r?\n/);
      let rows = 0;
      for (let line of lines) {
        rows += 1 + Math.floor(Math.max(width(line) - 1, 0) / columns);
      }
      return (erase.line + cursor3.prevLine()).repeat(rows - 1) + erase.line + cursor3.to(0);
    };
  }
});

// ../../node_modules/enquirer/lib/prompt.js
var require_prompt2 = __commonJS({
  "../../node_modules/enquirer/lib/prompt.js"(exports2, module2) {
    "use strict";
    var Events = require("events");
    var stripAnsi2 = require_strip_ansi();
    var keypress = require_keypress();
    var timer = require_timer();
    var State = require_state();
    var theme = require_theme();
    var utils = require_utils11();
    var ansi = require_ansi();
    var Prompt = class _Prompt extends Events {
      static {
        __name(this, "Prompt");
      }
      constructor(options = {}) {
        super();
        this.name = options.name;
        this.type = options.type;
        this.options = options;
        theme(this);
        timer(this);
        this.state = new State(this);
        this.initial = [options.initial, options.default].find((v) => v != null);
        this.stdout = options.stdout || process.stdout;
        this.stdin = options.stdin || process.stdin;
        this.scale = options.scale || 1;
        this.term = this.options.term || process.env.TERM_PROGRAM;
        this.margin = margin(this.options.margin);
        this.setMaxListeners(0);
        setOptions(this);
      }
      async keypress(input, event = {}) {
        this.keypressed = true;
        let key = keypress.action(input, keypress(input, event), this.options.actions);
        this.state.keypress = key;
        this.emit("keypress", input, key);
        this.emit("state", this.state.clone());
        const fn = this.options[key.action] || this[key.action] || this.dispatch;
        if (typeof fn === "function") {
          return await fn.call(this, input, key);
        }
        this.alert();
      }
      alert() {
        delete this.state.alert;
        if (this.options.show === false) {
          this.emit("alert");
        } else {
          this.stdout.write(ansi.code.beep);
        }
      }
      cursorHide() {
        this.stdout.write(ansi.cursor.hide());
        const releaseOnExit = utils.onExit(() => this.cursorShow());
        this.on("close", () => {
          this.cursorShow();
          releaseOnExit();
        });
      }
      cursorShow() {
        this.stdout.write(ansi.cursor.show());
      }
      write(str) {
        if (!str) return;
        if (this.stdout && this.state.show !== false) {
          this.stdout.write(str);
        }
        this.state.buffer += str;
      }
      clear(lines = 0) {
        let buffer = this.state.buffer;
        this.state.buffer = "";
        if (!buffer && !lines || this.options.show === false) return;
        this.stdout.write(ansi.cursor.down(lines) + ansi.clear(buffer, this.width));
      }
      restore() {
        if (this.state.closed || this.options.show === false) return;
        let { prompt: prompt2, after, rest } = this.sections();
        let { cursor: cursor3, initial = "", input = "", value = "" } = this;
        let size = this.state.size = rest.length;
        let state13 = { after, cursor: cursor3, initial, input, prompt: prompt2, size, value };
        let codes = ansi.cursor.restore(state13);
        if (codes) {
          this.stdout.write(codes);
        }
      }
      sections() {
        let { buffer, input, prompt: prompt2 } = this.state;
        prompt2 = stripAnsi2(prompt2);
        let buf = stripAnsi2(buffer);
        let idx = buf.indexOf(prompt2);
        let header = buf.slice(0, idx);
        let rest = buf.slice(idx);
        let lines = rest.split("\n");
        let first = lines[0];
        let last = lines[lines.length - 1];
        let promptLine = prompt2 + (input ? " " + input : "");
        let len = promptLine.length;
        let after = len < first.length ? first.slice(len + 1) : "";
        return { header, prompt: first, after, rest: lines.slice(1), last };
      }
      async submit() {
        this.state.submitted = true;
        this.state.validating = true;
        if (this.options.onSubmit) {
          await this.options.onSubmit.call(this, this.name, this.value, this);
        }
        let result2 = this.state.error || await this.validate(this.value, this.state);
        if (result2 !== true) {
          let error4 = "\n" + this.symbols.pointer + " ";
          if (typeof result2 === "string") {
            error4 += result2.trim();
          } else {
            error4 += "Invalid input";
          }
          this.state.error = "\n" + this.styles.danger(error4);
          this.state.submitted = false;
          await this.render();
          await this.alert();
          this.state.validating = false;
          this.state.error = void 0;
          return;
        }
        this.state.validating = false;
        await this.render();
        await this.close();
        this.value = await this.result(this.value);
        this.emit("submit", this.value);
      }
      async cancel(err) {
        this.state.cancelled = this.state.submitted = true;
        await this.render();
        await this.close();
        if (typeof this.options.onCancel === "function") {
          await this.options.onCancel.call(this, this.name, this.value, this);
        }
        this.emit("cancel", await this.error(err));
      }
      async close() {
        this.state.closed = true;
        try {
          let sections = this.sections();
          let lines = Math.ceil(sections.prompt.length / this.width);
          if (sections.rest) {
            this.write(ansi.cursor.down(sections.rest.length));
          }
          this.write("\n".repeat(lines));
        } catch (err) {
        }
        this.emit("close");
      }
      start() {
        if (!this.stop && this.options.show !== false) {
          this.stop = keypress.listen(this, this.keypress.bind(this));
          this.once("close", this.stop);
          this.emit("start", this);
        }
      }
      async skip() {
        this.skipped = this.options.skip === true;
        if (typeof this.options.skip === "function") {
          this.skipped = await this.options.skip.call(this, this.name, this.value);
        }
        return this.skipped;
      }
      async initialize() {
        let { format: format32, options, result: result2 } = this;
        this.format = () => format32.call(this, this.value);
        this.result = () => result2.call(this, this.value);
        if (typeof options.initial === "function") {
          this.initial = await options.initial.call(this, this);
        }
        if (typeof options.onRun === "function") {
          await options.onRun.call(this, this);
        }
        if (typeof options.onSubmit === "function") {
          let onSubmit = options.onSubmit.bind(this);
          let submit = this.submit.bind(this);
          delete this.options.onSubmit;
          this.submit = async () => {
            await onSubmit(this.name, this.value, this);
            return submit();
          };
        }
        await this.start();
        await this.render();
      }
      render() {
        throw new Error("expected prompt to have a custom render method");
      }
      run() {
        return new Promise(async (resolve13, reject) => {
          this.once("submit", resolve13);
          this.once("cancel", reject);
          if (await this.skip()) {
            this.render = () => {
            };
            return this.submit();
          }
          await this.initialize();
          this.emit("run");
        });
      }
      async element(name, choice, i32) {
        let { options, state: state13, symbols, timers } = this;
        let timer2 = timers && timers[name];
        state13.timer = timer2;
        let value = options[name] || state13[name] || symbols[name];
        let val = choice && choice[name] != null ? choice[name] : await value;
        if (val === "") return val;
        let res = await this.resolve(val, state13, choice, i32);
        if (!res && choice && choice[name]) {
          return this.resolve(value, state13, choice, i32);
        }
        return res;
      }
      async prefix() {
        let element = await this.element("prefix") || this.symbols;
        let timer2 = this.timers && this.timers.prefix;
        let state13 = this.state;
        state13.timer = timer2;
        if (utils.isObject(element)) element = element[state13.status] || element.pending;
        if (!utils.hasColor(element)) {
          let style = this.styles[state13.status] || this.styles.pending;
          return style(element);
        }
        return element;
      }
      async message() {
        let message2 = await this.element("message");
        if (!utils.hasColor(message2)) {
          return this.styles.strong(message2);
        }
        return message2;
      }
      async separator() {
        let element = await this.element("separator") || this.symbols;
        let timer2 = this.timers && this.timers.separator;
        let state13 = this.state;
        state13.timer = timer2;
        let value = element[state13.status] || element.pending || state13.separator;
        let ele = await this.resolve(value, state13);
        if (utils.isObject(ele)) ele = ele[state13.status] || ele.pending;
        if (!utils.hasColor(ele)) {
          return this.styles.muted(ele);
        }
        return ele;
      }
      async pointer(choice, i32) {
        let val = await this.element("pointer", choice, i32);
        if (typeof val === "string" && utils.hasColor(val)) {
          return val;
        }
        if (val) {
          let styles = this.styles;
          let focused = this.index === i32;
          let style = focused ? styles.primary : (val2) => val2;
          let ele = await this.resolve(val[focused ? "on" : "off"] || val, this.state);
          let styled = !utils.hasColor(ele) ? style(ele) : ele;
          return focused ? styled : " ".repeat(ele.length);
        }
      }
      async indicator(choice, i32) {
        let val = await this.element("indicator", choice, i32);
        if (typeof val === "string" && utils.hasColor(val)) {
          return val;
        }
        if (val) {
          let styles = this.styles;
          let enabled = choice.enabled === true;
          let style = enabled ? styles.success : styles.dark;
          let ele = val[enabled ? "on" : "off"] || val;
          return !utils.hasColor(ele) ? style(ele) : ele;
        }
        return "";
      }
      body() {
        return null;
      }
      footer() {
        if (this.state.status === "pending") {
          return this.element("footer");
        }
      }
      header() {
        if (this.state.status === "pending") {
          return this.element("header");
        }
      }
      async hint() {
        if (this.state.status === "pending" && !this.isValue(this.state.input)) {
          let hint = await this.element("hint");
          if (!utils.hasColor(hint)) {
            return this.styles.muted(hint);
          }
          return hint;
        }
      }
      error(err) {
        return !this.state.submitted ? err || this.state.error : "";
      }
      format(value) {
        return value;
      }
      result(value) {
        return value;
      }
      validate(value) {
        if (this.options.required === true) {
          return this.isValue(value);
        }
        return true;
      }
      isValue(value) {
        return value != null && value !== "";
      }
      resolve(value, ...args) {
        return utils.resolve(this, value, ...args);
      }
      get base() {
        return _Prompt.prototype;
      }
      get style() {
        return this.styles[this.state.status];
      }
      get height() {
        return this.options.rows || utils.height(this.stdout, 25);
      }
      get width() {
        return this.options.columns || utils.width(this.stdout, 80);
      }
      get size() {
        return { width: this.width, height: this.height };
      }
      set cursor(value) {
        this.state.cursor = value;
      }
      get cursor() {
        return this.state.cursor;
      }
      set input(value) {
        this.state.input = value;
      }
      get input() {
        return this.state.input;
      }
      set value(value) {
        this.state.value = value;
      }
      get value() {
        let { input, value } = this.state;
        let result2 = [value, input].find(this.isValue.bind(this));
        return this.isValue(result2) ? result2 : this.initial;
      }
      static get prompt() {
        return (options) => new this(options).run();
      }
    };
    function setOptions(prompt2) {
      let isValidKey = /* @__PURE__ */ __name((key) => {
        return prompt2[key] === void 0 || typeof prompt2[key] === "function";
      }, "isValidKey");
      let ignore2 = [
        "actions",
        "choices",
        "initial",
        "margin",
        "roles",
        "styles",
        "symbols",
        "theme",
        "timers",
        "value"
      ];
      let ignoreFn = [
        "body",
        "footer",
        "error",
        "header",
        "hint",
        "indicator",
        "message",
        "prefix",
        "separator",
        "skip"
      ];
      for (let key of Object.keys(prompt2.options)) {
        if (ignore2.includes(key)) continue;
        if (/^on[A-Z]/.test(key)) continue;
        let option = prompt2.options[key];
        if (typeof option === "function" && isValidKey(key)) {
          if (!ignoreFn.includes(key)) {
            prompt2[key] = option.bind(prompt2);
          }
        } else if (typeof prompt2[key] !== "function") {
          prompt2[key] = option;
        }
      }
    }
    __name(setOptions, "setOptions");
    function margin(value) {
      if (typeof value === "number") {
        value = [value, value, value, value];
      }
      let arr = [].concat(value || []);
      let pad = /* @__PURE__ */ __name((i32) => i32 % 2 === 0 ? "\n" : " ", "pad");
      let res = [];
      for (let i32 = 0; i32 < 4; i32++) {
        let char = pad(i32);
        if (arr[i32]) {
          res.push(char.repeat(arr[i32]));
        } else {
          res.push("");
        }
      }
      return res;
    }
    __name(margin, "margin");
    module2.exports = Prompt;
  }
});

// ../../node_modules/enquirer/lib/roles.js
var require_roles = __commonJS({
  "../../node_modules/enquirer/lib/roles.js"(exports2, module2) {
    "use strict";
    var utils = require_utils11();
    var roles = {
      default(prompt2, choice) {
        return choice;
      },
      checkbox(prompt2, choice) {
        throw new Error("checkbox role is not implemented yet");
      },
      editable(prompt2, choice) {
        throw new Error("editable role is not implemented yet");
      },
      expandable(prompt2, choice) {
        throw new Error("expandable role is not implemented yet");
      },
      heading(prompt2, choice) {
        choice.disabled = "";
        choice.indicator = [choice.indicator, " "].find((v) => v != null);
        choice.message = choice.message || "";
        return choice;
      },
      input(prompt2, choice) {
        throw new Error("input role is not implemented yet");
      },
      option(prompt2, choice) {
        return roles.default(prompt2, choice);
      },
      radio(prompt2, choice) {
        throw new Error("radio role is not implemented yet");
      },
      separator(prompt2, choice) {
        choice.disabled = "";
        choice.indicator = [choice.indicator, " "].find((v) => v != null);
        choice.message = choice.message || prompt2.symbols.line.repeat(5);
        return choice;
      },
      spacer(prompt2, choice) {
        return choice;
      }
    };
    module2.exports = (name, options = {}) => {
      let role = utils.merge({}, roles, options.roles);
      return role[name] || role.default;
    };
  }
});

// ../../node_modules/enquirer/lib/types/array.js
var require_array3 = __commonJS({
  "../../node_modules/enquirer/lib/types/array.js"(exports2, module2) {
    "use strict";
    var stripAnsi2 = require_strip_ansi();
    var Prompt = require_prompt2();
    var roles = require_roles();
    var utils = require_utils11();
    var { reorder, scrollUp, scrollDown, isObject: isObject3, swap } = utils;
    var ArrayPrompt = class extends Prompt {
      static {
        __name(this, "ArrayPrompt");
      }
      constructor(options) {
        super(options);
        this.cursorHide();
        this.maxSelected = options.maxSelected || Infinity;
        this.multiple = options.multiple || false;
        this.initial = options.initial || 0;
        this.delay = options.delay || 0;
        this.longest = 0;
        this.num = "";
      }
      async initialize() {
        if (typeof this.options.initial === "function") {
          this.initial = await this.options.initial.call(this);
        }
        await this.reset(true);
        await super.initialize();
      }
      async reset() {
        let { choices, initial, autofocus, suggest } = this.options;
        this.state._choices = [];
        this.state.choices = [];
        this.choices = await Promise.all(await this.toChoices(choices));
        this.choices.forEach((ch) => ch.enabled = false);
        if (typeof suggest !== "function" && this.selectable.length === 0) {
          throw new Error("At least one choice must be selectable");
        }
        if (isObject3(initial)) initial = Object.keys(initial);
        if (Array.isArray(initial)) {
          if (autofocus != null) this.index = this.findIndex(autofocus);
          initial.forEach((v) => this.enable(this.find(v)));
          await this.render();
        } else {
          if (autofocus != null) initial = autofocus;
          if (typeof initial === "string") initial = this.findIndex(initial);
          if (typeof initial === "number" && initial > -1) {
            this.index = Math.max(0, Math.min(initial, this.choices.length));
            this.enable(this.find(this.index));
          }
        }
        if (this.isDisabled(this.focused)) {
          await this.down();
        }
      }
      async toChoices(value, parent) {
        this.state.loadingChoices = true;
        let choices = [];
        let index = 0;
        let toChoices = /* @__PURE__ */ __name(async (items, parent2) => {
          if (typeof items === "function") items = await items.call(this);
          if (items instanceof Promise) items = await items;
          for (let i32 = 0; i32 < items.length; i32++) {
            let choice = items[i32] = await this.toChoice(items[i32], index++, parent2);
            choices.push(choice);
            if (choice.choices) {
              await toChoices(choice.choices, choice);
            }
          }
          return choices;
        }, "toChoices");
        return toChoices(value, parent).then((choices2) => {
          this.state.loadingChoices = false;
          return choices2;
        });
      }
      async toChoice(ele, i32, parent) {
        if (typeof ele === "function") ele = await ele.call(this, this);
        if (ele instanceof Promise) ele = await ele;
        if (typeof ele === "string") ele = { name: ele };
        if (ele.normalized) return ele;
        ele.normalized = true;
        let origVal = ele.value;
        let role = roles(ele.role, this.options);
        ele = role(this, ele);
        if (typeof ele.disabled === "string" && !ele.hint) {
          ele.hint = ele.disabled;
          ele.disabled = true;
        }
        if (ele.disabled === true && ele.hint == null) {
          ele.hint = "(disabled)";
        }
        if (ele.index != null) return ele;
        ele.name = ele.name || ele.key || ele.title || ele.value || ele.message;
        ele.message = ele.message || ele.name || "";
        ele.value = [ele.value, ele.name].find(this.isValue.bind(this));
        ele.input = "";
        ele.index = i32;
        ele.cursor = 0;
        utils.define(ele, "parent", parent);
        ele.level = parent ? parent.level + 1 : 1;
        if (ele.indent == null) {
          ele.indent = parent ? parent.indent + "  " : ele.indent || "";
        }
        ele.path = parent ? parent.path + "." + ele.name : ele.name;
        ele.enabled = !!(this.multiple && !this.isDisabled(ele) && (ele.enabled || this.isSelected(ele)));
        if (!this.isDisabled(ele)) {
          this.longest = Math.max(this.longest, stripAnsi2(ele.message).length);
        }
        let choice = { ...ele };
        ele.reset = (input = choice.input, value = choice.value) => {
          for (let key of Object.keys(choice)) ele[key] = choice[key];
          ele.input = input;
          ele.value = value;
        };
        if (origVal == null && typeof ele.initial === "function") {
          ele.input = await ele.initial.call(this, this.state, ele, i32);
        }
        return ele;
      }
      async onChoice(choice, i32) {
        this.emit("choice", choice, i32, this);
        if (typeof choice.onChoice === "function") {
          await choice.onChoice.call(this, this.state, choice, i32);
        }
      }
      async addChoice(ele, i32, parent) {
        let choice = await this.toChoice(ele, i32, parent);
        this.choices.push(choice);
        this.index = this.choices.length - 1;
        this.limit = this.choices.length;
        return choice;
      }
      async newItem(item, i32, parent) {
        let ele = { name: "New choice name?", editable: true, newChoice: true, ...item };
        let choice = await this.addChoice(ele, i32, parent);
        choice.updateChoice = () => {
          delete choice.newChoice;
          choice.name = choice.message = choice.input;
          choice.input = "";
          choice.cursor = 0;
        };
        return this.render();
      }
      indent(choice) {
        if (choice.indent == null) {
          return choice.level > 1 ? "  ".repeat(choice.level - 1) : "";
        }
        return choice.indent;
      }
      dispatch(s, key) {
        if (this.multiple && this[key.name]) return this[key.name]();
        this.alert();
      }
      focus(choice, enabled) {
        if (typeof enabled !== "boolean") enabled = choice.enabled;
        if (enabled && !choice.enabled && this.selected.length >= this.maxSelected) {
          return this.alert();
        }
        this.index = choice.index;
        choice.enabled = enabled && !this.isDisabled(choice);
        return choice;
      }
      space() {
        if (!this.multiple) return this.alert();
        if (!this.focused) return;
        this.toggle(this.focused);
        return this.render();
      }
      a() {
        if (this.maxSelected < this.choices.length) return this.alert();
        let enabled = this.selectable.every((ch) => ch.enabled);
        this.choices.forEach((ch) => ch.enabled = !enabled);
        return this.render();
      }
      i() {
        if (this.choices.length - this.selected.length > this.maxSelected) {
          return this.alert();
        }
        this.choices.forEach((ch) => ch.enabled = !ch.enabled);
        return this.render();
      }
      g() {
        if (!this.choices.some((ch) => !!ch.parent)) return this.a();
        const focused = this.focused;
        this.toggle(focused.parent && !focused.choices ? focused.parent : focused);
        return this.render();
      }
      toggle(choice, enabled) {
        if (!choice.enabled && this.selected.length >= this.maxSelected) {
          return this.alert();
        }
        if (typeof enabled !== "boolean") enabled = !choice.enabled;
        choice.enabled = enabled;
        if (choice.choices) {
          choice.choices.forEach((ch) => this.toggle(ch, enabled));
        }
        let parent = choice.parent;
        while (parent) {
          let choices = parent.choices.filter((ch) => this.isDisabled(ch));
          parent.enabled = choices.every((ch) => ch.enabled === true);
          parent = parent.parent;
        }
        reset6(this, this.choices);
        this.emit("toggle", choice, this);
        return choice;
      }
      enable(choice) {
        if (this.selected.length >= this.maxSelected) return this.alert();
        choice.enabled = !this.isDisabled(choice);
        choice.choices && choice.choices.forEach(this.enable.bind(this));
        return choice;
      }
      disable(choice) {
        choice.enabled = false;
        choice.choices && choice.choices.forEach(this.disable.bind(this));
        return choice;
      }
      number(n10) {
        this.num += n10;
        let number = /* @__PURE__ */ __name((num) => {
          let i32 = Number(num);
          if (i32 > this.choices.length - 1) return this.alert();
          let focused = this.focused;
          let choice = this.choices.find((ch) => i32 === ch.index);
          if (!choice.enabled && this.selected.length >= this.maxSelected) {
            return this.alert();
          }
          if (this.visible.indexOf(choice) === -1) {
            let choices = reorder(this.choices);
            let actualIdx = choices.indexOf(choice);
            if (focused.index > actualIdx) {
              let start = choices.slice(actualIdx, actualIdx + this.limit);
              let end = choices.filter((ch) => !start.includes(ch));
              this.choices = start.concat(end);
            } else {
              let pos = actualIdx - this.limit + 1;
              this.choices = choices.slice(pos).concat(choices.slice(0, pos));
            }
          }
          this.index = this.choices.indexOf(choice);
          this.toggle(this.focused);
          return this.render();
        }, "number");
        clearTimeout(this.numberTimeout);
        return new Promise((resolve13) => {
          let len = this.choices.length;
          let num = this.num;
          let handle = /* @__PURE__ */ __name((val = false, res) => {
            clearTimeout(this.numberTimeout);
            if (val) res = number(num);
            this.num = "";
            resolve13(res);
          }, "handle");
          if (num === "0" || num.length === 1 && Number(num + "0") > len) {
            return handle(true);
          }
          if (Number(num) > len) {
            return handle(false, this.alert());
          }
          this.numberTimeout = setTimeout(() => handle(true), this.delay);
        });
      }
      home() {
        this.choices = reorder(this.choices);
        this.index = 0;
        return this.render();
      }
      end() {
        let pos = this.choices.length - this.limit;
        let choices = reorder(this.choices);
        this.choices = choices.slice(pos).concat(choices.slice(0, pos));
        this.index = this.limit - 1;
        return this.render();
      }
      first() {
        this.index = 0;
        return this.render();
      }
      last() {
        this.index = this.visible.length - 1;
        return this.render();
      }
      prev() {
        if (this.visible.length <= 1) return this.alert();
        return this.up();
      }
      next() {
        if (this.visible.length <= 1) return this.alert();
        return this.down();
      }
      right() {
        if (this.cursor >= this.input.length) return this.alert();
        this.cursor++;
        return this.render();
      }
      left() {
        if (this.cursor <= 0) return this.alert();
        this.cursor--;
        return this.render();
      }
      up() {
        let len = this.choices.length;
        let vis = this.visible.length;
        let idx = this.index;
        if (this.options.scroll === false && idx === 0) {
          return this.alert();
        }
        if (len > vis && idx === 0) {
          return this.scrollUp();
        }
        this.index = (idx - 1 % len + len) % len;
        if (this.isDisabled() && !this.allChoicesAreDisabled()) {
          return this.up();
        }
        return this.render();
      }
      down() {
        let len = this.choices.length;
        let vis = this.visible.length;
        let idx = this.index;
        if (this.options.scroll === false && idx === vis - 1) {
          return this.alert();
        }
        if (len > vis && idx === vis - 1) {
          return this.scrollDown();
        }
        this.index = (idx + 1) % len;
        if (this.isDisabled() && !this.allChoicesAreDisabled()) {
          return this.down();
        }
        return this.render();
      }
      scrollUp(i32 = 0) {
        this.choices = scrollUp(this.choices);
        this.index = i32;
        if (this.isDisabled()) {
          return this.up();
        }
        return this.render();
      }
      scrollDown(i32 = this.visible.length - 1) {
        this.choices = scrollDown(this.choices);
        this.index = i32;
        if (this.isDisabled()) {
          return this.down();
        }
        return this.render();
      }
      async shiftUp() {
        if (this.options.sort === true) {
          this.sorting = true;
          this.swap(this.index - 1);
          await this.up();
          this.sorting = false;
          return;
        }
        return this.scrollUp(this.index);
      }
      async shiftDown() {
        if (this.options.sort === true) {
          this.sorting = true;
          this.swap(this.index + 1);
          await this.down();
          this.sorting = false;
          return;
        }
        return this.scrollDown(this.index);
      }
      pageUp() {
        if (this.visible.length <= 1) return this.alert();
        this.limit = Math.max(this.limit - 1, 0);
        this.index = Math.min(this.limit - 1, this.index);
        this._limit = this.limit;
        if (this.isDisabled()) {
          return this.up();
        }
        return this.render();
      }
      pageDown() {
        if (this.visible.length >= this.choices.length) return this.alert();
        this.index = Math.max(0, this.index);
        this.limit = Math.min(this.limit + 1, this.choices.length);
        this._limit = this.limit;
        if (this.isDisabled()) {
          return this.down();
        }
        return this.render();
      }
      swap(pos) {
        swap(this.choices, this.index, pos);
      }
      allChoicesAreDisabled(choices = this.choices) {
        return choices.every((choice) => this.isDisabled(choice));
      }
      isDisabled(choice = this.focused) {
        let keys = ["disabled", "collapsed", "hidden", "completing", "readonly"];
        if (choice && keys.some((key) => choice[key] === true)) {
          return true;
        }
        return choice && choice.role === "heading";
      }
      isEnabled(choice = this.focused) {
        if (Array.isArray(choice)) return choice.every((ch) => this.isEnabled(ch));
        if (choice.choices) {
          let choices = choice.choices.filter((ch) => !this.isDisabled(ch));
          return choice.enabled && choices.every((ch) => this.isEnabled(ch));
        }
        return choice.enabled && !this.isDisabled(choice);
      }
      isChoice(choice, value) {
        return choice.name === value || choice.index === Number(value);
      }
      isSelected(choice) {
        if (Array.isArray(this.initial)) {
          return this.initial.some((value) => this.isChoice(choice, value));
        }
        return this.isChoice(choice, this.initial);
      }
      map(names = [], prop = "value") {
        return [].concat(names || []).reduce((acc, name) => {
          acc[name] = this.find(name, prop);
          return acc;
        }, {});
      }
      filter(value, prop) {
        let isChoice = /* @__PURE__ */ __name((ele, i32) => [ele.name, i32].includes(value), "isChoice");
        let fn = typeof value === "function" ? value : isChoice;
        let choices = this.options.multiple ? this.state._choices : this.choices;
        let result2 = choices.filter(fn);
        if (prop) {
          return result2.map((ch) => ch[prop]);
        }
        return result2;
      }
      find(value, prop) {
        if (isObject3(value)) return prop ? value[prop] : value;
        let isChoice = /* @__PURE__ */ __name((ele, i32) => [ele.name, i32].includes(value), "isChoice");
        let fn = typeof value === "function" ? value : isChoice;
        let choice = this.choices.find(fn);
        if (choice) {
          return prop ? choice[prop] : choice;
        }
      }
      findIndex(value) {
        return this.choices.indexOf(this.find(value));
      }
      async submit() {
        let choice = this.focused;
        if (!choice) return this.alert();
        if (choice.newChoice) {
          if (!choice.input) return this.alert();
          choice.updateChoice();
          return this.render();
        }
        if (this.choices.some((ch) => ch.newChoice)) {
          return this.alert();
        }
        let { reorder: reorder2, sort } = this.options;
        let multi = this.multiple === true;
        let value = this.selected;
        if (value === void 0) {
          return this.alert();
        }
        if (Array.isArray(value) && reorder2 !== false && sort !== true) {
          value = utils.reorder(value);
        }
        this.value = multi ? value.map((ch) => ch.name) : value.name;
        return super.submit();
      }
      set choices(choices = []) {
        this.state._choices = this.state._choices || [];
        this.state.choices = choices;
        for (let choice of choices) {
          if (!this.state._choices.some((ch) => ch.name === choice.name)) {
            this.state._choices.push(choice);
          }
        }
        if (!this._initial && this.options.initial) {
          this._initial = true;
          let init = this.initial;
          if (typeof init === "string" || typeof init === "number") {
            let choice = this.find(init);
            if (choice) {
              this.initial = choice.index;
              this.focus(choice, true);
            }
          }
        }
      }
      get choices() {
        return reset6(this, this.state.choices || []);
      }
      set visible(visible) {
        this.state.visible = visible;
      }
      get visible() {
        return (this.state.visible || this.choices).slice(0, this.limit);
      }
      set limit(num) {
        this.state.limit = num;
      }
      get limit() {
        let { state: state13, options, choices } = this;
        let limit = state13.limit || this._limit || options.limit || choices.length;
        return Math.min(limit, this.height);
      }
      set value(value) {
        super.value = value;
      }
      get value() {
        if (typeof super.value !== "string" && super.value === this.initial) {
          return this.input;
        }
        return super.value;
      }
      set index(i32) {
        this.state.index = i32;
      }
      get index() {
        return Math.max(0, this.state ? this.state.index : 0);
      }
      get enabled() {
        return this.filter(this.isEnabled.bind(this));
      }
      get focused() {
        let choice = this.choices[this.index];
        if (choice && this.state.submitted && this.multiple !== true) {
          choice.enabled = true;
        }
        return choice;
      }
      get selectable() {
        return this.choices.filter((choice) => !this.isDisabled(choice));
      }
      get selected() {
        return this.multiple ? this.enabled : this.focused;
      }
    };
    function reset6(prompt2, choices) {
      if (choices instanceof Promise) return choices;
      if (typeof choices === "function") {
        if (utils.isAsyncFn(choices)) return choices;
        choices = choices.call(prompt2, prompt2);
      }
      for (let choice of choices) {
        if (Array.isArray(choice.choices)) {
          let items = choice.choices.filter((ch) => !prompt2.isDisabled(ch));
          choice.enabled = items.every((ch) => ch.enabled === true);
        }
        if (prompt2.isDisabled(choice) === true) {
          delete choice.enabled;
        }
      }
      return choices;
    }
    __name(reset6, "reset");
    module2.exports = ArrayPrompt;
  }
});

// ../../node_modules/enquirer/lib/prompts/select.js
var require_select = __commonJS({
  "../../node_modules/enquirer/lib/prompts/select.js"(exports2, module2) {
    "use strict";
    var ArrayPrompt = require_array3();
    var utils = require_utils11();
    var SelectPrompt = class extends ArrayPrompt {
      static {
        __name(this, "SelectPrompt");
      }
      constructor(options) {
        super(options);
        this.emptyError = this.options.emptyError || "No items were selected";
      }
      async dispatch(s, key) {
        if (this.multiple) {
          return this[key.name] ? await this[key.name](s, key) : await super.dispatch(s, key);
        }
        this.alert();
      }
      separator() {
        if (this.options.separator) return super.separator();
        let sep7 = this.styles.muted(this.symbols.ellipsis);
        return this.state.submitted ? super.separator() : sep7;
      }
      pointer(choice, i32) {
        return !this.multiple || this.options.pointer ? super.pointer(choice, i32) : "";
      }
      indicator(choice, i32) {
        return this.multiple ? super.indicator(choice, i32) : "";
      }
      choiceMessage(choice, i32) {
        let message2 = this.resolve(choice.message, this.state, choice, i32);
        if (choice.role === "heading" && !utils.hasColor(message2)) {
          message2 = this.styles.strong(message2);
        }
        return this.resolve(message2, this.state, choice, i32);
      }
      choiceSeparator() {
        return ":";
      }
      async renderChoice(choice, i32) {
        await this.onChoice(choice, i32);
        let focused = this.index === i32;
        let pointer = await this.pointer(choice, i32);
        let check = await this.indicator(choice, i32) + (choice.pad || "");
        let hint = await this.resolve(choice.hint, this.state, choice, i32);
        if (hint && !utils.hasColor(hint)) {
          hint = this.styles.muted(hint);
        }
        let ind = this.indent(choice);
        let msg = await this.choiceMessage(choice, i32);
        let line = /* @__PURE__ */ __name(() => [this.margin[3], ind + pointer + check, msg, this.margin[1], hint].filter(Boolean).join(" "), "line");
        if (choice.role === "heading") {
          return line();
        }
        if (choice.disabled) {
          if (!utils.hasColor(msg)) {
            msg = this.styles.disabled(msg);
          }
          return line();
        }
        if (focused) {
          msg = this.styles.em(msg);
        }
        return line();
      }
      async renderChoices() {
        if (this.state.loading === "choices") {
          return this.styles.warning("Loading choices");
        }
        if (this.state.submitted) return "";
        let choices = this.visible.map(async (ch, i32) => await this.renderChoice(ch, i32));
        let visible = await Promise.all(choices);
        if (!visible.length) visible.push(this.styles.danger("No matching choices"));
        let result2 = this.margin[0] + visible.join("\n");
        let header;
        if (this.options.choicesHeader) {
          header = await this.resolve(this.options.choicesHeader, this.state);
        }
        return [header, result2].filter(Boolean).join("\n");
      }
      format() {
        if (!this.state.submitted || this.state.cancelled) return "";
        if (Array.isArray(this.selected)) {
          return this.selected.map((choice) => this.styles.primary(choice.name)).join(", ");
        }
        return this.styles.primary(this.selected.name);
      }
      async render() {
        let { submitted, size } = this.state;
        let prompt2 = "";
        let header = await this.header();
        let prefix = await this.prefix();
        let separator = await this.separator();
        let message2 = await this.message();
        if (this.options.promptLine !== false) {
          prompt2 = [prefix, message2, separator, ""].join(" ");
          this.state.prompt = prompt2;
        }
        let output = await this.format();
        let help = await this.error() || await this.hint();
        let body = await this.renderChoices();
        let footer = await this.footer();
        if (output) prompt2 += output;
        if (help && !prompt2.includes(help)) prompt2 += " " + help;
        if (submitted && !output && !body.trim() && this.multiple && this.emptyError != null) {
          prompt2 += this.styles.danger(this.emptyError);
        }
        this.clear(size);
        this.write([header, prompt2, body, footer].filter(Boolean).join("\n"));
        this.write(this.margin[2]);
        this.restore();
      }
    };
    module2.exports = SelectPrompt;
  }
});

// ../../node_modules/enquirer/lib/prompts/autocomplete.js
var require_autocomplete = __commonJS({
  "../../node_modules/enquirer/lib/prompts/autocomplete.js"(exports2, module2) {
    "use strict";
    var Select2 = require_select();
    var highlight = /* @__PURE__ */ __name((input, color) => {
      const regex = input ? new RegExp(input, "ig") : /$^/;
      return (str) => {
        return input ? str.replace(regex, (match) => color(match)) : str;
      };
    }, "highlight");
    var AutoComplete = class extends Select2 {
      static {
        __name(this, "AutoComplete");
      }
      constructor(options) {
        super(options);
        this.cursorShow();
      }
      moveCursor(n10) {
        this.state.cursor += n10;
      }
      dispatch(ch) {
        return this.append(ch);
      }
      space(ch) {
        return this.options.multiple ? super.space(ch) : this.append(ch);
      }
      append(ch) {
        let { cursor: cursor3, input } = this.state;
        this.input = input.slice(0, cursor3) + ch + input.slice(cursor3);
        this.moveCursor(1);
        return this.complete();
      }
      delete() {
        let { cursor: cursor3, input } = this.state;
        if (!input) return this.alert();
        this.input = input.slice(0, cursor3 - 1) + input.slice(cursor3);
        this.moveCursor(-1);
        return this.complete();
      }
      deleteForward() {
        let { cursor: cursor3, input } = this.state;
        if (input[cursor3] === void 0) return this.alert();
        this.input = `${input}`.slice(0, cursor3) + `${input}`.slice(cursor3 + 1);
        return this.complete();
      }
      number(ch) {
        return this.append(ch);
      }
      async complete() {
        this.completing = true;
        this.choices = await this.suggest(this.input, this.state._choices);
        this.state.limit = void 0;
        this.index = Math.min(Math.max(this.visible.length - 1, 0), this.index);
        await this.render();
        this.completing = false;
      }
      suggest(input = this.input, choices = this.state._choices) {
        if (typeof this.options.suggest === "function") {
          return this.options.suggest.call(this, input, choices);
        }
        let str = input.toLowerCase();
        return choices.filter((ch) => ch.message.toLowerCase().includes(str));
      }
      pointer() {
        return "";
      }
      format() {
        if (!this.focused) return this.input;
        if (this.options.multiple && this.state.submitted) {
          return this.selected.map((ch) => this.styles.primary(ch.message)).join(", ");
        }
        if (this.state.submitted) {
          let value = this.value = this.input = this.focused.value;
          return this.styles.primary(value);
        }
        return this.input;
      }
      async render() {
        if (this.state.status !== "pending") return super.render();
        const hl = this.options.highlight || this.styles.complement;
        const style = /* @__PURE__ */ __name((input, color2) => {
          if (!input) return input;
          if (hl.stack) return hl(input);
          return hl.call(this, input);
        }, "style");
        const color = highlight(this.input, style);
        const choices = this.choices;
        this.choices = choices.map((ch) => ({ ...ch, message: color(ch.message) }));
        await super.render();
        this.choices = choices;
      }
      submit() {
        if (this.options.multiple) {
          this.value = this.selected.map((ch) => ch.name);
        }
        return super.submit();
      }
    };
    module2.exports = AutoComplete;
  }
});

// ../../node_modules/enquirer/lib/placeholder.js
var require_placeholder = __commonJS({
  "../../node_modules/enquirer/lib/placeholder.js"(exports2, module2) {
    "use strict";
    var utils = require_utils11();
    module2.exports = (prompt2, options = {}) => {
      prompt2.cursorHide();
      let { input = "", initial = "", pos, showCursor = true, color } = options;
      let style = color || prompt2.styles.placeholder;
      let inverse = utils.inverse(prompt2.styles.primary);
      let blinker = /* @__PURE__ */ __name((str) => inverse(prompt2.styles.black(str)), "blinker");
      let output = input;
      let char = " ";
      let reverse = blinker(char);
      if (prompt2.blink && prompt2.blink.off === true) {
        blinker = /* @__PURE__ */ __name((str) => str, "blinker");
        reverse = "";
      }
      if (showCursor && pos === 0 && initial === "" && input === "") {
        return blinker(char);
      }
      if (showCursor && pos === 0 && (input === initial || input === "")) {
        return blinker(initial[0]) + style(initial.slice(1));
      }
      initial = utils.isPrimitive(initial) ? `${initial}` : "";
      input = utils.isPrimitive(input) ? `${input}` : "";
      let placeholder = initial && initial.startsWith(input) && initial !== input;
      let cursor3 = placeholder ? blinker(initial[input.length]) : reverse;
      if (pos !== input.length && showCursor === true) {
        output = input.slice(0, pos) + blinker(input[pos]) + input.slice(pos + 1);
        cursor3 = "";
      }
      if (showCursor === false) {
        cursor3 = "";
      }
      if (placeholder) {
        let raw = prompt2.styles.unstyle(output + cursor3);
        return output + cursor3 + style(initial.slice(raw.length));
      }
      return output + cursor3;
    };
  }
});

// ../../node_modules/enquirer/lib/prompts/form.js
var require_form = __commonJS({
  "../../node_modules/enquirer/lib/prompts/form.js"(exports2, module2) {
    "use strict";
    var stripAnsi2 = require_strip_ansi();
    var SelectPrompt = require_select();
    var placeholder = require_placeholder();
    var FormPrompt = class extends SelectPrompt {
      static {
        __name(this, "FormPrompt");
      }
      constructor(options) {
        super({ ...options, multiple: true });
        this.type = "form";
        this.initial = this.options.initial;
        this.align = [this.options.align, "right"].find((v) => v != null);
        this.emptyError = "";
        this.values = {};
      }
      async reset(first) {
        await super.reset();
        if (first === true) this._index = this.index;
        this.index = this._index;
        this.values = {};
        this.choices.forEach((choice) => choice.reset && choice.reset());
        return this.render();
      }
      dispatch(char) {
        return !!char && this.append(char);
      }
      append(char) {
        let choice = this.focused;
        if (!choice) return this.alert();
        let { cursor: cursor3, input } = choice;
        choice.value = choice.input = input.slice(0, cursor3) + char + input.slice(cursor3);
        choice.cursor++;
        return this.render();
      }
      delete() {
        let choice = this.focused;
        if (!choice || choice.cursor <= 0) return this.alert();
        let { cursor: cursor3, input } = choice;
        choice.value = choice.input = input.slice(0, cursor3 - 1) + input.slice(cursor3);
        choice.cursor--;
        return this.render();
      }
      deleteForward() {
        let choice = this.focused;
        if (!choice) return this.alert();
        let { cursor: cursor3, input } = choice;
        if (input[cursor3] === void 0) return this.alert();
        let str = `${input}`.slice(0, cursor3) + `${input}`.slice(cursor3 + 1);
        choice.value = choice.input = str;
        return this.render();
      }
      right() {
        let choice = this.focused;
        if (!choice) return this.alert();
        if (choice.cursor >= choice.input.length) return this.alert();
        choice.cursor++;
        return this.render();
      }
      left() {
        let choice = this.focused;
        if (!choice) return this.alert();
        if (choice.cursor <= 0) return this.alert();
        choice.cursor--;
        return this.render();
      }
      space(ch, key) {
        return this.dispatch(ch, key);
      }
      number(ch, key) {
        return this.dispatch(ch, key);
      }
      next() {
        let ch = this.focused;
        if (!ch) return this.alert();
        let { initial, input } = ch;
        if (initial && initial.startsWith(input) && input !== initial) {
          ch.value = ch.input = initial;
          ch.cursor = ch.value.length;
          return this.render();
        }
        return super.next();
      }
      prev() {
        let ch = this.focused;
        if (!ch) return this.alert();
        if (ch.cursor === 0) return super.prev();
        ch.value = ch.input = "";
        ch.cursor = 0;
        return this.render();
      }
      separator() {
        return "";
      }
      format(value) {
        return !this.state.submitted ? super.format(value) : "";
      }
      pointer() {
        return "";
      }
      indicator(choice) {
        return choice.input ? "\u29BF" : "\u2299";
      }
      async choiceSeparator(choice, i32) {
        let sep7 = await this.resolve(choice.separator, this.state, choice, i32) || ":";
        return sep7 ? " " + this.styles.disabled(sep7) : "";
      }
      async renderChoice(choice, i32) {
        await this.onChoice(choice, i32);
        let { state: state13, styles } = this;
        let { cursor: cursor3, initial = "", name, input = "" } = choice;
        let { muted, submitted, primary, danger } = styles;
        let focused = this.index === i32;
        let validate = choice.validate || (() => true);
        let sep7 = await this.choiceSeparator(choice, i32);
        let msg = choice.message;
        if (this.align === "right") msg = msg.padStart(this.longest + 1, " ");
        if (this.align === "left") msg = msg.padEnd(this.longest + 1, " ");
        let value = this.values[name] = input || initial;
        let color = input ? "success" : "dark";
        if (await validate.call(choice, value, this.state) !== true) {
          color = "danger";
        }
        let style = styles[color];
        let indicator = style(await this.indicator(choice, i32)) + (choice.pad || "");
        let indent = this.indent(choice);
        let line = /* @__PURE__ */ __name(() => [indent, indicator, msg + sep7, input].filter(Boolean).join(" "), "line");
        if (state13.submitted) {
          msg = stripAnsi2(msg);
          input = submitted(input);
          return line();
        }
        if (choice.format) {
          input = await choice.format.call(this, input, choice, i32);
        } else {
          let color2 = this.styles.muted;
          let options = { input, initial, pos: cursor3, showCursor: focused, color: color2 };
          input = placeholder(this, options);
        }
        if (!this.isValue(input)) {
          input = this.styles.muted(this.symbols.ellipsis);
        }
        if (choice.result) {
          this.values[name] = await choice.result.call(this, value, choice, i32);
        }
        if (focused) {
          msg = primary(msg);
        }
        if (choice.error) {
          input += (input ? " " : "") + danger(choice.error.trim());
        } else if (choice.hint) {
          input += (input ? " " : "") + muted(choice.hint.trim());
        }
        return line();
      }
      async submit() {
        this.value = this.values;
        return super.base.submit.call(this);
      }
    };
    module2.exports = FormPrompt;
  }
});

// ../../node_modules/enquirer/lib/types/auth.js
var require_auth = __commonJS({
  "../../node_modules/enquirer/lib/types/auth.js"(exports2, module2) {
    "use strict";
    var FormPrompt = require_form();
    var defaultAuthenticate = /* @__PURE__ */ __name(() => {
      throw new Error("expected prompt to have a custom authenticate method");
    }, "defaultAuthenticate");
    var factory = /* @__PURE__ */ __name((authenticate = defaultAuthenticate) => {
      class AuthPrompt extends FormPrompt {
        static {
          __name(this, "AuthPrompt");
        }
        constructor(options) {
          super(options);
        }
        async submit() {
          this.value = await authenticate.call(this, this.values, this.state);
          super.base.submit.call(this);
        }
        static create(authenticate2) {
          return factory(authenticate2);
        }
      }
      return AuthPrompt;
    }, "factory");
    module2.exports = factory();
  }
});

// ../../node_modules/enquirer/lib/prompts/basicauth.js
var require_basicauth = __commonJS({
  "../../node_modules/enquirer/lib/prompts/basicauth.js"(exports2, module2) {
    "use strict";
    var AuthPrompt = require_auth();
    function defaultAuthenticate(value, state13) {
      if (value.username === this.options.username && value.password === this.options.password) {
        return true;
      }
      return false;
    }
    __name(defaultAuthenticate, "defaultAuthenticate");
    var factory = /* @__PURE__ */ __name((authenticate = defaultAuthenticate) => {
      const choices = [
        { name: "username", message: "username" },
        {
          name: "password",
          message: "password",
          format(input) {
            if (this.options.showPassword) {
              return input;
            }
            let color = this.state.submitted ? this.styles.primary : this.styles.muted;
            return color(this.symbols.asterisk.repeat(input.length));
          }
        }
      ];
      class BasicAuthPrompt extends AuthPrompt.create(authenticate) {
        static {
          __name(this, "BasicAuthPrompt");
        }
        constructor(options) {
          super({ ...options, choices });
        }
        static create(authenticate2) {
          return factory(authenticate2);
        }
      }
      return BasicAuthPrompt;
    }, "factory");
    module2.exports = factory();
  }
});

// ../../node_modules/enquirer/lib/types/boolean.js
var require_boolean = __commonJS({
  "../../node_modules/enquirer/lib/types/boolean.js"(exports2, module2) {
    "use strict";
    var Prompt = require_prompt2();
    var { isPrimitive, hasColor } = require_utils11();
    var BooleanPrompt = class extends Prompt {
      static {
        __name(this, "BooleanPrompt");
      }
      constructor(options) {
        super(options);
        this.cursorHide();
      }
      async initialize() {
        let initial = await this.resolve(this.initial, this.state);
        this.input = await this.cast(initial);
        await super.initialize();
      }
      dispatch(ch) {
        if (!this.isValue(ch)) return this.alert();
        this.input = ch;
        return this.submit();
      }
      format(value) {
        let { styles, state: state13 } = this;
        return !state13.submitted ? styles.primary(value) : styles.success(value);
      }
      cast(input) {
        return this.isTrue(input);
      }
      isTrue(input) {
        return /^[ty1]/i.test(input);
      }
      isFalse(input) {
        return /^[fn0]/i.test(input);
      }
      isValue(value) {
        return isPrimitive(value) && (this.isTrue(value) || this.isFalse(value));
      }
      async hint() {
        if (this.state.status === "pending") {
          let hint = await this.element("hint");
          if (!hasColor(hint)) {
            return this.styles.muted(hint);
          }
          return hint;
        }
      }
      async render() {
        let { input, size } = this.state;
        let prefix = await this.prefix();
        let sep7 = await this.separator();
        let msg = await this.message();
        let hint = this.styles.muted(this.default);
        let promptLine = [prefix, msg, hint, sep7].filter(Boolean).join(" ");
        this.state.prompt = promptLine;
        let header = await this.header();
        let value = this.value = this.cast(input);
        let output = await this.format(value);
        let help = await this.error() || await this.hint();
        let footer = await this.footer();
        if (help && !promptLine.includes(help)) output += " " + help;
        promptLine += " " + output;
        this.clear(size);
        this.write([header, promptLine, footer].filter(Boolean).join("\n"));
        this.restore();
      }
      set value(value) {
        super.value = value;
      }
      get value() {
        return this.cast(super.value);
      }
    };
    module2.exports = BooleanPrompt;
  }
});

// ../../node_modules/enquirer/lib/prompts/confirm.js
var require_confirm = __commonJS({
  "../../node_modules/enquirer/lib/prompts/confirm.js"(exports2, module2) {
    "use strict";
    var BooleanPrompt = require_boolean();
    var ConfirmPrompt = class extends BooleanPrompt {
      static {
        __name(this, "ConfirmPrompt");
      }
      constructor(options) {
        super(options);
        this.default = this.options.default || (this.initial ? "(Y/n)" : "(y/N)");
      }
    };
    module2.exports = ConfirmPrompt;
  }
});

// ../../node_modules/enquirer/lib/prompts/editable.js
var require_editable = __commonJS({
  "../../node_modules/enquirer/lib/prompts/editable.js"(exports2, module2) {
    "use strict";
    var Select2 = require_select();
    var Form = require_form();
    var form = Form.prototype;
    var Editable = class extends Select2 {
      static {
        __name(this, "Editable");
      }
      constructor(options) {
        super({ ...options, multiple: true });
        this.align = [this.options.align, "left"].find((v) => v != null);
        this.emptyError = "";
        this.values = {};
      }
      dispatch(char, key) {
        let choice = this.focused;
        let parent = choice.parent || {};
        if (!choice.editable && !parent.editable) {
          if (char === "a" || char === "i") return super[char]();
        }
        return form.dispatch.call(this, char, key);
      }
      append(char, key) {
        return form.append.call(this, char, key);
      }
      delete(char, key) {
        return form.delete.call(this, char, key);
      }
      space(char) {
        return this.focused.editable ? this.append(char) : super.space();
      }
      number(char) {
        return this.focused.editable ? this.append(char) : super.number(char);
      }
      next() {
        return this.focused.editable ? form.next.call(this) : super.next();
      }
      prev() {
        return this.focused.editable ? form.prev.call(this) : super.prev();
      }
      async indicator(choice, i32) {
        let symbol = choice.indicator || "";
        let value = choice.editable ? symbol : super.indicator(choice, i32);
        return await this.resolve(value, this.state, choice, i32) || "";
      }
      indent(choice) {
        return choice.role === "heading" ? "" : choice.editable ? " " : "  ";
      }
      async renderChoice(choice, i32) {
        choice.indent = "";
        if (choice.editable) return form.renderChoice.call(this, choice, i32);
        return super.renderChoice(choice, i32);
      }
      error() {
        return "";
      }
      footer() {
        return this.state.error;
      }
      async validate() {
        let result2 = true;
        for (let choice of this.choices) {
          if (typeof choice.validate !== "function") {
            continue;
          }
          if (choice.role === "heading") {
            continue;
          }
          let val = choice.parent ? this.value[choice.parent.name] : this.value;
          if (choice.editable) {
            val = choice.value === choice.name ? choice.initial || "" : choice.value;
          } else if (!this.isDisabled(choice)) {
            val = choice.enabled === true;
          }
          result2 = await choice.validate(val, this.state);
          if (result2 !== true) {
            break;
          }
        }
        if (result2 !== true) {
          this.state.error = typeof result2 === "string" ? result2 : "Invalid Input";
        }
        return result2;
      }
      submit() {
        if (this.focused.newChoice === true) return super.submit();
        if (this.choices.some((ch) => ch.newChoice)) {
          return this.alert();
        }
        this.value = {};
        for (let choice of this.choices) {
          let val = choice.parent ? this.value[choice.parent.name] : this.value;
          if (choice.role === "heading") {
            this.value[choice.name] = {};
            continue;
          }
          if (choice.editable) {
            val[choice.name] = choice.value === choice.name ? choice.initial || "" : choice.value;
          } else if (!this.isDisabled(choice)) {
            val[choice.name] = choice.enabled === true;
          }
        }
        return this.base.submit.call(this);
      }
    };
    module2.exports = Editable;
  }
});

// ../../node_modules/enquirer/lib/types/string.js
var require_string3 = __commonJS({
  "../../node_modules/enquirer/lib/types/string.js"(exports2, module2) {
    "use strict";
    var Prompt = require_prompt2();
    var keypress = require_keypress();
    var placeholder = require_placeholder();
    var { isPrimitive } = require_utils11();
    var StringPrompt = class extends Prompt {
      static {
        __name(this, "StringPrompt");
      }
      constructor(options) {
        super(options);
        this.initial = isPrimitive(this.initial) ? String(this.initial) : "";
        if (this.initial) this.cursorHide();
        this.state.prevCursor = 0;
        this.state.clipboard = [];
        this.keypressTimeout = this.options.keypressTimeout !== void 0 ? this.options.keypressTimeout : null;
      }
      async keypress(input, key = input ? keypress(input, {}) : {}) {
        const now = Date.now();
        const elapsed = now - this.lastKeypress;
        this.lastKeypress = now;
        const isEnterKey = key.name === "return" || key.name === "enter";
        let prev = this.state.prevKeypress;
        let append;
        this.state.prevKeypress = key;
        if (this.keypressTimeout != null && isEnterKey) {
          if (elapsed < this.keypressTimeout) {
            return this.submit();
          }
          this.state.multilineBuffer = this.state.multilineBuffer || "";
          this.state.multilineBuffer += input;
          append = true;
          prev = null;
        }
        if (append || this.options.multiline && isEnterKey) {
          if (!prev || prev.name !== "return") {
            return this.append("\n", key);
          }
        }
        return super.keypress(input, key);
      }
      moveCursor(n10) {
        this.cursor += n10;
      }
      reset() {
        this.input = this.value = "";
        this.cursor = 0;
        return this.render();
      }
      dispatch(ch, key) {
        if (!ch || key.ctrl || key.code) return this.alert();
        this.append(ch);
      }
      append(ch) {
        let { cursor: cursor3, input } = this.state;
        this.input = `${input}`.slice(0, cursor3) + ch + `${input}`.slice(cursor3);
        this.moveCursor(String(ch).length);
        this.render();
      }
      insert(str) {
        this.append(str);
      }
      delete() {
        let { cursor: cursor3, input } = this.state;
        if (cursor3 <= 0) return this.alert();
        this.input = `${input}`.slice(0, cursor3 - 1) + `${input}`.slice(cursor3);
        this.moveCursor(-1);
        this.render();
      }
      deleteForward() {
        let { cursor: cursor3, input } = this.state;
        if (input[cursor3] === void 0) return this.alert();
        this.input = `${input}`.slice(0, cursor3) + `${input}`.slice(cursor3 + 1);
        this.render();
      }
      cutForward() {
        let pos = this.cursor;
        if (this.input.length <= pos) return this.alert();
        this.state.clipboard.push(this.input.slice(pos));
        this.input = this.input.slice(0, pos);
        this.render();
      }
      cutLeft() {
        let pos = this.cursor;
        if (pos === 0) return this.alert();
        let before = this.input.slice(0, pos);
        let after = this.input.slice(pos);
        let words = before.split(" ");
        this.state.clipboard.push(words.pop());
        this.input = words.join(" ");
        this.cursor = this.input.length;
        this.input += after;
        this.render();
      }
      paste() {
        if (!this.state.clipboard.length) return this.alert();
        this.insert(this.state.clipboard.pop());
        this.render();
      }
      toggleCursor() {
        if (this.state.prevCursor) {
          this.cursor = this.state.prevCursor;
          this.state.prevCursor = 0;
        } else {
          this.state.prevCursor = this.cursor;
          this.cursor = 0;
        }
        this.render();
      }
      first() {
        this.cursor = 0;
        this.render();
      }
      last() {
        this.cursor = this.input.length - 1;
        this.render();
      }
      next() {
        let init = this.initial != null ? String(this.initial) : "";
        if (!init || !init.startsWith(this.input)) return this.alert();
        this.input = this.initial;
        this.cursor = this.initial.length;
        this.render();
      }
      prev() {
        if (!this.input) return this.alert();
        this.reset();
      }
      backward() {
        return this.left();
      }
      forward() {
        return this.right();
      }
      right() {
        if (this.cursor >= this.input.length) return this.alert();
        this.moveCursor(1);
        return this.render();
      }
      left() {
        if (this.cursor <= 0) return this.alert();
        this.moveCursor(-1);
        return this.render();
      }
      isValue(value) {
        return !!value;
      }
      async format(input = this.value) {
        let initial = await this.resolve(this.initial, this.state);
        if (!this.state.submitted) {
          return placeholder(this, { input, initial, pos: this.cursor });
        }
        return this.styles.submitted(input || initial);
      }
      async render() {
        let size = this.state.size;
        let prefix = await this.prefix();
        let separator = await this.separator();
        let message2 = await this.message();
        let prompt2 = [prefix, message2, separator].filter(Boolean).join(" ");
        this.state.prompt = prompt2;
        let header = await this.header();
        let output = await this.format();
        let help = await this.error() || await this.hint();
        let footer = await this.footer();
        if (help && !output.includes(help)) output += " " + help;
        prompt2 += " " + output;
        this.clear(size);
        this.write([header, prompt2, footer].filter(Boolean).join("\n"));
        this.restore();
      }
    };
    module2.exports = StringPrompt;
  }
});

// ../../node_modules/enquirer/lib/completer.js
var require_completer = __commonJS({
  "../../node_modules/enquirer/lib/completer.js"(exports2, module2) {
    "use strict";
    var unique = /* @__PURE__ */ __name((arr) => arr.filter((v, i32) => arr.lastIndexOf(v) === i32), "unique");
    var compact = /* @__PURE__ */ __name((arr) => unique(arr).filter(Boolean), "compact");
    module2.exports = (action, data3 = {}, value = "") => {
      let { past = [], present = "" } = data3;
      let rest, prev;
      switch (action) {
        case "prev":
        case "undo":
          rest = past.slice(0, past.length - 1);
          prev = past[past.length - 1] || "";
          return {
            past: compact([value, ...rest]),
            present: prev
          };
        case "next":
        case "redo":
          rest = past.slice(1);
          prev = past[0] || "";
          return {
            past: compact([...rest, value]),
            present: prev
          };
        case "save":
          return {
            past: compact([...past, value]),
            present: ""
          };
        case "remove":
          prev = compact(past.filter((v) => v !== value));
          present = "";
          if (prev.length) {
            present = prev.pop();
          }
          return {
            past: prev,
            present
          };
        default: {
          throw new Error(`Invalid action: "${action}"`);
        }
      }
    };
  }
});

// ../../node_modules/enquirer/lib/prompts/input.js
var require_input = __commonJS({
  "../../node_modules/enquirer/lib/prompts/input.js"(exports2, module2) {
    "use strict";
    var Prompt = require_string3();
    var completer = require_completer();
    var Input = class extends Prompt {
      static {
        __name(this, "Input");
      }
      constructor(options) {
        super(options);
        let history = this.options.history;
        if (history && history.store) {
          let initial = history.values || this.initial;
          this.autosave = !!history.autosave;
          this.store = history.store;
          this.data = this.store.get("values") || { past: [], present: initial };
          this.initial = this.data.present || this.data.past[this.data.past.length - 1];
        }
      }
      completion(action) {
        if (!this.store) return this.alert();
        this.data = completer(action, this.data, this.input);
        if (!this.data.present) return this.alert();
        this.input = this.data.present;
        this.cursor = this.input.length;
        return this.render();
      }
      altUp() {
        return this.completion("prev");
      }
      altDown() {
        return this.completion("next");
      }
      prev() {
        this.save();
        return super.prev();
      }
      save() {
        if (!this.store) return;
        this.data = completer("save", this.data, this.input);
        this.store.set("values", this.data);
      }
      submit() {
        if (this.store && this.autosave === true) {
          this.save();
        }
        return super.submit();
      }
    };
    module2.exports = Input;
  }
});

// ../../node_modules/enquirer/lib/prompts/invisible.js
var require_invisible = __commonJS({
  "../../node_modules/enquirer/lib/prompts/invisible.js"(exports2, module2) {
    "use strict";
    var StringPrompt = require_string3();
    var InvisiblePrompt = class extends StringPrompt {
      static {
        __name(this, "InvisiblePrompt");
      }
      format() {
        return "";
      }
    };
    module2.exports = InvisiblePrompt;
  }
});

// ../../node_modules/enquirer/lib/prompts/list.js
var require_list = __commonJS({
  "../../node_modules/enquirer/lib/prompts/list.js"(exports2, module2) {
    "use strict";
    var StringPrompt = require_string3();
    var ListPrompt = class extends StringPrompt {
      static {
        __name(this, "ListPrompt");
      }
      constructor(options = {}) {
        super(options);
        this.sep = this.options.separator || /, */;
        this.initial = options.initial || "";
      }
      split(input = this.value) {
        return input ? String(input).split(this.sep) : [];
      }
      format() {
        let style = this.state.submitted ? this.styles.primary : (val) => val;
        return this.list.map(style).join(", ");
      }
      async submit(value) {
        let result2 = this.state.error || await this.validate(this.list, this.state);
        if (result2 !== true) {
          this.state.error = result2;
          return super.submit();
        }
        this.value = this.list;
        return super.submit();
      }
      get list() {
        return this.split();
      }
    };
    module2.exports = ListPrompt;
  }
});

// ../../node_modules/enquirer/lib/prompts/multiselect.js
var require_multiselect = __commonJS({
  "../../node_modules/enquirer/lib/prompts/multiselect.js"(exports2, module2) {
    "use strict";
    var Select2 = require_select();
    var MultiSelect = class extends Select2 {
      static {
        __name(this, "MultiSelect");
      }
      constructor(options) {
        super({ ...options, multiple: true });
      }
    };
    module2.exports = MultiSelect;
  }
});

// ../../node_modules/enquirer/lib/types/number.js
var require_number = __commonJS({
  "../../node_modules/enquirer/lib/types/number.js"(exports2, module2) {
    "use strict";
    var StringPrompt = require_string3();
    var NumberPrompt = class extends StringPrompt {
      static {
        __name(this, "NumberPrompt");
      }
      constructor(options = {}) {
        super({ style: "number", ...options });
        this.min = this.isValue(options.min) ? this.toNumber(options.min) : -Infinity;
        this.max = this.isValue(options.max) ? this.toNumber(options.max) : Infinity;
        this.delay = options.delay != null ? options.delay : 1e3;
        this.float = options.float !== false;
        this.round = options.round === true || options.float === false;
        this.major = options.major || 10;
        this.minor = options.minor || 1;
        this.initial = options.initial != null ? options.initial : "";
        this.input = String(this.initial);
        this.cursor = this.input.length;
        this.cursorShow();
      }
      append(ch) {
        if (!/[-+.]/.test(ch) || ch === "." && this.input.includes(".")) {
          return this.alert("invalid number");
        }
        return super.append(ch);
      }
      number(ch) {
        return super.append(ch);
      }
      next() {
        if (this.input && this.input !== this.initial) return this.alert();
        if (!this.isValue(this.initial)) return this.alert();
        this.input = this.initial;
        this.cursor = String(this.initial).length;
        return this.render();
      }
      up(number) {
        let step = number || this.minor;
        let num = this.toNumber(this.input);
        if (num > this.max + step) return this.alert();
        this.input = `${num + step}`;
        return this.render();
      }
      down(number) {
        let step = number || this.minor;
        let num = this.toNumber(this.input);
        if (num < this.min - step) return this.alert();
        this.input = `${num - step}`;
        return this.render();
      }
      shiftDown() {
        return this.down(this.major);
      }
      shiftUp() {
        return this.up(this.major);
      }
      format(input = this.input) {
        if (typeof this.options.format === "function") {
          return this.options.format.call(this, input);
        }
        return this.styles.info(input);
      }
      toNumber(value = "") {
        return this.float ? +value : Math.round(+value);
      }
      isValue(value) {
        return /^[-+]?[0-9]+((\.)|(\.[0-9]+))?$/.test(value);
      }
      submit() {
        let value = [this.input, this.initial].find((v) => this.isValue(v));
        this.value = this.toNumber(value || 0);
        return super.submit();
      }
    };
    module2.exports = NumberPrompt;
  }
});

// ../../node_modules/enquirer/lib/prompts/numeral.js
var require_numeral = __commonJS({
  "../../node_modules/enquirer/lib/prompts/numeral.js"(exports2, module2) {
    module2.exports = require_number();
  }
});

// ../../node_modules/enquirer/lib/prompts/password.js
var require_password = __commonJS({
  "../../node_modules/enquirer/lib/prompts/password.js"(exports2, module2) {
    "use strict";
    var StringPrompt = require_string3();
    var PasswordPrompt = class extends StringPrompt {
      static {
        __name(this, "PasswordPrompt");
      }
      constructor(options) {
        super(options);
        this.cursorShow();
      }
      format(input = this.input) {
        if (!this.keypressed) return "";
        let color = this.state.submitted ? this.styles.primary : this.styles.muted;
        return color(this.symbols.asterisk.repeat(input.length));
      }
    };
    module2.exports = PasswordPrompt;
  }
});

// ../../node_modules/enquirer/lib/prompts/scale.js
var require_scale = __commonJS({
  "../../node_modules/enquirer/lib/prompts/scale.js"(exports2, module2) {
    "use strict";
    var stripAnsi2 = require_strip_ansi();
    var ArrayPrompt = require_array3();
    var utils = require_utils11();
    var LikertScale = class extends ArrayPrompt {
      static {
        __name(this, "LikertScale");
      }
      constructor(options = {}) {
        super(options);
        this.widths = [].concat(options.messageWidth || 50);
        this.align = [].concat(options.align || "left");
        this.linebreak = options.linebreak || false;
        this.edgeLength = options.edgeLength || 3;
        this.newline = options.newline || "\n   ";
        let start = options.startNumber || 1;
        if (typeof this.scale === "number") {
          this.scaleKey = false;
          this.scale = Array(this.scale).fill(0).map((v, i32) => ({ name: i32 + start }));
        }
      }
      async reset() {
        this.tableized = false;
        await super.reset();
        return this.render();
      }
      tableize() {
        if (this.tableized === true) return;
        this.tableized = true;
        let longest = 0;
        for (let ch of this.choices) {
          longest = Math.max(longest, ch.message.length);
          ch.scaleIndex = ch.initial || 2;
          ch.scale = [];
          for (let i32 = 0; i32 < this.scale.length; i32++) {
            ch.scale.push({ index: i32 });
          }
        }
        this.widths[0] = Math.min(this.widths[0], longest + 3);
      }
      async dispatch(s, key) {
        if (this.multiple) {
          return this[key.name] ? await this[key.name](s, key) : await super.dispatch(s, key);
        }
        this.alert();
      }
      heading(msg, item, i32) {
        return this.styles.strong(msg);
      }
      separator() {
        return this.styles.muted(this.symbols.ellipsis);
      }
      right() {
        let choice = this.focused;
        if (choice.scaleIndex >= this.scale.length - 1) return this.alert();
        choice.scaleIndex++;
        return this.render();
      }
      left() {
        let choice = this.focused;
        if (choice.scaleIndex <= 0) return this.alert();
        choice.scaleIndex--;
        return this.render();
      }
      indent() {
        return "";
      }
      format() {
        if (this.state.submitted) {
          let values = this.choices.map((ch) => this.styles.info(ch.index));
          return values.join(", ");
        }
        return "";
      }
      pointer() {
        return "";
      }
      /**
       * Render the scale "Key". Something like:
       * @return {String}
       */
      renderScaleKey() {
        if (this.scaleKey === false) return "";
        if (this.state.submitted) return "";
        let scale = this.scale.map((item) => `   ${item.name} - ${item.message}`);
        let key = ["", ...scale].map((item) => this.styles.muted(item));
        return key.join("\n");
      }
      /**
       * Render the heading row for the scale.
       * @return {String}
       */
      renderScaleHeading(max) {
        let keys = this.scale.map((ele) => ele.name);
        if (typeof this.options.renderScaleHeading === "function") {
          keys = this.options.renderScaleHeading.call(this, max);
        }
        let diff = this.scaleLength - keys.join("").length;
        let spacing = Math.round(diff / (keys.length - 1));
        let names = keys.map((key) => this.styles.strong(key));
        let headings = names.join(" ".repeat(spacing));
        let padding = " ".repeat(this.widths[0]);
        return this.margin[3] + padding + this.margin[1] + headings;
      }
      /**
       * Render a scale indicator => ◯ or ◉ by default
       */
      scaleIndicator(choice, item, i32) {
        if (typeof this.options.scaleIndicator === "function") {
          return this.options.scaleIndicator.call(this, choice, item, i32);
        }
        let enabled = choice.scaleIndex === item.index;
        if (item.disabled) return this.styles.hint(this.symbols.radio.disabled);
        if (enabled) return this.styles.success(this.symbols.radio.on);
        return this.symbols.radio.off;
      }
      /**
       * Render the actual scale => ◯────◯────◉────◯────◯
       */
      renderScale(choice, i32) {
        let scale = choice.scale.map((item) => this.scaleIndicator(choice, item, i32));
        let padding = this.term === "Hyper" ? "" : " ";
        return scale.join(padding + this.symbols.line.repeat(this.edgeLength));
      }
      /**
       * Render a choice, including scale =>
       *   "The website is easy to navigate. ◯───◯───◉───◯───◯"
       */
      async renderChoice(choice, i32) {
        await this.onChoice(choice, i32);
        let focused = this.index === i32;
        let pointer = await this.pointer(choice, i32);
        let hint = await choice.hint;
        if (hint && !utils.hasColor(hint)) {
          hint = this.styles.muted(hint);
        }
        let pad = /* @__PURE__ */ __name((str) => this.margin[3] + str.replace(/\s+$/, "").padEnd(this.widths[0], " "), "pad");
        let newline = this.newline;
        let ind = this.indent(choice);
        let message2 = await this.resolve(choice.message, this.state, choice, i32);
        let scale = await this.renderScale(choice, i32);
        let margin = this.margin[1] + this.margin[3];
        this.scaleLength = stripAnsi2(scale).length;
        this.widths[0] = Math.min(this.widths[0], this.width - this.scaleLength - margin.length);
        let msg = utils.wordWrap(message2, { width: this.widths[0], newline });
        let lines = msg.split("\n").map((line) => pad(line) + this.margin[1]);
        if (focused) {
          scale = this.styles.info(scale);
          lines = lines.map((line) => this.styles.info(line));
        }
        lines[0] += scale;
        if (this.linebreak) lines.push("");
        return [ind + pointer, lines.join("\n")].filter(Boolean);
      }
      async renderChoices() {
        if (this.state.submitted) return "";
        this.tableize();
        let choices = this.visible.map(async (ch, i32) => await this.renderChoice(ch, i32));
        let visible = await Promise.all(choices);
        let heading = await this.renderScaleHeading();
        return this.margin[0] + [heading, ...visible.map((v) => v.join(" "))].join("\n");
      }
      async render() {
        let { submitted, size } = this.state;
        let prefix = await this.prefix();
        let separator = await this.separator();
        let message2 = await this.message();
        let prompt2 = "";
        if (this.options.promptLine !== false) {
          prompt2 = [prefix, message2, separator, ""].join(" ");
          this.state.prompt = prompt2;
        }
        let header = await this.header();
        let output = await this.format();
        let key = await this.renderScaleKey();
        let help = await this.error() || await this.hint();
        let body = await this.renderChoices();
        let footer = await this.footer();
        let err = this.emptyError;
        if (output) prompt2 += output;
        if (help && !prompt2.includes(help)) prompt2 += " " + help;
        if (submitted && !output && !body.trim() && this.multiple && err != null) {
          prompt2 += this.styles.danger(err);
        }
        this.clear(size);
        this.write([header, prompt2, key, body, footer].filter(Boolean).join("\n"));
        if (!this.state.submitted) {
          this.write(this.margin[2]);
        }
        this.restore();
      }
      submit() {
        this.value = {};
        for (let choice of this.choices) {
          this.value[choice.name] = choice.scaleIndex;
        }
        return this.base.submit.call(this);
      }
    };
    module2.exports = LikertScale;
  }
});

// ../../node_modules/enquirer/lib/interpolate.js
var require_interpolate = __commonJS({
  "../../node_modules/enquirer/lib/interpolate.js"(exports2, module2) {
    "use strict";
    var stripAnsi2 = require_strip_ansi();
    var clean = /* @__PURE__ */ __name((str = "") => {
      return typeof str === "string" ? str.replace(/^['"]|['"]$/g, "") : "";
    }, "clean");
    var Item = class {
      static {
        __name(this, "Item");
      }
      constructor(token) {
        this.name = token.key;
        this.field = token.field || {};
        this.value = clean(token.initial || this.field.initial || "");
        this.message = token.message || this.name;
        this.cursor = 0;
        this.input = "";
        this.lines = [];
      }
    };
    var tokenize = /* @__PURE__ */ __name(async (options = {}, defaults = {}, fn = (token) => token) => {
      let unique = /* @__PURE__ */ new Set();
      let fields = options.fields || [];
      let input = options.template;
      let tabstops = [];
      let items = [];
      let keys = [];
      let line = 1;
      if (typeof input === "function") {
        input = await input();
      }
      let i32 = -1;
      let next = /* @__PURE__ */ __name(() => input[++i32], "next");
      let peek = /* @__PURE__ */ __name(() => input[i32 + 1], "peek");
      let push = /* @__PURE__ */ __name((token) => {
        token.line = line;
        tabstops.push(token);
      }, "push");
      push({ type: "bos", value: "" });
      while (i32 < input.length - 1) {
        let value = next();
        if (/^[^\S\n ]$/.test(value)) {
          push({ type: "text", value });
          continue;
        }
        if (value === "\n") {
          push({ type: "newline", value });
          line++;
          continue;
        }
        if (value === "\\") {
          value += next();
          push({ type: "text", value });
          continue;
        }
        if ((value === "$" || value === "#" || value === "{") && peek() === "{") {
          let n10 = next();
          value += n10;
          let token = { type: "template", open: value, inner: "", close: "", value };
          let ch;
          while (ch = next()) {
            if (ch === "}") {
              if (peek() === "}") ch += next();
              token.value += ch;
              token.close = ch;
              break;
            }
            if (ch === ":") {
              token.initial = "";
              token.key = token.inner;
            } else if (token.initial !== void 0) {
              token.initial += ch;
            }
            token.value += ch;
            token.inner += ch;
          }
          token.template = token.open + (token.initial || token.inner) + token.close;
          token.key = token.key || token.inner;
          if (hasOwnProperty.call(defaults, token.key)) {
            token.initial = defaults[token.key];
          }
          token = fn(token);
          push(token);
          keys.push(token.key);
          unique.add(token.key);
          let item = items.find((item2) => item2.name === token.key);
          token.field = fields.find((ch2) => ch2.name === token.key);
          if (!item) {
            item = new Item(token);
            items.push(item);
          }
          item.lines.push(token.line - 1);
          continue;
        }
        let last = tabstops[tabstops.length - 1];
        if (last.type === "text" && last.line === line) {
          last.value += value;
        } else {
          push({ type: "text", value });
        }
      }
      push({ type: "eos", value: "" });
      return { input, tabstops, unique, keys, items };
    }, "tokenize");
    module2.exports = async (prompt2) => {
      let options = prompt2.options;
      let required = new Set(options.required === true ? [] : options.required || []);
      let defaults = { ...options.values, ...options.initial };
      let { tabstops, items, keys } = await tokenize(options, defaults);
      let result2 = createFn("result", prompt2, options);
      let format32 = createFn("format", prompt2, options);
      let isValid = createFn("validate", prompt2, options, true);
      let isVal = prompt2.isValue.bind(prompt2);
      return async (state13 = {}, submitted = false) => {
        let index = 0;
        state13.required = required;
        state13.items = items;
        state13.keys = keys;
        state13.output = "";
        let validate = /* @__PURE__ */ __name(async (value, state14, item, index2) => {
          let error4 = await isValid(value, state14, item, index2);
          if (error4 === false) {
            return "Invalid field " + item.name;
          }
          return error4;
        }, "validate");
        for (let token of tabstops) {
          let value = token.value;
          let key = token.key;
          if (token.type !== "template") {
            if (value) state13.output += value;
            continue;
          }
          if (token.type === "template") {
            let item = items.find((ch) => ch.name === key);
            if (options.required === true) {
              state13.required.add(item.name);
            }
            let val = [item.input, state13.values[item.value], item.value, value].find(isVal);
            let field = item.field || {};
            let message2 = field.message || token.inner;
            if (submitted) {
              let error4 = await validate(state13.values[key], state13, item, index);
              if (error4 && typeof error4 === "string" || error4 === false) {
                state13.invalid.set(key, error4);
                continue;
              }
              state13.invalid.delete(key);
              let res = await result2(state13.values[key], state13, item, index);
              state13.output += stripAnsi2(res);
              continue;
            }
            item.placeholder = false;
            let before = value;
            value = await format32(value, state13, item, index);
            if (val !== value) {
              state13.values[key] = val;
              value = prompt2.styles.typing(val);
              state13.missing.delete(message2);
            } else {
              state13.values[key] = void 0;
              val = `<${message2}>`;
              value = prompt2.styles.primary(val);
              item.placeholder = true;
              if (state13.required.has(key)) {
                state13.missing.add(message2);
              }
            }
            if (state13.missing.has(message2) && state13.validating) {
              value = prompt2.styles.warning(val);
            }
            if (state13.invalid.has(key) && state13.validating) {
              value = prompt2.styles.danger(val);
            }
            if (index === state13.index) {
              if (before !== value) {
                value = prompt2.styles.underline(value);
              } else {
                value = prompt2.styles.heading(stripAnsi2(value));
              }
            }
            index++;
          }
          if (value) {
            state13.output += value;
          }
        }
        let lines = state13.output.split("\n").map((l20) => " " + l20);
        let len = items.length;
        let done = 0;
        for (let item of items) {
          if (state13.invalid.has(item.name)) {
            item.lines.forEach((i32) => {
              if (lines[i32][0] !== " ") return;
              lines[i32] = state13.styles.danger(state13.symbols.bullet) + lines[i32].slice(1);
            });
          }
          if (prompt2.isValue(state13.values[item.name])) {
            done++;
          }
        }
        state13.completed = (done / len * 100).toFixed(0);
        state13.output = lines.join("\n");
        return state13.output;
      };
    };
    function createFn(prop, prompt2, options, fallback2) {
      return (value, state13, item, index) => {
        if (typeof item.field[prop] === "function") {
          return item.field[prop].call(prompt2, value, state13, item, index);
        }
        return [fallback2, value].find((v) => prompt2.isValue(v));
      };
    }
    __name(createFn, "createFn");
  }
});

// ../../node_modules/enquirer/lib/prompts/snippet.js
var require_snippet = __commonJS({
  "../../node_modules/enquirer/lib/prompts/snippet.js"(exports2, module2) {
    "use strict";
    var stripAnsi2 = require_strip_ansi();
    var interpolate = require_interpolate();
    var Prompt = require_prompt2();
    var SnippetPrompt = class extends Prompt {
      static {
        __name(this, "SnippetPrompt");
      }
      constructor(options) {
        super(options);
        this.cursorHide();
        this.reset(true);
      }
      async initialize() {
        this.interpolate = await interpolate(this);
        await super.initialize();
      }
      async reset(first) {
        this.state.keys = [];
        this.state.invalid = /* @__PURE__ */ new Map();
        this.state.missing = /* @__PURE__ */ new Set();
        this.state.completed = 0;
        this.state.values = {};
        if (first !== true) {
          await this.initialize();
          await this.render();
        }
      }
      moveCursor(n10) {
        let item = this.getItem();
        this.cursor += n10;
        item.cursor += n10;
      }
      dispatch(ch, key) {
        if (!key.code && !key.ctrl && ch != null && this.getItem()) {
          this.append(ch, key);
          return;
        }
        this.alert();
      }
      append(ch, key) {
        let item = this.getItem();
        let prefix = item.input.slice(0, this.cursor);
        let suffix = item.input.slice(this.cursor);
        this.input = item.input = `${prefix}${ch}${suffix}`;
        this.moveCursor(1);
        this.render();
      }
      delete() {
        let item = this.getItem();
        if (this.cursor <= 0 || !item.input) return this.alert();
        let suffix = item.input.slice(this.cursor);
        let prefix = item.input.slice(0, this.cursor - 1);
        this.input = item.input = `${prefix}${suffix}`;
        this.moveCursor(-1);
        this.render();
      }
      increment(i32) {
        return i32 >= this.state.keys.length - 1 ? 0 : i32 + 1;
      }
      decrement(i32) {
        return i32 <= 0 ? this.state.keys.length - 1 : i32 - 1;
      }
      first() {
        this.state.index = 0;
        this.render();
      }
      last() {
        this.state.index = this.state.keys.length - 1;
        this.render();
      }
      right() {
        if (this.cursor >= this.input.length) return this.alert();
        this.moveCursor(1);
        this.render();
      }
      left() {
        if (this.cursor <= 0) return this.alert();
        this.moveCursor(-1);
        this.render();
      }
      prev() {
        this.state.index = this.decrement(this.state.index);
        this.getItem();
        this.render();
      }
      next() {
        this.state.index = this.increment(this.state.index);
        this.getItem();
        this.render();
      }
      up() {
        this.prev();
      }
      down() {
        this.next();
      }
      format(value) {
        let color = this.state.completed < 100 ? this.styles.warning : this.styles.success;
        if (this.state.submitted === true && this.state.completed !== 100) {
          color = this.styles.danger;
        }
        return color(`${this.state.completed}% completed`);
      }
      async render() {
        let { index, keys = [], submitted, size } = this.state;
        let newline = [this.options.newline, "\n"].find((v) => v != null);
        let prefix = await this.prefix();
        let separator = await this.separator();
        let message2 = await this.message();
        let prompt2 = [prefix, message2, separator].filter(Boolean).join(" ");
        this.state.prompt = prompt2;
        let header = await this.header();
        let error4 = await this.error() || "";
        let hint = await this.hint() || "";
        let body = submitted ? "" : await this.interpolate(this.state);
        let key = this.state.key = keys[index] || "";
        let input = await this.format(key);
        let footer = await this.footer();
        if (input) prompt2 += " " + input;
        if (hint && !input && this.state.completed === 0) prompt2 += " " + hint;
        this.clear(size);
        let lines = [header, prompt2, body, footer, error4.trim()];
        this.write(lines.filter(Boolean).join(newline));
        this.restore();
      }
      getItem(name) {
        let { items, keys, index } = this.state;
        let item = items.find((ch) => ch.name === keys[index]);
        if (item && item.input != null) {
          this.input = item.input;
          this.cursor = item.cursor;
        }
        return item;
      }
      async submit() {
        if (typeof this.interpolate !== "function") await this.initialize();
        await this.interpolate(this.state, true);
        let { invalid, missing, output, values } = this.state;
        if (invalid.size) {
          let err = "";
          for (let [key, value] of invalid) err += `Invalid ${key}: ${value}
`;
          this.state.error = err;
          return super.submit();
        }
        if (missing.size) {
          this.state.error = "Required: " + [...missing.keys()].join(", ");
          return super.submit();
        }
        let lines = stripAnsi2(output).split("\n");
        let result2 = lines.map((v) => v.slice(1)).join("\n");
        this.value = { values, result: result2 };
        return super.submit();
      }
    };
    module2.exports = SnippetPrompt;
  }
});

// ../../node_modules/enquirer/lib/prompts/sort.js
var require_sort3 = __commonJS({
  "../../node_modules/enquirer/lib/prompts/sort.js"(exports2, module2) {
    "use strict";
    var hint = "(Use <shift>+<up/down> to sort)";
    var Prompt = require_select();
    var Sort = class extends Prompt {
      static {
        __name(this, "Sort");
      }
      constructor(options) {
        super({ ...options, reorder: false, sort: true, multiple: true });
        this.state.hint = [this.options.hint, hint].find(this.isValue.bind(this));
      }
      indicator() {
        return "";
      }
      async renderChoice(choice, i32) {
        let str = await super.renderChoice(choice, i32);
        let sym = this.symbols.identicalTo + " ";
        let pre = this.index === i32 && this.sorting ? this.styles.muted(sym) : "  ";
        if (this.options.drag === false) pre = "";
        if (this.options.numbered === true) {
          return pre + `${i32 + 1} - ` + str;
        }
        return pre + str;
      }
      get selected() {
        return this.choices;
      }
      submit() {
        this.value = this.choices.map((choice) => choice.value);
        return super.submit();
      }
    };
    module2.exports = Sort;
  }
});

// ../../node_modules/enquirer/lib/prompts/survey.js
var require_survey = __commonJS({
  "../../node_modules/enquirer/lib/prompts/survey.js"(exports2, module2) {
    "use strict";
    var ArrayPrompt = require_array3();
    var Survey = class extends ArrayPrompt {
      static {
        __name(this, "Survey");
      }
      constructor(options = {}) {
        super(options);
        this.emptyError = options.emptyError || "No items were selected";
        this.term = process.env.TERM_PROGRAM;
        if (!this.options.header) {
          let header = ["", "4 - Strongly Agree", "3 - Agree", "2 - Neutral", "1 - Disagree", "0 - Strongly Disagree", ""];
          header = header.map((ele) => this.styles.muted(ele));
          this.state.header = header.join("\n   ");
        }
      }
      async toChoices(...args) {
        if (this.createdScales) return false;
        this.createdScales = true;
        let choices = await super.toChoices(...args);
        for (let choice of choices) {
          choice.scale = createScale(5, this.options);
          choice.scaleIdx = 2;
        }
        return choices;
      }
      dispatch() {
        this.alert();
      }
      space() {
        let choice = this.focused;
        let ele = choice.scale[choice.scaleIdx];
        let selected = ele.selected;
        choice.scale.forEach((e32) => e32.selected = false);
        ele.selected = !selected;
        return this.render();
      }
      indicator() {
        return "";
      }
      pointer() {
        return "";
      }
      separator() {
        return this.styles.muted(this.symbols.ellipsis);
      }
      right() {
        let choice = this.focused;
        if (choice.scaleIdx >= choice.scale.length - 1) return this.alert();
        choice.scaleIdx++;
        return this.render();
      }
      left() {
        let choice = this.focused;
        if (choice.scaleIdx <= 0) return this.alert();
        choice.scaleIdx--;
        return this.render();
      }
      indent() {
        return "   ";
      }
      async renderChoice(item, i32) {
        await this.onChoice(item, i32);
        let focused = this.index === i32;
        let isHyper = this.term === "Hyper";
        let n10 = !isHyper ? 8 : 9;
        let s = !isHyper ? " " : "";
        let ln = this.symbols.line.repeat(n10);
        let sp = " ".repeat(n10 + (isHyper ? 0 : 1));
        let dot = /* @__PURE__ */ __name((enabled) => (enabled ? this.styles.success("\u25C9") : "\u25EF") + s, "dot");
        let num = i32 + 1 + ".";
        let color = focused ? this.styles.heading : this.styles.noop;
        let msg = await this.resolve(item.message, this.state, item, i32);
        let indent = this.indent(item);
        let scale = indent + item.scale.map((e32, i33) => dot(i33 === item.scaleIdx)).join(ln);
        let val = /* @__PURE__ */ __name((i33) => i33 === item.scaleIdx ? color(i33) : i33, "val");
        let next = indent + item.scale.map((e32, i33) => val(i33)).join(sp);
        let line = /* @__PURE__ */ __name(() => [num, msg].filter(Boolean).join(" "), "line");
        let lines = /* @__PURE__ */ __name(() => [line(), scale, next, " "].filter(Boolean).join("\n"), "lines");
        if (focused) {
          scale = this.styles.cyan(scale);
          next = this.styles.cyan(next);
        }
        return lines();
      }
      async renderChoices() {
        if (this.state.submitted) return "";
        let choices = this.visible.map(async (ch, i32) => await this.renderChoice(ch, i32));
        let visible = await Promise.all(choices);
        if (!visible.length) visible.push(this.styles.danger("No matching choices"));
        return visible.join("\n");
      }
      format() {
        if (this.state.submitted) {
          let values = this.choices.map((ch) => this.styles.info(ch.scaleIdx));
          return values.join(", ");
        }
        return "";
      }
      async render() {
        let { submitted, size } = this.state;
        let prefix = await this.prefix();
        let separator = await this.separator();
        let message2 = await this.message();
        let prompt2 = [prefix, message2, separator].filter(Boolean).join(" ");
        this.state.prompt = prompt2;
        let header = await this.header();
        let output = await this.format();
        let help = await this.error() || await this.hint();
        let body = await this.renderChoices();
        let footer = await this.footer();
        if (output || !help) prompt2 += " " + output;
        if (help && !prompt2.includes(help)) prompt2 += " " + help;
        if (submitted && !output && !body && this.multiple && this.type !== "form") {
          prompt2 += this.styles.danger(this.emptyError);
        }
        this.clear(size);
        this.write([prompt2, header, body, footer].filter(Boolean).join("\n"));
        this.restore();
      }
      submit() {
        this.value = {};
        for (let choice of this.choices) {
          this.value[choice.name] = choice.scaleIdx;
        }
        return this.base.submit.call(this);
      }
    };
    function createScale(n10, options = {}) {
      if (Array.isArray(options.scale)) {
        return options.scale.map((ele) => ({ ...ele }));
      }
      let scale = [];
      for (let i32 = 1; i32 < n10 + 1; i32++) scale.push({ i: i32, selected: false });
      return scale;
    }
    __name(createScale, "createScale");
    module2.exports = Survey;
  }
});

// ../../node_modules/enquirer/lib/prompts/text.js
var require_text = __commonJS({
  "../../node_modules/enquirer/lib/prompts/text.js"(exports2, module2) {
    module2.exports = require_input();
  }
});

// ../../node_modules/enquirer/lib/prompts/toggle.js
var require_toggle = __commonJS({
  "../../node_modules/enquirer/lib/prompts/toggle.js"(exports2, module2) {
    "use strict";
    var BooleanPrompt = require_boolean();
    var TogglePrompt = class extends BooleanPrompt {
      static {
        __name(this, "TogglePrompt");
      }
      async initialize() {
        await super.initialize();
        this.value = this.initial = this.resolve(this.options.initial);
        this.disabled = this.options.disabled || "no";
        this.enabled = this.options.enabled || "yes";
        await this.render();
      }
      reset() {
        this.value = this.initial;
        this.render();
      }
      delete() {
        this.alert();
      }
      toggle() {
        this.value = !this.value;
        this.render();
      }
      enable() {
        if (this.value === true) return this.alert();
        this.value = true;
        this.render();
      }
      disable() {
        if (this.value === false) return this.alert();
        this.value = false;
        this.render();
      }
      up() {
        this.toggle();
      }
      down() {
        this.toggle();
      }
      right() {
        this.toggle();
      }
      left() {
        this.toggle();
      }
      next() {
        this.toggle();
      }
      prev() {
        this.toggle();
      }
      dispatch(ch = "", key) {
        switch (ch.toLowerCase()) {
          case " ":
            return this.toggle();
          case "1":
          case "y":
          case "t":
            return this.enable();
          case "0":
          case "n":
          case "f":
            return this.disable();
          default: {
            return this.alert();
          }
        }
      }
      format() {
        let active = /* @__PURE__ */ __name((str) => this.styles.primary.underline(str), "active");
        let value = [
          this.value ? this.disabled : active(this.disabled),
          this.value ? active(this.enabled) : this.enabled
        ];
        return value.join(this.styles.muted(" / "));
      }
      async render() {
        let { size } = this.state;
        let header = await this.header();
        let prefix = await this.prefix();
        let separator = await this.separator();
        let message2 = await this.message();
        let output = await this.format();
        let help = await this.error() || await this.hint();
        let footer = await this.footer();
        let prompt2 = [prefix, message2, separator, output].join(" ");
        this.state.prompt = prompt2;
        if (help && !prompt2.includes(help)) prompt2 += " " + help;
        this.clear(size);
        this.write([header, prompt2, footer].filter(Boolean).join("\n"));
        this.write(this.margin[2]);
        this.restore();
      }
    };
    module2.exports = TogglePrompt;
  }
});

// ../../node_modules/enquirer/lib/prompts/quiz.js
var require_quiz = __commonJS({
  "../../node_modules/enquirer/lib/prompts/quiz.js"(exports2, module2) {
    "use strict";
    var SelectPrompt = require_select();
    var Quiz = class extends SelectPrompt {
      static {
        __name(this, "Quiz");
      }
      constructor(options) {
        super(options);
        if (typeof this.options.correctChoice !== "number" || this.options.correctChoice < 0) {
          throw new Error("Please specify the index of the correct answer from the list of choices");
        }
      }
      async toChoices(value, parent) {
        let choices = await super.toChoices(value, parent);
        if (choices.length < 2) {
          throw new Error("Please give at least two choices to the user");
        }
        if (this.options.correctChoice > choices.length) {
          throw new Error("Please specify the index of the correct answer from the list of choices");
        }
        return choices;
      }
      check(state13) {
        return state13.index === this.options.correctChoice;
      }
      async result(selected) {
        return {
          selectedAnswer: selected,
          correctAnswer: this.options.choices[this.options.correctChoice].value,
          correct: await this.check(this.state)
        };
      }
    };
    module2.exports = Quiz;
  }
});

// ../../node_modules/enquirer/lib/prompts/index.js
var require_prompts = __commonJS({
  "../../node_modules/enquirer/lib/prompts/index.js"(exports2) {
    "use strict";
    var utils = require_utils11();
    var define2 = /* @__PURE__ */ __name((key, fn) => {
      utils.defineExport(exports2, key, fn);
      utils.defineExport(exports2, key.toLowerCase(), fn);
    }, "define");
    define2("AutoComplete", () => require_autocomplete());
    define2("BasicAuth", () => require_basicauth());
    define2("Confirm", () => require_confirm());
    define2("Editable", () => require_editable());
    define2("Form", () => require_form());
    define2("Input", () => require_input());
    define2("Invisible", () => require_invisible());
    define2("List", () => require_list());
    define2("MultiSelect", () => require_multiselect());
    define2("Numeral", () => require_numeral());
    define2("Password", () => require_password());
    define2("Scale", () => require_scale());
    define2("Select", () => require_select());
    define2("Snippet", () => require_snippet());
    define2("Sort", () => require_sort3());
    define2("Survey", () => require_survey());
    define2("Text", () => require_text());
    define2("Toggle", () => require_toggle());
    define2("Quiz", () => require_quiz());
  }
});

// ../../node_modules/enquirer/lib/types/index.js
var require_types4 = __commonJS({
  "../../node_modules/enquirer/lib/types/index.js"(exports2, module2) {
    module2.exports = {
      ArrayPrompt: require_array3(),
      AuthPrompt: require_auth(),
      BooleanPrompt: require_boolean(),
      NumberPrompt: require_number(),
      StringPrompt: require_string3()
    };
  }
});

// ../../node_modules/enquirer/index.js
var require_enquirer = __commonJS({
  "../../node_modules/enquirer/index.js"(exports2, module2) {
    "use strict";
    var assert = require("assert");
    var Events = require("events");
    var utils = require_utils11();
    var Enquirer = class extends Events {
      static {
        __name(this, "Enquirer");
      }
      constructor(options, answers) {
        super();
        this.options = utils.merge({}, options);
        this.answers = { ...answers };
      }
      /**
       * Register a custom prompt type.
       *
       * ```js
       * const Enquirer = require('enquirer');
       * const enquirer = new Enquirer();
       * enquirer.register('customType', require('./custom-prompt'));
       * ```
       * @name register()
       * @param {String} `type`
       * @param {Function|Prompt} `fn` `Prompt` class, or a function that returns a `Prompt` class.
       * @return {Object} Returns the Enquirer instance
       * @api public
       */
      register(type, fn) {
        if (utils.isObject(type)) {
          for (let key of Object.keys(type)) this.register(key, type[key]);
          return this;
        }
        assert.equal(typeof fn, "function", "expected a function");
        const name = type.toLowerCase();
        if (fn.prototype instanceof this.Prompt) {
          this.prompts[name] = fn;
        } else {
          this.prompts[name] = fn(this.Prompt, this);
        }
        return this;
      }
      /**
       * Prompt function that takes a "question" object or array of question objects,
       * and returns an object with responses from the user.
       *
       * ```js
       * const Enquirer = require('enquirer');
       * const enquirer = new Enquirer();
       *
       * const response = await enquirer.prompt({
       *   type: 'input',
       *   name: 'username',
       *   message: 'What is your username?'
       * });
       * console.log(response);
       * ```
       * @name prompt()
       * @param {Array|Object} `questions` Options objects for one or more prompts to run.
       * @return {Promise} Promise that returns an "answers" object with the user's responses.
       * @api public
       */
      async prompt(questions = []) {
        for (let question2 of [].concat(questions)) {
          try {
            if (typeof question2 === "function") question2 = await question2.call(this);
            await this.ask(utils.merge({}, this.options, question2));
          } catch (err) {
            return Promise.reject(err);
          }
        }
        return this.answers;
      }
      async ask(question2) {
        if (typeof question2 === "function") {
          question2 = await question2.call(this);
        }
        let opts = utils.merge({}, this.options, question2);
        let { type, name } = question2;
        let { set, get: get4 } = utils;
        if (typeof type === "function") {
          type = await type.call(this, question2, this.answers);
        }
        if (!type) return this.answers[name];
        if (type === "number") type = "numeral";
        assert(this.prompts[type], `Prompt "${type}" is not registered`);
        let prompt2 = new this.prompts[type](opts);
        let value = get4(this.answers, name);
        prompt2.state.answers = this.answers;
        prompt2.enquirer = this;
        if (name) {
          prompt2.on("submit", (value2) => {
            this.emit("answer", name, value2, prompt2);
            set(this.answers, name, value2);
          });
        }
        let emit = prompt2.emit.bind(prompt2);
        prompt2.emit = (...args) => {
          this.emit.call(this, ...args);
          return emit(...args);
        };
        this.emit("prompt", prompt2, this);
        if (opts.autofill && value != null) {
          prompt2.value = prompt2.input = value;
          if (opts.autofill === "show") {
            await prompt2.submit();
          }
        } else {
          value = prompt2.value = await prompt2.run();
        }
        return value;
      }
      /**
       * Use an enquirer plugin.
       *
       * ```js
       * const Enquirer = require('enquirer');
       * const enquirer = new Enquirer();
       * const plugin = enquirer => {
       *   // do stuff to enquire instance
       * };
       * enquirer.use(plugin);
       * ```
       * @name use()
       * @param {Function} `plugin` Plugin function that takes an instance of Enquirer.
       * @return {Object} Returns the Enquirer instance.
       * @api public
       */
      use(plugin) {
        plugin.call(this, this);
        return this;
      }
      set Prompt(value) {
        this._Prompt = value;
      }
      get Prompt() {
        return this._Prompt || this.constructor.Prompt;
      }
      get prompts() {
        return this.constructor.prompts;
      }
      static set Prompt(value) {
        this._Prompt = value;
      }
      static get Prompt() {
        return this._Prompt || require_prompt2();
      }
      static get prompts() {
        return require_prompts();
      }
      static get types() {
        return require_types4();
      }
      /**
       * Prompt function that takes a "question" object or array of question objects,
       * and returns an object with responses from the user.
       *
       * ```js
       * const { prompt } = require('enquirer');
       * const response = await prompt({
       *   type: 'input',
       *   name: 'username',
       *   message: 'What is your username?'
       * });
       * console.log(response);
       * ```
       * @name Enquirer#prompt
       * @param {Array|Object} `questions` Options objects for one or more prompts to run.
       * @return {Promise} Promise that returns an "answers" object with the user's responses.
       * @api public
       */
      static get prompt() {
        const fn = /* @__PURE__ */ __name((questions, ...rest) => {
          let enquirer = new this(...rest);
          let emit = enquirer.emit.bind(enquirer);
          enquirer.emit = (...args) => {
            fn.emit(...args);
            return emit(...args);
          };
          return enquirer.prompt(questions);
        }, "fn");
        utils.mixinEmitter(fn, new Events());
        return fn;
      }
    };
    utils.mixinEmitter(Enquirer, new Events());
    var prompts = Enquirer.prompts;
    for (let name of Object.keys(prompts)) {
      let key = name.toLowerCase();
      let run = /* @__PURE__ */ __name((options) => new prompts[name](options).run(), "run");
      Enquirer.prompt[key] = run;
      Enquirer[key] = run;
      if (!Enquirer[name]) {
        Reflect.defineProperty(Enquirer, name, { get: /* @__PURE__ */ __name(() => prompts[name], "get") });
      }
    }
    var define2 = /* @__PURE__ */ __name((name) => {
      utils.defineExport(Enquirer, name, () => Enquirer.types[name]);
    }, "define");
    define2("ArrayPrompt");
    define2("AuthPrompt");
    define2("BooleanPrompt");
    define2("NumberPrompt");
    define2("StringPrompt");
    module2.exports = Enquirer;
  }
});

// lib/commands/flags/types.ts
var FlagsMenuOptions;
var init_types16 = __esm({
  "lib/commands/flags/types.ts"() {
    "use strict";
    FlagsMenuOptions = /* @__PURE__ */ ((FlagsMenuOptions2) => {
      FlagsMenuOptions2["ALL_TO_RECOMMENDED"] = "Set all flags to recommended values";
      FlagsMenuOptions2["UNCONFIGURED_TO_RECOMMENDED"] = "Set unconfigured flags to recommended values";
      FlagsMenuOptions2["UNCONFIGURED_TO_DEFAULT"] = "Set unconfigured flags to their implied configuration (record current behavior)";
      FlagsMenuOptions2["MODIFY_SPECIFIC_FLAG"] = "Modify a specific flag";
      FlagsMenuOptions2["EXIT"] = "Exit";
      return FlagsMenuOptions2;
    })(FlagsMenuOptions || {});
  }
});

// lib/commands/flags/interactive-handler.ts
var import_enquirer, InteractiveHandler;
var init_interactive_handler = __esm({
  "lib/commands/flags/interactive-handler.ts"() {
    "use strict";
    import_enquirer = __toESM(require_enquirer());
    init_types16();
    InteractiveHandler = class {
      constructor(flags, flagOperations) {
        this.flags = flags;
        this.flagOperations = flagOperations;
      }
      static {
        __name(this, "InteractiveHandler");
      }
      /** Displays flags that have differences between user and recommended values */
      async displayFlagsWithDifferences() {
        const flagsWithDifferences = this.flags.filter((flag) => flag.userValue === void 0 || !this.isUserValueEqualToRecommended(flag));
        if (flagsWithDifferences.length > 0) {
          await this.flagOperations.displayFlagTable(flagsWithDifferences);
        }
      }
      /** Checks if user value matches recommended value */
      isUserValueEqualToRecommended(flag) {
        return String(flag.userValue) === String(flag.recommendedValue);
      }
      /** Main interactive mode handler that shows menu and processes user selection */
      async handleInteractiveMode() {
        await this.displayFlagsWithDifferences();
        const prompt2 = new import_enquirer.Select({
          name: "option",
          message: "Menu",
          choices: Object.values(FlagsMenuOptions)
        });
        const answer = await prompt2.run();
        switch (answer) {
          case "Set all flags to recommended values" /* ALL_TO_RECOMMENDED */:
            return { recommended: true, all: true, set: true };
          case "Set unconfigured flags to recommended values" /* UNCONFIGURED_TO_RECOMMENDED */:
            return { recommended: true, unconfigured: true, set: true };
          case "Set unconfigured flags to their implied configuration (record current behavior)" /* UNCONFIGURED_TO_DEFAULT */:
            return { default: true, unconfigured: true, set: true };
          case "Modify a specific flag" /* MODIFY_SPECIFIC_FLAG */:
            return this.handleSpecificFlagSelection();
          case "Exit" /* EXIT */:
            return null;
          default:
            return null;
        }
      }
      /** Handles the specific flag selection flow with flag and value prompts */
      async handleSpecificFlagSelection() {
        const booleanFlags = this.flags.filter((flag) => this.flagOperations.isBooleanFlag(flag));
        const flagPrompt = new import_enquirer.Select({
          name: "flag",
          message: "Select which flag you would like to modify:",
          limit: 100,
          choices: booleanFlags.map((flag) => flag.name)
        });
        const selectedFlagName = await flagPrompt.run();
        const valuePrompt = new import_enquirer.Select({
          name: "value",
          message: "Select a value:",
          choices: ["true", "false"]
        });
        const value = await valuePrompt.run();
        return {
          FLAGNAME: [selectedFlagName],
          value,
          set: true
        };
      }
    };
  }
});

// lib/commands/flags/router.ts
var FlagOperationRouter;
var init_router = __esm({
  "lib/commands/flags/router.ts"() {
    "use strict";
    FlagOperationRouter = class {
      constructor(validator, interactiveHandler, flagOperations) {
        this.validator = validator;
        this.interactiveHandler = interactiveHandler;
        this.flagOperations = flagOperations;
      }
      static {
        __name(this, "FlagOperationRouter");
      }
      /** Routes flag operations to appropriate handlers based on parameters */
      async route(params) {
        if (params.interactive) {
          await this.handleInteractiveMode();
          return;
        }
        if (params.safe) {
          await this.flagOperations.setSafeFlags(params);
          return;
        }
        const isValid = await this.validator.validateParams(params);
        if (!isValid) return;
        if (params.set) {
          await this.handleSetOperations(params);
        } else {
          await this.flagOperations.displayFlags(params);
          await this.showHelpMessage(params);
        }
      }
      /** Handles flag setting operations, routing to single or multiple flag methods */
      async handleSetOperations(params) {
        if (params.FLAGNAME && params.value) {
          await this.flagOperations.setFlag(params);
        } else if (params.all || params.unconfigured) {
          await this.flagOperations.setMultipleFlags(params);
        }
      }
      /** Manages interactive mode */
      async handleInteractiveMode() {
        while (true) {
          const interactiveParams = await this.interactiveHandler.handleInteractiveMode();
          if (!interactiveParams) return;
          await this.flagOperations.execute(interactiveParams);
          if (!interactiveParams.FLAGNAME) {
            return;
          }
        }
      }
      /** Shows help message when no specific options are provided */
      async showHelpMessage(params) {
        if (!params.all && !params.FLAGNAME) {
          await this.flagOperations.displayHelpMessage();
        }
      }
    };
  }
});

// lib/commands/flags/validator.ts
var FlagValidator;
var init_validator = __esm({
  "lib/commands/flags/validator.ts"() {
    "use strict";
    FlagValidator = class {
      constructor(ioHelper) {
        this.ioHelper = ioHelper;
      }
      static {
        __name(this, "FlagValidator");
      }
      /** Shows error message when CDK version is incompatible with flags command */
      async showIncompatibleVersionError() {
        await this.ioHelper.defaults.error("The 'cdk flags' command is not compatible with the AWS CDK library used by your application. Please upgrade to 2.212.0 or above.");
      }
      /** Validates all parameters and returns true if valid, false if any validation fails */
      async validateParams(params) {
        const validations = [
          () => this.validateFlagNameAndAll(params),
          () => this.validateSetRequirement(params),
          () => this.validateValueRequirement(params),
          () => this.validateMutuallyExclusive(params),
          () => this.validateUnconfiguredUsage(params),
          () => this.validateSetWithFlags(params)
        ];
        for (const validation of validations) {
          const isValid = await validation();
          if (!isValid) return false;
        }
        return true;
      }
      /** Validates that --all and specific flag names are not used together */
      async validateFlagNameAndAll(params) {
        if (params.FLAGNAME && params.all) {
          await this.ioHelper.defaults.error("Error: Cannot use both --all and a specific flag name. Please use either --all to show all flags or specify a single flag name.");
          return false;
        }
        return true;
      }
      /** Validates that modification options require --set flag */
      async validateSetRequirement(params) {
        if ((params.value || params.recommended || params.default || params.unconfigured) && !params.set) {
          await this.ioHelper.defaults.error("Error: This option can only be used with --set.");
          return false;
        }
        return true;
      }
      /** Validates that --value requires a specific flag name */
      async validateValueRequirement(params) {
        if (params.value && !params.FLAGNAME) {
          await this.ioHelper.defaults.error("Error: --value requires a specific flag name. Please specify a flag name when providing a value.");
          return false;
        }
        return true;
      }
      /** Validates that mutually exclusive options are not used together */
      async validateMutuallyExclusive(params) {
        if (params.recommended && params.default) {
          await this.ioHelper.defaults.error("Error: Cannot use both --recommended and --default. Please choose one option.");
          return false;
        }
        if (params.unconfigured && params.all) {
          await this.ioHelper.defaults.error("Error: Cannot use both --unconfigured and --all. Please choose one option.");
          return false;
        }
        return true;
      }
      /** Validates that --unconfigured is not used with specific flag names */
      async validateUnconfiguredUsage(params) {
        if (params.unconfigured && params.FLAGNAME) {
          await this.ioHelper.defaults.error("Error: Cannot use --unconfigured with a specific flag name. --unconfigured works with multiple flags.");
          return false;
        }
        return true;
      }
      /** Validates that --set operations have required accompanying options */
      async validateSetWithFlags(params) {
        if (params.set && params.FLAGNAME && !params.value) {
          await this.ioHelper.defaults.error("Error: When setting a specific flag, you must provide a --value.");
          return false;
        }
        if (params.set && params.all && !params.recommended && !params.default) {
          await this.ioHelper.defaults.error("Error: When using --set with --all, you must specify either --recommended or --default.");
          return false;
        }
        if (params.set && params.unconfigured && !params.recommended && !params.default) {
          await this.ioHelper.defaults.error("Error: When using --set with --unconfigured, you must specify either --recommended or --default.");
          return false;
        }
        if (params.set && !params.all && !params.unconfigured && !params.FLAGNAME) {
          await this.ioHelper.defaults.error("Error: When using --set, you must specify either --all, --unconfigured, or provide a specific flag name.");
          return false;
        }
        return true;
      }
    };
  }
});

// lib/commands/flags/flags.ts
var FlagCommandHandler;
var init_flags = __esm({
  "lib/commands/flags/flags.ts"() {
    "use strict";
    init_interactive_handler();
    init_obsolete_flags();
    init_operations();
    init_router();
    init_validator();
    FlagCommandHandler = class {
      static {
        __name(this, "FlagCommandHandler");
      }
      /** Main component that sets up all flag operation components */
      constructor(flagData, ioHelper, options, toolkit, cliContextValues = {}) {
        this.flags = flagData.filter((flag) => !OBSOLETE_FLAGS.includes(flag.name));
        this.options = { ...options, concurrency: options.concurrency ?? 4 };
        this.ioHelper = ioHelper;
        const validator = new FlagValidator(ioHelper);
        const flagOperations = new FlagOperations(this.flags, toolkit, ioHelper, cliContextValues);
        const interactiveHandler = new InteractiveHandler(this.flags, flagOperations);
        this.router = new FlagOperationRouter(validator, interactiveHandler, flagOperations);
      }
      /** Main entry point that processes the flags command */
      async processFlagsCommand() {
        if (this.flags.length === 0) {
          await this.ioHelper.defaults.error("The 'cdk flags' command is not compatible with the AWS CDK library used by your application. Please upgrade to 2.212.0 or above.");
          return;
        }
        await this.router.route(this.options);
      }
    };
  }
});

// lib/cli/util/check-unknown-options.ts
function collectKnownOptions(optionDefs) {
  const known = /* @__PURE__ */ new Set();
  for (const [name, def] of Object.entries(optionDefs)) {
    known.add(name);
    known.add(kebabToCamel(name));
    if (def.alias) {
      const aliases = Array.isArray(def.alias) ? def.alias : [def.alias];
      for (const a32 of aliases) {
        known.add(a32);
      }
    }
    if (def.negativeAlias) {
      known.add(def.negativeAlias);
    }
  }
  return known;
}
function findUnknownOptions(argv) {
  const command = argv._[0];
  const canonicalCommand = commandAliasMap.get(command) ?? command;
  const commandDef = config.commands[canonicalCommand];
  const commandKnownOptions = commandDef?.options ? collectKnownOptions(commandDef.options) : /* @__PURE__ */ new Set();
  const positionalArgRaw = commandDef?.arg?.name;
  const positionalArgs = positionalArgRaw ? /* @__PURE__ */ new Set([positionalArgRaw, positionalArgRaw.toLowerCase()]) : /* @__PURE__ */ new Set();
  const unknown = [];
  for (const key of Object.keys(argv)) {
    if (argv[key] === void 0) {
      continue;
    }
    if (yargsInternals.has(key) || positionalArgs.has(key)) {
      continue;
    }
    if (globalKnownOptions.has(key) || commandKnownOptions.has(key)) {
      continue;
    }
    if (isFromEnvPrefix(key, "CDK")) {
      continue;
    }
    unknown.push(key);
  }
  return unknown;
}
function kebabToCamel(str) {
  return str.replace(/-([a-z])/g, (_, c32) => c32.toUpperCase());
}
function isFromEnvPrefix(key, prefix) {
  const screamingSnake = key.replace(/[A-Z]/g, (m20) => `_${m20}`).toUpperCase();
  return process.env[`${prefix}_${screamingSnake}`] !== void 0;
}
var config, globalKnownOptions, commandAliasMap, yargsInternals;
var init_check_unknown_options = __esm({
  "lib/cli/util/check-unknown-options.ts"() {
    "use strict";
    config = require_cli_type_registry();
    __name(collectKnownOptions, "collectKnownOptions");
    globalKnownOptions = collectKnownOptions(config.globalOptions);
    commandAliasMap = /* @__PURE__ */ new Map();
    for (const [name, def] of Object.entries(config.commands)) {
      if (def.aliases) {
        for (const alias of def.aliases) {
          commandAliasMap.set(alias, name);
        }
      }
    }
    yargsInternals = /* @__PURE__ */ new Set(["_", "$0", "help", "h", "version"]);
    __name(findUnknownOptions, "findUnknownOptions");
    __name(kebabToCamel, "kebabToCamel");
    __name(isFromEnvPrefix, "isFromEnvPrefix");
  }
});

// lib/cli/util/guess-agent.ts
function guessAgent() {
  const awsExecutionEnv = (process.env.AWS_EXECUTION_ENV ?? "").toLocaleLowerCase();
  if (awsExecutionEnv.includes("amazonq") || awsExecutionEnv.includes("kiro")) {
    return true;
  }
  if (process.env.CLAUDECODE) {
    return true;
  }
  if (Object.keys(process.env).some((x) => x.startsWith("CODEX_"))) {
    return true;
  }
  if (process.env.CURSOR_AGENT) {
    return true;
  }
  if (process.env.VSCODE_AGENT) {
    return true;
  }
  if (Object.keys(process.env).some((x) => x.startsWith("CLINE_"))) {
    return true;
  }
  return void 0;
}
var init_guess_agent = __esm({
  "lib/cli/util/guess-agent.ts"() {
    "use strict";
    __name(guessAgent, "guessAgent");
  }
});

// lib/cli/cli.ts
var cli_exports = {};
__export(cli_exports, {
  cli: () => cli,
  exec: () => exec4
});
async function exec4(args, synthesizer) {
  const libraryLoadTime = performance.now();
  const argv = await parseCommandLineArguments(args);
  argv.language = getLanguageFromAlias(argv.language) ?? argv.language;
  if (argv.noColor) {
    process.env.FORCE_COLOR = "0";
  } else if (argv.color) {
    process.env.FORCE_COLOR = "3";
  } else if (!process.stdout.isTTY) {
    process.env.FORCE_COLOR = "0";
  }
  const cmd = argv._[0];
  let ioMessageLevel = "info";
  if (argv.verbose) {
    switch (argv.verbose) {
      case 1:
        ioMessageLevel = "debug";
        break;
      case 2:
      default:
        ioMessageLevel = "trace";
        break;
    }
  }
  const ioHost = CliIoHost.instance({
    logLevel: ioMessageLevel,
    isTTY: process.stdout.isTTY,
    isCI: Boolean(argv.ci),
    currentAction: cmd,
    stackProgress: argv.progress,
    autoRespond: argv.yes
  }, true);
  const ioHelper = asIoHelper(ioHost, ioHost.currentAction);
  setSdkTracing(Boolean(argv.debugCli) || argv.verbose > 2);
  try {
    await checkForPlatformWarnings(ioHelper);
  } catch (e32) {
    await ioHost.defaults.debug(`Error while checking for platform warnings: ${e32}`);
  }
  await ioHost.defaults.debug("CDK Toolkit CLI version:", versionWithBuild());
  await ioHost.defaults.debug("Command line arguments:", argv);
  const unknownOptions = findUnknownOptions(argv);
  if (unknownOptions.length > 0) {
    const formatted = unknownOptions.map((o10) => `--${o10}`).join(", ");
    await ioHost.defaults.warn(`Unknown option(s): ${formatted}. These will be ignored. Run 'cdk --help' to see available options.`);
  }
  const configuration = await Configuration.fromArgsAndFiles(
    ioHelper,
    {
      commandLineArguments: {
        ...argv,
        _: argv._
        // TypeScript at its best
      }
    }
  );
  const proxyAgent = await new ProxyAgentProvider(ioHelper).create({
    proxyAddress: configuration.settings.get(["proxy"]),
    caBundlePath: configuration.settings.get(["caBundlePath"])
  });
  try {
    await ioHost.startTelemetry(argv, configuration.context, proxyAgent);
  } catch (e32) {
    await ioHost.asIoHelper().defaults.trace(`Telemetry instantiation failed: ${e32.message}`);
  }
  ioHost.telemetry?.attachLoadTime(libraryLoadTime);
  ioHost.telemetry?.attachLanguage(await guessLanguage(process.cwd()));
  ioHost.telemetry?.attachAgent(guessAgent());
  const isSafeToWriteNotices = !isCI2() || Boolean(ciSystemIsStdErrSafe());
  let shouldDisplayNotices;
  if (argv.notices !== void 0) {
    shouldDisplayNotices = argv.notices;
  } else {
    const configNotices = configuration.settings.get(["notices"]);
    if (configNotices !== void 0) {
      shouldDisplayNotices = configNotices !== "false" && Boolean(configNotices);
    } else {
      shouldDisplayNotices = isSafeToWriteNotices;
    }
  }
  ioHost.noticesDestination = shouldDisplayNotices ? "stderr" : "drop";
  const notices = Notices.create({
    ioHost,
    context: configuration.context,
    output: configuration.settings.get(["outdir"]),
    language: await guessLanguage(process.cwd()),
    httpOptions: { agent: proxyAgent },
    cliVersion: versionNumber2()
  });
  const refreshNotices = (async () => {
    if (shouldDisplayNotices && cmd !== "notices") {
      await trapErrors(ioHelper, "Could not refresh notices", () => notices.refresh());
    }
  })();
  const sdkProvider = await SdkProvider.withAwsCliCompatibleDefaults({
    ioHelper,
    requestHandler: sdkRequestHandler(proxyAgent),
    logger: new IoHostSdkLogger(asIoHelper(ioHost, ioHost.currentAction)),
    pluginHost: GLOBAL_PLUGIN_HOST
  }, configuration.settings.get(["profile"]), configuration.settings.get(["region"]));
  try {
    await ioHost.telemetry?.attachRegion(sdkProvider.defaultRegion);
  } catch (e32) {
    await ioHost.asIoHelper().defaults.trace(`Telemetry attach region failed: ${e32.message}`);
  }
  let outDirLock;
  const cloudExecutable = new CloudExecutable({
    configuration,
    sdkProvider,
    synthesizer: synthesizer ?? (async (aws, config2) => {
      await outDirLock?.release();
      const { assembly, lock, perfCounters } = await execProgram(aws, ioHost.asIoHelper(), config2);
      outDirLock = lock;
      const tree = await loadTree(assembly, ioHelper.defaults.trace.bind(ioHelper.defaults));
      if (tree) {
        const v = findConstructLibraryVersion(tree);
        if (v) {
          ioHost.telemetry?.attachCdkLibVersion(v);
        }
      }
      if (perfCounters) {
        ioHost.telemetry?.attachCountersToNextEvent(perfCounters);
      }
      return assembly;
    }),
    ioHelper: ioHost.asIoHelper()
  });
  async function loadPlugins(...settings) {
    for (const source of settings) {
      const plugins = source.get(["plugin"]) || [];
      for (const plugin of plugins) {
        await GLOBAL_PLUGIN_HOST.load(plugin, ioHost);
      }
    }
  }
  __name(loadPlugins, "loadPlugins");
  await loadPlugins(configuration.settings);
  if (typeof cmd !== "string") {
    throw new import_toolkit_lib22.ToolkitError("InvalidArgType", `First argument should be a string. Got: ${cmd} (${typeof cmd})`);
  }
  try {
    return await main(cmd, argv);
  } finally {
    await outDirLock?.release();
    if (shouldDisplayVersionMessage()) {
      await displayVersionMessage(ioHelper);
    }
    await refreshNotices;
    if (cmd === "notices") {
      await notices.refresh({ force: true });
      await notices.display({
        includeAcknowledged: !argv.unacknowledged,
        showTotal: argv.unacknowledged
      });
    } else if (shouldDisplayNotices && cmd !== "version") {
      await trapErrors(ioHelper, "Could not display notices", () => notices.display());
    }
  }
  async function main(command, args2) {
    ioHost.currentAction = command;
    const toolkitStackName = ToolkitInfo.determineName(configuration.settings.get(["toolkitStackName"]));
    await ioHost.defaults.debug(`Toolkit stack: ${chalk38.bold(toolkitStackName)}`);
    const cloudFormation = new Deployments({
      sdkProvider,
      toolkitStackName,
      ioHelper: asIoHelper(ioHost, ioHost.currentAction)
    });
    if (args2.all && args2.STACKS) {
      throw new import_toolkit_lib22.ToolkitError("StacksOrAllRequired", "You must either specify a list of Stacks or the `--all` argument");
    }
    args2.STACKS = args2.STACKS ?? (args2.STACK ? [args2.STACK] : []);
    args2.ENVIRONMENTS = args2.ENVIRONMENTS ?? [];
    const selector = {
      allTopLevel: args2.all,
      patterns: args2.STACKS
    };
    const cli2 = new CdkToolkit({
      ioHost,
      cloudExecutable,
      toolkitStackName,
      deployments: cloudFormation,
      verbose: argv.trace || argv.verbose > 0,
      ignoreErrors: argv["ignore-errors"],
      strict: argv.strict,
      configuration,
      sdkProvider
    });
    ioHost.telemetry?.markOperationStart();
    switch (command) {
      case "context":
        ioHost.currentAction = "context";
        return contextHandler({
          ioHelper,
          context: configuration.context,
          clear: argv.clear,
          json: argv.json,
          force: argv.force,
          reset: argv.reset
        });
      case "docs":
      case "doc":
        ioHost.currentAction = "docs";
        return docs({
          ioHelper,
          browser: configuration.settings.get(["browser"])
        });
      case "doctor":
        ioHost.currentAction = "doctor";
        return doctor({
          ioHelper,
          settings: configuration.settings
        });
      case "ls":
      case "list":
        ioHost.currentAction = "list";
        return cli2.list(args2.STACKS, {
          long: args2.long,
          json: argv.json,
          showDeps: args2.showDependencies
        });
      case "diff":
        ioHost.currentAction = "diff";
        const enableDiffNoFail = isFeatureEnabled(configuration, cxapi14.ENABLE_DIFF_NO_FAIL_CONTEXT);
        return cli2.diff({
          stackNames: args2.STACKS,
          exclusively: args2.exclusively,
          templatePath: args2.template,
          strict: args2.strict,
          contextLines: args2.contextLines,
          securityOnly: args2.securityOnly,
          fail: args2.fail != null ? args2.fail : !enableDiffNoFail,
          compareAgainstProcessedTemplate: args2.processed,
          quiet: args2.quiet,
          method: determineDiffMethod(args2),
          toolkitStackName,
          importExistingResources: args2.importExistingResources,
          includeMoves: args2["include-moves"]
        });
      case "drift":
        ioHost.currentAction = "drift";
        return cli2.drift({
          selector,
          fail: args2.fail
        });
      case "refactor":
        cliRequireUnstable(configuration, "refactor");
        ioHost.currentAction = "refactor";
        return cli2.refactor({
          dryRun: args2.dryRun,
          overrideFile: args2.overrideFile,
          revert: args2.revert,
          stacks: selector,
          additionalStackNames: arrayFromYargs(args2.additionalStackName ?? []),
          force: args2.force ?? false,
          roleArn: args2.roleArn
        });
      case "bootstrap":
        ioHost.currentAction = "bootstrap";
        const source = await determineBootstrapVersion(ioHost, args2);
        if (args2.showTemplate) {
          const bootstrapper = new Bootstrapper(source, asIoHelper(ioHost, ioHost.currentAction));
          return bootstrapper.showTemplate(args2.json);
        }
        return cli2.bootstrap(args2.ENVIRONMENTS, {
          source,
          roleArn: args2.roleArn,
          forceDeployment: argv.force,
          toolkitStackName,
          execute: args2.execute,
          tags: configuration.settings.get(["tags"]),
          terminationProtection: args2.terminationProtection,
          usePreviousParameters: args2["previous-parameters"],
          importExistingResources: args2.importExistingResources,
          parameters: {
            bucketName: configuration.settings.get(["toolkitBucket", "bucketName"]),
            kmsKeyId: configuration.settings.get(["toolkitBucket", "kmsKeyId"]),
            createCustomerMasterKey: args2.bootstrapCustomerKey,
            qualifier: args2.qualifier ?? configuration.context.get("@aws-cdk/core:bootstrapQualifier"),
            publicAccessBlockConfiguration: args2.publicAccessBlockConfiguration,
            examplePermissionsBoundary: argv.examplePermissionsBoundary,
            customPermissionsBoundary: argv.customPermissionsBoundary,
            trustedAccounts: arrayFromYargs(args2.trust),
            trustedAccountsForLookup: arrayFromYargs(args2.trustForLookup),
            untrustedAccounts: arrayFromYargs(args2.untrust),
            cloudFormationExecutionPolicies: arrayFromYargs(args2.cloudformationExecutionPolicies),
            denyExternalId: args2.denyExternalId
          }
        });
      case "deploy":
        ioHost.currentAction = "deploy";
        const parameterMap = {};
        for (const parameter of args2.parameters) {
          if (typeof parameter === "string") {
            const keyValue = parameter.split("=");
            parameterMap[keyValue[0]] = keyValue.slice(1).join("=");
          }
        }
        if (args2.execute !== void 0 && args2.method !== void 0) {
          throw new import_toolkit_lib22.ToolkitError("ConflictingExecuteAndMethod", "Can not supply both --[no-]execute and --method at the same time");
        }
        return cli2.deploy({
          selector,
          exclusively: args2.exclusively,
          toolkitStackName,
          roleArn: args2.roleArn,
          notificationArns: args2.notificationArns,
          requireApproval: configuration.settings.get(["requireApproval"]),
          reuseAssets: args2["build-exclude"],
          tags: configuration.settings.get(["tags"]),
          deploymentMethod: determineDeploymentMethod(args2, configuration),
          force: args2.force,
          parameters: parameterMap,
          usePreviousParameters: args2["previous-parameters"],
          outputsFile: configuration.settings.get(["outputsFile"]),
          progress: configuration.settings.get(["progress"]),
          ci: args2.ci,
          rollback: configuration.settings.get(["rollback"]),
          watch: args2.watch,
          traceLogs: args2.logs,
          concurrency: args2.concurrency,
          assetParallelism: configuration.settings.get(["assetParallelism"]),
          assetBuildConcurrency: configuration.settings.get(["assetBuildConcurrency"]),
          assetBuildTime: configuration.settings.get(["assetPrebuild"]) ? "all-before-deploy" /* ALL_BEFORE_DEPLOY */ : "just-in-time" /* JUST_IN_TIME */,
          ignoreNoStacks: args2.ignoreNoStacks
        });
      case "validate":
        cliRequireUnstable(configuration, "validate");
        ioHost.currentAction = "validate";
        configuration.context.set("@aws-cdk/core:failSynthOnValidationErrors", false);
        return cli2.validate({
          stacks: specificStacksOrAllRecursively(args2.STACKS),
          online: args2.online
        });
      case "diagnose":
        cliRequireUnstable(configuration, "diagnose");
        ioHost.currentAction = "diagnose";
        return cli2.diagnose({
          stacks: specificStacksOrAllRecursively(args2.STACKS),
          concurrency: args2.concurrency,
          toolkitStackName: args2.toolkitStackName
        });
      case "rollback":
        ioHost.currentAction = "rollback";
        return cli2.rollback({
          selector,
          toolkitStackName,
          roleArn: args2.roleArn,
          force: args2.force,
          validateBootstrapStackVersion: args2["validate-bootstrap-version"],
          orphanLogicalIds: args2.orphan
        });
      case "publish-assets":
        ioHost.currentAction = "publish-assets";
        cliRequireUnstable(configuration, "publish-assets");
        return cli2.publishAssets({
          stacks: convertStackSelector(selector, args2.exclusively),
          force: args2.force,
          concurrency: args2.concurrency
        });
      case "orphan":
        cliRequireUnstable(configuration, "orphan");
        ioHost.currentAction = "orphan";
        return cli2.orphan({
          constructPath: args2.PATHS ?? [],
          roleArn: args2.roleArn,
          toolkitStackName
        });
      case "import":
        ioHost.currentAction = "import";
        return cli2.import({
          selector,
          toolkitStackName,
          roleArn: args2.roleArn,
          deploymentMethod: {
            method: "change-set",
            execute: args2.execute,
            changeSetName: args2.changeSetName
          },
          progress: configuration.settings.get(["progress"]),
          rollback: configuration.settings.get(["rollback"]),
          recordResourceMapping: args2["record-resource-mapping"],
          resourceMappingFile: args2["resource-mapping"],
          resourceMappingInline: args2["resource-mapping-inline"],
          force: args2.force
        });
      case "watch":
        ioHost.currentAction = "watch";
        await cli2.watch({
          selector,
          exclusively: args2.exclusively,
          toolkitStackName,
          roleArn: args2.roleArn,
          reuseAssets: args2["build-exclude"],
          deploymentMethod: determineDeploymentMethod(args2, configuration, true),
          force: args2.force,
          progress: configuration.settings.get(["progress"]),
          rollback: configuration.settings.get(["rollback"]),
          traceLogs: args2.logs,
          concurrency: args2.concurrency
        });
        return;
      case "destroy":
        ioHost.currentAction = "destroy";
        return cli2.destroy({
          selector,
          exclusively: args2.exclusively,
          force: args2.force,
          roleArn: args2.roleArn,
          concurrency: args2.concurrency
        });
      case "gc":
        ioHost.currentAction = "gc";
        cliRequireUnstable(configuration, "gc");
        if (args2.bootstrapStackName) {
          await ioHost.defaults.warn("--bootstrap-stack-name is deprecated and will be removed when gc is GA. Use --toolkit-stack-name.");
        }
        if (args2.roleArn) {
          await ioHost.defaults.warn("The --role-arn option is not supported for the gc command and will be ignored.");
        }
        return cli2.garbageCollect(args2.ENVIRONMENTS, {
          action: args2.action,
          type: args2.type,
          rollbackBufferDays: args2["rollback-buffer-days"],
          createdBufferDays: args2["created-buffer-days"],
          bootstrapStackName: args2.toolkitStackName ?? args2.bootstrapStackName,
          confirm: args2.confirm
        });
      case "flags":
        ioHost.currentAction = "flags";
        cliRequireUnstable(configuration, "flags");
        const toolkit = new import_toolkit_lib22.Toolkit({
          ioHost,
          toolkitStackName,
          unstableFeatures: configuration.settings.get(["unstable"])
        });
        const flagsData = await toolkit.flags(cloudExecutable);
        const handler = new FlagCommandHandler(flagsData, ioHelper, args2, toolkit, configuration.context.all);
        return handler.processFlagsCommand();
      case "synthesize":
      case "synth":
        ioHost.currentAction = "synth";
        const quiet = configuration.settings.get(["quiet"]) ?? args2.quiet;
        if (args2.exclusively) {
          return cli2.synth(args2.STACKS, args2.exclusively, quiet, args2.validation, argv.json);
        } else {
          return cli2.synth(args2.STACKS, true, quiet, args2.validation, argv.json);
        }
      case "notices":
        ioHost.currentAction = "notices";
        ioHost.noticesDestination = "stdout";
        return;
      case "metadata":
        ioHost.currentAction = "metadata";
        return cli2.metadata(args2.STACK, argv.json);
      case "acknowledge":
      case "ack":
        ioHost.currentAction = "notices";
        return cli2.acknowledge(args2.ID);
      case "cli-telemetry":
        ioHost.currentAction = "cli-telemetry";
        if (args2.enable === void 0 && args2.disable === void 0 && args2.status === void 0) {
          throw new import_toolkit_lib22.ToolkitError("TelemetryArgRequired", "Must specify '--enable', '--disable', or '--status'");
        }
        if (args2.status) {
          return cli2.cliTelemetryStatus(args2);
        } else {
          const enable = args2.enable ?? !args2.disable;
          return cli2.cliTelemetry(enable);
        }
      case "init":
        ioHost.currentAction = "init";
        const language = configuration.settings.get(["language"]);
        if (args2.list) {
          return printAvailableTemplates(ioHelper, language);
        } else {
          if (args2["from-path"]) {
            cliRequireUnstable(configuration, "init");
          }
          return cliInit({
            ioHelper,
            type: args2.TEMPLATE,
            language,
            canUseNetwork: void 0,
            generateOnly: args2.generateOnly,
            libVersion: args2.libVersion,
            fromPath: args2["from-path"],
            templatePath: args2["template-path"],
            packageManager: args2["package-manager"],
            projectName: args2.projectName
          });
        }
      case "migrate":
        ioHost.currentAction = "migrate";
        return cli2.migrate({
          stackName: args2["stack-name"],
          fromPath: args2["from-path"],
          fromStack: args2["from-stack"],
          language: args2.language,
          outputPath: args2["output-path"],
          fromScan: getMigrateScanType(args2["from-scan"]),
          filter: args2.filter,
          account: args2.account,
          region: args2.region,
          compress: args2.compress
        });
      case "version":
        ioHost.currentAction = "version";
        return ioHost.defaults.result(versionWithBuild());
      default:
        throw new import_toolkit_lib22.ToolkitError("UnknownCommand", "Unknown command: " + command);
    }
  }
  __name(main, "main");
}
async function determineBootstrapVersion(ioHost, args) {
  let source;
  if (args.template) {
    await ioHost.defaults.info(`Using bootstrapping template from ${args.template}`);
    source = { source: "custom", templateFile: args.template };
  } else if (process.env.CDK_LEGACY_BOOTSTRAP) {
    await ioHost.defaults.info("CDK_LEGACY_BOOTSTRAP set, using legacy-style bootstrapping");
    source = { source: "legacy" };
  } else {
    source = { source: "default" };
  }
  return source;
}
function isFeatureEnabled(configuration, featureFlag) {
  return configuration.context.get(featureFlag) ?? cxapi14.futureFlagDefault(featureFlag);
}
function convertStackSelector(selector, exclusively) {
  return {
    patterns: selector.patterns,
    strategy: selector.patterns.length > 0 ? import_toolkit_lib22.StackSelectionStrategy.PATTERN_MATCH : import_toolkit_lib22.StackSelectionStrategy.ALL_STACKS,
    expand: exclusively ? import_toolkit_lib22.ExpandStackSelection.NONE : import_toolkit_lib22.ExpandStackSelection.UPSTREAM
  };
}
function specificStacksOrAllRecursively(patterns) {
  return {
    strategy: patterns.length > 0 ? import_toolkit_lib22.StackSelectionStrategy.PATTERN_MATCH : import_toolkit_lib22.StackSelectionStrategy.ALL_STACKS,
    patterns
  };
}
function arrayFromYargs(xs) {
  if (xs.length === 0) {
    return void 0;
  }
  return xs.filter((x) => x !== "");
}
function determineDiffMethod(args) {
  if (args.method && args.method !== "auto") {
    return args.method;
  }
  if (args["change-set"] === false) {
    return "template";
  }
  if (args.template) {
    return "template";
  }
  return "auto";
}
function determineDeploymentMethod(args, configuration, watch2) {
  let deploymentMethod;
  switch (args.method) {
    case "execute-change-set":
      if (!args.STACKS || args.STACKS.length !== 1) {
        throw new import_toolkit_lib22.ToolkitError("ExactlyOneStack", "--method=execute-change-set requires exactly one stack");
      }
      if (watch2 || args.watch) {
        throw new import_toolkit_lib22.ToolkitError("WatchWithExecuteChangeSet", "--method=execute-change-set cannot be used with watch");
      }
      rejectIncompatibleOptions(args, "--method=execute-change-set", {
        force: "--force",
        parameters: "--parameters",
        importExistingResources: "--import-existing-resources",
        revertDrift: "--revert-drift"
      });
      return {
        method: "execute-change-set",
        changeSetName: args.changeSetName ?? "cdk-deploy-change-set"
      };
    case "direct":
      rejectIncompatibleOptions(args, "--method=direct", {
        changeSetName: "--change-set-name",
        importExistingResources: "--import-existing-resources",
        revertDrift: "--revert-drift"
      });
      deploymentMethod = { method: "direct" };
      break;
    case "change-set":
      deploymentMethod = {
        method: "change-set",
        execute: true,
        changeSetName: args.changeSetName,
        importExistingResources: args.importExistingResources,
        revertDrift: args.revertDrift
      };
      break;
    case "prepare-change-set":
      deploymentMethod = {
        method: "change-set",
        execute: false,
        changeSetName: args.changeSetName,
        importExistingResources: args.importExistingResources,
        revertDrift: args.revertDrift
      };
      break;
    case void 0:
    default:
      deploymentMethod = {
        method: "change-set",
        execute: watch2 ? true : args.execute ?? true,
        changeSetName: args.changeSetName,
        importExistingResources: args.importExistingResources,
        revertDrift: args.revertDrift
      };
      break;
  }
  const hotswapMode = determineHotswapMode(args.hotswap, args.hotswapFallback, watch2);
  const hotswapProperties = configuration.settings.get(["hotswap"]) || {};
  switch (hotswapMode) {
    case "fall-back" /* FALL_BACK */:
      return {
        method: "hotswap",
        properties: hotswapProperties,
        fallback: deploymentMethod
      };
    case "hotswap-only" /* HOTSWAP_ONLY */:
      return {
        method: "hotswap",
        properties: hotswapProperties
      };
    default:
    case "full-deployment" /* FULL_DEPLOYMENT */:
      return deploymentMethod;
  }
}
function cliRequireUnstable(configuration, feature) {
  if (!configuration.settings.get(["unstable"]).includes(feature)) {
    throw new import_toolkit_lib22.ToolkitError(`Unstable${ucfirst(feature)}`, `Unstable feature use: '${feature}' is unstable. It must be opted in via '--unstable', e.g. 'cdk ${feature} --unstable=${feature}'`);
  }
  function ucfirst(x) {
    return x[0].toUpperCase() + x.slice(1);
  }
  __name(ucfirst, "ucfirst");
}
function rejectIncompatibleOptions(args, option, flags) {
  for (const [key, flag] of Object.entries(flags)) {
    const value = args[key];
    let isSet3 = false;
    if (Array.isArray(value)) {
      isSet3 = value.some((v) => typeof v === "string" || typeof v === "number");
    } else {
      isSet3 = !!value;
    }
    if (isSet3) {
      throw new import_toolkit_lib22.ToolkitError("IncompatibleOptions", `${flag} cannot be used with ${option}`);
    }
  }
}
function determineHotswapMode(hotswap, hotswapFallback, watch2) {
  if (hotswap && hotswapFallback) {
    throw new import_toolkit_lib22.ToolkitError("ConflictingHotswapArgs", "Can not supply both --hotswap and --hotswap-fallback at the same time");
  } else if (!hotswap && !hotswapFallback) {
    if (hotswap === void 0 && hotswapFallback === void 0) {
      return watch2 ? "hotswap-only" /* HOTSWAP_ONLY */ : "full-deployment" /* FULL_DEPLOYMENT */;
    } else if (hotswap === false || hotswapFallback === false) {
      return "full-deployment" /* FULL_DEPLOYMENT */;
    }
  }
  let hotswapMode;
  if (hotswap) {
    hotswapMode = "hotswap-only" /* HOTSWAP_ONLY */;
  } else {
    hotswapMode = "fall-back" /* FALL_BACK */;
  }
  return hotswapMode;
}
function cli(args = process.argv.slice(2)) {
  let error4;
  exec4(args).then(async (value) => {
    if (typeof value === "number") {
      process.exitCode = value;
    }
  }).catch(async (err) => {
    prettyPrintError(err, isDeveloperBuildVersion());
    error4 = {
      name: cdkCliErrorName(err)
    };
    process.exitCode = 1;
  }).finally(async () => {
    try {
      await CliIoHost.get()?.telemetry?.end(error4);
    } catch (e32) {
      await CliIoHost.get()?.asIoHelper().defaults.trace(`Ending Telemetry failed: ${e32.message}`);
    }
  });
}
var cxapi14, import_toolkit_lib22, chalk38;
var init_cli = __esm({
  "lib/cli/cli.ts"() {
    "use strict";
    cxapi14 = __toESM(require_lib11());
    import_toolkit_lib22 = __toESM(require_lib12());
    chalk38 = __toESM(require_source());
    init_util9();
    init_cdk_toolkit();
    init_ci_systems();
    init_display_version();
    init_io_host2();
    init_parse_command_line_arguments();
    init_platform_warnings();
    init_pretty_print_error();
    init_proxy_agent();
    init_singleton_plugin_host();
    init_error2();
    init_user_configuration();
    init_trap_errors();
    init_version();
    init_api_private();
    init_api();
    init_aws_auth2();
    init_bootstrap3();
    init_deployments3();
    init_hotswap3();
    init_context5();
    init_docs();
    init_doctor();
    init_flags();
    init_init2();
    init_language();
    init_migrate();
    init_cxapp();
    init_check_unknown_options();
    init_ci();
    init_guess_agent();
    __name(exec4, "exec");
    __name(determineBootstrapVersion, "determineBootstrapVersion");
    __name(isFeatureEnabled, "isFeatureEnabled");
    __name(convertStackSelector, "convertStackSelector");
    __name(specificStacksOrAllRecursively, "specificStacksOrAllRecursively");
    __name(arrayFromYargs, "arrayFromYargs");
    __name(determineDiffMethod, "determineDiffMethod");
    __name(determineDeploymentMethod, "determineDeploymentMethod");
    __name(cliRequireUnstable, "cliRequireUnstable");
    __name(rejectIncompatibleOptions, "rejectIncompatibleOptions");
    __name(determineHotswapMode, "determineHotswapMode");
    __name(cli, "cli");
  }
});

// lib/index.js
var __createBinding2 = exports && exports.__createBinding || (Object.create ? (function(o10, m20, k32, k210) {
  if (k210 === void 0) k210 = k32;
  var desc = Object.getOwnPropertyDescriptor(m20, k32);
  if (!desc || ("get" in desc ? !m20.__esModule : desc.writable || desc.configurable)) {
    desc = { enumerable: true, get: /* @__PURE__ */ __name(function() {
      return m20[k32];
    }, "get") };
  }
  Object.defineProperty(o10, k210, desc);
}) : (function(o10, m20, k32, k210) {
  if (k210 === void 0) k210 = k32;
  o10[k210] = m20[k32];
}));
var __exportStar2 = exports && exports.__exportStar || function(m20, exports2) {
  for (var p10 in m20) if (p10 !== "default" && !Object.prototype.hasOwnProperty.call(exports2, p10)) __createBinding2(exports2, m20, p10);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.exec = exports.cli = void 0;
__exportStar2((init_api(), __toCommonJS(api_exports)), exports);
var cli_1 = (init_cli(), __toCommonJS(cli_exports));
Object.defineProperty(exports, "cli", { enumerable: true, get: /* @__PURE__ */ __name(function() {
  return cli_1.cli;
}, "get") });
Object.defineProperty(exports, "exec", { enumerable: true, get: /* @__PURE__ */ __name(function() {
  return cli_1.exec;
}, "get") });
/*! Bundled license information:

is-extglob/index.js:
  (*!
   * is-extglob <https://github.com/jonschlinkert/is-extglob>
   *
   * Copyright (c) 2014-2016, Jon Schlinkert.
   * Licensed under the MIT License.
   *)

is-glob/index.js:
  (*!
   * is-glob <https://github.com/jonschlinkert/is-glob>
   *
   * Copyright (c) 2014-2017, Jon Schlinkert.
   * Released under the MIT License.
   *)

is-number/index.js:
  (*!
   * is-number <https://github.com/jonschlinkert/is-number>
   *
   * Copyright (c) 2014-present, Jon Schlinkert.
   * Released under the MIT License.
   *)

to-regex-range/index.js:
  (*!
   * to-regex-range <https://github.com/micromatch/to-regex-range>
   *
   * Copyright (c) 2015-present, Jon Schlinkert.
   * Released under the MIT License.
   *)

fill-range/index.js:
  (*!
   * fill-range <https://github.com/jonschlinkert/fill-range>
   *
   * Copyright (c) 2014-present, Jon Schlinkert.
   * Licensed under the MIT License.
   *)

queue-microtask/index.js:
  (*! queue-microtask. MIT License. Feross Aboukhadijeh <https://feross.org/opensource> *)

run-parallel/index.js:
  (*! run-parallel. MIT License. Feross Aboukhadijeh <https://feross.org/opensource> *)

chokidar/esm/index.js:
  (*! chokidar - MIT License (c) 2012 Paul Miller (paulmillr.com) *)
*/
